#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 21420
#define LARGE_STATE_COUNT 3112
#define SYMBOL_COUNT 427
#define ALIAS_COUNT 16
#define TOKEN_COUNT 144
#define EXTERNAL_TOKEN_COUNT 7
#define FIELD_COUNT 38
#define MAX_ALIAS_SEQUENCE_LENGTH 11
#define PRODUCTION_ID_COUNT 239

enum ts_symbol_identifiers {
  sym__lowercase_identifier = 1,
  anon_sym_SEMI_SEMI = 2,
  anon_sym_let = 3,
  anon_sym_rec = 4,
  anon_sym_and = 5,
  anon_sym_COLON_GT = 6,
  anon_sym_EQ = 7,
  anon_sym_TILDE = 8,
  anon_sym_QMARK = 9,
  anon_sym_COLON = 10,
  anon_sym_LPAREN = 11,
  anon_sym_RPAREN = 12,
  anon_sym_external = 13,
  anon_sym_type = 14,
  anon_sym_nonrec = 15,
  anon_sym_private = 16,
  anon_sym_DOT_DOT = 17,
  anon_sym_PLUS_EQ = 18,
  anon_sym_COMMA = 19,
  anon_sym_PLUS = 20,
  anon_sym_BANG = 21,
  anon_sym_DASH = 22,
  anon_sym__ = 23,
  anon_sym_COLON_EQ = 24,
  anon_sym_PIPE = 25,
  anon_sym_LBRACK = 26,
  anon_sym_RBRACK = 27,
  anon_sym_true = 28,
  anon_sym_false = 29,
  anon_sym_of = 30,
  anon_sym_COLON2 = 31,
  anon_sym_DOT = 32,
  anon_sym_DASH_GT = 33,
  anon_sym_STAR = 34,
  anon_sym_LBRACE = 35,
  anon_sym_SEMI = 36,
  anon_sym_RBRACE = 37,
  anon_sym_mutable = 38,
  anon_sym_constraint = 39,
  anon_sym_exception = 40,
  anon_sym_module = 41,
  anon_sym_open = 42,
  anon_sym_include = 43,
  anon_sym_class = 44,
  anon_sym_virtual = 45,
  anon_sym_val = 46,
  anon_sym_sig = 47,
  anon_sym_end = 48,
  anon_sym_with = 49,
  anon_sym_functor = 50,
  anon_sym_struct = 51,
  anon_sym_object = 52,
  anon_sym_inherit = 53,
  anon_sym_method = 54,
  anon_sym_in = 55,
  anon_sym_fun = 56,
  anon_sym_as = 57,
  anon_sym_initializer = 58,
  anon_sym_LBRACK_GT = 59,
  anon_sym_LBRACK_LT = 60,
  anon_sym_GT = 61,
  anon_sym_AMP = 62,
  anon_sym_LT = 63,
  anon_sym_POUND = 64,
  anon_sym_COLON_COLON = 65,
  anon_sym_LBRACK_PIPE = 66,
  anon_sym_PIPE_RBRACK = 67,
  anon_sym_LT_DASH = 68,
  anon_sym_if = 69,
  anon_sym_then = 70,
  anon_sym_else = 71,
  anon_sym_while = 72,
  anon_sym_do = 73,
  anon_sym_done = 74,
  anon_sym_for = 75,
  anon_sym_to = 76,
  anon_sym_downto = 77,
  anon_sym_match = 78,
  anon_sym_when = 79,
  anon_sym_function = 80,
  anon_sym_try = 81,
  anon_sym_assert = 82,
  anon_sym_lazy = 83,
  anon_sym_new = 84,
  anon_sym_LBRACE_LT = 85,
  anon_sym_GT_RBRACE = 86,
  anon_sym_begin = 87,
  sym_ocamlyacc_value = 88,
  anon_sym_effect = 89,
  aux_sym_attribute_token1 = 90,
  anon_sym_LBRACK_AT_AT = 91,
  anon_sym_LBRACK_AT_AT_AT = 92,
  anon_sym_LBRACK_PERCENT = 93,
  anon_sym_LBRACE_PERCENT = 94,
  aux_sym_quoted_extension_token1 = 95,
  anon_sym_LBRACK_PERCENT_PERCENT = 96,
  anon_sym_LBRACE_PERCENT_PERCENT = 97,
  anon_sym_PERCENT = 98,
  aux_sym_number_token1 = 99,
  aux_sym_signed_number_token1 = 100,
  anon_sym_SQUOTE = 101,
  anon_sym_SQUOTE2 = 102,
  aux_sym_character_content_token1 = 103,
  aux_sym_character_content_token2 = 104,
  anon_sym_DQUOTE = 105,
  aux_sym_string_content_token1 = 106,
  aux_sym_string_content_token2 = 107,
  aux_sym_string_content_token3 = 108,
  aux_sym_string_content_token4 = 109,
  aux_sym_string_content_token5 = 110,
  aux_sym_quoted_string_content_token1 = 111,
  aux_sym_escape_sequence_token1 = 112,
  aux_sym_escape_sequence_token2 = 113,
  aux_sym_escape_sequence_token3 = 114,
  aux_sym_escape_sequence_token4 = 115,
  sym_conversion_specification = 116,
  sym_pretty_printing_indication = 117,
  sym_prefix_operator = 118,
  aux_sym_sign_operator_token1 = 119,
  sym_hash_operator = 120,
  sym_pow_operator = 121,
  sym_mult_operator = 122,
  aux_sym_add_operator_token1 = 123,
  sym_concat_operator = 124,
  sym_rel_operator = 125,
  sym_and_operator = 126,
  sym_or_operator = 127,
  sym_assign_operator = 128,
  sym_indexing_operator = 129,
  sym_let_operator = 130,
  sym_let_and_operator = 131,
  sym_match_operator = 132,
  sym__uppercase_identifier = 133,
  aux_sym_directive_token1 = 134,
  aux_sym_type_variable_token1 = 135,
  aux_sym_tag_token1 = 136,
  aux_sym_attribute_id_token1 = 137,
  sym_comment = 138,
  sym__left_quoted_string_delimiter = 139,
  sym__right_quoted_string_delimiter = 140,
  sym_line_number_directive = 141,
  sym__null = 142,
  sym__error_sentinel = 143,
  sym_compilation_unit = 144,
  sym__structure = 145,
  sym_expression_item = 146,
  sym__signature = 147,
  sym_toplevel_directive = 148,
  sym__structure_item = 149,
  sym_value_definition = 150,
  sym_let_binding = 151,
  sym_parameter = 152,
  sym_external = 153,
  sym_type_definition = 154,
  sym_type_binding = 155,
  sym__type_params = 156,
  sym__type_param = 157,
  sym__type_equation = 158,
  sym_variant_declaration = 159,
  sym_constructor_declaration = 160,
  sym__constructor_argument = 161,
  sym_record_declaration = 162,
  sym_field_declaration = 163,
  sym_type_constraint = 164,
  sym_exception_definition = 165,
  sym_module_definition = 166,
  sym_module_binding = 167,
  sym_module_parameter = 168,
  sym_module_type_definition = 169,
  sym_open_module = 170,
  sym_include_module = 171,
  sym_class_definition = 172,
  sym_class_binding = 173,
  sym_class_type_definition = 174,
  sym_class_type_binding = 175,
  sym__signature_item = 176,
  sym_value_specification = 177,
  sym_include_module_type = 178,
  sym__module_typed = 179,
  sym__module_type = 180,
  sym_signature = 181,
  sym_module_type_constraint = 182,
  sym_constrain_type = 183,
  sym_constrain_module = 184,
  sym_constrain_module_type = 185,
  sym_module_type_of = 186,
  sym_functor_type = 187,
  sym_parenthesized_module_type = 188,
  sym__simple_module_expression = 189,
  sym__module_expression = 190,
  sym_structure = 191,
  sym_functor = 192,
  sym_module_application = 193,
  sym_typed_module_expression = 194,
  sym_packed_module = 195,
  sym_parenthesized_module_expression = 196,
  sym__class_typed = 197,
  sym__simple_class_type = 198,
  sym__class_type = 199,
  sym_instantiated_class_type = 200,
  sym_class_body_type = 201,
  sym__class_field_specification = 202,
  sym_inheritance_specification = 203,
  sym_instance_variable_specification = 204,
  sym_method_specification = 205,
  sym_type_parameter_constraint = 206,
  sym_let_open_class_type = 207,
  sym_class_function_type = 208,
  sym__simple_class_expression = 209,
  sym__class_expression = 210,
  sym_instantiated_class = 211,
  sym_typed_class_expression = 212,
  sym_class_function = 213,
  sym_class_application = 214,
  sym_let_class_expression = 215,
  sym__class_field = 216,
  sym_inheritance_definition = 217,
  sym_instance_variable_definition = 218,
  sym_method_definition = 219,
  sym_class_initializer = 220,
  sym_let_open_class_expression = 221,
  sym_parenthesized_class_expression = 222,
  sym__typed = 223,
  sym__simple_typed = 224,
  sym__polymorphic_typed = 225,
  sym__polymorphic_type = 226,
  sym_polymorphic_type = 227,
  sym__abstract_type = 228,
  sym__parenthesized_abstract_type = 229,
  sym__simple_type = 230,
  sym__type = 231,
  sym_function_type = 232,
  sym_labeled_argument_type = 233,
  sym__proper_tuple_type = 234,
  sym__labeled_tuple_type = 235,
  sym_labeled_tuple_element_type = 236,
  sym__tuple_type_rhs = 237,
  sym_constructed_type = 238,
  sym_aliased_type = 239,
  sym_local_open_type = 240,
  sym_polymorphic_variant_type = 241,
  sym__tag_spec = 242,
  sym_tag_specification = 243,
  sym_package_type = 244,
  sym_object_type = 245,
  sym_method_type = 246,
  sym_hash_type = 247,
  sym_parenthesized_type = 248,
  sym__simple_expression = 249,
  sym__expression = 250,
  sym__sequence_expression = 251,
  sym_typed_expression = 252,
  sym_labeled_tuple_element = 253,
  sym__tuple_expression = 254,
  sym_cons_expression = 255,
  sym_list_expression = 256,
  sym_array_expression = 257,
  sym_record_expression = 258,
  sym_field_expression = 259,
  sym_application_expression = 260,
  sym_labeled_argument = 261,
  sym_prefix_expression = 262,
  sym_sign_expression = 263,
  sym_hash_expression = 264,
  sym_infix_expression = 265,
  sym_field_get_expression = 266,
  sym_array_get_expression = 267,
  sym_string_get_expression = 268,
  sym_bigarray_get_expression = 269,
  sym_set_expression = 270,
  sym_if_expression = 271,
  sym_then_clause = 272,
  sym_else_clause = 273,
  sym_while_expression = 274,
  sym_do_clause = 275,
  sym_for_expression = 276,
  sym__sequence_expression_anonymous = 277,
  sym_match_expression = 278,
  sym__match_cases = 279,
  sym_match_case = 280,
  sym_guard = 281,
  sym_refutation_case = 282,
  sym_function_expression = 283,
  sym_fun_expression = 284,
  sym_try_expression = 285,
  sym_let_expression = 286,
  sym_coercion_expression = 287,
  sym_assert_expression = 288,
  sym_lazy_expression = 289,
  sym_let_module_expression = 290,
  sym_let_open_expression = 291,
  sym_local_open_expression = 292,
  sym_package_expression = 293,
  sym_let_exception_expression = 294,
  sym_new_expression = 295,
  sym_object_copy_expression = 296,
  sym_instance_variable_expression = 297,
  sym_method_invocation = 298,
  sym_object_expression = 299,
  sym_parenthesized_expression = 300,
  sym__simple_pattern = 301,
  sym__effect_pattern = 302,
  sym__pattern = 303,
  sym__simple_binding_pattern = 304,
  sym__binding_pattern = 305,
  sym_alias_pattern = 306,
  sym_alias_binding_pattern = 307,
  sym_typed_pattern = 308,
  sym_typed_binding_pattern = 309,
  sym__or_pattern_anonymous = 310,
  sym__or_binding_pattern_anonymous = 311,
  sym_constructor_pattern = 312,
  sym_constructor_binding_pattern = 313,
  sym_tag_pattern = 314,
  sym_tag_binding_pattern = 315,
  sym_polymorphic_variant_pattern = 316,
  sym_labeled_tuple_element_pattern = 317,
  sym__tuple_pattern = 318,
  sym_labeled_tuple_element_binding_pattern = 319,
  sym__tuple_binding_pattern = 320,
  sym_record_pattern = 321,
  sym_field_pattern = 322,
  sym_record_binding_pattern = 323,
  sym_field_binding_pattern = 324,
  sym_list_pattern = 325,
  sym_list_binding_pattern = 326,
  sym_cons_pattern = 327,
  sym_cons_binding_pattern = 328,
  sym_array_pattern = 329,
  sym_array_binding_pattern = 330,
  sym_range_pattern = 331,
  sym_lazy_pattern = 332,
  sym_lazy_binding_pattern = 333,
  sym_local_open_pattern = 334,
  sym_local_open_binding_pattern = 335,
  sym_package_pattern = 336,
  sym_parenthesized_pattern = 337,
  sym_parenthesized_binding_pattern = 338,
  sym_exception_pattern = 339,
  sym_effect_pattern = 340,
  sym_attribute = 341,
  sym_item_attribute = 342,
  sym_floating_attribute = 343,
  sym_attribute_payload = 344,
  sym_extension = 345,
  sym_quoted_extension = 346,
  sym_item_extension = 347,
  sym_quoted_item_extension = 348,
  sym__attribute = 349,
  sym__constant = 350,
  sym__signed_constant = 351,
  sym_number = 352,
  sym_signed_number = 353,
  sym_character = 354,
  sym_character_content = 355,
  sym_string = 356,
  sym_string_content = 357,
  sym_quoted_string = 358,
  sym__quoted_string = 359,
  sym_quoted_string_content = 360,
  sym_escape_sequence = 361,
  sym_boolean = 362,
  sym_unit = 363,
  sym_sign_operator = 364,
  sym__infix_operator = 365,
  sym_add_operator = 366,
  sym_indexing_operator_path = 367,
  sym__value_name = 368,
  sym__simple_value_pattern = 369,
  sym_parenthesized_operator = 370,
  sym_value_path = 371,
  sym_module_path = 372,
  sym_extended_module_path = 373,
  sym_module_type_path = 374,
  sym_field_path = 375,
  sym_constructor_path = 376,
  sym_type_constructor_path = 377,
  sym_class_path = 378,
  sym_class_type_path = 379,
  sym__instance_variable_name = 380,
  sym__constructor_name = 381,
  sym_directive = 382,
  sym_type_variable = 383,
  sym_tag = 384,
  sym_attribute_id = 385,
  aux_sym__structure_repeat1 = 386,
  aux_sym__structure_repeat2 = 387,
  aux_sym_expression_item_repeat1 = 388,
  aux_sym__signature_repeat1 = 389,
  aux_sym_value_definition_repeat1 = 390,
  aux_sym_let_binding_repeat1 = 391,
  aux_sym_external_repeat1 = 392,
  aux_sym_type_definition_repeat1 = 393,
  aux_sym_type_binding_repeat1 = 394,
  aux_sym__type_params_repeat1 = 395,
  aux_sym_variant_declaration_repeat1 = 396,
  aux_sym_constructor_declaration_repeat1 = 397,
  aux_sym__constructor_argument_repeat1 = 398,
  aux_sym_record_declaration_repeat1 = 399,
  aux_sym_module_definition_repeat1 = 400,
  aux_sym_module_binding_repeat1 = 401,
  aux_sym_class_definition_repeat1 = 402,
  aux_sym_class_type_definition_repeat1 = 403,
  aux_sym_module_type_constraint_repeat1 = 404,
  aux_sym_instantiated_class_type_repeat1 = 405,
  aux_sym_class_body_type_repeat1 = 406,
  aux_sym_instance_variable_specification_repeat1 = 407,
  aux_sym_method_specification_repeat1 = 408,
  aux_sym_class_application_repeat1 = 409,
  aux_sym__abstract_type_repeat1 = 410,
  aux_sym_polymorphic_variant_type_repeat1 = 411,
  aux_sym_polymorphic_variant_type_repeat2 = 412,
  aux_sym_tag_specification_repeat1 = 413,
  aux_sym_object_type_repeat1 = 414,
  aux_sym_list_expression_repeat1 = 415,
  aux_sym_record_expression_repeat1 = 416,
  aux_sym__match_cases_repeat1 = 417,
  aux_sym_object_copy_expression_repeat1 = 418,
  aux_sym_object_expression_repeat1 = 419,
  aux_sym_record_pattern_repeat1 = 420,
  aux_sym_record_binding_pattern_repeat1 = 421,
  aux_sym_list_pattern_repeat1 = 422,
  aux_sym_list_binding_pattern_repeat1 = 423,
  aux_sym_string_content_repeat1 = 424,
  aux_sym_quoted_string_content_repeat1 = 425,
  aux_sym_attribute_id_repeat1 = 426,
  alias_sym_class_name = 427,
  alias_sym_class_type_name = 428,
  alias_sym_constructor_name = 429,
  alias_sym_field_name = 430,
  alias_sym_instance_variable_name = 431,
  alias_sym_label_name = 432,
  alias_sym_method_name = 433,
  alias_sym_module_name = 434,
  alias_sym_module_type_name = 435,
  alias_sym_or_pattern = 436,
  alias_sym_sequence_expression = 437,
  alias_sym_tuple_expression = 438,
  alias_sym_tuple_pattern = 439,
  alias_sym_type_constructor = 440,
  alias_sym_value_name = 441,
  alias_sym_value_pattern = 442,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__lowercase_identifier] = "_lowercase_identifier",
  [anon_sym_SEMI_SEMI] = ";;",
  [anon_sym_let] = "let",
  [anon_sym_rec] = "rec",
  [anon_sym_and] = "and",
  [anon_sym_COLON_GT] = ":>",
  [anon_sym_EQ] = "=",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_external] = "external",
  [anon_sym_type] = "type",
  [anon_sym_nonrec] = "nonrec",
  [anon_sym_private] = "private",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_COMMA] = ",",
  [anon_sym_PLUS] = "+",
  [anon_sym_BANG] = "!",
  [anon_sym_DASH] = "-",
  [anon_sym__] = "_",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_PIPE] = "|",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_of] = "of",
  [anon_sym_COLON2] = ":",
  [anon_sym_DOT] = ".",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_STAR] = "*",
  [anon_sym_LBRACE] = "{",
  [anon_sym_SEMI] = ";",
  [anon_sym_RBRACE] = "}",
  [anon_sym_mutable] = "mutable",
  [anon_sym_constraint] = "constraint",
  [anon_sym_exception] = "exception",
  [anon_sym_module] = "module",
  [anon_sym_open] = "open",
  [anon_sym_include] = "include",
  [anon_sym_class] = "class",
  [anon_sym_virtual] = "virtual",
  [anon_sym_val] = "val",
  [anon_sym_sig] = "sig",
  [anon_sym_end] = "end",
  [anon_sym_with] = "with",
  [anon_sym_functor] = "functor",
  [anon_sym_struct] = "struct",
  [anon_sym_object] = "object",
  [anon_sym_inherit] = "inherit",
  [anon_sym_method] = "method",
  [anon_sym_in] = "in",
  [anon_sym_fun] = "fun",
  [anon_sym_as] = "as",
  [anon_sym_initializer] = "initializer",
  [anon_sym_LBRACK_GT] = "[>",
  [anon_sym_LBRACK_LT] = "[<",
  [anon_sym_GT] = ">",
  [anon_sym_AMP] = "&",
  [anon_sym_LT] = "<",
  [anon_sym_POUND] = "#",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_LBRACK_PIPE] = "[|",
  [anon_sym_PIPE_RBRACK] = "|]",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_if] = "if",
  [anon_sym_then] = "then",
  [anon_sym_else] = "else",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_done] = "done",
  [anon_sym_for] = "for",
  [anon_sym_to] = "to",
  [anon_sym_downto] = "downto",
  [anon_sym_match] = "match",
  [anon_sym_when] = "when",
  [anon_sym_function] = "function",
  [anon_sym_try] = "try",
  [anon_sym_assert] = "assert",
  [anon_sym_lazy] = "lazy",
  [anon_sym_new] = "new",
  [anon_sym_LBRACE_LT] = "{<",
  [anon_sym_GT_RBRACE] = ">}",
  [anon_sym_begin] = "begin",
  [sym_ocamlyacc_value] = "ocamlyacc_value",
  [anon_sym_effect] = "effect",
  [aux_sym_attribute_token1] = "[@",
  [anon_sym_LBRACK_AT_AT] = "[@@",
  [anon_sym_LBRACK_AT_AT_AT] = "[@@@",
  [anon_sym_LBRACK_PERCENT] = "[%",
  [anon_sym_LBRACE_PERCENT] = "{%",
  [aux_sym_quoted_extension_token1] = "quoted_extension_token1",
  [anon_sym_LBRACK_PERCENT_PERCENT] = "[%%",
  [anon_sym_LBRACE_PERCENT_PERCENT] = "{%%",
  [anon_sym_PERCENT] = "%",
  [aux_sym_number_token1] = "number_token1",
  [aux_sym_signed_number_token1] = "signed_number_token1",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_SQUOTE2] = "'",
  [aux_sym_character_content_token1] = "character_content_token1",
  [aux_sym_character_content_token2] = "character_content_token2",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_content_token1] = "string_content_token1",
  [aux_sym_string_content_token2] = "string_content_token2",
  [aux_sym_string_content_token3] = "string_content_token3",
  [aux_sym_string_content_token4] = "escape_sequence",
  [aux_sym_string_content_token5] = "escape_sequence",
  [aux_sym_quoted_string_content_token1] = "quoted_string_content_token1",
  [aux_sym_escape_sequence_token1] = "escape_sequence_token1",
  [aux_sym_escape_sequence_token2] = "escape_sequence_token2",
  [aux_sym_escape_sequence_token3] = "escape_sequence_token3",
  [aux_sym_escape_sequence_token4] = "escape_sequence_token4",
  [sym_conversion_specification] = "conversion_specification",
  [sym_pretty_printing_indication] = "pretty_printing_indication",
  [sym_prefix_operator] = "prefix_operator",
  [aux_sym_sign_operator_token1] = "sign_operator_token1",
  [sym_hash_operator] = "hash_operator",
  [sym_pow_operator] = "pow_operator",
  [sym_mult_operator] = "mult_operator",
  [aux_sym_add_operator_token1] = "add_operator_token1",
  [sym_concat_operator] = "concat_operator",
  [sym_rel_operator] = "rel_operator",
  [sym_and_operator] = "and_operator",
  [sym_or_operator] = "or_operator",
  [sym_assign_operator] = "assign_operator",
  [sym_indexing_operator] = "indexing_operator",
  [sym_let_operator] = "let_operator",
  [sym_let_and_operator] = "let_and_operator",
  [sym_match_operator] = "match_operator",
  [sym__uppercase_identifier] = "_uppercase_identifier",
  [aux_sym_directive_token1] = "directive_token1",
  [aux_sym_type_variable_token1] = "type_variable_token1",
  [aux_sym_tag_token1] = "tag_token1",
  [aux_sym_attribute_id_token1] = "attribute_id_token1",
  [sym_comment] = "comment",
  [sym__left_quoted_string_delimiter] = "_left_quoted_string_delimiter",
  [sym__right_quoted_string_delimiter] = "_right_quoted_string_delimiter",
  [sym_line_number_directive] = "line_number_directive",
  [sym__null] = "_null",
  [sym__error_sentinel] = "_error_sentinel",
  [sym_compilation_unit] = "compilation_unit",
  [sym__structure] = "_structure",
  [sym_expression_item] = "expression_item",
  [sym__signature] = "_signature",
  [sym_toplevel_directive] = "toplevel_directive",
  [sym__structure_item] = "_structure_item",
  [sym_value_definition] = "value_definition",
  [sym_let_binding] = "let_binding",
  [sym_parameter] = "parameter",
  [sym_external] = "external",
  [sym_type_definition] = "type_definition",
  [sym_type_binding] = "type_binding",
  [sym__type_params] = "_type_params",
  [sym__type_param] = "_type_param",
  [sym__type_equation] = "_type_equation",
  [sym_variant_declaration] = "variant_declaration",
  [sym_constructor_declaration] = "constructor_declaration",
  [sym__constructor_argument] = "_constructor_argument",
  [sym_record_declaration] = "record_declaration",
  [sym_field_declaration] = "field_declaration",
  [sym_type_constraint] = "type_constraint",
  [sym_exception_definition] = "exception_definition",
  [sym_module_definition] = "module_definition",
  [sym_module_binding] = "module_binding",
  [sym_module_parameter] = "module_parameter",
  [sym_module_type_definition] = "module_type_definition",
  [sym_open_module] = "open_module",
  [sym_include_module] = "include_module",
  [sym_class_definition] = "class_definition",
  [sym_class_binding] = "class_binding",
  [sym_class_type_definition] = "class_type_definition",
  [sym_class_type_binding] = "class_type_binding",
  [sym__signature_item] = "_signature_item",
  [sym_value_specification] = "value_specification",
  [sym_include_module_type] = "include_module_type",
  [sym__module_typed] = "_module_typed",
  [sym__module_type] = "_module_type",
  [sym_signature] = "signature",
  [sym_module_type_constraint] = "module_type_constraint",
  [sym_constrain_type] = "constrain_type",
  [sym_constrain_module] = "constrain_module",
  [sym_constrain_module_type] = "constrain_module_type",
  [sym_module_type_of] = "module_type_of",
  [sym_functor_type] = "functor_type",
  [sym_parenthesized_module_type] = "parenthesized_module_type",
  [sym__simple_module_expression] = "_simple_module_expression",
  [sym__module_expression] = "_module_expression",
  [sym_structure] = "structure",
  [sym_functor] = "functor",
  [sym_module_application] = "module_application",
  [sym_typed_module_expression] = "typed_module_expression",
  [sym_packed_module] = "packed_module",
  [sym_parenthesized_module_expression] = "parenthesized_module_expression",
  [sym__class_typed] = "_class_typed",
  [sym__simple_class_type] = "_simple_class_type",
  [sym__class_type] = "_class_type",
  [sym_instantiated_class_type] = "instantiated_class_type",
  [sym_class_body_type] = "class_body_type",
  [sym__class_field_specification] = "_class_field_specification",
  [sym_inheritance_specification] = "inheritance_specification",
  [sym_instance_variable_specification] = "instance_variable_specification",
  [sym_method_specification] = "method_specification",
  [sym_type_parameter_constraint] = "type_parameter_constraint",
  [sym_let_open_class_type] = "let_open_class_type",
  [sym_class_function_type] = "class_function_type",
  [sym__simple_class_expression] = "_simple_class_expression",
  [sym__class_expression] = "_class_expression",
  [sym_instantiated_class] = "instantiated_class",
  [sym_typed_class_expression] = "typed_class_expression",
  [sym_class_function] = "class_function",
  [sym_class_application] = "class_application",
  [sym_let_class_expression] = "let_class_expression",
  [sym__class_field] = "_class_field",
  [sym_inheritance_definition] = "inheritance_definition",
  [sym_instance_variable_definition] = "instance_variable_definition",
  [sym_method_definition] = "method_definition",
  [sym_class_initializer] = "class_initializer",
  [sym_let_open_class_expression] = "let_open_class_expression",
  [sym_parenthesized_class_expression] = "parenthesized_class_expression",
  [sym__typed] = "_typed",
  [sym__simple_typed] = "_simple_typed",
  [sym__polymorphic_typed] = "_polymorphic_typed",
  [sym__polymorphic_type] = "_polymorphic_type",
  [sym_polymorphic_type] = "polymorphic_type",
  [sym__abstract_type] = "_abstract_type",
  [sym__parenthesized_abstract_type] = "abstract_type",
  [sym__simple_type] = "_simple_type",
  [sym__type] = "_type",
  [sym_function_type] = "function_type",
  [sym_labeled_argument_type] = "labeled_argument_type",
  [sym__proper_tuple_type] = "tuple_type",
  [sym__labeled_tuple_type] = "tuple_type",
  [sym_labeled_tuple_element_type] = "labeled_tuple_element_type",
  [sym__tuple_type_rhs] = "_tuple_type_rhs",
  [sym_constructed_type] = "constructed_type",
  [sym_aliased_type] = "aliased_type",
  [sym_local_open_type] = "local_open_type",
  [sym_polymorphic_variant_type] = "polymorphic_variant_type",
  [sym__tag_spec] = "_tag_spec",
  [sym_tag_specification] = "tag_specification",
  [sym_package_type] = "package_type",
  [sym_object_type] = "object_type",
  [sym_method_type] = "method_type",
  [sym_hash_type] = "hash_type",
  [sym_parenthesized_type] = "parenthesized_type",
  [sym__simple_expression] = "_simple_expression",
  [sym__expression] = "_expression",
  [sym__sequence_expression] = "_sequence_expression",
  [sym_typed_expression] = "typed_expression",
  [sym_labeled_tuple_element] = "labeled_tuple_element",
  [sym__tuple_expression] = "_tuple_expression",
  [sym_cons_expression] = "cons_expression",
  [sym_list_expression] = "list_expression",
  [sym_array_expression] = "array_expression",
  [sym_record_expression] = "record_expression",
  [sym_field_expression] = "field_expression",
  [sym_application_expression] = "application_expression",
  [sym_labeled_argument] = "labeled_argument",
  [sym_prefix_expression] = "prefix_expression",
  [sym_sign_expression] = "sign_expression",
  [sym_hash_expression] = "hash_expression",
  [sym_infix_expression] = "infix_expression",
  [sym_field_get_expression] = "field_get_expression",
  [sym_array_get_expression] = "array_get_expression",
  [sym_string_get_expression] = "string_get_expression",
  [sym_bigarray_get_expression] = "bigarray_get_expression",
  [sym_set_expression] = "set_expression",
  [sym_if_expression] = "if_expression",
  [sym_then_clause] = "then_clause",
  [sym_else_clause] = "else_clause",
  [sym_while_expression] = "while_expression",
  [sym_do_clause] = "do_clause",
  [sym_for_expression] = "for_expression",
  [sym__sequence_expression_anonymous] = "_sequence_expression_anonymous",
  [sym_match_expression] = "match_expression",
  [sym__match_cases] = "_match_cases",
  [sym_match_case] = "match_case",
  [sym_guard] = "guard",
  [sym_refutation_case] = "refutation_case",
  [sym_function_expression] = "function_expression",
  [sym_fun_expression] = "fun_expression",
  [sym_try_expression] = "try_expression",
  [sym_let_expression] = "let_expression",
  [sym_coercion_expression] = "coercion_expression",
  [sym_assert_expression] = "assert_expression",
  [sym_lazy_expression] = "lazy_expression",
  [sym_let_module_expression] = "let_module_expression",
  [sym_let_open_expression] = "let_open_expression",
  [sym_local_open_expression] = "local_open_expression",
  [sym_package_expression] = "package_expression",
  [sym_let_exception_expression] = "let_exception_expression",
  [sym_new_expression] = "new_expression",
  [sym_object_copy_expression] = "object_copy_expression",
  [sym_instance_variable_expression] = "instance_variable_expression",
  [sym_method_invocation] = "method_invocation",
  [sym_object_expression] = "object_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym__simple_pattern] = "_simple_pattern",
  [sym__effect_pattern] = "_effect_pattern",
  [sym__pattern] = "_pattern",
  [sym__simple_binding_pattern] = "_simple_binding_pattern",
  [sym__binding_pattern] = "_binding_pattern",
  [sym_alias_pattern] = "alias_pattern",
  [sym_alias_binding_pattern] = "alias_pattern",
  [sym_typed_pattern] = "typed_pattern",
  [sym_typed_binding_pattern] = "typed_pattern",
  [sym__or_pattern_anonymous] = "_or_pattern_anonymous",
  [sym__or_binding_pattern_anonymous] = "_or_binding_pattern_anonymous",
  [sym_constructor_pattern] = "constructor_pattern",
  [sym_constructor_binding_pattern] = "constructor_pattern",
  [sym_tag_pattern] = "tag_pattern",
  [sym_tag_binding_pattern] = "tag_pattern",
  [sym_polymorphic_variant_pattern] = "polymorphic_variant_pattern",
  [sym_labeled_tuple_element_pattern] = "labeled_tuple_element_pattern",
  [sym__tuple_pattern] = "_tuple_pattern",
  [sym_labeled_tuple_element_binding_pattern] = "labeled_tuple_element_binding_pattern",
  [sym__tuple_binding_pattern] = "_tuple_binding_pattern",
  [sym_record_pattern] = "record_pattern",
  [sym_field_pattern] = "field_pattern",
  [sym_record_binding_pattern] = "record_binding_pattern",
  [sym_field_binding_pattern] = "field_pattern",
  [sym_list_pattern] = "list_pattern",
  [sym_list_binding_pattern] = "list_binding_pattern",
  [sym_cons_pattern] = "cons_pattern",
  [sym_cons_binding_pattern] = "cons_pattern",
  [sym_array_pattern] = "array_pattern",
  [sym_array_binding_pattern] = "array_binding_pattern",
  [sym_range_pattern] = "range_pattern",
  [sym_lazy_pattern] = "lazy_pattern",
  [sym_lazy_binding_pattern] = "lazy_pattern",
  [sym_local_open_pattern] = "local_open_pattern",
  [sym_local_open_binding_pattern] = "local_open_pattern",
  [sym_package_pattern] = "package_pattern",
  [sym_parenthesized_pattern] = "parenthesized_pattern",
  [sym_parenthesized_binding_pattern] = "parenthesized_pattern",
  [sym_exception_pattern] = "exception_pattern",
  [sym_effect_pattern] = "effect_pattern",
  [sym_attribute] = "attribute",
  [sym_item_attribute] = "item_attribute",
  [sym_floating_attribute] = "floating_attribute",
  [sym_attribute_payload] = "attribute_payload",
  [sym_extension] = "extension",
  [sym_quoted_extension] = "quoted_extension",
  [sym_item_extension] = "item_extension",
  [sym_quoted_item_extension] = "quoted_item_extension",
  [sym__attribute] = "_attribute",
  [sym__constant] = "_constant",
  [sym__signed_constant] = "_signed_constant",
  [sym_number] = "number",
  [sym_signed_number] = "signed_number",
  [sym_character] = "character",
  [sym_character_content] = "character_content",
  [sym_string] = "string",
  [sym_string_content] = "string_content",
  [sym_quoted_string] = "quoted_string",
  [sym__quoted_string] = "_quoted_string",
  [sym_quoted_string_content] = "quoted_string_content",
  [sym_escape_sequence] = "escape_sequence",
  [sym_boolean] = "boolean",
  [sym_unit] = "unit",
  [sym_sign_operator] = "sign_operator",
  [sym__infix_operator] = "_infix_operator",
  [sym_add_operator] = "add_operator",
  [sym_indexing_operator_path] = "indexing_operator_path",
  [sym__value_name] = "_value_name",
  [sym__simple_value_pattern] = "_simple_value_pattern",
  [sym_parenthesized_operator] = "parenthesized_operator",
  [sym_value_path] = "value_path",
  [sym_module_path] = "module_path",
  [sym_extended_module_path] = "extended_module_path",
  [sym_module_type_path] = "module_type_path",
  [sym_field_path] = "field_path",
  [sym_constructor_path] = "constructor_path",
  [sym_type_constructor_path] = "type_constructor_path",
  [sym_class_path] = "class_path",
  [sym_class_type_path] = "class_type_path",
  [sym__instance_variable_name] = "_instance_variable_name",
  [sym__constructor_name] = "_constructor_name",
  [sym_directive] = "directive",
  [sym_type_variable] = "type_variable",
  [sym_tag] = "tag",
  [sym_attribute_id] = "attribute_id",
  [aux_sym__structure_repeat1] = "_structure_repeat1",
  [aux_sym__structure_repeat2] = "_structure_repeat2",
  [aux_sym_expression_item_repeat1] = "expression_item_repeat1",
  [aux_sym__signature_repeat1] = "_signature_repeat1",
  [aux_sym_value_definition_repeat1] = "value_definition_repeat1",
  [aux_sym_let_binding_repeat1] = "let_binding_repeat1",
  [aux_sym_external_repeat1] = "external_repeat1",
  [aux_sym_type_definition_repeat1] = "type_definition_repeat1",
  [aux_sym_type_binding_repeat1] = "type_binding_repeat1",
  [aux_sym__type_params_repeat1] = "_type_params_repeat1",
  [aux_sym_variant_declaration_repeat1] = "variant_declaration_repeat1",
  [aux_sym_constructor_declaration_repeat1] = "constructor_declaration_repeat1",
  [aux_sym__constructor_argument_repeat1] = "_constructor_argument_repeat1",
  [aux_sym_record_declaration_repeat1] = "record_declaration_repeat1",
  [aux_sym_module_definition_repeat1] = "module_definition_repeat1",
  [aux_sym_module_binding_repeat1] = "module_binding_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [aux_sym_class_type_definition_repeat1] = "class_type_definition_repeat1",
  [aux_sym_module_type_constraint_repeat1] = "module_type_constraint_repeat1",
  [aux_sym_instantiated_class_type_repeat1] = "instantiated_class_type_repeat1",
  [aux_sym_class_body_type_repeat1] = "class_body_type_repeat1",
  [aux_sym_instance_variable_specification_repeat1] = "instance_variable_specification_repeat1",
  [aux_sym_method_specification_repeat1] = "method_specification_repeat1",
  [aux_sym_class_application_repeat1] = "class_application_repeat1",
  [aux_sym__abstract_type_repeat1] = "_abstract_type_repeat1",
  [aux_sym_polymorphic_variant_type_repeat1] = "polymorphic_variant_type_repeat1",
  [aux_sym_polymorphic_variant_type_repeat2] = "polymorphic_variant_type_repeat2",
  [aux_sym_tag_specification_repeat1] = "tag_specification_repeat1",
  [aux_sym_object_type_repeat1] = "object_type_repeat1",
  [aux_sym_list_expression_repeat1] = "list_expression_repeat1",
  [aux_sym_record_expression_repeat1] = "record_expression_repeat1",
  [aux_sym__match_cases_repeat1] = "_match_cases_repeat1",
  [aux_sym_object_copy_expression_repeat1] = "object_copy_expression_repeat1",
  [aux_sym_object_expression_repeat1] = "object_expression_repeat1",
  [aux_sym_record_pattern_repeat1] = "record_pattern_repeat1",
  [aux_sym_record_binding_pattern_repeat1] = "record_binding_pattern_repeat1",
  [aux_sym_list_pattern_repeat1] = "list_pattern_repeat1",
  [aux_sym_list_binding_pattern_repeat1] = "list_binding_pattern_repeat1",
  [aux_sym_string_content_repeat1] = "string_content_repeat1",
  [aux_sym_quoted_string_content_repeat1] = "quoted_string_content_repeat1",
  [aux_sym_attribute_id_repeat1] = "attribute_id_repeat1",
  [alias_sym_class_name] = "class_name",
  [alias_sym_class_type_name] = "class_type_name",
  [alias_sym_constructor_name] = "constructor_name",
  [alias_sym_field_name] = "field_name",
  [alias_sym_instance_variable_name] = "instance_variable_name",
  [alias_sym_label_name] = "label_name",
  [alias_sym_method_name] = "method_name",
  [alias_sym_module_name] = "module_name",
  [alias_sym_module_type_name] = "module_type_name",
  [alias_sym_or_pattern] = "or_pattern",
  [alias_sym_sequence_expression] = "sequence_expression",
  [alias_sym_tuple_expression] = "tuple_expression",
  [alias_sym_tuple_pattern] = "tuple_pattern",
  [alias_sym_type_constructor] = "type_constructor",
  [alias_sym_value_name] = "value_name",
  [alias_sym_value_pattern] = "value_pattern",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__lowercase_identifier] = sym__lowercase_identifier,
  [anon_sym_SEMI_SEMI] = anon_sym_SEMI_SEMI,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_rec] = anon_sym_rec,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_COLON_GT] = anon_sym_COLON_GT,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_external] = anon_sym_external,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_nonrec] = anon_sym_nonrec,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym__] = anon_sym__,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_COLON2] = anon_sym_COLON,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_mutable] = anon_sym_mutable,
  [anon_sym_constraint] = anon_sym_constraint,
  [anon_sym_exception] = anon_sym_exception,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_open] = anon_sym_open,
  [anon_sym_include] = anon_sym_include,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_virtual] = anon_sym_virtual,
  [anon_sym_val] = anon_sym_val,
  [anon_sym_sig] = anon_sym_sig,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_functor] = anon_sym_functor,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_inherit] = anon_sym_inherit,
  [anon_sym_method] = anon_sym_method,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_fun] = anon_sym_fun,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_initializer] = anon_sym_initializer,
  [anon_sym_LBRACK_GT] = anon_sym_LBRACK_GT,
  [anon_sym_LBRACK_LT] = anon_sym_LBRACK_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_LBRACK_PIPE] = anon_sym_LBRACK_PIPE,
  [anon_sym_PIPE_RBRACK] = anon_sym_PIPE_RBRACK,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_done] = anon_sym_done,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_downto] = anon_sym_downto,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_lazy] = anon_sym_lazy,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_LBRACE_LT] = anon_sym_LBRACE_LT,
  [anon_sym_GT_RBRACE] = anon_sym_GT_RBRACE,
  [anon_sym_begin] = anon_sym_begin,
  [sym_ocamlyacc_value] = sym_ocamlyacc_value,
  [anon_sym_effect] = anon_sym_effect,
  [aux_sym_attribute_token1] = aux_sym_attribute_token1,
  [anon_sym_LBRACK_AT_AT] = anon_sym_LBRACK_AT_AT,
  [anon_sym_LBRACK_AT_AT_AT] = anon_sym_LBRACK_AT_AT_AT,
  [anon_sym_LBRACK_PERCENT] = anon_sym_LBRACK_PERCENT,
  [anon_sym_LBRACE_PERCENT] = anon_sym_LBRACE_PERCENT,
  [aux_sym_quoted_extension_token1] = aux_sym_quoted_extension_token1,
  [anon_sym_LBRACK_PERCENT_PERCENT] = anon_sym_LBRACK_PERCENT_PERCENT,
  [anon_sym_LBRACE_PERCENT_PERCENT] = anon_sym_LBRACE_PERCENT_PERCENT,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [aux_sym_number_token1] = aux_sym_number_token1,
  [aux_sym_signed_number_token1] = aux_sym_signed_number_token1,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_SQUOTE2] = anon_sym_SQUOTE,
  [aux_sym_character_content_token1] = aux_sym_character_content_token1,
  [aux_sym_character_content_token2] = aux_sym_character_content_token2,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_content_token1] = aux_sym_string_content_token1,
  [aux_sym_string_content_token2] = aux_sym_string_content_token2,
  [aux_sym_string_content_token3] = aux_sym_string_content_token3,
  [aux_sym_string_content_token4] = sym_escape_sequence,
  [aux_sym_string_content_token5] = sym_escape_sequence,
  [aux_sym_quoted_string_content_token1] = aux_sym_quoted_string_content_token1,
  [aux_sym_escape_sequence_token1] = aux_sym_escape_sequence_token1,
  [aux_sym_escape_sequence_token2] = aux_sym_escape_sequence_token2,
  [aux_sym_escape_sequence_token3] = aux_sym_escape_sequence_token3,
  [aux_sym_escape_sequence_token4] = aux_sym_escape_sequence_token4,
  [sym_conversion_specification] = sym_conversion_specification,
  [sym_pretty_printing_indication] = sym_pretty_printing_indication,
  [sym_prefix_operator] = sym_prefix_operator,
  [aux_sym_sign_operator_token1] = aux_sym_sign_operator_token1,
  [sym_hash_operator] = sym_hash_operator,
  [sym_pow_operator] = sym_pow_operator,
  [sym_mult_operator] = sym_mult_operator,
  [aux_sym_add_operator_token1] = aux_sym_add_operator_token1,
  [sym_concat_operator] = sym_concat_operator,
  [sym_rel_operator] = sym_rel_operator,
  [sym_and_operator] = sym_and_operator,
  [sym_or_operator] = sym_or_operator,
  [sym_assign_operator] = sym_assign_operator,
  [sym_indexing_operator] = sym_indexing_operator,
  [sym_let_operator] = sym_let_operator,
  [sym_let_and_operator] = sym_let_and_operator,
  [sym_match_operator] = sym_match_operator,
  [sym__uppercase_identifier] = sym__uppercase_identifier,
  [aux_sym_directive_token1] = aux_sym_directive_token1,
  [aux_sym_type_variable_token1] = aux_sym_type_variable_token1,
  [aux_sym_tag_token1] = aux_sym_tag_token1,
  [aux_sym_attribute_id_token1] = aux_sym_attribute_id_token1,
  [sym_comment] = sym_comment,
  [sym__left_quoted_string_delimiter] = sym__left_quoted_string_delimiter,
  [sym__right_quoted_string_delimiter] = sym__right_quoted_string_delimiter,
  [sym_line_number_directive] = sym_line_number_directive,
  [sym__null] = sym__null,
  [sym__error_sentinel] = sym__error_sentinel,
  [sym_compilation_unit] = sym_compilation_unit,
  [sym__structure] = sym__structure,
  [sym_expression_item] = sym_expression_item,
  [sym__signature] = sym__signature,
  [sym_toplevel_directive] = sym_toplevel_directive,
  [sym__structure_item] = sym__structure_item,
  [sym_value_definition] = sym_value_definition,
  [sym_let_binding] = sym_let_binding,
  [sym_parameter] = sym_parameter,
  [sym_external] = sym_external,
  [sym_type_definition] = sym_type_definition,
  [sym_type_binding] = sym_type_binding,
  [sym__type_params] = sym__type_params,
  [sym__type_param] = sym__type_param,
  [sym__type_equation] = sym__type_equation,
  [sym_variant_declaration] = sym_variant_declaration,
  [sym_constructor_declaration] = sym_constructor_declaration,
  [sym__constructor_argument] = sym__constructor_argument,
  [sym_record_declaration] = sym_record_declaration,
  [sym_field_declaration] = sym_field_declaration,
  [sym_type_constraint] = sym_type_constraint,
  [sym_exception_definition] = sym_exception_definition,
  [sym_module_definition] = sym_module_definition,
  [sym_module_binding] = sym_module_binding,
  [sym_module_parameter] = sym_module_parameter,
  [sym_module_type_definition] = sym_module_type_definition,
  [sym_open_module] = sym_open_module,
  [sym_include_module] = sym_include_module,
  [sym_class_definition] = sym_class_definition,
  [sym_class_binding] = sym_class_binding,
  [sym_class_type_definition] = sym_class_type_definition,
  [sym_class_type_binding] = sym_class_type_binding,
  [sym__signature_item] = sym__signature_item,
  [sym_value_specification] = sym_value_specification,
  [sym_include_module_type] = sym_include_module_type,
  [sym__module_typed] = sym__module_typed,
  [sym__module_type] = sym__module_type,
  [sym_signature] = sym_signature,
  [sym_module_type_constraint] = sym_module_type_constraint,
  [sym_constrain_type] = sym_constrain_type,
  [sym_constrain_module] = sym_constrain_module,
  [sym_constrain_module_type] = sym_constrain_module_type,
  [sym_module_type_of] = sym_module_type_of,
  [sym_functor_type] = sym_functor_type,
  [sym_parenthesized_module_type] = sym_parenthesized_module_type,
  [sym__simple_module_expression] = sym__simple_module_expression,
  [sym__module_expression] = sym__module_expression,
  [sym_structure] = sym_structure,
  [sym_functor] = sym_functor,
  [sym_module_application] = sym_module_application,
  [sym_typed_module_expression] = sym_typed_module_expression,
  [sym_packed_module] = sym_packed_module,
  [sym_parenthesized_module_expression] = sym_parenthesized_module_expression,
  [sym__class_typed] = sym__class_typed,
  [sym__simple_class_type] = sym__simple_class_type,
  [sym__class_type] = sym__class_type,
  [sym_instantiated_class_type] = sym_instantiated_class_type,
  [sym_class_body_type] = sym_class_body_type,
  [sym__class_field_specification] = sym__class_field_specification,
  [sym_inheritance_specification] = sym_inheritance_specification,
  [sym_instance_variable_specification] = sym_instance_variable_specification,
  [sym_method_specification] = sym_method_specification,
  [sym_type_parameter_constraint] = sym_type_parameter_constraint,
  [sym_let_open_class_type] = sym_let_open_class_type,
  [sym_class_function_type] = sym_class_function_type,
  [sym__simple_class_expression] = sym__simple_class_expression,
  [sym__class_expression] = sym__class_expression,
  [sym_instantiated_class] = sym_instantiated_class,
  [sym_typed_class_expression] = sym_typed_class_expression,
  [sym_class_function] = sym_class_function,
  [sym_class_application] = sym_class_application,
  [sym_let_class_expression] = sym_let_class_expression,
  [sym__class_field] = sym__class_field,
  [sym_inheritance_definition] = sym_inheritance_definition,
  [sym_instance_variable_definition] = sym_instance_variable_definition,
  [sym_method_definition] = sym_method_definition,
  [sym_class_initializer] = sym_class_initializer,
  [sym_let_open_class_expression] = sym_let_open_class_expression,
  [sym_parenthesized_class_expression] = sym_parenthesized_class_expression,
  [sym__typed] = sym__typed,
  [sym__simple_typed] = sym__simple_typed,
  [sym__polymorphic_typed] = sym__polymorphic_typed,
  [sym__polymorphic_type] = sym__polymorphic_type,
  [sym_polymorphic_type] = sym_polymorphic_type,
  [sym__abstract_type] = sym__abstract_type,
  [sym__parenthesized_abstract_type] = sym__parenthesized_abstract_type,
  [sym__simple_type] = sym__simple_type,
  [sym__type] = sym__type,
  [sym_function_type] = sym_function_type,
  [sym_labeled_argument_type] = sym_labeled_argument_type,
  [sym__proper_tuple_type] = sym__proper_tuple_type,
  [sym__labeled_tuple_type] = sym__proper_tuple_type,
  [sym_labeled_tuple_element_type] = sym_labeled_tuple_element_type,
  [sym__tuple_type_rhs] = sym__tuple_type_rhs,
  [sym_constructed_type] = sym_constructed_type,
  [sym_aliased_type] = sym_aliased_type,
  [sym_local_open_type] = sym_local_open_type,
  [sym_polymorphic_variant_type] = sym_polymorphic_variant_type,
  [sym__tag_spec] = sym__tag_spec,
  [sym_tag_specification] = sym_tag_specification,
  [sym_package_type] = sym_package_type,
  [sym_object_type] = sym_object_type,
  [sym_method_type] = sym_method_type,
  [sym_hash_type] = sym_hash_type,
  [sym_parenthesized_type] = sym_parenthesized_type,
  [sym__simple_expression] = sym__simple_expression,
  [sym__expression] = sym__expression,
  [sym__sequence_expression] = sym__sequence_expression,
  [sym_typed_expression] = sym_typed_expression,
  [sym_labeled_tuple_element] = sym_labeled_tuple_element,
  [sym__tuple_expression] = sym__tuple_expression,
  [sym_cons_expression] = sym_cons_expression,
  [sym_list_expression] = sym_list_expression,
  [sym_array_expression] = sym_array_expression,
  [sym_record_expression] = sym_record_expression,
  [sym_field_expression] = sym_field_expression,
  [sym_application_expression] = sym_application_expression,
  [sym_labeled_argument] = sym_labeled_argument,
  [sym_prefix_expression] = sym_prefix_expression,
  [sym_sign_expression] = sym_sign_expression,
  [sym_hash_expression] = sym_hash_expression,
  [sym_infix_expression] = sym_infix_expression,
  [sym_field_get_expression] = sym_field_get_expression,
  [sym_array_get_expression] = sym_array_get_expression,
  [sym_string_get_expression] = sym_string_get_expression,
  [sym_bigarray_get_expression] = sym_bigarray_get_expression,
  [sym_set_expression] = sym_set_expression,
  [sym_if_expression] = sym_if_expression,
  [sym_then_clause] = sym_then_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_while_expression] = sym_while_expression,
  [sym_do_clause] = sym_do_clause,
  [sym_for_expression] = sym_for_expression,
  [sym__sequence_expression_anonymous] = sym__sequence_expression_anonymous,
  [sym_match_expression] = sym_match_expression,
  [sym__match_cases] = sym__match_cases,
  [sym_match_case] = sym_match_case,
  [sym_guard] = sym_guard,
  [sym_refutation_case] = sym_refutation_case,
  [sym_function_expression] = sym_function_expression,
  [sym_fun_expression] = sym_fun_expression,
  [sym_try_expression] = sym_try_expression,
  [sym_let_expression] = sym_let_expression,
  [sym_coercion_expression] = sym_coercion_expression,
  [sym_assert_expression] = sym_assert_expression,
  [sym_lazy_expression] = sym_lazy_expression,
  [sym_let_module_expression] = sym_let_module_expression,
  [sym_let_open_expression] = sym_let_open_expression,
  [sym_local_open_expression] = sym_local_open_expression,
  [sym_package_expression] = sym_package_expression,
  [sym_let_exception_expression] = sym_let_exception_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_object_copy_expression] = sym_object_copy_expression,
  [sym_instance_variable_expression] = sym_instance_variable_expression,
  [sym_method_invocation] = sym_method_invocation,
  [sym_object_expression] = sym_object_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym__simple_pattern] = sym__simple_pattern,
  [sym__effect_pattern] = sym__effect_pattern,
  [sym__pattern] = sym__pattern,
  [sym__simple_binding_pattern] = sym__simple_binding_pattern,
  [sym__binding_pattern] = sym__binding_pattern,
  [sym_alias_pattern] = sym_alias_pattern,
  [sym_alias_binding_pattern] = sym_alias_pattern,
  [sym_typed_pattern] = sym_typed_pattern,
  [sym_typed_binding_pattern] = sym_typed_pattern,
  [sym__or_pattern_anonymous] = sym__or_pattern_anonymous,
  [sym__or_binding_pattern_anonymous] = sym__or_binding_pattern_anonymous,
  [sym_constructor_pattern] = sym_constructor_pattern,
  [sym_constructor_binding_pattern] = sym_constructor_pattern,
  [sym_tag_pattern] = sym_tag_pattern,
  [sym_tag_binding_pattern] = sym_tag_pattern,
  [sym_polymorphic_variant_pattern] = sym_polymorphic_variant_pattern,
  [sym_labeled_tuple_element_pattern] = sym_labeled_tuple_element_pattern,
  [sym__tuple_pattern] = sym__tuple_pattern,
  [sym_labeled_tuple_element_binding_pattern] = sym_labeled_tuple_element_binding_pattern,
  [sym__tuple_binding_pattern] = sym__tuple_binding_pattern,
  [sym_record_pattern] = sym_record_pattern,
  [sym_field_pattern] = sym_field_pattern,
  [sym_record_binding_pattern] = sym_record_binding_pattern,
  [sym_field_binding_pattern] = sym_field_pattern,
  [sym_list_pattern] = sym_list_pattern,
  [sym_list_binding_pattern] = sym_list_binding_pattern,
  [sym_cons_pattern] = sym_cons_pattern,
  [sym_cons_binding_pattern] = sym_cons_pattern,
  [sym_array_pattern] = sym_array_pattern,
  [sym_array_binding_pattern] = sym_array_binding_pattern,
  [sym_range_pattern] = sym_range_pattern,
  [sym_lazy_pattern] = sym_lazy_pattern,
  [sym_lazy_binding_pattern] = sym_lazy_pattern,
  [sym_local_open_pattern] = sym_local_open_pattern,
  [sym_local_open_binding_pattern] = sym_local_open_pattern,
  [sym_package_pattern] = sym_package_pattern,
  [sym_parenthesized_pattern] = sym_parenthesized_pattern,
  [sym_parenthesized_binding_pattern] = sym_parenthesized_pattern,
  [sym_exception_pattern] = sym_exception_pattern,
  [sym_effect_pattern] = sym_effect_pattern,
  [sym_attribute] = sym_attribute,
  [sym_item_attribute] = sym_item_attribute,
  [sym_floating_attribute] = sym_floating_attribute,
  [sym_attribute_payload] = sym_attribute_payload,
  [sym_extension] = sym_extension,
  [sym_quoted_extension] = sym_quoted_extension,
  [sym_item_extension] = sym_item_extension,
  [sym_quoted_item_extension] = sym_quoted_item_extension,
  [sym__attribute] = sym__attribute,
  [sym__constant] = sym__constant,
  [sym__signed_constant] = sym__signed_constant,
  [sym_number] = sym_number,
  [sym_signed_number] = sym_signed_number,
  [sym_character] = sym_character,
  [sym_character_content] = sym_character_content,
  [sym_string] = sym_string,
  [sym_string_content] = sym_string_content,
  [sym_quoted_string] = sym_quoted_string,
  [sym__quoted_string] = sym__quoted_string,
  [sym_quoted_string_content] = sym_quoted_string_content,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_boolean] = sym_boolean,
  [sym_unit] = sym_unit,
  [sym_sign_operator] = sym_sign_operator,
  [sym__infix_operator] = sym__infix_operator,
  [sym_add_operator] = sym_add_operator,
  [sym_indexing_operator_path] = sym_indexing_operator_path,
  [sym__value_name] = sym__value_name,
  [sym__simple_value_pattern] = sym__simple_value_pattern,
  [sym_parenthesized_operator] = sym_parenthesized_operator,
  [sym_value_path] = sym_value_path,
  [sym_module_path] = sym_module_path,
  [sym_extended_module_path] = sym_extended_module_path,
  [sym_module_type_path] = sym_module_type_path,
  [sym_field_path] = sym_field_path,
  [sym_constructor_path] = sym_constructor_path,
  [sym_type_constructor_path] = sym_type_constructor_path,
  [sym_class_path] = sym_class_path,
  [sym_class_type_path] = sym_class_type_path,
  [sym__instance_variable_name] = sym__instance_variable_name,
  [sym__constructor_name] = sym__constructor_name,
  [sym_directive] = sym_directive,
  [sym_type_variable] = sym_type_variable,
  [sym_tag] = sym_tag,
  [sym_attribute_id] = sym_attribute_id,
  [aux_sym__structure_repeat1] = aux_sym__structure_repeat1,
  [aux_sym__structure_repeat2] = aux_sym__structure_repeat2,
  [aux_sym_expression_item_repeat1] = aux_sym_expression_item_repeat1,
  [aux_sym__signature_repeat1] = aux_sym__signature_repeat1,
  [aux_sym_value_definition_repeat1] = aux_sym_value_definition_repeat1,
  [aux_sym_let_binding_repeat1] = aux_sym_let_binding_repeat1,
  [aux_sym_external_repeat1] = aux_sym_external_repeat1,
  [aux_sym_type_definition_repeat1] = aux_sym_type_definition_repeat1,
  [aux_sym_type_binding_repeat1] = aux_sym_type_binding_repeat1,
  [aux_sym__type_params_repeat1] = aux_sym__type_params_repeat1,
  [aux_sym_variant_declaration_repeat1] = aux_sym_variant_declaration_repeat1,
  [aux_sym_constructor_declaration_repeat1] = aux_sym_constructor_declaration_repeat1,
  [aux_sym__constructor_argument_repeat1] = aux_sym__constructor_argument_repeat1,
  [aux_sym_record_declaration_repeat1] = aux_sym_record_declaration_repeat1,
  [aux_sym_module_definition_repeat1] = aux_sym_module_definition_repeat1,
  [aux_sym_module_binding_repeat1] = aux_sym_module_binding_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [aux_sym_class_type_definition_repeat1] = aux_sym_class_type_definition_repeat1,
  [aux_sym_module_type_constraint_repeat1] = aux_sym_module_type_constraint_repeat1,
  [aux_sym_instantiated_class_type_repeat1] = aux_sym_instantiated_class_type_repeat1,
  [aux_sym_class_body_type_repeat1] = aux_sym_class_body_type_repeat1,
  [aux_sym_instance_variable_specification_repeat1] = aux_sym_instance_variable_specification_repeat1,
  [aux_sym_method_specification_repeat1] = aux_sym_method_specification_repeat1,
  [aux_sym_class_application_repeat1] = aux_sym_class_application_repeat1,
  [aux_sym__abstract_type_repeat1] = aux_sym__abstract_type_repeat1,
  [aux_sym_polymorphic_variant_type_repeat1] = aux_sym_polymorphic_variant_type_repeat1,
  [aux_sym_polymorphic_variant_type_repeat2] = aux_sym_polymorphic_variant_type_repeat2,
  [aux_sym_tag_specification_repeat1] = aux_sym_tag_specification_repeat1,
  [aux_sym_object_type_repeat1] = aux_sym_object_type_repeat1,
  [aux_sym_list_expression_repeat1] = aux_sym_list_expression_repeat1,
  [aux_sym_record_expression_repeat1] = aux_sym_record_expression_repeat1,
  [aux_sym__match_cases_repeat1] = aux_sym__match_cases_repeat1,
  [aux_sym_object_copy_expression_repeat1] = aux_sym_object_copy_expression_repeat1,
  [aux_sym_object_expression_repeat1] = aux_sym_object_expression_repeat1,
  [aux_sym_record_pattern_repeat1] = aux_sym_record_pattern_repeat1,
  [aux_sym_record_binding_pattern_repeat1] = aux_sym_record_binding_pattern_repeat1,
  [aux_sym_list_pattern_repeat1] = aux_sym_list_pattern_repeat1,
  [aux_sym_list_binding_pattern_repeat1] = aux_sym_list_binding_pattern_repeat1,
  [aux_sym_string_content_repeat1] = aux_sym_string_content_repeat1,
  [aux_sym_quoted_string_content_repeat1] = aux_sym_quoted_string_content_repeat1,
  [aux_sym_attribute_id_repeat1] = aux_sym_attribute_id_repeat1,
  [alias_sym_class_name] = alias_sym_class_name,
  [alias_sym_class_type_name] = alias_sym_class_type_name,
  [alias_sym_constructor_name] = alias_sym_constructor_name,
  [alias_sym_field_name] = alias_sym_field_name,
  [alias_sym_instance_variable_name] = alias_sym_instance_variable_name,
  [alias_sym_label_name] = alias_sym_label_name,
  [alias_sym_method_name] = alias_sym_method_name,
  [alias_sym_module_name] = alias_sym_module_name,
  [alias_sym_module_type_name] = alias_sym_module_type_name,
  [alias_sym_or_pattern] = alias_sym_or_pattern,
  [alias_sym_sequence_expression] = alias_sym_sequence_expression,
  [alias_sym_tuple_expression] = alias_sym_tuple_expression,
  [alias_sym_tuple_pattern] = alias_sym_tuple_pattern,
  [alias_sym_type_constructor] = alias_sym_type_constructor,
  [alias_sym_value_name] = alias_sym_value_name,
  [alias_sym_value_pattern] = alias_sym_value_pattern,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__lowercase_identifier] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SEMI_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_external] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonrec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mutable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constraint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exception] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_open] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_include] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_virtual] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_val] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sig] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_functor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inherit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_method] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fun] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_initializer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_done] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_downto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lazy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_begin] = {
    .visible = true,
    .named = false,
  },
  [sym_ocamlyacc_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_effect] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_attribute_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_AT_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_quoted_extension_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACK_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_signed_number_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_character_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_character_content_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_token4] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_string_content_token5] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_quoted_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token4] = {
    .visible = false,
    .named = false,
  },
  [sym_conversion_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_pretty_printing_indication] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_sign_operator_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_hash_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_pow_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_mult_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_add_operator_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_concat_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_rel_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_and_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_or_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_assign_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indexing_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_let_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_let_and_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_match_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__uppercase_identifier] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_directive_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_variable_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tag_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_id_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__left_quoted_string_delimiter] = {
    .visible = false,
    .named = true,
  },
  [sym__right_quoted_string_delimiter] = {
    .visible = false,
    .named = true,
  },
  [sym_line_number_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__null] = {
    .visible = false,
    .named = true,
  },
  [sym__error_sentinel] = {
    .visible = false,
    .named = true,
  },
  [sym_compilation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__structure] = {
    .visible = false,
    .named = true,
  },
  [sym_expression_item] = {
    .visible = true,
    .named = true,
  },
  [sym__signature] = {
    .visible = false,
    .named = true,
  },
  [sym_toplevel_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__structure_item] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_value_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_let_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_external] = {
    .visible = true,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_binding] = {
    .visible = true,
    .named = true,
  },
  [sym__type_params] = {
    .visible = false,
    .named = true,
  },
  [sym__type_param] = {
    .visible = false,
    .named = true,
  },
  [sym__type_equation] = {
    .visible = false,
    .named = true,
  },
  [sym_variant_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__constructor_argument] = {
    .visible = false,
    .named = true,
  },
  [sym_record_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_exception_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_module_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_module_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_module_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_open_module] = {
    .visible = true,
    .named = true,
  },
  [sym_include_module] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_class_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type_binding] = {
    .visible = true,
    .named = true,
  },
  [sym__signature_item] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_value_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_include_module_type] = {
    .visible = true,
    .named = true,
  },
  [sym__module_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__module_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_constrain_type] = {
    .visible = true,
    .named = true,
  },
  [sym_constrain_module] = {
    .visible = true,
    .named = true,
  },
  [sym_constrain_module_type] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_of] = {
    .visible = true,
    .named = true,
  },
  [sym_functor_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_module_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_module_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__module_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_structure] = {
    .visible = true,
    .named = true,
  },
  [sym_functor] = {
    .visible = true,
    .named = true,
  },
  [sym_module_application] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_module_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_packed_module] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_module_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__class_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_class_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__class_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_instantiated_class_type] = {
    .visible = true,
    .named = true,
  },
  [sym_class_body_type] = {
    .visible = true,
    .named = true,
  },
  [sym__class_field_specification] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_inheritance_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_variable_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_method_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_let_open_class_type] = {
    .visible = true,
    .named = true,
  },
  [sym_class_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_class_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__class_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_instantiated_class] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_class_function] = {
    .visible = true,
    .named = true,
  },
  [sym_class_application] = {
    .visible = true,
    .named = true,
  },
  [sym_let_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__class_field] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_inheritance_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_variable_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_method_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_class_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_let_open_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_class_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__typed] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__polymorphic_typed] = {
    .visible = false,
    .named = true,
  },
  [sym__polymorphic_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_polymorphic_type] = {
    .visible = true,
    .named = true,
  },
  [sym__abstract_type] = {
    .visible = false,
    .named = true,
  },
  [sym__parenthesized_abstract_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_argument_type] = {
    .visible = true,
    .named = true,
  },
  [sym__proper_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym__labeled_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_tuple_element_type] = {
    .visible = true,
    .named = true,
  },
  [sym__tuple_type_rhs] = {
    .visible = false,
    .named = true,
  },
  [sym_constructed_type] = {
    .visible = true,
    .named = true,
  },
  [sym_aliased_type] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_type] = {
    .visible = true,
    .named = true,
  },
  [sym_polymorphic_variant_type] = {
    .visible = true,
    .named = true,
  },
  [sym__tag_spec] = {
    .visible = false,
    .named = true,
  },
  [sym_tag_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_package_type] = {
    .visible = true,
    .named = true,
  },
  [sym_object_type] = {
    .visible = true,
    .named = true,
  },
  [sym_method_type] = {
    .visible = true,
    .named = true,
  },
  [sym_hash_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__sequence_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_typed_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_tuple_element] = {
    .visible = true,
    .named = true,
  },
  [sym__tuple_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_cons_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_list_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_record_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_application_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_sign_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hash_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_string_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_bigarray_get_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_set_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_then_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_do_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_for_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__sequence_expression_anonymous] = {
    .visible = false,
    .named = true,
  },
  [sym_match_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__match_cases] = {
    .visible = false,
    .named = true,
  },
  [sym_match_case] = {
    .visible = true,
    .named = true,
  },
  [sym_guard] = {
    .visible = true,
    .named = true,
  },
  [sym_refutation_case] = {
    .visible = true,
    .named = true,
  },
  [sym_function_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_fun_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_try_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_coercion_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_module_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_open_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_package_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_exception_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_object_copy_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_variable_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_method_invocation] = {
    .visible = true,
    .named = true,
  },
  [sym_object_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__effect_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__simple_binding_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__binding_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_alias_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_alias_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__or_pattern_anonymous] = {
    .visible = false,
    .named = true,
  },
  [sym__or_binding_pattern_anonymous] = {
    .visible = false,
    .named = true,
  },
  [sym_constructor_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tag_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tag_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_polymorphic_variant_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_tuple_element_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__tuple_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_labeled_tuple_element_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__tuple_binding_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_record_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_record_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_cons_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_cons_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_array_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_array_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_range_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_local_open_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_package_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_binding_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_exception_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_effect_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_item_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_floating_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_payload] = {
    .visible = true,
    .named = true,
  },
  [sym_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_item_extension] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_item_extension] = {
    .visible = true,
    .named = true,
  },
  [sym__attribute] = {
    .visible = false,
    .named = true,
  },
  [sym__constant] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__signed_constant] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_signed_number] = {
    .visible = true,
    .named = true,
  },
  [sym_character] = {
    .visible = true,
    .named = true,
  },
  [sym_character_content] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_string] = {
    .visible = true,
    .named = true,
  },
  [sym__quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym_quoted_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_sign_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__infix_operator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_add_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indexing_operator_path] = {
    .visible = true,
    .named = true,
  },
  [sym__value_name] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_value_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_value_path] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path] = {
    .visible = true,
    .named = true,
  },
  [sym_extended_module_path] = {
    .visible = true,
    .named = true,
  },
  [sym_module_type_path] = {
    .visible = true,
    .named = true,
  },
  [sym_field_path] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_path] = {
    .visible = true,
    .named = true,
  },
  [sym_type_constructor_path] = {
    .visible = true,
    .named = true,
  },
  [sym_class_path] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type_path] = {
    .visible = true,
    .named = true,
  },
  [sym__instance_variable_name] = {
    .visible = false,
    .named = true,
  },
  [sym__constructor_name] = {
    .visible = false,
    .named = true,
  },
  [sym_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_type_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_id] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__structure_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__structure_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_expression_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__signature_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_value_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_external_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_params_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variant_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constructor_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__constructor_argument_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_type_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_type_constraint_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_instantiated_class_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_body_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_instance_variable_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_method_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_application_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__abstract_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_variant_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_variant_type_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tag_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__match_cases_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_copy_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_binding_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_binding_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_quoted_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_id_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_class_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_class_type_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_constructor_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_field_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_instance_variable_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_label_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_method_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_module_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_module_type_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_or_pattern] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_sequence_expression] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_tuple_expression] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_constructor] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_value_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_value_pattern] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_argument = 2,
  field_array = 3,
  field_body = 4,
  field_class = 5,
  field_class_type = 6,
  field_codomain = 7,
  field_coercion = 8,
  field_condition = 9,
  field_constraint = 10,
  field_continuation = 11,
  field_default = 12,
  field_domain = 13,
  field_effect = 14,
  field_equation = 15,
  field_expression = 16,
  field_field = 17,
  field_from = 18,
  field_function = 19,
  field_functor = 20,
  field_index = 21,
  field_initializer = 22,
  field_left = 23,
  field_method = 24,
  field_module = 25,
  field_module_type = 26,
  field_name = 27,
  field_object = 28,
  field_operator = 29,
  field_pattern = 30,
  field_record = 31,
  field_right = 32,
  field_self = 33,
  field_self_type = 34,
  field_string = 35,
  field_to = 36,
  field_type = 37,
  field_value = 38,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_argument] = "argument",
  [field_array] = "array",
  [field_body] = "body",
  [field_class] = "class",
  [field_class_type] = "class_type",
  [field_codomain] = "codomain",
  [field_coercion] = "coercion",
  [field_condition] = "condition",
  [field_constraint] = "constraint",
  [field_continuation] = "continuation",
  [field_default] = "default",
  [field_domain] = "domain",
  [field_effect] = "effect",
  [field_equation] = "equation",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_from] = "from",
  [field_function] = "function",
  [field_functor] = "functor",
  [field_index] = "index",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_method] = "method",
  [field_module] = "module",
  [field_module_type] = "module_type",
  [field_name] = "name",
  [field_object] = "object",
  [field_operator] = "operator",
  [field_pattern] = "pattern",
  [field_record] = "record",
  [field_right] = "right",
  [field_self] = "self",
  [field_self_type] = "self_type",
  [field_string] = "string",
  [field_to] = "to",
  [field_type] = "type",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [3] = {.index = 0, .length = 1},
  [7] = {.index = 1, .length = 1},
  [9] = {.index = 2, .length = 1},
  [15] = {.index = 3, .length = 2},
  [16] = {.index = 5, .length = 1},
  [19] = {.index = 6, .length = 1},
  [20] = {.index = 7, .length = 1},
  [21] = {.index = 8, .length = 2},
  [22] = {.index = 10, .length = 1},
  [23] = {.index = 11, .length = 1},
  [26] = {.index = 12, .length = 1},
  [27] = {.index = 13, .length = 1},
  [28] = {.index = 14, .length = 1},
  [36] = {.index = 15, .length = 1},
  [37] = {.index = 16, .length = 2},
  [38] = {.index = 18, .length = 1},
  [39] = {.index = 19, .length = 2},
  [40] = {.index = 21, .length = 1},
  [42] = {.index = 22, .length = 2},
  [43] = {.index = 24, .length = 1},
  [44] = {.index = 25, .length = 2},
  [47] = {.index = 22, .length = 2},
  [50] = {.index = 27, .length = 1},
  [51] = {.index = 28, .length = 1},
  [52] = {.index = 29, .length = 1},
  [53] = {.index = 30, .length = 1},
  [54] = {.index = 31, .length = 1},
  [55] = {.index = 32, .length = 2},
  [56] = {.index = 34, .length = 1},
  [57] = {.index = 35, .length = 1},
  [58] = {.index = 27, .length = 1},
  [59] = {.index = 36, .length = 1},
  [61] = {.index = 37, .length = 1},
  [62] = {.index = 35, .length = 1},
  [63] = {.index = 38, .length = 1},
  [64] = {.index = 39, .length = 1},
  [65] = {.index = 40, .length = 1},
  [67] = {.index = 41, .length = 1},
  [68] = {.index = 42, .length = 1},
  [69] = {.index = 43, .length = 1},
  [70] = {.index = 27, .length = 1},
  [71] = {.index = 44, .length = 2},
  [72] = {.index = 46, .length = 2},
  [73] = {.index = 48, .length = 3},
  [74] = {.index = 51, .length = 2},
  [75] = {.index = 53, .length = 2},
  [76] = {.index = 55, .length = 2},
  [77] = {.index = 57, .length = 1},
  [78] = {.index = 58, .length = 3},
  [79] = {.index = 61, .length = 2},
  [80] = {.index = 61, .length = 2},
  [81] = {.index = 55, .length = 2},
  [82] = {.index = 63, .length = 1},
  [83] = {.index = 64, .length = 2},
  [84] = {.index = 66, .length = 1},
  [85] = {.index = 67, .length = 1},
  [86] = {.index = 68, .length = 2},
  [87] = {.index = 66, .length = 1},
  [88] = {.index = 28, .length = 1},
  [89] = {.index = 70, .length = 1},
  [90] = {.index = 27, .length = 1},
  [92] = {.index = 66, .length = 1},
  [93] = {.index = 71, .length = 1},
  [94] = {.index = 72, .length = 2},
  [95] = {.index = 74, .length = 2},
  [96] = {.index = 76, .length = 1},
  [97] = {.index = 66, .length = 1},
  [98] = {.index = 77, .length = 2},
  [99] = {.index = 79, .length = 2},
  [100] = {.index = 81, .length = 1},
  [101] = {.index = 82, .length = 2},
  [102] = {.index = 39, .length = 1},
  [103] = {.index = 84, .length = 1},
  [104] = {.index = 85, .length = 2},
  [105] = {.index = 84, .length = 1},
  [107] = {.index = 87, .length = 1},
  [109] = {.index = 14, .length = 1},
  [110] = {.index = 88, .length = 1},
  [112] = {.index = 84, .length = 1},
  [113] = {.index = 39, .length = 1},
  [114] = {.index = 89, .length = 2},
  [115] = {.index = 91, .length = 3},
  [116] = {.index = 94, .length = 2},
  [117] = {.index = 96, .length = 3},
  [118] = {.index = 94, .length = 2},
  [119] = {.index = 99, .length = 1},
  [120] = {.index = 100, .length = 2},
  [121] = {.index = 102, .length = 2},
  [122] = {.index = 104, .length = 1},
  [123] = {.index = 66, .length = 1},
  [124] = {.index = 105, .length = 1},
  [126] = {.index = 106, .length = 2},
  [127] = {.index = 63, .length = 1},
  [128] = {.index = 108, .length = 1},
  [129] = {.index = 109, .length = 2},
  [131] = {.index = 106, .length = 2},
  [132] = {.index = 111, .length = 3},
  [133] = {.index = 114, .length = 2},
  [134] = {.index = 38, .length = 1},
  [135] = {.index = 116, .length = 2},
  [136] = {.index = 118, .length = 2},
  [137] = {.index = 120, .length = 2},
  [138] = {.index = 122, .length = 1},
  [139] = {.index = 123, .length = 1},
  [140] = {.index = 124, .length = 2},
  [141] = {.index = 126, .length = 1},
  [142] = {.index = 127, .length = 1},
  [143] = {.index = 128, .length = 2},
  [144] = {.index = 38, .length = 1},
  [146] = {.index = 66, .length = 1},
  [147] = {.index = 38, .length = 1},
  [148] = {.index = 63, .length = 1},
  [149] = {.index = 130, .length = 2},
  [150] = {.index = 132, .length = 2},
  [151] = {.index = 134, .length = 2},
  [152] = {.index = 81, .length = 1},
  [153] = {.index = 14, .length = 1},
  [154] = {.index = 136, .length = 3},
  [155] = {.index = 139, .length = 2},
  [156] = {.index = 141, .length = 1},
  [157] = {.index = 142, .length = 1},
  [158] = {.index = 99, .length = 1},
  [159] = {.index = 143, .length = 1},
  [160] = {.index = 143, .length = 1},
  [162] = {.index = 144, .length = 2},
  [163] = {.index = 146, .length = 2},
  [164] = {.index = 148, .length = 2},
  [165] = {.index = 150, .length = 1},
  [167] = {.index = 151, .length = 2},
  [168] = {.index = 108, .length = 1},
  [169] = {.index = 153, .length = 3},
  [170] = {.index = 156, .length = 3},
  [171] = {.index = 159, .length = 2},
  [172] = {.index = 161, .length = 3},
  [173] = {.index = 122, .length = 1},
  [174] = {.index = 164, .length = 2},
  [175] = {.index = 166, .length = 1},
  [176] = {.index = 167, .length = 1},
  [177] = {.index = 168, .length = 2},
  [178] = {.index = 170, .length = 2},
  [179] = {.index = 63, .length = 1},
  [180] = {.index = 167, .length = 1},
  [181] = {.index = 167, .length = 1},
  [182] = {.index = 130, .length = 2},
  [183] = {.index = 63, .length = 1},
  [184] = {.index = 172, .length = 1},
  [185] = {.index = 173, .length = 2},
  [186] = {.index = 175, .length = 3},
  [187] = {.index = 178, .length = 3},
  [188] = {.index = 181, .length = 3},
  [189] = {.index = 184, .length = 1},
  [190] = {.index = 99, .length = 1},
  [191] = {.index = 185, .length = 2},
  [192] = {.index = 187, .length = 1},
  [193] = {.index = 187, .length = 1},
  [194] = {.index = 188, .length = 1},
  [195] = {.index = 188, .length = 1},
  [196] = {.index = 189, .length = 2},
  [197] = {.index = 191, .length = 1},
  [198] = {.index = 192, .length = 1},
  [199] = {.index = 193, .length = 4},
  [200] = {.index = 197, .length = 3},
  [201] = {.index = 200, .length = 2},
  [202] = {.index = 202, .length = 1},
  [203] = {.index = 99, .length = 1},
  [204] = {.index = 203, .length = 2},
  [205] = {.index = 173, .length = 2},
  [206] = {.index = 99, .length = 1},
  [207] = {.index = 99, .length = 1},
  [208] = {.index = 205, .length = 1},
  [209] = {.index = 173, .length = 2},
  [210] = {.index = 206, .length = 2},
  [211] = {.index = 208, .length = 3},
  [212] = {.index = 187, .length = 1},
  [213] = {.index = 211, .length = 2},
  [214] = {.index = 211, .length = 2},
  [215] = {.index = 213, .length = 1},
  [216] = {.index = 213, .length = 1},
  [217] = {.index = 214, .length = 1},
  [218] = {.index = 215, .length = 3},
  [219] = {.index = 218, .length = 4},
  [220] = {.index = 222, .length = 2},
  [221] = {.index = 224, .length = 2},
  [222] = {.index = 226, .length = 2},
  [223] = {.index = 228, .length = 3},
  [224] = {.index = 226, .length = 2},
  [225] = {.index = 226, .length = 2},
  [226] = {.index = 187, .length = 1},
  [227] = {.index = 231, .length = 3},
  [228] = {.index = 213, .length = 1},
  [229] = {.index = 234, .length = 2},
  [230] = {.index = 234, .length = 2},
  [231] = {.index = 236, .length = 1},
  [232] = {.index = 237, .length = 2},
  [233] = {.index = 239, .length = 3},
  [234] = {.index = 242, .length = 2},
  [235] = {.index = 244, .length = 2},
  [236] = {.index = 246, .length = 2},
  [237] = {.index = 248, .length = 3},
  [238] = {.index = 251, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_module, 1},
  [2] =
    {field_module_type, 1},
  [3] =
    {field_equation, 1, .inherited = true},
    {field_name, 0},
  [5] =
    {field_name, 1},
  [6] =
    {field_module_type, 1, .inherited = true},
  [7] =
    {field_module, 2},
  [8] =
    {field_argument, 1},
    {field_functor, 0},
  [10] =
    {field_codomain, 1},
  [11] =
    {field_module_type, 2},
  [12] =
    {field_class_type, 1, .inherited = true},
  [13] =
    {field_pattern, 0},
  [14] =
    {field_type, 2, .inherited = true},
  [15] =
    {field_expression, 1},
  [16] =
    {field_expression, 1},
    {field_operator, 0},
  [18] =
    {field_argument, 0},
  [19] =
    {field_argument, 1, .inherited = true},
    {field_function, 0},
  [21] =
    {field_type, 1},
  [22] =
    {field_body, 2},
    {field_name, 0},
  [24] =
    {field_equation, 1},
  [25] =
    {field_equation, 2, .inherited = true},
    {field_name, 1},
  [27] =
    {field_body, 2},
  [28] =
    {field_module_type, 2, .inherited = true},
  [29] =
    {field_module, 3},
  [30] =
    {field_functor, 0},
  [31] =
    {field_codomain, 2},
  [32] =
    {field_codomain, 2},
    {field_domain, 0},
  [34] =
    {field_module_type, 0},
  [35] =
    {field_class_type, 2, .inherited = true},
  [36] =
    {field_pattern, 1},
  [37] =
    {field_class_type, 1},
  [38] =
    {field_type, 3, .inherited = true},
  [39] =
    {field_type, 1, .inherited = true},
  [40] =
    {field_class, 1},
  [41] =
    {field_initializer, 1},
  [42] =
    {field_condition, 1},
  [43] =
    {field_expression, 2},
  [44] =
    {field_field, 2},
    {field_record, 0},
  [46] =
    {field_method, 2},
    {field_object, 0},
  [48] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [51] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [53] =
    {field_left, 0},
    {field_right, 2},
  [55] =
    {field_body, 3},
    {field_name, 0},
  [57] =
    {field_equation, 2},
  [58] =
    {field_body, 3},
    {field_equation, 1, .inherited = true},
    {field_name, 0},
  [61] =
    {field_body, 3},
    {field_name, 1},
  [63] =
    {field_body, 4},
  [64] =
    {field_body, 3},
    {field_module_type, 1, .inherited = true},
  [66] =
    {field_body, 3},
  [67] =
    {field_value, 2},
  [68] =
    {field_module, 1},
    {field_module_type, 2, .inherited = true},
  [70] =
    {field_codomain, 3},
  [71] =
    {field_class_type, 3, .inherited = true},
  [72] =
    {field_argument, 1, .inherited = true},
    {field_class, 0},
  [74] =
    {field_body, 3},
    {field_class_type, 1, .inherited = true},
  [76] =
    {field_pattern, 2},
  [77] =
    {field_body, 2},
    {field_pattern, 0},
  [79] =
    {field_alias, 2},
    {field_pattern, 0},
  [81] =
    {field_expression, 3},
  [82] =
    {field_expression, 1},
    {field_type, 2, .inherited = true},
  [84] =
    {field_type, 2},
  [85] =
    {field_alias, 2},
    {field_type, 0},
  [87] =
    {field_class, 2},
  [88] =
    {field_condition, 2},
  [89] =
    {field_constraint, 3},
    {field_type, 1},
  [91] =
    {field_body, 4},
    {field_equation, 1, .inherited = true},
    {field_name, 0},
  [94] =
    {field_body, 4},
    {field_name, 1},
  [96] =
    {field_body, 4},
    {field_equation, 2, .inherited = true},
    {field_name, 1},
  [99] =
    {field_body, 5},
  [100] =
    {field_body, 4},
    {field_module_type, 2, .inherited = true},
  [102] =
    {field_module_type, 3, .inherited = true},
    {field_value, 2},
  [104] =
    {field_equation, 2, .inherited = true},
  [105] =
    {field_class_type, 4, .inherited = true},
  [106] =
    {field_body, 4},
    {field_class_type, 2, .inherited = true},
  [108] =
    {field_pattern, 3},
  [109] =
    {field_pattern, 1},
    {field_type, 2, .inherited = true},
  [111] =
    {field_body, 3},
    {field_pattern, 0},
    {field_type, 1, .inherited = true},
  [114] =
    {field_body, 3},
    {field_pattern, 0},
  [116] =
    {field_continuation, 3},
    {field_effect, 1},
  [118] =
    {field_module, 2},
    {field_module_type, 3, .inherited = true},
  [120] =
    {field_coercion, 3},
    {field_expression, 1},
  [122] =
    {field_type, 3},
  [123] =
    {field_record, 1},
  [124] =
    {field_body, 3},
    {field_type, 1, .inherited = true},
  [126] =
    {field_self, 2},
  [127] =
    {field_coercion, 3},
  [128] =
    {field_alias, 3},
    {field_class, 1},
  [130] =
    {field_body, 4},
    {field_type, 2, .inherited = true},
  [132] =
    {field_array, 0},
    {field_index, 3},
  [134] =
    {field_index, 3},
    {field_string, 0},
  [136] =
    {field_body, 5},
    {field_equation, 2, .inherited = true},
    {field_name, 1},
  [139] =
    {field_coercion, 4},
    {field_value, 2},
  [141] =
    {field_equation, 3, .inherited = true},
  [142] =
    {field_constraint, 3},
  [143] =
    {field_class_type, 5, .inherited = true},
  [144] =
    {field_body, 5},
    {field_class_type, 3, .inherited = true},
  [146] =
    {field_class, 1},
    {field_class_type, 2, .inherited = true},
  [148] =
    {field_pattern, 2},
    {field_type, 3, .inherited = true},
  [150] =
    {field_module_type, 3, .inherited = true},
  [151] =
    {field_pattern, 3},
    {field_type, 1, .inherited = true},
  [153] =
    {field_body, 4},
    {field_coercion, 2},
    {field_pattern, 0},
  [156] =
    {field_body, 4},
    {field_pattern, 0},
    {field_type, 2, .inherited = true},
  [159] =
    {field_module, 3},
    {field_module_type, 4, .inherited = true},
  [161] =
    {field_coercion, 4},
    {field_expression, 1},
    {field_type, 2, .inherited = true},
  [164] =
    {field_self, 2},
    {field_type, 3, .inherited = true},
  [166] =
    {field_coercion, 4},
  [167] =
    {field_type, 4, .inherited = true},
  [168] =
    {field_coercion, 4},
    {field_type, 2, .inherited = true},
  [170] =
    {field_alias, 4},
    {field_class, 2},
  [172] =
    {field_self, 3},
  [173] =
    {field_body, 5},
    {field_type, 3, .inherited = true},
  [175] =
    {field_array, 0},
    {field_index, 4},
    {field_operator, 2},
  [178] =
    {field_index, 4},
    {field_operator, 2},
    {field_string, 0},
  [181] =
    {field_coercion, 5},
    {field_module_type, 3, .inherited = true},
    {field_value, 2},
  [184] =
    {field_constraint, 4},
  [185] =
    {field_body, 6},
    {field_class_type, 4, .inherited = true},
  [187] =
    {field_body, 6},
  [188] =
    {field_class_type, 6, .inherited = true},
  [189] =
    {field_default, 4},
    {field_pattern, 2},
  [191] =
    {field_module_type, 4, .inherited = true},
  [192] =
    {field_self_type, 2},
  [193] =
    {field_body, 5},
    {field_coercion, 3},
    {field_pattern, 0},
    {field_type, 1, .inherited = true},
  [197] =
    {field_body, 5},
    {field_coercion, 3},
    {field_pattern, 0},
  [200] =
    {field_coercion, 5},
    {field_type, 3, .inherited = true},
  [202] =
    {field_coercion, 5},
  [203] =
    {field_body, 5},
    {field_coercion, 3},
  [205] =
    {field_type, 5, .inherited = true},
  [206] =
    {field_self, 3},
    {field_type, 4, .inherited = true},
  [208] =
    {field_from, 3},
    {field_name, 1},
    {field_to, 5},
  [211] =
    {field_body, 7},
    {field_class_type, 5, .inherited = true},
  [213] =
    {field_body, 7},
  [214] =
    {field_class_type, 7, .inherited = true},
  [215] =
    {field_default, 5},
    {field_pattern, 2},
    {field_type, 3, .inherited = true},
  [218] =
    {field_body, 6},
    {field_coercion, 4},
    {field_pattern, 0},
    {field_type, 2, .inherited = true},
  [222] =
    {field_body, 6},
    {field_coercion, 4},
  [224] =
    {field_coercion, 6},
    {field_type, 4, .inherited = true},
  [226] =
    {field_body, 6},
    {field_type, 4, .inherited = true},
  [228] =
    {field_body, 6},
    {field_coercion, 4},
    {field_type, 2, .inherited = true},
  [231] =
    {field_from, 4},
    {field_name, 2},
    {field_to, 6},
  [234] =
    {field_body, 8},
    {field_class_type, 6, .inherited = true},
  [236] =
    {field_body, 8},
  [237] =
    {field_default, 6},
    {field_pattern, 4},
  [239] =
    {field_body, 7},
    {field_coercion, 5},
    {field_type, 3, .inherited = true},
  [242] =
    {field_body, 7},
    {field_coercion, 5},
  [244] =
    {field_body, 7},
    {field_type, 5, .inherited = true},
  [246] =
    {field_body, 9},
    {field_class_type, 7, .inherited = true},
  [248] =
    {field_default, 7},
    {field_pattern, 4},
    {field_type, 5, .inherited = true},
  [251] =
    {field_body, 8},
    {field_coercion, 6},
    {field_type, 4, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_value_name,
  },
  [2] = {
    [0] = sym_type_variable,
  },
  [3] = {
    [0] = alias_sym_type_constructor,
  },
  [4] = {
    [0] = alias_sym_type_constructor,
  },
  [5] = {
    [0] = alias_sym_module_name,
  },
  [6] = {
    [0] = alias_sym_constructor_name,
  },
  [8] = {
    [0] = alias_sym_module_type_name,
  },
  [10] = {
    [0] = alias_sym_class_name,
  },
  [11] = {
    [0] = alias_sym_instance_variable_name,
  },
  [12] = {
    [0] = alias_sym_tuple_expression,
  },
  [13] = {
    [0] = alias_sym_sequence_expression,
  },
  [14] = {
    [1] = sym_type_variable,
  },
  [15] = {
    [0] = alias_sym_type_constructor,
  },
  [16] = {
    [1] = alias_sym_type_constructor,
  },
  [17] = {
    [0] = alias_sym_constructor_name,
    [1] = alias_sym_constructor_name,
  },
  [18] = {
    [2] = alias_sym_module_type_name,
  },
  [19] = {
    [0] = alias_sym_module_name,
  },
  [24] = {
    [1] = alias_sym_class_name,
  },
  [25] = {
    [0] = alias_sym_value_pattern,
  },
  [26] = {
    [0] = alias_sym_class_name,
  },
  [29] = {
    [0] = alias_sym_or_pattern,
  },
  [30] = {
    [0] = alias_sym_tuple_pattern,
  },
  [31] = {
    [0] = sym_record_pattern,
  },
  [32] = {
    [0] = sym_list_pattern,
  },
  [33] = {
    [0] = sym_array_pattern,
  },
  [34] = {
    [1] = alias_sym_label_name,
  },
  [35] = {
    [0] = alias_sym_field_name,
  },
  [41] = {
    [2] = sym_type_variable,
  },
  [42] = {
    [0] = alias_sym_type_constructor,
  },
  [44] = {
    [1] = alias_sym_type_constructor,
  },
  [45] = {
    [2] = alias_sym_type_constructor,
  },
  [46] = {
    [2] = alias_sym_module_name,
  },
  [48] = {
    [1] = alias_sym_constructor_name,
  },
  [49] = {
    [3] = alias_sym_module_type_name,
  },
  [50] = {
    [0] = alias_sym_module_name,
  },
  [51] = {
    [0] = alias_sym_module_name,
  },
  [57] = {
    [1] = alias_sym_class_name,
  },
  [58] = {
    [0] = alias_sym_class_name,
  },
  [60] = {
    [0] = alias_sym_class_type_name,
  },
  [62] = {
    [0] = alias_sym_class_name,
  },
  [66] = {
    [1] = alias_sym_method_name,
  },
  [72] = {
    [2] = alias_sym_method_name,
  },
  [76] = {
    [0] = alias_sym_type_constructor,
  },
  [78] = {
    [0] = alias_sym_type_constructor,
  },
  [79] = {
    [1] = alias_sym_type_constructor,
  },
  [82] = {
    [2] = alias_sym_module_type_name,
  },
  [83] = {
    [0] = alias_sym_module_name,
  },
  [84] = {
    [0] = alias_sym_module_name,
  },
  [88] = {
    [1] = alias_sym_module_name,
  },
  [90] = {
    [0] = alias_sym_class_type_name,
  },
  [91] = {
    [3] = alias_sym_class_name,
  },
  [92] = {
    [1] = alias_sym_class_name,
  },
  [93] = {
    [1] = alias_sym_class_name,
  },
  [95] = {
    [0] = alias_sym_class_name,
  },
  [97] = {
    [0] = alias_sym_class_name,
  },
  [100] = {
    [1] = alias_sym_label_name,
  },
  [102] = {
    [0] = alias_sym_method_name,
  },
  [103] = {
    [0] = alias_sym_label_name,
  },
  [106] = {
    [2] = alias_sym_field_name,
  },
  [108] = {
    [2] = alias_sym_method_name,
  },
  [109] = {
    [1] = alias_sym_method_name,
  },
  [111] = {
    [2] = alias_sym_class_name,
  },
  [112] = {
    [0] = sym__parenthesized_abstract_type,
  },
  [113] = {
    [0] = alias_sym_field_name,
  },
  [115] = {
    [0] = alias_sym_type_constructor,
  },
  [116] = {
    [1] = alias_sym_type_constructor,
  },
  [117] = {
    [1] = alias_sym_type_constructor,
  },
  [119] = {
    [3] = alias_sym_module_type_name,
  },
  [120] = {
    [0] = alias_sym_module_name,
  },
  [123] = {
    [1] = alias_sym_class_type_name,
  },
  [124] = {
    [3] = alias_sym_class_name,
  },
  [125] = {
    [4] = alias_sym_class_name,
  },
  [126] = {
    [1] = alias_sym_class_name,
  },
  [127] = {
    [1] = alias_sym_class_name,
  },
  [128] = {
    [1] = alias_sym_label_name,
  },
  [130] = {
    [2] = alias_sym_class_type_name,
  },
  [131] = {
    [0] = alias_sym_class_name,
  },
  [134] = {
    [2] = alias_sym_label_name,
  },
  [138] = {
    [1] = alias_sym_label_name,
  },
  [144] = {
    [2] = alias_sym_method_name,
  },
  [145] = {
    [3] = alias_sym_method_name,
  },
  [146] = {
    [1] = alias_sym_method_name,
  },
  [147] = {
    [1] = alias_sym_method_name,
  },
  [153] = {
    [1] = alias_sym_field_name,
  },
  [154] = {
    [1] = alias_sym_type_constructor,
  },
  [158] = {
    [3] = alias_sym_class_name,
  },
  [159] = {
    [3] = alias_sym_class_name,
  },
  [160] = {
    [4] = alias_sym_class_name,
  },
  [161] = {
    [5] = alias_sym_class_name,
  },
  [162] = {
    [1] = alias_sym_class_name,
  },
  [165] = {
    [2] = alias_sym_module_name,
  },
  [166] = {
    [3] = alias_sym_module_name,
  },
  [179] = {
    [2] = alias_sym_method_name,
  },
  [180] = {
    [2] = alias_sym_method_name,
  },
  [181] = {
    [3] = alias_sym_method_name,
  },
  [182] = {
    [1] = alias_sym_method_name,
  },
  [183] = {
    [1] = alias_sym_method_name,
  },
  [190] = {
    [3] = alias_sym_class_type_name,
  },
  [191] = {
    [3] = alias_sym_class_name,
  },
  [192] = {
    [3] = alias_sym_class_name,
  },
  [193] = {
    [4] = alias_sym_class_name,
  },
  [194] = {
    [4] = alias_sym_class_name,
  },
  [195] = {
    [5] = alias_sym_class_name,
  },
  [197] = {
    [3] = alias_sym_module_name,
  },
  [205] = {
    [2] = alias_sym_method_name,
  },
  [206] = {
    [2] = alias_sym_method_name,
  },
  [207] = {
    [3] = alias_sym_method_name,
  },
  [208] = {
    [3] = alias_sym_method_name,
  },
  [209] = {
    [1] = alias_sym_method_name,
  },
  [212] = {
    [4] = alias_sym_class_type_name,
  },
  [213] = {
    [3] = alias_sym_class_name,
  },
  [214] = {
    [4] = alias_sym_class_name,
  },
  [215] = {
    [4] = alias_sym_class_name,
  },
  [216] = {
    [5] = alias_sym_class_name,
  },
  [217] = {
    [5] = alias_sym_class_name,
  },
  [224] = {
    [2] = alias_sym_method_name,
  },
  [225] = {
    [3] = alias_sym_method_name,
  },
  [226] = {
    [3] = alias_sym_method_name,
  },
  [228] = {
    [5] = alias_sym_class_type_name,
  },
  [229] = {
    [4] = alias_sym_class_name,
  },
  [230] = {
    [5] = alias_sym_class_name,
  },
  [231] = {
    [5] = alias_sym_class_name,
  },
  [232] = {
    [1] = alias_sym_label_name,
  },
  [235] = {
    [3] = alias_sym_method_name,
  },
  [236] = {
    [5] = alias_sym_class_name,
  },
  [237] = {
    [1] = alias_sym_label_name,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__abstract_type, 2,
    sym__abstract_type,
    sym__parenthesized_abstract_type,
  sym__tuple_expression, 2,
    sym__tuple_expression,
    alias_sym_tuple_expression,
  sym__sequence_expression_anonymous, 2,
    sym__sequence_expression_anonymous,
    alias_sym_sequence_expression,
  sym__or_pattern_anonymous, 2,
    sym__or_pattern_anonymous,
    alias_sym_or_pattern,
  sym__or_binding_pattern_anonymous, 2,
    sym__or_binding_pattern_anonymous,
    alias_sym_or_pattern,
  sym__tuple_pattern, 2,
    sym__tuple_pattern,
    alias_sym_tuple_pattern,
  sym__tuple_binding_pattern, 2,
    sym__tuple_binding_pattern,
    alias_sym_tuple_pattern,
  sym_record_binding_pattern, 2,
    sym_record_binding_pattern,
    sym_record_pattern,
  sym_list_binding_pattern, 2,
    sym_list_binding_pattern,
    sym_list_pattern,
  sym_array_binding_pattern, 2,
    sym_array_binding_pattern,
    sym_array_pattern,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 2,
  [9] = 6,
  [10] = 2,
  [11] = 6,
  [12] = 2,
  [13] = 6,
  [14] = 2,
  [15] = 2,
  [16] = 2,
  [17] = 2,
  [18] = 2,
  [19] = 2,
  [20] = 2,
  [21] = 2,
  [22] = 2,
  [23] = 2,
  [24] = 2,
  [25] = 2,
  [26] = 2,
  [27] = 2,
  [28] = 2,
  [29] = 29,
  [30] = 2,
  [31] = 2,
  [32] = 2,
  [33] = 2,
  [34] = 2,
  [35] = 2,
  [36] = 2,
  [37] = 2,
  [38] = 2,
  [39] = 2,
  [40] = 2,
  [41] = 2,
  [42] = 2,
  [43] = 2,
  [44] = 2,
  [45] = 2,
  [46] = 2,
  [47] = 2,
  [48] = 2,
  [49] = 2,
  [50] = 2,
  [51] = 2,
  [52] = 2,
  [53] = 2,
  [54] = 2,
  [55] = 2,
  [56] = 2,
  [57] = 2,
  [58] = 2,
  [59] = 2,
  [60] = 2,
  [61] = 2,
  [62] = 2,
  [63] = 2,
  [64] = 2,
  [65] = 2,
  [66] = 2,
  [67] = 2,
  [68] = 2,
  [69] = 2,
  [70] = 2,
  [71] = 2,
  [72] = 2,
  [73] = 2,
  [74] = 2,
  [75] = 2,
  [76] = 2,
  [77] = 2,
  [78] = 2,
  [79] = 2,
  [80] = 2,
  [81] = 2,
  [82] = 2,
  [83] = 2,
  [84] = 2,
  [85] = 2,
  [86] = 2,
  [87] = 2,
  [88] = 2,
  [89] = 89,
  [90] = 89,
  [91] = 91,
  [92] = 91,
  [93] = 93,
  [94] = 94,
  [95] = 91,
  [96] = 91,
  [97] = 97,
  [98] = 91,
  [99] = 91,
  [100] = 100,
  [101] = 94,
  [102] = 97,
  [103] = 93,
  [104] = 100,
  [105] = 105,
  [106] = 91,
  [107] = 105,
  [108] = 91,
  [109] = 91,
  [110] = 91,
  [111] = 91,
  [112] = 91,
  [113] = 91,
  [114] = 91,
  [115] = 91,
  [116] = 91,
  [117] = 91,
  [118] = 91,
  [119] = 91,
  [120] = 91,
  [121] = 91,
  [122] = 91,
  [123] = 91,
  [124] = 91,
  [125] = 91,
  [126] = 91,
  [127] = 91,
  [128] = 128,
  [129] = 129,
  [130] = 128,
  [131] = 129,
  [132] = 128,
  [133] = 129,
  [134] = 128,
  [135] = 129,
  [136] = 128,
  [137] = 129,
  [138] = 128,
  [139] = 129,
  [140] = 128,
  [141] = 129,
  [142] = 128,
  [143] = 129,
  [144] = 128,
  [145] = 129,
  [146] = 128,
  [147] = 129,
  [148] = 128,
  [149] = 129,
  [150] = 128,
  [151] = 129,
  [152] = 128,
  [153] = 129,
  [154] = 128,
  [155] = 129,
  [156] = 128,
  [157] = 129,
  [158] = 128,
  [159] = 129,
  [160] = 128,
  [161] = 129,
  [162] = 128,
  [163] = 129,
  [164] = 128,
  [165] = 91,
  [166] = 129,
  [167] = 128,
  [168] = 129,
  [169] = 128,
  [170] = 129,
  [171] = 128,
  [172] = 128,
  [173] = 128,
  [174] = 129,
  [175] = 128,
  [176] = 129,
  [177] = 128,
  [178] = 129,
  [179] = 128,
  [180] = 129,
  [181] = 128,
  [182] = 129,
  [183] = 128,
  [184] = 129,
  [185] = 128,
  [186] = 129,
  [187] = 128,
  [188] = 129,
  [189] = 128,
  [190] = 91,
  [191] = 129,
  [192] = 128,
  [193] = 129,
  [194] = 128,
  [195] = 129,
  [196] = 128,
  [197] = 129,
  [198] = 128,
  [199] = 129,
  [200] = 128,
  [201] = 129,
  [202] = 128,
  [203] = 129,
  [204] = 128,
  [205] = 128,
  [206] = 129,
  [207] = 128,
  [208] = 129,
  [209] = 128,
  [210] = 129,
  [211] = 129,
  [212] = 128,
  [213] = 129,
  [214] = 129,
  [215] = 129,
  [216] = 91,
  [217] = 91,
  [218] = 91,
  [219] = 91,
  [220] = 91,
  [221] = 91,
  [222] = 91,
  [223] = 91,
  [224] = 91,
  [225] = 91,
  [226] = 91,
  [227] = 91,
  [228] = 91,
  [229] = 91,
  [230] = 91,
  [231] = 91,
  [232] = 91,
  [233] = 91,
  [234] = 91,
  [235] = 91,
  [236] = 91,
  [237] = 91,
  [238] = 91,
  [239] = 91,
  [240] = 91,
  [241] = 91,
  [242] = 242,
  [243] = 242,
  [244] = 242,
  [245] = 242,
  [246] = 242,
  [247] = 242,
  [248] = 242,
  [249] = 242,
  [250] = 242,
  [251] = 242,
  [252] = 242,
  [253] = 242,
  [254] = 242,
  [255] = 242,
  [256] = 242,
  [257] = 242,
  [258] = 242,
  [259] = 242,
  [260] = 242,
  [261] = 242,
  [262] = 242,
  [263] = 242,
  [264] = 242,
  [265] = 242,
  [266] = 242,
  [267] = 242,
  [268] = 242,
  [269] = 242,
  [270] = 242,
  [271] = 242,
  [272] = 242,
  [273] = 242,
  [274] = 242,
  [275] = 242,
  [276] = 242,
  [277] = 242,
  [278] = 242,
  [279] = 242,
  [280] = 242,
  [281] = 242,
  [282] = 91,
  [283] = 242,
  [284] = 242,
  [285] = 242,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 288,
  [291] = 289,
  [292] = 288,
  [293] = 289,
  [294] = 288,
  [295] = 288,
  [296] = 288,
  [297] = 289,
  [298] = 91,
  [299] = 289,
  [300] = 288,
  [301] = 288,
  [302] = 289,
  [303] = 289,
  [304] = 289,
  [305] = 288,
  [306] = 288,
  [307] = 307,
  [308] = 289,
  [309] = 288,
  [310] = 288,
  [311] = 289,
  [312] = 288,
  [313] = 91,
  [314] = 288,
  [315] = 288,
  [316] = 289,
  [317] = 288,
  [318] = 91,
  [319] = 91,
  [320] = 289,
  [321] = 289,
  [322] = 322,
  [323] = 289,
  [324] = 289,
  [325] = 289,
  [326] = 289,
  [327] = 288,
  [328] = 288,
  [329] = 288,
  [330] = 288,
  [331] = 289,
  [332] = 91,
  [333] = 288,
  [334] = 91,
  [335] = 289,
  [336] = 288,
  [337] = 289,
  [338] = 288,
  [339] = 289,
  [340] = 288,
  [341] = 289,
  [342] = 289,
  [343] = 289,
  [344] = 288,
  [345] = 288,
  [346] = 289,
  [347] = 288,
  [348] = 288,
  [349] = 289,
  [350] = 289,
  [351] = 286,
  [352] = 289,
  [353] = 288,
  [354] = 289,
  [355] = 288,
  [356] = 289,
  [357] = 288,
  [358] = 286,
  [359] = 287,
  [360] = 289,
  [361] = 289,
  [362] = 286,
  [363] = 287,
  [364] = 286,
  [365] = 287,
  [366] = 286,
  [367] = 286,
  [368] = 286,
  [369] = 286,
  [370] = 286,
  [371] = 286,
  [372] = 288,
  [373] = 286,
  [374] = 286,
  [375] = 286,
  [376] = 286,
  [377] = 286,
  [378] = 286,
  [379] = 286,
  [380] = 286,
  [381] = 286,
  [382] = 286,
  [383] = 286,
  [384] = 286,
  [385] = 286,
  [386] = 286,
  [387] = 286,
  [388] = 286,
  [389] = 286,
  [390] = 286,
  [391] = 286,
  [392] = 286,
  [393] = 286,
  [394] = 286,
  [395] = 286,
  [396] = 286,
  [397] = 307,
  [398] = 322,
  [399] = 286,
  [400] = 307,
  [401] = 322,
  [402] = 286,
  [403] = 307,
  [404] = 322,
  [405] = 286,
  [406] = 307,
  [407] = 322,
  [408] = 286,
  [409] = 307,
  [410] = 322,
  [411] = 286,
  [412] = 307,
  [413] = 322,
  [414] = 286,
  [415] = 307,
  [416] = 322,
  [417] = 286,
  [418] = 307,
  [419] = 322,
  [420] = 286,
  [421] = 307,
  [422] = 322,
  [423] = 286,
  [424] = 307,
  [425] = 322,
  [426] = 286,
  [427] = 307,
  [428] = 322,
  [429] = 307,
  [430] = 322,
  [431] = 307,
  [432] = 322,
  [433] = 307,
  [434] = 322,
  [435] = 307,
  [436] = 322,
  [437] = 307,
  [438] = 322,
  [439] = 307,
  [440] = 322,
  [441] = 307,
  [442] = 322,
  [443] = 307,
  [444] = 322,
  [445] = 307,
  [446] = 322,
  [447] = 307,
  [448] = 322,
  [449] = 307,
  [450] = 322,
  [451] = 307,
  [452] = 322,
  [453] = 307,
  [454] = 322,
  [455] = 307,
  [456] = 322,
  [457] = 307,
  [458] = 322,
  [459] = 307,
  [460] = 322,
  [461] = 307,
  [462] = 322,
  [463] = 307,
  [464] = 322,
  [465] = 307,
  [466] = 322,
  [467] = 307,
  [468] = 322,
  [469] = 307,
  [470] = 322,
  [471] = 307,
  [472] = 322,
  [473] = 307,
  [474] = 322,
  [475] = 307,
  [476] = 322,
  [477] = 307,
  [478] = 322,
  [479] = 307,
  [480] = 322,
  [481] = 307,
  [482] = 322,
  [483] = 307,
  [484] = 322,
  [485] = 307,
  [486] = 322,
  [487] = 307,
  [488] = 322,
  [489] = 307,
  [490] = 322,
  [491] = 307,
  [492] = 322,
  [493] = 286,
  [494] = 494,
  [495] = 494,
  [496] = 494,
  [497] = 494,
  [498] = 494,
  [499] = 494,
  [500] = 494,
  [501] = 494,
  [502] = 494,
  [503] = 494,
  [504] = 494,
  [505] = 494,
  [506] = 494,
  [507] = 494,
  [508] = 494,
  [509] = 509,
  [510] = 494,
  [511] = 494,
  [512] = 494,
  [513] = 494,
  [514] = 494,
  [515] = 494,
  [516] = 509,
  [517] = 494,
  [518] = 494,
  [519] = 494,
  [520] = 494,
  [521] = 494,
  [522] = 509,
  [523] = 494,
  [524] = 494,
  [525] = 494,
  [526] = 494,
  [527] = 494,
  [528] = 494,
  [529] = 494,
  [530] = 494,
  [531] = 494,
  [532] = 494,
  [533] = 494,
  [534] = 494,
  [535] = 494,
  [536] = 509,
  [537] = 494,
  [538] = 494,
  [539] = 494,
  [540] = 494,
  [541] = 541,
  [542] = 542,
  [543] = 543,
  [544] = 544,
  [545] = 541,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 542,
  [551] = 543,
  [552] = 543,
  [553] = 544,
  [554] = 554,
  [555] = 541,
  [556] = 556,
  [557] = 546,
  [558] = 547,
  [559] = 548,
  [560] = 560,
  [561] = 549,
  [562] = 542,
  [563] = 544,
  [564] = 541,
  [565] = 546,
  [566] = 547,
  [567] = 548,
  [568] = 549,
  [569] = 542,
  [570] = 543,
  [571] = 544,
  [572] = 541,
  [573] = 546,
  [574] = 547,
  [575] = 548,
  [576] = 549,
  [577] = 542,
  [578] = 543,
  [579] = 579,
  [580] = 543,
  [581] = 544,
  [582] = 582,
  [583] = 556,
  [584] = 541,
  [585] = 546,
  [586] = 547,
  [587] = 548,
  [588] = 549,
  [589] = 544,
  [590] = 541,
  [591] = 546,
  [592] = 547,
  [593] = 548,
  [594] = 549,
  [595] = 542,
  [596] = 543,
  [597] = 544,
  [598] = 541,
  [599] = 546,
  [600] = 547,
  [601] = 548,
  [602] = 549,
  [603] = 542,
  [604] = 543,
  [605] = 542,
  [606] = 606,
  [607] = 543,
  [608] = 544,
  [609] = 556,
  [610] = 610,
  [611] = 541,
  [612] = 546,
  [613] = 547,
  [614] = 548,
  [615] = 544,
  [616] = 541,
  [617] = 546,
  [618] = 547,
  [619] = 548,
  [620] = 549,
  [621] = 542,
  [622] = 543,
  [623] = 623,
  [624] = 549,
  [625] = 542,
  [626] = 556,
  [627] = 543,
  [628] = 544,
  [629] = 629,
  [630] = 541,
  [631] = 544,
  [632] = 541,
  [633] = 546,
  [634] = 547,
  [635] = 548,
  [636] = 549,
  [637] = 542,
  [638] = 543,
  [639] = 546,
  [640] = 547,
  [641] = 548,
  [642] = 556,
  [643] = 549,
  [644] = 542,
  [645] = 543,
  [646] = 544,
  [647] = 544,
  [648] = 541,
  [649] = 546,
  [650] = 547,
  [651] = 548,
  [652] = 549,
  [653] = 542,
  [654] = 543,
  [655] = 655,
  [656] = 541,
  [657] = 546,
  [658] = 547,
  [659] = 556,
  [660] = 548,
  [661] = 549,
  [662] = 542,
  [663] = 543,
  [664] = 544,
  [665] = 541,
  [666] = 546,
  [667] = 547,
  [668] = 548,
  [669] = 549,
  [670] = 542,
  [671] = 543,
  [672] = 544,
  [673] = 549,
  [674] = 541,
  [675] = 546,
  [676] = 556,
  [677] = 547,
  [678] = 548,
  [679] = 544,
  [680] = 541,
  [681] = 546,
  [682] = 547,
  [683] = 548,
  [684] = 549,
  [685] = 542,
  [686] = 543,
  [687] = 549,
  [688] = 542,
  [689] = 543,
  [690] = 544,
  [691] = 556,
  [692] = 542,
  [693] = 541,
  [694] = 546,
  [695] = 544,
  [696] = 541,
  [697] = 546,
  [698] = 547,
  [699] = 548,
  [700] = 549,
  [701] = 542,
  [702] = 543,
  [703] = 547,
  [704] = 548,
  [705] = 549,
  [706] = 556,
  [707] = 542,
  [708] = 544,
  [709] = 541,
  [710] = 546,
  [711] = 547,
  [712] = 548,
  [713] = 549,
  [714] = 542,
  [715] = 543,
  [716] = 543,
  [717] = 544,
  [718] = 541,
  [719] = 556,
  [720] = 546,
  [721] = 544,
  [722] = 541,
  [723] = 546,
  [724] = 547,
  [725] = 548,
  [726] = 549,
  [727] = 542,
  [728] = 543,
  [729] = 547,
  [730] = 548,
  [731] = 549,
  [732] = 556,
  [733] = 542,
  [734] = 543,
  [735] = 544,
  [736] = 736,
  [737] = 556,
  [738] = 541,
  [739] = 546,
  [740] = 547,
  [741] = 548,
  [742] = 549,
  [743] = 556,
  [744] = 542,
  [745] = 543,
  [746] = 544,
  [747] = 747,
  [748] = 541,
  [749] = 556,
  [750] = 546,
  [751] = 547,
  [752] = 548,
  [753] = 549,
  [754] = 542,
  [755] = 556,
  [756] = 543,
  [757] = 544,
  [758] = 758,
  [759] = 541,
  [760] = 546,
  [761] = 556,
  [762] = 547,
  [763] = 548,
  [764] = 549,
  [765] = 542,
  [766] = 543,
  [767] = 556,
  [768] = 544,
  [769] = 769,
  [770] = 541,
  [771] = 546,
  [772] = 547,
  [773] = 556,
  [774] = 548,
  [775] = 549,
  [776] = 542,
  [777] = 543,
  [778] = 544,
  [779] = 556,
  [780] = 780,
  [781] = 541,
  [782] = 546,
  [783] = 547,
  [784] = 548,
  [785] = 556,
  [786] = 549,
  [787] = 542,
  [788] = 543,
  [789] = 544,
  [790] = 790,
  [791] = 556,
  [792] = 541,
  [793] = 546,
  [794] = 547,
  [795] = 548,
  [796] = 549,
  [797] = 556,
  [798] = 542,
  [799] = 543,
  [800] = 544,
  [801] = 541,
  [802] = 556,
  [803] = 546,
  [804] = 547,
  [805] = 548,
  [806] = 549,
  [807] = 542,
  [808] = 556,
  [809] = 543,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 556,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 556,
  [821] = 816,
  [822] = 543,
  [823] = 823,
  [824] = 824,
  [825] = 556,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 556,
  [850] = 544,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 544,
  [855] = 610,
  [856] = 623,
  [857] = 811,
  [858] = 812,
  [859] = 826,
  [860] = 827,
  [861] = 837,
  [862] = 541,
  [863] = 546,
  [864] = 544,
  [865] = 541,
  [866] = 546,
  [867] = 547,
  [868] = 548,
  [869] = 549,
  [870] = 542,
  [871] = 543,
  [872] = 544,
  [873] = 541,
  [874] = 546,
  [875] = 547,
  [876] = 548,
  [877] = 547,
  [878] = 549,
  [879] = 542,
  [880] = 851,
  [881] = 543,
  [882] = 544,
  [883] = 541,
  [884] = 546,
  [885] = 547,
  [886] = 548,
  [887] = 548,
  [888] = 549,
  [889] = 542,
  [890] = 541,
  [891] = 543,
  [892] = 544,
  [893] = 541,
  [894] = 546,
  [895] = 547,
  [896] = 548,
  [897] = 549,
  [898] = 542,
  [899] = 543,
  [900] = 544,
  [901] = 541,
  [902] = 546,
  [903] = 547,
  [904] = 548,
  [905] = 549,
  [906] = 542,
  [907] = 543,
  [908] = 556,
  [909] = 554,
  [910] = 758,
  [911] = 560,
  [912] = 579,
  [913] = 582,
  [914] = 769,
  [915] = 780,
  [916] = 790,
  [917] = 810,
  [918] = 823,
  [919] = 824,
  [920] = 835,
  [921] = 836,
  [922] = 844,
  [923] = 544,
  [924] = 541,
  [925] = 546,
  [926] = 547,
  [927] = 548,
  [928] = 549,
  [929] = 542,
  [930] = 543,
  [931] = 544,
  [932] = 541,
  [933] = 546,
  [934] = 547,
  [935] = 548,
  [936] = 549,
  [937] = 542,
  [938] = 543,
  [939] = 546,
  [940] = 556,
  [941] = 556,
  [942] = 556,
  [943] = 556,
  [944] = 544,
  [945] = 556,
  [946] = 554,
  [947] = 758,
  [948] = 560,
  [949] = 579,
  [950] = 582,
  [951] = 769,
  [952] = 780,
  [953] = 790,
  [954] = 810,
  [955] = 823,
  [956] = 824,
  [957] = 835,
  [958] = 836,
  [959] = 844,
  [960] = 541,
  [961] = 546,
  [962] = 556,
  [963] = 554,
  [964] = 758,
  [965] = 560,
  [966] = 549,
  [967] = 582,
  [968] = 769,
  [969] = 780,
  [970] = 790,
  [971] = 810,
  [972] = 823,
  [973] = 824,
  [974] = 835,
  [975] = 836,
  [976] = 844,
  [977] = 547,
  [978] = 556,
  [979] = 758,
  [980] = 560,
  [981] = 579,
  [982] = 582,
  [983] = 769,
  [984] = 780,
  [985] = 790,
  [986] = 810,
  [987] = 824,
  [988] = 836,
  [989] = 844,
  [990] = 548,
  [991] = 556,
  [992] = 758,
  [993] = 560,
  [994] = 579,
  [995] = 582,
  [996] = 769,
  [997] = 780,
  [998] = 790,
  [999] = 810,
  [1000] = 824,
  [1001] = 836,
  [1002] = 844,
  [1003] = 549,
  [1004] = 556,
  [1005] = 758,
  [1006] = 560,
  [1007] = 579,
  [1008] = 582,
  [1009] = 769,
  [1010] = 780,
  [1011] = 790,
  [1012] = 542,
  [1013] = 556,
  [1014] = 758,
  [1015] = 560,
  [1016] = 579,
  [1017] = 582,
  [1018] = 769,
  [1019] = 780,
  [1020] = 790,
  [1021] = 543,
  [1022] = 556,
  [1023] = 758,
  [1024] = 560,
  [1025] = 579,
  [1026] = 582,
  [1027] = 769,
  [1028] = 780,
  [1029] = 790,
  [1030] = 544,
  [1031] = 556,
  [1032] = 758,
  [1033] = 560,
  [1034] = 579,
  [1035] = 582,
  [1036] = 769,
  [1037] = 780,
  [1038] = 790,
  [1039] = 610,
  [1040] = 556,
  [1041] = 758,
  [1042] = 560,
  [1043] = 579,
  [1044] = 582,
  [1045] = 769,
  [1046] = 780,
  [1047] = 790,
  [1048] = 541,
  [1049] = 556,
  [1050] = 758,
  [1051] = 560,
  [1052] = 579,
  [1053] = 582,
  [1054] = 769,
  [1055] = 780,
  [1056] = 790,
  [1057] = 546,
  [1058] = 758,
  [1059] = 560,
  [1060] = 579,
  [1061] = 582,
  [1062] = 769,
  [1063] = 780,
  [1064] = 790,
  [1065] = 547,
  [1066] = 758,
  [1067] = 560,
  [1068] = 579,
  [1069] = 582,
  [1070] = 769,
  [1071] = 780,
  [1072] = 790,
  [1073] = 548,
  [1074] = 758,
  [1075] = 560,
  [1076] = 579,
  [1077] = 582,
  [1078] = 769,
  [1079] = 780,
  [1080] = 790,
  [1081] = 549,
  [1082] = 758,
  [1083] = 560,
  [1084] = 579,
  [1085] = 582,
  [1086] = 769,
  [1087] = 780,
  [1088] = 790,
  [1089] = 542,
  [1090] = 758,
  [1091] = 560,
  [1092] = 579,
  [1093] = 582,
  [1094] = 769,
  [1095] = 780,
  [1096] = 790,
  [1097] = 543,
  [1098] = 758,
  [1099] = 560,
  [1100] = 579,
  [1101] = 582,
  [1102] = 769,
  [1103] = 780,
  [1104] = 790,
  [1105] = 544,
  [1106] = 758,
  [1107] = 560,
  [1108] = 579,
  [1109] = 582,
  [1110] = 769,
  [1111] = 780,
  [1112] = 790,
  [1113] = 623,
  [1114] = 758,
  [1115] = 560,
  [1116] = 579,
  [1117] = 582,
  [1118] = 769,
  [1119] = 780,
  [1120] = 790,
  [1121] = 541,
  [1122] = 758,
  [1123] = 560,
  [1124] = 579,
  [1125] = 582,
  [1126] = 769,
  [1127] = 780,
  [1128] = 790,
  [1129] = 546,
  [1130] = 758,
  [1131] = 560,
  [1132] = 579,
  [1133] = 582,
  [1134] = 769,
  [1135] = 780,
  [1136] = 790,
  [1137] = 547,
  [1138] = 758,
  [1139] = 560,
  [1140] = 579,
  [1141] = 582,
  [1142] = 769,
  [1143] = 780,
  [1144] = 790,
  [1145] = 548,
  [1146] = 758,
  [1147] = 560,
  [1148] = 579,
  [1149] = 582,
  [1150] = 769,
  [1151] = 780,
  [1152] = 790,
  [1153] = 549,
  [1154] = 758,
  [1155] = 560,
  [1156] = 579,
  [1157] = 582,
  [1158] = 769,
  [1159] = 780,
  [1160] = 790,
  [1161] = 542,
  [1162] = 758,
  [1163] = 560,
  [1164] = 579,
  [1165] = 582,
  [1166] = 769,
  [1167] = 780,
  [1168] = 790,
  [1169] = 543,
  [1170] = 758,
  [1171] = 560,
  [1172] = 579,
  [1173] = 582,
  [1174] = 769,
  [1175] = 780,
  [1176] = 790,
  [1177] = 544,
  [1178] = 758,
  [1179] = 560,
  [1180] = 579,
  [1181] = 582,
  [1182] = 769,
  [1183] = 780,
  [1184] = 790,
  [1185] = 541,
  [1186] = 758,
  [1187] = 560,
  [1188] = 579,
  [1189] = 582,
  [1190] = 769,
  [1191] = 780,
  [1192] = 790,
  [1193] = 546,
  [1194] = 758,
  [1195] = 560,
  [1196] = 579,
  [1197] = 582,
  [1198] = 769,
  [1199] = 780,
  [1200] = 790,
  [1201] = 547,
  [1202] = 758,
  [1203] = 560,
  [1204] = 579,
  [1205] = 582,
  [1206] = 769,
  [1207] = 780,
  [1208] = 790,
  [1209] = 548,
  [1210] = 758,
  [1211] = 560,
  [1212] = 579,
  [1213] = 582,
  [1214] = 769,
  [1215] = 780,
  [1216] = 790,
  [1217] = 549,
  [1218] = 758,
  [1219] = 560,
  [1220] = 579,
  [1221] = 582,
  [1222] = 769,
  [1223] = 780,
  [1224] = 790,
  [1225] = 542,
  [1226] = 758,
  [1227] = 560,
  [1228] = 579,
  [1229] = 582,
  [1230] = 769,
  [1231] = 780,
  [1232] = 790,
  [1233] = 543,
  [1234] = 758,
  [1235] = 560,
  [1236] = 579,
  [1237] = 582,
  [1238] = 769,
  [1239] = 780,
  [1240] = 790,
  [1241] = 758,
  [1242] = 560,
  [1243] = 579,
  [1244] = 582,
  [1245] = 769,
  [1246] = 780,
  [1247] = 790,
  [1248] = 758,
  [1249] = 560,
  [1250] = 579,
  [1251] = 582,
  [1252] = 769,
  [1253] = 780,
  [1254] = 790,
  [1255] = 758,
  [1256] = 560,
  [1257] = 579,
  [1258] = 582,
  [1259] = 769,
  [1260] = 780,
  [1261] = 790,
  [1262] = 758,
  [1263] = 560,
  [1264] = 579,
  [1265] = 582,
  [1266] = 769,
  [1267] = 780,
  [1268] = 790,
  [1269] = 758,
  [1270] = 560,
  [1271] = 579,
  [1272] = 582,
  [1273] = 769,
  [1274] = 780,
  [1275] = 790,
  [1276] = 758,
  [1277] = 560,
  [1278] = 579,
  [1279] = 582,
  [1280] = 769,
  [1281] = 780,
  [1282] = 790,
  [1283] = 758,
  [1284] = 560,
  [1285] = 579,
  [1286] = 582,
  [1287] = 769,
  [1288] = 780,
  [1289] = 790,
  [1290] = 549,
  [1291] = 542,
  [1292] = 547,
  [1293] = 853,
  [1294] = 606,
  [1295] = 747,
  [1296] = 851,
  [1297] = 852,
  [1298] = 811,
  [1299] = 853,
  [1300] = 606,
  [1301] = 747,
  [1302] = 812,
  [1303] = 543,
  [1304] = 826,
  [1305] = 853,
  [1306] = 606,
  [1307] = 747,
  [1308] = 827,
  [1309] = 853,
  [1310] = 606,
  [1311] = 747,
  [1312] = 837,
  [1313] = 544,
  [1314] = 556,
  [1315] = 853,
  [1316] = 606,
  [1317] = 747,
  [1318] = 851,
  [1319] = 853,
  [1320] = 606,
  [1321] = 747,
  [1322] = 541,
  [1323] = 546,
  [1324] = 853,
  [1325] = 606,
  [1326] = 747,
  [1327] = 610,
  [1328] = 623,
  [1329] = 853,
  [1330] = 606,
  [1331] = 747,
  [1332] = 811,
  [1333] = 812,
  [1334] = 853,
  [1335] = 606,
  [1336] = 747,
  [1337] = 826,
  [1338] = 827,
  [1339] = 837,
  [1340] = 853,
  [1341] = 606,
  [1342] = 747,
  [1343] = 547,
  [1344] = 548,
  [1345] = 853,
  [1346] = 606,
  [1347] = 747,
  [1348] = 548,
  [1349] = 853,
  [1350] = 606,
  [1351] = 747,
  [1352] = 853,
  [1353] = 606,
  [1354] = 747,
  [1355] = 549,
  [1356] = 853,
  [1357] = 606,
  [1358] = 747,
  [1359] = 542,
  [1360] = 853,
  [1361] = 606,
  [1362] = 747,
  [1363] = 853,
  [1364] = 606,
  [1365] = 747,
  [1366] = 544,
  [1367] = 853,
  [1368] = 606,
  [1369] = 747,
  [1370] = 541,
  [1371] = 546,
  [1372] = 853,
  [1373] = 606,
  [1374] = 747,
  [1375] = 547,
  [1376] = 548,
  [1377] = 853,
  [1378] = 606,
  [1379] = 747,
  [1380] = 549,
  [1381] = 542,
  [1382] = 853,
  [1383] = 606,
  [1384] = 747,
  [1385] = 736,
  [1386] = 543,
  [1387] = 853,
  [1388] = 606,
  [1389] = 747,
  [1390] = 544,
  [1391] = 541,
  [1392] = 853,
  [1393] = 606,
  [1394] = 747,
  [1395] = 546,
  [1396] = 547,
  [1397] = 853,
  [1398] = 606,
  [1399] = 747,
  [1400] = 548,
  [1401] = 549,
  [1402] = 853,
  [1403] = 606,
  [1404] = 747,
  [1405] = 542,
  [1406] = 543,
  [1407] = 853,
  [1408] = 606,
  [1409] = 747,
  [1410] = 853,
  [1411] = 606,
  [1412] = 747,
  [1413] = 543,
  [1414] = 853,
  [1415] = 606,
  [1416] = 747,
  [1417] = 544,
  [1418] = 1418,
  [1419] = 853,
  [1420] = 606,
  [1421] = 747,
  [1422] = 556,
  [1423] = 1423,
  [1424] = 853,
  [1425] = 606,
  [1426] = 747,
  [1427] = 851,
  [1428] = 853,
  [1429] = 606,
  [1430] = 747,
  [1431] = 546,
  [1432] = 853,
  [1433] = 606,
  [1434] = 747,
  [1435] = 547,
  [1436] = 610,
  [1437] = 853,
  [1438] = 606,
  [1439] = 747,
  [1440] = 623,
  [1441] = 853,
  [1442] = 606,
  [1443] = 747,
  [1444] = 811,
  [1445] = 853,
  [1446] = 606,
  [1447] = 747,
  [1448] = 812,
  [1449] = 826,
  [1450] = 853,
  [1451] = 606,
  [1452] = 747,
  [1453] = 827,
  [1454] = 837,
  [1455] = 853,
  [1456] = 606,
  [1457] = 747,
  [1458] = 548,
  [1459] = 853,
  [1460] = 606,
  [1461] = 747,
  [1462] = 1423,
  [1463] = 853,
  [1464] = 606,
  [1465] = 747,
  [1466] = 549,
  [1467] = 542,
  [1468] = 853,
  [1469] = 606,
  [1470] = 747,
  [1471] = 556,
  [1472] = 853,
  [1473] = 606,
  [1474] = 747,
  [1475] = 544,
  [1476] = 853,
  [1477] = 606,
  [1478] = 747,
  [1479] = 541,
  [1480] = 546,
  [1481] = 853,
  [1482] = 606,
  [1483] = 747,
  [1484] = 547,
  [1485] = 548,
  [1486] = 853,
  [1487] = 606,
  [1488] = 747,
  [1489] = 1423,
  [1490] = 736,
  [1491] = 1423,
  [1492] = 736,
  [1493] = 579,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1496,
  [1497] = 1494,
  [1498] = 1498,
  [1499] = 1499,
  [1500] = 1500,
  [1501] = 1494,
  [1502] = 1494,
  [1503] = 1503,
  [1504] = 1494,
  [1505] = 1503,
  [1506] = 1503,
  [1507] = 1500,
  [1508] = 1495,
  [1509] = 1496,
  [1510] = 1503,
  [1511] = 1500,
  [1512] = 1498,
  [1513] = 1499,
  [1514] = 1500,
  [1515] = 1495,
  [1516] = 1494,
  [1517] = 1503,
  [1518] = 1495,
  [1519] = 1496,
  [1520] = 1496,
  [1521] = 1498,
  [1522] = 1495,
  [1523] = 1496,
  [1524] = 1499,
  [1525] = 1500,
  [1526] = 1498,
  [1527] = 1499,
  [1528] = 1500,
  [1529] = 1500,
  [1530] = 1494,
  [1531] = 1503,
  [1532] = 1498,
  [1533] = 1495,
  [1534] = 1496,
  [1535] = 1498,
  [1536] = 1495,
  [1537] = 1496,
  [1538] = 1498,
  [1539] = 1498,
  [1540] = 1499,
  [1541] = 1500,
  [1542] = 1499,
  [1543] = 1494,
  [1544] = 1503,
  [1545] = 1500,
  [1546] = 1499,
  [1547] = 1500,
  [1548] = 1494,
  [1549] = 1495,
  [1550] = 1496,
  [1551] = 1503,
  [1552] = 1498,
  [1553] = 1499,
  [1554] = 1500,
  [1555] = 1494,
  [1556] = 1503,
  [1557] = 1499,
  [1558] = 1494,
  [1559] = 1500,
  [1560] = 1500,
  [1561] = 1495,
  [1562] = 1496,
  [1563] = 1495,
  [1564] = 1498,
  [1565] = 1499,
  [1566] = 1496,
  [1567] = 1494,
  [1568] = 1503,
  [1569] = 1494,
  [1570] = 1498,
  [1571] = 1499,
  [1572] = 1500,
  [1573] = 1495,
  [1574] = 1496,
  [1575] = 1503,
  [1576] = 1498,
  [1577] = 1499,
  [1578] = 1500,
  [1579] = 1494,
  [1580] = 1503,
  [1581] = 1500,
  [1582] = 1495,
  [1583] = 1496,
  [1584] = 1500,
  [1585] = 1495,
  [1586] = 1496,
  [1587] = 1498,
  [1588] = 1498,
  [1589] = 1499,
  [1590] = 1499,
  [1591] = 1494,
  [1592] = 1503,
  [1593] = 1494,
  [1594] = 1494,
  [1595] = 1503,
  [1596] = 1503,
  [1597] = 1495,
  [1598] = 1496,
  [1599] = 1494,
  [1600] = 1503,
  [1601] = 1500,
  [1602] = 1498,
  [1603] = 1499,
  [1604] = 1499,
  [1605] = 1494,
  [1606] = 1503,
  [1607] = 1503,
  [1608] = 816,
  [1609] = 1495,
  [1610] = 1496,
  [1611] = 1495,
  [1612] = 1495,
  [1613] = 1495,
  [1614] = 1496,
  [1615] = 816,
  [1616] = 1498,
  [1617] = 1496,
  [1618] = 1499,
  [1619] = 1495,
  [1620] = 1494,
  [1621] = 1503,
  [1622] = 1498,
  [1623] = 1499,
  [1624] = 1500,
  [1625] = 1498,
  [1626] = 1495,
  [1627] = 1496,
  [1628] = 1495,
  [1629] = 1499,
  [1630] = 1498,
  [1631] = 1499,
  [1632] = 1494,
  [1633] = 1494,
  [1634] = 1503,
  [1635] = 1503,
  [1636] = 816,
  [1637] = 1495,
  [1638] = 1495,
  [1639] = 1496,
  [1640] = 1496,
  [1641] = 1498,
  [1642] = 1500,
  [1643] = 1499,
  [1644] = 1494,
  [1645] = 1494,
  [1646] = 1503,
  [1647] = 1500,
  [1648] = 1495,
  [1649] = 1496,
  [1650] = 1498,
  [1651] = 1495,
  [1652] = 1500,
  [1653] = 1500,
  [1654] = 1496,
  [1655] = 1498,
  [1656] = 1498,
  [1657] = 1499,
  [1658] = 1500,
  [1659] = 1499,
  [1660] = 1494,
  [1661] = 1503,
  [1662] = 1500,
  [1663] = 1500,
  [1664] = 1499,
  [1665] = 1500,
  [1666] = 1500,
  [1667] = 1500,
  [1668] = 1500,
  [1669] = 1496,
  [1670] = 1503,
  [1671] = 1498,
  [1672] = 1500,
  [1673] = 1499,
  [1674] = 1494,
  [1675] = 1494,
  [1676] = 1503,
  [1677] = 1503,
  [1678] = 1503,
  [1679] = 1500,
  [1680] = 1495,
  [1681] = 1496,
  [1682] = 1500,
  [1683] = 1498,
  [1684] = 1499,
  [1685] = 1500,
  [1686] = 1494,
  [1687] = 1503,
  [1688] = 1495,
  [1689] = 1496,
  [1690] = 1500,
  [1691] = 1495,
  [1692] = 1496,
  [1693] = 1495,
  [1694] = 1498,
  [1695] = 1499,
  [1696] = 1496,
  [1697] = 1494,
  [1698] = 1503,
  [1699] = 1498,
  [1700] = 1500,
  [1701] = 1499,
  [1702] = 1495,
  [1703] = 1496,
  [1704] = 1500,
  [1705] = 1498,
  [1706] = 1499,
  [1707] = 1500,
  [1708] = 1494,
  [1709] = 1503,
  [1710] = 1498,
  [1711] = 1499,
  [1712] = 1494,
  [1713] = 1495,
  [1714] = 1496,
  [1715] = 1503,
  [1716] = 1498,
  [1717] = 1496,
  [1718] = 1494,
  [1719] = 1499,
  [1720] = 1500,
  [1721] = 1494,
  [1722] = 1503,
  [1723] = 1503,
  [1724] = 1496,
  [1725] = 1495,
  [1726] = 1500,
  [1727] = 1495,
  [1728] = 1496,
  [1729] = 1503,
  [1730] = 1498,
  [1731] = 1499,
  [1732] = 1496,
  [1733] = 1494,
  [1734] = 1503,
  [1735] = 1500,
  [1736] = 1495,
  [1737] = 1496,
  [1738] = 1495,
  [1739] = 1495,
  [1740] = 1496,
  [1741] = 1496,
  [1742] = 1496,
  [1743] = 1498,
  [1744] = 1499,
  [1745] = 1498,
  [1746] = 1494,
  [1747] = 1503,
  [1748] = 1499,
  [1749] = 1500,
  [1750] = 1500,
  [1751] = 1495,
  [1752] = 1496,
  [1753] = 1498,
  [1754] = 1498,
  [1755] = 1498,
  [1756] = 1499,
  [1757] = 1499,
  [1758] = 1494,
  [1759] = 1503,
  [1760] = 1499,
  [1761] = 1494,
  [1762] = 1503,
  [1763] = 1498,
  [1764] = 1495,
  [1765] = 1496,
  [1766] = 1500,
  [1767] = 1499,
  [1768] = 1498,
  [1769] = 1499,
  [1770] = 1500,
  [1771] = 816,
  [1772] = 1494,
  [1773] = 1500,
  [1774] = 1503,
  [1775] = 1500,
  [1776] = 1495,
  [1777] = 1496,
  [1778] = 1500,
  [1779] = 1500,
  [1780] = 1500,
  [1781] = 1495,
  [1782] = 1496,
  [1783] = 1498,
  [1784] = 1498,
  [1785] = 1499,
  [1786] = 1500,
  [1787] = 1499,
  [1788] = 1500,
  [1789] = 1494,
  [1790] = 1500,
  [1791] = 1503,
  [1792] = 1500,
  [1793] = 1500,
  [1794] = 1494,
  [1795] = 1500,
  [1796] = 1498,
  [1797] = 1495,
  [1798] = 1496,
  [1799] = 1500,
  [1800] = 1500,
  [1801] = 1498,
  [1802] = 1499,
  [1803] = 1500,
  [1804] = 1500,
  [1805] = 1500,
  [1806] = 1500,
  [1807] = 1494,
  [1808] = 1503,
  [1809] = 1494,
  [1810] = 1503,
  [1811] = 1495,
  [1812] = 1812,
  [1813] = 1812,
  [1814] = 816,
  [1815] = 816,
  [1816] = 1816,
  [1817] = 1816,
  [1818] = 1818,
  [1819] = 1819,
  [1820] = 1820,
  [1821] = 1821,
  [1822] = 1822,
  [1823] = 1823,
  [1824] = 1824,
  [1825] = 1825,
  [1826] = 1826,
  [1827] = 1827,
  [1828] = 1828,
  [1829] = 1829,
  [1830] = 1818,
  [1831] = 1812,
  [1832] = 1818,
  [1833] = 1819,
  [1834] = 1820,
  [1835] = 1821,
  [1836] = 1822,
  [1837] = 1823,
  [1838] = 1824,
  [1839] = 1825,
  [1840] = 1826,
  [1841] = 1827,
  [1842] = 1828,
  [1843] = 1829,
  [1844] = 1812,
  [1845] = 1818,
  [1846] = 1819,
  [1847] = 1820,
  [1848] = 1821,
  [1849] = 1822,
  [1850] = 1823,
  [1851] = 1824,
  [1852] = 1825,
  [1853] = 1826,
  [1854] = 1827,
  [1855] = 1828,
  [1856] = 1829,
  [1857] = 1812,
  [1858] = 1818,
  [1859] = 1819,
  [1860] = 1820,
  [1861] = 1821,
  [1862] = 1822,
  [1863] = 1823,
  [1864] = 1824,
  [1865] = 1825,
  [1866] = 1826,
  [1867] = 1827,
  [1868] = 1828,
  [1869] = 1829,
  [1870] = 1812,
  [1871] = 1818,
  [1872] = 1819,
  [1873] = 1820,
  [1874] = 1821,
  [1875] = 1822,
  [1876] = 1823,
  [1877] = 1824,
  [1878] = 1825,
  [1879] = 1826,
  [1880] = 1827,
  [1881] = 1828,
  [1882] = 1829,
  [1883] = 1819,
  [1884] = 1820,
  [1885] = 1821,
  [1886] = 1822,
  [1887] = 1812,
  [1888] = 1823,
  [1889] = 1824,
  [1890] = 1825,
  [1891] = 1826,
  [1892] = 1827,
  [1893] = 1828,
  [1894] = 1829,
  [1895] = 1818,
  [1896] = 1819,
  [1897] = 1820,
  [1898] = 1821,
  [1899] = 1822,
  [1900] = 1823,
  [1901] = 1824,
  [1902] = 1825,
  [1903] = 1826,
  [1904] = 1827,
  [1905] = 1828,
  [1906] = 1829,
  [1907] = 1812,
  [1908] = 1818,
  [1909] = 1819,
  [1910] = 1820,
  [1911] = 1821,
  [1912] = 1822,
  [1913] = 1823,
  [1914] = 1824,
  [1915] = 1825,
  [1916] = 1826,
  [1917] = 1827,
  [1918] = 1828,
  [1919] = 1829,
  [1920] = 1812,
  [1921] = 1818,
  [1922] = 1819,
  [1923] = 1820,
  [1924] = 1821,
  [1925] = 1822,
  [1926] = 1823,
  [1927] = 1824,
  [1928] = 1825,
  [1929] = 1826,
  [1930] = 1827,
  [1931] = 1828,
  [1932] = 1829,
  [1933] = 1816,
  [1934] = 1812,
  [1935] = 1819,
  [1936] = 1816,
  [1937] = 1816,
  [1938] = 1820,
  [1939] = 1821,
  [1940] = 1822,
  [1941] = 1812,
  [1942] = 1823,
  [1943] = 1818,
  [1944] = 1819,
  [1945] = 1820,
  [1946] = 1821,
  [1947] = 1822,
  [1948] = 1823,
  [1949] = 1824,
  [1950] = 1825,
  [1951] = 1826,
  [1952] = 1827,
  [1953] = 1828,
  [1954] = 1829,
  [1955] = 1824,
  [1956] = 1825,
  [1957] = 1818,
  [1958] = 1819,
  [1959] = 1820,
  [1960] = 1821,
  [1961] = 1822,
  [1962] = 1823,
  [1963] = 1824,
  [1964] = 1825,
  [1965] = 1826,
  [1966] = 1827,
  [1967] = 1828,
  [1968] = 1829,
  [1969] = 1812,
  [1970] = 1826,
  [1971] = 1827,
  [1972] = 1828,
  [1973] = 1816,
  [1974] = 1816,
  [1975] = 1829,
  [1976] = 1818,
  [1977] = 1819,
  [1978] = 1820,
  [1979] = 1821,
  [1980] = 1822,
  [1981] = 1823,
  [1982] = 1824,
  [1983] = 1825,
  [1984] = 1826,
  [1985] = 1827,
  [1986] = 1828,
  [1987] = 1829,
  [1988] = 1812,
  [1989] = 1818,
  [1990] = 1819,
  [1991] = 1820,
  [1992] = 1821,
  [1993] = 1822,
  [1994] = 1823,
  [1995] = 1824,
  [1996] = 1825,
  [1997] = 1826,
  [1998] = 1827,
  [1999] = 1828,
  [2000] = 1829,
  [2001] = 1812,
  [2002] = 1816,
  [2003] = 1816,
  [2004] = 1818,
  [2005] = 1818,
  [2006] = 1819,
  [2007] = 1820,
  [2008] = 1821,
  [2009] = 1822,
  [2010] = 1823,
  [2011] = 1824,
  [2012] = 1825,
  [2013] = 1826,
  [2014] = 1827,
  [2015] = 1828,
  [2016] = 1829,
  [2017] = 1812,
  [2018] = 1818,
  [2019] = 1819,
  [2020] = 1820,
  [2021] = 1821,
  [2022] = 1822,
  [2023] = 1823,
  [2024] = 1824,
  [2025] = 1825,
  [2026] = 1826,
  [2027] = 1827,
  [2028] = 1828,
  [2029] = 1829,
  [2030] = 1819,
  [2031] = 1812,
  [2032] = 1820,
  [2033] = 1821,
  [2034] = 1822,
  [2035] = 1823,
  [2036] = 1824,
  [2037] = 1825,
  [2038] = 1826,
  [2039] = 1827,
  [2040] = 1828,
  [2041] = 1829,
  [2042] = 1816,
  [2043] = 1816,
  [2044] = 1818,
  [2045] = 1819,
  [2046] = 1820,
  [2047] = 1821,
  [2048] = 1822,
  [2049] = 1823,
  [2050] = 1824,
  [2051] = 1825,
  [2052] = 1826,
  [2053] = 1827,
  [2054] = 1828,
  [2055] = 1829,
  [2056] = 1812,
  [2057] = 1818,
  [2058] = 1819,
  [2059] = 1820,
  [2060] = 1821,
  [2061] = 1822,
  [2062] = 1823,
  [2063] = 1824,
  [2064] = 1825,
  [2065] = 1826,
  [2066] = 1827,
  [2067] = 1828,
  [2068] = 1829,
  [2069] = 1812,
  [2070] = 1816,
  [2071] = 1812,
  [2072] = 1818,
  [2073] = 1819,
  [2074] = 1820,
  [2075] = 1821,
  [2076] = 1822,
  [2077] = 1823,
  [2078] = 1824,
  [2079] = 1825,
  [2080] = 1826,
  [2081] = 1827,
  [2082] = 1828,
  [2083] = 1829,
  [2084] = 1812,
  [2085] = 1816,
  [2086] = 1818,
  [2087] = 1819,
  [2088] = 1820,
  [2089] = 1821,
  [2090] = 1822,
  [2091] = 1823,
  [2092] = 1824,
  [2093] = 1825,
  [2094] = 1826,
  [2095] = 1827,
  [2096] = 1828,
  [2097] = 1829,
  [2098] = 1812,
  [2099] = 1816,
  [2100] = 1818,
  [2101] = 1819,
  [2102] = 1820,
  [2103] = 1821,
  [2104] = 1822,
  [2105] = 1823,
  [2106] = 1824,
  [2107] = 1825,
  [2108] = 1826,
  [2109] = 1827,
  [2110] = 1828,
  [2111] = 1829,
  [2112] = 1818,
  [2113] = 1812,
  [2114] = 1819,
  [2115] = 1816,
  [2116] = 1820,
  [2117] = 1821,
  [2118] = 1822,
  [2119] = 1823,
  [2120] = 1824,
  [2121] = 1818,
  [2122] = 1825,
  [2123] = 1819,
  [2124] = 1820,
  [2125] = 1821,
  [2126] = 1822,
  [2127] = 1823,
  [2128] = 1824,
  [2129] = 1825,
  [2130] = 1826,
  [2131] = 1827,
  [2132] = 1828,
  [2133] = 1829,
  [2134] = 1826,
  [2135] = 1827,
  [2136] = 1828,
  [2137] = 1829,
  [2138] = 1812,
  [2139] = 1816,
  [2140] = 1818,
  [2141] = 1819,
  [2142] = 1820,
  [2143] = 1821,
  [2144] = 1822,
  [2145] = 1823,
  [2146] = 1824,
  [2147] = 1825,
  [2148] = 1826,
  [2149] = 1827,
  [2150] = 1828,
  [2151] = 1829,
  [2152] = 1812,
  [2153] = 1812,
  [2154] = 1818,
  [2155] = 1816,
  [2156] = 1818,
  [2157] = 1819,
  [2158] = 1820,
  [2159] = 1821,
  [2160] = 1822,
  [2161] = 1823,
  [2162] = 1824,
  [2163] = 1825,
  [2164] = 1826,
  [2165] = 1828,
  [2166] = 1829,
  [2167] = 1819,
  [2168] = 1820,
  [2169] = 1821,
  [2170] = 1822,
  [2171] = 1823,
  [2172] = 1812,
  [2173] = 1824,
  [2174] = 1825,
  [2175] = 1826,
  [2176] = 1827,
  [2177] = 1828,
  [2178] = 1829,
  [2179] = 1816,
  [2180] = 1818,
  [2181] = 1819,
  [2182] = 1820,
  [2183] = 1821,
  [2184] = 1822,
  [2185] = 1823,
  [2186] = 1824,
  [2187] = 1825,
  [2188] = 1826,
  [2189] = 1827,
  [2190] = 1828,
  [2191] = 1829,
  [2192] = 1812,
  [2193] = 1812,
  [2194] = 2194,
  [2195] = 1816,
  [2196] = 1818,
  [2197] = 1816,
  [2198] = 1819,
  [2199] = 1820,
  [2200] = 1821,
  [2201] = 1822,
  [2202] = 1823,
  [2203] = 1824,
  [2204] = 1825,
  [2205] = 1826,
  [2206] = 1827,
  [2207] = 1828,
  [2208] = 1829,
  [2209] = 1818,
  [2210] = 1816,
  [2211] = 1812,
  [2212] = 1818,
  [2213] = 1819,
  [2214] = 1820,
  [2215] = 1821,
  [2216] = 1822,
  [2217] = 1823,
  [2218] = 1824,
  [2219] = 1825,
  [2220] = 1826,
  [2221] = 1827,
  [2222] = 1828,
  [2223] = 1829,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 1812,
  [2227] = 1818,
  [2228] = 1819,
  [2229] = 1820,
  [2230] = 1821,
  [2231] = 1822,
  [2232] = 1823,
  [2233] = 1824,
  [2234] = 1825,
  [2235] = 1826,
  [2236] = 1827,
  [2237] = 1828,
  [2238] = 1829,
  [2239] = 1812,
  [2240] = 1818,
  [2241] = 1819,
  [2242] = 1820,
  [2243] = 1821,
  [2244] = 1822,
  [2245] = 1823,
  [2246] = 1824,
  [2247] = 1825,
  [2248] = 1826,
  [2249] = 1827,
  [2250] = 1828,
  [2251] = 1829,
  [2252] = 1812,
  [2253] = 1818,
  [2254] = 1819,
  [2255] = 1820,
  [2256] = 1821,
  [2257] = 1822,
  [2258] = 1823,
  [2259] = 1824,
  [2260] = 1825,
  [2261] = 1826,
  [2262] = 1827,
  [2263] = 1828,
  [2264] = 1829,
  [2265] = 1812,
  [2266] = 1818,
  [2267] = 1819,
  [2268] = 1820,
  [2269] = 1821,
  [2270] = 1822,
  [2271] = 1823,
  [2272] = 1824,
  [2273] = 1825,
  [2274] = 1826,
  [2275] = 1827,
  [2276] = 1828,
  [2277] = 1829,
  [2278] = 1812,
  [2279] = 2225,
  [2280] = 2280,
  [2281] = 1816,
  [2282] = 1818,
  [2283] = 1819,
  [2284] = 1820,
  [2285] = 1821,
  [2286] = 1822,
  [2287] = 1823,
  [2288] = 1824,
  [2289] = 1825,
  [2290] = 1826,
  [2291] = 1827,
  [2292] = 1828,
  [2293] = 1829,
  [2294] = 1812,
  [2295] = 1818,
  [2296] = 1819,
  [2297] = 1820,
  [2298] = 1821,
  [2299] = 1822,
  [2300] = 1823,
  [2301] = 1824,
  [2302] = 1825,
  [2303] = 1826,
  [2304] = 1827,
  [2305] = 1828,
  [2306] = 1829,
  [2307] = 1812,
  [2308] = 1818,
  [2309] = 1819,
  [2310] = 1820,
  [2311] = 1821,
  [2312] = 1822,
  [2313] = 1823,
  [2314] = 1824,
  [2315] = 1825,
  [2316] = 1826,
  [2317] = 1827,
  [2318] = 1828,
  [2319] = 1829,
  [2320] = 1812,
  [2321] = 1818,
  [2322] = 1819,
  [2323] = 1820,
  [2324] = 1821,
  [2325] = 1822,
  [2326] = 1823,
  [2327] = 1824,
  [2328] = 1825,
  [2329] = 1826,
  [2330] = 1827,
  [2331] = 1828,
  [2332] = 1829,
  [2333] = 1812,
  [2334] = 1816,
  [2335] = 1818,
  [2336] = 1819,
  [2337] = 1820,
  [2338] = 1821,
  [2339] = 1822,
  [2340] = 1823,
  [2341] = 1824,
  [2342] = 1825,
  [2343] = 1826,
  [2344] = 1827,
  [2345] = 1828,
  [2346] = 1829,
  [2347] = 2347,
  [2348] = 1812,
  [2349] = 1818,
  [2350] = 1819,
  [2351] = 1820,
  [2352] = 1821,
  [2353] = 1822,
  [2354] = 1823,
  [2355] = 1824,
  [2356] = 1825,
  [2357] = 1826,
  [2358] = 1827,
  [2359] = 1828,
  [2360] = 1829,
  [2361] = 1812,
  [2362] = 1812,
  [2363] = 1818,
  [2364] = 1819,
  [2365] = 1820,
  [2366] = 1821,
  [2367] = 1822,
  [2368] = 1823,
  [2369] = 1824,
  [2370] = 1825,
  [2371] = 1826,
  [2372] = 1827,
  [2373] = 1828,
  [2374] = 1829,
  [2375] = 1812,
  [2376] = 1818,
  [2377] = 1819,
  [2378] = 1820,
  [2379] = 1821,
  [2380] = 1822,
  [2381] = 1823,
  [2382] = 1824,
  [2383] = 1825,
  [2384] = 1826,
  [2385] = 1827,
  [2386] = 1828,
  [2387] = 1829,
  [2388] = 1812,
  [2389] = 1818,
  [2390] = 1819,
  [2391] = 1820,
  [2392] = 1821,
  [2393] = 1822,
  [2394] = 1823,
  [2395] = 1824,
  [2396] = 1825,
  [2397] = 1826,
  [2398] = 1827,
  [2399] = 1828,
  [2400] = 1829,
  [2401] = 1812,
  [2402] = 1818,
  [2403] = 1819,
  [2404] = 1820,
  [2405] = 1821,
  [2406] = 1822,
  [2407] = 1823,
  [2408] = 1824,
  [2409] = 1825,
  [2410] = 1826,
  [2411] = 1827,
  [2412] = 1828,
  [2413] = 1829,
  [2414] = 1812,
  [2415] = 2280,
  [2416] = 1818,
  [2417] = 1819,
  [2418] = 1820,
  [2419] = 1821,
  [2420] = 1822,
  [2421] = 1823,
  [2422] = 1824,
  [2423] = 1825,
  [2424] = 1826,
  [2425] = 1827,
  [2426] = 1828,
  [2427] = 1829,
  [2428] = 1812,
  [2429] = 1818,
  [2430] = 1819,
  [2431] = 1820,
  [2432] = 1821,
  [2433] = 1822,
  [2434] = 1823,
  [2435] = 1824,
  [2436] = 1825,
  [2437] = 1826,
  [2438] = 1827,
  [2439] = 1828,
  [2440] = 1829,
  [2441] = 1827,
  [2442] = 2442,
  [2443] = 2443,
  [2444] = 816,
  [2445] = 816,
  [2446] = 2443,
  [2447] = 2442,
  [2448] = 816,
  [2449] = 2442,
  [2450] = 2442,
  [2451] = 2443,
  [2452] = 2443,
  [2453] = 2442,
  [2454] = 2442,
  [2455] = 816,
  [2456] = 2443,
  [2457] = 2443,
  [2458] = 2443,
  [2459] = 2443,
  [2460] = 2442,
  [2461] = 2442,
  [2462] = 2442,
  [2463] = 2443,
  [2464] = 2442,
  [2465] = 2443,
  [2466] = 2443,
  [2467] = 2442,
  [2468] = 2443,
  [2469] = 2442,
  [2470] = 816,
  [2471] = 816,
  [2472] = 816,
  [2473] = 2443,
  [2474] = 2442,
  [2475] = 816,
  [2476] = 816,
  [2477] = 2477,
  [2478] = 816,
  [2479] = 2442,
  [2480] = 2477,
  [2481] = 2443,
  [2482] = 2482,
  [2483] = 2483,
  [2484] = 2483,
  [2485] = 2483,
  [2486] = 2483,
  [2487] = 2443,
  [2488] = 2483,
  [2489] = 2482,
  [2490] = 2442,
  [2491] = 2477,
  [2492] = 2483,
  [2493] = 2483,
  [2494] = 2477,
  [2495] = 2483,
  [2496] = 2482,
  [2497] = 2442,
  [2498] = 2442,
  [2499] = 816,
  [2500] = 2482,
  [2501] = 2443,
  [2502] = 2443,
  [2503] = 2443,
  [2504] = 2504,
  [2505] = 2504,
  [2506] = 2506,
  [2507] = 2442,
  [2508] = 2506,
  [2509] = 2506,
  [2510] = 2504,
  [2511] = 2504,
  [2512] = 2506,
  [2513] = 2504,
  [2514] = 2506,
  [2515] = 2504,
  [2516] = 816,
  [2517] = 816,
  [2518] = 816,
  [2519] = 2442,
  [2520] = 816,
  [2521] = 816,
  [2522] = 816,
  [2523] = 816,
  [2524] = 816,
  [2525] = 2443,
  [2526] = 2526,
  [2527] = 2527,
  [2528] = 816,
  [2529] = 2442,
  [2530] = 2527,
  [2531] = 816,
  [2532] = 2527,
  [2533] = 816,
  [2534] = 2527,
  [2535] = 816,
  [2536] = 2527,
  [2537] = 2443,
  [2538] = 2526,
  [2539] = 2527,
  [2540] = 2527,
  [2541] = 816,
  [2542] = 2442,
  [2543] = 2543,
  [2544] = 2526,
  [2545] = 2442,
  [2546] = 2546,
  [2547] = 2543,
  [2548] = 2526,
  [2549] = 2442,
  [2550] = 2546,
  [2551] = 2443,
  [2552] = 2552,
  [2553] = 2442,
  [2554] = 2442,
  [2555] = 2442,
  [2556] = 2443,
  [2557] = 2552,
  [2558] = 2552,
  [2559] = 2442,
  [2560] = 2552,
  [2561] = 2552,
  [2562] = 2543,
  [2563] = 2443,
  [2564] = 2552,
  [2565] = 2552,
  [2566] = 2442,
  [2567] = 2546,
  [2568] = 2552,
  [2569] = 2443,
  [2570] = 2442,
  [2571] = 2442,
  [2572] = 2552,
  [2573] = 2443,
  [2574] = 2443,
  [2575] = 2552,
  [2576] = 2443,
  [2577] = 2543,
  [2578] = 2443,
  [2579] = 2442,
  [2580] = 2443,
  [2581] = 2443,
  [2582] = 2443,
  [2583] = 2546,
  [2584] = 2443,
  [2585] = 2442,
  [2586] = 2442,
  [2587] = 2442,
  [2588] = 2442,
  [2589] = 2442,
  [2590] = 2590,
  [2591] = 2543,
  [2592] = 2592,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 2595,
  [2596] = 2596,
  [2597] = 2442,
  [2598] = 2598,
  [2599] = 2599,
  [2600] = 2546,
  [2601] = 2594,
  [2602] = 2602,
  [2603] = 2595,
  [2604] = 2593,
  [2605] = 2596,
  [2606] = 2606,
  [2607] = 2598,
  [2608] = 2602,
  [2609] = 2592,
  [2610] = 2610,
  [2611] = 2610,
  [2612] = 2599,
  [2613] = 2606,
  [2614] = 2614,
  [2615] = 2606,
  [2616] = 2602,
  [2617] = 2599,
  [2618] = 2610,
  [2619] = 2596,
  [2620] = 2593,
  [2621] = 2598,
  [2622] = 2595,
  [2623] = 2592,
  [2624] = 2594,
  [2625] = 2477,
  [2626] = 2599,
  [2627] = 2610,
  [2628] = 2596,
  [2629] = 2595,
  [2630] = 2590,
  [2631] = 2593,
  [2632] = 2592,
  [2633] = 2594,
  [2634] = 2606,
  [2635] = 2602,
  [2636] = 2598,
  [2637] = 2637,
  [2638] = 2482,
  [2639] = 2614,
  [2640] = 2590,
  [2641] = 2637,
  [2642] = 2614,
  [2643] = 2637,
  [2644] = 2644,
  [2645] = 2644,
  [2646] = 2646,
  [2647] = 2644,
  [2648] = 2646,
  [2649] = 2646,
  [2650] = 2646,
  [2651] = 2646,
  [2652] = 2644,
  [2653] = 2646,
  [2654] = 2646,
  [2655] = 2646,
  [2656] = 2644,
  [2657] = 2646,
  [2658] = 2646,
  [2659] = 2644,
  [2660] = 2646,
  [2661] = 2646,
  [2662] = 2644,
  [2663] = 2646,
  [2664] = 2646,
  [2665] = 2646,
  [2666] = 2644,
  [2667] = 2646,
  [2668] = 2646,
  [2669] = 2644,
  [2670] = 2646,
  [2671] = 2646,
  [2672] = 2644,
  [2673] = 2644,
  [2674] = 2644,
  [2675] = 2644,
  [2676] = 2644,
  [2677] = 2646,
  [2678] = 2646,
  [2679] = 2646,
  [2680] = 2644,
  [2681] = 2644,
  [2682] = 2644,
  [2683] = 2644,
  [2684] = 2644,
  [2685] = 2644,
  [2686] = 2646,
  [2687] = 2637,
  [2688] = 2644,
  [2689] = 2644,
  [2690] = 2644,
  [2691] = 2646,
  [2692] = 2646,
  [2693] = 2646,
  [2694] = 2646,
  [2695] = 2644,
  [2696] = 2644,
  [2697] = 2644,
  [2698] = 2644,
  [2699] = 2646,
  [2700] = 2644,
  [2701] = 2644,
  [2702] = 2644,
  [2703] = 2646,
  [2704] = 2646,
  [2705] = 2646,
  [2706] = 2644,
  [2707] = 2644,
  [2708] = 2644,
  [2709] = 2646,
  [2710] = 2644,
  [2711] = 2644,
  [2712] = 2644,
  [2713] = 2644,
  [2714] = 2644,
  [2715] = 2646,
  [2716] = 2644,
  [2717] = 2644,
  [2718] = 2644,
  [2719] = 2646,
  [2720] = 2644,
  [2721] = 2646,
  [2722] = 2646,
  [2723] = 2644,
  [2724] = 2644,
  [2725] = 2644,
  [2726] = 2644,
  [2727] = 2644,
  [2728] = 2646,
  [2729] = 2646,
  [2730] = 2646,
  [2731] = 2646,
  [2732] = 2646,
  [2733] = 2644,
  [2734] = 2646,
  [2735] = 2646,
  [2736] = 2646,
  [2737] = 2737,
  [2738] = 2738,
  [2739] = 2739,
  [2740] = 2738,
  [2741] = 2737,
  [2742] = 2742,
  [2743] = 2743,
  [2744] = 2743,
  [2745] = 2739,
  [2746] = 2738,
  [2747] = 2737,
  [2748] = 2742,
  [2749] = 2743,
  [2750] = 2739,
  [2751] = 2738,
  [2752] = 2737,
  [2753] = 2737,
  [2754] = 2742,
  [2755] = 2743,
  [2756] = 2739,
  [2757] = 2738,
  [2758] = 2738,
  [2759] = 2737,
  [2760] = 2737,
  [2761] = 2742,
  [2762] = 2743,
  [2763] = 2739,
  [2764] = 2738,
  [2765] = 2737,
  [2766] = 2737,
  [2767] = 2742,
  [2768] = 2743,
  [2769] = 2739,
  [2770] = 2738,
  [2771] = 2477,
  [2772] = 2742,
  [2773] = 2743,
  [2774] = 2742,
  [2775] = 2739,
  [2776] = 2743,
  [2777] = 2739,
  [2778] = 2738,
  [2779] = 2737,
  [2780] = 2742,
  [2781] = 2742,
  [2782] = 2743,
  [2783] = 2743,
  [2784] = 2739,
  [2785] = 2738,
  [2786] = 2739,
  [2787] = 2738,
  [2788] = 2737,
  [2789] = 2743,
  [2790] = 2790,
  [2791] = 2742,
  [2792] = 2743,
  [2793] = 2739,
  [2794] = 2738,
  [2795] = 2738,
  [2796] = 2737,
  [2797] = 2739,
  [2798] = 2742,
  [2799] = 2743,
  [2800] = 2738,
  [2801] = 2739,
  [2802] = 2738,
  [2803] = 2737,
  [2804] = 2737,
  [2805] = 2742,
  [2806] = 2742,
  [2807] = 2743,
  [2808] = 2739,
  [2809] = 2738,
  [2810] = 2743,
  [2811] = 2737,
  [2812] = 2739,
  [2813] = 2738,
  [2814] = 2742,
  [2815] = 2737,
  [2816] = 2742,
  [2817] = 2743,
  [2818] = 2743,
  [2819] = 2739,
  [2820] = 2738,
  [2821] = 2737,
  [2822] = 2738,
  [2823] = 2737,
  [2824] = 2739,
  [2825] = 2742,
  [2826] = 2743,
  [2827] = 2739,
  [2828] = 2738,
  [2829] = 2738,
  [2830] = 2737,
  [2831] = 2737,
  [2832] = 2742,
  [2833] = 2743,
  [2834] = 2737,
  [2835] = 2835,
  [2836] = 2742,
  [2837] = 2742,
  [2838] = 2743,
  [2839] = 2739,
  [2840] = 2743,
  [2841] = 2841,
  [2842] = 2738,
  [2843] = 2739,
  [2844] = 2738,
  [2845] = 2742,
  [2846] = 2739,
  [2847] = 2738,
  [2848] = 2742,
  [2849] = 2737,
  [2850] = 2742,
  [2851] = 2743,
  [2852] = 2743,
  [2853] = 2739,
  [2854] = 2738,
  [2855] = 2737,
  [2856] = 2742,
  [2857] = 2743,
  [2858] = 2739,
  [2859] = 2738,
  [2860] = 2737,
  [2861] = 2742,
  [2862] = 2737,
  [2863] = 2737,
  [2864] = 2739,
  [2865] = 2742,
  [2866] = 2738,
  [2867] = 2739,
  [2868] = 2737,
  [2869] = 2737,
  [2870] = 2743,
  [2871] = 2743,
  [2872] = 2742,
  [2873] = 2742,
  [2874] = 2739,
  [2875] = 2743,
  [2876] = 2738,
  [2877] = 2738,
  [2878] = 2739,
  [2879] = 2738,
  [2880] = 2737,
  [2881] = 2742,
  [2882] = 2743,
  [2883] = 2743,
  [2884] = 2739,
  [2885] = 2738,
  [2886] = 2737,
  [2887] = 2739,
  [2888] = 2742,
  [2889] = 2743,
  [2890] = 2739,
  [2891] = 2738,
  [2892] = 2737,
  [2893] = 2738,
  [2894] = 2742,
  [2895] = 2743,
  [2896] = 2739,
  [2897] = 2738,
  [2898] = 2742,
  [2899] = 2743,
  [2900] = 2737,
  [2901] = 2742,
  [2902] = 2743,
  [2903] = 2739,
  [2904] = 2737,
  [2905] = 2742,
  [2906] = 2738,
  [2907] = 2737,
  [2908] = 2742,
  [2909] = 2743,
  [2910] = 2739,
  [2911] = 2743,
  [2912] = 2738,
  [2913] = 2737,
  [2914] = 2742,
  [2915] = 2743,
  [2916] = 2739,
  [2917] = 2739,
  [2918] = 2738,
  [2919] = 2737,
  [2920] = 2738,
  [2921] = 2737,
  [2922] = 2737,
  [2923] = 2742,
  [2924] = 2743,
  [2925] = 2739,
  [2926] = 2738,
  [2927] = 2742,
  [2928] = 2743,
  [2929] = 2739,
  [2930] = 2738,
  [2931] = 2742,
  [2932] = 2737,
  [2933] = 2742,
  [2934] = 2934,
  [2935] = 2737,
  [2936] = 2737,
  [2937] = 2742,
  [2938] = 2743,
  [2939] = 2743,
  [2940] = 2739,
  [2941] = 2738,
  [2942] = 2742,
  [2943] = 2737,
  [2944] = 2742,
  [2945] = 2743,
  [2946] = 2743,
  [2947] = 2947,
  [2948] = 2948,
  [2949] = 2737,
  [2950] = 2742,
  [2951] = 2743,
  [2952] = 2739,
  [2953] = 2739,
  [2954] = 2738,
  [2955] = 2737,
  [2956] = 2742,
  [2957] = 2743,
  [2958] = 2739,
  [2959] = 2738,
  [2960] = 2738,
  [2961] = 2739,
  [2962] = 2739,
  [2963] = 2739,
  [2964] = 2964,
  [2965] = 2965,
  [2966] = 2477,
  [2967] = 2964,
  [2968] = 2482,
  [2969] = 2969,
  [2970] = 2964,
  [2971] = 2964,
  [2972] = 2964,
  [2973] = 2964,
  [2974] = 2526,
  [2975] = 2975,
  [2976] = 2964,
  [2977] = 2964,
  [2978] = 2477,
  [2979] = 2969,
  [2980] = 2975,
  [2981] = 2590,
  [2982] = 2975,
  [2983] = 2964,
  [2984] = 2969,
  [2985] = 2964,
  [2986] = 2975,
  [2987] = 2964,
  [2988] = 2988,
  [2989] = 2989,
  [2990] = 2988,
  [2991] = 2989,
  [2992] = 2992,
  [2993] = 2993,
  [2994] = 2989,
  [2995] = 2988,
  [2996] = 2996,
  [2997] = 2989,
  [2998] = 2988,
  [2999] = 2999,
  [3000] = 2996,
  [3001] = 2989,
  [3002] = 2988,
  [3003] = 2989,
  [3004] = 2993,
  [3005] = 2996,
  [3006] = 2988,
  [3007] = 2442,
  [3008] = 2993,
  [3009] = 2988,
  [3010] = 2999,
  [3011] = 3011,
  [3012] = 2993,
  [3013] = 2992,
  [3014] = 2999,
  [3015] = 2989,
  [3016] = 3011,
  [3017] = 2988,
  [3018] = 3011,
  [3019] = 2989,
  [3020] = 2993,
  [3021] = 2989,
  [3022] = 3022,
  [3023] = 2988,
  [3024] = 2992,
  [3025] = 2988,
  [3026] = 2482,
  [3027] = 2988,
  [3028] = 2989,
  [3029] = 2996,
  [3030] = 2546,
  [3031] = 2989,
  [3032] = 3011,
  [3033] = 2989,
  [3034] = 2989,
  [3035] = 2988,
  [3036] = 2988,
  [3037] = 2989,
  [3038] = 2988,
  [3039] = 2999,
  [3040] = 3022,
  [3041] = 2996,
  [3042] = 2992,
  [3043] = 2988,
  [3044] = 3011,
  [3045] = 3022,
  [3046] = 2988,
  [3047] = 2988,
  [3048] = 2988,
  [3049] = 2989,
  [3050] = 2989,
  [3051] = 2482,
  [3052] = 2996,
  [3053] = 2989,
  [3054] = 2992,
  [3055] = 2989,
  [3056] = 2988,
  [3057] = 2989,
  [3058] = 2999,
  [3059] = 3022,
  [3060] = 2993,
  [3061] = 2996,
  [3062] = 3062,
  [3063] = 2988,
  [3064] = 3062,
  [3065] = 3062,
  [3066] = 3062,
  [3067] = 2988,
  [3068] = 3062,
  [3069] = 3062,
  [3070] = 2989,
  [3071] = 2999,
  [3072] = 2989,
  [3073] = 2989,
  [3074] = 2988,
  [3075] = 2992,
  [3076] = 3022,
  [3077] = 2988,
  [3078] = 2993,
  [3079] = 2989,
  [3080] = 2543,
  [3081] = 3011,
  [3082] = 2988,
  [3083] = 2988,
  [3084] = 2989,
  [3085] = 2614,
  [3086] = 2988,
  [3087] = 2989,
  [3088] = 3022,
  [3089] = 2993,
  [3090] = 2988,
  [3091] = 3011,
  [3092] = 3011,
  [3093] = 2999,
  [3094] = 2989,
  [3095] = 2989,
  [3096] = 3022,
  [3097] = 2988,
  [3098] = 2988,
  [3099] = 2988,
  [3100] = 2989,
  [3101] = 2992,
  [3102] = 2988,
  [3103] = 2989,
  [3104] = 3022,
  [3105] = 2989,
  [3106] = 2988,
  [3107] = 2992,
  [3108] = 2989,
  [3109] = 2996,
  [3110] = 2999,
  [3111] = 2989,
  [3112] = 3112,
  [3113] = 3113,
  [3114] = 3114,
  [3115] = 3115,
  [3116] = 3116,
  [3117] = 3117,
  [3118] = 3118,
  [3119] = 3119,
  [3120] = 3120,
  [3121] = 3121,
  [3122] = 3122,
  [3123] = 3114,
  [3124] = 3116,
  [3125] = 3117,
  [3126] = 3118,
  [3127] = 3119,
  [3128] = 3120,
  [3129] = 3121,
  [3130] = 3115,
  [3131] = 3131,
  [3132] = 3132,
  [3133] = 3133,
  [3134] = 3134,
  [3135] = 3135,
  [3136] = 3136,
  [3137] = 3137,
  [3138] = 3122,
  [3139] = 3139,
  [3140] = 3140,
  [3141] = 3116,
  [3142] = 3131,
  [3143] = 3117,
  [3144] = 3118,
  [3145] = 3132,
  [3146] = 3133,
  [3147] = 3134,
  [3148] = 3135,
  [3149] = 3136,
  [3150] = 3137,
  [3151] = 3117,
  [3152] = 3121,
  [3153] = 3119,
  [3154] = 3120,
  [3155] = 3121,
  [3156] = 3139,
  [3157] = 3140,
  [3158] = 3158,
  [3159] = 3159,
  [3160] = 2637,
  [3161] = 3112,
  [3162] = 3162,
  [3163] = 3112,
  [3164] = 3159,
  [3165] = 3112,
  [3166] = 3159,
  [3167] = 3112,
  [3168] = 3159,
  [3169] = 3112,
  [3170] = 3159,
  [3171] = 3112,
  [3172] = 3159,
  [3173] = 3112,
  [3174] = 3159,
  [3175] = 3112,
  [3176] = 3159,
  [3177] = 3112,
  [3178] = 3159,
  [3179] = 3112,
  [3180] = 3159,
  [3181] = 3112,
  [3182] = 3159,
  [3183] = 3112,
  [3184] = 3112,
  [3185] = 3112,
  [3186] = 3159,
  [3187] = 3112,
  [3188] = 3159,
  [3189] = 3112,
  [3190] = 3159,
  [3191] = 3112,
  [3192] = 3159,
  [3193] = 3112,
  [3194] = 3159,
  [3195] = 3112,
  [3196] = 3159,
  [3197] = 3112,
  [3198] = 3159,
  [3199] = 3112,
  [3200] = 3159,
  [3201] = 3112,
  [3202] = 3159,
  [3203] = 3112,
  [3204] = 3159,
  [3205] = 3112,
  [3206] = 3159,
  [3207] = 3112,
  [3208] = 3159,
  [3209] = 3112,
  [3210] = 3159,
  [3211] = 3112,
  [3212] = 3159,
  [3213] = 3112,
  [3214] = 3159,
  [3215] = 3112,
  [3216] = 3159,
  [3217] = 3112,
  [3218] = 3159,
  [3219] = 3112,
  [3220] = 3159,
  [3221] = 3112,
  [3222] = 3159,
  [3223] = 3112,
  [3224] = 3159,
  [3225] = 3159,
  [3226] = 3159,
  [3227] = 3112,
  [3228] = 3159,
  [3229] = 3112,
  [3230] = 3159,
  [3231] = 3112,
  [3232] = 3159,
  [3233] = 3112,
  [3234] = 3159,
  [3235] = 3112,
  [3236] = 3159,
  [3237] = 3112,
  [3238] = 3159,
  [3239] = 3112,
  [3240] = 3159,
  [3241] = 3112,
  [3242] = 3159,
  [3243] = 3112,
  [3244] = 3159,
  [3245] = 3112,
  [3246] = 3159,
  [3247] = 3159,
  [3248] = 3248,
  [3249] = 3249,
  [3250] = 3250,
  [3251] = 3251,
  [3252] = 3252,
  [3253] = 3253,
  [3254] = 3254,
  [3255] = 3255,
  [3256] = 3256,
  [3257] = 3132,
  [3258] = 3133,
  [3259] = 3134,
  [3260] = 3260,
  [3261] = 3261,
  [3262] = 3262,
  [3263] = 3263,
  [3264] = 3264,
  [3265] = 3265,
  [3266] = 3266,
  [3267] = 3267,
  [3268] = 3268,
  [3269] = 3269,
  [3270] = 3135,
  [3271] = 3136,
  [3272] = 3272,
  [3273] = 3273,
  [3274] = 3274,
  [3275] = 3275,
  [3276] = 3276,
  [3277] = 3277,
  [3278] = 3278,
  [3279] = 3279,
  [3280] = 3280,
  [3281] = 3281,
  [3282] = 3282,
  [3283] = 3283,
  [3284] = 3284,
  [3285] = 3285,
  [3286] = 3137,
  [3287] = 3287,
  [3288] = 3288,
  [3289] = 3289,
  [3290] = 3290,
  [3291] = 3291,
  [3292] = 3292,
  [3293] = 3293,
  [3294] = 3294,
  [3295] = 3295,
  [3296] = 3296,
  [3297] = 3297,
  [3298] = 3298,
  [3299] = 3299,
  [3300] = 3300,
  [3301] = 3301,
  [3302] = 3302,
  [3303] = 3303,
  [3304] = 3304,
  [3305] = 3305,
  [3306] = 3306,
  [3307] = 3307,
  [3308] = 3308,
  [3309] = 3309,
  [3310] = 3310,
  [3311] = 3311,
  [3312] = 3250,
  [3313] = 3251,
  [3314] = 3252,
  [3315] = 3249,
  [3316] = 3253,
  [3317] = 3254,
  [3318] = 3260,
  [3319] = 3319,
  [3320] = 3261,
  [3321] = 3262,
  [3322] = 3263,
  [3323] = 3264,
  [3324] = 3265,
  [3325] = 3266,
  [3326] = 3267,
  [3327] = 3268,
  [3328] = 3269,
  [3329] = 3272,
  [3330] = 3273,
  [3331] = 3274,
  [3332] = 3275,
  [3333] = 3249,
  [3334] = 3276,
  [3335] = 3277,
  [3336] = 3278,
  [3337] = 3279,
  [3338] = 3280,
  [3339] = 3281,
  [3340] = 3282,
  [3341] = 3283,
  [3342] = 3284,
  [3343] = 3285,
  [3344] = 3249,
  [3345] = 3287,
  [3346] = 3288,
  [3347] = 3114,
  [3348] = 3289,
  [3349] = 3115,
  [3350] = 3290,
  [3351] = 3351,
  [3352] = 3291,
  [3353] = 3292,
  [3354] = 3293,
  [3355] = 3249,
  [3356] = 3294,
  [3357] = 3296,
  [3358] = 3297,
  [3359] = 3298,
  [3360] = 3360,
  [3361] = 3249,
  [3362] = 3362,
  [3363] = 3299,
  [3364] = 3300,
  [3365] = 3249,
  [3366] = 3139,
  [3367] = 3301,
  [3368] = 3249,
  [3369] = 3131,
  [3370] = 3249,
  [3371] = 3302,
  [3372] = 3249,
  [3373] = 3303,
  [3374] = 3374,
  [3375] = 3249,
  [3376] = 3140,
  [3377] = 3377,
  [3378] = 3249,
  [3379] = 3249,
  [3380] = 3131,
  [3381] = 3249,
  [3382] = 3249,
  [3383] = 3132,
  [3384] = 3133,
  [3385] = 3134,
  [3386] = 3249,
  [3387] = 3305,
  [3388] = 3306,
  [3389] = 3307,
  [3390] = 3135,
  [3391] = 3136,
  [3392] = 3392,
  [3393] = 3249,
  [3394] = 3137,
  [3395] = 3308,
  [3396] = 3309,
  [3397] = 3249,
  [3398] = 3310,
  [3399] = 3311,
  [3400] = 3249,
  [3401] = 3249,
  [3402] = 3374,
  [3403] = 3249,
  [3404] = 3131,
  [3405] = 3249,
  [3406] = 3249,
  [3407] = 3249,
  [3408] = 3249,
  [3409] = 3249,
  [3410] = 3377,
  [3411] = 3249,
  [3412] = 3412,
  [3413] = 3132,
  [3414] = 3133,
  [3415] = 3134,
  [3416] = 3249,
  [3417] = 3135,
  [3418] = 3136,
  [3419] = 3249,
  [3420] = 3131,
  [3421] = 3137,
  [3422] = 3249,
  [3423] = 3249,
  [3424] = 3249,
  [3425] = 3139,
  [3426] = 3249,
  [3427] = 3132,
  [3428] = 3133,
  [3429] = 3134,
  [3430] = 3249,
  [3431] = 3135,
  [3432] = 3136,
  [3433] = 3137,
  [3434] = 3249,
  [3435] = 3249,
  [3436] = 3140,
  [3437] = 3249,
  [3438] = 3249,
  [3439] = 3360,
  [3440] = 3362,
  [3441] = 3249,
  [3442] = 3139,
  [3443] = 3249,
  [3444] = 3249,
  [3445] = 3249,
  [3446] = 3248,
  [3447] = 3392,
  [3448] = 3140,
  [3449] = 3249,
  [3450] = 3450,
  [3451] = 3451,
  [3452] = 3452,
  [3453] = 3453,
  [3454] = 3454,
  [3455] = 3455,
  [3456] = 3456,
  [3457] = 3139,
  [3458] = 3458,
  [3459] = 3459,
  [3460] = 3460,
  [3461] = 3412,
  [3462] = 3351,
  [3463] = 3458,
  [3464] = 3460,
  [3465] = 3319,
  [3466] = 3450,
  [3467] = 3140,
  [3468] = 3468,
  [3469] = 3468,
  [3470] = 3470,
  [3471] = 3471,
  [3472] = 3472,
  [3473] = 3470,
  [3474] = 3471,
  [3475] = 3472,
  [3476] = 3451,
  [3477] = 3452,
  [3478] = 3453,
  [3479] = 3454,
  [3480] = 3255,
  [3481] = 3256,
  [3482] = 3455,
  [3483] = 3295,
  [3484] = 3114,
  [3485] = 3114,
  [3486] = 3115,
  [3487] = 3115,
  [3488] = 3114,
  [3489] = 3115,
  [3490] = 3456,
  [3491] = 3459,
  [3492] = 3304,
  [3493] = 3289,
  [3494] = 3310,
  [3495] = 3311,
  [3496] = 3288,
  [3497] = 3289,
  [3498] = 3470,
  [3499] = 3290,
  [3500] = 3472,
  [3501] = 3140,
  [3502] = 3272,
  [3503] = 3291,
  [3504] = 3273,
  [3505] = 3292,
  [3506] = 3293,
  [3507] = 3294,
  [3508] = 3296,
  [3509] = 3274,
  [3510] = 3468,
  [3511] = 3470,
  [3512] = 3298,
  [3513] = 3275,
  [3514] = 3460,
  [3515] = 3290,
  [3516] = 3296,
  [3517] = 3256,
  [3518] = 3115,
  [3519] = 3295,
  [3520] = 3471,
  [3521] = 3458,
  [3522] = 3250,
  [3523] = 3297,
  [3524] = 3351,
  [3525] = 3251,
  [3526] = 3252,
  [3527] = 3253,
  [3528] = 3254,
  [3529] = 3260,
  [3530] = 3281,
  [3531] = 3261,
  [3532] = 3282,
  [3533] = 3262,
  [3534] = 3263,
  [3535] = 3264,
  [3536] = 3265,
  [3537] = 3266,
  [3538] = 3267,
  [3539] = 3472,
  [3540] = 3292,
  [3541] = 3268,
  [3542] = 3269,
  [3543] = 3256,
  [3544] = 3468,
  [3545] = 3272,
  [3546] = 3298,
  [3547] = 3273,
  [3548] = 3274,
  [3549] = 3275,
  [3550] = 3293,
  [3551] = 3276,
  [3552] = 3277,
  [3553] = 3294,
  [3554] = 3362,
  [3555] = 3278,
  [3556] = 3460,
  [3557] = 3250,
  [3558] = 3279,
  [3559] = 3280,
  [3560] = 3251,
  [3561] = 3252,
  [3562] = 3300,
  [3563] = 3281,
  [3564] = 3255,
  [3565] = 3253,
  [3566] = 3254,
  [3567] = 3260,
  [3568] = 3282,
  [3569] = 3283,
  [3570] = 3284,
  [3571] = 3456,
  [3572] = 3285,
  [3573] = 3287,
  [3574] = 3351,
  [3575] = 3288,
  [3576] = 3276,
  [3577] = 3290,
  [3578] = 3283,
  [3579] = 3454,
  [3580] = 3277,
  [3581] = 3291,
  [3582] = 3292,
  [3583] = 3293,
  [3584] = 3299,
  [3585] = 3294,
  [3586] = 3468,
  [3587] = 3262,
  [3588] = 3263,
  [3589] = 3470,
  [3590] = 3256,
  [3591] = 3264,
  [3592] = 3265,
  [3593] = 3266,
  [3594] = 3267,
  [3595] = 3455,
  [3596] = 3268,
  [3597] = 3269,
  [3598] = 3115,
  [3599] = 3450,
  [3600] = 3296,
  [3601] = 3272,
  [3602] = 3273,
  [3603] = 3274,
  [3604] = 3275,
  [3605] = 3276,
  [3606] = 3297,
  [3607] = 3255,
  [3608] = 3277,
  [3609] = 3299,
  [3610] = 3303,
  [3611] = 3278,
  [3612] = 3279,
  [3613] = 3280,
  [3614] = 3300,
  [3615] = 3456,
  [3616] = 3281,
  [3617] = 3282,
  [3618] = 3283,
  [3619] = 3284,
  [3620] = 3285,
  [3621] = 3287,
  [3622] = 3471,
  [3623] = 3472,
  [3624] = 3288,
  [3625] = 3289,
  [3626] = 3459,
  [3627] = 3284,
  [3628] = 3459,
  [3629] = 3291,
  [3630] = 3292,
  [3631] = 3301,
  [3632] = 3250,
  [3633] = 3293,
  [3634] = 3294,
  [3635] = 3251,
  [3636] = 3285,
  [3637] = 3252,
  [3638] = 3296,
  [3639] = 3451,
  [3640] = 3297,
  [3641] = 3298,
  [3642] = 3302,
  [3643] = 3297,
  [3644] = 3303,
  [3645] = 3253,
  [3646] = 3254,
  [3647] = 3260,
  [3648] = 3261,
  [3649] = 3304,
  [3650] = 3305,
  [3651] = 3306,
  [3652] = 3307,
  [3653] = 3255,
  [3654] = 3308,
  [3655] = 3309,
  [3656] = 3310,
  [3657] = 3311,
  [3658] = 3295,
  [3659] = 3256,
  [3660] = 3299,
  [3661] = 3300,
  [3662] = 3261,
  [3663] = 3360,
  [3664] = 3374,
  [3665] = 3295,
  [3666] = 3287,
  [3667] = 3301,
  [3668] = 3262,
  [3669] = 3377,
  [3670] = 3298,
  [3671] = 3248,
  [3672] = 3263,
  [3673] = 3302,
  [3674] = 3261,
  [3675] = 3303,
  [3676] = 3264,
  [3677] = 3269,
  [3678] = 3288,
  [3679] = 3374,
  [3680] = 3304,
  [3681] = 3377,
  [3682] = 3265,
  [3683] = 3305,
  [3684] = 3248,
  [3685] = 3306,
  [3686] = 3290,
  [3687] = 3392,
  [3688] = 3307,
  [3689] = 3374,
  [3690] = 3377,
  [3691] = 3308,
  [3692] = 3248,
  [3693] = 3392,
  [3694] = 3360,
  [3695] = 3295,
  [3696] = 3309,
  [3697] = 3131,
  [3698] = 3310,
  [3699] = 3452,
  [3700] = 3299,
  [3701] = 3132,
  [3702] = 3133,
  [3703] = 3311,
  [3704] = 3360,
  [3705] = 3134,
  [3706] = 3362,
  [3707] = 3360,
  [3708] = 3135,
  [3709] = 3362,
  [3710] = 3266,
  [3711] = 3289,
  [3712] = 3301,
  [3713] = 3136,
  [3714] = 3267,
  [3715] = 3255,
  [3716] = 3137,
  [3717] = 3268,
  [3718] = 3269,
  [3719] = 3114,
  [3720] = 3278,
  [3721] = 3458,
  [3722] = 3272,
  [3723] = 3301,
  [3724] = 3273,
  [3725] = 3274,
  [3726] = 3455,
  [3727] = 3275,
  [3728] = 3450,
  [3729] = 3453,
  [3730] = 3302,
  [3731] = 3276,
  [3732] = 3279,
  [3733] = 3280,
  [3734] = 3302,
  [3735] = 3277,
  [3736] = 3451,
  [3737] = 3304,
  [3738] = 3291,
  [3739] = 3452,
  [3740] = 3305,
  [3741] = 3306,
  [3742] = 3450,
  [3743] = 3307,
  [3744] = 3308,
  [3745] = 3278,
  [3746] = 3309,
  [3747] = 3310,
  [3748] = 3279,
  [3749] = 3311,
  [3750] = 3280,
  [3751] = 3470,
  [3752] = 3281,
  [3753] = 3451,
  [3754] = 3471,
  [3755] = 3453,
  [3756] = 3454,
  [3757] = 3250,
  [3758] = 3412,
  [3759] = 3454,
  [3760] = 3282,
  [3761] = 3114,
  [3762] = 3283,
  [3763] = 3304,
  [3764] = 3458,
  [3765] = 3139,
  [3766] = 3284,
  [3767] = 3285,
  [3768] = 3131,
  [3769] = 3362,
  [3770] = 3412,
  [3771] = 3450,
  [3772] = 3471,
  [3773] = 3412,
  [3774] = 3451,
  [3775] = 3140,
  [3776] = 3452,
  [3777] = 3453,
  [3778] = 3251,
  [3779] = 3252,
  [3780] = 3253,
  [3781] = 3254,
  [3782] = 3260,
  [3783] = 3132,
  [3784] = 3133,
  [3785] = 3134,
  [3786] = 3454,
  [3787] = 3135,
  [3788] = 3452,
  [3789] = 3136,
  [3790] = 3287,
  [3791] = 3137,
  [3792] = 3460,
  [3793] = 3472,
  [3794] = 3305,
  [3795] = 3455,
  [3796] = 3456,
  [3797] = 3374,
  [3798] = 3459,
  [3799] = 3377,
  [3800] = 3248,
  [3801] = 3392,
  [3802] = 3456,
  [3803] = 3306,
  [3804] = 3459,
  [3805] = 3307,
  [3806] = 3412,
  [3807] = 3300,
  [3808] = 3455,
  [3809] = 3351,
  [3810] = 3351,
  [3811] = 3458,
  [3812] = 3460,
  [3813] = 3453,
  [3814] = 3139,
  [3815] = 3262,
  [3816] = 3308,
  [3817] = 3263,
  [3818] = 3264,
  [3819] = 3468,
  [3820] = 3265,
  [3821] = 3303,
  [3822] = 3266,
  [3823] = 3267,
  [3824] = 3309,
  [3825] = 3268,
  [3826] = 3392,
  [3827] = 3294,
  [3828] = 3451,
  [3829] = 3829,
  [3830] = 3830,
  [3831] = 3453,
  [3832] = 3454,
  [3833] = 3833,
  [3834] = 3456,
  [3835] = 3835,
  [3836] = 3459,
  [3837] = 3412,
  [3838] = 3351,
  [3839] = 3458,
  [3840] = 3460,
  [3841] = 3468,
  [3842] = 3470,
  [3843] = 3471,
  [3844] = 3829,
  [3845] = 3830,
  [3846] = 3472,
  [3847] = 3833,
  [3848] = 3835,
  [3849] = 3830,
  [3850] = 3833,
  [3851] = 3255,
  [3852] = 3455,
  [3853] = 3256,
  [3854] = 3456,
  [3855] = 3459,
  [3856] = 3412,
  [3857] = 3351,
  [3858] = 3830,
  [3859] = 3458,
  [3860] = 3460,
  [3861] = 3833,
  [3862] = 3295,
  [3863] = 3468,
  [3864] = 3470,
  [3865] = 3471,
  [3866] = 3472,
  [3867] = 3362,
  [3868] = 3255,
  [3869] = 3256,
  [3870] = 3830,
  [3871] = 3295,
  [3872] = 3833,
  [3873] = 3299,
  [3874] = 3300,
  [3875] = 3830,
  [3876] = 3833,
  [3877] = 3301,
  [3878] = 3830,
  [3879] = 3833,
  [3880] = 3302,
  [3881] = 3303,
  [3882] = 3250,
  [3883] = 3251,
  [3884] = 3252,
  [3885] = 3304,
  [3886] = 3830,
  [3887] = 3253,
  [3888] = 3254,
  [3889] = 3260,
  [3890] = 3833,
  [3891] = 3830,
  [3892] = 3262,
  [3893] = 3263,
  [3894] = 3833,
  [3895] = 3305,
  [3896] = 3830,
  [3897] = 3306,
  [3898] = 3307,
  [3899] = 3264,
  [3900] = 3833,
  [3901] = 3265,
  [3902] = 3830,
  [3903] = 3833,
  [3904] = 3830,
  [3905] = 3833,
  [3906] = 3830,
  [3907] = 3374,
  [3908] = 3377,
  [3909] = 3833,
  [3910] = 3248,
  [3911] = 3392,
  [3912] = 3830,
  [3913] = 3374,
  [3914] = 3377,
  [3915] = 3248,
  [3916] = 3833,
  [3917] = 3392,
  [3918] = 3830,
  [3919] = 3266,
  [3920] = 3267,
  [3921] = 3308,
  [3922] = 3833,
  [3923] = 3309,
  [3924] = 3310,
  [3925] = 3830,
  [3926] = 3311,
  [3927] = 3833,
  [3928] = 3830,
  [3929] = 3268,
  [3930] = 3833,
  [3931] = 3830,
  [3932] = 3269,
  [3933] = 3833,
  [3934] = 3830,
  [3935] = 3829,
  [3936] = 3936,
  [3937] = 3272,
  [3938] = 3833,
  [3939] = 3830,
  [3940] = 3830,
  [3941] = 3941,
  [3942] = 3833,
  [3943] = 3830,
  [3944] = 3944,
  [3945] = 3833,
  [3946] = 3830,
  [3947] = 3833,
  [3948] = 3360,
  [3949] = 3362,
  [3950] = 3830,
  [3951] = 3833,
  [3952] = 3833,
  [3953] = 3273,
  [3954] = 3830,
  [3955] = 3835,
  [3956] = 3833,
  [3957] = 3833,
  [3958] = 3274,
  [3959] = 3830,
  [3960] = 3833,
  [3961] = 3275,
  [3962] = 3941,
  [3963] = 3830,
  [3964] = 3944,
  [3965] = 3965,
  [3966] = 3941,
  [3967] = 3833,
  [3968] = 3276,
  [3969] = 3944,
  [3970] = 3830,
  [3971] = 3833,
  [3972] = 3277,
  [3973] = 3278,
  [3974] = 3279,
  [3975] = 3830,
  [3976] = 3280,
  [3977] = 3833,
  [3978] = 3281,
  [3979] = 3282,
  [3980] = 3830,
  [3981] = 3833,
  [3982] = 3830,
  [3983] = 3283,
  [3984] = 3833,
  [3985] = 3284,
  [3986] = 3285,
  [3987] = 3830,
  [3988] = 3287,
  [3989] = 3360,
  [3990] = 3833,
  [3991] = 3288,
  [3992] = 3114,
  [3993] = 3830,
  [3994] = 3115,
  [3995] = 3289,
  [3996] = 3833,
  [3997] = 3830,
  [3998] = 3833,
  [3999] = 3291,
  [4000] = 3292,
  [4001] = 3830,
  [4002] = 3293,
  [4003] = 3294,
  [4004] = 3830,
  [4005] = 3833,
  [4006] = 3296,
  [4007] = 3830,
  [4008] = 3833,
  [4009] = 3830,
  [4010] = 3297,
  [4011] = 3833,
  [4012] = 3830,
  [4013] = 3298,
  [4014] = 3250,
  [4015] = 3251,
  [4016] = 3835,
  [4017] = 3252,
  [4018] = 3253,
  [4019] = 3254,
  [4020] = 3835,
  [4021] = 3835,
  [4022] = 3829,
  [4023] = 3936,
  [4024] = 3260,
  [4025] = 3261,
  [4026] = 3830,
  [4027] = 3262,
  [4028] = 3263,
  [4029] = 3264,
  [4030] = 3265,
  [4031] = 3833,
  [4032] = 3835,
  [4033] = 3266,
  [4034] = 3267,
  [4035] = 3941,
  [4036] = 3944,
  [4037] = 3268,
  [4038] = 3269,
  [4039] = 3272,
  [4040] = 3273,
  [4041] = 3274,
  [4042] = 3275,
  [4043] = 3276,
  [4044] = 3277,
  [4045] = 3278,
  [4046] = 3279,
  [4047] = 3280,
  [4048] = 3281,
  [4049] = 3282,
  [4050] = 3283,
  [4051] = 3131,
  [4052] = 3284,
  [4053] = 3285,
  [4054] = 3287,
  [4055] = 3288,
  [4056] = 3289,
  [4057] = 3290,
  [4058] = 3291,
  [4059] = 3829,
  [4060] = 3292,
  [4061] = 3293,
  [4062] = 3132,
  [4063] = 3133,
  [4064] = 3134,
  [4065] = 3296,
  [4066] = 3135,
  [4067] = 3136,
  [4068] = 3137,
  [4069] = 3829,
  [4070] = 3114,
  [4071] = 3936,
  [4072] = 3115,
  [4073] = 3830,
  [4074] = 3297,
  [4075] = 3299,
  [4076] = 3300,
  [4077] = 3833,
  [4078] = 3261,
  [4079] = 3835,
  [4080] = 3139,
  [4081] = 3301,
  [4082] = 3140,
  [4083] = 3298,
  [4084] = 3450,
  [4085] = 3302,
  [4086] = 3303,
  [4087] = 3304,
  [4088] = 3290,
  [4089] = 3305,
  [4090] = 3306,
  [4091] = 3307,
  [4092] = 3308,
  [4093] = 3309,
  [4094] = 3310,
  [4095] = 3311,
  [4096] = 3829,
  [4097] = 3936,
  [4098] = 3830,
  [4099] = 3833,
  [4100] = 3451,
  [4101] = 3835,
  [4102] = 3936,
  [4103] = 3131,
  [4104] = 3452,
  [4105] = 3941,
  [4106] = 3944,
  [4107] = 3453,
  [4108] = 3454,
  [4109] = 3132,
  [4110] = 3133,
  [4111] = 3134,
  [4112] = 3135,
  [4113] = 3136,
  [4114] = 3137,
  [4115] = 3965,
  [4116] = 3829,
  [4117] = 3830,
  [4118] = 3833,
  [4119] = 3835,
  [4120] = 3139,
  [4121] = 3140,
  [4122] = 3455,
  [4123] = 3450,
  [4124] = 3452,
  [4125] = 3304,
  [4126] = 4126,
  [4127] = 4126,
  [4128] = 3139,
  [4129] = 4129,
  [4130] = 3965,
  [4131] = 3131,
  [4132] = 3255,
  [4133] = 3131,
  [4134] = 3351,
  [4135] = 4135,
  [4136] = 3136,
  [4137] = 4137,
  [4138] = 4138,
  [4139] = 4139,
  [4140] = 3458,
  [4141] = 4126,
  [4142] = 3460,
  [4143] = 4126,
  [4144] = 4126,
  [4145] = 3114,
  [4146] = 4146,
  [4147] = 4129,
  [4148] = 3450,
  [4149] = 4126,
  [4150] = 4150,
  [4151] = 4151,
  [4152] = 4126,
  [4153] = 3303,
  [4154] = 3965,
  [4155] = 3374,
  [4156] = 4150,
  [4157] = 4151,
  [4158] = 4137,
  [4159] = 4126,
  [4160] = 4126,
  [4161] = 4161,
  [4162] = 3256,
  [4163] = 3250,
  [4164] = 4164,
  [4165] = 4165,
  [4166] = 4166,
  [4167] = 4126,
  [4168] = 3251,
  [4169] = 3295,
  [4170] = 3252,
  [4171] = 3253,
  [4172] = 3254,
  [4173] = 3260,
  [4174] = 3137,
  [4175] = 3965,
  [4176] = 4126,
  [4177] = 4126,
  [4178] = 4164,
  [4179] = 4165,
  [4180] = 3140,
  [4181] = 3377,
  [4182] = 3248,
  [4183] = 3450,
  [4184] = 3468,
  [4185] = 4126,
  [4186] = 4126,
  [4187] = 4138,
  [4188] = 4139,
  [4189] = 3262,
  [4190] = 3263,
  [4191] = 3264,
  [4192] = 3308,
  [4193] = 3470,
  [4194] = 4126,
  [4195] = 3265,
  [4196] = 3266,
  [4197] = 3267,
  [4198] = 3451,
  [4199] = 3268,
  [4200] = 3452,
  [4201] = 3453,
  [4202] = 3392,
  [4203] = 3269,
  [4204] = 4126,
  [4205] = 3471,
  [4206] = 3272,
  [4207] = 3273,
  [4208] = 3274,
  [4209] = 3275,
  [4210] = 3276,
  [4211] = 3114,
  [4212] = 3454,
  [4213] = 3305,
  [4214] = 3472,
  [4215] = 4126,
  [4216] = 3451,
  [4217] = 3360,
  [4218] = 3277,
  [4219] = 4126,
  [4220] = 3278,
  [4221] = 3279,
  [4222] = 3280,
  [4223] = 3140,
  [4224] = 3281,
  [4225] = 3282,
  [4226] = 3283,
  [4227] = 3284,
  [4228] = 3285,
  [4229] = 3287,
  [4230] = 3288,
  [4231] = 3289,
  [4232] = 4126,
  [4233] = 4150,
  [4234] = 3309,
  [4235] = 3291,
  [4236] = 3292,
  [4237] = 3293,
  [4238] = 4135,
  [4239] = 3294,
  [4240] = 3452,
  [4241] = 4151,
  [4242] = 4126,
  [4243] = 4161,
  [4244] = 4126,
  [4245] = 3296,
  [4246] = 3453,
  [4247] = 4137,
  [4248] = 3454,
  [4249] = 4138,
  [4250] = 4139,
  [4251] = 3362,
  [4252] = 3115,
  [4253] = 4126,
  [4254] = 4126,
  [4255] = 4126,
  [4256] = 3456,
  [4257] = 3297,
  [4258] = 3261,
  [4259] = 4146,
  [4260] = 4129,
  [4261] = 3310,
  [4262] = 3311,
  [4263] = 4126,
  [4264] = 3298,
  [4265] = 3300,
  [4266] = 3290,
  [4267] = 4164,
  [4268] = 4126,
  [4269] = 3299,
  [4270] = 4150,
  [4271] = 4151,
  [4272] = 3132,
  [4273] = 3133,
  [4274] = 4165,
  [4275] = 3134,
  [4276] = 3295,
  [4277] = 4164,
  [4278] = 4165,
  [4279] = 3255,
  [4280] = 3115,
  [4281] = 3301,
  [4282] = 3302,
  [4283] = 4126,
  [4284] = 4138,
  [4285] = 3412,
  [4286] = 3306,
  [4287] = 3307,
  [4288] = 3308,
  [4289] = 3309,
  [4290] = 3310,
  [4291] = 3311,
  [4292] = 4126,
  [4293] = 4135,
  [4294] = 4126,
  [4295] = 3306,
  [4296] = 4126,
  [4297] = 4135,
  [4298] = 3307,
  [4299] = 4126,
  [4300] = 4137,
  [4301] = 3135,
  [4302] = 3136,
  [4303] = 3256,
  [4304] = 3137,
  [4305] = 4126,
  [4306] = 4126,
  [4307] = 4129,
  [4308] = 4138,
  [4309] = 4139,
  [4310] = 3459,
  [4311] = 4164,
  [4312] = 4135,
  [4313] = 4137,
  [4314] = 4138,
  [4315] = 4139,
  [4316] = 3135,
  [4317] = 4139,
  [4318] = 4126,
  [4319] = 4150,
  [4320] = 4146,
  [4321] = 4129,
  [4322] = 3455,
  [4323] = 3250,
  [4324] = 4126,
  [4325] = 4166,
  [4326] = 3251,
  [4327] = 3252,
  [4328] = 3300,
  [4329] = 3253,
  [4330] = 3254,
  [4331] = 3260,
  [4332] = 3455,
  [4333] = 4150,
  [4334] = 4165,
  [4335] = 4151,
  [4336] = 4151,
  [4337] = 4164,
  [4338] = 4165,
  [4339] = 4126,
  [4340] = 3262,
  [4341] = 3263,
  [4342] = 3264,
  [4343] = 3265,
  [4344] = 3266,
  [4345] = 3267,
  [4346] = 3965,
  [4347] = 3374,
  [4348] = 3268,
  [4349] = 3269,
  [4350] = 3272,
  [4351] = 4126,
  [4352] = 3273,
  [4353] = 3274,
  [4354] = 3275,
  [4355] = 3276,
  [4356] = 4126,
  [4357] = 3456,
  [4358] = 3459,
  [4359] = 3277,
  [4360] = 3303,
  [4361] = 3278,
  [4362] = 4126,
  [4363] = 3279,
  [4364] = 3280,
  [4365] = 3281,
  [4366] = 3282,
  [4367] = 3283,
  [4368] = 3284,
  [4369] = 3285,
  [4370] = 3287,
  [4371] = 3288,
  [4372] = 3289,
  [4373] = 3412,
  [4374] = 4126,
  [4375] = 4146,
  [4376] = 3291,
  [4377] = 3292,
  [4378] = 3293,
  [4379] = 3294,
  [4380] = 3351,
  [4381] = 3377,
  [4382] = 3458,
  [4383] = 3296,
  [4384] = 3362,
  [4385] = 3297,
  [4386] = 4126,
  [4387] = 4138,
  [4388] = 4139,
  [4389] = 3460,
  [4390] = 4126,
  [4391] = 3298,
  [4392] = 4126,
  [4393] = 3248,
  [4394] = 4150,
  [4395] = 4151,
  [4396] = 3468,
  [4397] = 3261,
  [4398] = 4164,
  [4399] = 4165,
  [4400] = 3139,
  [4401] = 3470,
  [4402] = 3132,
  [4403] = 3133,
  [4404] = 3471,
  [4405] = 3134,
  [4406] = 3290,
  [4407] = 4146,
  [4408] = 3472,
  [4409] = 3360,
  [4410] = 3299,
  [4411] = 3301,
  [4412] = 3302,
  [4413] = 3392,
  [4414] = 3304,
  [4415] = 3305,
  [4416] = 3265,
  [4417] = 4417,
  [4418] = 3301,
  [4419] = 3452,
  [4420] = 4420,
  [4421] = 3351,
  [4422] = 3265,
  [4423] = 4417,
  [4424] = 4424,
  [4425] = 4420,
  [4426] = 4417,
  [4427] = 4427,
  [4428] = 4424,
  [4429] = 4429,
  [4430] = 4420,
  [4431] = 4424,
  [4432] = 4420,
  [4433] = 4417,
  [4434] = 4417,
  [4435] = 4435,
  [4436] = 3460,
  [4437] = 3251,
  [4438] = 3299,
  [4439] = 3252,
  [4440] = 4440,
  [4441] = 4441,
  [4442] = 3300,
  [4443] = 3453,
  [4444] = 3454,
  [4445] = 3294,
  [4446] = 3297,
  [4447] = 4424,
  [4448] = 3458,
  [4449] = 3253,
  [4450] = 3254,
  [4451] = 3255,
  [4452] = 3260,
  [4453] = 3455,
  [4454] = 3255,
  [4455] = 3260,
  [4456] = 4417,
  [4457] = 4424,
  [4458] = 3261,
  [4459] = 4420,
  [4460] = 3965,
  [4461] = 4417,
  [4462] = 4420,
  [4463] = 3455,
  [4464] = 4420,
  [4465] = 4417,
  [4466] = 4417,
  [4467] = 3450,
  [4468] = 3295,
  [4469] = 3374,
  [4470] = 4166,
  [4471] = 3250,
  [4472] = 3459,
  [4473] = 4417,
  [4474] = 4474,
  [4475] = 4424,
  [4476] = 4474,
  [4477] = 3262,
  [4478] = 3263,
  [4479] = 3264,
  [4480] = 3468,
  [4481] = 3301,
  [4482] = 3261,
  [4483] = 3266,
  [4484] = 3267,
  [4485] = 3470,
  [4486] = 3256,
  [4487] = 3268,
  [4488] = 3269,
  [4489] = 3471,
  [4490] = 3272,
  [4491] = 3298,
  [4492] = 3472,
  [4493] = 4424,
  [4494] = 4161,
  [4495] = 3377,
  [4496] = 4420,
  [4497] = 3248,
  [4498] = 4417,
  [4499] = 4420,
  [4500] = 4500,
  [4501] = 3360,
  [4502] = 4424,
  [4503] = 4420,
  [4504] = 3460,
  [4505] = 4166,
  [4506] = 4506,
  [4507] = 4417,
  [4508] = 4508,
  [4509] = 4435,
  [4510] = 4500,
  [4511] = 3307,
  [4512] = 4427,
  [4513] = 4166,
  [4514] = 4417,
  [4515] = 3273,
  [4516] = 3274,
  [4517] = 3251,
  [4518] = 3275,
  [4519] = 4420,
  [4520] = 3276,
  [4521] = 4424,
  [4522] = 4424,
  [4523] = 4161,
  [4524] = 4420,
  [4525] = 4417,
  [4526] = 3252,
  [4527] = 3965,
  [4528] = 3296,
  [4529] = 4420,
  [4530] = 3308,
  [4531] = 4440,
  [4532] = 3306,
  [4533] = 4441,
  [4534] = 4474,
  [4535] = 3305,
  [4536] = 3456,
  [4537] = 4424,
  [4538] = 3273,
  [4539] = 4424,
  [4540] = 3274,
  [4541] = 3275,
  [4542] = 3276,
  [4543] = 3302,
  [4544] = 4420,
  [4545] = 3277,
  [4546] = 4424,
  [4547] = 4420,
  [4548] = 4417,
  [4549] = 4420,
  [4550] = 3303,
  [4551] = 4417,
  [4552] = 3278,
  [4553] = 3266,
  [4554] = 3267,
  [4555] = 4417,
  [4556] = 4417,
  [4557] = 4420,
  [4558] = 3470,
  [4559] = 3302,
  [4560] = 3256,
  [4561] = 3279,
  [4562] = 3392,
  [4563] = 4424,
  [4564] = 3280,
  [4565] = 3277,
  [4566] = 4424,
  [4567] = 4420,
  [4568] = 4417,
  [4569] = 3392,
  [4570] = 4427,
  [4571] = 4424,
  [4572] = 4420,
  [4573] = 4417,
  [4574] = 4506,
  [4575] = 4508,
  [4576] = 4435,
  [4577] = 4500,
  [4578] = 4424,
  [4579] = 3281,
  [4580] = 4420,
  [4581] = 4417,
  [4582] = 4420,
  [4583] = 4417,
  [4584] = 3282,
  [4585] = 4506,
  [4586] = 3283,
  [4587] = 4427,
  [4588] = 4474,
  [4589] = 4424,
  [4590] = 4420,
  [4591] = 4417,
  [4592] = 4417,
  [4593] = 4508,
  [4594] = 4424,
  [4595] = 4420,
  [4596] = 4417,
  [4597] = 3268,
  [4598] = 3309,
  [4599] = 3310,
  [4600] = 3284,
  [4601] = 4435,
  [4602] = 4602,
  [4603] = 3285,
  [4604] = 4161,
  [4605] = 3287,
  [4606] = 4506,
  [4607] = 4424,
  [4608] = 4508,
  [4609] = 4435,
  [4610] = 4500,
  [4611] = 4427,
  [4612] = 3288,
  [4613] = 4440,
  [4614] = 3303,
  [4615] = 3278,
  [4616] = 3279,
  [4617] = 3289,
  [4618] = 4441,
  [4619] = 3300,
  [4620] = 4508,
  [4621] = 4424,
  [4622] = 3290,
  [4623] = 4500,
  [4624] = 4424,
  [4625] = 4424,
  [4626] = 4420,
  [4627] = 4417,
  [4628] = 3269,
  [4629] = 4427,
  [4630] = 4420,
  [4631] = 3262,
  [4632] = 3291,
  [4633] = 3253,
  [4634] = 4420,
  [4635] = 3311,
  [4636] = 3451,
  [4637] = 4417,
  [4638] = 3280,
  [4639] = 3263,
  [4640] = 3471,
  [4641] = 3254,
  [4642] = 3264,
  [4643] = 3272,
  [4644] = 4506,
  [4645] = 4424,
  [4646] = 3412,
  [4647] = 4424,
  [4648] = 4420,
  [4649] = 4417,
  [4650] = 4420,
  [4651] = 4420,
  [4652] = 4417,
  [4653] = 3292,
  [4654] = 3293,
  [4655] = 3294,
  [4656] = 3298,
  [4657] = 3468,
  [4658] = 4424,
  [4659] = 3305,
  [4660] = 3306,
  [4661] = 3307,
  [4662] = 3362,
  [4663] = 3452,
  [4664] = 4508,
  [4665] = 3472,
  [4666] = 4602,
  [4667] = 3296,
  [4668] = 3308,
  [4669] = 3292,
  [4670] = 3309,
  [4671] = 3310,
  [4672] = 3453,
  [4673] = 4673,
  [4674] = 3311,
  [4675] = 4424,
  [4676] = 3454,
  [4677] = 4420,
  [4678] = 4417,
  [4679] = 4417,
  [4680] = 3456,
  [4681] = 4424,
  [4682] = 4420,
  [4683] = 3360,
  [4684] = 4506,
  [4685] = 4417,
  [4686] = 4508,
  [4687] = 4435,
  [4688] = 4500,
  [4689] = 4420,
  [4690] = 4427,
  [4691] = 3362,
  [4692] = 4440,
  [4693] = 4441,
  [4694] = 4474,
  [4695] = 3250,
  [4696] = 3459,
  [4697] = 4424,
  [4698] = 4420,
  [4699] = 4166,
  [4700] = 4417,
  [4701] = 4420,
  [4702] = 3293,
  [4703] = 4420,
  [4704] = 4420,
  [4705] = 4424,
  [4706] = 4435,
  [4707] = 3281,
  [4708] = 4500,
  [4709] = 3282,
  [4710] = 4417,
  [4711] = 4424,
  [4712] = 4420,
  [4713] = 4420,
  [4714] = 4417,
  [4715] = 4417,
  [4716] = 4424,
  [4717] = 4420,
  [4718] = 4417,
  [4719] = 3283,
  [4720] = 3284,
  [4721] = 4440,
  [4722] = 4441,
  [4723] = 4474,
  [4724] = 4420,
  [4725] = 4417,
  [4726] = 4424,
  [4727] = 4420,
  [4728] = 4417,
  [4729] = 4417,
  [4730] = 4424,
  [4731] = 3412,
  [4732] = 4424,
  [4733] = 4161,
  [4734] = 4420,
  [4735] = 3351,
  [4736] = 3299,
  [4737] = 3297,
  [4738] = 3285,
  [4739] = 3287,
  [4740] = 4417,
  [4741] = 3304,
  [4742] = 4417,
  [4743] = 3458,
  [4744] = 4424,
  [4745] = 4506,
  [4746] = 4508,
  [4747] = 4435,
  [4748] = 4500,
  [4749] = 4427,
  [4750] = 3450,
  [4751] = 3295,
  [4752] = 3451,
  [4753] = 3374,
  [4754] = 4424,
  [4755] = 4420,
  [4756] = 4417,
  [4757] = 4424,
  [4758] = 3288,
  [4759] = 3289,
  [4760] = 3290,
  [4761] = 4420,
  [4762] = 4417,
  [4763] = 3291,
  [4764] = 4506,
  [4765] = 3377,
  [4766] = 3248,
  [4767] = 3304,
  [4768] = 4161,
  [4769] = 4161,
  [4770] = 4166,
  [4771] = 3965,
  [4772] = 3965,
  [4773] = 4166,
  [4774] = 4166,
  [4775] = 3965,
  [4776] = 4166,
  [4777] = 4161,
  [4778] = 3965,
  [4779] = 4161,
  [4780] = 4161,
  [4781] = 4161,
  [4782] = 4782,
  [4783] = 4166,
  [4784] = 2637,
  [4785] = 4785,
  [4786] = 4166,
  [4787] = 4782,
  [4788] = 4788,
  [4789] = 4789,
  [4790] = 4782,
  [4791] = 4782,
  [4792] = 4782,
  [4793] = 4793,
  [4794] = 4794,
  [4795] = 4794,
  [4796] = 4794,
  [4797] = 4794,
  [4798] = 4793,
  [4799] = 4793,
  [4800] = 4794,
  [4801] = 4794,
  [4802] = 4794,
  [4803] = 3139,
  [4804] = 4793,
  [4805] = 4794,
  [4806] = 4794,
  [4807] = 4794,
  [4808] = 4793,
  [4809] = 4793,
  [4810] = 3137,
  [4811] = 3115,
  [4812] = 4794,
  [4813] = 4794,
  [4814] = 4794,
  [4815] = 4793,
  [4816] = 4793,
  [4817] = 4793,
  [4818] = 4794,
  [4819] = 4794,
  [4820] = 4794,
  [4821] = 4793,
  [4822] = 4794,
  [4823] = 4793,
  [4824] = 4793,
  [4825] = 4794,
  [4826] = 4794,
  [4827] = 4793,
  [4828] = 4793,
  [4829] = 4793,
  [4830] = 3140,
  [4831] = 4793,
  [4832] = 4794,
  [4833] = 4794,
  [4834] = 3135,
  [4835] = 4793,
  [4836] = 4794,
  [4837] = 4793,
  [4838] = 4793,
  [4839] = 4794,
  [4840] = 4794,
  [4841] = 3114,
  [4842] = 4793,
  [4843] = 4794,
  [4844] = 4794,
  [4845] = 4793,
  [4846] = 4793,
  [4847] = 4794,
  [4848] = 4794,
  [4849] = 4793,
  [4850] = 4793,
  [4851] = 4794,
  [4852] = 4794,
  [4853] = 4793,
  [4854] = 4793,
  [4855] = 4794,
  [4856] = 4793,
  [4857] = 4793,
  [4858] = 4794,
  [4859] = 4793,
  [4860] = 4860,
  [4861] = 4793,
  [4862] = 4793,
  [4863] = 4793,
  [4864] = 4794,
  [4865] = 4794,
  [4866] = 4793,
  [4867] = 4793,
  [4868] = 4794,
  [4869] = 4793,
  [4870] = 4793,
  [4871] = 4794,
  [4872] = 3131,
  [4873] = 4793,
  [4874] = 4794,
  [4875] = 4793,
  [4876] = 4793,
  [4877] = 4794,
  [4878] = 4793,
  [4879] = 4794,
  [4880] = 4793,
  [4881] = 4794,
  [4882] = 4793,
  [4883] = 4793,
  [4884] = 4794,
  [4885] = 4794,
  [4886] = 4794,
  [4887] = 4794,
  [4888] = 4793,
  [4889] = 4794,
  [4890] = 3132,
  [4891] = 4793,
  [4892] = 3133,
  [4893] = 3134,
  [4894] = 3136,
  [4895] = 4794,
  [4896] = 4793,
  [4897] = 3262,
  [4898] = 4898,
  [4899] = 3455,
  [4900] = 3459,
  [4901] = 3412,
  [4902] = 4898,
  [4903] = 3451,
  [4904] = 3351,
  [4905] = 4898,
  [4906] = 4898,
  [4907] = 4898,
  [4908] = 3305,
  [4909] = 3306,
  [4910] = 3307,
  [4911] = 3468,
  [4912] = 3293,
  [4913] = 3297,
  [4914] = 4898,
  [4915] = 3308,
  [4916] = 4898,
  [4917] = 4898,
  [4918] = 3248,
  [4919] = 4898,
  [4920] = 4898,
  [4921] = 3291,
  [4922] = 4898,
  [4923] = 3452,
  [4924] = 4898,
  [4925] = 3458,
  [4926] = 3453,
  [4927] = 3255,
  [4928] = 3139,
  [4929] = 3263,
  [4930] = 4898,
  [4931] = 3454,
  [4932] = 3264,
  [4933] = 3456,
  [4934] = 4898,
  [4935] = 4898,
  [4936] = 4898,
  [4937] = 4898,
  [4938] = 4898,
  [4939] = 3115,
  [4940] = 3296,
  [4941] = 4898,
  [4942] = 3250,
  [4943] = 4898,
  [4944] = 4898,
  [4945] = 3471,
  [4946] = 3114,
  [4947] = 4898,
  [4948] = 3131,
  [4949] = 4898,
  [4950] = 3135,
  [4951] = 3292,
  [4952] = 4898,
  [4953] = 3265,
  [4954] = 3302,
  [4955] = 3360,
  [4956] = 3303,
  [4957] = 3266,
  [4958] = 3267,
  [4959] = 4898,
  [4960] = 4898,
  [4961] = 3472,
  [4962] = 3460,
  [4963] = 3374,
  [4964] = 3309,
  [4965] = 4898,
  [4966] = 3251,
  [4967] = 3362,
  [4968] = 4898,
  [4969] = 3301,
  [4970] = 3450,
  [4971] = 4898,
  [4972] = 3377,
  [4973] = 3268,
  [4974] = 3311,
  [4975] = 3269,
  [4976] = 3295,
  [4977] = 4898,
  [4978] = 4898,
  [4979] = 3256,
  [4980] = 4898,
  [4981] = 4898,
  [4982] = 3392,
  [4983] = 3252,
  [4984] = 4898,
  [4985] = 4898,
  [4986] = 3272,
  [4987] = 4898,
  [4988] = 3136,
  [4989] = 4898,
  [4990] = 4898,
  [4991] = 3115,
  [4992] = 3140,
  [4993] = 3298,
  [4994] = 3294,
  [4995] = 3273,
  [4996] = 3299,
  [4997] = 3300,
  [4998] = 3274,
  [4999] = 4898,
  [5000] = 4898,
  [5001] = 4898,
  [5002] = 3275,
  [5003] = 3276,
  [5004] = 3304,
  [5005] = 3277,
  [5006] = 3278,
  [5007] = 3279,
  [5008] = 3280,
  [5009] = 4898,
  [5010] = 3137,
  [5011] = 3281,
  [5012] = 3253,
  [5013] = 3132,
  [5014] = 3282,
  [5015] = 3133,
  [5016] = 3254,
  [5017] = 3283,
  [5018] = 3284,
  [5019] = 3285,
  [5020] = 3287,
  [5021] = 3288,
  [5022] = 3289,
  [5023] = 3290,
  [5024] = 3260,
  [5025] = 4898,
  [5026] = 3134,
  [5027] = 4898,
  [5028] = 4898,
  [5029] = 3261,
  [5030] = 4898,
  [5031] = 3470,
  [5032] = 3310,
  [5033] = 3266,
  [5034] = 3459,
  [5035] = 3248,
  [5036] = 3351,
  [5037] = 3278,
  [5038] = 3460,
  [5039] = 3255,
  [5040] = 5040,
  [5041] = 3362,
  [5042] = 3302,
  [5043] = 3262,
  [5044] = 3451,
  [5045] = 3140,
  [5046] = 3450,
  [5047] = 3263,
  [5048] = 3468,
  [5049] = 3279,
  [5050] = 3470,
  [5051] = 3264,
  [5052] = 3256,
  [5053] = 3280,
  [5054] = 3250,
  [5055] = 3471,
  [5056] = 3281,
  [5057] = 3290,
  [5058] = 3301,
  [5059] = 3472,
  [5060] = 3412,
  [5061] = 3296,
  [5062] = 5062,
  [5063] = 3452,
  [5064] = 3458,
  [5065] = 3300,
  [5066] = 3282,
  [5067] = 3283,
  [5068] = 3284,
  [5069] = 3285,
  [5070] = 3251,
  [5071] = 3307,
  [5072] = 3305,
  [5073] = 5040,
  [5074] = 3287,
  [5075] = 3392,
  [5076] = 5040,
  [5077] = 3265,
  [5078] = 3293,
  [5079] = 3297,
  [5080] = 3137,
  [5081] = 3455,
  [5082] = 3261,
  [5083] = 3453,
  [5084] = 3252,
  [5085] = 3304,
  [5086] = 3298,
  [5087] = 5062,
  [5088] = 3308,
  [5089] = 3268,
  [5090] = 3253,
  [5091] = 3454,
  [5092] = 3360,
  [5093] = 3269,
  [5094] = 3288,
  [5095] = 3309,
  [5096] = 3289,
  [5097] = 3374,
  [5098] = 3272,
  [5099] = 3273,
  [5100] = 5040,
  [5101] = 3303,
  [5102] = 3254,
  [5103] = 3294,
  [5104] = 3260,
  [5105] = 3115,
  [5106] = 3274,
  [5107] = 3299,
  [5108] = 3275,
  [5109] = 3276,
  [5110] = 3114,
  [5111] = 3310,
  [5112] = 3311,
  [5113] = 5040,
  [5114] = 3295,
  [5115] = 3135,
  [5116] = 3131,
  [5117] = 3277,
  [5118] = 3306,
  [5119] = 3139,
  [5120] = 3291,
  [5121] = 3292,
  [5122] = 3136,
  [5123] = 3377,
  [5124] = 3456,
  [5125] = 5040,
  [5126] = 3132,
  [5127] = 3133,
  [5128] = 3134,
  [5129] = 3267,
  [5130] = 3291,
  [5131] = 5131,
  [5132] = 3292,
  [5133] = 5131,
  [5134] = 3295,
  [5135] = 5131,
  [5136] = 5131,
  [5137] = 5131,
  [5138] = 3139,
  [5139] = 5131,
  [5140] = 3455,
  [5141] = 3374,
  [5142] = 5131,
  [5143] = 3451,
  [5144] = 3294,
  [5145] = 5145,
  [5146] = 5131,
  [5147] = 3377,
  [5148] = 3248,
  [5149] = 3140,
  [5150] = 3392,
  [5151] = 5131,
  [5152] = 5131,
  [5153] = 5131,
  [5154] = 3297,
  [5155] = 3299,
  [5156] = 3132,
  [5157] = 5131,
  [5158] = 5131,
  [5159] = 3133,
  [5160] = 3139,
  [5161] = 3134,
  [5162] = 5131,
  [5163] = 5131,
  [5164] = 3300,
  [5165] = 5131,
  [5166] = 5131,
  [5167] = 5131,
  [5168] = 5131,
  [5169] = 3132,
  [5170] = 3133,
  [5171] = 5131,
  [5172] = 3134,
  [5173] = 5131,
  [5174] = 3965,
  [5175] = 5131,
  [5176] = 5131,
  [5177] = 5131,
  [5178] = 3456,
  [5179] = 3135,
  [5180] = 5131,
  [5181] = 3136,
  [5182] = 3459,
  [5183] = 3137,
  [5184] = 3301,
  [5185] = 5131,
  [5186] = 3412,
  [5187] = 3351,
  [5188] = 3458,
  [5189] = 5131,
  [5190] = 3460,
  [5191] = 5131,
  [5192] = 5131,
  [5193] = 3302,
  [5194] = 5131,
  [5195] = 3452,
  [5196] = 5131,
  [5197] = 3303,
  [5198] = 3140,
  [5199] = 3304,
  [5200] = 5131,
  [5201] = 3298,
  [5202] = 3468,
  [5203] = 5145,
  [5204] = 5131,
  [5205] = 3470,
  [5206] = 5131,
  [5207] = 3135,
  [5208] = 5131,
  [5209] = 3453,
  [5210] = 3136,
  [5211] = 3305,
  [5212] = 5131,
  [5213] = 3471,
  [5214] = 3289,
  [5215] = 3472,
  [5216] = 5131,
  [5217] = 3114,
  [5218] = 3293,
  [5219] = 3137,
  [5220] = 5131,
  [5221] = 3306,
  [5222] = 3114,
  [5223] = 5131,
  [5224] = 5131,
  [5225] = 3115,
  [5226] = 5131,
  [5227] = 3450,
  [5228] = 5131,
  [5229] = 3307,
  [5230] = 5131,
  [5231] = 3290,
  [5232] = 5131,
  [5233] = 5131,
  [5234] = 5234,
  [5235] = 5235,
  [5236] = 3360,
  [5237] = 5234,
  [5238] = 5235,
  [5239] = 5235,
  [5240] = 3296,
  [5241] = 5235,
  [5242] = 3261,
  [5243] = 5235,
  [5244] = 3255,
  [5245] = 5131,
  [5246] = 3308,
  [5247] = 5235,
  [5248] = 3309,
  [5249] = 3256,
  [5250] = 3310,
  [5251] = 3311,
  [5252] = 3131,
  [5253] = 3362,
  [5254] = 5234,
  [5255] = 3250,
  [5256] = 3251,
  [5257] = 3252,
  [5258] = 3253,
  [5259] = 3254,
  [5260] = 3260,
  [5261] = 3262,
  [5262] = 3263,
  [5263] = 3264,
  [5264] = 3265,
  [5265] = 3266,
  [5266] = 3267,
  [5267] = 3131,
  [5268] = 3268,
  [5269] = 3269,
  [5270] = 3272,
  [5271] = 3273,
  [5272] = 3274,
  [5273] = 3275,
  [5274] = 3276,
  [5275] = 3277,
  [5276] = 3278,
  [5277] = 3279,
  [5278] = 3280,
  [5279] = 3281,
  [5280] = 3282,
  [5281] = 3283,
  [5282] = 3284,
  [5283] = 3285,
  [5284] = 3287,
  [5285] = 3288,
  [5286] = 3454,
  [5287] = 3453,
  [5288] = 3285,
  [5289] = 3287,
  [5290] = 3256,
  [5291] = 3255,
  [5292] = 3256,
  [5293] = 3471,
  [5294] = 3472,
  [5295] = 3377,
  [5296] = 3272,
  [5297] = 3248,
  [5298] = 3288,
  [5299] = 3471,
  [5300] = 3472,
  [5301] = 3289,
  [5302] = 3274,
  [5303] = 4166,
  [5304] = 3295,
  [5305] = 3277,
  [5306] = 3260,
  [5307] = 3471,
  [5308] = 3291,
  [5309] = 3456,
  [5310] = 3292,
  [5311] = 3251,
  [5312] = 3459,
  [5313] = 3293,
  [5314] = 3294,
  [5315] = 3305,
  [5316] = 3292,
  [5317] = 3306,
  [5318] = 3301,
  [5319] = 3307,
  [5320] = 3114,
  [5321] = 3412,
  [5322] = 3351,
  [5323] = 3115,
  [5324] = 3293,
  [5325] = 3115,
  [5326] = 3273,
  [5327] = 3275,
  [5328] = 3458,
  [5329] = 3278,
  [5330] = 3276,
  [5331] = 3279,
  [5332] = 3392,
  [5333] = 3252,
  [5334] = 3139,
  [5335] = 3274,
  [5336] = 3294,
  [5337] = 3300,
  [5338] = 4161,
  [5339] = 3303,
  [5340] = 3296,
  [5341] = 3288,
  [5342] = 3289,
  [5343] = 3451,
  [5344] = 3302,
  [5345] = 3280,
  [5346] = 3284,
  [5347] = 3303,
  [5348] = 3308,
  [5349] = 3304,
  [5350] = 3287,
  [5351] = 3965,
  [5352] = 3452,
  [5353] = 3460,
  [5354] = 3412,
  [5355] = 3309,
  [5356] = 3454,
  [5357] = 3255,
  [5358] = 3362,
  [5359] = 3360,
  [5360] = 3471,
  [5361] = 3276,
  [5362] = 3305,
  [5363] = 3310,
  [5364] = 3455,
  [5365] = 3306,
  [5366] = 3307,
  [5367] = 3277,
  [5368] = 3308,
  [5369] = 3309,
  [5370] = 3265,
  [5371] = 3250,
  [5372] = 3310,
  [5373] = 3253,
  [5374] = 3296,
  [5375] = 3297,
  [5376] = 3374,
  [5377] = 3311,
  [5378] = 3311,
  [5379] = 3266,
  [5380] = 3278,
  [5381] = 3304,
  [5382] = 3279,
  [5383] = 3267,
  [5384] = 3377,
  [5385] = 3248,
  [5386] = 3392,
  [5387] = 3280,
  [5388] = 3360,
  [5389] = 3299,
  [5390] = 3290,
  [5391] = 3251,
  [5392] = 3299,
  [5393] = 3300,
  [5394] = 3252,
  [5395] = 3253,
  [5396] = 3295,
  [5397] = 3254,
  [5398] = 3250,
  [5399] = 3260,
  [5400] = 3261,
  [5401] = 3450,
  [5402] = 3261,
  [5403] = 3131,
  [5404] = 3262,
  [5405] = 3450,
  [5406] = 3281,
  [5407] = 3451,
  [5408] = 3302,
  [5409] = 3297,
  [5410] = 3290,
  [5411] = 3282,
  [5412] = 3132,
  [5413] = 3133,
  [5414] = 3134,
  [5415] = 3283,
  [5416] = 3452,
  [5417] = 3453,
  [5418] = 3285,
  [5419] = 3135,
  [5420] = 3268,
  [5421] = 3374,
  [5422] = 3136,
  [5423] = 3137,
  [5424] = 3269,
  [5425] = 3262,
  [5426] = 3263,
  [5427] = 3264,
  [5428] = 3301,
  [5429] = 3265,
  [5430] = 3298,
  [5431] = 3454,
  [5432] = 3456,
  [5433] = 3459,
  [5434] = 3351,
  [5435] = 3275,
  [5436] = 3254,
  [5437] = 3266,
  [5438] = 3412,
  [5439] = 3273,
  [5440] = 3267,
  [5441] = 3263,
  [5442] = 3264,
  [5443] = 3291,
  [5444] = 3140,
  [5445] = 3281,
  [5446] = 3268,
  [5447] = 3269,
  [5448] = 3460,
  [5449] = 3282,
  [5450] = 3468,
  [5451] = 3455,
  [5452] = 3272,
  [5453] = 3298,
  [5454] = 3468,
  [5455] = 3470,
  [5456] = 3283,
  [5457] = 3284,
  [5458] = 3470,
  [5459] = 3412,
  [5460] = 3458,
  [5461] = 3362,
  [5462] = 3308,
  [5463] = 3254,
  [5464] = 3456,
  [5465] = 3302,
  [5466] = 3260,
  [5467] = 3255,
  [5468] = 5468,
  [5469] = 5469,
  [5470] = 3412,
  [5471] = 5471,
  [5472] = 3262,
  [5473] = 3263,
  [5474] = 3264,
  [5475] = 3265,
  [5476] = 3266,
  [5477] = 3267,
  [5478] = 3290,
  [5479] = 3255,
  [5480] = 3268,
  [5481] = 3256,
  [5482] = 3269,
  [5483] = 3272,
  [5484] = 3273,
  [5485] = 3274,
  [5486] = 3275,
  [5487] = 3276,
  [5488] = 5488,
  [5489] = 3459,
  [5490] = 3277,
  [5491] = 3311,
  [5492] = 3468,
  [5493] = 3278,
  [5494] = 5494,
  [5495] = 3471,
  [5496] = 3470,
  [5497] = 3471,
  [5498] = 3279,
  [5499] = 3280,
  [5500] = 3256,
  [5501] = 3472,
  [5502] = 3281,
  [5503] = 3282,
  [5504] = 3283,
  [5505] = 3284,
  [5506] = 3285,
  [5507] = 3287,
  [5508] = 3456,
  [5509] = 3288,
  [5510] = 3289,
  [5511] = 3115,
  [5512] = 3303,
  [5513] = 5513,
  [5514] = 3459,
  [5515] = 3306,
  [5516] = 3291,
  [5517] = 3292,
  [5518] = 3293,
  [5519] = 3307,
  [5520] = 3294,
  [5521] = 3360,
  [5522] = 3362,
  [5523] = 3351,
  [5524] = 5494,
  [5525] = 3472,
  [5526] = 3458,
  [5527] = 3460,
  [5528] = 3377,
  [5529] = 3248,
  [5530] = 3296,
  [5531] = 3392,
  [5532] = 3297,
  [5533] = 5533,
  [5534] = 3455,
  [5535] = 3450,
  [5536] = 5513,
  [5537] = 4166,
  [5538] = 3412,
  [5539] = 3459,
  [5540] = 3412,
  [5541] = 3256,
  [5542] = 3298,
  [5543] = 3304,
  [5544] = 3295,
  [5545] = 3468,
  [5546] = 3455,
  [5547] = 3470,
  [5548] = 3451,
  [5549] = 3301,
  [5550] = 3300,
  [5551] = 4161,
  [5552] = 3452,
  [5553] = 3453,
  [5554] = 3250,
  [5555] = 3305,
  [5556] = 3468,
  [5557] = 3309,
  [5558] = 3351,
  [5559] = 3351,
  [5560] = 3251,
  [5561] = 5469,
  [5562] = 3471,
  [5563] = 3470,
  [5564] = 3252,
  [5565] = 3458,
  [5566] = 3460,
  [5567] = 3253,
  [5568] = 3255,
  [5569] = 3295,
  [5570] = 3456,
  [5571] = 5488,
  [5572] = 3460,
  [5573] = 3458,
  [5574] = 3472,
  [5575] = 3454,
  [5576] = 3261,
  [5577] = 3310,
  [5578] = 3299,
  [5579] = 3455,
  [5580] = 3965,
  [5581] = 3295,
  [5582] = 3374,
  [5583] = 5583,
  [5584] = 3459,
  [5585] = 5585,
  [5586] = 5586,
  [5587] = 3377,
  [5588] = 3248,
  [5589] = 3451,
  [5590] = 3140,
  [5591] = 5591,
  [5592] = 3468,
  [5593] = 5593,
  [5594] = 5594,
  [5595] = 5595,
  [5596] = 3470,
  [5597] = 3392,
  [5598] = 5598,
  [5599] = 5599,
  [5600] = 5600,
  [5601] = 5601,
  [5602] = 3256,
  [5603] = 5603,
  [5604] = 5469,
  [5605] = 5605,
  [5606] = 5606,
  [5607] = 5607,
  [5608] = 5591,
  [5609] = 5609,
  [5610] = 5610,
  [5611] = 3452,
  [5612] = 5513,
  [5613] = 5613,
  [5614] = 5494,
  [5615] = 3453,
  [5616] = 3454,
  [5617] = 5617,
  [5618] = 5586,
  [5619] = 5619,
  [5620] = 5620,
  [5621] = 5621,
  [5622] = 5595,
  [5623] = 5623,
  [5624] = 5488,
  [5625] = 3450,
  [5626] = 3255,
  [5627] = 5627,
  [5628] = 5598,
  [5629] = 3460,
  [5630] = 5630,
  [5631] = 5603,
  [5632] = 5469,
  [5633] = 5633,
  [5634] = 5634,
  [5635] = 5635,
  [5636] = 3115,
  [5637] = 5637,
  [5638] = 3114,
  [5639] = 4161,
  [5640] = 3360,
  [5641] = 3362,
  [5642] = 5494,
  [5643] = 5643,
  [5644] = 3377,
  [5645] = 5630,
  [5646] = 5646,
  [5647] = 3248,
  [5648] = 3135,
  [5649] = 5649,
  [5650] = 5605,
  [5651] = 5583,
  [5652] = 5652,
  [5653] = 5606,
  [5654] = 3451,
  [5655] = 5655,
  [5656] = 5656,
  [5657] = 3458,
  [5658] = 3295,
  [5659] = 3455,
  [5660] = 3965,
  [5661] = 5488,
  [5662] = 5662,
  [5663] = 5513,
  [5664] = 3452,
  [5665] = 3453,
  [5666] = 5666,
  [5667] = 5667,
  [5668] = 5599,
  [5669] = 5600,
  [5670] = 5609,
  [5671] = 5637,
  [5672] = 5672,
  [5673] = 5673,
  [5674] = 5585,
  [5675] = 3472,
  [5676] = 5662,
  [5677] = 5677,
  [5678] = 3131,
  [5679] = 3454,
  [5680] = 3136,
  [5681] = 5681,
  [5682] = 5594,
  [5683] = 3456,
  [5684] = 3459,
  [5685] = 3351,
  [5686] = 3460,
  [5687] = 5687,
  [5688] = 3255,
  [5689] = 5607,
  [5690] = 5617,
  [5691] = 5681,
  [5692] = 5610,
  [5693] = 5693,
  [5694] = 5693,
  [5695] = 5655,
  [5696] = 3360,
  [5697] = 5623,
  [5698] = 3137,
  [5699] = 3392,
  [5700] = 5656,
  [5701] = 3468,
  [5702] = 3351,
  [5703] = 5667,
  [5704] = 3470,
  [5705] = 3450,
  [5706] = 3256,
  [5707] = 5707,
  [5708] = 3362,
  [5709] = 5672,
  [5710] = 3132,
  [5711] = 5673,
  [5712] = 3133,
  [5713] = 5687,
  [5714] = 3139,
  [5715] = 3134,
  [5716] = 3458,
  [5717] = 3455,
  [5718] = 3374,
  [5719] = 3295,
  [5720] = 5643,
  [5721] = 5619,
  [5722] = 3965,
  [5723] = 5723,
  [5724] = 5724,
  [5725] = 5620,
  [5726] = 4166,
  [5727] = 5593,
  [5728] = 5627,
  [5729] = 5601,
  [5730] = 3472,
  [5731] = 3374,
  [5732] = 5723,
  [5733] = 5724,
  [5734] = 3456,
  [5735] = 5621,
  [5736] = 5646,
  [5737] = 5649,
  [5738] = 5633,
  [5739] = 5634,
  [5740] = 5652,
  [5741] = 5666,
  [5742] = 5677,
  [5743] = 5635,
  [5744] = 5613,
  [5745] = 5707,
  [5746] = 5599,
  [5747] = 5656,
  [5748] = 3115,
  [5749] = 5594,
  [5750] = 5609,
  [5751] = 3311,
  [5752] = 5591,
  [5753] = 3452,
  [5754] = 5637,
  [5755] = 3115,
  [5756] = 3453,
  [5757] = 5591,
  [5758] = 3374,
  [5759] = 5652,
  [5760] = 5666,
  [5761] = 3454,
  [5762] = 3250,
  [5763] = 5585,
  [5764] = 3251,
  [5765] = 3252,
  [5766] = 5619,
  [5767] = 3253,
  [5768] = 3114,
  [5769] = 3297,
  [5770] = 3377,
  [5771] = 5667,
  [5772] = 5667,
  [5773] = 5595,
  [5774] = 5621,
  [5775] = 3254,
  [5776] = 3248,
  [5777] = 3260,
  [5778] = 3374,
  [5779] = 5598,
  [5780] = 3261,
  [5781] = 5603,
  [5782] = 4166,
  [5783] = 5707,
  [5784] = 5605,
  [5785] = 3392,
  [5786] = 3455,
  [5787] = 3299,
  [5788] = 3377,
  [5789] = 3248,
  [5790] = 3262,
  [5791] = 3300,
  [5792] = 5586,
  [5793] = 3263,
  [5794] = 3392,
  [5795] = 3264,
  [5796] = 5707,
  [5797] = 4166,
  [5798] = 3450,
  [5799] = 5655,
  [5800] = 3265,
  [5801] = 5627,
  [5802] = 3266,
  [5803] = 5646,
  [5804] = 5606,
  [5805] = 3450,
  [5806] = 3362,
  [5807] = 3267,
  [5808] = 5607,
  [5809] = 5672,
  [5810] = 5673,
  [5811] = 5617,
  [5812] = 5662,
  [5813] = 5620,
  [5814] = 5623,
  [5815] = 5633,
  [5816] = 5672,
  [5817] = 5599,
  [5818] = 3140,
  [5819] = 5634,
  [5820] = 5673,
  [5821] = 3256,
  [5822] = 5600,
  [5823] = 3248,
  [5824] = 3305,
  [5825] = 3451,
  [5826] = 3268,
  [5827] = 3306,
  [5828] = 5635,
  [5829] = 3452,
  [5830] = 5634,
  [5831] = 3269,
  [5832] = 5600,
  [5833] = 3272,
  [5834] = 3453,
  [5835] = 5630,
  [5836] = 3454,
  [5837] = 5649,
  [5838] = 5652,
  [5839] = 3307,
  [5840] = 5609,
  [5841] = 3273,
  [5842] = 3274,
  [5843] = 5681,
  [5844] = 3275,
  [5845] = 3276,
  [5846] = 5610,
  [5847] = 3277,
  [5848] = 5666,
  [5849] = 5585,
  [5850] = 3278,
  [5851] = 5662,
  [5852] = 5681,
  [5853] = 5586,
  [5854] = 4161,
  [5855] = 5693,
  [5856] = 5656,
  [5857] = 5693,
  [5858] = 3451,
  [5859] = 3456,
  [5860] = 3360,
  [5861] = 3459,
  [5862] = 3472,
  [5863] = 3412,
  [5864] = 5583,
  [5865] = 5723,
  [5866] = 5613,
  [5867] = 3279,
  [5868] = 3362,
  [5869] = 3452,
  [5870] = 5677,
  [5871] = 3280,
  [5872] = 5687,
  [5873] = 5610,
  [5874] = 3453,
  [5875] = 3131,
  [5876] = 3281,
  [5877] = 3282,
  [5878] = 3283,
  [5879] = 3284,
  [5880] = 5635,
  [5881] = 3285,
  [5882] = 3287,
  [5883] = 3454,
  [5884] = 3295,
  [5885] = 3288,
  [5886] = 3296,
  [5887] = 5630,
  [5888] = 5687,
  [5889] = 3289,
  [5890] = 3290,
  [5891] = 3451,
  [5892] = 3132,
  [5893] = 3133,
  [5894] = 3134,
  [5895] = 5724,
  [5896] = 5677,
  [5897] = 3135,
  [5898] = 3136,
  [5899] = 3137,
  [5900] = 3377,
  [5901] = 3351,
  [5902] = 5619,
  [5903] = 5621,
  [5904] = 3392,
  [5905] = 3255,
  [5906] = 3291,
  [5907] = 3301,
  [5908] = 5613,
  [5909] = 5643,
  [5910] = 5723,
  [5911] = 5643,
  [5912] = 3965,
  [5913] = 5594,
  [5914] = 3298,
  [5915] = 3458,
  [5916] = 3460,
  [5917] = 5598,
  [5918] = 5724,
  [5919] = 5593,
  [5920] = 3139,
  [5921] = 3360,
  [5922] = 5637,
  [5923] = 5601,
  [5924] = 3360,
  [5925] = 5601,
  [5926] = 3470,
  [5927] = 5603,
  [5928] = 5627,
  [5929] = 3471,
  [5930] = 5655,
  [5931] = 5646,
  [5932] = 5605,
  [5933] = 3450,
  [5934] = 5623,
  [5935] = 5606,
  [5936] = 5583,
  [5937] = 5593,
  [5938] = 5607,
  [5939] = 3468,
  [5940] = 3304,
  [5941] = 3292,
  [5942] = 5649,
  [5943] = 3308,
  [5944] = 3293,
  [5945] = 5595,
  [5946] = 5617,
  [5947] = 3309,
  [5948] = 3374,
  [5949] = 3294,
  [5950] = 3310,
  [5951] = 3302,
  [5952] = 3303,
  [5953] = 3362,
  [5954] = 5620,
  [5955] = 5633,
  [5956] = 4161,
  [5957] = 3262,
  [5958] = 3255,
  [5959] = 4166,
  [5960] = 3278,
  [5961] = 3279,
  [5962] = 3280,
  [5963] = 5963,
  [5964] = 3471,
  [5965] = 3281,
  [5966] = 3299,
  [5967] = 3282,
  [5968] = 3283,
  [5969] = 3284,
  [5970] = 3456,
  [5971] = 3285,
  [5972] = 3287,
  [5973] = 5973,
  [5974] = 3251,
  [5975] = 3288,
  [5976] = 3289,
  [5977] = 3252,
  [5978] = 3253,
  [5979] = 5963,
  [5980] = 3310,
  [5981] = 3254,
  [5982] = 3301,
  [5983] = 3291,
  [5984] = 3300,
  [5985] = 3292,
  [5986] = 3293,
  [5987] = 3260,
  [5988] = 3294,
  [5989] = 3290,
  [5990] = 4161,
  [5991] = 3132,
  [5992] = 3295,
  [5993] = 5973,
  [5994] = 3311,
  [5995] = 3296,
  [5996] = 3136,
  [5997] = 3133,
  [5998] = 3139,
  [5999] = 3470,
  [6000] = 3134,
  [6001] = 3302,
  [6002] = 3297,
  [6003] = 5963,
  [6004] = 5973,
  [6005] = 3303,
  [6006] = 3309,
  [6007] = 5973,
  [6008] = 5973,
  [6009] = 3308,
  [6010] = 3450,
  [6011] = 3472,
  [6012] = 3452,
  [6013] = 6013,
  [6014] = 3248,
  [6015] = 3468,
  [6016] = 3351,
  [6017] = 3277,
  [6018] = 3458,
  [6019] = 3455,
  [6020] = 3304,
  [6021] = 5963,
  [6022] = 3256,
  [6023] = 3392,
  [6024] = 3454,
  [6025] = 5963,
  [6026] = 5973,
  [6027] = 5973,
  [6028] = 3453,
  [6029] = 3263,
  [6030] = 6013,
  [6031] = 3264,
  [6032] = 3377,
  [6033] = 3460,
  [6034] = 6013,
  [6035] = 6035,
  [6036] = 3265,
  [6037] = 3266,
  [6038] = 3298,
  [6039] = 5973,
  [6040] = 3267,
  [6041] = 3115,
  [6042] = 3135,
  [6043] = 3131,
  [6044] = 3140,
  [6045] = 5963,
  [6046] = 3137,
  [6047] = 3268,
  [6048] = 3269,
  [6049] = 3412,
  [6050] = 3374,
  [6051] = 3261,
  [6052] = 3114,
  [6053] = 3360,
  [6054] = 3272,
  [6055] = 3273,
  [6056] = 3459,
  [6057] = 3274,
  [6058] = 3275,
  [6059] = 3250,
  [6060] = 6013,
  [6061] = 3305,
  [6062] = 3276,
  [6063] = 6035,
  [6064] = 3451,
  [6065] = 3306,
  [6066] = 6035,
  [6067] = 3115,
  [6068] = 3307,
  [6069] = 3362,
  [6070] = 5973,
  [6071] = 3248,
  [6072] = 3456,
  [6073] = 3459,
  [6074] = 3412,
  [6075] = 3351,
  [6076] = 3458,
  [6077] = 3460,
  [6078] = 3299,
  [6079] = 3300,
  [6080] = 3468,
  [6081] = 3301,
  [6082] = 3470,
  [6083] = 3471,
  [6084] = 3472,
  [6085] = 3302,
  [6086] = 3303,
  [6087] = 3304,
  [6088] = 3305,
  [6089] = 3306,
  [6090] = 3307,
  [6091] = 3308,
  [6092] = 3309,
  [6093] = 3310,
  [6094] = 3311,
  [6095] = 3255,
  [6096] = 3256,
  [6097] = 3295,
  [6098] = 3360,
  [6099] = 3362,
  [6100] = 3450,
  [6101] = 3451,
  [6102] = 3452,
  [6103] = 3453,
  [6104] = 3454,
  [6105] = 3455,
  [6106] = 3456,
  [6107] = 3459,
  [6108] = 3412,
  [6109] = 3351,
  [6110] = 3458,
  [6111] = 3460,
  [6112] = 3468,
  [6113] = 3470,
  [6114] = 3471,
  [6115] = 3472,
  [6116] = 3255,
  [6117] = 3256,
  [6118] = 3295,
  [6119] = 3450,
  [6120] = 3451,
  [6121] = 3452,
  [6122] = 3453,
  [6123] = 3454,
  [6124] = 3455,
  [6125] = 3456,
  [6126] = 3459,
  [6127] = 3412,
  [6128] = 3351,
  [6129] = 3458,
  [6130] = 3460,
  [6131] = 3468,
  [6132] = 3470,
  [6133] = 3471,
  [6134] = 3472,
  [6135] = 3255,
  [6136] = 3256,
  [6137] = 3295,
  [6138] = 3374,
  [6139] = 3377,
  [6140] = 3248,
  [6141] = 3392,
  [6142] = 3374,
  [6143] = 3377,
  [6144] = 3392,
  [6145] = 3374,
  [6146] = 3377,
  [6147] = 3248,
  [6148] = 3392,
  [6149] = 6149,
  [6150] = 6150,
  [6151] = 6149,
  [6152] = 3114,
  [6153] = 3115,
  [6154] = 6150,
  [6155] = 6150,
  [6156] = 6149,
  [6157] = 6150,
  [6158] = 3261,
  [6159] = 3290,
  [6160] = 3131,
  [6161] = 3132,
  [6162] = 3133,
  [6163] = 3134,
  [6164] = 3135,
  [6165] = 3136,
  [6166] = 3137,
  [6167] = 3114,
  [6168] = 3139,
  [6169] = 3140,
  [6170] = 3114,
  [6171] = 3261,
  [6172] = 3290,
  [6173] = 3360,
  [6174] = 3114,
  [6175] = 3114,
  [6176] = 3250,
  [6177] = 3251,
  [6178] = 3252,
  [6179] = 3253,
  [6180] = 3254,
  [6181] = 3260,
  [6182] = 3262,
  [6183] = 3263,
  [6184] = 3264,
  [6185] = 3265,
  [6186] = 3266,
  [6187] = 3267,
  [6188] = 3131,
  [6189] = 3268,
  [6190] = 3269,
  [6191] = 3272,
  [6192] = 3273,
  [6193] = 3274,
  [6194] = 3275,
  [6195] = 3276,
  [6196] = 3277,
  [6197] = 3278,
  [6198] = 3279,
  [6199] = 3280,
  [6200] = 3281,
  [6201] = 3282,
  [6202] = 3283,
  [6203] = 3284,
  [6204] = 3285,
  [6205] = 3287,
  [6206] = 3288,
  [6207] = 3289,
  [6208] = 3132,
  [6209] = 3133,
  [6210] = 3134,
  [6211] = 3291,
  [6212] = 3292,
  [6213] = 3293,
  [6214] = 3294,
  [6215] = 3135,
  [6216] = 3136,
  [6217] = 3137,
  [6218] = 3296,
  [6219] = 3297,
  [6220] = 3131,
  [6221] = 3298,
  [6222] = 3132,
  [6223] = 3133,
  [6224] = 3134,
  [6225] = 3135,
  [6226] = 3136,
  [6227] = 3137,
  [6228] = 3139,
  [6229] = 3131,
  [6230] = 3140,
  [6231] = 3132,
  [6232] = 3133,
  [6233] = 3134,
  [6234] = 3135,
  [6235] = 3136,
  [6236] = 3137,
  [6237] = 3360,
  [6238] = 3299,
  [6239] = 3300,
  [6240] = 3139,
  [6241] = 3301,
  [6242] = 3131,
  [6243] = 3302,
  [6244] = 3303,
  [6245] = 3140,
  [6246] = 3304,
  [6247] = 3132,
  [6248] = 3133,
  [6249] = 3134,
  [6250] = 3305,
  [6251] = 3140,
  [6252] = 3307,
  [6253] = 3135,
  [6254] = 3136,
  [6255] = 3137,
  [6256] = 3115,
  [6257] = 3115,
  [6258] = 3115,
  [6259] = 3115,
  [6260] = 3308,
  [6261] = 3309,
  [6262] = 3310,
  [6263] = 3311,
  [6264] = 3114,
  [6265] = 3115,
  [6266] = 3139,
  [6267] = 3131,
  [6268] = 3140,
  [6269] = 3132,
  [6270] = 3133,
  [6271] = 3134,
  [6272] = 3135,
  [6273] = 3136,
  [6274] = 3137,
  [6275] = 3362,
  [6276] = 3139,
  [6277] = 3140,
  [6278] = 3250,
  [6279] = 3251,
  [6280] = 3252,
  [6281] = 3253,
  [6282] = 3254,
  [6283] = 3260,
  [6284] = 3139,
  [6285] = 3262,
  [6286] = 3263,
  [6287] = 3264,
  [6288] = 3265,
  [6289] = 3266,
  [6290] = 3267,
  [6291] = 3131,
  [6292] = 3268,
  [6293] = 3269,
  [6294] = 3272,
  [6295] = 3273,
  [6296] = 3274,
  [6297] = 3275,
  [6298] = 3276,
  [6299] = 3277,
  [6300] = 3278,
  [6301] = 3279,
  [6302] = 3280,
  [6303] = 3140,
  [6304] = 3281,
  [6305] = 3282,
  [6306] = 3283,
  [6307] = 3284,
  [6308] = 3285,
  [6309] = 3287,
  [6310] = 3288,
  [6311] = 3289,
  [6312] = 3132,
  [6313] = 3133,
  [6314] = 3134,
  [6315] = 3291,
  [6316] = 3292,
  [6317] = 3293,
  [6318] = 3294,
  [6319] = 3135,
  [6320] = 3136,
  [6321] = 3137,
  [6322] = 3296,
  [6323] = 3297,
  [6324] = 3298,
  [6325] = 6149,
  [6326] = 3139,
  [6327] = 3140,
  [6328] = 3299,
  [6329] = 3300,
  [6330] = 3301,
  [6331] = 3302,
  [6332] = 3303,
  [6333] = 3304,
  [6334] = 3305,
  [6335] = 3306,
  [6336] = 3307,
  [6337] = 3308,
  [6338] = 3309,
  [6339] = 3310,
  [6340] = 3311,
  [6341] = 3115,
  [6342] = 3362,
  [6343] = 3450,
  [6344] = 3131,
  [6345] = 3132,
  [6346] = 3133,
  [6347] = 3134,
  [6348] = 3451,
  [6349] = 3135,
  [6350] = 3136,
  [6351] = 3137,
  [6352] = 3452,
  [6353] = 3453,
  [6354] = 3454,
  [6355] = 3250,
  [6356] = 3251,
  [6357] = 3252,
  [6358] = 3253,
  [6359] = 3254,
  [6360] = 3260,
  [6361] = 3261,
  [6362] = 3262,
  [6363] = 3263,
  [6364] = 3264,
  [6365] = 3265,
  [6366] = 3266,
  [6367] = 3267,
  [6368] = 3268,
  [6369] = 3269,
  [6370] = 3272,
  [6371] = 3273,
  [6372] = 3274,
  [6373] = 3275,
  [6374] = 3276,
  [6375] = 3277,
  [6376] = 3278,
  [6377] = 3279,
  [6378] = 3280,
  [6379] = 3281,
  [6380] = 3282,
  [6381] = 3283,
  [6382] = 3284,
  [6383] = 3285,
  [6384] = 3287,
  [6385] = 3288,
  [6386] = 3289,
  [6387] = 3290,
  [6388] = 3291,
  [6389] = 3292,
  [6390] = 3293,
  [6391] = 3294,
  [6392] = 3296,
  [6393] = 3297,
  [6394] = 3455,
  [6395] = 3139,
  [6396] = 3965,
  [6397] = 3298,
  [6398] = 3306,
  [6399] = 3304,
  [6400] = 3471,
  [6401] = 3472,
  [6402] = 3255,
  [6403] = 3295,
  [6404] = 3256,
  [6405] = 3290,
  [6406] = 3132,
  [6407] = 3133,
  [6408] = 3134,
  [6409] = 3450,
  [6410] = 4161,
  [6411] = 3452,
  [6412] = 3295,
  [6413] = 3308,
  [6414] = 3135,
  [6415] = 3136,
  [6416] = 3137,
  [6417] = 3309,
  [6418] = 3450,
  [6419] = 3451,
  [6420] = 3452,
  [6421] = 3453,
  [6422] = 3454,
  [6423] = 3310,
  [6424] = 3299,
  [6425] = 3455,
  [6426] = 6426,
  [6427] = 3456,
  [6428] = 3459,
  [6429] = 3412,
  [6430] = 3351,
  [6431] = 3458,
  [6432] = 3460,
  [6433] = 3453,
  [6434] = 3468,
  [6435] = 3470,
  [6436] = 3471,
  [6437] = 3472,
  [6438] = 3139,
  [6439] = 3311,
  [6440] = 3139,
  [6441] = 3255,
  [6442] = 3256,
  [6443] = 3301,
  [6444] = 3295,
  [6445] = 3454,
  [6446] = 3302,
  [6447] = 3140,
  [6448] = 3304,
  [6449] = 3374,
  [6450] = 3377,
  [6451] = 3248,
  [6452] = 3392,
  [6453] = 3374,
  [6454] = 3377,
  [6455] = 3248,
  [6456] = 3392,
  [6457] = 3374,
  [6458] = 3305,
  [6459] = 3306,
  [6460] = 3307,
  [6461] = 3377,
  [6462] = 3248,
  [6463] = 3392,
  [6464] = 3374,
  [6465] = 3377,
  [6466] = 3248,
  [6467] = 3392,
  [6468] = 3451,
  [6469] = 3308,
  [6470] = 3309,
  [6471] = 3310,
  [6472] = 3374,
  [6473] = 3377,
  [6474] = 3248,
  [6475] = 3392,
  [6476] = 3311,
  [6477] = 3250,
  [6478] = 3251,
  [6479] = 3252,
  [6480] = 3253,
  [6481] = 3254,
  [6482] = 3260,
  [6483] = 3452,
  [6484] = 6484,
  [6485] = 3262,
  [6486] = 3263,
  [6487] = 3264,
  [6488] = 3265,
  [6489] = 3266,
  [6490] = 3267,
  [6491] = 3131,
  [6492] = 3268,
  [6493] = 3269,
  [6494] = 6426,
  [6495] = 3272,
  [6496] = 3273,
  [6497] = 3274,
  [6498] = 3275,
  [6499] = 3276,
  [6500] = 3277,
  [6501] = 3278,
  [6502] = 3279,
  [6503] = 3280,
  [6504] = 3281,
  [6505] = 3282,
  [6506] = 3283,
  [6507] = 3284,
  [6508] = 3285,
  [6509] = 3287,
  [6510] = 3288,
  [6511] = 3289,
  [6512] = 3132,
  [6513] = 3133,
  [6514] = 3134,
  [6515] = 3291,
  [6516] = 3292,
  [6517] = 3293,
  [6518] = 3294,
  [6519] = 3135,
  [6520] = 3136,
  [6521] = 3137,
  [6522] = 3296,
  [6523] = 3114,
  [6524] = 3115,
  [6525] = 3297,
  [6526] = 3298,
  [6527] = 6484,
  [6528] = 3451,
  [6529] = 3453,
  [6530] = 6484,
  [6531] = 3305,
  [6532] = 3454,
  [6533] = 6426,
  [6534] = 3139,
  [6535] = 3140,
  [6536] = 6484,
  [6537] = 6426,
  [6538] = 3456,
  [6539] = 3300,
  [6540] = 3360,
  [6541] = 3131,
  [6542] = 3132,
  [6543] = 3133,
  [6544] = 3134,
  [6545] = 3135,
  [6546] = 3136,
  [6547] = 3137,
  [6548] = 3362,
  [6549] = 3250,
  [6550] = 3251,
  [6551] = 3252,
  [6552] = 3253,
  [6553] = 3254,
  [6554] = 3260,
  [6555] = 3262,
  [6556] = 3263,
  [6557] = 3264,
  [6558] = 3265,
  [6559] = 3266,
  [6560] = 3267,
  [6561] = 3459,
  [6562] = 3268,
  [6563] = 3269,
  [6564] = 3272,
  [6565] = 3273,
  [6566] = 3274,
  [6567] = 3275,
  [6568] = 3276,
  [6569] = 3277,
  [6570] = 3278,
  [6571] = 3279,
  [6572] = 3280,
  [6573] = 3281,
  [6574] = 3282,
  [6575] = 3283,
  [6576] = 3284,
  [6577] = 3285,
  [6578] = 3287,
  [6579] = 3288,
  [6580] = 3289,
  [6581] = 3412,
  [6582] = 3351,
  [6583] = 3291,
  [6584] = 3292,
  [6585] = 3293,
  [6586] = 3294,
  [6587] = 3458,
  [6588] = 3460,
  [6589] = 3296,
  [6590] = 3297,
  [6591] = 3261,
  [6592] = 3139,
  [6593] = 3303,
  [6594] = 3298,
  [6595] = 3140,
  [6596] = 3290,
  [6597] = 3131,
  [6598] = 3115,
  [6599] = 3299,
  [6600] = 3374,
  [6601] = 3301,
  [6602] = 3377,
  [6603] = 3248,
  [6604] = 3302,
  [6605] = 3392,
  [6606] = 3304,
  [6607] = 3114,
  [6608] = 3305,
  [6609] = 3306,
  [6610] = 3307,
  [6611] = 3308,
  [6612] = 3309,
  [6613] = 3310,
  [6614] = 3311,
  [6615] = 3115,
  [6616] = 3455,
  [6617] = 3450,
  [6618] = 3115,
  [6619] = 3300,
  [6620] = 3303,
  [6621] = 3362,
  [6622] = 3115,
  [6623] = 3450,
  [6624] = 3451,
  [6625] = 3452,
  [6626] = 3453,
  [6627] = 3454,
  [6628] = 3468,
  [6629] = 3470,
  [6630] = 3306,
  [6631] = 3471,
  [6632] = 3965,
  [6633] = 3472,
  [6634] = 3451,
  [6635] = 3140,
  [6636] = 3452,
  [6637] = 3360,
  [6638] = 3250,
  [6639] = 3412,
  [6640] = 3458,
  [6641] = 3251,
  [6642] = 3252,
  [6643] = 3253,
  [6644] = 3254,
  [6645] = 3260,
  [6646] = 3455,
  [6647] = 3114,
  [6648] = 3262,
  [6649] = 3263,
  [6650] = 3264,
  [6651] = 3265,
  [6652] = 3266,
  [6653] = 3267,
  [6654] = 3268,
  [6655] = 3269,
  [6656] = 3471,
  [6657] = 3272,
  [6658] = 3472,
  [6659] = 3273,
  [6660] = 3274,
  [6661] = 3275,
  [6662] = 3276,
  [6663] = 3277,
  [6664] = 3278,
  [6665] = 3279,
  [6666] = 3280,
  [6667] = 3281,
  [6668] = 3282,
  [6669] = 3283,
  [6670] = 3284,
  [6671] = 3285,
  [6672] = 3287,
  [6673] = 3288,
  [6674] = 3289,
  [6675] = 3453,
  [6676] = 3454,
  [6677] = 3291,
  [6678] = 3292,
  [6679] = 3293,
  [6680] = 3294,
  [6681] = 3360,
  [6682] = 3362,
  [6683] = 3456,
  [6684] = 3296,
  [6685] = 3456,
  [6686] = 3250,
  [6687] = 3459,
  [6688] = 3351,
  [6689] = 3297,
  [6690] = 3460,
  [6691] = 3251,
  [6692] = 3252,
  [6693] = 3253,
  [6694] = 3254,
  [6695] = 3260,
  [6696] = 3262,
  [6697] = 3263,
  [6698] = 3264,
  [6699] = 3468,
  [6700] = 3265,
  [6701] = 3266,
  [6702] = 3267,
  [6703] = 3470,
  [6704] = 3459,
  [6705] = 3268,
  [6706] = 3269,
  [6707] = 3272,
  [6708] = 3298,
  [6709] = 3273,
  [6710] = 3274,
  [6711] = 3275,
  [6712] = 3276,
  [6713] = 3277,
  [6714] = 3278,
  [6715] = 3279,
  [6716] = 3280,
  [6717] = 3412,
  [6718] = 3281,
  [6719] = 3282,
  [6720] = 3283,
  [6721] = 3284,
  [6722] = 3285,
  [6723] = 3287,
  [6724] = 3288,
  [6725] = 3289,
  [6726] = 3351,
  [6727] = 3458,
  [6728] = 3460,
  [6729] = 3291,
  [6730] = 3292,
  [6731] = 3293,
  [6732] = 3294,
  [6733] = 3255,
  [6734] = 3296,
  [6735] = 3455,
  [6736] = 3250,
  [6737] = 3297,
  [6738] = 3251,
  [6739] = 3252,
  [6740] = 3253,
  [6741] = 3254,
  [6742] = 3255,
  [6743] = 3260,
  [6744] = 3261,
  [6745] = 3262,
  [6746] = 3263,
  [6747] = 3264,
  [6748] = 3265,
  [6749] = 3266,
  [6750] = 3267,
  [6751] = 3256,
  [6752] = 3268,
  [6753] = 3269,
  [6754] = 3272,
  [6755] = 3298,
  [6756] = 3139,
  [6757] = 3273,
  [6758] = 3274,
  [6759] = 3275,
  [6760] = 3115,
  [6761] = 3115,
  [6762] = 3115,
  [6763] = 3115,
  [6764] = 3276,
  [6765] = 3277,
  [6766] = 3278,
  [6767] = 3279,
  [6768] = 3280,
  [6769] = 3132,
  [6770] = 3281,
  [6771] = 3282,
  [6772] = 3283,
  [6773] = 3284,
  [6774] = 3285,
  [6775] = 3287,
  [6776] = 3133,
  [6777] = 3288,
  [6778] = 3289,
  [6779] = 3290,
  [6780] = 3134,
  [6781] = 3468,
  [6782] = 3291,
  [6783] = 3292,
  [6784] = 3293,
  [6785] = 3294,
  [6786] = 3470,
  [6787] = 3256,
  [6788] = 3471,
  [6789] = 3296,
  [6790] = 3472,
  [6791] = 3250,
  [6792] = 3297,
  [6793] = 3251,
  [6794] = 3299,
  [6795] = 3252,
  [6796] = 3300,
  [6797] = 3253,
  [6798] = 3254,
  [6799] = 3260,
  [6800] = 3261,
  [6801] = 3295,
  [6802] = 3262,
  [6803] = 3263,
  [6804] = 3264,
  [6805] = 3301,
  [6806] = 3265,
  [6807] = 3266,
  [6808] = 3267,
  [6809] = 3268,
  [6810] = 3269,
  [6811] = 3272,
  [6812] = 3298,
  [6813] = 3273,
  [6814] = 3274,
  [6815] = 3275,
  [6816] = 3276,
  [6817] = 3302,
  [6818] = 3277,
  [6819] = 3303,
  [6820] = 3278,
  [6821] = 3279,
  [6822] = 3280,
  [6823] = 3281,
  [6824] = 3282,
  [6825] = 3283,
  [6826] = 3284,
  [6827] = 3285,
  [6828] = 3287,
  [6829] = 3304,
  [6830] = 3288,
  [6831] = 3289,
  [6832] = 3290,
  [6833] = 3291,
  [6834] = 3292,
  [6835] = 3293,
  [6836] = 3294,
  [6837] = 3305,
  [6838] = 3306,
  [6839] = 3307,
  [6840] = 3135,
  [6841] = 3136,
  [6842] = 3296,
  [6843] = 3308,
  [6844] = 3309,
  [6845] = 3310,
  [6846] = 3311,
  [6847] = 3137,
  [6848] = 3297,
  [6849] = 3299,
  [6850] = 3300,
  [6851] = 3261,
  [6852] = 3450,
  [6853] = 3131,
  [6854] = 3301,
  [6855] = 3298,
  [6856] = 3302,
  [6857] = 3303,
  [6858] = 3304,
  [6859] = 3290,
  [6860] = 3451,
  [6861] = 3305,
  [6862] = 3306,
  [6863] = 3307,
  [6864] = 3452,
  [6865] = 3308,
  [6866] = 3309,
  [6867] = 3310,
  [6868] = 3453,
  [6869] = 3311,
  [6870] = 3454,
  [6871] = 3362,
  [6872] = 3299,
  [6873] = 3300,
  [6874] = 3261,
  [6875] = 3301,
  [6876] = 3307,
  [6877] = 3456,
  [6878] = 3459,
  [6879] = 3412,
  [6880] = 3351,
  [6881] = 3302,
  [6882] = 3458,
  [6883] = 3303,
  [6884] = 3460,
  [6885] = 3255,
  [6886] = 3455,
  [6887] = 3304,
  [6888] = 3290,
  [6889] = 3295,
  [6890] = 3374,
  [6891] = 3468,
  [6892] = 3305,
  [6893] = 3306,
  [6894] = 3307,
  [6895] = 3470,
  [6896] = 3256,
  [6897] = 3308,
  [6898] = 3309,
  [6899] = 3310,
  [6900] = 3311,
  [6901] = 3362,
  [6902] = 3140,
  [6903] = 3299,
  [6904] = 3300,
  [6905] = 3455,
  [6906] = 3301,
  [6907] = 3132,
  [6908] = 3133,
  [6909] = 3134,
  [6910] = 3302,
  [6911] = 3303,
  [6912] = 3304,
  [6913] = 3305,
  [6914] = 3306,
  [6915] = 3307,
  [6916] = 3308,
  [6917] = 3309,
  [6918] = 3310,
  [6919] = 3311,
  [6920] = 3135,
  [6921] = 3360,
  [6922] = 3362,
  [6923] = 3456,
  [6924] = 3459,
  [6925] = 3136,
  [6926] = 3412,
  [6927] = 3137,
  [6928] = 3351,
  [6929] = 3458,
  [6930] = 3460,
  [6931] = 3468,
  [6932] = 3470,
  [6933] = 3471,
  [6934] = 3472,
  [6935] = 3360,
  [6936] = 3362,
  [6937] = 3114,
  [6938] = 3471,
  [6939] = 3255,
  [6940] = 3256,
  [6941] = 3472,
  [6942] = 3377,
  [6943] = 3248,
  [6944] = 3261,
  [6945] = 3139,
  [6946] = 3360,
  [6947] = 3295,
  [6948] = 3115,
  [6949] = 3131,
  [6950] = 3360,
  [6951] = 3250,
  [6952] = 3251,
  [6953] = 3252,
  [6954] = 3253,
  [6955] = 3254,
  [6956] = 3260,
  [6957] = 3261,
  [6958] = 3262,
  [6959] = 3263,
  [6960] = 3264,
  [6961] = 3140,
  [6962] = 3265,
  [6963] = 3266,
  [6964] = 3267,
  [6965] = 3268,
  [6966] = 3269,
  [6967] = 3272,
  [6968] = 3273,
  [6969] = 3274,
  [6970] = 3275,
  [6971] = 3276,
  [6972] = 3277,
  [6973] = 3278,
  [6974] = 3279,
  [6975] = 3280,
  [6976] = 3281,
  [6977] = 3282,
  [6978] = 3283,
  [6979] = 3284,
  [6980] = 3285,
  [6981] = 3287,
  [6982] = 3288,
  [6983] = 3289,
  [6984] = 3290,
  [6985] = 3392,
  [6986] = 3291,
  [6987] = 3292,
  [6988] = 3293,
  [6989] = 3294,
  [6990] = 3296,
  [6991] = 3297,
  [6992] = 3455,
  [6993] = 3132,
  [6994] = 3133,
  [6995] = 3450,
  [6996] = 3134,
  [6997] = 3456,
  [6998] = 3459,
  [6999] = 3298,
  [7000] = 3412,
  [7001] = 3351,
  [7002] = 3458,
  [7003] = 3460,
  [7004] = 3255,
  [7005] = 3295,
  [7006] = 3131,
  [7007] = 3451,
  [7008] = 3452,
  [7009] = 3468,
  [7010] = 3453,
  [7011] = 3454,
  [7012] = 3135,
  [7013] = 3136,
  [7014] = 3137,
  [7015] = 3299,
  [7016] = 3300,
  [7017] = 4166,
  [7018] = 3450,
  [7019] = 3301,
  [7020] = 3470,
  [7021] = 3114,
  [7022] = 3302,
  [7023] = 3303,
  [7024] = 3256,
  [7025] = 3285,
  [7026] = 3374,
  [7027] = 3471,
  [7028] = 3472,
  [7029] = 3377,
  [7030] = 3248,
  [7031] = 3392,
  [7032] = 3451,
  [7033] = 3452,
  [7034] = 3453,
  [7035] = 3454,
  [7036] = 3456,
  [7037] = 3459,
  [7038] = 3412,
  [7039] = 3351,
  [7040] = 3458,
  [7041] = 3460,
  [7042] = 3255,
  [7043] = 3455,
  [7044] = 3468,
  [7045] = 3470,
  [7046] = 3256,
  [7047] = 3471,
  [7048] = 3472,
  [7049] = 3265,
  [7050] = 3295,
  [7051] = 3374,
  [7052] = 3965,
  [7053] = 3377,
  [7054] = 3248,
  [7055] = 3392,
  [7056] = 3266,
  [7057] = 3250,
  [7058] = 3251,
  [7059] = 3252,
  [7060] = 3253,
  [7061] = 3254,
  [7062] = 3260,
  [7063] = 3262,
  [7064] = 3263,
  [7065] = 3264,
  [7066] = 3265,
  [7067] = 3266,
  [7068] = 3267,
  [7069] = 3268,
  [7070] = 3269,
  [7071] = 3272,
  [7072] = 3273,
  [7073] = 3274,
  [7074] = 3275,
  [7075] = 3276,
  [7076] = 3277,
  [7077] = 3278,
  [7078] = 3279,
  [7079] = 3280,
  [7080] = 3281,
  [7081] = 3282,
  [7082] = 3283,
  [7083] = 3284,
  [7084] = 3285,
  [7085] = 3287,
  [7086] = 3288,
  [7087] = 3289,
  [7088] = 3291,
  [7089] = 3292,
  [7090] = 3293,
  [7091] = 3294,
  [7092] = 3296,
  [7093] = 3297,
  [7094] = 3300,
  [7095] = 3261,
  [7096] = 3294,
  [7097] = 3298,
  [7098] = 3305,
  [7099] = 3306,
  [7100] = 3307,
  [7101] = 3303,
  [7102] = 3452,
  [7103] = 3455,
  [7104] = 3296,
  [7105] = 3290,
  [7106] = 3308,
  [7107] = 3309,
  [7108] = 3267,
  [7109] = 3310,
  [7110] = 3453,
  [7111] = 3299,
  [7112] = 3311,
  [7113] = 3454,
  [7114] = 3301,
  [7115] = 3360,
  [7116] = 3362,
  [7117] = 3302,
  [7118] = 3456,
  [7119] = 3304,
  [7120] = 3305,
  [7121] = 3306,
  [7122] = 3307,
  [7123] = 3308,
  [7124] = 3309,
  [7125] = 3310,
  [7126] = 3311,
  [7127] = 3459,
  [7128] = 3412,
  [7129] = 3456,
  [7130] = 3459,
  [7131] = 3268,
  [7132] = 3412,
  [7133] = 3351,
  [7134] = 3458,
  [7135] = 3460,
  [7136] = 3269,
  [7137] = 3115,
  [7138] = 3351,
  [7139] = 3468,
  [7140] = 3470,
  [7141] = 3299,
  [7142] = 3471,
  [7143] = 3300,
  [7144] = 3472,
  [7145] = 3261,
  [7146] = 3965,
  [7147] = 3303,
  [7148] = 3471,
  [7149] = 3272,
  [7150] = 3362,
  [7151] = 3298,
  [7152] = 3261,
  [7153] = 3290,
  [7154] = 3290,
  [7155] = 3360,
  [7156] = 3472,
  [7157] = 3299,
  [7158] = 4166,
  [7159] = 3301,
  [7160] = 3458,
  [7161] = 3460,
  [7162] = 3255,
  [7163] = 3273,
  [7164] = 3274,
  [7165] = 3302,
  [7166] = 3275,
  [7167] = 3276,
  [7168] = 3302,
  [7169] = 3277,
  [7170] = 3303,
  [7171] = 3278,
  [7172] = 3279,
  [7173] = 3280,
  [7174] = 3304,
  [7175] = 3305,
  [7176] = 3306,
  [7177] = 3307,
  [7178] = 4161,
  [7179] = 3308,
  [7180] = 3309,
  [7181] = 3310,
  [7182] = 3311,
  [7183] = 3256,
  [7184] = 3300,
  [7185] = 3255,
  [7186] = 3250,
  [7187] = 3455,
  [7188] = 3115,
  [7189] = 3297,
  [7190] = 3295,
  [7191] = 3281,
  [7192] = 3282,
  [7193] = 3450,
  [7194] = 3295,
  [7195] = 3272,
  [7196] = 3298,
  [7197] = 3374,
  [7198] = 3283,
  [7199] = 3374,
  [7200] = 3377,
  [7201] = 3248,
  [7202] = 3251,
  [7203] = 3392,
  [7204] = 3468,
  [7205] = 3273,
  [7206] = 3299,
  [7207] = 3252,
  [7208] = 3253,
  [7209] = 3254,
  [7210] = 3284,
  [7211] = 3274,
  [7212] = 3470,
  [7213] = 3256,
  [7214] = 3260,
  [7215] = 3275,
  [7216] = 3261,
  [7217] = 3471,
  [7218] = 3472,
  [7219] = 3377,
  [7220] = 3248,
  [7221] = 3287,
  [7222] = 3303,
  [7223] = 3360,
  [7224] = 3304,
  [7225] = 3392,
  [7226] = 3288,
  [7227] = 3289,
  [7228] = 3252,
  [7229] = 3262,
  [7230] = 3263,
  [7231] = 3450,
  [7232] = 3374,
  [7233] = 3290,
  [7234] = 3276,
  [7235] = 3302,
  [7236] = 3451,
  [7237] = 3458,
  [7238] = 3277,
  [7239] = 3303,
  [7240] = 3278,
  [7241] = 3269,
  [7242] = 3377,
  [7243] = 3248,
  [7244] = 3292,
  [7245] = 3293,
  [7246] = 3279,
  [7247] = 3280,
  [7248] = 3362,
  [7249] = 3450,
  [7250] = 3392,
  [7251] = 3262,
  [7252] = 3281,
  [7253] = 3452,
  [7254] = 3282,
  [7255] = 3251,
  [7256] = 3294,
  [7257] = 3283,
  [7258] = 3284,
  [7259] = 3285,
  [7260] = 3453,
  [7261] = 3287,
  [7262] = 3304,
  [7263] = 3288,
  [7264] = 3451,
  [7265] = 3305,
  [7266] = 3306,
  [7267] = 3307,
  [7268] = 3264,
  [7269] = 3451,
  [7270] = 3301,
  [7271] = 3289,
  [7272] = 3454,
  [7273] = 3360,
  [7274] = 3456,
  [7275] = 3459,
  [7276] = 3452,
  [7277] = 3412,
  [7278] = 3453,
  [7279] = 3351,
  [7280] = 3454,
  [7281] = 3360,
  [7282] = 3458,
  [7283] = 3263,
  [7284] = 3460,
  [7285] = 3264,
  [7286] = 3301,
  [7287] = 3265,
  [7288] = 3266,
  [7289] = 3267,
  [7290] = 3300,
  [7291] = 3268,
  [7292] = 3269,
  [7293] = 3272,
  [7294] = 3298,
  [7295] = 3291,
  [7296] = 3273,
  [7297] = 3255,
  [7298] = 3451,
  [7299] = 3455,
  [7300] = 3274,
  [7301] = 3275,
  [7302] = 3452,
  [7303] = 3276,
  [7304] = 3302,
  [7305] = 3277,
  [7306] = 3296,
  [7307] = 3308,
  [7308] = 3309,
  [7309] = 3310,
  [7310] = 3455,
  [7311] = 3278,
  [7312] = 3279,
  [7313] = 3311,
  [7314] = 3360,
  [7315] = 3362,
  [7316] = 3280,
  [7317] = 3450,
  [7318] = 3456,
  [7319] = 3250,
  [7320] = 3459,
  [7321] = 3295,
  [7322] = 3300,
  [7323] = 3374,
  [7324] = 3351,
  [7325] = 3297,
  [7326] = 3253,
  [7327] = 3460,
  [7328] = 3251,
  [7329] = 3299,
  [7330] = 3252,
  [7331] = 3300,
  [7332] = 3453,
  [7333] = 3468,
  [7334] = 3454,
  [7335] = 3456,
  [7336] = 3459,
  [7337] = 3412,
  [7338] = 3351,
  [7339] = 3253,
  [7340] = 3458,
  [7341] = 3460,
  [7342] = 3470,
  [7343] = 3281,
  [7344] = 3282,
  [7345] = 3283,
  [7346] = 3284,
  [7347] = 3468,
  [7348] = 3256,
  [7349] = 3285,
  [7350] = 3287,
  [7351] = 3470,
  [7352] = 3304,
  [7353] = 3288,
  [7354] = 3289,
  [7355] = 3290,
  [7356] = 3471,
  [7357] = 3254,
  [7358] = 3472,
  [7359] = 3291,
  [7360] = 3255,
  [7361] = 3292,
  [7362] = 3293,
  [7363] = 3294,
  [7364] = 3305,
  [7365] = 3306,
  [7366] = 3307,
  [7367] = 3250,
  [7368] = 3251,
  [7369] = 3252,
  [7370] = 3253,
  [7371] = 3254,
  [7372] = 3255,
  [7373] = 3260,
  [7374] = 3260,
  [7375] = 3262,
  [7376] = 3263,
  [7377] = 3264,
  [7378] = 3296,
  [7379] = 3265,
  [7380] = 3266,
  [7381] = 3267,
  [7382] = 3256,
  [7383] = 3308,
  [7384] = 3131,
  [7385] = 3268,
  [7386] = 3269,
  [7387] = 3309,
  [7388] = 3272,
  [7389] = 3310,
  [7390] = 3273,
  [7391] = 3274,
  [7392] = 3275,
  [7393] = 3276,
  [7394] = 3277,
  [7395] = 3278,
  [7396] = 3279,
  [7397] = 3280,
  [7398] = 3281,
  [7399] = 3282,
  [7400] = 3283,
  [7401] = 3284,
  [7402] = 3285,
  [7403] = 3287,
  [7404] = 3288,
  [7405] = 3289,
  [7406] = 3311,
  [7407] = 3132,
  [7408] = 3133,
  [7409] = 3134,
  [7410] = 3291,
  [7411] = 3292,
  [7412] = 3293,
  [7413] = 3294,
  [7414] = 3135,
  [7415] = 3136,
  [7416] = 3137,
  [7417] = 3296,
  [7418] = 3362,
  [7419] = 3250,
  [7420] = 3471,
  [7421] = 3115,
  [7422] = 3297,
  [7423] = 3297,
  [7424] = 3261,
  [7425] = 3295,
  [7426] = 3251,
  [7427] = 3299,
  [7428] = 3252,
  [7429] = 3253,
  [7430] = 3254,
  [7431] = 3298,
  [7432] = 3260,
  [7433] = 3261,
  [7434] = 3472,
  [7435] = 3377,
  [7436] = 3248,
  [7437] = 3292,
  [7438] = 3262,
  [7439] = 3263,
  [7440] = 3264,
  [7441] = 3301,
  [7442] = 3265,
  [7443] = 3139,
  [7444] = 3266,
  [7445] = 3267,
  [7446] = 3268,
  [7447] = 3269,
  [7448] = 3272,
  [7449] = 3298,
  [7450] = 3140,
  [7451] = 3273,
  [7452] = 3274,
  [7453] = 3275,
  [7454] = 3276,
  [7455] = 3302,
  [7456] = 3277,
  [7457] = 3278,
  [7458] = 3279,
  [7459] = 3280,
  [7460] = 3303,
  [7461] = 3392,
  [7462] = 3965,
  [7463] = 3293,
  [7464] = 3451,
  [7465] = 3450,
  [7466] = 3281,
  [7467] = 3282,
  [7468] = 3254,
  [7469] = 3283,
  [7470] = 3284,
  [7471] = 3285,
  [7472] = 3287,
  [7473] = 3304,
  [7474] = 3288,
  [7475] = 3289,
  [7476] = 3262,
  [7477] = 3263,
  [7478] = 3290,
  [7479] = 3452,
  [7480] = 3291,
  [7481] = 3260,
  [7482] = 3264,
  [7483] = 3455,
  [7484] = 3468,
  [7485] = 3301,
  [7486] = 3453,
  [7487] = 3454,
  [7488] = 3360,
  [7489] = 3265,
  [7490] = 3266,
  [7491] = 3267,
  [7492] = 3470,
  [7493] = 3256,
  [7494] = 3292,
  [7495] = 3412,
  [7496] = 3293,
  [7497] = 3294,
  [7498] = 3305,
  [7499] = 3306,
  [7500] = 3307,
  [7501] = 3362,
  [7502] = 3458,
  [7503] = 3268,
  [7504] = 3296,
  [7505] = 3308,
  [7506] = 3309,
  [7507] = 3455,
  [7508] = 3310,
  [7509] = 3311,
  [7510] = 3362,
  [7511] = 3250,
  [7512] = 3412,
  [7513] = 3450,
  [7514] = 3115,
  [7515] = 3295,
  [7516] = 3297,
  [7517] = 3291,
  [7518] = 3268,
  [7519] = 3309,
  [7520] = 3133,
  [7521] = 3311,
  [7522] = 3310,
  [7523] = 3311,
  [7524] = 3134,
  [7525] = 3291,
  [7526] = 3305,
  [7527] = 3292,
  [7528] = 3360,
  [7529] = 3362,
  [7530] = 3293,
  [7531] = 3294,
  [7532] = 3135,
  [7533] = 3136,
  [7534] = 3137,
  [7535] = 3296,
  [7536] = 3306,
  [7537] = 3297,
  [7538] = 3307,
  [7539] = 3306,
  [7540] = 3308,
  [7541] = 3309,
  [7542] = 3300,
  [7543] = 3310,
  [7544] = 3311,
  [7545] = 3965,
  [7546] = 3281,
  [7547] = 3282,
  [7548] = 3283,
  [7549] = 3268,
  [7550] = 3450,
  [7551] = 3284,
  [7552] = 3451,
  [7553] = 3452,
  [7554] = 7554,
  [7555] = 3374,
  [7556] = 3453,
  [7557] = 3454,
  [7558] = 3455,
  [7559] = 3965,
  [7560] = 3302,
  [7561] = 3412,
  [7562] = 3458,
  [7563] = 3471,
  [7564] = 3472,
  [7565] = 4161,
  [7566] = 3272,
  [7567] = 3377,
  [7568] = 3248,
  [7569] = 3456,
  [7570] = 3459,
  [7571] = 3412,
  [7572] = 3351,
  [7573] = 3392,
  [7574] = 3298,
  [7575] = 3965,
  [7576] = 3460,
  [7577] = 3255,
  [7578] = 3300,
  [7579] = 3299,
  [7580] = 3468,
  [7581] = 3300,
  [7582] = 3470,
  [7583] = 3256,
  [7584] = 3965,
  [7585] = 3471,
  [7586] = 3269,
  [7587] = 3303,
  [7588] = 3273,
  [7589] = 7589,
  [7590] = 3274,
  [7591] = 3965,
  [7592] = 3275,
  [7593] = 3301,
  [7594] = 3303,
  [7595] = 3139,
  [7596] = 7596,
  [7597] = 3250,
  [7598] = 3285,
  [7599] = 3297,
  [7600] = 3303,
  [7601] = 3302,
  [7602] = 3131,
  [7603] = 3251,
  [7604] = 3303,
  [7605] = 4166,
  [7606] = 3276,
  [7607] = 7607,
  [7608] = 7608,
  [7609] = 3299,
  [7610] = 3252,
  [7611] = 3253,
  [7612] = 3254,
  [7613] = 3260,
  [7614] = 3295,
  [7615] = 7615,
  [7616] = 4161,
  [7617] = 7554,
  [7618] = 7589,
  [7619] = 3412,
  [7620] = 3262,
  [7621] = 3263,
  [7622] = 3299,
  [7623] = 3264,
  [7624] = 3301,
  [7625] = 3265,
  [7626] = 3266,
  [7627] = 3267,
  [7628] = 3131,
  [7629] = 3307,
  [7630] = 3308,
  [7631] = 3272,
  [7632] = 3298,
  [7633] = 3471,
  [7634] = 3273,
  [7635] = 3274,
  [7636] = 3302,
  [7637] = 3275,
  [7638] = 3287,
  [7639] = 3276,
  [7640] = 3302,
  [7641] = 3277,
  [7642] = 3304,
  [7643] = 3305,
  [7644] = 3306,
  [7645] = 3307,
  [7646] = 3278,
  [7647] = 3279,
  [7648] = 3280,
  [7649] = 3308,
  [7650] = 3309,
  [7651] = 3310,
  [7652] = 3311,
  [7653] = 3277,
  [7654] = 4166,
  [7655] = 3278,
  [7656] = 7596,
  [7657] = 3965,
  [7658] = 3281,
  [7659] = 3282,
  [7660] = 3283,
  [7661] = 3284,
  [7662] = 3285,
  [7663] = 3287,
  [7664] = 3304,
  [7665] = 3299,
  [7666] = 4166,
  [7667] = 3374,
  [7668] = 3300,
  [7669] = 3288,
  [7670] = 3140,
  [7671] = 3289,
  [7672] = 3304,
  [7673] = 3377,
  [7674] = 3248,
  [7675] = 3279,
  [7676] = 3392,
  [7677] = 3301,
  [7678] = 3132,
  [7679] = 3280,
  [7680] = 3133,
  [7681] = 3134,
  [7682] = 3291,
  [7683] = 4161,
  [7684] = 7607,
  [7685] = 7608,
  [7686] = 3288,
  [7687] = 3292,
  [7688] = 3293,
  [7689] = 3294,
  [7690] = 3305,
  [7691] = 3306,
  [7692] = 3307,
  [7693] = 3250,
  [7694] = 3135,
  [7695] = 3136,
  [7696] = 3251,
  [7697] = 3137,
  [7698] = 3252,
  [7699] = 3253,
  [7700] = 3254,
  [7701] = 3260,
  [7702] = 7615,
  [7703] = 3965,
  [7704] = 3262,
  [7705] = 3263,
  [7706] = 3264,
  [7707] = 3289,
  [7708] = 3304,
  [7709] = 3296,
  [7710] = 3308,
  [7711] = 3309,
  [7712] = 3132,
  [7713] = 3265,
  [7714] = 3310,
  [7715] = 3266,
  [7716] = 3267,
  [7717] = 3305,
  [7718] = 3301,
  [7719] = 3965,
  [7720] = 7596,
  [7721] = 7721,
  [7722] = 7607,
  [7723] = 7723,
  [7724] = 7608,
  [7725] = 3470,
  [7726] = 3135,
  [7727] = 7721,
  [7728] = 3136,
  [7729] = 3137,
  [7730] = 5471,
  [7731] = 3296,
  [7732] = 3256,
  [7733] = 4161,
  [7734] = 3472,
  [7735] = 7721,
  [7736] = 7736,
  [7737] = 7737,
  [7738] = 5513,
  [7739] = 4166,
  [7740] = 7740,
  [7741] = 4166,
  [7742] = 7742,
  [7743] = 3450,
  [7744] = 4161,
  [7745] = 3965,
  [7746] = 7721,
  [7747] = 5655,
  [7748] = 3278,
  [7749] = 3295,
  [7750] = 3456,
  [7751] = 7751,
  [7752] = 7752,
  [7753] = 7753,
  [7754] = 7754,
  [7755] = 7755,
  [7756] = 7756,
  [7757] = 7757,
  [7758] = 3459,
  [7759] = 7721,
  [7760] = 3374,
  [7761] = 3351,
  [7762] = 4161,
  [7763] = 3460,
  [7764] = 3255,
  [7765] = 7765,
  [7766] = 3450,
  [7767] = 3279,
  [7768] = 7554,
  [7769] = 3468,
  [7770] = 7770,
  [7771] = 7721,
  [7772] = 3470,
  [7773] = 3256,
  [7774] = 7589,
  [7775] = 7775,
  [7776] = 3284,
  [7777] = 3275,
  [7778] = 3273,
  [7779] = 7721,
  [7780] = 5655,
  [7781] = 7781,
  [7782] = 5599,
  [7783] = 3299,
  [7784] = 7721,
  [7785] = 3291,
  [7786] = 5513,
  [7787] = 3468,
  [7788] = 5583,
  [7789] = 5469,
  [7790] = 7740,
  [7791] = 7791,
  [7792] = 7754,
  [7793] = 5600,
  [7794] = 3300,
  [7795] = 7795,
  [7796] = 7796,
  [7797] = 7797,
  [7798] = 3451,
  [7799] = 3377,
  [7800] = 7800,
  [7801] = 7801,
  [7802] = 3248,
  [7803] = 7721,
  [7804] = 7721,
  [7805] = 3292,
  [7806] = 3452,
  [7807] = 3360,
  [7808] = 3301,
  [7809] = 3392,
  [7810] = 3453,
  [7811] = 3454,
  [7812] = 7770,
  [7813] = 7791,
  [7814] = 3362,
  [7815] = 4161,
  [7816] = 7721,
  [7817] = 3450,
  [7818] = 7818,
  [7819] = 7819,
  [7820] = 7820,
  [7821] = 7821,
  [7822] = 7822,
  [7823] = 3451,
  [7824] = 3250,
  [7825] = 3452,
  [7826] = 3453,
  [7827] = 3454,
  [7828] = 7721,
  [7829] = 3374,
  [7830] = 7723,
  [7831] = 3377,
  [7832] = 7721,
  [7833] = 7721,
  [7834] = 7834,
  [7835] = 3280,
  [7836] = 7721,
  [7837] = 3274,
  [7838] = 3248,
  [7839] = 5687,
  [7840] = 7742,
  [7841] = 3140,
  [7842] = 7721,
  [7843] = 3281,
  [7844] = 3302,
  [7845] = 3303,
  [7846] = 3458,
  [7847] = 4161,
  [7848] = 3297,
  [7849] = 7849,
  [7850] = 3304,
  [7851] = 3455,
  [7852] = 7721,
  [7853] = 5613,
  [7854] = 3295,
  [7855] = 3965,
  [7856] = 7723,
  [7857] = 7721,
  [7858] = 3293,
  [7859] = 3294,
  [7860] = 7860,
  [7861] = 7751,
  [7862] = 3472,
  [7863] = 3295,
  [7864] = 3452,
  [7865] = 4166,
  [7866] = 7866,
  [7867] = 7721,
  [7868] = 7868,
  [7869] = 7721,
  [7870] = 7870,
  [7871] = 7871,
  [7872] = 3288,
  [7873] = 7873,
  [7874] = 3392,
  [7875] = 3282,
  [7876] = 7781,
  [7877] = 7877,
  [7878] = 7615,
  [7879] = 7818,
  [7880] = 4166,
  [7881] = 7877,
  [7882] = 3305,
  [7883] = 4166,
  [7884] = 3377,
  [7885] = 3456,
  [7886] = 3459,
  [7887] = 3306,
  [7888] = 4166,
  [7889] = 3351,
  [7890] = 3248,
  [7891] = 3460,
  [7892] = 3269,
  [7893] = 3965,
  [7894] = 7736,
  [7895] = 7737,
  [7896] = 7871,
  [7897] = 7752,
  [7898] = 7753,
  [7899] = 7755,
  [7900] = 7756,
  [7901] = 7757,
  [7902] = 3307,
  [7903] = 3453,
  [7904] = 3289,
  [7905] = 3298,
  [7906] = 4161,
  [7907] = 3456,
  [7908] = 3468,
  [7909] = 3470,
  [7910] = 3965,
  [7911] = 3459,
  [7912] = 3351,
  [7913] = 3251,
  [7914] = 7914,
  [7915] = 3460,
  [7916] = 3132,
  [7917] = 7795,
  [7918] = 7796,
  [7919] = 3468,
  [7920] = 7797,
  [7921] = 3252,
  [7922] = 3470,
  [7923] = 7721,
  [7924] = 5667,
  [7925] = 3283,
  [7926] = 3253,
  [7927] = 7800,
  [7928] = 3471,
  [7929] = 3254,
  [7930] = 7801,
  [7931] = 3260,
  [7932] = 7721,
  [7933] = 3255,
  [7934] = 3450,
  [7935] = 3139,
  [7936] = 3262,
  [7937] = 3263,
  [7938] = 3264,
  [7939] = 3256,
  [7940] = 4161,
  [7941] = 3265,
  [7942] = 7873,
  [7943] = 5599,
  [7944] = 5600,
  [7945] = 3266,
  [7946] = 3267,
  [7947] = 7868,
  [7948] = 3965,
  [7949] = 3131,
  [7950] = 3451,
  [7951] = 3374,
  [7952] = 3139,
  [7953] = 3268,
  [7954] = 3452,
  [7955] = 5687,
  [7956] = 5583,
  [7957] = 5469,
  [7958] = 3276,
  [7959] = 7765,
  [7960] = 3269,
  [7961] = 3453,
  [7962] = 3454,
  [7963] = 3308,
  [7964] = 3455,
  [7965] = 5613,
  [7966] = 3392,
  [7967] = 5533,
  [7968] = 3309,
  [7969] = 3310,
  [7970] = 7870,
  [7971] = 7819,
  [7972] = 7820,
  [7973] = 5667,
  [7974] = 7821,
  [7975] = 3285,
  [7976] = 4166,
  [7977] = 3456,
  [7978] = 7822,
  [7979] = 3458,
  [7980] = 3374,
  [7981] = 3412,
  [7982] = 3458,
  [7983] = 3295,
  [7984] = 3287,
  [7985] = 3459,
  [7986] = 3140,
  [7987] = 7775,
  [7988] = 3255,
  [7989] = 3471,
  [7990] = 7723,
  [7991] = 3454,
  [7992] = 3133,
  [7993] = 3272,
  [7994] = 3472,
  [7995] = 3277,
  [7996] = 3351,
  [7997] = 3374,
  [7998] = 7866,
  [7999] = 3311,
  [8000] = 3377,
  [8001] = 3460,
  [8002] = 7834,
  [8003] = 3248,
  [8004] = 3392,
  [8005] = 3451,
  [8006] = 3255,
  [8007] = 3455,
  [8008] = 3256,
  [8009] = 3134,
  [8010] = 3412,
  [8011] = 7849,
  [8012] = 3392,
  [8013] = 3377,
  [8014] = 3248,
  [8015] = 7860,
  [8016] = 5468,
  [8017] = 7914,
  [8018] = 4166,
  [8019] = 5599,
  [8020] = 7870,
  [8021] = 4166,
  [8022] = 8022,
  [8023] = 8022,
  [8024] = 8024,
  [8025] = 7800,
  [8026] = 5600,
  [8027] = 8027,
  [8028] = 7742,
  [8029] = 7877,
  [8030] = 7737,
  [8031] = 8031,
  [8032] = 8022,
  [8033] = 8024,
  [8034] = 8027,
  [8035] = 7795,
  [8036] = 8022,
  [8037] = 7819,
  [8038] = 7791,
  [8039] = 8022,
  [8040] = 7781,
  [8041] = 7596,
  [8042] = 4161,
  [8043] = 8024,
  [8044] = 8024,
  [8045] = 4166,
  [8046] = 8046,
  [8047] = 7801,
  [8048] = 8022,
  [8049] = 8024,
  [8050] = 8046,
  [8051] = 3450,
  [8052] = 7740,
  [8053] = 8022,
  [8054] = 3295,
  [8055] = 8024,
  [8056] = 8046,
  [8057] = 8046,
  [8058] = 8046,
  [8059] = 3374,
  [8060] = 8046,
  [8061] = 8046,
  [8062] = 8022,
  [8063] = 8024,
  [8064] = 4161,
  [8065] = 4161,
  [8066] = 3454,
  [8067] = 7849,
  [8068] = 8046,
  [8069] = 8046,
  [8070] = 7751,
  [8071] = 8024,
  [8072] = 7820,
  [8073] = 8046,
  [8074] = 3458,
  [8075] = 8022,
  [8076] = 8024,
  [8077] = 7821,
  [8078] = 8022,
  [8079] = 5583,
  [8080] = 3460,
  [8081] = 7755,
  [8082] = 7822,
  [8083] = 8046,
  [8084] = 3472,
  [8085] = 7914,
  [8086] = 7752,
  [8087] = 3451,
  [8088] = 8046,
  [8089] = 8022,
  [8090] = 8024,
  [8091] = 8022,
  [8092] = 8024,
  [8093] = 8024,
  [8094] = 8031,
  [8095] = 8027,
  [8096] = 3470,
  [8097] = 5687,
  [8098] = 5469,
  [8099] = 4161,
  [8100] = 8046,
  [8101] = 8027,
  [8102] = 8024,
  [8103] = 3377,
  [8104] = 3248,
  [8105] = 7736,
  [8106] = 7754,
  [8107] = 8046,
  [8108] = 3456,
  [8109] = 4161,
  [8110] = 7607,
  [8111] = 7608,
  [8112] = 3468,
  [8113] = 7797,
  [8114] = 8022,
  [8115] = 8022,
  [8116] = 3351,
  [8117] = 8022,
  [8118] = 8024,
  [8119] = 8024,
  [8120] = 7770,
  [8121] = 4166,
  [8122] = 7589,
  [8123] = 7753,
  [8124] = 3412,
  [8125] = 8024,
  [8126] = 8022,
  [8127] = 8024,
  [8128] = 3452,
  [8129] = 4785,
  [8130] = 8022,
  [8131] = 8024,
  [8132] = 8046,
  [8133] = 8027,
  [8134] = 8046,
  [8135] = 4166,
  [8136] = 3255,
  [8137] = 8046,
  [8138] = 7796,
  [8139] = 7775,
  [8140] = 8022,
  [8141] = 8022,
  [8142] = 8024,
  [8143] = 5613,
  [8144] = 7756,
  [8145] = 7554,
  [8146] = 8046,
  [8147] = 4161,
  [8148] = 5655,
  [8149] = 8022,
  [8150] = 3459,
  [8151] = 7615,
  [8152] = 8024,
  [8153] = 7757,
  [8154] = 7834,
  [8155] = 5667,
  [8156] = 8022,
  [8157] = 3455,
  [8158] = 8024,
  [8159] = 8046,
  [8160] = 4166,
  [8161] = 8022,
  [8162] = 3392,
  [8163] = 5513,
  [8164] = 8024,
  [8165] = 4789,
  [8166] = 3471,
  [8167] = 4788,
  [8168] = 7868,
  [8169] = 3453,
  [8170] = 8046,
  [8171] = 8046,
  [8172] = 7765,
  [8173] = 8027,
  [8174] = 8046,
  [8175] = 3256,
  [8176] = 3281,
  [8177] = 8177,
  [8178] = 8178,
  [8179] = 8179,
  [8180] = 8180,
  [8181] = 8181,
  [8182] = 8182,
  [8183] = 8183,
  [8184] = 8184,
  [8185] = 8185,
  [8186] = 3455,
  [8187] = 8187,
  [8188] = 3295,
  [8189] = 8189,
  [8190] = 7742,
  [8191] = 8191,
  [8192] = 8192,
  [8193] = 8193,
  [8194] = 3290,
  [8195] = 8195,
  [8196] = 7819,
  [8197] = 7820,
  [8198] = 7821,
  [8199] = 7822,
  [8200] = 8200,
  [8201] = 3456,
  [8202] = 3459,
  [8203] = 3362,
  [8204] = 3412,
  [8205] = 3298,
  [8206] = 3351,
  [8207] = 3458,
  [8208] = 3460,
  [8209] = 8209,
  [8210] = 3468,
  [8211] = 3470,
  [8212] = 8184,
  [8213] = 8185,
  [8214] = 8187,
  [8215] = 3471,
  [8216] = 3472,
  [8217] = 5655,
  [8218] = 8218,
  [8219] = 8184,
  [8220] = 8185,
  [8221] = 4860,
  [8222] = 8222,
  [8223] = 8187,
  [8224] = 8224,
  [8225] = 8222,
  [8226] = 8181,
  [8227] = 3250,
  [8228] = 8228,
  [8229] = 8184,
  [8230] = 8185,
  [8231] = 8187,
  [8232] = 3255,
  [8233] = 8233,
  [8234] = 3299,
  [8235] = 8184,
  [8236] = 8185,
  [8237] = 8187,
  [8238] = 3256,
  [8239] = 8184,
  [8240] = 8185,
  [8241] = 8187,
  [8242] = 5513,
  [8243] = 8177,
  [8244] = 7834,
  [8245] = 8184,
  [8246] = 8185,
  [8247] = 8187,
  [8248] = 8184,
  [8249] = 8185,
  [8250] = 3251,
  [8251] = 8187,
  [8252] = 8184,
  [8253] = 8185,
  [8254] = 8187,
  [8255] = 3252,
  [8256] = 8222,
  [8257] = 8184,
  [8258] = 8185,
  [8259] = 7849,
  [8260] = 8187,
  [8261] = 8177,
  [8262] = 3295,
  [8263] = 3374,
  [8264] = 8264,
  [8265] = 3253,
  [8266] = 8184,
  [8267] = 8185,
  [8268] = 8187,
  [8269] = 3254,
  [8270] = 3260,
  [8271] = 8271,
  [8272] = 8184,
  [8273] = 8185,
  [8274] = 3377,
  [8275] = 3248,
  [8276] = 8187,
  [8277] = 3139,
  [8278] = 8184,
  [8279] = 8185,
  [8280] = 3392,
  [8281] = 8187,
  [8282] = 8187,
  [8283] = 8184,
  [8284] = 8185,
  [8285] = 8187,
  [8286] = 3450,
  [8287] = 3374,
  [8288] = 8288,
  [8289] = 8184,
  [8290] = 8185,
  [8291] = 7736,
  [8292] = 8187,
  [8293] = 7737,
  [8294] = 3301,
  [8295] = 8177,
  [8296] = 8184,
  [8297] = 8185,
  [8298] = 8187,
  [8299] = 8184,
  [8300] = 8185,
  [8301] = 3377,
  [8302] = 8187,
  [8303] = 3248,
  [8304] = 8184,
  [8305] = 8185,
  [8306] = 8187,
  [8307] = 3392,
  [8308] = 7870,
  [8309] = 8185,
  [8310] = 8187,
  [8311] = 8191,
  [8312] = 3451,
  [8313] = 8313,
  [8314] = 8184,
  [8315] = 8185,
  [8316] = 8187,
  [8317] = 3452,
  [8318] = 5583,
  [8319] = 5469,
  [8320] = 8184,
  [8321] = 8185,
  [8322] = 7765,
  [8323] = 8187,
  [8324] = 3453,
  [8325] = 3140,
  [8326] = 3454,
  [8327] = 3262,
  [8328] = 3263,
  [8329] = 3264,
  [8330] = 8330,
  [8331] = 3265,
  [8332] = 3266,
  [8333] = 8333,
  [8334] = 8334,
  [8335] = 7775,
  [8336] = 3267,
  [8337] = 3131,
  [8338] = 7781,
  [8339] = 3268,
  [8340] = 3269,
  [8341] = 3272,
  [8342] = 3273,
  [8343] = 3274,
  [8344] = 3275,
  [8345] = 3276,
  [8346] = 3277,
  [8347] = 7740,
  [8348] = 7754,
  [8349] = 3458,
  [8350] = 3278,
  [8351] = 7752,
  [8352] = 3279,
  [8353] = 7753,
  [8354] = 7755,
  [8355] = 3360,
  [8356] = 3280,
  [8357] = 3455,
  [8358] = 7756,
  [8359] = 7757,
  [8360] = 3300,
  [8361] = 5667,
  [8362] = 3282,
  [8363] = 3283,
  [8364] = 3284,
  [8365] = 3472,
  [8366] = 3285,
  [8367] = 3287,
  [8368] = 3288,
  [8369] = 3289,
  [8370] = 8184,
  [8371] = 3302,
  [8372] = 3132,
  [8373] = 3133,
  [8374] = 8185,
  [8375] = 3134,
  [8376] = 3291,
  [8377] = 7751,
  [8378] = 7795,
  [8379] = 7796,
  [8380] = 7797,
  [8381] = 7800,
  [8382] = 7801,
  [8383] = 3303,
  [8384] = 3456,
  [8385] = 3459,
  [8386] = 3351,
  [8387] = 3460,
  [8388] = 5599,
  [8389] = 5600,
  [8390] = 3304,
  [8391] = 3450,
  [8392] = 3374,
  [8393] = 8177,
  [8394] = 3261,
  [8395] = 3468,
  [8396] = 3292,
  [8397] = 3470,
  [8398] = 3305,
  [8399] = 3306,
  [8400] = 3307,
  [8401] = 3293,
  [8402] = 3294,
  [8403] = 3377,
  [8404] = 3248,
  [8405] = 3135,
  [8406] = 3136,
  [8407] = 7770,
  [8408] = 3137,
  [8409] = 8222,
  [8410] = 5613,
  [8411] = 3392,
  [8412] = 7791,
  [8413] = 3308,
  [8414] = 3309,
  [8415] = 3296,
  [8416] = 8416,
  [8417] = 3310,
  [8418] = 7877,
  [8419] = 3451,
  [8420] = 3311,
  [8421] = 7914,
  [8422] = 3452,
  [8423] = 3453,
  [8424] = 3454,
  [8425] = 8425,
  [8426] = 8426,
  [8427] = 8222,
  [8428] = 3255,
  [8429] = 3297,
  [8430] = 8430,
  [8431] = 8431,
  [8432] = 3256,
  [8433] = 8433,
  [8434] = 5687,
  [8435] = 7868,
  [8436] = 8184,
  [8437] = 3472,
  [8438] = 8438,
  [8439] = 8439,
  [8440] = 8416,
  [8441] = 8441,
  [8442] = 8442,
  [8443] = 8425,
  [8444] = 8426,
  [8445] = 8445,
  [8446] = 8446,
  [8447] = 8447,
  [8448] = 8431,
  [8449] = 8449,
  [8450] = 8271,
  [8451] = 8430,
  [8452] = 8178,
  [8453] = 8453,
  [8454] = 8454,
  [8455] = 8195,
  [8456] = 8179,
  [8457] = 8457,
  [8458] = 8264,
  [8459] = 8445,
  [8460] = 8447,
  [8461] = 8461,
  [8462] = 8433,
  [8463] = 8183,
  [8464] = 8192,
  [8465] = 8189,
  [8466] = 8461,
  [8467] = 3455,
  [8468] = 8313,
  [8469] = 8180,
  [8470] = 8447,
  [8471] = 8430,
  [8472] = 8182,
  [8473] = 8228,
  [8474] = 8454,
  [8475] = 8178,
  [8476] = 5533,
  [8477] = 8461,
  [8478] = 8192,
  [8479] = 8479,
  [8480] = 8195,
  [8481] = 8481,
  [8482] = 8179,
  [8483] = 8264,
  [8484] = 8200,
  [8485] = 8433,
  [8486] = 8313,
  [8487] = 8487,
  [8488] = 8488,
  [8489] = 8193,
  [8490] = 8330,
  [8491] = 3412,
  [8492] = 3458,
  [8493] = 8493,
  [8494] = 8494,
  [8495] = 8495,
  [8496] = 8496,
  [8497] = 8445,
  [8498] = 8498,
  [8499] = 8499,
  [8500] = 8500,
  [8501] = 8501,
  [8502] = 5468,
  [8503] = 8457,
  [8504] = 8438,
  [8505] = 8441,
  [8506] = 3471,
  [8507] = 8442,
  [8508] = 8224,
  [8509] = 8209,
  [8510] = 8189,
  [8511] = 8333,
  [8512] = 8416,
  [8513] = 8209,
  [8514] = 8200,
  [8515] = 8228,
  [8516] = 8516,
  [8517] = 8445,
  [8518] = 8218,
  [8519] = 8425,
  [8520] = 8520,
  [8521] = 8224,
  [8522] = 8499,
  [8523] = 8523,
  [8524] = 8446,
  [8525] = 8525,
  [8526] = 8526,
  [8527] = 8479,
  [8528] = 8218,
  [8529] = 8453,
  [8530] = 5471,
  [8531] = 8233,
  [8532] = 8481,
  [8533] = 8487,
  [8534] = 8534,
  [8535] = 8330,
  [8536] = 8523,
  [8537] = 8498,
  [8538] = 8538,
  [8539] = 8525,
  [8540] = 8526,
  [8541] = 8426,
  [8542] = 8488,
  [8543] = 8233,
  [8544] = 8544,
  [8545] = 8545,
  [8546] = 8493,
  [8547] = 8494,
  [8548] = 8548,
  [8549] = 8495,
  [8550] = 8550,
  [8551] = 8551,
  [8552] = 8183,
  [8553] = 8553,
  [8554] = 8554,
  [8555] = 8553,
  [8556] = 8544,
  [8557] = 8180,
  [8558] = 8439,
  [8559] = 8431,
  [8560] = 8182,
  [8561] = 8461,
  [8562] = 8496,
  [8563] = 8333,
  [8564] = 3295,
  [8565] = 8548,
  [8566] = 8449,
  [8567] = 8500,
  [8568] = 8447,
  [8569] = 8271,
  [8570] = 8193,
  [8571] = 8446,
  [8572] = 8481,
  [8573] = 8487,
  [8574] = 8493,
  [8575] = 8494,
  [8576] = 8495,
  [8577] = 8496,
  [8578] = 8500,
  [8579] = 8439,
  [8580] = 8442,
  [8581] = 8523,
  [8582] = 8525,
  [8583] = 8526,
  [8584] = 8488,
  [8585] = 8494,
  [8586] = 8438,
  [8587] = 8523,
  [8588] = 8525,
  [8589] = 8526,
  [8590] = 8479,
  [8591] = 8481,
  [8592] = 8487,
  [8593] = 8488,
  [8594] = 8441,
  [8595] = 8544,
  [8596] = 8493,
  [8597] = 8442,
  [8598] = 8495,
  [8599] = 8548,
  [8600] = 8494,
  [8601] = 8495,
  [8602] = 8496,
  [8603] = 8500,
  [8604] = 8438,
  [8605] = 8441,
  [8606] = 8442,
  [8607] = 8445,
  [8608] = 8446,
  [8609] = 8544,
  [8610] = 8493,
  [8611] = 8548,
  [8612] = 8523,
  [8613] = 8496,
  [8614] = 8614,
  [8615] = 8439,
  [8616] = 8461,
  [8617] = 8445,
  [8618] = 8544,
  [8619] = 8548,
  [8620] = 8525,
  [8621] = 8526,
  [8622] = 8498,
  [8623] = 8461,
  [8624] = 8499,
  [8625] = 8525,
  [8626] = 8526,
  [8627] = 8479,
  [8628] = 8481,
  [8629] = 8457,
  [8630] = 8487,
  [8631] = 8493,
  [8632] = 8494,
  [8633] = 8495,
  [8634] = 8496,
  [8635] = 8500,
  [8636] = 8438,
  [8637] = 8441,
  [8638] = 8442,
  [8639] = 8445,
  [8640] = 8446,
  [8641] = 8498,
  [8642] = 8457,
  [8643] = 8461,
  [8644] = 8500,
  [8645] = 8499,
  [8646] = 8439,
  [8647] = 8614,
  [8648] = 8544,
  [8649] = 8548,
  [8650] = 8438,
  [8651] = 3412,
  [8652] = 8461,
  [8653] = 8488,
  [8654] = 8445,
  [8655] = 8441,
  [8656] = 8446,
  [8657] = 8498,
  [8658] = 8457,
  [8659] = 3471,
  [8660] = 8498,
  [8661] = 8488,
  [8662] = 8479,
  [8663] = 8457,
  [8664] = 3965,
  [8665] = 8439,
  [8666] = 8479,
  [8667] = 8487,
  [8668] = 8481,
  [8669] = 8523,
  [8670] = 8670,
  [8671] = 8671,
  [8672] = 8671,
  [8673] = 8673,
  [8674] = 8498,
  [8675] = 8671,
  [8676] = 8671,
  [8677] = 8673,
  [8678] = 8457,
  [8679] = 8671,
  [8680] = 8446,
  [8681] = 8671,
  [8682] = 8673,
  [8683] = 8479,
  [8684] = 8673,
  [8685] = 8673,
  [8686] = 8671,
  [8687] = 8673,
  [8688] = 8671,
  [8689] = 8544,
  [8690] = 8671,
  [8691] = 4161,
  [8692] = 8673,
  [8693] = 8614,
  [8694] = 8614,
  [8695] = 8695,
  [8696] = 8673,
  [8697] = 8697,
  [8698] = 8548,
  [8699] = 8614,
  [8700] = 8488,
  [8701] = 8701,
  [8702] = 8673,
  [8703] = 8703,
  [8704] = 8670,
  [8705] = 8671,
  [8706] = 8670,
  [8707] = 8673,
  [8708] = 8701,
  [8709] = 8671,
  [8710] = 3412,
  [8711] = 8711,
  [8712] = 8671,
  [8713] = 8481,
  [8714] = 8703,
  [8715] = 8487,
  [8716] = 8673,
  [8717] = 8671,
  [8718] = 8671,
  [8719] = 8488,
  [8720] = 8670,
  [8721] = 8673,
  [8722] = 8673,
  [8723] = 8493,
  [8724] = 8494,
  [8725] = 8495,
  [8726] = 8496,
  [8727] = 8439,
  [8728] = 8500,
  [8729] = 8457,
  [8730] = 8488,
  [8731] = 8498,
  [8732] = 8732,
  [8733] = 8438,
  [8734] = 8671,
  [8735] = 8670,
  [8736] = 8441,
  [8737] = 3295,
  [8738] = 8695,
  [8739] = 8498,
  [8740] = 8673,
  [8741] = 8670,
  [8742] = 8673,
  [8743] = 8743,
  [8744] = 8673,
  [8745] = 8671,
  [8746] = 7607,
  [8747] = 8671,
  [8748] = 7608,
  [8749] = 8670,
  [8750] = 8673,
  [8751] = 8670,
  [8752] = 8671,
  [8753] = 8439,
  [8754] = 8457,
  [8755] = 8523,
  [8756] = 8525,
  [8757] = 8526,
  [8758] = 7554,
  [8759] = 8671,
  [8760] = 8673,
  [8761] = 8457,
  [8762] = 4166,
  [8763] = 3458,
  [8764] = 8673,
  [8765] = 8711,
  [8766] = 8442,
  [8767] = 8479,
  [8768] = 8673,
  [8769] = 8671,
  [8770] = 8670,
  [8771] = 3471,
  [8772] = 8498,
  [8773] = 8697,
  [8774] = 8481,
  [8775] = 8523,
  [8776] = 8525,
  [8777] = 8671,
  [8778] = 8526,
  [8779] = 8446,
  [8780] = 8670,
  [8781] = 8487,
  [8782] = 7596,
  [8783] = 8673,
  [8784] = 8493,
  [8785] = 3472,
  [8786] = 8544,
  [8787] = 8494,
  [8788] = 8495,
  [8789] = 8496,
  [8790] = 8548,
  [8791] = 8671,
  [8792] = 7615,
  [8793] = 8500,
  [8794] = 8438,
  [8795] = 8673,
  [8796] = 8441,
  [8797] = 8614,
  [8798] = 3455,
  [8799] = 8442,
  [8800] = 8488,
  [8801] = 8801,
  [8802] = 8802,
  [8803] = 8801,
  [8804] = 8496,
  [8805] = 8500,
  [8806] = 8806,
  [8807] = 8806,
  [8808] = 8808,
  [8809] = 8802,
  [8810] = 8806,
  [8811] = 8438,
  [8812] = 8441,
  [8813] = 8442,
  [8814] = 8806,
  [8815] = 8815,
  [8816] = 8802,
  [8817] = 8802,
  [8818] = 8818,
  [8819] = 8806,
  [8820] = 8820,
  [8821] = 8802,
  [8822] = 8806,
  [8823] = 8806,
  [8824] = 8461,
  [8825] = 8802,
  [8826] = 8806,
  [8827] = 8827,
  [8828] = 8445,
  [8829] = 8802,
  [8830] = 8802,
  [8831] = 8831,
  [8832] = 8801,
  [8833] = 8806,
  [8834] = 8834,
  [8835] = 8835,
  [8836] = 8802,
  [8837] = 8802,
  [8838] = 8808,
  [8839] = 8806,
  [8840] = 8802,
  [8841] = 8815,
  [8842] = 8614,
  [8843] = 8806,
  [8844] = 8806,
  [8845] = 8479,
  [8846] = 8802,
  [8847] = 8808,
  [8848] = 8446,
  [8849] = 8815,
  [8850] = 8850,
  [8851] = 8806,
  [8852] = 8801,
  [8853] = 8802,
  [8854] = 8802,
  [8855] = 8481,
  [8856] = 8487,
  [8857] = 8493,
  [8858] = 8494,
  [8859] = 8495,
  [8860] = 8806,
  [8861] = 8496,
  [8862] = 8500,
  [8863] = 8802,
  [8864] = 8802,
  [8865] = 8865,
  [8866] = 8850,
  [8867] = 8806,
  [8868] = 8802,
  [8869] = 8523,
  [8870] = 8438,
  [8871] = 8808,
  [8872] = 8806,
  [8873] = 8802,
  [8874] = 8441,
  [8875] = 8834,
  [8876] = 8806,
  [8877] = 8525,
  [8878] = 8815,
  [8879] = 8526,
  [8880] = 8880,
  [8881] = 8806,
  [8882] = 8850,
  [8883] = 8442,
  [8884] = 8802,
  [8885] = 8885,
  [8886] = 8818,
  [8887] = 8488,
  [8888] = 8802,
  [8889] = 8806,
  [8890] = 8802,
  [8891] = 3455,
  [8892] = 8865,
  [8893] = 8880,
  [8894] = 8488,
  [8895] = 8439,
  [8896] = 8806,
  [8897] = 8802,
  [8898] = 8865,
  [8899] = 8544,
  [8900] = 8900,
  [8901] = 8901,
  [8902] = 8806,
  [8903] = 8802,
  [8904] = 8806,
  [8905] = 8499,
  [8906] = 8820,
  [8907] = 8806,
  [8908] = 8802,
  [8909] = 8499,
  [8910] = 8548,
  [8911] = 8806,
  [8912] = 8457,
  [8913] = 8802,
  [8914] = 8865,
  [8915] = 8802,
  [8916] = 8806,
  [8917] = 8801,
  [8918] = 8802,
  [8919] = 8806,
  [8920] = 8802,
  [8921] = 8835,
  [8922] = 8806,
  [8923] = 8806,
  [8924] = 8802,
  [8925] = 3412,
  [8926] = 8498,
  [8927] = 8806,
  [8928] = 8802,
  [8929] = 8457,
  [8930] = 8806,
  [8931] = 8802,
  [8932] = 8806,
  [8933] = 8806,
  [8934] = 8850,
  [8935] = 8802,
  [8936] = 8806,
  [8937] = 8937,
  [8938] = 8808,
  [8939] = 8802,
  [8940] = 7589,
  [8941] = 8806,
  [8942] = 8802,
  [8943] = 8943,
  [8944] = 8944,
  [8945] = 8614,
  [8946] = 8885,
  [8947] = 8947,
  [8948] = 8523,
  [8949] = 8802,
  [8950] = 8525,
  [8951] = 8827,
  [8952] = 8526,
  [8953] = 8818,
  [8954] = 8834,
  [8955] = 8835,
  [8956] = 8820,
  [8957] = 8957,
  [8958] = 8488,
  [8959] = 8959,
  [8960] = 8885,
  [8961] = 8808,
  [8962] = 8827,
  [8963] = 3458,
  [8964] = 8818,
  [8965] = 8834,
  [8966] = 8835,
  [8967] = 8820,
  [8968] = 8831,
  [8969] = 8865,
  [8970] = 8885,
  [8971] = 8827,
  [8972] = 8818,
  [8973] = 8865,
  [8974] = 8834,
  [8975] = 8835,
  [8976] = 8820,
  [8977] = 8806,
  [8978] = 8885,
  [8979] = 8827,
  [8980] = 8885,
  [8981] = 8827,
  [8982] = 8885,
  [8983] = 8488,
  [8984] = 8885,
  [8985] = 8885,
  [8986] = 8986,
  [8987] = 8944,
  [8988] = 8808,
  [8989] = 8885,
  [8990] = 8808,
  [8991] = 8815,
  [8992] = 8850,
  [8993] = 8445,
  [8994] = 8802,
  [8995] = 8461,
  [8996] = 8806,
  [8997] = 8865,
  [8998] = 3412,
  [8999] = 8801,
  [9000] = 8806,
  [9001] = 8498,
  [9002] = 8808,
  [9003] = 8808,
  [9004] = 8445,
  [9005] = 8446,
  [9006] = 8801,
  [9007] = 8802,
  [9008] = 3471,
  [9009] = 8947,
  [9010] = 8544,
  [9011] = 8806,
  [9012] = 8801,
  [9013] = 8548,
  [9014] = 3295,
  [9015] = 8802,
  [9016] = 8801,
  [9017] = 8808,
  [9018] = 8802,
  [9019] = 8801,
  [9020] = 8445,
  [9021] = 9021,
  [9022] = 8802,
  [9023] = 8815,
  [9024] = 8850,
  [9025] = 9025,
  [9026] = 8479,
  [9027] = 3472,
  [9028] = 8808,
  [9029] = 8808,
  [9030] = 8806,
  [9031] = 8806,
  [9032] = 8439,
  [9033] = 8865,
  [9034] = 8865,
  [9035] = 8481,
  [9036] = 8802,
  [9037] = 8498,
  [9038] = 8461,
  [9039] = 3471,
  [9040] = 8487,
  [9041] = 8806,
  [9042] = 8457,
  [9043] = 8493,
  [9044] = 8808,
  [9045] = 8944,
  [9046] = 3295,
  [9047] = 8494,
  [9048] = 8865,
  [9049] = 8802,
  [9050] = 8457,
  [9051] = 9051,
  [9052] = 8495,
  [9053] = 8808,
  [9054] = 8944,
  [9055] = 9055,
  [9056] = 8461,
  [9057] = 8806,
  [9058] = 8498,
  [9059] = 8808,
  [9060] = 5471,
  [9061] = 8544,
  [9062] = 3351,
  [9063] = 8493,
  [9064] = 3458,
  [9065] = 3460,
  [9066] = 8498,
  [9067] = 8457,
  [9068] = 8496,
  [9069] = 8548,
  [9070] = 8544,
  [9071] = 5513,
  [9072] = 7742,
  [9073] = 8494,
  [9074] = 8495,
  [9075] = 8496,
  [9076] = 8500,
  [9077] = 3255,
  [9078] = 8438,
  [9079] = 8481,
  [9080] = 3455,
  [9081] = 5655,
  [9082] = 8500,
  [9083] = 3256,
  [9084] = 8487,
  [9085] = 8479,
  [9086] = 8438,
  [9087] = 8441,
  [9088] = 8442,
  [9089] = 5494,
  [9090] = 5583,
  [9091] = 8743,
  [9092] = 8481,
  [9093] = 7800,
  [9094] = 7821,
  [9095] = 9025,
  [9096] = 7822,
  [9097] = 5469,
  [9098] = 9098,
  [9099] = 3452,
  [9100] = 7868,
  [9101] = 5667,
  [9102] = 8441,
  [9103] = 8523,
  [9104] = 3456,
  [9105] = 8479,
  [9106] = 3468,
  [9107] = 7736,
  [9108] = 7737,
  [9109] = 7870,
  [9110] = 3459,
  [9111] = 7801,
  [9112] = 8457,
  [9113] = 3351,
  [9114] = 3458,
  [9115] = 3470,
  [9116] = 3460,
  [9117] = 8442,
  [9118] = 3256,
  [9119] = 5613,
  [9120] = 8523,
  [9121] = 3471,
  [9122] = 3295,
  [9123] = 8526,
  [9124] = 8488,
  [9125] = 3451,
  [9126] = 8439,
  [9127] = 8439,
  [9128] = 3453,
  [9129] = 5687,
  [9130] = 3412,
  [9131] = 3455,
  [9132] = 8493,
  [9133] = 8446,
  [9134] = 8494,
  [9135] = 8488,
  [9136] = 7877,
  [9137] = 8495,
  [9138] = 7914,
  [9139] = 9139,
  [9140] = 3468,
  [9141] = 7751,
  [9142] = 7834,
  [9143] = 7819,
  [9144] = 7752,
  [9145] = 7753,
  [9146] = 3454,
  [9147] = 7755,
  [9148] = 7765,
  [9149] = 3470,
  [9150] = 8525,
  [9151] = 7795,
  [9152] = 8614,
  [9153] = 7756,
  [9154] = 5469,
  [9155] = 7757,
  [9156] = 9156,
  [9157] = 5599,
  [9158] = 5600,
  [9159] = 8446,
  [9160] = 5468,
  [9161] = 5488,
  [9162] = 8548,
  [9163] = 9163,
  [9164] = 8526,
  [9165] = 7770,
  [9166] = 7796,
  [9167] = 7791,
  [9168] = 3255,
  [9169] = 3456,
  [9170] = 7775,
  [9171] = 3450,
  [9172] = 3472,
  [9173] = 3295,
  [9174] = 7820,
  [9175] = 3374,
  [9176] = 5513,
  [9177] = 7781,
  [9178] = 8487,
  [9179] = 7797,
  [9180] = 7740,
  [9181] = 3459,
  [9182] = 7754,
  [9183] = 7849,
  [9184] = 8525,
  [9185] = 3377,
  [9186] = 3248,
  [9187] = 5533,
  [9188] = 8614,
  [9189] = 8498,
  [9190] = 3392,
  [9191] = 3472,
  [9192] = 3450,
  [9193] = 5600,
  [9194] = 5613,
  [9195] = 9195,
  [9196] = 3360,
  [9197] = 5621,
  [9198] = 8614,
  [9199] = 9199,
  [9200] = 9200,
  [9201] = 5677,
  [9202] = 8488,
  [9203] = 5599,
  [9204] = 5609,
  [9205] = 5607,
  [9206] = 5594,
  [9207] = 5623,
  [9208] = 5681,
  [9209] = 5656,
  [9210] = 5595,
  [9211] = 9211,
  [9212] = 5662,
  [9213] = 8457,
  [9214] = 3453,
  [9215] = 9215,
  [9216] = 9216,
  [9217] = 5583,
  [9218] = 9218,
  [9219] = 5610,
  [9220] = 5627,
  [9221] = 3362,
  [9222] = 5606,
  [9223] = 5591,
  [9224] = 3451,
  [9225] = 9225,
  [9226] = 5646,
  [9227] = 5649,
  [9228] = 5652,
  [9229] = 7860,
  [9230] = 5619,
  [9231] = 5666,
  [9232] = 5643,
  [9233] = 5693,
  [9234] = 5585,
  [9235] = 5598,
  [9236] = 3454,
  [9237] = 8614,
  [9238] = 5673,
  [9239] = 5586,
  [9240] = 3458,
  [9241] = 5603,
  [9242] = 3377,
  [9243] = 3248,
  [9244] = 8457,
  [9245] = 7873,
  [9246] = 5723,
  [9247] = 3452,
  [9248] = 7818,
  [9249] = 5667,
  [9250] = 9250,
  [9251] = 5724,
  [9252] = 7866,
  [9253] = 3472,
  [9254] = 5630,
  [9255] = 3374,
  [9256] = 9256,
  [9257] = 5605,
  [9258] = 5707,
  [9259] = 8498,
  [9260] = 8498,
  [9261] = 9216,
  [9262] = 5687,
  [9263] = 5634,
  [9264] = 3392,
  [9265] = 5593,
  [9266] = 5617,
  [9267] = 5633,
  [9268] = 5635,
  [9269] = 7871,
  [9270] = 5637,
  [9271] = 9271,
  [9272] = 5601,
  [9273] = 5655,
  [9274] = 5672,
  [9275] = 9275,
  [9276] = 9276,
  [9277] = 8488,
  [9278] = 5620,
  [9279] = 9279,
  [9280] = 9280,
  [9281] = 9281,
  [9282] = 9282,
  [9283] = 9281,
  [9284] = 9284,
  [9285] = 9285,
  [9286] = 9286,
  [9287] = 9284,
  [9288] = 9288,
  [9289] = 9289,
  [9290] = 9284,
  [9291] = 9286,
  [9292] = 9292,
  [9293] = 9281,
  [9294] = 5655,
  [9295] = 9295,
  [9296] = 9296,
  [9297] = 9289,
  [9298] = 9282,
  [9299] = 9296,
  [9300] = 9300,
  [9301] = 9280,
  [9302] = 9302,
  [9303] = 3412,
  [9304] = 9304,
  [9305] = 9302,
  [9306] = 9304,
  [9307] = 8181,
  [9308] = 9289,
  [9309] = 9309,
  [9310] = 9310,
  [9311] = 9311,
  [9312] = 9312,
  [9313] = 9313,
  [9314] = 9300,
  [9315] = 9304,
  [9316] = 9296,
  [9317] = 9282,
  [9318] = 9318,
  [9319] = 9319,
  [9320] = 9288,
  [9321] = 9295,
  [9322] = 9322,
  [9323] = 9304,
  [9324] = 9302,
  [9325] = 9300,
  [9326] = 9282,
  [9327] = 9319,
  [9328] = 9302,
  [9329] = 9304,
  [9330] = 9304,
  [9331] = 9331,
  [9332] = 9302,
  [9333] = 9304,
  [9334] = 9300,
  [9335] = 9302,
  [9336] = 9300,
  [9337] = 9302,
  [9338] = 9163,
  [9339] = 9339,
  [9340] = 9304,
  [9341] = 9304,
  [9342] = 9302,
  [9343] = 9300,
  [9344] = 9344,
  [9345] = 9302,
  [9346] = 9346,
  [9347] = 9285,
  [9348] = 9304,
  [9349] = 9282,
  [9350] = 9304,
  [9351] = 9300,
  [9352] = 9304,
  [9353] = 9302,
  [9354] = 9300,
  [9355] = 9355,
  [9356] = 9344,
  [9357] = 9357,
  [9358] = 9302,
  [9359] = 9302,
  [9360] = 9302,
  [9361] = 9361,
  [9362] = 9362,
  [9363] = 9300,
  [9364] = 9304,
  [9365] = 9300,
  [9366] = 3471,
  [9367] = 9319,
  [9368] = 9368,
  [9369] = 9300,
  [9370] = 9300,
  [9371] = 9163,
  [9372] = 9372,
  [9373] = 9286,
  [9374] = 9292,
  [9375] = 9355,
  [9376] = 9312,
  [9377] = 9300,
  [9378] = 9279,
  [9379] = 9344,
  [9380] = 3279,
  [9381] = 9381,
  [9382] = 9382,
  [9383] = 9383,
  [9384] = 9384,
  [9385] = 9286,
  [9386] = 3302,
  [9387] = 9381,
  [9388] = 9382,
  [9389] = 3298,
  [9390] = 9282,
  [9391] = 3304,
  [9392] = 9286,
  [9393] = 9393,
  [9394] = 9296,
  [9395] = 9395,
  [9396] = 3305,
  [9397] = 3306,
  [9398] = 3307,
  [9399] = 9399,
  [9400] = 3139,
  [9401] = 9401,
  [9402] = 9402,
  [9403] = 9403,
  [9404] = 9404,
  [9405] = 9405,
  [9406] = 9406,
  [9407] = 9407,
  [9408] = 9408,
  [9409] = 9409,
  [9410] = 3308,
  [9411] = 3309,
  [9412] = 3310,
  [9413] = 3140,
  [9414] = 3374,
  [9415] = 9383,
  [9416] = 9416,
  [9417] = 9417,
  [9418] = 9418,
  [9419] = 9419,
  [9420] = 3311,
  [9421] = 3377,
  [9422] = 9422,
  [9423] = 3248,
  [9424] = 3392,
  [9425] = 3374,
  [9426] = 9426,
  [9427] = 9427,
  [9428] = 9428,
  [9429] = 9429,
  [9430] = 9430,
  [9431] = 9431,
  [9432] = 3377,
  [9433] = 9296,
  [9434] = 3248,
  [9435] = 9435,
  [9436] = 9436,
  [9437] = 9437,
  [9438] = 9422,
  [9439] = 3392,
  [9440] = 9440,
  [9441] = 9163,
  [9442] = 9395,
  [9443] = 9402,
  [9444] = 9403,
  [9445] = 9445,
  [9446] = 9404,
  [9447] = 9405,
  [9448] = 9381,
  [9449] = 9406,
  [9450] = 9407,
  [9451] = 9408,
  [9452] = 9409,
  [9453] = 9382,
  [9454] = 9416,
  [9455] = 9417,
  [9456] = 9418,
  [9457] = 9419,
  [9458] = 9458,
  [9459] = 9426,
  [9460] = 9427,
  [9461] = 9428,
  [9462] = 9429,
  [9463] = 9430,
  [9464] = 9431,
  [9465] = 9465,
  [9466] = 9466,
  [9467] = 9435,
  [9468] = 9436,
  [9469] = 9437,
  [9470] = 9470,
  [9471] = 9440,
  [9472] = 9163,
  [9473] = 9399,
  [9474] = 9445,
  [9475] = 9401,
  [9476] = 9312,
  [9477] = 9465,
  [9478] = 9478,
  [9479] = 9466,
  [9480] = 9480,
  [9481] = 9309,
  [9482] = 9383,
  [9483] = 9458,
  [9484] = 9484,
  [9485] = 9485,
  [9486] = 9486,
  [9487] = 9487,
  [9488] = 9422,
  [9489] = 9399,
  [9490] = 9401,
  [9491] = 3362,
  [9492] = 9339,
  [9493] = 9289,
  [9494] = 9383,
  [9495] = 9422,
  [9496] = 9496,
  [9497] = 9399,
  [9498] = 9381,
  [9499] = 9382,
  [9500] = 9465,
  [9501] = 9466,
  [9502] = 9470,
  [9503] = 3458,
  [9504] = 3455,
  [9505] = 9381,
  [9506] = 9399,
  [9507] = 9401,
  [9508] = 9383,
  [9509] = 9422,
  [9510] = 9510,
  [9511] = 9470,
  [9512] = 9382,
  [9513] = 9381,
  [9514] = 9382,
  [9515] = 9465,
  [9516] = 9466,
  [9517] = 9470,
  [9518] = 3472,
  [9519] = 9310,
  [9520] = 9465,
  [9521] = 9466,
  [9522] = 9470,
  [9523] = 9384,
  [9524] = 9393,
  [9525] = 9465,
  [9526] = 9526,
  [9527] = 9399,
  [9528] = 9401,
  [9529] = 9486,
  [9530] = 9383,
  [9531] = 9422,
  [9532] = 9163,
  [9533] = 9466,
  [9534] = 9381,
  [9535] = 9465,
  [9536] = 9466,
  [9537] = 9470,
  [9538] = 3295,
  [9539] = 3300,
  [9540] = 9282,
  [9541] = 9399,
  [9542] = 9401,
  [9543] = 3261,
  [9544] = 9383,
  [9545] = 9422,
  [9546] = 9381,
  [9547] = 9382,
  [9548] = 9465,
  [9549] = 9466,
  [9550] = 9286,
  [9551] = 9470,
  [9552] = 9510,
  [9553] = 9399,
  [9554] = 9401,
  [9555] = 9383,
  [9556] = 9422,
  [9557] = 9355,
  [9558] = 9381,
  [9559] = 9401,
  [9560] = 9382,
  [9561] = 9465,
  [9562] = 9466,
  [9563] = 9470,
  [9564] = 9470,
  [9565] = 9484,
  [9566] = 3303,
  [9567] = 9399,
  [9568] = 9401,
  [9569] = 9383,
  [9570] = 9570,
  [9571] = 9422,
  [9572] = 9485,
  [9573] = 9381,
  [9574] = 9382,
  [9575] = 9465,
  [9576] = 9466,
  [9577] = 9470,
  [9578] = 3290,
  [9579] = 9579,
  [9580] = 3374,
  [9581] = 9399,
  [9582] = 9401,
  [9583] = 3377,
  [9584] = 9383,
  [9585] = 3248,
  [9586] = 9422,
  [9587] = 3392,
  [9588] = 9381,
  [9589] = 9382,
  [9590] = 9465,
  [9591] = 9466,
  [9592] = 9470,
  [9593] = 9296,
  [9594] = 3360,
  [9595] = 9399,
  [9596] = 9401,
  [9597] = 3450,
  [9598] = 9383,
  [9599] = 9399,
  [9600] = 9422,
  [9601] = 9401,
  [9602] = 9478,
  [9603] = 9381,
  [9604] = 9382,
  [9605] = 9465,
  [9606] = 9466,
  [9607] = 9470,
  [9608] = 3451,
  [9609] = 3452,
  [9610] = 3453,
  [9611] = 3454,
  [9612] = 9399,
  [9613] = 9401,
  [9614] = 9383,
  [9615] = 9383,
  [9616] = 9616,
  [9617] = 9382,
  [9618] = 9422,
  [9619] = 9289,
  [9620] = 9381,
  [9621] = 9382,
  [9622] = 9422,
  [9623] = 3299,
  [9624] = 9624,
  [9625] = 9478,
  [9626] = 9383,
  [9627] = 9627,
  [9628] = 5687,
  [9629] = 5655,
  [9630] = 9381,
  [9631] = 9382,
  [9632] = 9632,
  [9633] = 9383,
  [9634] = 9381,
  [9635] = 9381,
  [9636] = 3456,
  [9637] = 3459,
  [9638] = 9382,
  [9639] = 3351,
  [9640] = 3460,
  [9641] = 9381,
  [9642] = 3250,
  [9643] = 5687,
  [9644] = 5655,
  [9645] = 9383,
  [9646] = 3251,
  [9647] = 3468,
  [9648] = 3252,
  [9649] = 3470,
  [9650] = 3253,
  [9651] = 3254,
  [9652] = 3260,
  [9653] = 9289,
  [9654] = 9381,
  [9655] = 9382,
  [9656] = 9382,
  [9657] = 9383,
  [9658] = 3262,
  [9659] = 3263,
  [9660] = 3264,
  [9661] = 9381,
  [9662] = 3265,
  [9663] = 9382,
  [9664] = 3266,
  [9665] = 3267,
  [9666] = 3131,
  [9667] = 3268,
  [9668] = 3269,
  [9669] = 3272,
  [9670] = 3255,
  [9671] = 9383,
  [9672] = 3273,
  [9673] = 3274,
  [9674] = 3275,
  [9675] = 3276,
  [9676] = 3301,
  [9677] = 3277,
  [9678] = 3256,
  [9679] = 9381,
  [9680] = 3278,
  [9681] = 9382,
  [9682] = 3280,
  [9683] = 3281,
  [9684] = 3282,
  [9685] = 3283,
  [9686] = 3284,
  [9687] = 3285,
  [9688] = 3287,
  [9689] = 9383,
  [9690] = 9383,
  [9691] = 3288,
  [9692] = 3289,
  [9693] = 3132,
  [9694] = 3133,
  [9695] = 3134,
  [9696] = 3291,
  [9697] = 3292,
  [9698] = 3293,
  [9699] = 3294,
  [9700] = 9381,
  [9701] = 9382,
  [9702] = 3135,
  [9703] = 3136,
  [9704] = 3137,
  [9705] = 3296,
  [9706] = 9383,
  [9707] = 9465,
  [9708] = 9466,
  [9709] = 3297,
  [9710] = 9381,
  [9711] = 9470,
  [9712] = 9382,
  [9713] = 7860,
  [9714] = 7871,
  [9715] = 7818,
  [9716] = 7873,
  [9717] = 7866,
  [9718] = 9383,
  [9719] = 9382,
  [9720] = 9720,
  [9721] = 9721,
  [9722] = 9720,
  [9723] = 9427,
  [9724] = 9384,
  [9725] = 9406,
  [9726] = 9393,
  [9727] = 9426,
  [9728] = 9428,
  [9729] = 9427,
  [9730] = 9440,
  [9731] = 3450,
  [9732] = 9721,
  [9733] = 9720,
  [9734] = 9734,
  [9735] = 9735,
  [9736] = 9417,
  [9737] = 9384,
  [9738] = 9428,
  [9739] = 9429,
  [9740] = 9429,
  [9741] = 9430,
  [9742] = 9407,
  [9743] = 9393,
  [9744] = 9431,
  [9745] = 9486,
  [9746] = 9746,
  [9747] = 9747,
  [9748] = 9458,
  [9749] = 9735,
  [9750] = 9384,
  [9751] = 9393,
  [9752] = 9752,
  [9753] = 9435,
  [9754] = 9436,
  [9755] = 9437,
  [9756] = 9440,
  [9757] = 9445,
  [9758] = 9721,
  [9759] = 9720,
  [9760] = 9163,
  [9761] = 9735,
  [9762] = 5687,
  [9763] = 9408,
  [9764] = 9430,
  [9765] = 9409,
  [9766] = 9395,
  [9767] = 9440,
  [9768] = 9735,
  [9769] = 9769,
  [9770] = 8498,
  [9771] = 8457,
  [9772] = 9484,
  [9773] = 9773,
  [9774] = 9485,
  [9775] = 3374,
  [9776] = 9431,
  [9777] = 9735,
  [9778] = 3392,
  [9779] = 3374,
  [9780] = 9780,
  [9781] = 9735,
  [9782] = 3377,
  [9783] = 9406,
  [9784] = 9721,
  [9785] = 9720,
  [9786] = 9721,
  [9787] = 9720,
  [9788] = 9486,
  [9789] = 9435,
  [9790] = 9445,
  [9791] = 9407,
  [9792] = 9735,
  [9793] = 9296,
  [9794] = 9436,
  [9795] = 9163,
  [9796] = 3452,
  [9797] = 8488,
  [9798] = 9437,
  [9799] = 9799,
  [9800] = 9418,
  [9801] = 9801,
  [9802] = 9747,
  [9803] = 8461,
  [9804] = 9484,
  [9805] = 9485,
  [9806] = 3374,
  [9807] = 9402,
  [9808] = 9312,
  [9809] = 9403,
  [9810] = 9404,
  [9811] = 9721,
  [9812] = 9720,
  [9813] = 9486,
  [9814] = 9419,
  [9815] = 9735,
  [9816] = 9816,
  [9817] = 3377,
  [9818] = 3248,
  [9819] = 9405,
  [9820] = 3392,
  [9821] = 9458,
  [9822] = 9735,
  [9823] = 9402,
  [9824] = 9780,
  [9825] = 9825,
  [9826] = 9721,
  [9827] = 9403,
  [9828] = 3248,
  [9829] = 9721,
  [9830] = 9720,
  [9831] = 9721,
  [9832] = 9289,
  [9833] = 9735,
  [9834] = 9720,
  [9835] = 9720,
  [9836] = 9395,
  [9837] = 9435,
  [9838] = 9721,
  [9839] = 9720,
  [9840] = 9840,
  [9841] = 9436,
  [9842] = 9721,
  [9843] = 9426,
  [9844] = 9437,
  [9845] = 9845,
  [9846] = 9445,
  [9847] = 5655,
  [9848] = 8499,
  [9849] = 9735,
  [9850] = 9404,
  [9851] = 8479,
  [9852] = 8481,
  [9853] = 8487,
  [9854] = 8493,
  [9855] = 8494,
  [9856] = 8495,
  [9857] = 8496,
  [9858] = 8500,
  [9859] = 8438,
  [9860] = 9721,
  [9861] = 8441,
  [9862] = 9720,
  [9863] = 8442,
  [9864] = 8445,
  [9865] = 9312,
  [9866] = 8446,
  [9867] = 9721,
  [9868] = 9395,
  [9869] = 9720,
  [9870] = 9845,
  [9871] = 9825,
  [9872] = 9426,
  [9873] = 3451,
  [9874] = 9427,
  [9875] = 5687,
  [9876] = 9428,
  [9877] = 9458,
  [9878] = 9429,
  [9879] = 9430,
  [9880] = 8439,
  [9881] = 8461,
  [9882] = 9752,
  [9883] = 5655,
  [9884] = 9735,
  [9885] = 9840,
  [9886] = 9355,
  [9887] = 9431,
  [9888] = 9888,
  [9889] = 5687,
  [9890] = 3377,
  [9891] = 9408,
  [9892] = 3392,
  [9893] = 9405,
  [9894] = 9406,
  [9895] = 9407,
  [9896] = 9735,
  [9897] = 9408,
  [9898] = 9286,
  [9899] = 9409,
  [9900] = 9721,
  [9901] = 9720,
  [9902] = 9484,
  [9903] = 9416,
  [9904] = 9409,
  [9905] = 9355,
  [9906] = 9416,
  [9907] = 9417,
  [9908] = 9418,
  [9909] = 9312,
  [9910] = 9485,
  [9911] = 9735,
  [9912] = 9419,
  [9913] = 8445,
  [9914] = 3454,
  [9915] = 5655,
  [9916] = 9510,
  [9917] = 9735,
  [9918] = 3248,
  [9919] = 9919,
  [9920] = 9416,
  [9921] = 8544,
  [9922] = 8548,
  [9923] = 8523,
  [9924] = 8525,
  [9925] = 8526,
  [9926] = 9282,
  [9927] = 9417,
  [9928] = 9721,
  [9929] = 9721,
  [9930] = 9720,
  [9931] = 9720,
  [9932] = 9418,
  [9933] = 9402,
  [9934] = 9403,
  [9935] = 9404,
  [9936] = 9405,
  [9937] = 9510,
  [9938] = 9419,
  [9939] = 9735,
  [9940] = 9355,
  [9941] = 9941,
  [9942] = 9510,
  [9943] = 3453,
  [9944] = 7860,
  [9945] = 9417,
  [9946] = 9946,
  [9947] = 9418,
  [9948] = 9458,
  [9949] = 9402,
  [9950] = 9486,
  [9951] = 9951,
  [9952] = 9403,
  [9953] = 9445,
  [9954] = 9954,
  [9955] = 9955,
  [9956] = 9419,
  [9957] = 3296,
  [9958] = 9163,
  [9959] = 9404,
  [9960] = 8544,
  [9961] = 8548,
  [9962] = 8523,
  [9963] = 8525,
  [9964] = 8526,
  [9965] = 9510,
  [9966] = 3297,
  [9967] = 9430,
  [9968] = 9968,
  [9969] = 9405,
  [9970] = 9970,
  [9971] = 9426,
  [9972] = 9427,
  [9973] = 9428,
  [9974] = 9974,
  [9975] = 9975,
  [9976] = 9406,
  [9977] = 9429,
  [9978] = 9407,
  [9979] = 9355,
  [9980] = 9430,
  [9981] = 9981,
  [9982] = 9408,
  [9983] = 9409,
  [9984] = 9984,
  [9985] = 9985,
  [9986] = 9986,
  [9987] = 9987,
  [9988] = 9431,
  [9989] = 9845,
  [9990] = 9970,
  [9991] = 9991,
  [9992] = 9840,
  [9993] = 8479,
  [9994] = 8481,
  [9995] = 9282,
  [9996] = 8487,
  [9997] = 3301,
  [9998] = 9426,
  [9999] = 9435,
  [10000] = 9436,
  [10001] = 9747,
  [10002] = 8493,
  [10003] = 8494,
  [10004] = 8495,
  [10005] = 8496,
  [10006] = 8500,
  [10007] = 8438,
  [10008] = 8441,
  [10009] = 8442,
  [10010] = 9437,
  [10011] = 3412,
  [10012] = 3360,
  [10013] = 8457,
  [10014] = 10014,
  [10015] = 3362,
  [10016] = 8446,
  [10017] = 9440,
  [10018] = 3302,
  [10019] = 3303,
  [10020] = 9486,
  [10021] = 3139,
  [10022] = 9427,
  [10023] = 10023,
  [10024] = 3374,
  [10025] = 10025,
  [10026] = 10026,
  [10027] = 10023,
  [10028] = 10028,
  [10029] = 3304,
  [10030] = 9968,
  [10031] = 3305,
  [10032] = 3965,
  [10033] = 10025,
  [10034] = 3306,
  [10035] = 3307,
  [10036] = 10026,
  [10037] = 3377,
  [10038] = 3374,
  [10039] = 9163,
  [10040] = 3377,
  [10041] = 3308,
  [10042] = 10042,
  [10043] = 3250,
  [10044] = 10044,
  [10045] = 10045,
  [10046] = 3248,
  [10047] = 3392,
  [10048] = 3309,
  [10049] = 9825,
  [10050] = 9384,
  [10051] = 10051,
  [10052] = 10052,
  [10053] = 3248,
  [10054] = 3310,
  [10055] = 3295,
  [10056] = 3311,
  [10057] = 9393,
  [10058] = 9780,
  [10059] = 10045,
  [10060] = 9981,
  [10061] = 3392,
  [10062] = 3140,
  [10063] = 3374,
  [10064] = 3377,
  [10065] = 3248,
  [10066] = 10044,
  [10067] = 10051,
  [10068] = 9416,
  [10069] = 9417,
  [10070] = 9163,
  [10071] = 9418,
  [10072] = 10072,
  [10073] = 3251,
  [10074] = 3252,
  [10075] = 9384,
  [10076] = 3253,
  [10077] = 3254,
  [10078] = 3392,
  [10079] = 3260,
  [10080] = 9393,
  [10081] = 10081,
  [10082] = 10082,
  [10083] = 9419,
  [10084] = 9458,
  [10085] = 10085,
  [10086] = 9974,
  [10087] = 3458,
  [10088] = 9402,
  [10089] = 8498,
  [10090] = 8457,
  [10091] = 10091,
  [10092] = 10092,
  [10093] = 3298,
  [10094] = 9975,
  [10095] = 9981,
  [10096] = 10096,
  [10097] = 9955,
  [10098] = 3262,
  [10099] = 3263,
  [10100] = 3264,
  [10101] = 9435,
  [10102] = 8479,
  [10103] = 10103,
  [10104] = 8481,
  [10105] = 8487,
  [10106] = 10023,
  [10107] = 8493,
  [10108] = 8494,
  [10109] = 8495,
  [10110] = 3265,
  [10111] = 9968,
  [10112] = 3266,
  [10113] = 3267,
  [10114] = 8496,
  [10115] = 8500,
  [10116] = 8438,
  [10117] = 8441,
  [10118] = 8439,
  [10119] = 8461,
  [10120] = 8442,
  [10121] = 8445,
  [10122] = 8446,
  [10123] = 9436,
  [10124] = 9984,
  [10125] = 9955,
  [10126] = 3131,
  [10127] = 3268,
  [10128] = 3269,
  [10129] = 3272,
  [10130] = 9437,
  [10131] = 9974,
  [10132] = 8445,
  [10133] = 9975,
  [10134] = 9981,
  [10135] = 3273,
  [10136] = 3274,
  [10137] = 3275,
  [10138] = 5687,
  [10139] = 7866,
  [10140] = 5655,
  [10141] = 9984,
  [10142] = 10028,
  [10143] = 9289,
  [10144] = 3300,
  [10145] = 3276,
  [10146] = 9752,
  [10147] = 9840,
  [10148] = 10044,
  [10149] = 10051,
  [10150] = 9403,
  [10151] = 9406,
  [10152] = 10152,
  [10153] = 10028,
  [10154] = 10154,
  [10155] = 10155,
  [10156] = 10156,
  [10157] = 5655,
  [10158] = 10042,
  [10159] = 3277,
  [10160] = 10023,
  [10161] = 10025,
  [10162] = 10026,
  [10163] = 9407,
  [10164] = 10164,
  [10165] = 10165,
  [10166] = 10044,
  [10167] = 3278,
  [10168] = 3374,
  [10169] = 3279,
  [10170] = 10051,
  [10171] = 3280,
  [10172] = 9840,
  [10173] = 9445,
  [10174] = 9440,
  [10175] = 10175,
  [10176] = 9408,
  [10177] = 10177,
  [10178] = 10085,
  [10179] = 9954,
  [10180] = 10052,
  [10181] = 10096,
  [10182] = 10085,
  [10183] = 9954,
  [10184] = 3281,
  [10185] = 3282,
  [10186] = 3283,
  [10187] = 3284,
  [10188] = 3285,
  [10189] = 9974,
  [10190] = 9975,
  [10191] = 9981,
  [10192] = 9981,
  [10193] = 10193,
  [10194] = 3287,
  [10195] = 3456,
  [10196] = 9984,
  [10197] = 9286,
  [10198] = 10052,
  [10199] = 9409,
  [10200] = 10200,
  [10201] = 10152,
  [10202] = 10202,
  [10203] = 10154,
  [10204] = 3459,
  [10205] = 10155,
  [10206] = 10044,
  [10207] = 10051,
  [10208] = 9484,
  [10209] = 9485,
  [10210] = 10156,
  [10211] = 10193,
  [10212] = 10025,
  [10213] = 10200,
  [10214] = 10202,
  [10215] = 3351,
  [10216] = 3460,
  [10217] = 3288,
  [10218] = 3289,
  [10219] = 3450,
  [10220] = 10028,
  [10221] = 10042,
  [10222] = 10026,
  [10223] = 10175,
  [10224] = 8461,
  [10225] = 10044,
  [10226] = 10051,
  [10227] = 3132,
  [10228] = 8499,
  [10229] = 9404,
  [10230] = 10152,
  [10231] = 3468,
  [10232] = 3470,
  [10233] = 3133,
  [10234] = 3134,
  [10235] = 10235,
  [10236] = 8439,
  [10237] = 7871,
  [10238] = 3291,
  [10239] = 10239,
  [10240] = 10154,
  [10241] = 10241,
  [10242] = 10085,
  [10243] = 9954,
  [10244] = 10155,
  [10245] = 9405,
  [10246] = 10052,
  [10247] = 3292,
  [10248] = 3293,
  [10249] = 10156,
  [10250] = 3377,
  [10251] = 3248,
  [10252] = 9955,
  [10253] = 10253,
  [10254] = 9282,
  [10255] = 10152,
  [10256] = 10193,
  [10257] = 10200,
  [10258] = 10154,
  [10259] = 10202,
  [10260] = 10155,
  [10261] = 3392,
  [10262] = 10156,
  [10263] = 9312,
  [10264] = 9845,
  [10265] = 10175,
  [10266] = 9845,
  [10267] = 9955,
  [10268] = 10193,
  [10269] = 9968,
  [10270] = 8488,
  [10271] = 10200,
  [10272] = 3136,
  [10273] = 10273,
  [10274] = 9431,
  [10275] = 9484,
  [10276] = 10202,
  [10277] = 3137,
  [10278] = 10175,
  [10279] = 3451,
  [10280] = 9395,
  [10281] = 3471,
  [10282] = 9485,
  [10283] = 3452,
  [10284] = 9296,
  [10285] = 9955,
  [10286] = 3453,
  [10287] = 7873,
  [10288] = 3454,
  [10289] = 5687,
  [10290] = 3294,
  [10291] = 3255,
  [10292] = 3455,
  [10293] = 8488,
  [10294] = 9428,
  [10295] = 9510,
  [10296] = 7818,
  [10297] = 9395,
  [10298] = 8614,
  [10299] = 3472,
  [10300] = 8498,
  [10301] = 3256,
  [10302] = 8181,
  [10303] = 10303,
  [10304] = 9429,
  [10305] = 3135,
  [10306] = 9416,
  [10307] = 3299,
  [10308] = 10042,
  [10309] = 10309,
  [10310] = 10310,
  [10311] = 10311,
  [10312] = 10045,
  [10313] = 8496,
  [10314] = 10314,
  [10315] = 10315,
  [10316] = 10316,
  [10317] = 10317,
  [10318] = 9426,
  [10319] = 10319,
  [10320] = 8614,
  [10321] = 9427,
  [10322] = 10309,
  [10323] = 9406,
  [10324] = 9384,
  [10325] = 9428,
  [10326] = 7596,
  [10327] = 9440,
  [10328] = 9407,
  [10329] = 9429,
  [10330] = 8487,
  [10331] = 8446,
  [10332] = 9416,
  [10333] = 10333,
  [10334] = 9486,
  [10335] = 9417,
  [10336] = 10311,
  [10337] = 9393,
  [10338] = 10096,
  [10339] = 10339,
  [10340] = 9430,
  [10341] = 10309,
  [10342] = 10311,
  [10343] = 10311,
  [10344] = 8457,
  [10345] = 9486,
  [10346] = 10346,
  [10347] = 10347,
  [10348] = 10348,
  [10349] = 8500,
  [10350] = 10311,
  [10351] = 10346,
  [10352] = 9418,
  [10353] = 10347,
  [10354] = 10096,
  [10355] = 10355,
  [10356] = 10356,
  [10357] = 10311,
  [10358] = 10316,
  [10359] = 10317,
  [10360] = 9408,
  [10361] = 10309,
  [10362] = 4789,
  [10363] = 10348,
  [10364] = 9282,
  [10365] = 9409,
  [10366] = 9355,
  [10367] = 10346,
  [10368] = 10347,
  [10369] = 10355,
  [10370] = 5687,
  [10371] = 10371,
  [10372] = 10311,
  [10373] = 10316,
  [10374] = 10374,
  [10375] = 10317,
  [10376] = 4161,
  [10377] = 10371,
  [10378] = 8498,
  [10379] = 9840,
  [10380] = 9419,
  [10381] = 10381,
  [10382] = 10311,
  [10383] = 9845,
  [10384] = 3374,
  [10385] = 10316,
  [10386] = 10317,
  [10387] = 9780,
  [10388] = 3377,
  [10389] = 9484,
  [10390] = 9431,
  [10391] = 5655,
  [10392] = 10309,
  [10393] = 10309,
  [10394] = 10348,
  [10395] = 9384,
  [10396] = 10311,
  [10397] = 8488,
  [10398] = 10346,
  [10399] = 8439,
  [10400] = 10347,
  [10401] = 8614,
  [10402] = 10355,
  [10403] = 9393,
  [10404] = 10316,
  [10405] = 10348,
  [10406] = 10317,
  [10407] = 3248,
  [10408] = 10309,
  [10409] = 9445,
  [10410] = 9436,
  [10411] = 9485,
  [10412] = 10348,
  [10413] = 9384,
  [10414] = 10346,
  [10415] = 9393,
  [10416] = 10348,
  [10417] = 10347,
  [10418] = 10311,
  [10419] = 10316,
  [10420] = 10346,
  [10421] = 10355,
  [10422] = 10422,
  [10423] = 10347,
  [10424] = 10355,
  [10425] = 10317,
  [10426] = 8457,
  [10427] = 10311,
  [10428] = 8488,
  [10429] = 10311,
  [10430] = 9510,
  [10431] = 8479,
  [10432] = 10309,
  [10433] = 10316,
  [10434] = 10317,
  [10435] = 7751,
  [10436] = 10309,
  [10437] = 10355,
  [10438] = 10348,
  [10439] = 4166,
  [10440] = 10346,
  [10441] = 10347,
  [10442] = 10442,
  [10443] = 10355,
  [10444] = 7607,
  [10445] = 8495,
  [10446] = 10316,
  [10447] = 10317,
  [10448] = 9484,
  [10449] = 10348,
  [10450] = 10309,
  [10451] = 10316,
  [10452] = 3392,
  [10453] = 10348,
  [10454] = 10346,
  [10455] = 3377,
  [10456] = 9747,
  [10457] = 3374,
  [10458] = 10347,
  [10459] = 9485,
  [10460] = 10346,
  [10461] = 10347,
  [10462] = 10355,
  [10463] = 10463,
  [10464] = 3248,
  [10465] = 3392,
  [10466] = 10355,
  [10467] = 9395,
  [10468] = 9510,
  [10469] = 8438,
  [10470] = 8498,
  [10471] = 10314,
  [10472] = 10045,
  [10473] = 3377,
  [10474] = 3248,
  [10475] = 4788,
  [10476] = 10442,
  [10477] = 9458,
  [10478] = 10310,
  [10479] = 10096,
  [10480] = 8493,
  [10481] = 10311,
  [10482] = 10316,
  [10483] = 3392,
  [10484] = 10317,
  [10485] = 9840,
  [10486] = 10316,
  [10487] = 10317,
  [10488] = 10346,
  [10489] = 3374,
  [10490] = 9458,
  [10491] = 10309,
  [10492] = 10316,
  [10493] = 10355,
  [10494] = 9435,
  [10495] = 10317,
  [10496] = 8481,
  [10497] = 8441,
  [10498] = 4785,
  [10499] = 10309,
  [10500] = 10309,
  [10501] = 9402,
  [10502] = 9312,
  [10503] = 10348,
  [10504] = 8442,
  [10505] = 10346,
  [10506] = 9403,
  [10507] = 10356,
  [10508] = 10311,
  [10509] = 9404,
  [10510] = 10347,
  [10511] = 10355,
  [10512] = 9486,
  [10513] = 9510,
  [10514] = 10317,
  [10515] = 9405,
  [10516] = 10316,
  [10517] = 10317,
  [10518] = 10347,
  [10519] = 10519,
  [10520] = 7554,
  [10521] = 10374,
  [10522] = 10348,
  [10523] = 10348,
  [10524] = 10315,
  [10525] = 7615,
  [10526] = 10346,
  [10527] = 10348,
  [10528] = 10346,
  [10529] = 10347,
  [10530] = 9445,
  [10531] = 10355,
  [10532] = 10347,
  [10533] = 10355,
  [10534] = 10339,
  [10535] = 7589,
  [10536] = 10536,
  [10537] = 10519,
  [10538] = 9484,
  [10539] = 9437,
  [10540] = 9485,
  [10541] = 9845,
  [10542] = 10045,
  [10543] = 9163,
  [10544] = 8494,
  [10545] = 10311,
  [10546] = 10546,
  [10547] = 10547,
  [10548] = 10548,
  [10549] = 10549,
  [10550] = 10546,
  [10551] = 10547,
  [10552] = 10548,
  [10553] = 10549,
  [10554] = 9752,
  [10555] = 9825,
  [10556] = 10316,
  [10557] = 7608,
  [10558] = 7757,
  [10559] = 10559,
  [10560] = 10560,
  [10561] = 10561,
  [10562] = 3468,
  [10563] = 10563,
  [10564] = 9282,
  [10565] = 9406,
  [10566] = 9407,
  [10567] = 9408,
  [10568] = 9409,
  [10569] = 10559,
  [10570] = 5655,
  [10571] = 9840,
  [10572] = 5599,
  [10573] = 5600,
  [10574] = 10559,
  [10575] = 9416,
  [10576] = 9417,
  [10577] = 9418,
  [10578] = 9419,
  [10579] = 9458,
  [10580] = 9163,
  [10581] = 3377,
  [10582] = 9845,
  [10583] = 9426,
  [10584] = 3248,
  [10585] = 10559,
  [10586] = 7791,
  [10587] = 9427,
  [10588] = 9428,
  [10589] = 9429,
  [10590] = 9430,
  [10591] = 10559,
  [10592] = 10045,
  [10593] = 9431,
  [10594] = 10559,
  [10595] = 9435,
  [10596] = 9436,
  [10597] = 9437,
  [10598] = 10339,
  [10599] = 9845,
  [10600] = 10559,
  [10601] = 3452,
  [10602] = 9840,
  [10603] = 9840,
  [10604] = 9395,
  [10605] = 9440,
  [10606] = 7752,
  [10607] = 7753,
  [10608] = 7755,
  [10609] = 10559,
  [10610] = 7756,
  [10611] = 9486,
  [10612] = 9282,
  [10613] = 7736,
  [10614] = 10559,
  [10615] = 7737,
  [10616] = 9282,
  [10617] = 10442,
  [10618] = 4789,
  [10619] = 10310,
  [10620] = 9286,
  [10621] = 4860,
  [10622] = 3451,
  [10623] = 10559,
  [10624] = 10624,
  [10625] = 3470,
  [10626] = 3256,
  [10627] = 8498,
  [10628] = 8499,
  [10629] = 10442,
  [10630] = 10559,
  [10631] = 8439,
  [10632] = 9445,
  [10633] = 8461,
  [10634] = 10310,
  [10635] = 4788,
  [10636] = 10559,
  [10637] = 10356,
  [10638] = 7877,
  [10639] = 10561,
  [10640] = 10559,
  [10641] = 7914,
  [10642] = 10442,
  [10643] = 10310,
  [10644] = 5667,
  [10645] = 3374,
  [10646] = 10559,
  [10647] = 9485,
  [10648] = 7795,
  [10649] = 9402,
  [10650] = 10559,
  [10651] = 9403,
  [10652] = 7796,
  [10653] = 10624,
  [10654] = 7797,
  [10655] = 7800,
  [10656] = 7801,
  [10657] = 3454,
  [10658] = 9458,
  [10659] = 9404,
  [10660] = 10519,
  [10661] = 9405,
  [10662] = 9384,
  [10663] = 9393,
  [10664] = 10519,
  [10665] = 10314,
  [10666] = 3392,
  [10667] = 9163,
  [10668] = 10315,
  [10669] = 10669,
  [10670] = 10547,
  [10671] = 5687,
  [10672] = 5655,
  [10673] = 10356,
  [10674] = 7775,
  [10675] = 5613,
  [10676] = 10548,
  [10677] = 7819,
  [10678] = 7820,
  [10679] = 7821,
  [10680] = 7822,
  [10681] = 9296,
  [10682] = 10559,
  [10683] = 9406,
  [10684] = 9407,
  [10685] = 10685,
  [10686] = 9405,
  [10687] = 9408,
  [10688] = 9409,
  [10689] = 9163,
  [10690] = 10690,
  [10691] = 10549,
  [10692] = 8479,
  [10693] = 10356,
  [10694] = 8481,
  [10695] = 8487,
  [10696] = 8493,
  [10697] = 8494,
  [10698] = 8495,
  [10699] = 10519,
  [10700] = 10314,
  [10701] = 8496,
  [10702] = 8500,
  [10703] = 8438,
  [10704] = 8441,
  [10705] = 8442,
  [10706] = 7868,
  [10707] = 9845,
  [10708] = 8445,
  [10709] = 7834,
  [10710] = 8446,
  [10711] = 9282,
  [10712] = 10314,
  [10713] = 8614,
  [10714] = 9416,
  [10715] = 9417,
  [10716] = 9418,
  [10717] = 10315,
  [10718] = 8445,
  [10719] = 9419,
  [10720] = 4785,
  [10721] = 7849,
  [10722] = 10374,
  [10723] = 10723,
  [10724] = 10559,
  [10725] = 10559,
  [10726] = 10690,
  [10727] = 10096,
  [10728] = 10728,
  [10729] = 9510,
  [10730] = 10723,
  [10731] = 8457,
  [10732] = 10096,
  [10733] = 10728,
  [10734] = 10371,
  [10735] = 7765,
  [10736] = 7870,
  [10737] = 9426,
  [10738] = 9427,
  [10739] = 9428,
  [10740] = 9429,
  [10741] = 9430,
  [10742] = 9431,
  [10743] = 10559,
  [10744] = 5513,
  [10745] = 3460,
  [10746] = 10045,
  [10747] = 8181,
  [10748] = 9163,
  [10749] = 9435,
  [10750] = 9436,
  [10751] = 9437,
  [10752] = 8488,
  [10753] = 5655,
  [10754] = 9484,
  [10755] = 9289,
  [10756] = 9440,
  [10757] = 3374,
  [10758] = 10758,
  [10759] = 10559,
  [10760] = 5687,
  [10761] = 3377,
  [10762] = 3248,
  [10763] = 10315,
  [10764] = 5687,
  [10765] = 7781,
  [10766] = 3392,
  [10767] = 9395,
  [10768] = 3255,
  [10769] = 10559,
  [10770] = 7740,
  [10771] = 8461,
  [10772] = 7742,
  [10773] = 10773,
  [10774] = 8544,
  [10775] = 8548,
  [10776] = 5583,
  [10777] = 8523,
  [10778] = 8525,
  [10779] = 8526,
  [10780] = 5469,
  [10781] = 3450,
  [10782] = 3453,
  [10783] = 10546,
  [10784] = 3456,
  [10785] = 3459,
  [10786] = 9845,
  [10787] = 3351,
  [10788] = 10560,
  [10789] = 10559,
  [10790] = 7770,
  [10791] = 9402,
  [10792] = 9403,
  [10793] = 9445,
  [10794] = 9404,
  [10795] = 7754,
  [10796] = 10563,
  [10797] = 3295,
  [10798] = 10798,
  [10799] = 10799,
  [10800] = 10800,
  [10801] = 10801,
  [10802] = 10802,
  [10803] = 10803,
  [10804] = 10804,
  [10805] = 10805,
  [10806] = 8445,
  [10807] = 10807,
  [10808] = 4785,
  [10809] = 10809,
  [10810] = 8313,
  [10811] = 10811,
  [10812] = 10812,
  [10813] = 10801,
  [10814] = 10814,
  [10815] = 10815,
  [10816] = 10816,
  [10817] = 10817,
  [10818] = 10801,
  [10819] = 10819,
  [10820] = 10820,
  [10821] = 10821,
  [10822] = 10822,
  [10823] = 8431,
  [10824] = 8479,
  [10825] = 8481,
  [10826] = 8487,
  [10827] = 8493,
  [10828] = 8494,
  [10829] = 8495,
  [10830] = 8496,
  [10831] = 4788,
  [10832] = 8500,
  [10833] = 8438,
  [10834] = 8441,
  [10835] = 8442,
  [10836] = 10310,
  [10837] = 10045,
  [10838] = 10801,
  [10839] = 10839,
  [10840] = 10624,
  [10841] = 10841,
  [10842] = 10801,
  [10843] = 10843,
  [10844] = 10844,
  [10845] = 8445,
  [10846] = 8426,
  [10847] = 10847,
  [10848] = 8499,
  [10849] = 10801,
  [10850] = 10850,
  [10851] = 10851,
  [10852] = 10801,
  [10853] = 10853,
  [10854] = 9286,
  [10855] = 10855,
  [10856] = 10801,
  [10857] = 10801,
  [10858] = 8271,
  [10859] = 8330,
  [10860] = 9282,
  [10861] = 10861,
  [10862] = 8446,
  [10863] = 10863,
  [10864] = 10864,
  [10865] = 10865,
  [10866] = 9458,
  [10867] = 8525,
  [10868] = 10801,
  [10869] = 10519,
  [10870] = 10801,
  [10871] = 10871,
  [10872] = 8526,
  [10873] = 10314,
  [10874] = 10874,
  [10875] = 10875,
  [10876] = 8433,
  [10877] = 8193,
  [10878] = 10801,
  [10879] = 10879,
  [10880] = 10801,
  [10881] = 8209,
  [10882] = 10882,
  [10883] = 10883,
  [10884] = 10339,
  [10885] = 10801,
  [10886] = 8228,
  [10887] = 10887,
  [10888] = 8454,
  [10889] = 10889,
  [10890] = 8553,
  [10891] = 8449,
  [10892] = 10801,
  [10893] = 8488,
  [10894] = 3362,
  [10895] = 10801,
  [10896] = 10896,
  [10897] = 10356,
  [10898] = 10898,
  [10899] = 10801,
  [10900] = 9773,
  [10901] = 5687,
  [10902] = 10902,
  [10903] = 10903,
  [10904] = 10442,
  [10905] = 10905,
  [10906] = 10906,
  [10907] = 10907,
  [10908] = 10908,
  [10909] = 10909,
  [10910] = 10910,
  [10911] = 10911,
  [10912] = 10912,
  [10913] = 5468,
  [10914] = 10914,
  [10915] = 10801,
  [10916] = 10916,
  [10917] = 8520,
  [10918] = 10918,
  [10919] = 10919,
  [10920] = 10920,
  [10921] = 10801,
  [10922] = 10922,
  [10923] = 10923,
  [10924] = 10690,
  [10925] = 10925,
  [10926] = 10926,
  [10927] = 10927,
  [10928] = 9395,
  [10929] = 8614,
  [10930] = 8183,
  [10931] = 10801,
  [10932] = 10932,
  [10933] = 10933,
  [10934] = 10934,
  [10935] = 8479,
  [10936] = 10936,
  [10937] = 10937,
  [10938] = 8481,
  [10939] = 10939,
  [10940] = 8487,
  [10941] = 10941,
  [10942] = 10942,
  [10943] = 10943,
  [10944] = 10944,
  [10945] = 10945,
  [10946] = 8488,
  [10947] = 10947,
  [10948] = 8493,
  [10949] = 10045,
  [10950] = 8494,
  [10951] = 10951,
  [10952] = 8495,
  [10953] = 8496,
  [10954] = 8500,
  [10955] = 9484,
  [10956] = 9485,
  [10957] = 8438,
  [10958] = 8441,
  [10959] = 8442,
  [10960] = 10723,
  [10961] = 10310,
  [10962] = 10962,
  [10963] = 8224,
  [10964] = 4860,
  [10965] = 9289,
  [10966] = 10966,
  [10967] = 10967,
  [10968] = 10968,
  [10969] = 10969,
  [10970] = 10801,
  [10971] = 10971,
  [10972] = 10801,
  [10973] = 9402,
  [10974] = 9403,
  [10975] = 10975,
  [10976] = 10801,
  [10977] = 9404,
  [10978] = 9405,
  [10979] = 10979,
  [10980] = 8461,
  [10981] = 10981,
  [10982] = 10982,
  [10983] = 9840,
  [10984] = 8439,
  [10985] = 10985,
  [10986] = 10986,
  [10987] = 10987,
  [10988] = 10988,
  [10989] = 10728,
  [10990] = 10990,
  [10991] = 10991,
  [10992] = 10992,
  [10993] = 10993,
  [10994] = 10994,
  [10995] = 10995,
  [10996] = 10996,
  [10997] = 10997,
  [10998] = 10998,
  [10999] = 10999,
  [11000] = 11000,
  [11001] = 11001,
  [11002] = 11002,
  [11003] = 11003,
  [11004] = 11004,
  [11005] = 11005,
  [11006] = 11006,
  [11007] = 11007,
  [11008] = 11008,
  [11009] = 8333,
  [11010] = 11010,
  [11011] = 11011,
  [11012] = 11012,
  [11013] = 11013,
  [11014] = 11014,
  [11015] = 11015,
  [11016] = 11016,
  [11017] = 11017,
  [11018] = 11018,
  [11019] = 11019,
  [11020] = 11020,
  [11021] = 11021,
  [11022] = 11022,
  [11023] = 11023,
  [11024] = 11024,
  [11025] = 10801,
  [11026] = 10561,
  [11027] = 10801,
  [11028] = 8446,
  [11029] = 11029,
  [11030] = 10981,
  [11031] = 10801,
  [11032] = 5533,
  [11033] = 10985,
  [11034] = 10986,
  [11035] = 11035,
  [11036] = 10987,
  [11037] = 10991,
  [11038] = 10992,
  [11039] = 10993,
  [11040] = 10994,
  [11041] = 10995,
  [11042] = 10996,
  [11043] = 10798,
  [11044] = 10997,
  [11045] = 10998,
  [11046] = 10999,
  [11047] = 11000,
  [11048] = 11001,
  [11049] = 11002,
  [11050] = 11050,
  [11051] = 11004,
  [11052] = 11005,
  [11053] = 11006,
  [11054] = 11007,
  [11055] = 11008,
  [11056] = 8416,
  [11057] = 11010,
  [11058] = 11011,
  [11059] = 11012,
  [11060] = 11013,
  [11061] = 11014,
  [11062] = 11015,
  [11063] = 11016,
  [11064] = 11017,
  [11065] = 11018,
  [11066] = 11019,
  [11067] = 11020,
  [11068] = 11021,
  [11069] = 11022,
  [11070] = 9510,
  [11071] = 8425,
  [11072] = 10096,
  [11073] = 10801,
  [11074] = 11074,
  [11075] = 11075,
  [11076] = 11076,
  [11077] = 11077,
  [11078] = 11078,
  [11079] = 11079,
  [11080] = 11074,
  [11081] = 11075,
  [11082] = 11082,
  [11083] = 11083,
  [11084] = 11084,
  [11085] = 11085,
  [11086] = 11086,
  [11087] = 11087,
  [11088] = 11088,
  [11089] = 11089,
  [11090] = 11090,
  [11091] = 9406,
  [11092] = 9407,
  [11093] = 10371,
  [11094] = 10801,
  [11095] = 9408,
  [11096] = 9409,
  [11097] = 11097,
  [11098] = 11098,
  [11099] = 11099,
  [11100] = 11100,
  [11101] = 11101,
  [11102] = 5655,
  [11103] = 11103,
  [11104] = 11104,
  [11105] = 5471,
  [11106] = 10801,
  [11107] = 10045,
  [11108] = 9384,
  [11109] = 8430,
  [11110] = 9393,
  [11111] = 11111,
  [11112] = 10801,
  [11113] = 11113,
  [11114] = 9445,
  [11115] = 11115,
  [11116] = 11116,
  [11117] = 11117,
  [11118] = 8178,
  [11119] = 8182,
  [11120] = 10519,
  [11121] = 8498,
  [11122] = 10801,
  [11123] = 8179,
  [11124] = 8548,
  [11125] = 8264,
  [11126] = 10801,
  [11127] = 8498,
  [11128] = 11128,
  [11129] = 8457,
  [11130] = 10801,
  [11131] = 11131,
  [11132] = 8523,
  [11133] = 11133,
  [11134] = 9312,
  [11135] = 11135,
  [11136] = 10314,
  [11137] = 10339,
  [11138] = 11138,
  [11139] = 10801,
  [11140] = 11140,
  [11141] = 11141,
  [11142] = 11142,
  [11143] = 11143,
  [11144] = 11144,
  [11145] = 8189,
  [11146] = 9416,
  [11147] = 3374,
  [11148] = 9417,
  [11149] = 9418,
  [11150] = 9419,
  [11151] = 11151,
  [11152] = 11152,
  [11153] = 10801,
  [11154] = 11154,
  [11155] = 11155,
  [11156] = 11156,
  [11157] = 8200,
  [11158] = 11158,
  [11159] = 11159,
  [11160] = 11160,
  [11161] = 11161,
  [11162] = 11162,
  [11163] = 10356,
  [11164] = 9486,
  [11165] = 11165,
  [11166] = 10801,
  [11167] = 11167,
  [11168] = 3360,
  [11169] = 11169,
  [11170] = 8439,
  [11171] = 10801,
  [11172] = 8461,
  [11173] = 8218,
  [11174] = 11174,
  [11175] = 10315,
  [11176] = 11176,
  [11177] = 10339,
  [11178] = 8453,
  [11179] = 8457,
  [11180] = 3377,
  [11181] = 3248,
  [11182] = 3392,
  [11183] = 9296,
  [11184] = 10801,
  [11185] = 9426,
  [11186] = 9427,
  [11187] = 9428,
  [11188] = 9429,
  [11189] = 9430,
  [11190] = 11190,
  [11191] = 9431,
  [11192] = 11192,
  [11193] = 11193,
  [11194] = 11194,
  [11195] = 11195,
  [11196] = 11196,
  [11197] = 10801,
  [11198] = 4789,
  [11199] = 11199,
  [11200] = 10374,
  [11201] = 11201,
  [11202] = 9435,
  [11203] = 9436,
  [11204] = 9437,
  [11205] = 11205,
  [11206] = 8233,
  [11207] = 8180,
  [11208] = 8195,
  [11209] = 10801,
  [11210] = 11210,
  [11211] = 9163,
  [11212] = 11212,
  [11213] = 11213,
  [11214] = 9440,
  [11215] = 11215,
  [11216] = 11216,
  [11217] = 10801,
  [11218] = 10962,
  [11219] = 10979,
  [11220] = 9845,
  [11221] = 11221,
  [11222] = 11222,
  [11223] = 11035,
  [11224] = 11224,
  [11225] = 7868,
  [11226] = 10801,
  [11227] = 11227,
  [11228] = 8192,
  [11229] = 11229,
  [11230] = 11230,
  [11231] = 11231,
  [11232] = 11232,
  [11233] = 10442,
  [11234] = 10801,
  [11235] = 10315,
  [11236] = 11236,
  [11237] = 10546,
  [11238] = 10547,
  [11239] = 10548,
  [11240] = 10549,
  [11241] = 11241,
  [11242] = 10801,
  [11243] = 11241,
  [11244] = 9355,
  [11245] = 11245,
  [11246] = 11246,
  [11247] = 8544,
  [11248] = 11003,
  [11249] = 11249,
  [11250] = 11250,
  [11251] = 9435,
  [11252] = 9437,
  [11253] = 11018,
  [11254] = 9404,
  [11255] = 3392,
  [11256] = 9436,
  [11257] = 9437,
  [11258] = 11250,
  [11259] = 11002,
  [11260] = 9426,
  [11261] = 10690,
  [11262] = 9409,
  [11263] = 8442,
  [11264] = 11250,
  [11265] = 9407,
  [11266] = 11019,
  [11267] = 10988,
  [11268] = 11268,
  [11269] = 11250,
  [11270] = 9416,
  [11271] = 11001,
  [11272] = 8520,
  [11273] = 9431,
  [11274] = 9395,
  [11275] = 11275,
  [11276] = 9416,
  [11277] = 10994,
  [11278] = 3374,
  [11279] = 9417,
  [11280] = 9418,
  [11281] = 9419,
  [11282] = 11250,
  [11283] = 10962,
  [11284] = 5687,
  [11285] = 8500,
  [11286] = 10315,
  [11287] = 9419,
  [11288] = 10315,
  [11289] = 10962,
  [11290] = 10979,
  [11291] = 10356,
  [11292] = 11250,
  [11293] = 11293,
  [11294] = 11294,
  [11295] = 5687,
  [11296] = 11249,
  [11297] = 11297,
  [11298] = 11035,
  [11299] = 11299,
  [11300] = 9440,
  [11301] = 11301,
  [11302] = 9440,
  [11303] = 10979,
  [11304] = 10624,
  [11305] = 8487,
  [11306] = 9427,
  [11307] = 11307,
  [11308] = 9408,
  [11309] = 10987,
  [11310] = 11310,
  [11311] = 9426,
  [11312] = 9427,
  [11313] = 9428,
  [11314] = 9429,
  [11315] = 9430,
  [11316] = 3374,
  [11317] = 11250,
  [11318] = 11310,
  [11319] = 9426,
  [11320] = 9427,
  [11321] = 10723,
  [11322] = 3377,
  [11323] = 3248,
  [11324] = 9428,
  [11325] = 10728,
  [11326] = 9428,
  [11327] = 9429,
  [11328] = 9430,
  [11329] = 9431,
  [11330] = 11035,
  [11331] = 8496,
  [11332] = 5655,
  [11333] = 9312,
  [11334] = 3392,
  [11335] = 11250,
  [11336] = 9431,
  [11337] = 3377,
  [11338] = 10992,
  [11339] = 10356,
  [11340] = 10045,
  [11341] = 9417,
  [11342] = 11249,
  [11343] = 11343,
  [11344] = 9402,
  [11345] = 10991,
  [11346] = 9435,
  [11347] = 9430,
  [11348] = 11020,
  [11349] = 9395,
  [11350] = 9403,
  [11351] = 9404,
  [11352] = 11035,
  [11353] = 3377,
  [11354] = 11354,
  [11355] = 3248,
  [11356] = 9436,
  [11357] = 9437,
  [11358] = 10982,
  [11359] = 5687,
  [11360] = 11250,
  [11361] = 9405,
  [11362] = 9440,
  [11363] = 5655,
  [11364] = 9402,
  [11365] = 9403,
  [11366] = 11250,
  [11367] = 11021,
  [11368] = 8494,
  [11369] = 11369,
  [11370] = 11022,
  [11371] = 11371,
  [11372] = 11369,
  [11373] = 11250,
  [11374] = 9445,
  [11375] = 8481,
  [11376] = 9405,
  [11377] = 9445,
  [11378] = 11250,
  [11379] = 11250,
  [11380] = 9402,
  [11381] = 9403,
  [11382] = 10442,
  [11383] = 10339,
  [11384] = 7751,
  [11385] = 9404,
  [11386] = 9355,
  [11387] = 10690,
  [11388] = 9395,
  [11389] = 8439,
  [11390] = 10310,
  [11391] = 10999,
  [11392] = 10993,
  [11393] = 3248,
  [11394] = 11394,
  [11395] = 8438,
  [11396] = 11396,
  [11397] = 8441,
  [11398] = 9405,
  [11399] = 9407,
  [11400] = 11310,
  [11401] = 9395,
  [11402] = 8498,
  [11403] = 11354,
  [11404] = 8457,
  [11405] = 11405,
  [11406] = 9405,
  [11407] = 10981,
  [11408] = 9445,
  [11409] = 10315,
  [11410] = 11410,
  [11411] = 10310,
  [11412] = 11010,
  [11413] = 11294,
  [11414] = 11003,
  [11415] = 9416,
  [11416] = 9458,
  [11417] = 11011,
  [11418] = 8614,
  [11419] = 11007,
  [11420] = 11004,
  [11421] = 10996,
  [11422] = 11250,
  [11423] = 11012,
  [11424] = 8495,
  [11425] = 11250,
  [11426] = 11426,
  [11427] = 10998,
  [11428] = 9418,
  [11429] = 5655,
  [11430] = 11430,
  [11431] = 10985,
  [11432] = 9426,
  [11433] = 3392,
  [11434] = 11434,
  [11435] = 11299,
  [11436] = 11294,
  [11437] = 9427,
  [11438] = 9428,
  [11439] = 9403,
  [11440] = 11440,
  [11441] = 11250,
  [11442] = 10442,
  [11443] = 10995,
  [11444] = 9429,
  [11445] = 9430,
  [11446] = 11446,
  [11447] = 5687,
  [11448] = 8488,
  [11449] = 11008,
  [11450] = 10310,
  [11451] = 9458,
  [11452] = 11426,
  [11453] = 9431,
  [11454] = 10997,
  [11455] = 11455,
  [11456] = 10519,
  [11457] = 9840,
  [11458] = 11430,
  [11459] = 9435,
  [11460] = 10356,
  [11461] = 11461,
  [11462] = 9417,
  [11463] = 9418,
  [11464] = 11299,
  [11465] = 9416,
  [11466] = 11343,
  [11467] = 11410,
  [11468] = 9417,
  [11469] = 9435,
  [11470] = 9436,
  [11471] = 9418,
  [11472] = 9437,
  [11473] = 11013,
  [11474] = 9419,
  [11475] = 11250,
  [11476] = 10798,
  [11477] = 9406,
  [11478] = 9407,
  [11479] = 11479,
  [11480] = 9408,
  [11481] = 8493,
  [11482] = 9409,
  [11483] = 11483,
  [11484] = 11074,
  [11485] = 9458,
  [11486] = 10561,
  [11487] = 11014,
  [11488] = 10314,
  [11489] = 11489,
  [11490] = 9406,
  [11491] = 9419,
  [11492] = 10519,
  [11493] = 11015,
  [11494] = 11394,
  [11495] = 11354,
  [11496] = 11016,
  [11497] = 11250,
  [11498] = 9436,
  [11499] = 10314,
  [11500] = 11017,
  [11501] = 11241,
  [11502] = 11268,
  [11503] = 9408,
  [11504] = 11005,
  [11505] = 9445,
  [11506] = 10519,
  [11507] = 9440,
  [11508] = 9406,
  [11509] = 9407,
  [11510] = 11510,
  [11511] = 8446,
  [11512] = 11075,
  [11513] = 11250,
  [11514] = 8614,
  [11515] = 10962,
  [11516] = 11516,
  [11517] = 10314,
  [11518] = 3374,
  [11519] = 8479,
  [11520] = 9406,
  [11521] = 9429,
  [11522] = 11000,
  [11523] = 5687,
  [11524] = 10986,
  [11525] = 11268,
  [11526] = 11250,
  [11527] = 11006,
  [11528] = 10979,
  [11529] = 9404,
  [11530] = 11250,
  [11531] = 11250,
  [11532] = 11532,
  [11533] = 9402,
  [11534] = 9458,
  [11535] = 9408,
  [11536] = 11510,
  [11537] = 11310,
  [11538] = 9409,
  [11539] = 11268,
  [11540] = 11249,
  [11541] = 11369,
  [11542] = 11294,
  [11543] = 11410,
  [11544] = 11461,
  [11545] = 11293,
  [11546] = 11297,
  [11547] = 11483,
  [11548] = 11516,
  [11549] = 11310,
  [11550] = 11268,
  [11551] = 11249,
  [11552] = 11294,
  [11553] = 9409,
  [11554] = 4860,
  [11555] = 11354,
  [11556] = 11299,
  [11557] = 11354,
  [11558] = 11310,
  [11559] = 11268,
  [11560] = 11249,
  [11561] = 11369,
  [11562] = 11294,
  [11563] = 11410,
  [11564] = 11299,
  [11565] = 10690,
  [11566] = 11354,
  [11567] = 11299,
  [11568] = 10442,
  [11569] = 11426,
  [11570] = 11013,
  [11571] = 11571,
  [11572] = 11014,
  [11573] = 11573,
  [11574] = 11015,
  [11575] = 8439,
  [11576] = 3377,
  [11577] = 9435,
  [11578] = 8461,
  [11579] = 11016,
  [11580] = 11017,
  [11581] = 11018,
  [11582] = 9436,
  [11583] = 11019,
  [11584] = 11020,
  [11585] = 9437,
  [11586] = 11021,
  [11587] = 11022,
  [11588] = 11588,
  [11589] = 11573,
  [11590] = 8496,
  [11591] = 8500,
  [11592] = 8438,
  [11593] = 8441,
  [11594] = 11573,
  [11595] = 8442,
  [11596] = 11430,
  [11597] = 5655,
  [11598] = 11573,
  [11599] = 11573,
  [11600] = 11600,
  [11601] = 11573,
  [11602] = 8445,
  [11603] = 8446,
  [11604] = 10315,
  [11605] = 11573,
  [11606] = 3255,
  [11607] = 11573,
  [11608] = 10962,
  [11609] = 11483,
  [11610] = 11573,
  [11611] = 9286,
  [11612] = 10979,
  [11613] = 3374,
  [11614] = 11573,
  [11615] = 11573,
  [11616] = 8445,
  [11617] = 10442,
  [11618] = 11618,
  [11619] = 8544,
  [11620] = 8548,
  [11621] = 8523,
  [11622] = 11573,
  [11623] = 8525,
  [11624] = 8526,
  [11625] = 10381,
  [11626] = 9458,
  [11627] = 11516,
  [11628] = 11075,
  [11629] = 11461,
  [11630] = 11573,
  [11631] = 3248,
  [11632] = 11573,
  [11633] = 10310,
  [11634] = 11035,
  [11635] = 11635,
  [11636] = 8488,
  [11637] = 11573,
  [11638] = 9416,
  [11639] = 11571,
  [11640] = 11573,
  [11641] = 11573,
  [11642] = 11573,
  [11643] = 11573,
  [11644] = 5687,
  [11645] = 11573,
  [11646] = 9440,
  [11647] = 11573,
  [11648] = 11648,
  [11649] = 10371,
  [11650] = 11573,
  [11651] = 10463,
  [11652] = 11426,
  [11653] = 11653,
  [11654] = 11654,
  [11655] = 9406,
  [11656] = 11430,
  [11657] = 11573,
  [11658] = 8479,
  [11659] = 11573,
  [11660] = 11635,
  [11661] = 10045,
  [11662] = 11662,
  [11663] = 11573,
  [11664] = 11035,
  [11665] = 11665,
  [11666] = 11666,
  [11667] = 11667,
  [11668] = 8461,
  [11669] = 10536,
  [11670] = 11573,
  [11671] = 4785,
  [11672] = 8481,
  [11673] = 9417,
  [11674] = 9418,
  [11675] = 3256,
  [11676] = 11666,
  [11677] = 9419,
  [11678] = 10356,
  [11679] = 11667,
  [11680] = 11680,
  [11681] = 10981,
  [11682] = 9163,
  [11683] = 9409,
  [11684] = 9407,
  [11685] = 11685,
  [11686] = 10962,
  [11687] = 11297,
  [11688] = 11573,
  [11689] = 8487,
  [11690] = 10339,
  [11691] = 11573,
  [11692] = 11011,
  [11693] = 11012,
  [11694] = 10985,
  [11695] = 9408,
  [11696] = 11696,
  [11697] = 10986,
  [11698] = 11600,
  [11699] = 11573,
  [11700] = 10987,
  [11701] = 11573,
  [11702] = 11618,
  [11703] = 11588,
  [11704] = 11654,
  [11705] = 10979,
  [11706] = 11293,
  [11707] = 9289,
  [11708] = 9445,
  [11709] = 11573,
  [11710] = 11618,
  [11711] = 9426,
  [11712] = 9427,
  [11713] = 11430,
  [11714] = 11573,
  [11715] = 3392,
  [11716] = 9428,
  [11717] = 11717,
  [11718] = 11573,
  [11719] = 10690,
  [11720] = 11074,
  [11721] = 11426,
  [11722] = 11722,
  [11723] = 8498,
  [11724] = 9429,
  [11725] = 9402,
  [11726] = 9395,
  [11727] = 9430,
  [11728] = 10991,
  [11729] = 10992,
  [11730] = 8614,
  [11731] = 10519,
  [11732] = 11732,
  [11733] = 11733,
  [11734] = 9431,
  [11735] = 8457,
  [11736] = 10314,
  [11737] = 11241,
  [11738] = 8520,
  [11739] = 11573,
  [11740] = 11573,
  [11741] = 11696,
  [11742] = 11653,
  [11743] = 10371,
  [11744] = 10993,
  [11745] = 11573,
  [11746] = 10994,
  [11747] = 10995,
  [11748] = 10996,
  [11749] = 11662,
  [11750] = 9296,
  [11751] = 11751,
  [11752] = 11573,
  [11753] = 10798,
  [11754] = 11573,
  [11755] = 11733,
  [11756] = 9403,
  [11757] = 8493,
  [11758] = 11680,
  [11759] = 11717,
  [11760] = 8494,
  [11761] = 10997,
  [11762] = 9404,
  [11763] = 10998,
  [11764] = 11732,
  [11765] = 9405,
  [11766] = 10999,
  [11767] = 11767,
  [11768] = 11573,
  [11769] = 11685,
  [11770] = 11000,
  [11771] = 8499,
  [11772] = 11001,
  [11773] = 11002,
  [11774] = 11003,
  [11775] = 11004,
  [11776] = 11573,
  [11777] = 11573,
  [11778] = 11573,
  [11779] = 4789,
  [11780] = 11005,
  [11781] = 9282,
  [11782] = 11006,
  [11783] = 11007,
  [11784] = 11665,
  [11785] = 11008,
  [11786] = 11767,
  [11787] = 11573,
  [11788] = 11573,
  [11789] = 11722,
  [11790] = 11751,
  [11791] = 8495,
  [11792] = 11010,
  [11793] = 4788,
  [11794] = 11794,
  [11795] = 11795,
  [11796] = 11796,
  [11797] = 11797,
  [11798] = 11798,
  [11799] = 11799,
  [11800] = 11800,
  [11801] = 11801,
  [11802] = 11802,
  [11803] = 11803,
  [11804] = 11797,
  [11805] = 11798,
  [11806] = 11806,
  [11807] = 11799,
  [11808] = 11795,
  [11809] = 11796,
  [11810] = 11797,
  [11811] = 11798,
  [11812] = 11799,
  [11813] = 11800,
  [11814] = 11801,
  [11815] = 11802,
  [11816] = 11803,
  [11817] = 8488,
  [11818] = 11806,
  [11819] = 8445,
  [11820] = 11795,
  [11821] = 8498,
  [11822] = 11796,
  [11823] = 11823,
  [11824] = 11797,
  [11825] = 11798,
  [11826] = 11799,
  [11827] = 11800,
  [11828] = 11801,
  [11829] = 11802,
  [11830] = 11803,
  [11831] = 8488,
  [11832] = 11795,
  [11833] = 11833,
  [11834] = 11806,
  [11835] = 9312,
  [11836] = 11795,
  [11837] = 11653,
  [11838] = 11662,
  [11839] = 11796,
  [11840] = 11797,
  [11841] = 11798,
  [11842] = 11799,
  [11843] = 11800,
  [11844] = 11801,
  [11845] = 11802,
  [11846] = 11803,
  [11847] = 11806,
  [11848] = 8457,
  [11849] = 11849,
  [11850] = 11806,
  [11851] = 11795,
  [11852] = 11852,
  [11853] = 11796,
  [11854] = 11797,
  [11855] = 11798,
  [11856] = 11799,
  [11857] = 11800,
  [11858] = 11801,
  [11859] = 11802,
  [11860] = 11803,
  [11861] = 11861,
  [11862] = 11806,
  [11863] = 11795,
  [11864] = 11796,
  [11865] = 9355,
  [11866] = 11797,
  [11867] = 11798,
  [11868] = 11799,
  [11869] = 11800,
  [11870] = 11801,
  [11871] = 11802,
  [11872] = 11803,
  [11873] = 11806,
  [11874] = 11806,
  [11875] = 11795,
  [11876] = 11796,
  [11877] = 11797,
  [11878] = 11798,
  [11879] = 11799,
  [11880] = 11800,
  [11881] = 11801,
  [11882] = 11802,
  [11883] = 11803,
  [11884] = 11800,
  [11885] = 11885,
  [11886] = 11806,
  [11887] = 11795,
  [11888] = 11796,
  [11889] = 11797,
  [11890] = 11798,
  [11891] = 11799,
  [11892] = 11800,
  [11893] = 11801,
  [11894] = 11802,
  [11895] = 11803,
  [11896] = 11795,
  [11897] = 11806,
  [11898] = 11795,
  [11899] = 11801,
  [11900] = 11796,
  [11901] = 11797,
  [11902] = 11798,
  [11903] = 11799,
  [11904] = 11800,
  [11905] = 11801,
  [11906] = 11802,
  [11907] = 11803,
  [11908] = 11802,
  [11909] = 11806,
  [11910] = 11910,
  [11911] = 11795,
  [11912] = 11912,
  [11913] = 11796,
  [11914] = 11914,
  [11915] = 11797,
  [11916] = 11798,
  [11917] = 11799,
  [11918] = 11800,
  [11919] = 11801,
  [11920] = 11802,
  [11921] = 11803,
  [11922] = 11806,
  [11923] = 11795,
  [11924] = 11796,
  [11925] = 11796,
  [11926] = 11797,
  [11927] = 11798,
  [11928] = 11799,
  [11929] = 11800,
  [11930] = 11801,
  [11931] = 11802,
  [11932] = 11803,
  [11933] = 11806,
  [11934] = 11795,
  [11935] = 11796,
  [11936] = 11797,
  [11937] = 11798,
  [11938] = 11799,
  [11939] = 11800,
  [11940] = 11801,
  [11941] = 11802,
  [11942] = 11803,
  [11943] = 11943,
  [11944] = 11806,
  [11945] = 11795,
  [11946] = 11797,
  [11947] = 11798,
  [11948] = 11799,
  [11949] = 11796,
  [11950] = 11797,
  [11951] = 11798,
  [11952] = 11799,
  [11953] = 11800,
  [11954] = 11801,
  [11955] = 11802,
  [11956] = 11803,
  [11957] = 11806,
  [11958] = 11800,
  [11959] = 11801,
  [11960] = 11795,
  [11961] = 11802,
  [11962] = 11796,
  [11963] = 11803,
  [11964] = 11797,
  [11965] = 11798,
  [11966] = 11799,
  [11967] = 11800,
  [11968] = 11801,
  [11969] = 11802,
  [11970] = 11803,
  [11971] = 11733,
  [11972] = 11665,
  [11973] = 11806,
  [11974] = 11795,
  [11975] = 11680,
  [11976] = 11796,
  [11977] = 11797,
  [11978] = 11798,
  [11979] = 11799,
  [11980] = 11800,
  [11981] = 11801,
  [11982] = 11802,
  [11983] = 11803,
  [11984] = 11717,
  [11985] = 11722,
  [11986] = 11806,
  [11987] = 11795,
  [11988] = 11796,
  [11989] = 11797,
  [11990] = 11798,
  [11991] = 11799,
  [11992] = 11800,
  [11993] = 11801,
  [11994] = 11802,
  [11995] = 11803,
  [11996] = 9845,
  [11997] = 11806,
  [11998] = 11795,
  [11999] = 11796,
  [12000] = 11797,
  [12001] = 11798,
  [12002] = 11799,
  [12003] = 11800,
  [12004] = 11801,
  [12005] = 11802,
  [12006] = 11803,
  [12007] = 11806,
  [12008] = 11795,
  [12009] = 11796,
  [12010] = 11797,
  [12011] = 11798,
  [12012] = 11799,
  [12013] = 11800,
  [12014] = 11801,
  [12015] = 11802,
  [12016] = 11803,
  [12017] = 11806,
  [12018] = 12018,
  [12019] = 11795,
  [12020] = 11796,
  [12021] = 11797,
  [12022] = 11798,
  [12023] = 11799,
  [12024] = 11800,
  [12025] = 11801,
  [12026] = 11802,
  [12027] = 11803,
  [12028] = 11806,
  [12029] = 11795,
  [12030] = 11767,
  [12031] = 11796,
  [12032] = 11797,
  [12033] = 11798,
  [12034] = 11799,
  [12035] = 11800,
  [12036] = 11801,
  [12037] = 11802,
  [12038] = 11803,
  [12039] = 11803,
  [12040] = 12040,
  [12041] = 11806,
  [12042] = 11795,
  [12043] = 11796,
  [12044] = 11797,
  [12045] = 11798,
  [12046] = 11799,
  [12047] = 11800,
  [12048] = 11801,
  [12049] = 11802,
  [12050] = 11803,
  [12051] = 11806,
  [12052] = 11795,
  [12053] = 11796,
  [12054] = 11797,
  [12055] = 11798,
  [12056] = 11799,
  [12057] = 11800,
  [12058] = 11801,
  [12059] = 11802,
  [12060] = 11803,
  [12061] = 11806,
  [12062] = 11795,
  [12063] = 11796,
  [12064] = 11797,
  [12065] = 11798,
  [12066] = 11799,
  [12067] = 11800,
  [12068] = 11801,
  [12069] = 11802,
  [12070] = 11803,
  [12071] = 11806,
  [12072] = 11795,
  [12073] = 11796,
  [12074] = 11797,
  [12075] = 11798,
  [12076] = 11799,
  [12077] = 11800,
  [12078] = 11801,
  [12079] = 11802,
  [12080] = 11803,
  [12081] = 11732,
  [12082] = 11806,
  [12083] = 11795,
  [12084] = 11796,
  [12085] = 11797,
  [12086] = 11798,
  [12087] = 11799,
  [12088] = 11800,
  [12089] = 11801,
  [12090] = 11802,
  [12091] = 11803,
  [12092] = 11806,
  [12093] = 11795,
  [12094] = 11796,
  [12095] = 11797,
  [12096] = 11798,
  [12097] = 11799,
  [12098] = 11800,
  [12099] = 11801,
  [12100] = 11802,
  [12101] = 11803,
  [12102] = 11806,
  [12103] = 11795,
  [12104] = 11796,
  [12105] = 11797,
  [12106] = 11798,
  [12107] = 11799,
  [12108] = 11800,
  [12109] = 11801,
  [12110] = 11802,
  [12111] = 11803,
  [12112] = 12112,
  [12113] = 11806,
  [12114] = 8498,
  [12115] = 8457,
  [12116] = 11795,
  [12117] = 11796,
  [12118] = 11797,
  [12119] = 11798,
  [12120] = 11799,
  [12121] = 11800,
  [12122] = 11801,
  [12123] = 11802,
  [12124] = 11803,
  [12125] = 11806,
  [12126] = 11795,
  [12127] = 11654,
  [12128] = 11796,
  [12129] = 11797,
  [12130] = 11798,
  [12131] = 11799,
  [12132] = 11800,
  [12133] = 11801,
  [12134] = 11802,
  [12135] = 11803,
  [12136] = 11806,
  [12137] = 11795,
  [12138] = 11861,
  [12139] = 11796,
  [12140] = 11797,
  [12141] = 11798,
  [12142] = 11799,
  [12143] = 11800,
  [12144] = 11801,
  [12145] = 11802,
  [12146] = 11803,
  [12147] = 11806,
  [12148] = 11795,
  [12149] = 11796,
  [12150] = 11797,
  [12151] = 11798,
  [12152] = 11799,
  [12153] = 11800,
  [12154] = 11801,
  [12155] = 11802,
  [12156] = 11803,
  [12157] = 11806,
  [12158] = 11806,
  [12159] = 11795,
  [12160] = 11696,
  [12161] = 11796,
  [12162] = 11797,
  [12163] = 11798,
  [12164] = 11799,
  [12165] = 11800,
  [12166] = 11801,
  [12167] = 11802,
  [12168] = 11803,
  [12169] = 11806,
  [12170] = 11795,
  [12171] = 11796,
  [12172] = 11797,
  [12173] = 11798,
  [12174] = 11799,
  [12175] = 11800,
  [12176] = 11801,
  [12177] = 11802,
  [12178] = 11803,
  [12179] = 11806,
  [12180] = 11795,
  [12181] = 11796,
  [12182] = 11797,
  [12183] = 11798,
  [12184] = 11799,
  [12185] = 11800,
  [12186] = 11801,
  [12187] = 11802,
  [12188] = 11803,
  [12189] = 11806,
  [12190] = 11795,
  [12191] = 11796,
  [12192] = 11795,
  [12193] = 11797,
  [12194] = 11798,
  [12195] = 11799,
  [12196] = 11800,
  [12197] = 11801,
  [12198] = 11802,
  [12199] = 11803,
  [12200] = 11806,
  [12201] = 11795,
  [12202] = 11796,
  [12203] = 11797,
  [12204] = 11798,
  [12205] = 11799,
  [12206] = 11806,
  [12207] = 11801,
  [12208] = 11802,
  [12209] = 11803,
  [12210] = 11806,
  [12211] = 11795,
  [12212] = 11796,
  [12213] = 11797,
  [12214] = 11798,
  [12215] = 11799,
  [12216] = 11800,
  [12217] = 11801,
  [12218] = 11802,
  [12219] = 11803,
  [12220] = 8488,
  [12221] = 10962,
  [12222] = 10979,
  [12223] = 11035,
  [12224] = 11794,
  [12225] = 11796,
  [12226] = 12226,
  [12227] = 10371,
  [12228] = 12228,
  [12229] = 12229,
  [12230] = 11797,
  [12231] = 11798,
  [12232] = 11799,
  [12233] = 11800,
  [12234] = 11801,
  [12235] = 11802,
  [12236] = 11803,
  [12237] = 8479,
  [12238] = 8481,
  [12239] = 8487,
  [12240] = 8493,
  [12241] = 8494,
  [12242] = 8495,
  [12243] = 8496,
  [12244] = 8500,
  [12245] = 8438,
  [12246] = 8441,
  [12247] = 8442,
  [12248] = 8446,
  [12249] = 11910,
  [12250] = 12250,
  [12251] = 12251,
  [12252] = 11912,
  [12253] = 8461,
  [12254] = 12226,
  [12255] = 12255,
  [12256] = 11914,
  [12257] = 11751,
  [12258] = 8479,
  [12259] = 8481,
  [12260] = 8487,
  [12261] = 8493,
  [12262] = 8494,
  [12263] = 8495,
  [12264] = 8496,
  [12265] = 8500,
  [12266] = 8438,
  [12267] = 8441,
  [12268] = 8442,
  [12269] = 8445,
  [12270] = 8446,
  [12271] = 12226,
  [12272] = 11806,
  [12273] = 8499,
  [12274] = 8614,
  [12275] = 8439,
  [12276] = 8461,
  [12277] = 10962,
  [12278] = 10979,
  [12279] = 11035,
  [12280] = 12226,
  [12281] = 8544,
  [12282] = 8548,
  [12283] = 8523,
  [12284] = 8525,
  [12285] = 8526,
  [12286] = 11795,
  [12287] = 11426,
  [12288] = 11430,
  [12289] = 12226,
  [12290] = 11796,
  [12291] = 12226,
  [12292] = 12226,
  [12293] = 11797,
  [12294] = 11798,
  [12295] = 11799,
  [12296] = 11800,
  [12297] = 11801,
  [12298] = 11802,
  [12299] = 12226,
  [12300] = 12300,
  [12301] = 11803,
  [12302] = 11426,
  [12303] = 12226,
  [12304] = 11430,
  [12305] = 8439,
  [12306] = 12226,
  [12307] = 12226,
  [12308] = 11600,
  [12309] = 12309,
  [12310] = 11796,
  [12311] = 10962,
  [12312] = 10979,
  [12313] = 11035,
  [12314] = 12226,
  [12315] = 12226,
  [12316] = 12226,
  [12317] = 11806,
  [12318] = 12226,
  [12319] = 12226,
  [12320] = 12226,
  [12321] = 11795,
  [12322] = 12226,
  [12323] = 12226,
  [12324] = 12226,
  [12325] = 11796,
  [12326] = 12226,
  [12327] = 12226,
  [12328] = 11797,
  [12329] = 11798,
  [12330] = 11799,
  [12331] = 12226,
  [12332] = 11800,
  [12333] = 11801,
  [12334] = 11802,
  [12335] = 12226,
  [12336] = 11803,
  [12337] = 12226,
  [12338] = 12226,
  [12339] = 12226,
  [12340] = 12226,
  [12341] = 11635,
  [12342] = 12226,
  [12343] = 12226,
  [12344] = 12226,
  [12345] = 12226,
  [12346] = 12226,
  [12347] = 12226,
  [12348] = 11666,
  [12349] = 12226,
  [12350] = 11667,
  [12351] = 12226,
  [12352] = 10690,
  [12353] = 11852,
  [12354] = 11806,
  [12355] = 12226,
  [12356] = 12226,
  [12357] = 12226,
  [12358] = 12226,
  [12359] = 12226,
  [12360] = 11795,
  [12361] = 11852,
  [12362] = 11796,
  [12363] = 11665,
  [12364] = 11666,
  [12365] = 11667,
  [12366] = 11797,
  [12367] = 11798,
  [12368] = 11799,
  [12369] = 11696,
  [12370] = 11733,
  [12371] = 11800,
  [12372] = 11801,
  [12373] = 11802,
  [12374] = 11803,
  [12375] = 11571,
  [12376] = 12376,
  [12377] = 11685,
  [12378] = 10442,
  [12379] = 10310,
  [12380] = 12228,
  [12381] = 11588,
  [12382] = 12382,
  [12383] = 11885,
  [12384] = 11665,
  [12385] = 11666,
  [12386] = 11667,
  [12387] = 11696,
  [12388] = 10356,
  [12389] = 11733,
  [12390] = 11806,
  [12391] = 10519,
  [12392] = 10314,
  [12393] = 11795,
  [12394] = 10315,
  [12395] = 11796,
  [12396] = 11797,
  [12397] = 11798,
  [12398] = 11799,
  [12399] = 11800,
  [12400] = 11801,
  [12401] = 11802,
  [12402] = 11803,
  [12403] = 12226,
  [12404] = 11943,
  [12405] = 11461,
  [12406] = 11293,
  [12407] = 11297,
  [12408] = 11483,
  [12409] = 8498,
  [12410] = 8457,
  [12411] = 11516,
  [12412] = 4860,
  [12413] = 11800,
  [12414] = 8520,
  [12415] = 12415,
  [12416] = 12416,
  [12417] = 12228,
  [12418] = 12418,
  [12419] = 8442,
  [12420] = 10339,
  [12421] = 8457,
  [12422] = 3374,
  [12423] = 9406,
  [12424] = 9407,
  [12425] = 8614,
  [12426] = 8446,
  [12427] = 9408,
  [12428] = 9409,
  [12429] = 12418,
  [12430] = 3377,
  [12431] = 3248,
  [12432] = 3392,
  [12433] = 11943,
  [12434] = 8479,
  [12435] = 8488,
  [12436] = 8461,
  [12437] = 8457,
  [12438] = 11426,
  [12439] = 11885,
  [12440] = 12440,
  [12441] = 11426,
  [12442] = 8445,
  [12443] = 11430,
  [12444] = 11600,
  [12445] = 11794,
  [12446] = 9416,
  [12447] = 9417,
  [12448] = 9418,
  [12449] = 9419,
  [12450] = 8481,
  [12451] = 12451,
  [12452] = 11635,
  [12453] = 11571,
  [12454] = 5687,
  [12455] = 9426,
  [12456] = 9427,
  [12457] = 9428,
  [12458] = 9429,
  [12459] = 9430,
  [12460] = 12228,
  [12461] = 9431,
  [12462] = 9435,
  [12463] = 8499,
  [12464] = 9436,
  [12465] = 9437,
  [12466] = 9440,
  [12467] = 11654,
  [12468] = 11588,
  [12469] = 11653,
  [12470] = 11662,
  [12471] = 11680,
  [12472] = 12472,
  [12473] = 11717,
  [12474] = 11732,
  [12475] = 12416,
  [12476] = 8544,
  [12477] = 8548,
  [12478] = 8523,
  [12479] = 12479,
  [12480] = 8525,
  [12481] = 8526,
  [12482] = 12418,
  [12483] = 12418,
  [12484] = 8614,
  [12485] = 9296,
  [12486] = 12440,
  [12487] = 9445,
  [12488] = 12488,
  [12489] = 12489,
  [12490] = 5655,
  [12491] = 11665,
  [12492] = 12492,
  [12493] = 12493,
  [12494] = 11430,
  [12495] = 11666,
  [12496] = 11667,
  [12497] = 11794,
  [12498] = 9163,
  [12499] = 8493,
  [12500] = 12418,
  [12501] = 8494,
  [12502] = 8495,
  [12503] = 8496,
  [12504] = 8498,
  [12505] = 11665,
  [12506] = 8500,
  [12507] = 11910,
  [12508] = 11912,
  [12509] = 11666,
  [12510] = 11667,
  [12511] = 12511,
  [12512] = 12440,
  [12513] = 8438,
  [12514] = 8488,
  [12515] = 12515,
  [12516] = 12516,
  [12517] = 11426,
  [12518] = 10371,
  [12519] = 11430,
  [12520] = 12440,
  [12521] = 8479,
  [12522] = 9458,
  [12523] = 8481,
  [12524] = 12440,
  [12525] = 8487,
  [12526] = 8493,
  [12527] = 8494,
  [12528] = 8495,
  [12529] = 8496,
  [12530] = 8500,
  [12531] = 8438,
  [12532] = 8441,
  [12533] = 8442,
  [12534] = 8445,
  [12535] = 8498,
  [12536] = 12418,
  [12537] = 12418,
  [12538] = 8446,
  [12539] = 11885,
  [12540] = 8457,
  [12541] = 11910,
  [12542] = 9282,
  [12543] = 11912,
  [12544] = 11914,
  [12545] = 9395,
  [12546] = 11914,
  [12547] = 12440,
  [12548] = 11943,
  [12549] = 8439,
  [12550] = 8488,
  [12551] = 12440,
  [12552] = 12250,
  [12553] = 12553,
  [12554] = 11696,
  [12555] = 11733,
  [12556] = 11767,
  [12557] = 11685,
  [12558] = 8461,
  [12559] = 11696,
  [12560] = 8439,
  [12561] = 8441,
  [12562] = 8498,
  [12563] = 11733,
  [12564] = 9402,
  [12565] = 9403,
  [12566] = 12440,
  [12567] = 11849,
  [12568] = 9404,
  [12569] = 11722,
  [12570] = 11751,
  [12571] = 9405,
  [12572] = 8487,
  [12573] = 8438,
  [12574] = 12574,
  [12575] = 8445,
  [12576] = 12576,
  [12577] = 12577,
  [12578] = 12578,
  [12579] = 12579,
  [12580] = 9282,
  [12581] = 9312,
  [12582] = 8499,
  [12583] = 8479,
  [12584] = 8481,
  [12585] = 8487,
  [12586] = 8493,
  [12587] = 8494,
  [12588] = 8495,
  [12589] = 8496,
  [12590] = 8500,
  [12591] = 8438,
  [12592] = 8441,
  [12593] = 8442,
  [12594] = 8445,
  [12595] = 8446,
  [12596] = 8614,
  [12597] = 12597,
  [12598] = 12492,
  [12599] = 12493,
  [12600] = 9163,
  [12601] = 8498,
  [12602] = 8457,
  [12603] = 8498,
  [12604] = 8457,
  [12605] = 8498,
  [12606] = 8457,
  [12607] = 8498,
  [12608] = 8457,
  [12609] = 12609,
  [12610] = 10690,
  [12611] = 3377,
  [12612] = 11035,
  [12613] = 12613,
  [12614] = 3248,
  [12615] = 8488,
  [12616] = 8498,
  [12617] = 12617,
  [12618] = 12613,
  [12619] = 12619,
  [12620] = 8488,
  [12621] = 12621,
  [12622] = 12579,
  [12623] = 12623,
  [12624] = 12624,
  [12625] = 12625,
  [12626] = 12626,
  [12627] = 12627,
  [12628] = 12628,
  [12629] = 12629,
  [12630] = 12630,
  [12631] = 12631,
  [12632] = 12632,
  [12633] = 12577,
  [12634] = 12578,
  [12635] = 3456,
  [12636] = 12621,
  [12637] = 3459,
  [12638] = 3351,
  [12639] = 8544,
  [12640] = 12579,
  [12641] = 8548,
  [12642] = 8523,
  [12643] = 8499,
  [12644] = 8445,
  [12645] = 8525,
  [12646] = 8526,
  [12647] = 8544,
  [12648] = 8548,
  [12649] = 8523,
  [12650] = 8525,
  [12651] = 8526,
  [12652] = 12652,
  [12653] = 12653,
  [12654] = 3460,
  [12655] = 8488,
  [12656] = 8457,
  [12657] = 8461,
  [12658] = 8439,
  [12659] = 8461,
  [12660] = 8479,
  [12661] = 8481,
  [12662] = 8487,
  [12663] = 8493,
  [12664] = 8494,
  [12665] = 8495,
  [12666] = 8496,
  [12667] = 8500,
  [12668] = 8441,
  [12669] = 8442,
  [12670] = 3255,
  [12671] = 8445,
  [12672] = 8446,
  [12673] = 8614,
  [12674] = 12674,
  [12675] = 8498,
  [12676] = 8457,
  [12677] = 8479,
  [12678] = 8481,
  [12679] = 8487,
  [12680] = 8493,
  [12681] = 8494,
  [12682] = 8495,
  [12683] = 8496,
  [12684] = 8500,
  [12685] = 8438,
  [12686] = 8441,
  [12687] = 8442,
  [12688] = 8445,
  [12689] = 8446,
  [12690] = 8439,
  [12691] = 8461,
  [12692] = 9289,
  [12693] = 12553,
  [12694] = 8479,
  [12695] = 8488,
  [12696] = 8481,
  [12697] = 8487,
  [12698] = 8493,
  [12699] = 8494,
  [12700] = 8495,
  [12701] = 8496,
  [12702] = 8500,
  [12703] = 8438,
  [12704] = 12619,
  [12705] = 8441,
  [12706] = 8442,
  [12707] = 12623,
  [12708] = 12624,
  [12709] = 12625,
  [12710] = 12631,
  [12711] = 12632,
  [12712] = 8445,
  [12713] = 12626,
  [12714] = 12627,
  [12715] = 8439,
  [12716] = 8461,
  [12717] = 8499,
  [12718] = 8544,
  [12719] = 8548,
  [12720] = 8523,
  [12721] = 3468,
  [12722] = 8525,
  [12723] = 8526,
  [12724] = 3470,
  [12725] = 3256,
  [12726] = 8479,
  [12727] = 8481,
  [12728] = 8487,
  [12729] = 8493,
  [12730] = 8494,
  [12731] = 8495,
  [12732] = 8496,
  [12733] = 8500,
  [12734] = 8438,
  [12735] = 8441,
  [12736] = 8442,
  [12737] = 8445,
  [12738] = 8446,
  [12739] = 8446,
  [12740] = 12631,
  [12741] = 12741,
  [12742] = 12742,
  [12743] = 8439,
  [12744] = 8461,
  [12745] = 8479,
  [12746] = 8481,
  [12747] = 8487,
  [12748] = 8493,
  [12749] = 8494,
  [12750] = 8495,
  [12751] = 8496,
  [12752] = 8500,
  [12753] = 8438,
  [12754] = 8441,
  [12755] = 8442,
  [12756] = 8445,
  [12757] = 8446,
  [12758] = 8461,
  [12759] = 12621,
  [12760] = 12631,
  [12761] = 8439,
  [12762] = 8461,
  [12763] = 8499,
  [12764] = 9286,
  [12765] = 8488,
  [12766] = 12766,
  [12767] = 10962,
  [12768] = 10979,
  [12769] = 11035,
  [12770] = 12626,
  [12771] = 12627,
  [12772] = 12631,
  [12773] = 12628,
  [12774] = 8445,
  [12775] = 12629,
  [12776] = 10962,
  [12777] = 10979,
  [12778] = 11035,
  [12779] = 12631,
  [12780] = 12630,
  [12781] = 12631,
  [12782] = 12628,
  [12783] = 8544,
  [12784] = 8548,
  [12785] = 8523,
  [12786] = 8525,
  [12787] = 8526,
  [12788] = 9845,
  [12789] = 12631,
  [12790] = 8439,
  [12791] = 8544,
  [12792] = 8548,
  [12793] = 8523,
  [12794] = 8525,
  [12795] = 8526,
  [12796] = 9296,
  [12797] = 12741,
  [12798] = 12742,
  [12799] = 12631,
  [12800] = 8488,
  [12801] = 8461,
  [12802] = 12597,
  [12803] = 5655,
  [12804] = 8544,
  [12805] = 8548,
  [12806] = 8523,
  [12807] = 8525,
  [12808] = 8526,
  [12809] = 10962,
  [12810] = 12631,
  [12811] = 12629,
  [12812] = 8544,
  [12813] = 8548,
  [12814] = 8523,
  [12815] = 8525,
  [12816] = 8526,
  [12817] = 9355,
  [12818] = 12631,
  [12819] = 12630,
  [12820] = 12631,
  [12821] = 10979,
  [12822] = 12631,
  [12823] = 12631,
  [12824] = 8479,
  [12825] = 12631,
  [12826] = 8481,
  [12827] = 12631,
  [12828] = 8487,
  [12829] = 8493,
  [12830] = 8494,
  [12831] = 8495,
  [12832] = 8496,
  [12833] = 12631,
  [12834] = 8500,
  [12835] = 8438,
  [12836] = 8441,
  [12837] = 8442,
  [12838] = 12577,
  [12839] = 12578,
  [12840] = 12631,
  [12841] = 12841,
  [12842] = 12631,
  [12843] = 12631,
  [12844] = 8445,
  [12845] = 12631,
  [12846] = 12631,
  [12847] = 12631,
  [12848] = 12631,
  [12849] = 12631,
  [12850] = 12631,
  [12851] = 8488,
  [12852] = 8461,
  [12853] = 12488,
  [12854] = 12631,
  [12855] = 12489,
  [12856] = 12631,
  [12857] = 8446,
  [12858] = 12631,
  [12859] = 12631,
  [12860] = 12631,
  [12861] = 12631,
  [12862] = 8445,
  [12863] = 12631,
  [12864] = 11426,
  [12865] = 12631,
  [12866] = 12631,
  [12867] = 12631,
  [12868] = 12631,
  [12869] = 12631,
  [12870] = 12631,
  [12871] = 12631,
  [12872] = 12631,
  [12873] = 12873,
  [12874] = 12874,
  [12875] = 12875,
  [12876] = 12876,
  [12877] = 12877,
  [12878] = 12878,
  [12879] = 12879,
  [12880] = 8461,
  [12881] = 12881,
  [12882] = 12629,
  [12883] = 8461,
  [12884] = 8499,
  [12885] = 12873,
  [12886] = 12874,
  [12887] = 12875,
  [12888] = 11430,
  [12889] = 12873,
  [12890] = 11665,
  [12891] = 11666,
  [12892] = 11667,
  [12893] = 8498,
  [12894] = 8445,
  [12895] = 8457,
  [12896] = 3392,
  [12897] = 12613,
  [12898] = 12873,
  [12899] = 12899,
  [12900] = 12609,
  [12901] = 10339,
  [12902] = 8439,
  [12903] = 8461,
  [12904] = 12904,
  [12905] = 12574,
  [12906] = 12631,
  [12907] = 11696,
  [12908] = 11733,
  [12909] = 12652,
  [12910] = 3374,
  [12911] = 12653,
  [12912] = 12876,
  [12913] = 12877,
  [12914] = 12878,
  [12915] = 12879,
  [12916] = 12881,
  [12917] = 12904,
  [12918] = 8499,
  [12919] = 8496,
  [12920] = 8493,
  [12921] = 8494,
  [12922] = 8495,
  [12923] = 8496,
  [12924] = 8500,
  [12925] = 8438,
  [12926] = 8441,
  [12927] = 8442,
  [12928] = 9312,
  [12929] = 12929,
  [12930] = 8445,
  [12931] = 8488,
  [12932] = 8446,
  [12933] = 8488,
  [12934] = 12934,
  [12935] = 8614,
  [12936] = 3460,
  [12937] = 8496,
  [12938] = 8500,
  [12939] = 12939,
  [12940] = 8438,
  [12941] = 8441,
  [12942] = 8442,
  [12943] = 12623,
  [12944] = 8498,
  [12945] = 12929,
  [12946] = 12939,
  [12947] = 12934,
  [12948] = 12875,
  [12949] = 12939,
  [12950] = 12929,
  [12951] = 9419,
  [12952] = 12877,
  [12953] = 8457,
  [12954] = 12934,
  [12955] = 12929,
  [12956] = 3450,
  [12957] = 12939,
  [12958] = 12939,
  [12959] = 12934,
  [12960] = 8544,
  [12961] = 8548,
  [12962] = 8523,
  [12963] = 8525,
  [12964] = 8526,
  [12965] = 12939,
  [12966] = 12929,
  [12967] = 12934,
  [12968] = 8498,
  [12969] = 3468,
  [12970] = 3470,
  [12971] = 9458,
  [12972] = 12939,
  [12973] = 12929,
  [12974] = 12939,
  [12975] = 3297,
  [12976] = 12929,
  [12977] = 12934,
  [12978] = 8461,
  [12979] = 12934,
  [12980] = 9405,
  [12981] = 8457,
  [12982] = 8614,
  [12983] = 8548,
  [12984] = 12929,
  [12985] = 3451,
  [12986] = 8488,
  [12987] = 8488,
  [12988] = 3452,
  [12989] = 8498,
  [12990] = 12939,
  [12991] = 12929,
  [12992] = 12939,
  [12993] = 12934,
  [12994] = 12934,
  [12995] = 12929,
  [12996] = 8544,
  [12997] = 12929,
  [12998] = 8457,
  [12999] = 12929,
  [13000] = 3453,
  [13001] = 8499,
  [13002] = 12934,
  [13003] = 12934,
  [13004] = 12939,
  [13005] = 8439,
  [13006] = 8544,
  [13007] = 8548,
  [13008] = 8523,
  [13009] = 8525,
  [13010] = 8526,
  [13011] = 12929,
  [13012] = 12934,
  [13013] = 9417,
  [13014] = 8461,
  [13015] = 12574,
  [13016] = 8488,
  [13017] = 8479,
  [13018] = 8481,
  [13019] = 12939,
  [13020] = 3454,
  [13021] = 8614,
  [13022] = 8523,
  [13023] = 9289,
  [13024] = 3255,
  [13025] = 12939,
  [13026] = 12939,
  [13027] = 12929,
  [13028] = 8457,
  [13029] = 12934,
  [13030] = 8488,
  [13031] = 3256,
  [13032] = 12939,
  [13033] = 12929,
  [13034] = 8439,
  [13035] = 12934,
  [13036] = 8498,
  [13037] = 8487,
  [13038] = 8493,
  [13039] = 12929,
  [13040] = 8494,
  [13041] = 8495,
  [13042] = 8496,
  [13043] = 8500,
  [13044] = 8438,
  [13045] = 12939,
  [13046] = 8441,
  [13047] = 8442,
  [13048] = 8544,
  [13049] = 8548,
  [13050] = 8523,
  [13051] = 8525,
  [13052] = 8526,
  [13053] = 12929,
  [13054] = 12934,
  [13055] = 12934,
  [13056] = 8457,
  [13057] = 8525,
  [13058] = 9355,
  [13059] = 8453,
  [13060] = 12929,
  [13061] = 12632,
  [13062] = 12934,
  [13063] = 12939,
  [13064] = 8488,
  [13065] = 9430,
  [13066] = 12939,
  [13067] = 12929,
  [13068] = 12939,
  [13069] = 12934,
  [13070] = 8488,
  [13071] = 12939,
  [13072] = 8454,
  [13073] = 12939,
  [13074] = 12939,
  [13075] = 12939,
  [13076] = 12939,
  [13077] = 12939,
  [13078] = 8526,
  [13079] = 12939,
  [13080] = 8553,
  [13081] = 8449,
  [13082] = 12939,
  [13083] = 8446,
  [13084] = 12939,
  [13085] = 12939,
  [13086] = 12939,
  [13087] = 12939,
  [13088] = 12939,
  [13089] = 12929,
  [13090] = 8439,
  [13091] = 12939,
  [13092] = 12934,
  [13093] = 12874,
  [13094] = 8445,
  [13095] = 12878,
  [13096] = 13096,
  [13097] = 8445,
  [13098] = 12929,
  [13099] = 12934,
  [13100] = 8439,
  [13101] = 8461,
  [13102] = 8498,
  [13103] = 8499,
  [13104] = 12939,
  [13105] = 12939,
  [13106] = 5062,
  [13107] = 12929,
  [13108] = 12879,
  [13109] = 8479,
  [13110] = 8498,
  [13111] = 8439,
  [13112] = 8481,
  [13113] = 8487,
  [13114] = 8493,
  [13115] = 8494,
  [13116] = 8439,
  [13117] = 9445,
  [13118] = 12934,
  [13119] = 8461,
  [13120] = 9406,
  [13121] = 8498,
  [13122] = 12929,
  [13123] = 9407,
  [13124] = 9404,
  [13125] = 8488,
  [13126] = 8479,
  [13127] = 8481,
  [13128] = 8487,
  [13129] = 8493,
  [13130] = 8494,
  [13131] = 8495,
  [13132] = 8496,
  [13133] = 8500,
  [13134] = 8438,
  [13135] = 8441,
  [13136] = 8446,
  [13137] = 8495,
  [13138] = 8496,
  [13139] = 8498,
  [13140] = 12609,
  [13141] = 8442,
  [13142] = 8445,
  [13143] = 8446,
  [13144] = 8479,
  [13145] = 8500,
  [13146] = 9286,
  [13147] = 9408,
  [13148] = 8544,
  [13149] = 9409,
  [13150] = 12934,
  [13151] = 8481,
  [13152] = 13152,
  [13153] = 8487,
  [13154] = 12934,
  [13155] = 8438,
  [13156] = 8548,
  [13157] = 12939,
  [13158] = 8523,
  [13159] = 8493,
  [13160] = 8494,
  [13161] = 8495,
  [13162] = 8457,
  [13163] = 8495,
  [13164] = 8500,
  [13165] = 8438,
  [13166] = 12929,
  [13167] = 8526,
  [13168] = 12652,
  [13169] = 8441,
  [13170] = 12934,
  [13171] = 12653,
  [13172] = 8441,
  [13173] = 8442,
  [13174] = 8442,
  [13175] = 8614,
  [13176] = 8457,
  [13177] = 12619,
  [13178] = 12939,
  [13179] = 8479,
  [13180] = 8481,
  [13181] = 12876,
  [13182] = 8487,
  [13183] = 9435,
  [13184] = 8493,
  [13185] = 8494,
  [13186] = 8495,
  [13187] = 8496,
  [13188] = 8500,
  [13189] = 8438,
  [13190] = 8441,
  [13191] = 8442,
  [13192] = 8445,
  [13193] = 8457,
  [13194] = 12929,
  [13195] = 8446,
  [13196] = 8446,
  [13197] = 9436,
  [13198] = 8446,
  [13199] = 9025,
  [13200] = 12624,
  [13201] = 12939,
  [13202] = 12934,
  [13203] = 9437,
  [13204] = 12929,
  [13205] = 12934,
  [13206] = 8446,
  [13207] = 8457,
  [13208] = 8461,
  [13209] = 12939,
  [13210] = 8461,
  [13211] = 8499,
  [13212] = 8479,
  [13213] = 8439,
  [13214] = 12934,
  [13215] = 8439,
  [13216] = 9431,
  [13217] = 8498,
  [13218] = 8457,
  [13219] = 8499,
  [13220] = 8481,
  [13221] = 8487,
  [13222] = 8461,
  [13223] = 12939,
  [13224] = 13224,
  [13225] = 9440,
  [13226] = 8498,
  [13227] = 12929,
  [13228] = 8493,
  [13229] = 8494,
  [13230] = 8495,
  [13231] = 8496,
  [13232] = 9403,
  [13233] = 8500,
  [13234] = 8438,
  [13235] = 8441,
  [13236] = 8442,
  [13237] = 13237,
  [13238] = 12904,
  [13239] = 12939,
  [13240] = 8614,
  [13241] = 13241,
  [13242] = 9402,
  [13243] = 12939,
  [13244] = 12939,
  [13245] = 12929,
  [13246] = 12929,
  [13247] = 8445,
  [13248] = 8498,
  [13249] = 12939,
  [13250] = 8446,
  [13251] = 12934,
  [13252] = 12929,
  [13253] = 12934,
  [13254] = 12934,
  [13255] = 12934,
  [13256] = 8488,
  [13257] = 8439,
  [13258] = 12929,
  [13259] = 12625,
  [13260] = 12939,
  [13261] = 12939,
  [13262] = 9428,
  [13263] = 8614,
  [13264] = 9426,
  [13265] = 12934,
  [13266] = 12929,
  [13267] = 9427,
  [13268] = 12939,
  [13269] = 12881,
  [13270] = 8439,
  [13271] = 12934,
  [13272] = 12929,
  [13273] = 8743,
  [13274] = 8479,
  [13275] = 12929,
  [13276] = 9395,
  [13277] = 8544,
  [13278] = 8548,
  [13279] = 8523,
  [13280] = 8479,
  [13281] = 3298,
  [13282] = 8481,
  [13283] = 12939,
  [13284] = 8487,
  [13285] = 8493,
  [13286] = 8494,
  [13287] = 8495,
  [13288] = 12929,
  [13289] = 11426,
  [13290] = 8496,
  [13291] = 11430,
  [13292] = 9418,
  [13293] = 12934,
  [13294] = 8500,
  [13295] = 12741,
  [13296] = 12742,
  [13297] = 8457,
  [13298] = 12934,
  [13299] = 8438,
  [13300] = 8441,
  [13301] = 8445,
  [13302] = 13302,
  [13303] = 12939,
  [13304] = 8442,
  [13305] = 13305,
  [13306] = 9429,
  [13307] = 12929,
  [13308] = 12939,
  [13309] = 12939,
  [13310] = 8446,
  [13311] = 8481,
  [13312] = 12934,
  [13313] = 12929,
  [13314] = 12934,
  [13315] = 12939,
  [13316] = 12929,
  [13317] = 10690,
  [13318] = 12934,
  [13319] = 12934,
  [13320] = 8479,
  [13321] = 8481,
  [13322] = 12939,
  [13323] = 13323,
  [13324] = 12929,
  [13325] = 8487,
  [13326] = 8487,
  [13327] = 8614,
  [13328] = 8461,
  [13329] = 12939,
  [13330] = 8479,
  [13331] = 12934,
  [13332] = 8445,
  [13333] = 8481,
  [13334] = 13302,
  [13335] = 8487,
  [13336] = 8493,
  [13337] = 8494,
  [13338] = 8495,
  [13339] = 8525,
  [13340] = 8496,
  [13341] = 12929,
  [13342] = 8526,
  [13343] = 12939,
  [13344] = 8500,
  [13345] = 8438,
  [13346] = 9416,
  [13347] = 12939,
  [13348] = 12929,
  [13349] = 8441,
  [13350] = 12934,
  [13351] = 12929,
  [13352] = 8442,
  [13353] = 3456,
  [13354] = 3459,
  [13355] = 3351,
  [13356] = 8493,
  [13357] = 8494,
  [13358] = 8488,
  [13359] = 12939,
  [13360] = 12934,
  [13361] = 8525,
  [13362] = 12878,
  [13363] = 8494,
  [13364] = 8488,
  [13365] = 8498,
  [13366] = 9440,
  [13367] = 8457,
  [13368] = 3374,
  [13369] = 3377,
  [13370] = 8457,
  [13371] = 3248,
  [13372] = 8495,
  [13373] = 13373,
  [13374] = 8496,
  [13375] = 8500,
  [13376] = 8614,
  [13377] = 8438,
  [13378] = 8441,
  [13379] = 13379,
  [13380] = 13380,
  [13381] = 8493,
  [13382] = 8494,
  [13383] = 13383,
  [13384] = 9289,
  [13385] = 8495,
  [13386] = 9406,
  [13387] = 8498,
  [13388] = 8496,
  [13389] = 9416,
  [13390] = 9458,
  [13391] = 3392,
  [13392] = 8442,
  [13393] = 9417,
  [13394] = 9407,
  [13395] = 9418,
  [13396] = 8438,
  [13397] = 13373,
  [13398] = 8457,
  [13399] = 13399,
  [13400] = 13373,
  [13401] = 8487,
  [13402] = 13373,
  [13403] = 8500,
  [13404] = 9419,
  [13405] = 13373,
  [13406] = 13406,
  [13407] = 13407,
  [13408] = 8498,
  [13409] = 13409,
  [13410] = 13410,
  [13411] = 13411,
  [13412] = 8488,
  [13413] = 13373,
  [13414] = 10339,
  [13415] = 13415,
  [13416] = 8488,
  [13417] = 8439,
  [13418] = 8488,
  [13419] = 8438,
  [13420] = 8457,
  [13421] = 13421,
  [13422] = 8488,
  [13423] = 8614,
  [13424] = 8498,
  [13425] = 13373,
  [13426] = 8439,
  [13427] = 13373,
  [13428] = 13373,
  [13429] = 8614,
  [13430] = 9408,
  [13431] = 9409,
  [13432] = 13373,
  [13433] = 8441,
  [13434] = 8441,
  [13435] = 8446,
  [13436] = 8614,
  [13437] = 13437,
  [13438] = 12652,
  [13439] = 13373,
  [13440] = 13373,
  [13441] = 8498,
  [13442] = 8442,
  [13443] = 13443,
  [13444] = 8442,
  [13445] = 9402,
  [13446] = 8488,
  [13447] = 8457,
  [13448] = 8446,
  [13449] = 13373,
  [13450] = 13373,
  [13451] = 12904,
  [13452] = 9445,
  [13453] = 13373,
  [13454] = 13373,
  [13455] = 9282,
  [13456] = 9296,
  [13457] = 9403,
  [13458] = 8614,
  [13459] = 8500,
  [13460] = 12653,
  [13461] = 13461,
  [13462] = 13383,
  [13463] = 13409,
  [13464] = 13373,
  [13465] = 13373,
  [13466] = 13373,
  [13467] = 13373,
  [13468] = 8614,
  [13469] = 12741,
  [13470] = 8488,
  [13471] = 8439,
  [13472] = 12742,
  [13473] = 13399,
  [13474] = 13411,
  [13475] = 8488,
  [13476] = 9426,
  [13477] = 13373,
  [13478] = 8614,
  [13479] = 9427,
  [13480] = 9428,
  [13481] = 13481,
  [13482] = 13373,
  [13483] = 13373,
  [13484] = 8495,
  [13485] = 9429,
  [13486] = 13373,
  [13487] = 9430,
  [13488] = 8446,
  [13489] = 9431,
  [13490] = 13383,
  [13491] = 8614,
  [13492] = 13373,
  [13493] = 13373,
  [13494] = 13373,
  [13495] = 13373,
  [13496] = 13373,
  [13497] = 8479,
  [13498] = 9286,
  [13499] = 8498,
  [13500] = 8481,
  [13501] = 8487,
  [13502] = 8493,
  [13503] = 8494,
  [13504] = 8495,
  [13505] = 8496,
  [13506] = 8500,
  [13507] = 8438,
  [13508] = 8441,
  [13509] = 8442,
  [13510] = 9405,
  [13511] = 9395,
  [13512] = 13373,
  [13513] = 13373,
  [13514] = 13415,
  [13515] = 8481,
  [13516] = 5687,
  [13517] = 12609,
  [13518] = 8457,
  [13519] = 5655,
  [13520] = 8614,
  [13521] = 13406,
  [13522] = 8496,
  [13523] = 13373,
  [13524] = 8498,
  [13525] = 13407,
  [13526] = 13526,
  [13527] = 12874,
  [13528] = 12875,
  [13529] = 13410,
  [13530] = 8488,
  [13531] = 13373,
  [13532] = 9435,
  [13533] = 8457,
  [13534] = 8457,
  [13535] = 8439,
  [13536] = 8479,
  [13537] = 9436,
  [13538] = 13373,
  [13539] = 13539,
  [13540] = 13373,
  [13541] = 8446,
  [13542] = 13542,
  [13543] = 9437,
  [13544] = 13407,
  [13545] = 13373,
  [13546] = 13373,
  [13547] = 12574,
  [13548] = 13373,
  [13549] = 8457,
  [13550] = 13373,
  [13551] = 5145,
  [13552] = 8479,
  [13553] = 8498,
  [13554] = 8481,
  [13555] = 8487,
  [13556] = 8498,
  [13557] = 8493,
  [13558] = 13373,
  [13559] = 13383,
  [13560] = 8614,
  [13561] = 13373,
  [13562] = 8488,
  [13563] = 12619,
  [13564] = 8479,
  [13565] = 12623,
  [13566] = 12624,
  [13567] = 12625,
  [13568] = 8457,
  [13569] = 8498,
  [13570] = 12876,
  [13571] = 12877,
  [13572] = 13373,
  [13573] = 12879,
  [13574] = 12881,
  [13575] = 13373,
  [13576] = 8481,
  [13577] = 12632,
  [13578] = 13578,
  [13579] = 8487,
  [13580] = 8493,
  [13581] = 8494,
  [13582] = 9404,
  [13583] = 13583,
  [13584] = 9292,
  [13585] = 9280,
  [13586] = 9285,
  [13587] = 13587,
  [13588] = 13588,
  [13589] = 13589,
  [13590] = 13590,
  [13591] = 13590,
  [13592] = 3455,
  [13593] = 13589,
  [13594] = 9355,
  [13595] = 13590,
  [13596] = 13596,
  [13597] = 8614,
  [13598] = 13583,
  [13599] = 9295,
  [13600] = 13600,
  [13601] = 9288,
  [13602] = 9279,
  [13603] = 13603,
  [13604] = 13583,
  [13605] = 13583,
  [13606] = 13606,
  [13607] = 8614,
  [13608] = 8614,
  [13609] = 13609,
  [13610] = 9312,
  [13611] = 13589,
  [13612] = 13590,
  [13613] = 13613,
  [13614] = 8614,
  [13615] = 13615,
  [13616] = 10690,
  [13617] = 13589,
  [13618] = 5655,
  [13619] = 13619,
  [13620] = 3377,
  [13621] = 13621,
  [13622] = 13622,
  [13623] = 3248,
  [13624] = 9163,
  [13625] = 3392,
  [13626] = 13626,
  [13627] = 9445,
  [13628] = 13628,
  [13629] = 9406,
  [13630] = 9458,
  [13631] = 3377,
  [13632] = 9407,
  [13633] = 13633,
  [13634] = 9408,
  [13635] = 9409,
  [13636] = 9845,
  [13637] = 9339,
  [13638] = 9402,
  [13639] = 3248,
  [13640] = 9310,
  [13641] = 9403,
  [13642] = 13642,
  [13643] = 13643,
  [13644] = 13643,
  [13645] = 3392,
  [13646] = 13621,
  [13647] = 9404,
  [13648] = 9416,
  [13649] = 9417,
  [13650] = 13628,
  [13651] = 5687,
  [13652] = 9418,
  [13653] = 13653,
  [13654] = 13643,
  [13655] = 13628,
  [13656] = 13628,
  [13657] = 13657,
  [13658] = 5687,
  [13659] = 13621,
  [13660] = 9309,
  [13661] = 13661,
  [13662] = 5655,
  [13663] = 13621,
  [13664] = 9426,
  [13665] = 13643,
  [13666] = 9286,
  [13667] = 13667,
  [13668] = 13621,
  [13669] = 9427,
  [13670] = 9296,
  [13671] = 9282,
  [13672] = 13672,
  [13673] = 9289,
  [13674] = 9428,
  [13675] = 9429,
  [13676] = 13676,
  [13677] = 3374,
  [13678] = 9430,
  [13679] = 9431,
  [13680] = 9405,
  [13681] = 9435,
  [13682] = 5513,
  [13683] = 13621,
  [13684] = 9395,
  [13685] = 9436,
  [13686] = 13686,
  [13687] = 9437,
  [13688] = 3374,
  [13689] = 9440,
  [13690] = 13690,
  [13691] = 5469,
  [13692] = 9419,
  [13693] = 13693,
  [13694] = 13694,
  [13695] = 13695,
  [13696] = 13696,
  [13697] = 13697,
  [13698] = 13694,
  [13699] = 13699,
  [13700] = 7755,
  [13701] = 7756,
  [13702] = 7757,
  [13703] = 13697,
  [13704] = 13694,
  [13705] = 13694,
  [13706] = 5599,
  [13707] = 4785,
  [13708] = 13693,
  [13709] = 13709,
  [13710] = 13710,
  [13711] = 13694,
  [13712] = 13697,
  [13713] = 13713,
  [13714] = 9355,
  [13715] = 13715,
  [13716] = 9752,
  [13717] = 13717,
  [13718] = 13694,
  [13719] = 13719,
  [13720] = 13720,
  [13721] = 5630,
  [13722] = 13722,
  [13723] = 13723,
  [13724] = 13724,
  [13725] = 13697,
  [13726] = 13726,
  [13727] = 13694,
  [13728] = 13728,
  [13729] = 8534,
  [13730] = 13697,
  [13731] = 8538,
  [13732] = 13732,
  [13733] = 8545,
  [13734] = 8551,
  [13735] = 13697,
  [13736] = 13694,
  [13737] = 13697,
  [13738] = 13738,
  [13739] = 13694,
  [13740] = 13697,
  [13741] = 13741,
  [13742] = 13742,
  [13743] = 13743,
  [13744] = 3295,
  [13745] = 13745,
  [13746] = 13746,
  [13747] = 13747,
  [13748] = 13748,
  [13749] = 13694,
  [13750] = 7877,
  [13751] = 13694,
  [13752] = 13694,
  [13753] = 13694,
  [13754] = 13754,
  [13755] = 13755,
  [13756] = 13756,
  [13757] = 13757,
  [13758] = 13758,
  [13759] = 13759,
  [13760] = 13694,
  [13761] = 13761,
  [13762] = 13762,
  [13763] = 5600,
  [13764] = 13764,
  [13765] = 7914,
  [13766] = 13766,
  [13767] = 13697,
  [13768] = 13697,
  [13769] = 13769,
  [13770] = 13697,
  [13771] = 13697,
  [13772] = 13697,
  [13773] = 13773,
  [13774] = 13742,
  [13775] = 13775,
  [13776] = 13694,
  [13777] = 13694,
  [13778] = 5613,
  [13779] = 13697,
  [13780] = 9825,
  [13781] = 13781,
  [13782] = 13782,
  [13783] = 4789,
  [13784] = 13697,
  [13785] = 9289,
  [13786] = 13786,
  [13787] = 5667,
  [13788] = 13788,
  [13789] = 13694,
  [13790] = 13790,
  [13791] = 13697,
  [13792] = 8743,
  [13793] = 13693,
  [13794] = 13697,
  [13795] = 13697,
  [13796] = 13796,
  [13797] = 13694,
  [13798] = 13786,
  [13799] = 8550,
  [13800] = 13694,
  [13801] = 13801,
  [13802] = 13693,
  [13803] = 4788,
  [13804] = 13697,
  [13805] = 13805,
  [13806] = 10339,
  [13807] = 13807,
  [13808] = 13808,
  [13809] = 13694,
  [13810] = 9286,
  [13811] = 13811,
  [13812] = 13694,
  [13813] = 7795,
  [13814] = 7796,
  [13815] = 13694,
  [13816] = 13694,
  [13817] = 7797,
  [13818] = 7800,
  [13819] = 7801,
  [13820] = 13697,
  [13821] = 13821,
  [13822] = 13822,
  [13823] = 13823,
  [13824] = 13697,
  [13825] = 13697,
  [13826] = 13786,
  [13827] = 13827,
  [13828] = 13828,
  [13829] = 13829,
  [13830] = 13694,
  [13831] = 13694,
  [13832] = 13694,
  [13833] = 13697,
  [13834] = 13694,
  [13835] = 13835,
  [13836] = 13836,
  [13837] = 13837,
  [13838] = 13694,
  [13839] = 13839,
  [13840] = 13840,
  [13841] = 9312,
  [13842] = 13697,
  [13843] = 13697,
  [13844] = 13844,
  [13845] = 13845,
  [13846] = 13846,
  [13847] = 7819,
  [13848] = 7820,
  [13849] = 7821,
  [13850] = 7822,
  [13851] = 13851,
  [13852] = 13852,
  [13853] = 13853,
  [13854] = 13854,
  [13855] = 8501,
  [13856] = 13856,
  [13857] = 13857,
  [13858] = 7870,
  [13859] = 13697,
  [13860] = 13860,
  [13861] = 13861,
  [13862] = 13694,
  [13863] = 13694,
  [13864] = 13697,
  [13865] = 13694,
  [13866] = 13866,
  [13867] = 7834,
  [13868] = 13868,
  [13869] = 13697,
  [13870] = 13870,
  [13871] = 13871,
  [13872] = 13872,
  [13873] = 13697,
  [13874] = 13874,
  [13875] = 13694,
  [13876] = 13697,
  [13877] = 13697,
  [13878] = 13878,
  [13879] = 7849,
  [13880] = 13880,
  [13881] = 13697,
  [13882] = 13882,
  [13883] = 13697,
  [13884] = 13697,
  [13885] = 13885,
  [13886] = 13886,
  [13887] = 13697,
  [13888] = 13888,
  [13889] = 13694,
  [13890] = 13890,
  [13891] = 13694,
  [13892] = 13694,
  [13893] = 13697,
  [13894] = 13894,
  [13895] = 13895,
  [13896] = 13896,
  [13897] = 13694,
  [13898] = 5583,
  [13899] = 13786,
  [13900] = 13900,
  [13901] = 13901,
  [13902] = 13694,
  [13903] = 13694,
  [13904] = 13694,
  [13905] = 13905,
  [13906] = 13697,
  [13907] = 13697,
  [13908] = 13908,
  [13909] = 13694,
  [13910] = 13910,
  [13911] = 13911,
  [13912] = 13912,
  [13913] = 13694,
  [13914] = 13697,
  [13915] = 13915,
  [13916] = 13697,
  [13917] = 13697,
  [13918] = 13697,
  [13919] = 7752,
  [13920] = 13920,
  [13921] = 13921,
  [13922] = 13922,
  [13923] = 13923,
  [13924] = 7753,
  [13925] = 13694,
  [13926] = 9437,
  [13927] = 4785,
  [13928] = 4860,
  [13929] = 9404,
  [13930] = 13930,
  [13931] = 13931,
  [13932] = 10690,
  [13933] = 9402,
  [13934] = 9440,
  [13935] = 13935,
  [13936] = 9406,
  [13937] = 9407,
  [13938] = 9408,
  [13939] = 13939,
  [13940] = 9409,
  [13941] = 9418,
  [13942] = 13942,
  [13943] = 5687,
  [13944] = 9430,
  [13945] = 9458,
  [13946] = 9405,
  [13947] = 9431,
  [13948] = 13948,
  [13949] = 4788,
  [13950] = 9403,
  [13951] = 13951,
  [13952] = 9426,
  [13953] = 3392,
  [13954] = 4789,
  [13955] = 5655,
  [13956] = 3374,
  [13957] = 10339,
  [13958] = 3377,
  [13959] = 13959,
  [13960] = 13960,
  [13961] = 9163,
  [13962] = 9416,
  [13963] = 3248,
  [13964] = 9139,
  [13965] = 9395,
  [13966] = 9419,
  [13967] = 9427,
  [13968] = 9445,
  [13969] = 13969,
  [13970] = 9417,
  [13971] = 9098,
  [13972] = 9436,
  [13973] = 13973,
  [13974] = 9156,
  [13975] = 9435,
  [13976] = 9428,
  [13977] = 9429,
  [13978] = 4860,
  [13979] = 8520,
  [13980] = 13980,
  [13981] = 10371,
  [13982] = 13982,
  [13983] = 13983,
  [13984] = 9276,
  [13985] = 9211,
  [13986] = 9393,
  [13987] = 13987,
  [13988] = 9250,
  [13989] = 10339,
  [13990] = 13990,
  [13991] = 13983,
  [13992] = 9218,
  [13993] = 3374,
  [13994] = 10690,
  [13995] = 9275,
  [13996] = 9225,
  [13997] = 10547,
  [13998] = 9384,
  [13999] = 9484,
  [14000] = 13987,
  [14001] = 3392,
  [14002] = 9485,
  [14003] = 9271,
  [14004] = 3471,
  [14005] = 13983,
  [14006] = 10546,
  [14007] = 5488,
  [14008] = 13987,
  [14009] = 13983,
  [14010] = 9200,
  [14011] = 9486,
  [14012] = 9199,
  [14013] = 13987,
  [14014] = 9256,
  [14015] = 10549,
  [14016] = 3377,
  [14017] = 9195,
  [14018] = 9510,
  [14019] = 3248,
  [14020] = 14020,
  [14021] = 9215,
  [14022] = 14022,
  [14023] = 14023,
  [14024] = 3412,
  [14025] = 10548,
  [14026] = 14026,
  [14027] = 14026,
  [14028] = 5633,
  [14029] = 14026,
  [14030] = 5634,
  [14031] = 5609,
  [14032] = 14026,
  [14033] = 14026,
  [14034] = 5610,
  [14035] = 10690,
  [14036] = 14026,
  [14037] = 14037,
  [14038] = 14038,
  [14039] = 5652,
  [14040] = 14026,
  [14041] = 14026,
  [14042] = 14026,
  [14043] = 14043,
  [14044] = 14026,
  [14045] = 5681,
  [14046] = 9361,
  [14047] = 9282,
  [14048] = 14026,
  [14049] = 14038,
  [14050] = 14037,
  [14051] = 14043,
  [14052] = 14038,
  [14053] = 14037,
  [14054] = 14038,
  [14055] = 9357,
  [14056] = 14026,
  [14057] = 14026,
  [14058] = 14038,
  [14059] = 14026,
  [14060] = 14060,
  [14061] = 14043,
  [14062] = 14038,
  [14063] = 5693,
  [14064] = 14026,
  [14065] = 5666,
  [14066] = 14066,
  [14067] = 14038,
  [14068] = 14026,
  [14069] = 5677,
  [14070] = 9362,
  [14071] = 14026,
  [14072] = 5594,
  [14073] = 9163,
  [14074] = 5623,
  [14075] = 5656,
  [14076] = 14038,
  [14077] = 14026,
  [14078] = 14038,
  [14079] = 14026,
  [14080] = 14026,
  [14081] = 14038,
  [14082] = 9311,
  [14083] = 9318,
  [14084] = 14038,
  [14085] = 14038,
  [14086] = 14026,
  [14087] = 14038,
  [14088] = 14037,
  [14089] = 14038,
  [14090] = 14043,
  [14091] = 14038,
  [14092] = 14026,
  [14093] = 14038,
  [14094] = 14094,
  [14095] = 14038,
  [14096] = 8520,
  [14097] = 5585,
  [14098] = 14037,
  [14099] = 14038,
  [14100] = 14026,
  [14101] = 14038,
  [14102] = 14038,
  [14103] = 3458,
  [14104] = 14104,
  [14105] = 14038,
  [14106] = 14038,
  [14107] = 14038,
  [14108] = 14026,
  [14109] = 14038,
  [14110] = 14037,
  [14111] = 14043,
  [14112] = 14038,
  [14113] = 14026,
  [14114] = 14026,
  [14115] = 14038,
  [14116] = 14116,
  [14117] = 14038,
  [14118] = 14043,
  [14119] = 14038,
  [14120] = 14038,
  [14121] = 3472,
  [14122] = 9845,
  [14123] = 14038,
  [14124] = 14037,
  [14125] = 14038,
  [14126] = 5586,
  [14127] = 14038,
  [14128] = 14038,
  [14129] = 5617,
  [14130] = 14038,
  [14131] = 14026,
  [14132] = 14038,
  [14133] = 14026,
  [14134] = 5646,
  [14135] = 14026,
  [14136] = 14038,
  [14137] = 14026,
  [14138] = 14038,
  [14139] = 14104,
  [14140] = 9368,
  [14141] = 14038,
  [14142] = 14037,
  [14143] = 3139,
  [14144] = 14043,
  [14145] = 14038,
  [14146] = 14038,
  [14147] = 9163,
  [14148] = 14038,
  [14149] = 14038,
  [14150] = 14038,
  [14151] = 14038,
  [14152] = 14038,
  [14153] = 14038,
  [14154] = 14038,
  [14155] = 14038,
  [14156] = 14038,
  [14157] = 14038,
  [14158] = 14038,
  [14159] = 14038,
  [14160] = 14038,
  [14161] = 14038,
  [14162] = 14162,
  [14163] = 14043,
  [14164] = 14026,
  [14165] = 5723,
  [14166] = 5724,
  [14167] = 14094,
  [14168] = 14094,
  [14169] = 14026,
  [14170] = 5649,
  [14171] = 5707,
  [14172] = 14104,
  [14173] = 5637,
  [14174] = 14026,
  [14175] = 5593,
  [14176] = 14026,
  [14177] = 5601,
  [14178] = 14094,
  [14179] = 5595,
  [14180] = 14104,
  [14181] = 14037,
  [14182] = 14162,
  [14183] = 14026,
  [14184] = 14037,
  [14185] = 5662,
  [14186] = 14026,
  [14187] = 14162,
  [14188] = 5591,
  [14189] = 5672,
  [14190] = 14026,
  [14191] = 14162,
  [14192] = 5673,
  [14193] = 14026,
  [14194] = 14038,
  [14195] = 14162,
  [14196] = 9372,
  [14197] = 14037,
  [14198] = 14026,
  [14199] = 14037,
  [14200] = 14043,
  [14201] = 14043,
  [14202] = 14026,
  [14203] = 14043,
  [14204] = 3140,
  [14205] = 5619,
  [14206] = 14162,
  [14207] = 5643,
  [14208] = 14026,
  [14209] = 5621,
  [14210] = 9313,
  [14211] = 5598,
  [14212] = 14026,
  [14213] = 14038,
  [14214] = 5603,
  [14215] = 9840,
  [14216] = 5605,
  [14217] = 9322,
  [14218] = 14026,
  [14219] = 5627,
  [14220] = 9480,
  [14221] = 14221,
  [14222] = 14222,
  [14223] = 14223,
  [14224] = 10339,
  [14225] = 14221,
  [14226] = 9624,
  [14227] = 11075,
  [14228] = 5494,
  [14229] = 14229,
  [14230] = 11241,
  [14231] = 14221,
  [14232] = 14222,
  [14233] = 14221,
  [14234] = 14222,
  [14235] = 14229,
  [14236] = 14236,
  [14237] = 14221,
  [14238] = 14221,
  [14239] = 14221,
  [14240] = 14221,
  [14241] = 14221,
  [14242] = 14221,
  [14243] = 14222,
  [14244] = 14222,
  [14245] = 11074,
  [14246] = 14222,
  [14247] = 14221,
  [14248] = 14248,
  [14249] = 14229,
  [14250] = 14221,
  [14251] = 14221,
  [14252] = 14252,
  [14253] = 14222,
  [14254] = 14221,
  [14255] = 14255,
  [14256] = 14221,
  [14257] = 14236,
  [14258] = 14229,
  [14259] = 14259,
  [14260] = 14221,
  [14261] = 14222,
  [14262] = 13969,
  [14263] = 10371,
  [14264] = 14264,
  [14265] = 14222,
  [14266] = 14236,
  [14267] = 14222,
  [14268] = 14222,
  [14269] = 14236,
  [14270] = 14221,
  [14271] = 14221,
  [14272] = 14221,
  [14273] = 10045,
  [14274] = 14222,
  [14275] = 14222,
  [14276] = 14222,
  [14277] = 14221,
  [14278] = 14222,
  [14279] = 10546,
  [14280] = 10547,
  [14281] = 10548,
  [14282] = 10549,
  [14283] = 14221,
  [14284] = 14229,
  [14285] = 14222,
  [14286] = 14222,
  [14287] = 14229,
  [14288] = 14221,
  [14289] = 14236,
  [14290] = 14222,
  [14291] = 14222,
  [14292] = 14222,
  [14293] = 14222,
  [14294] = 14222,
  [14295] = 5494,
  [14296] = 14296,
  [14297] = 14297,
  [14298] = 14298,
  [14299] = 9801,
  [14300] = 14300,
  [14301] = 10239,
  [14302] = 9941,
  [14303] = 14303,
  [14304] = 14304,
  [14305] = 14305,
  [14306] = 14306,
  [14307] = 14307,
  [14308] = 14308,
  [14309] = 14309,
  [14310] = 14305,
  [14311] = 14305,
  [14312] = 14312,
  [14313] = 14297,
  [14314] = 14300,
  [14315] = 14315,
  [14316] = 14305,
  [14317] = 14305,
  [14318] = 14297,
  [14319] = 14300,
  [14320] = 10690,
  [14321] = 9445,
  [14322] = 14322,
  [14323] = 14300,
  [14324] = 14297,
  [14325] = 14325,
  [14326] = 14300,
  [14327] = 14297,
  [14328] = 14305,
  [14329] = 14297,
  [14330] = 14300,
  [14331] = 14305,
  [14332] = 14300,
  [14333] = 14315,
  [14334] = 10356,
  [14335] = 14297,
  [14336] = 14300,
  [14337] = 14337,
  [14338] = 14338,
  [14339] = 14339,
  [14340] = 14340,
  [14341] = 14306,
  [14342] = 14308,
  [14343] = 14337,
  [14344] = 14309,
  [14345] = 14297,
  [14346] = 14338,
  [14347] = 14347,
  [14348] = 14300,
  [14349] = 14305,
  [14350] = 14322,
  [14351] = 14303,
  [14352] = 14304,
  [14353] = 14353,
  [14354] = 14297,
  [14355] = 14339,
  [14356] = 14300,
  [14357] = 14305,
  [14358] = 5488,
  [14359] = 14297,
  [14360] = 14340,
  [14361] = 14300,
  [14362] = 14322,
  [14363] = 14325,
  [14364] = 14305,
  [14365] = 14297,
  [14366] = 14300,
  [14367] = 9406,
  [14368] = 5494,
  [14369] = 14369,
  [14370] = 14347,
  [14371] = 14297,
  [14372] = 14300,
  [14373] = 14373,
  [14374] = 10103,
  [14375] = 9407,
  [14376] = 14347,
  [14377] = 14377,
  [14378] = 11483,
  [14379] = 14297,
  [14380] = 14377,
  [14381] = 14300,
  [14382] = 14297,
  [14383] = 14337,
  [14384] = 14369,
  [14385] = 14297,
  [14386] = 9408,
  [14387] = 14300,
  [14388] = 14377,
  [14389] = 14297,
  [14390] = 14300,
  [14391] = 14305,
  [14392] = 14297,
  [14393] = 14300,
  [14394] = 14022,
  [14395] = 9409,
  [14396] = 13980,
  [14397] = 13990,
  [14398] = 13982,
  [14399] = 14020,
  [14400] = 14297,
  [14401] = 14300,
  [14402] = 14300,
  [14403] = 10982,
  [14404] = 14303,
  [14405] = 14304,
  [14406] = 14297,
  [14407] = 14300,
  [14408] = 11461,
  [14409] = 14305,
  [14410] = 14315,
  [14411] = 14297,
  [14412] = 5513,
  [14413] = 14306,
  [14414] = 14300,
  [14415] = 14308,
  [14416] = 14309,
  [14417] = 9458,
  [14418] = 14297,
  [14419] = 14297,
  [14420] = 9991,
  [14421] = 14300,
  [14422] = 14300,
  [14423] = 14322,
  [14424] = 14297,
  [14425] = 14300,
  [14426] = 14338,
  [14427] = 14340,
  [14428] = 5606,
  [14429] = 5607,
  [14430] = 14297,
  [14431] = 14300,
  [14432] = 5620,
  [14433] = 10988,
  [14434] = 5635,
  [14435] = 11516,
  [14436] = 14300,
  [14437] = 14297,
  [14438] = 14300,
  [14439] = 9919,
  [14440] = 14325,
  [14441] = 10339,
  [14442] = 14297,
  [14443] = 14300,
  [14444] = 10442,
  [14445] = 14297,
  [14446] = 14300,
  [14447] = 5469,
  [14448] = 14337,
  [14449] = 14297,
  [14450] = 14338,
  [14451] = 14300,
  [14452] = 14305,
  [14453] = 14347,
  [14454] = 14297,
  [14455] = 14300,
  [14456] = 14337,
  [14457] = 14305,
  [14458] = 14304,
  [14459] = 14305,
  [14460] = 14338,
  [14461] = 14303,
  [14462] = 14304,
  [14463] = 14297,
  [14464] = 14300,
  [14465] = 14339,
  [14466] = 14339,
  [14467] = 3412,
  [14468] = 14305,
  [14469] = 14297,
  [14470] = 14300,
  [14471] = 9734,
  [14472] = 14297,
  [14473] = 14297,
  [14474] = 14300,
  [14475] = 14337,
  [14476] = 14338,
  [14477] = 14340,
  [14478] = 14340,
  [14479] = 9746,
  [14480] = 14306,
  [14481] = 14297,
  [14482] = 14308,
  [14483] = 14340,
  [14484] = 14300,
  [14485] = 11293,
  [14486] = 10045,
  [14487] = 9416,
  [14488] = 14300,
  [14489] = 9417,
  [14490] = 14297,
  [14491] = 14300,
  [14492] = 14347,
  [14493] = 9418,
  [14494] = 14297,
  [14495] = 14300,
  [14496] = 9419,
  [14497] = 14377,
  [14498] = 14297,
  [14499] = 14300,
  [14500] = 14297,
  [14501] = 14300,
  [14502] = 11297,
  [14503] = 14337,
  [14504] = 14338,
  [14505] = 14305,
  [14506] = 14303,
  [14507] = 9769,
  [14508] = 14306,
  [14509] = 14509,
  [14510] = 14305,
  [14511] = 14322,
  [14512] = 14308,
  [14513] = 14513,
  [14514] = 14297,
  [14515] = 14325,
  [14516] = 14300,
  [14517] = 14023,
  [14518] = 14369,
  [14519] = 14305,
  [14520] = 14309,
  [14521] = 14305,
  [14522] = 14305,
  [14523] = 13672,
  [14524] = 9888,
  [14525] = 14340,
  [14526] = 14347,
  [14527] = 14377,
  [14528] = 14325,
  [14529] = 14305,
  [14530] = 14530,
  [14531] = 14369,
  [14532] = 14297,
  [14533] = 14315,
  [14534] = 14305,
  [14535] = 14297,
  [14536] = 14509,
  [14537] = 14513,
  [14538] = 14369,
  [14539] = 14300,
  [14540] = 14305,
  [14541] = 14541,
  [14542] = 14305,
  [14543] = 14369,
  [14544] = 9395,
  [14545] = 14509,
  [14546] = 3471,
  [14547] = 14513,
  [14548] = 14305,
  [14549] = 14549,
  [14550] = 14369,
  [14551] = 14315,
  [14552] = 9426,
  [14553] = 14306,
  [14554] = 14554,
  [14555] = 14308,
  [14556] = 10519,
  [14557] = 9427,
  [14558] = 14309,
  [14559] = 14369,
  [14560] = 14303,
  [14561] = 14304,
  [14562] = 10314,
  [14563] = 10374,
  [14564] = 9428,
  [14565] = 14513,
  [14566] = 9429,
  [14567] = 9430,
  [14568] = 14322,
  [14569] = 9431,
  [14570] = 14541,
  [14571] = 3456,
  [14572] = 14572,
  [14573] = 3459,
  [14574] = 14297,
  [14575] = 3351,
  [14576] = 14322,
  [14577] = 3460,
  [14578] = 14300,
  [14579] = 14305,
  [14580] = 14337,
  [14581] = 14338,
  [14582] = 14340,
  [14583] = 14306,
  [14584] = 14308,
  [14585] = 14309,
  [14586] = 3255,
  [14587] = 14305,
  [14588] = 14588,
  [14589] = 14305,
  [14590] = 14347,
  [14591] = 14339,
  [14592] = 9816,
  [14593] = 14322,
  [14594] = 14325,
  [14595] = 3360,
  [14596] = 14325,
  [14597] = 3362,
  [14598] = 14347,
  [14599] = 14297,
  [14600] = 14377,
  [14601] = 14601,
  [14602] = 3468,
  [14603] = 3470,
  [14604] = 3256,
  [14605] = 14541,
  [14606] = 10315,
  [14607] = 14377,
  [14608] = 14601,
  [14609] = 14303,
  [14610] = 14300,
  [14611] = 14305,
  [14612] = 14541,
  [14613] = 14305,
  [14614] = 14305,
  [14615] = 9435,
  [14616] = 14315,
  [14617] = 9402,
  [14618] = 9403,
  [14619] = 9436,
  [14620] = 9404,
  [14621] = 9437,
  [14622] = 14622,
  [14623] = 14303,
  [14624] = 14304,
  [14625] = 9405,
  [14626] = 14530,
  [14627] = 10310,
  [14628] = 14509,
  [14629] = 9440,
  [14630] = 14373,
  [14631] = 13969,
  [14632] = 14297,
  [14633] = 14601,
  [14634] = 14601,
  [14635] = 14309,
  [14636] = 14636,
  [14637] = 5649,
  [14638] = 14638,
  [14639] = 14022,
  [14640] = 13878,
  [14641] = 13980,
  [14642] = 7868,
  [14643] = 13990,
  [14644] = 13915,
  [14645] = 13982,
  [14646] = 13829,
  [14647] = 13912,
  [14648] = 14020,
  [14649] = 14649,
  [14650] = 7757,
  [14651] = 14651,
  [14652] = 5619,
  [14653] = 13695,
  [14654] = 14654,
  [14655] = 5621,
  [14656] = 7819,
  [14657] = 14651,
  [14658] = 14638,
  [14659] = 14636,
  [14660] = 14636,
  [14661] = 14654,
  [14662] = 7752,
  [14663] = 14636,
  [14664] = 14654,
  [14665] = 14654,
  [14666] = 14651,
  [14667] = 5583,
  [14668] = 5598,
  [14669] = 14654,
  [14670] = 3452,
  [14671] = 14638,
  [14672] = 14638,
  [14673] = 14654,
  [14674] = 7753,
  [14675] = 14636,
  [14676] = 14654,
  [14677] = 14649,
  [14678] = 14638,
  [14679] = 14649,
  [14680] = 14638,
  [14681] = 14654,
  [14682] = 5603,
  [14683] = 14649,
  [14684] = 14638,
  [14685] = 7849,
  [14686] = 14686,
  [14687] = 14638,
  [14688] = 5591,
  [14689] = 5605,
  [14690] = 14649,
  [14691] = 14636,
  [14692] = 14638,
  [14693] = 14636,
  [14694] = 14649,
  [14695] = 7755,
  [14696] = 14696,
  [14697] = 14651,
  [14698] = 14638,
  [14699] = 14638,
  [14700] = 14651,
  [14701] = 14636,
  [14702] = 14649,
  [14703] = 14636,
  [14704] = 14649,
  [14705] = 14638,
  [14706] = 14636,
  [14707] = 14649,
  [14708] = 14651,
  [14709] = 14636,
  [14710] = 14654,
  [14711] = 14654,
  [14712] = 14651,
  [14713] = 14651,
  [14714] = 14649,
  [14715] = 14638,
  [14716] = 14638,
  [14717] = 14638,
  [14718] = 14638,
  [14719] = 14651,
  [14720] = 14654,
  [14721] = 14649,
  [14722] = 7820,
  [14723] = 14649,
  [14724] = 14638,
  [14725] = 13888,
  [14726] = 5635,
  [14727] = 14651,
  [14728] = 7821,
  [14729] = 14729,
  [14730] = 14651,
  [14731] = 7870,
  [14732] = 14654,
  [14733] = 14654,
  [14734] = 14651,
  [14735] = 14735,
  [14736] = 14649,
  [14737] = 14636,
  [14738] = 14651,
  [14739] = 14654,
  [14740] = 14651,
  [14741] = 5652,
  [14742] = 14654,
  [14743] = 14654,
  [14744] = 9773,
  [14745] = 14649,
  [14746] = 14651,
  [14747] = 14636,
  [14748] = 13851,
  [14749] = 5666,
  [14750] = 14654,
  [14751] = 14654,
  [14752] = 14636,
  [14753] = 14649,
  [14754] = 3458,
  [14755] = 14649,
  [14756] = 14638,
  [14757] = 7822,
  [14758] = 11074,
  [14759] = 14636,
  [14760] = 7834,
  [14761] = 13853,
  [14762] = 13861,
  [14763] = 14638,
  [14764] = 14654,
  [14765] = 13866,
  [14766] = 13890,
  [14767] = 11075,
  [14768] = 14654,
  [14769] = 14651,
  [14770] = 5637,
  [14771] = 14636,
  [14772] = 5677,
  [14773] = 10690,
  [14774] = 5594,
  [14775] = 14651,
  [14776] = 5623,
  [14777] = 14649,
  [14778] = 14778,
  [14779] = 14649,
  [14780] = 14638,
  [14781] = 14654,
  [14782] = 14782,
  [14783] = 5643,
  [14784] = 5656,
  [14785] = 14651,
  [14786] = 14654,
  [14787] = 14649,
  [14788] = 14638,
  [14789] = 14651,
  [14790] = 14636,
  [14791] = 14654,
  [14792] = 14654,
  [14793] = 14793,
  [14794] = 14651,
  [14795] = 14649,
  [14796] = 14654,
  [14797] = 14654,
  [14798] = 3453,
  [14799] = 14654,
  [14800] = 14638,
  [14801] = 14801,
  [14802] = 14638,
  [14803] = 14654,
  [14804] = 5606,
  [14805] = 14651,
  [14806] = 14649,
  [14807] = 14807,
  [14808] = 14636,
  [14809] = 10882,
  [14810] = 7877,
  [14811] = 3454,
  [14812] = 14651,
  [14813] = 5607,
  [14814] = 5617,
  [14815] = 10883,
  [14816] = 10889,
  [14817] = 14638,
  [14818] = 14636,
  [14819] = 14654,
  [14820] = 13895,
  [14821] = 13896,
  [14822] = 7914,
  [14823] = 14649,
  [14824] = 14651,
  [14825] = 3472,
  [14826] = 14651,
  [14827] = 14636,
  [14828] = 14654,
  [14829] = 14654,
  [14830] = 14636,
  [14831] = 14649,
  [14832] = 3450,
  [14833] = 14649,
  [14834] = 14651,
  [14835] = 5667,
  [14836] = 14649,
  [14837] = 5620,
  [14838] = 14838,
  [14839] = 5585,
  [14840] = 14649,
  [14841] = 14638,
  [14842] = 14636,
  [14843] = 14636,
  [14844] = 5707,
  [14845] = 14651,
  [14846] = 5672,
  [14847] = 14638,
  [14848] = 5673,
  [14849] = 14638,
  [14850] = 14649,
  [14851] = 14649,
  [14852] = 10561,
  [14853] = 5633,
  [14854] = 14636,
  [14855] = 14638,
  [14856] = 14856,
  [14857] = 14654,
  [14858] = 14636,
  [14859] = 5599,
  [14860] = 5600,
  [14861] = 5634,
  [14862] = 14636,
  [14863] = 14649,
  [14864] = 14649,
  [14865] = 11205,
  [14866] = 14636,
  [14867] = 11104,
  [14868] = 14636,
  [14869] = 10843,
  [14870] = 10851,
  [14871] = 13910,
  [14872] = 14801,
  [14873] = 5627,
  [14874] = 5635,
  [14875] = 14654,
  [14876] = 14651,
  [14877] = 14877,
  [14878] = 14636,
  [14879] = 7795,
  [14880] = 5630,
  [14881] = 14649,
  [14882] = 14636,
  [14883] = 5613,
  [14884] = 14649,
  [14885] = 5586,
  [14886] = 5609,
  [14887] = 5610,
  [14888] = 14654,
  [14889] = 7796,
  [14890] = 14735,
  [14891] = 14649,
  [14892] = 14636,
  [14893] = 14638,
  [14894] = 14651,
  [14895] = 14638,
  [14896] = 14651,
  [14897] = 14649,
  [14898] = 14636,
  [14899] = 3295,
  [14900] = 14649,
  [14901] = 14651,
  [14902] = 14654,
  [14903] = 14903,
  [14904] = 3451,
  [14905] = 14649,
  [14906] = 14654,
  [14907] = 10967,
  [14908] = 10968,
  [14909] = 14651,
  [14910] = 14638,
  [14911] = 14636,
  [14912] = 10969,
  [14913] = 10971,
  [14914] = 3455,
  [14915] = 14638,
  [14916] = 14651,
  [14917] = 14636,
  [14918] = 7797,
  [14919] = 14654,
  [14920] = 7800,
  [14921] = 7801,
  [14922] = 14636,
  [14923] = 14649,
  [14924] = 14654,
  [14925] = 14807,
  [14926] = 5723,
  [14927] = 14651,
  [14928] = 11135,
  [14929] = 11141,
  [14930] = 11154,
  [14931] = 14636,
  [14932] = 14638,
  [14933] = 5681,
  [14934] = 11131,
  [14935] = 14935,
  [14936] = 5693,
  [14937] = 14638,
  [14938] = 3360,
  [14939] = 3362,
  [14940] = 14651,
  [14941] = 14941,
  [14942] = 14942,
  [14943] = 5646,
  [14944] = 14942,
  [14945] = 5724,
  [14946] = 11241,
  [14947] = 14649,
  [14948] = 5593,
  [14949] = 5601,
  [14950] = 5595,
  [14951] = 14651,
  [14952] = 14638,
  [14953] = 14638,
  [14954] = 14651,
  [14955] = 14651,
  [14956] = 14636,
  [14957] = 14638,
  [14958] = 14636,
  [14959] = 14638,
  [14960] = 14651,
  [14961] = 10800,
  [14962] = 7756,
  [14963] = 14638,
  [14964] = 14649,
  [14965] = 14651,
  [14966] = 14636,
  [14967] = 14638,
  [14968] = 14654,
  [14969] = 14654,
  [14970] = 11190,
  [14971] = 10624,
  [14972] = 14649,
  [14973] = 14651,
  [14974] = 14636,
  [14975] = 14838,
  [14976] = 14654,
  [14977] = 14649,
  [14978] = 14654,
  [14979] = 5662,
  [14980] = 14651,
  [14981] = 14636,
  [14982] = 5606,
  [14983] = 14636,
  [14984] = 14649,
  [14985] = 14651,
  [14986] = 14023,
  [14987] = 14638,
  [14988] = 14638,
  [14989] = 5607,
  [14990] = 14838,
  [14991] = 14838,
  [14992] = 5620,
  [14993] = 13846,
  [14994] = 14994,
  [14995] = 11152,
  [14996] = 14996,
  [14997] = 14997,
  [14998] = 14998,
  [14999] = 10014,
  [15000] = 14997,
  [15001] = 15001,
  [15002] = 15002,
  [15003] = 14997,
  [15004] = 14994,
  [15005] = 14998,
  [15006] = 14994,
  [15007] = 14994,
  [15008] = 15008,
  [15009] = 11162,
  [15010] = 14994,
  [15011] = 14997,
  [15012] = 14994,
  [15013] = 14997,
  [15014] = 14997,
  [15015] = 14994,
  [15016] = 11035,
  [15017] = 15017,
  [15018] = 15018,
  [15019] = 15019,
  [15020] = 14994,
  [15021] = 14998,
  [15022] = 15022,
  [15023] = 15002,
  [15024] = 15024,
  [15025] = 14997,
  [15026] = 14994,
  [15027] = 14994,
  [15028] = 14997,
  [15029] = 14997,
  [15030] = 14997,
  [15031] = 15031,
  [15032] = 14998,
  [15033] = 14998,
  [15034] = 14998,
  [15035] = 15035,
  [15036] = 14997,
  [15037] = 14994,
  [15038] = 14994,
  [15039] = 15035,
  [15040] = 15040,
  [15041] = 14997,
  [15042] = 14994,
  [15043] = 14994,
  [15044] = 14994,
  [15045] = 14994,
  [15046] = 15046,
  [15047] = 9773,
  [15048] = 14997,
  [15049] = 15049,
  [15050] = 14994,
  [15051] = 14994,
  [15052] = 15052,
  [15053] = 14997,
  [15054] = 15046,
  [15055] = 14998,
  [15056] = 15056,
  [15057] = 15002,
  [15058] = 14994,
  [15059] = 14998,
  [15060] = 15060,
  [15061] = 15017,
  [15062] = 15019,
  [15063] = 15063,
  [15064] = 14997,
  [15065] = 14997,
  [15066] = 14994,
  [15067] = 15067,
  [15068] = 14997,
  [15069] = 10865,
  [15070] = 14998,
  [15071] = 15071,
  [15072] = 15049,
  [15073] = 15035,
  [15074] = 15074,
  [15075] = 15002,
  [15076] = 15035,
  [15077] = 15031,
  [15078] = 14998,
  [15079] = 15079,
  [15080] = 15080,
  [15081] = 14997,
  [15082] = 15082,
  [15083] = 14998,
  [15084] = 15084,
  [15085] = 14997,
  [15086] = 15046,
  [15087] = 14998,
  [15088] = 14997,
  [15089] = 14994,
  [15090] = 15035,
  [15091] = 10871,
  [15092] = 15092,
  [15093] = 3269,
  [15094] = 14997,
  [15095] = 14994,
  [15096] = 15002,
  [15097] = 14994,
  [15098] = 14998,
  [15099] = 11155,
  [15100] = 14994,
  [15101] = 14994,
  [15102] = 14997,
  [15103] = 14997,
  [15104] = 11161,
  [15105] = 14994,
  [15106] = 14997,
  [15107] = 15107,
  [15108] = 14994,
  [15109] = 14997,
  [15110] = 14997,
  [15111] = 15046,
  [15112] = 14997,
  [15113] = 14994,
  [15114] = 15019,
  [15115] = 14998,
  [15116] = 15008,
  [15117] = 14994,
  [15118] = 14998,
  [15119] = 14994,
  [15120] = 11293,
  [15121] = 11297,
  [15122] = 14994,
  [15123] = 14997,
  [15124] = 15124,
  [15125] = 15031,
  [15126] = 11483,
  [15127] = 15127,
  [15128] = 14997,
  [15129] = 15002,
  [15130] = 15049,
  [15131] = 15002,
  [15132] = 14998,
  [15133] = 14994,
  [15134] = 14998,
  [15135] = 14994,
  [15136] = 15031,
  [15137] = 15049,
  [15138] = 15008,
  [15139] = 14994,
  [15140] = 15031,
  [15141] = 14997,
  [15142] = 15127,
  [15143] = 15143,
  [15144] = 15049,
  [15145] = 14998,
  [15146] = 14997,
  [15147] = 15008,
  [15148] = 15148,
  [15149] = 14998,
  [15150] = 14994,
  [15151] = 14997,
  [15152] = 14997,
  [15153] = 14997,
  [15154] = 15008,
  [15155] = 10898,
  [15156] = 10811,
  [15157] = 14994,
  [15158] = 11516,
  [15159] = 14994,
  [15160] = 14997,
  [15161] = 14997,
  [15162] = 15017,
  [15163] = 10962,
  [15164] = 15164,
  [15165] = 14997,
  [15166] = 14994,
  [15167] = 14994,
  [15168] = 14997,
  [15169] = 14998,
  [15170] = 14997,
  [15171] = 15035,
  [15172] = 14994,
  [15173] = 15173,
  [15174] = 15035,
  [15175] = 15175,
  [15176] = 14998,
  [15177] = 15019,
  [15178] = 15074,
  [15179] = 14997,
  [15180] = 15019,
  [15181] = 15031,
  [15182] = 15127,
  [15183] = 10979,
  [15184] = 15127,
  [15185] = 15049,
  [15186] = 14997,
  [15187] = 14994,
  [15188] = 15002,
  [15189] = 11138,
  [15190] = 15035,
  [15191] = 15017,
  [15192] = 14997,
  [15193] = 14994,
  [15194] = 15019,
  [15195] = 15008,
  [15196] = 10925,
  [15197] = 15031,
  [15198] = 14998,
  [15199] = 15019,
  [15200] = 15200,
  [15201] = 15201,
  [15202] = 15202,
  [15203] = 15203,
  [15204] = 15204,
  [15205] = 15205,
  [15206] = 15206,
  [15207] = 15204,
  [15208] = 15208,
  [15209] = 15209,
  [15210] = 15210,
  [15211] = 15211,
  [15212] = 15206,
  [15213] = 15213,
  [15214] = 15203,
  [15215] = 15205,
  [15216] = 15205,
  [15217] = 15217,
  [15218] = 15218,
  [15219] = 15219,
  [15220] = 15204,
  [15221] = 15221,
  [15222] = 15222,
  [15223] = 15210,
  [15224] = 15224,
  [15225] = 15225,
  [15226] = 15226,
  [15227] = 15206,
  [15228] = 15205,
  [15229] = 15229,
  [15230] = 15204,
  [15231] = 15203,
  [15232] = 15204,
  [15233] = 15233,
  [15234] = 15225,
  [15235] = 15235,
  [15236] = 15224,
  [15237] = 15237,
  [15238] = 15210,
  [15239] = 15239,
  [15240] = 15206,
  [15241] = 15226,
  [15242] = 15233,
  [15243] = 15205,
  [15244] = 15239,
  [15245] = 15204,
  [15246] = 15210,
  [15247] = 15210,
  [15248] = 15221,
  [15249] = 15222,
  [15250] = 15206,
  [15251] = 15251,
  [15252] = 15206,
  [15253] = 15205,
  [15254] = 15208,
  [15255] = 15209,
  [15256] = 15204,
  [15257] = 15210,
  [15258] = 15211,
  [15259] = 15210,
  [15260] = 15260,
  [15261] = 10381,
  [15262] = 15262,
  [15263] = 15213,
  [15264] = 15206,
  [15265] = 15229,
  [15266] = 15205,
  [15267] = 15217,
  [15268] = 15205,
  [15269] = 15218,
  [15270] = 15219,
  [15271] = 15219,
  [15272] = 15221,
  [15273] = 15222,
  [15274] = 15251,
  [15275] = 15204,
  [15276] = 15205,
  [15277] = 15210,
  [15278] = 15206,
  [15279] = 15204,
  [15280] = 15206,
  [15281] = 15281,
  [15282] = 15203,
  [15283] = 15205,
  [15284] = 15204,
  [15285] = 15210,
  [15286] = 15233,
  [15287] = 15239,
  [15288] = 15206,
  [15289] = 15233,
  [15290] = 15205,
  [15291] = 15218,
  [15292] = 15292,
  [15293] = 15204,
  [15294] = 15239,
  [15295] = 15210,
  [15296] = 15208,
  [15297] = 15209,
  [15298] = 15210,
  [15299] = 15221,
  [15300] = 15222,
  [15301] = 15206,
  [15302] = 15239,
  [15303] = 15206,
  [15304] = 15205,
  [15305] = 15229,
  [15306] = 15204,
  [15307] = 15208,
  [15308] = 15209,
  [15309] = 15204,
  [15310] = 15310,
  [15311] = 15311,
  [15312] = 15210,
  [15313] = 15224,
  [15314] = 15204,
  [15315] = 15206,
  [15316] = 15211,
  [15317] = 15205,
  [15318] = 15203,
  [15319] = 15213,
  [15320] = 15211,
  [15321] = 15204,
  [15322] = 15205,
  [15323] = 15217,
  [15324] = 15206,
  [15325] = 15218,
  [15326] = 15219,
  [15327] = 15203,
  [15328] = 15210,
  [15329] = 4789,
  [15330] = 15206,
  [15331] = 15213,
  [15332] = 15205,
  [15333] = 15225,
  [15334] = 15204,
  [15335] = 15204,
  [15336] = 15203,
  [15337] = 11489,
  [15338] = 15224,
  [15339] = 15210,
  [15340] = 15226,
  [15341] = 15210,
  [15342] = 15206,
  [15343] = 15204,
  [15344] = 15233,
  [15345] = 15239,
  [15346] = 15205,
  [15347] = 15210,
  [15348] = 15251,
  [15349] = 15210,
  [15350] = 15206,
  [15351] = 15217,
  [15352] = 15262,
  [15353] = 15353,
  [15354] = 15221,
  [15355] = 15219,
  [15356] = 15222,
  [15357] = 15204,
  [15358] = 15233,
  [15359] = 15218,
  [15360] = 15239,
  [15361] = 15206,
  [15362] = 15210,
  [15363] = 15206,
  [15364] = 15219,
  [15365] = 15208,
  [15366] = 15209,
  [15367] = 11426,
  [15368] = 15368,
  [15369] = 15369,
  [15370] = 4788,
  [15371] = 15210,
  [15372] = 15211,
  [15373] = 15373,
  [15374] = 15213,
  [15375] = 15262,
  [15376] = 15205,
  [15377] = 15217,
  [15378] = 15218,
  [15379] = 15219,
  [15380] = 15311,
  [15381] = 15381,
  [15382] = 15311,
  [15383] = 15383,
  [15384] = 15224,
  [15385] = 15204,
  [15386] = 15226,
  [15387] = 15203,
  [15388] = 15388,
  [15389] = 15233,
  [15390] = 15221,
  [15391] = 15222,
  [15392] = 15233,
  [15393] = 15239,
  [15394] = 15206,
  [15395] = 15225,
  [15396] = 15233,
  [15397] = 15388,
  [15398] = 15369,
  [15399] = 15399,
  [15400] = 15210,
  [15401] = 15401,
  [15402] = 15239,
  [15403] = 11455,
  [15404] = 11440,
  [15405] = 15221,
  [15406] = 15222,
  [15407] = 15208,
  [15408] = 15209,
  [15409] = 15206,
  [15410] = 15235,
  [15411] = 15237,
  [15412] = 15292,
  [15413] = 15208,
  [15414] = 15209,
  [15415] = 15415,
  [15416] = 15211,
  [15417] = 15211,
  [15418] = 13846,
  [15419] = 15229,
  [15420] = 15213,
  [15421] = 15213,
  [15422] = 11275,
  [15423] = 15205,
  [15424] = 15217,
  [15425] = 15218,
  [15426] = 15219,
  [15427] = 13695,
  [15428] = 13622,
  [15429] = 15204,
  [15430] = 15204,
  [15431] = 15221,
  [15432] = 15222,
  [15433] = 15203,
  [15434] = 15434,
  [15435] = 15435,
  [15436] = 15203,
  [15437] = 15205,
  [15438] = 15233,
  [15439] = 4785,
  [15440] = 11794,
  [15441] = 15217,
  [15442] = 15239,
  [15443] = 15218,
  [15444] = 15219,
  [15445] = 15208,
  [15446] = 15209,
  [15447] = 15447,
  [15448] = 15210,
  [15449] = 15221,
  [15450] = 15222,
  [15451] = 15206,
  [15452] = 15206,
  [15453] = 15208,
  [15454] = 15209,
  [15455] = 15211,
  [15456] = 15213,
  [15457] = 15205,
  [15458] = 15217,
  [15459] = 15218,
  [15460] = 15219,
  [15461] = 15461,
  [15462] = 15224,
  [15463] = 15463,
  [15464] = 15205,
  [15465] = 15465,
  [15466] = 15226,
  [15467] = 15388,
  [15468] = 15468,
  [15469] = 15204,
  [15470] = 15203,
  [15471] = 15224,
  [15472] = 10536,
  [15473] = 15226,
  [15474] = 15401,
  [15475] = 15399,
  [15476] = 15233,
  [15477] = 15292,
  [15478] = 15233,
  [15479] = 7866,
  [15480] = 15239,
  [15481] = 15239,
  [15482] = 15210,
  [15483] = 15483,
  [15484] = 15221,
  [15485] = 15222,
  [15486] = 15210,
  [15487] = 10804,
  [15488] = 15206,
  [15489] = 15229,
  [15490] = 15388,
  [15491] = 15208,
  [15492] = 15209,
  [15493] = 15239,
  [15494] = 15211,
  [15495] = 15204,
  [15496] = 15213,
  [15497] = 15401,
  [15498] = 15203,
  [15499] = 15210,
  [15500] = 15205,
  [15501] = 15217,
  [15502] = 15218,
  [15503] = 15219,
  [15504] = 15292,
  [15505] = 15369,
  [15506] = 15262,
  [15507] = 15262,
  [15508] = 15204,
  [15509] = 15208,
  [15510] = 15203,
  [15511] = 15225,
  [15512] = 15209,
  [15513] = 15224,
  [15514] = 15226,
  [15515] = 15435,
  [15516] = 15221,
  [15517] = 15222,
  [15518] = 15233,
  [15519] = 15239,
  [15520] = 15226,
  [15521] = 15401,
  [15522] = 15210,
  [15523] = 15251,
  [15524] = 15292,
  [15525] = 15233,
  [15526] = 15239,
  [15527] = 15221,
  [15528] = 15222,
  [15529] = 13878,
  [15530] = 15260,
  [15531] = 15206,
  [15532] = 11446,
  [15533] = 15210,
  [15534] = 15208,
  [15535] = 15209,
  [15536] = 15206,
  [15537] = 15262,
  [15538] = 15311,
  [15539] = 15401,
  [15540] = 15211,
  [15541] = 15292,
  [15542] = 15213,
  [15543] = 11371,
  [15544] = 15205,
  [15545] = 15221,
  [15546] = 15222,
  [15547] = 15415,
  [15548] = 15206,
  [15549] = 15401,
  [15550] = 15550,
  [15551] = 15399,
  [15552] = 15208,
  [15553] = 15204,
  [15554] = 15209,
  [15555] = 15203,
  [15556] = 15221,
  [15557] = 15211,
  [15558] = 15222,
  [15559] = 15208,
  [15560] = 15209,
  [15561] = 13888,
  [15562] = 15401,
  [15563] = 15415,
  [15564] = 13890,
  [15565] = 15211,
  [15566] = 15233,
  [15567] = 15239,
  [15568] = 13622,
  [15569] = 15229,
  [15570] = 15401,
  [15571] = 15213,
  [15572] = 15210,
  [15573] = 15211,
  [15574] = 15221,
  [15575] = 15222,
  [15576] = 12228,
  [15577] = 15401,
  [15578] = 15213,
  [15579] = 15205,
  [15580] = 15206,
  [15581] = 11885,
  [15582] = 15217,
  [15583] = 15218,
  [15584] = 15219,
  [15585] = 15208,
  [15586] = 15209,
  [15587] = 15213,
  [15588] = 15221,
  [15589] = 15222,
  [15590] = 15401,
  [15591] = 15211,
  [15592] = 15217,
  [15593] = 15206,
  [15594] = 15213,
  [15595] = 15205,
  [15596] = 15401,
  [15597] = 15204,
  [15598] = 15205,
  [15599] = 15203,
  [15600] = 15237,
  [15601] = 15217,
  [15602] = 15415,
  [15603] = 15218,
  [15604] = 15604,
  [15605] = 15219,
  [15606] = 15606,
  [15607] = 15607,
  [15608] = 15401,
  [15609] = 15233,
  [15610] = 15610,
  [15611] = 15239,
  [15612] = 15208,
  [15613] = 15209,
  [15614] = 15210,
  [15615] = 15229,
  [15616] = 15435,
  [15617] = 11430,
  [15618] = 15210,
  [15619] = 15204,
  [15620] = 15203,
  [15621] = 15205,
  [15622] = 15221,
  [15623] = 15222,
  [15624] = 15225,
  [15625] = 15206,
  [15626] = 15224,
  [15627] = 15226,
  [15628] = 15208,
  [15629] = 15209,
  [15630] = 15251,
  [15631] = 15631,
  [15632] = 15211,
  [15633] = 15233,
  [15634] = 15211,
  [15635] = 15239,
  [15636] = 15213,
  [15637] = 15205,
  [15638] = 15210,
  [15639] = 15205,
  [15640] = 15262,
  [15641] = 15311,
  [15642] = 15204,
  [15643] = 11307,
  [15644] = 15211,
  [15645] = 15221,
  [15646] = 15222,
  [15647] = 15229,
  [15648] = 15206,
  [15649] = 15399,
  [15650] = 15650,
  [15651] = 15208,
  [15652] = 15209,
  [15653] = 15210,
  [15654] = 15204,
  [15655] = 15213,
  [15656] = 15415,
  [15657] = 15203,
  [15658] = 15211,
  [15659] = 15206,
  [15660] = 15213,
  [15661] = 15213,
  [15662] = 15662,
  [15663] = 15205,
  [15664] = 15205,
  [15665] = 15217,
  [15666] = 15218,
  [15667] = 15219,
  [15668] = 11910,
  [15669] = 15217,
  [15670] = 15217,
  [15671] = 15204,
  [15672] = 15203,
  [15673] = 15224,
  [15674] = 15226,
  [15675] = 11912,
  [15676] = 15206,
  [15677] = 11914,
  [15678] = 15233,
  [15679] = 15239,
  [15680] = 15210,
  [15681] = 15217,
  [15682] = 15682,
  [15683] = 15205,
  [15684] = 15206,
  [15685] = 15685,
  [15686] = 15353,
  [15687] = 15401,
  [15688] = 15218,
  [15689] = 15205,
  [15690] = 15690,
  [15691] = 15210,
  [15692] = 15218,
  [15693] = 15219,
  [15694] = 15262,
  [15695] = 15213,
  [15696] = 15229,
  [15697] = 15463,
  [15698] = 15262,
  [15699] = 15204,
  [15700] = 15204,
  [15701] = 15203,
  [15702] = 15221,
  [15703] = 15222,
  [15704] = 10820,
  [15705] = 10821,
  [15706] = 15224,
  [15707] = 15226,
  [15708] = 15217,
  [15709] = 15709,
  [15710] = 15218,
  [15711] = 15210,
  [15712] = 15251,
  [15713] = 15206,
  [15714] = 15233,
  [15715] = 15239,
  [15716] = 15206,
  [15717] = 15210,
  [15718] = 15219,
  [15719] = 15205,
  [15720] = 15208,
  [15721] = 15209,
  [15722] = 15200,
  [15723] = 15723,
  [15724] = 15353,
  [15725] = 15200,
  [15726] = 15723,
  [15727] = 15550,
  [15728] = 15262,
  [15729] = 15311,
  [15730] = 15730,
  [15731] = 15434,
  [15732] = 15465,
  [15733] = 15381,
  [15734] = 15204,
  [15735] = 15211,
  [15736] = 15210,
  [15737] = 15662,
  [15738] = 15221,
  [15739] = 15222,
  [15740] = 15213,
  [15741] = 15235,
  [15742] = 15205,
  [15743] = 15233,
  [15744] = 15217,
  [15745] = 15206,
  [15746] = 15217,
  [15747] = 15399,
  [15748] = 15208,
  [15749] = 15210,
  [15750] = 15218,
  [15751] = 15730,
  [15752] = 15208,
  [15753] = 15219,
  [15754] = 15209,
  [15755] = 15209,
  [15756] = 15206,
  [15757] = 15205,
  [15758] = 15381,
  [15759] = 15415,
  [15760] = 15211,
  [15761] = 15217,
  [15762] = 15218,
  [15763] = 15205,
  [15764] = 15235,
  [15765] = 15219,
  [15766] = 15213,
  [15767] = 15262,
  [15768] = 15723,
  [15769] = 15769,
  [15770] = 15205,
  [15771] = 15204,
  [15772] = 15772,
  [15773] = 15217,
  [15774] = 15218,
  [15775] = 15219,
  [15776] = 11943,
  [15777] = 15381,
  [15778] = 15205,
  [15779] = 15218,
  [15780] = 15730,
  [15781] = 15235,
  [15782] = 15468,
  [15783] = 15210,
  [15784] = 15381,
  [15785] = 15399,
  [15786] = 15434,
  [15787] = 15206,
  [15788] = 15235,
  [15789] = 15631,
  [15790] = 15381,
  [15791] = 15251,
  [15792] = 15381,
  [15793] = 15229,
  [15794] = 15381,
  [15795] = 15205,
  [15796] = 15229,
  [15797] = 15381,
  [15798] = 15219,
  [15799] = 15769,
  [15800] = 15381,
  [15801] = 15219,
  [15802] = 15204,
  [15803] = 15381,
  [15804] = 15203,
  [15805] = 15204,
  [15806] = 15381,
  [15807] = 15229,
  [15808] = 15381,
  [15809] = 15381,
  [15810] = 15810,
  [15811] = 15224,
  [15812] = 15381,
  [15813] = 15226,
  [15814] = 15381,
  [15815] = 15203,
  [15816] = 15381,
  [15817] = 15204,
  [15818] = 15251,
  [15819] = 15381,
  [15820] = 15233,
  [15821] = 15381,
  [15822] = 15239,
  [15823] = 15381,
  [15824] = 15381,
  [15825] = 15381,
  [15826] = 15210,
  [15827] = 15381,
  [15828] = 15262,
  [15829] = 15381,
  [15830] = 15381,
  [15831] = 15381,
  [15832] = 15381,
  [15833] = 15221,
  [15834] = 15222,
  [15835] = 15381,
  [15836] = 15381,
  [15837] = 15206,
  [15838] = 15381,
  [15839] = 15381,
  [15840] = 15210,
  [15841] = 15381,
  [15842] = 15381,
  [15843] = 15208,
  [15844] = 15209,
  [15845] = 15381,
  [15846] = 15229,
  [15847] = 15381,
  [15848] = 15381,
  [15849] = 15211,
  [15850] = 15381,
  [15851] = 15224,
  [15852] = 15213,
  [15853] = 15381,
  [15854] = 15226,
  [15855] = 15206,
  [15856] = 15381,
  [15857] = 15381,
  [15858] = 15381,
  [15859] = 15205,
  [15860] = 15217,
  [15861] = 15381,
  [15862] = 15218,
  [15863] = 15219,
  [15864] = 15281,
  [15865] = 15369,
  [15866] = 15233,
  [15867] = 15685,
  [15868] = 15239,
  [15869] = 15205,
  [15870] = 11461,
  [15871] = 15237,
  [15872] = 15872,
  [15873] = 15204,
  [15874] = 15211,
  [15875] = 15204,
  [15876] = 15200,
  [15877] = 15210,
  [15878] = 15878,
  [15879] = 10463,
  [15880] = 15435,
  [15881] = 15229,
  [15882] = 15262,
  [15883] = 15353,
  [15884] = 15200,
  [15885] = 15723,
  [15886] = 15434,
  [15887] = 15682,
  [15888] = 15730,
  [15889] = 15204,
  [15890] = 15218,
  [15891] = 15203,
  [15892] = 15210,
  [15893] = 15353,
  [15894] = 15200,
  [15895] = 15723,
  [15896] = 15434,
  [15897] = 15685,
  [15898] = 15237,
  [15899] = 15723,
  [15900] = 15221,
  [15901] = 15434,
  [15902] = 15682,
  [15903] = 15222,
  [15904] = 15682,
  [15905] = 15204,
  [15906] = 15685,
  [15907] = 15206,
  [15908] = 15237,
  [15909] = 15909,
  [15910] = 15910,
  [15911] = 15911,
  [15912] = 15912,
  [15913] = 15913,
  [15914] = 15914,
  [15915] = 15915,
  [15916] = 15916,
  [15917] = 15916,
  [15918] = 15912,
  [15919] = 10803,
  [15920] = 10805,
  [15921] = 15921,
  [15922] = 15922,
  [15923] = 15923,
  [15924] = 15924,
  [15925] = 15925,
  [15926] = 15926,
  [15927] = 15912,
  [15928] = 15926,
  [15929] = 15929,
  [15930] = 15930,
  [15931] = 15931,
  [15932] = 15932,
  [15933] = 15933,
  [15934] = 15934,
  [15935] = 15935,
  [15936] = 15936,
  [15937] = 15924,
  [15938] = 15938,
  [15939] = 15932,
  [15940] = 15932,
  [15941] = 15916,
  [15942] = 15942,
  [15943] = 15943,
  [15944] = 15926,
  [15945] = 15945,
  [15946] = 15935,
  [15947] = 15929,
  [15948] = 15948,
  [15949] = 15949,
  [15950] = 15932,
  [15951] = 15951,
  [15952] = 15945,
  [15953] = 15912,
  [15954] = 15954,
  [15955] = 15916,
  [15956] = 15912,
  [15957] = 15926,
  [15958] = 15926,
  [15959] = 15945,
  [15960] = 15954,
  [15961] = 15961,
  [15962] = 15962,
  [15963] = 15913,
  [15964] = 15910,
  [15965] = 15965,
  [15966] = 15914,
  [15967] = 15912,
  [15968] = 15968,
  [15969] = 15969,
  [15970] = 15921,
  [15971] = 15971,
  [15972] = 15954,
  [15973] = 15973,
  [15974] = 15931,
  [15975] = 15930,
  [15976] = 15933,
  [15977] = 15915,
  [15978] = 15934,
  [15979] = 15924,
  [15980] = 15921,
  [15981] = 15921,
  [15982] = 15954,
  [15983] = 15921,
  [15984] = 15930,
  [15985] = 15922,
  [15986] = 15935,
  [15987] = 15935,
  [15988] = 15913,
  [15989] = 15921,
  [15990] = 15914,
  [15991] = 15915,
  [15992] = 15912,
  [15993] = 15916,
  [15994] = 15935,
  [15995] = 15995,
  [15996] = 15916,
  [15997] = 15936,
  [15998] = 15998,
  [15999] = 15929,
  [16000] = 15926,
  [16001] = 15911,
  [16002] = 15922,
  [16003] = 15942,
  [16004] = 15912,
  [16005] = 15932,
  [16006] = 16006,
  [16007] = 15916,
  [16008] = 15924,
  [16009] = 15995,
  [16010] = 15921,
  [16011] = 15924,
  [16012] = 15926,
  [16013] = 15961,
  [16014] = 15921,
  [16015] = 15935,
  [16016] = 15910,
  [16017] = 15932,
  [16018] = 15965,
  [16019] = 15913,
  [16020] = 15998,
  [16021] = 15929,
  [16022] = 15968,
  [16023] = 15969,
  [16024] = 15971,
  [16025] = 15914,
  [16026] = 15973,
  [16027] = 15911,
  [16028] = 15915,
  [16029] = 15932,
  [16030] = 15924,
  [16031] = 15922,
  [16032] = 15924,
  [16033] = 15916,
  [16034] = 15913,
  [16035] = 15954,
  [16036] = 15935,
  [16037] = 15912,
  [16038] = 15924,
  [16039] = 15916,
  [16040] = 12877,
  [16041] = 15929,
  [16042] = 16042,
  [16043] = 15926,
  [16044] = 15931,
  [16045] = 15914,
  [16046] = 15933,
  [16047] = 15934,
  [16048] = 15954,
  [16049] = 15912,
  [16050] = 15936,
  [16051] = 16051,
  [16052] = 15921,
  [16053] = 15942,
  [16054] = 15932,
  [16055] = 15998,
  [16056] = 16056,
  [16057] = 16057,
  [16058] = 16058,
  [16059] = 15935,
  [16060] = 15930,
  [16061] = 16061,
  [16062] = 15945,
  [16063] = 15912,
  [16064] = 16064,
  [16065] = 15929,
  [16066] = 15954,
  [16067] = 16067,
  [16068] = 15910,
  [16069] = 15965,
  [16070] = 15916,
  [16071] = 16071,
  [16072] = 15969,
  [16073] = 16073,
  [16074] = 15971,
  [16075] = 15973,
  [16076] = 16076,
  [16077] = 12878,
  [16078] = 12879,
  [16079] = 15929,
  [16080] = 15931,
  [16081] = 15913,
  [16082] = 15914,
  [16083] = 15915,
  [16084] = 15926,
  [16085] = 15933,
  [16086] = 16086,
  [16087] = 15922,
  [16088] = 15924,
  [16089] = 15934,
  [16090] = 15931,
  [16091] = 15936,
  [16092] = 15915,
  [16093] = 15933,
  [16094] = 15942,
  [16095] = 15934,
  [16096] = 15924,
  [16097] = 15929,
  [16098] = 15929,
  [16099] = 15926,
  [16100] = 10804,
  [16101] = 15910,
  [16102] = 15965,
  [16103] = 16086,
  [16104] = 15929,
  [16105] = 15971,
  [16106] = 15973,
  [16107] = 15932,
  [16108] = 15921,
  [16109] = 15995,
  [16110] = 15954,
  [16111] = 15945,
  [16112] = 15936,
  [16113] = 15931,
  [16114] = 16114,
  [16115] = 15933,
  [16116] = 15935,
  [16117] = 15934,
  [16118] = 15942,
  [16119] = 15916,
  [16120] = 15916,
  [16121] = 15954,
  [16122] = 15998,
  [16123] = 15932,
  [16124] = 15954,
  [16125] = 15921,
  [16126] = 15932,
  [16127] = 15910,
  [16128] = 15965,
  [16129] = 15922,
  [16130] = 16006,
  [16131] = 15971,
  [16132] = 15973,
  [16133] = 15921,
  [16134] = 15935,
  [16135] = 15945,
  [16136] = 15911,
  [16137] = 15936,
  [16138] = 15935,
  [16139] = 15998,
  [16140] = 15912,
  [16141] = 15942,
  [16142] = 15921,
  [16143] = 15912,
  [16144] = 15916,
  [16145] = 15911,
  [16146] = 15926,
  [16147] = 15912,
  [16148] = 15916,
  [16149] = 15910,
  [16150] = 15965,
  [16151] = 15971,
  [16152] = 15973,
  [16153] = 15932,
  [16154] = 15926,
  [16155] = 15945,
  [16156] = 15926,
  [16157] = 16157,
  [16158] = 15913,
  [16159] = 15936,
  [16160] = 15914,
  [16161] = 15915,
  [16162] = 15916,
  [16163] = 16163,
  [16164] = 15922,
  [16165] = 15942,
  [16166] = 15924,
  [16167] = 15924,
  [16168] = 15921,
  [16169] = 15924,
  [16170] = 15926,
  [16171] = 15935,
  [16172] = 15929,
  [16173] = 15913,
  [16174] = 15929,
  [16175] = 15926,
  [16176] = 15910,
  [16177] = 15932,
  [16178] = 15965,
  [16179] = 15910,
  [16180] = 15914,
  [16181] = 15912,
  [16182] = 15916,
  [16183] = 15971,
  [16184] = 15973,
  [16185] = 15931,
  [16186] = 15933,
  [16187] = 15934,
  [16188] = 15913,
  [16189] = 12904,
  [16190] = 15945,
  [16191] = 15936,
  [16192] = 15932,
  [16193] = 15942,
  [16194] = 15915,
  [16195] = 15914,
  [16196] = 15965,
  [16197] = 15915,
  [16198] = 15945,
  [16199] = 16086,
  [16200] = 15924,
  [16201] = 15922,
  [16202] = 15926,
  [16203] = 16056,
  [16204] = 15922,
  [16205] = 15910,
  [16206] = 15965,
  [16207] = 15935,
  [16208] = 15929,
  [16209] = 15971,
  [16210] = 15973,
  [16211] = 15936,
  [16212] = 15942,
  [16213] = 16086,
  [16214] = 15926,
  [16215] = 16163,
  [16216] = 15924,
  [16217] = 15954,
  [16218] = 16218,
  [16219] = 16219,
  [16220] = 15945,
  [16221] = 15924,
  [16222] = 15910,
  [16223] = 16223,
  [16224] = 15965,
  [16225] = 15954,
  [16226] = 15971,
  [16227] = 15973,
  [16228] = 15931,
  [16229] = 10463,
  [16230] = 15924,
  [16231] = 15921,
  [16232] = 15998,
  [16233] = 15935,
  [16234] = 15912,
  [16235] = 15936,
  [16236] = 16236,
  [16237] = 15921,
  [16238] = 15942,
  [16239] = 15961,
  [16240] = 15924,
  [16241] = 15916,
  [16242] = 15933,
  [16243] = 15935,
  [16244] = 15929,
  [16245] = 15910,
  [16246] = 15965,
  [16247] = 15911,
  [16248] = 15971,
  [16249] = 15973,
  [16250] = 15936,
  [16251] = 15998,
  [16252] = 15922,
  [16253] = 15942,
  [16254] = 15934,
  [16255] = 15911,
  [16256] = 15926,
  [16257] = 15912,
  [16258] = 15923,
  [16259] = 15924,
  [16260] = 15929,
  [16261] = 15912,
  [16262] = 15916,
  [16263] = 10381,
  [16264] = 16264,
  [16265] = 15910,
  [16266] = 15929,
  [16267] = 15965,
  [16268] = 15929,
  [16269] = 15971,
  [16270] = 15973,
  [16271] = 15936,
  [16272] = 15932,
  [16273] = 15926,
  [16274] = 15942,
  [16275] = 15926,
  [16276] = 15931,
  [16277] = 16277,
  [16278] = 15932,
  [16279] = 11426,
  [16280] = 15954,
  [16281] = 15933,
  [16282] = 15913,
  [16283] = 15910,
  [16284] = 15914,
  [16285] = 15965,
  [16286] = 15915,
  [16287] = 15934,
  [16288] = 15930,
  [16289] = 15911,
  [16290] = 15971,
  [16291] = 15973,
  [16292] = 15922,
  [16293] = 15936,
  [16294] = 15921,
  [16295] = 15942,
  [16296] = 15924,
  [16297] = 15932,
  [16298] = 15932,
  [16299] = 16299,
  [16300] = 16300,
  [16301] = 15910,
  [16302] = 15965,
  [16303] = 15932,
  [16304] = 15971,
  [16305] = 15973,
  [16306] = 15936,
  [16307] = 15929,
  [16308] = 15942,
  [16309] = 15995,
  [16310] = 15931,
  [16311] = 15933,
  [16312] = 15934,
  [16313] = 15916,
  [16314] = 16006,
  [16315] = 16315,
  [16316] = 15932,
  [16317] = 15931,
  [16318] = 15945,
  [16319] = 15924,
  [16320] = 15910,
  [16321] = 15965,
  [16322] = 15945,
  [16323] = 15971,
  [16324] = 15973,
  [16325] = 15936,
  [16326] = 16326,
  [16327] = 15935,
  [16328] = 16328,
  [16329] = 15942,
  [16330] = 15929,
  [16331] = 15998,
  [16332] = 15945,
  [16333] = 15911,
  [16334] = 15929,
  [16335] = 15912,
  [16336] = 16006,
  [16337] = 16277,
  [16338] = 15965,
  [16339] = 15916,
  [16340] = 15971,
  [16341] = 15973,
  [16342] = 15936,
  [16343] = 15942,
  [16344] = 15945,
  [16345] = 15926,
  [16346] = 15926,
  [16347] = 16086,
  [16348] = 12881,
  [16349] = 16061,
  [16350] = 16057,
  [16351] = 15913,
  [16352] = 15930,
  [16353] = 15910,
  [16354] = 15965,
  [16355] = 16061,
  [16356] = 15971,
  [16357] = 15973,
  [16358] = 16064,
  [16359] = 15936,
  [16360] = 16067,
  [16361] = 15942,
  [16362] = 16071,
  [16363] = 15935,
  [16364] = 16073,
  [16365] = 16056,
  [16366] = 16076,
  [16367] = 15914,
  [16368] = 15954,
  [16369] = 15910,
  [16370] = 15965,
  [16371] = 15913,
  [16372] = 15914,
  [16373] = 15915,
  [16374] = 15915,
  [16375] = 15971,
  [16376] = 15973,
  [16377] = 15932,
  [16378] = 15936,
  [16379] = 15922,
  [16380] = 16380,
  [16381] = 15942,
  [16382] = 15911,
  [16383] = 15933,
  [16384] = 15924,
  [16385] = 15921,
  [16386] = 16386,
  [16387] = 15935,
  [16388] = 15929,
  [16389] = 15910,
  [16390] = 15965,
  [16391] = 15971,
  [16392] = 15973,
  [16393] = 16057,
  [16394] = 15936,
  [16395] = 15942,
  [16396] = 16086,
  [16397] = 15935,
  [16398] = 15912,
  [16399] = 15934,
  [16400] = 15916,
  [16401] = 16236,
  [16402] = 15913,
  [16403] = 15965,
  [16404] = 15931,
  [16405] = 15933,
  [16406] = 15934,
  [16407] = 15971,
  [16408] = 15973,
  [16409] = 16057,
  [16410] = 15936,
  [16411] = 15930,
  [16412] = 16412,
  [16413] = 15942,
  [16414] = 15926,
  [16415] = 15954,
  [16416] = 15932,
  [16417] = 15930,
  [16418] = 15936,
  [16419] = 16061,
  [16420] = 15924,
  [16421] = 15942,
  [16422] = 16061,
  [16423] = 15945,
  [16424] = 16064,
  [16425] = 15954,
  [16426] = 16067,
  [16427] = 15936,
  [16428] = 15942,
  [16429] = 15929,
  [16430] = 15922,
  [16431] = 15932,
  [16432] = 15936,
  [16433] = 16071,
  [16434] = 15942,
  [16435] = 15912,
  [16436] = 15954,
  [16437] = 16073,
  [16438] = 16438,
  [16439] = 15936,
  [16440] = 15942,
  [16441] = 15921,
  [16442] = 16076,
  [16443] = 15954,
  [16444] = 15936,
  [16445] = 15954,
  [16446] = 16064,
  [16447] = 15942,
  [16448] = 15921,
  [16449] = 16449,
  [16450] = 15924,
  [16451] = 15962,
  [16452] = 15954,
  [16453] = 15954,
  [16454] = 16067,
  [16455] = 15936,
  [16456] = 16456,
  [16457] = 15948,
  [16458] = 15942,
  [16459] = 16459,
  [16460] = 15949,
  [16461] = 12251,
  [16462] = 15921,
  [16463] = 15936,
  [16464] = 15936,
  [16465] = 15942,
  [16466] = 15935,
  [16467] = 16467,
  [16468] = 15935,
  [16469] = 15935,
  [16470] = 15912,
  [16471] = 15913,
  [16472] = 15914,
  [16473] = 15938,
  [16474] = 15916,
  [16475] = 15936,
  [16476] = 15998,
  [16477] = 15915,
  [16478] = 15942,
  [16479] = 15938,
  [16480] = 15926,
  [16481] = 15921,
  [16482] = 15911,
  [16483] = 15912,
  [16484] = 15924,
  [16485] = 15916,
  [16486] = 15936,
  [16487] = 15912,
  [16488] = 15942,
  [16489] = 15916,
  [16490] = 15922,
  [16491] = 15929,
  [16492] = 15942,
  [16493] = 16493,
  [16494] = 15929,
  [16495] = 15936,
  [16496] = 15943,
  [16497] = 15932,
  [16498] = 15942,
  [16499] = 15916,
  [16500] = 16500,
  [16501] = 15924,
  [16502] = 16236,
  [16503] = 15936,
  [16504] = 15931,
  [16505] = 15942,
  [16506] = 16236,
  [16507] = 15935,
  [16508] = 15914,
  [16509] = 16064,
  [16510] = 15998,
  [16511] = 10820,
  [16512] = 15936,
  [16513] = 15926,
  [16514] = 15942,
  [16515] = 15926,
  [16516] = 10821,
  [16517] = 15924,
  [16518] = 15929,
  [16519] = 15923,
  [16520] = 15921,
  [16521] = 15936,
  [16522] = 15942,
  [16523] = 15935,
  [16524] = 15930,
  [16525] = 16525,
  [16526] = 16526,
  [16527] = 15936,
  [16528] = 15911,
  [16529] = 16056,
  [16530] = 15942,
  [16531] = 15929,
  [16532] = 15954,
  [16533] = 15912,
  [16534] = 16534,
  [16535] = 15954,
  [16536] = 15913,
  [16537] = 15914,
  [16538] = 15915,
  [16539] = 15936,
  [16540] = 16540,
  [16541] = 15942,
  [16542] = 15921,
  [16543] = 16456,
  [16544] = 15921,
  [16545] = 16545,
  [16546] = 15936,
  [16547] = 16071,
  [16548] = 16264,
  [16549] = 15942,
  [16550] = 15916,
  [16551] = 15922,
  [16552] = 15935,
  [16553] = 15998,
  [16554] = 16073,
  [16555] = 15932,
  [16556] = 15912,
  [16557] = 15936,
  [16558] = 15924,
  [16559] = 15995,
  [16560] = 15915,
  [16561] = 15942,
  [16562] = 15935,
  [16563] = 15916,
  [16564] = 16006,
  [16565] = 16277,
  [16566] = 15926,
  [16567] = 15995,
  [16568] = 15926,
  [16569] = 15936,
  [16570] = 15948,
  [16571] = 15942,
  [16572] = 11430,
  [16573] = 15924,
  [16574] = 15929,
  [16575] = 15935,
  [16576] = 15949,
  [16577] = 15998,
  [16578] = 15954,
  [16579] = 15936,
  [16580] = 15942,
  [16581] = 15911,
  [16582] = 16086,
  [16583] = 15929,
  [16584] = 15912,
  [16585] = 15916,
  [16586] = 15936,
  [16587] = 15932,
  [16588] = 15942,
  [16589] = 16086,
  [16590] = 15936,
  [16591] = 15942,
  [16592] = 15936,
  [16593] = 15931,
  [16594] = 15942,
  [16595] = 16076,
  [16596] = 15936,
  [16597] = 15926,
  [16598] = 15912,
  [16599] = 15942,
  [16600] = 15936,
  [16601] = 15933,
  [16602] = 15942,
  [16603] = 15936,
  [16604] = 15942,
  [16605] = 15936,
  [16606] = 15934,
  [16607] = 15942,
  [16608] = 15936,
  [16609] = 15942,
  [16610] = 15936,
  [16611] = 15942,
  [16612] = 15936,
  [16613] = 15998,
  [16614] = 15942,
  [16615] = 15936,
  [16616] = 15913,
  [16617] = 15942,
  [16618] = 15936,
  [16619] = 15954,
  [16620] = 15942,
  [16621] = 15936,
  [16622] = 15942,
  [16623] = 15936,
  [16624] = 15914,
  [16625] = 15942,
  [16626] = 15936,
  [16627] = 15942,
  [16628] = 15936,
  [16629] = 15942,
  [16630] = 15929,
  [16631] = 15942,
  [16632] = 15936,
  [16633] = 15942,
  [16634] = 15936,
  [16635] = 15942,
  [16636] = 15936,
  [16637] = 15942,
  [16638] = 15936,
  [16639] = 15942,
  [16640] = 15936,
  [16641] = 15942,
  [16642] = 15936,
  [16643] = 15942,
  [16644] = 15936,
  [16645] = 15942,
  [16646] = 15936,
  [16647] = 15942,
  [16648] = 15936,
  [16649] = 15942,
  [16650] = 15936,
  [16651] = 15942,
  [16652] = 15936,
  [16653] = 15942,
  [16654] = 15936,
  [16655] = 15942,
  [16656] = 15936,
  [16657] = 15942,
  [16658] = 15936,
  [16659] = 15942,
  [16660] = 15936,
  [16661] = 15942,
  [16662] = 15936,
  [16663] = 15942,
  [16664] = 15936,
  [16665] = 15942,
  [16666] = 15936,
  [16667] = 15942,
  [16668] = 15936,
  [16669] = 15942,
  [16670] = 15936,
  [16671] = 15942,
  [16672] = 15936,
  [16673] = 15942,
  [16674] = 12574,
  [16675] = 15971,
  [16676] = 15932,
  [16677] = 15995,
  [16678] = 15915,
  [16679] = 16679,
  [16680] = 15929,
  [16681] = 16236,
  [16682] = 15922,
  [16683] = 15931,
  [16684] = 16057,
  [16685] = 15924,
  [16686] = 15930,
  [16687] = 16061,
  [16688] = 16064,
  [16689] = 16459,
  [16690] = 16534,
  [16691] = 15933,
  [16692] = 15934,
  [16693] = 15961,
  [16694] = 16067,
  [16695] = 15954,
  [16696] = 16071,
  [16697] = 16697,
  [16698] = 16073,
  [16699] = 15921,
  [16700] = 16076,
  [16701] = 15954,
  [16702] = 15945,
  [16703] = 15921,
  [16704] = 15961,
  [16705] = 15935,
  [16706] = 15921,
  [16707] = 15913,
  [16708] = 15914,
  [16709] = 15915,
  [16710] = 16710,
  [16711] = 15962,
  [16712] = 15932,
  [16713] = 15926,
  [16714] = 15922,
  [16715] = 15924,
  [16716] = 15912,
  [16717] = 15929,
  [16718] = 15931,
  [16719] = 15935,
  [16720] = 15912,
  [16721] = 16157,
  [16722] = 15910,
  [16723] = 15916,
  [16724] = 15965,
  [16725] = 15933,
  [16726] = 15929,
  [16727] = 15934,
  [16728] = 15916,
  [16729] = 16067,
  [16730] = 16086,
  [16731] = 16086,
  [16732] = 15926,
  [16733] = 15936,
  [16734] = 15916,
  [16735] = 15931,
  [16736] = 15924,
  [16737] = 15933,
  [16738] = 15934,
  [16739] = 15968,
  [16740] = 15969,
  [16741] = 16456,
  [16742] = 16742,
  [16743] = 16743,
  [16744] = 16744,
  [16745] = 15971,
  [16746] = 15945,
  [16747] = 15929,
  [16748] = 15932,
  [16749] = 16679,
  [16750] = 15932,
  [16751] = 15926,
  [16752] = 15932,
  [16753] = 15932,
  [16754] = 16697,
  [16755] = 15916,
  [16756] = 16756,
  [16757] = 16710,
  [16758] = 15945,
  [16759] = 15973,
  [16760] = 15911,
  [16761] = 16459,
  [16762] = 15945,
  [16763] = 15935,
  [16764] = 15934,
  [16765] = 16710,
  [16766] = 15924,
  [16767] = 12876,
  [16768] = 16534,
  [16769] = 15998,
  [16770] = 15932,
  [16771] = 15942,
  [16772] = 15954,
  [16773] = 16679,
  [16774] = 15926,
  [16775] = 15929,
  [16776] = 15930,
  [16777] = 15932,
  [16778] = 15911,
  [16779] = 15931,
  [16780] = 16051,
  [16781] = 15935,
  [16782] = 16697,
  [16783] = 16380,
  [16784] = 16679,
  [16785] = 15921,
  [16786] = 15912,
  [16787] = 16710,
  [16788] = 16788,
  [16789] = 16789,
  [16790] = 15935,
  [16791] = 15913,
  [16792] = 15968,
  [16793] = 15912,
  [16794] = 16794,
  [16795] = 16449,
  [16796] = 15916,
  [16797] = 15910,
  [16798] = 16061,
  [16799] = 16006,
  [16800] = 15914,
  [16801] = 15926,
  [16802] = 15924,
  [16803] = 16679,
  [16804] = 15915,
  [16805] = 15933,
  [16806] = 16697,
  [16807] = 15933,
  [16808] = 15969,
  [16809] = 15921,
  [16810] = 16710,
  [16811] = 15929,
  [16812] = 16299,
  [16813] = 16679,
  [16814] = 15921,
  [16815] = 15932,
  [16816] = 16057,
  [16817] = 15954,
  [16818] = 15923,
  [16819] = 16697,
  [16820] = 16236,
  [16821] = 16710,
  [16822] = 16679,
  [16823] = 15916,
  [16824] = 15922,
  [16825] = 16825,
  [16826] = 16697,
  [16827] = 16086,
  [16828] = 16710,
  [16829] = 16679,
  [16830] = 15934,
  [16831] = 16697,
  [16832] = 16710,
  [16833] = 16679,
  [16834] = 15924,
  [16835] = 16835,
  [16836] = 15921,
  [16837] = 16697,
  [16838] = 16742,
  [16839] = 15934,
  [16840] = 16710,
  [16841] = 16679,
  [16842] = 16064,
  [16843] = 4860,
  [16844] = 15924,
  [16845] = 15929,
  [16846] = 16846,
  [16847] = 16697,
  [16848] = 16710,
  [16849] = 16679,
  [16850] = 15935,
  [16851] = 16851,
  [16852] = 15998,
  [16853] = 16697,
  [16854] = 16710,
  [16855] = 16679,
  [16856] = 15954,
  [16857] = 15954,
  [16858] = 15954,
  [16859] = 15998,
  [16860] = 16697,
  [16861] = 16710,
  [16862] = 16679,
  [16863] = 15921,
  [16864] = 15921,
  [16865] = 16697,
  [16866] = 16710,
  [16867] = 16679,
  [16868] = 15921,
  [16869] = 16697,
  [16870] = 16710,
  [16871] = 16679,
  [16872] = 16328,
  [16873] = 15929,
  [16874] = 15926,
  [16875] = 15911,
  [16876] = 16697,
  [16877] = 16710,
  [16878] = 16679,
  [16879] = 15912,
  [16880] = 15995,
  [16881] = 15912,
  [16882] = 16697,
  [16883] = 16710,
  [16884] = 16679,
  [16885] = 16006,
  [16886] = 15935,
  [16887] = 15932,
  [16888] = 15954,
  [16889] = 16697,
  [16890] = 15916,
  [16891] = 16710,
  [16892] = 16679,
  [16893] = 15954,
  [16894] = 16894,
  [16895] = 16697,
  [16896] = 16710,
  [16897] = 16679,
  [16898] = 15935,
  [16899] = 15912,
  [16900] = 15921,
  [16901] = 15998,
  [16902] = 16697,
  [16903] = 15926,
  [16904] = 16710,
  [16905] = 16679,
  [16906] = 15911,
  [16907] = 15913,
  [16908] = 16697,
  [16909] = 15912,
  [16910] = 16710,
  [16911] = 16679,
  [16912] = 15921,
  [16913] = 15914,
  [16914] = 15916,
  [16915] = 16697,
  [16916] = 16710,
  [16917] = 16679,
  [16918] = 15915,
  [16919] = 15916,
  [16920] = 16697,
  [16921] = 15926,
  [16922] = 16710,
  [16923] = 16679,
  [16924] = 16067,
  [16925] = 16925,
  [16926] = 15911,
  [16927] = 15922,
  [16928] = 16697,
  [16929] = 16710,
  [16930] = 16679,
  [16931] = 15930,
  [16932] = 15924,
  [16933] = 16061,
  [16934] = 16064,
  [16935] = 16697,
  [16936] = 16710,
  [16937] = 16679,
  [16938] = 16067,
  [16939] = 15935,
  [16940] = 16071,
  [16941] = 16697,
  [16942] = 16710,
  [16943] = 16679,
  [16944] = 16073,
  [16945] = 15935,
  [16946] = 16076,
  [16947] = 15926,
  [16948] = 15921,
  [16949] = 15912,
  [16950] = 16697,
  [16951] = 16710,
  [16952] = 16679,
  [16953] = 16071,
  [16954] = 15913,
  [16955] = 15914,
  [16956] = 15915,
  [16957] = 16697,
  [16958] = 16073,
  [16959] = 16710,
  [16960] = 16679,
  [16961] = 15929,
  [16962] = 15922,
  [16963] = 16963,
  [16964] = 15924,
  [16965] = 16697,
  [16966] = 15916,
  [16967] = 16710,
  [16968] = 16679,
  [16969] = 16969,
  [16970] = 16076,
  [16971] = 15931,
  [16972] = 16697,
  [16973] = 16710,
  [16974] = 16679,
  [16975] = 15929,
  [16976] = 15921,
  [16977] = 16697,
  [16978] = 16710,
  [16979] = 16679,
  [16980] = 16086,
  [16981] = 15933,
  [16982] = 16697,
  [16983] = 15934,
  [16984] = 16710,
  [16985] = 16679,
  [16986] = 15926,
  [16987] = 15913,
  [16988] = 16697,
  [16989] = 16710,
  [16990] = 16679,
  [16991] = 15931,
  [16992] = 15914,
  [16993] = 15933,
  [16994] = 15934,
  [16995] = 15932,
  [16996] = 16697,
  [16997] = 15945,
  [16998] = 16710,
  [16999] = 16679,
  [17000] = 15915,
  [17001] = 15932,
  [17002] = 16697,
  [17003] = 15916,
  [17004] = 16710,
  [17005] = 16679,
  [17006] = 15932,
  [17007] = 16697,
  [17008] = 16710,
  [17009] = 16679,
  [17010] = 15933,
  [17011] = 16697,
  [17012] = 15945,
  [17013] = 16710,
  [17014] = 16679,
  [17015] = 15924,
  [17016] = 15924,
  [17017] = 15954,
  [17018] = 15929,
  [17019] = 16697,
  [17020] = 16710,
  [17021] = 16679,
  [17022] = 15923,
  [17023] = 15922,
  [17024] = 17024,
  [17025] = 16697,
  [17026] = 16710,
  [17027] = 16679,
  [17028] = 15929,
  [17029] = 15924,
  [17030] = 16697,
  [17031] = 15929,
  [17032] = 16710,
  [17033] = 16679,
  [17034] = 15932,
  [17035] = 16743,
  [17036] = 16697,
  [17037] = 16710,
  [17038] = 16679,
  [17039] = 15932,
  [17040] = 15945,
  [17041] = 15911,
  [17042] = 16525,
  [17043] = 15935,
  [17044] = 16697,
  [17045] = 16710,
  [17046] = 16679,
  [17047] = 17047,
  [17048] = 15998,
  [17049] = 15936,
  [17050] = 16789,
  [17051] = 16697,
  [17052] = 17052,
  [17053] = 16710,
  [17054] = 16679,
  [17055] = 15968,
  [17056] = 16697,
  [17057] = 15938,
  [17058] = 16679,
  [17059] = 15954,
  [17060] = 16697,
  [17061] = 16679,
  [17062] = 16697,
  [17063] = 16679,
  [17064] = 16697,
  [17065] = 16679,
  [17066] = 16697,
  [17067] = 16679,
  [17068] = 16697,
  [17069] = 16679,
  [17070] = 16697,
  [17071] = 16679,
  [17072] = 16697,
  [17073] = 16679,
  [17074] = 16697,
  [17075] = 16679,
  [17076] = 16697,
  [17077] = 16679,
  [17078] = 16697,
  [17079] = 16679,
  [17080] = 16697,
  [17081] = 16679,
  [17082] = 16697,
  [17083] = 16679,
  [17084] = 16697,
  [17085] = 16679,
  [17086] = 16679,
  [17087] = 16679,
  [17088] = 16679,
  [17089] = 16679,
  [17090] = 16679,
  [17091] = 16679,
  [17092] = 16679,
  [17093] = 16679,
  [17094] = 16679,
  [17095] = 16679,
  [17096] = 16679,
  [17097] = 16679,
  [17098] = 16679,
  [17099] = 16679,
  [17100] = 16679,
  [17101] = 16679,
  [17102] = 16679,
  [17103] = 16679,
  [17104] = 16679,
  [17105] = 16679,
  [17106] = 16679,
  [17107] = 16679,
  [17108] = 16679,
  [17109] = 15998,
  [17110] = 16264,
  [17111] = 15912,
  [17112] = 16456,
  [17113] = 15942,
  [17114] = 15943,
  [17115] = 15929,
  [17116] = 15911,
  [17117] = 15912,
  [17118] = 15954,
  [17119] = 15943,
  [17120] = 15916,
  [17121] = 15931,
  [17122] = 15998,
  [17123] = 15954,
  [17124] = 15911,
  [17125] = 15932,
  [17126] = 15948,
  [17127] = 15926,
  [17128] = 10536,
  [17129] = 15973,
  [17130] = 15949,
  [17131] = 15923,
  [17132] = 15921,
  [17133] = 16277,
  [17134] = 16386,
  [17135] = 17024,
  [17136] = 16058,
  [17137] = 16794,
  [17138] = 15931,
  [17139] = 15954,
  [17140] = 15933,
  [17141] = 15921,
  [17142] = 15935,
  [17143] = 15930,
  [17144] = 16236,
  [17145] = 16526,
  [17146] = 15935,
  [17147] = 16459,
  [17148] = 15912,
  [17149] = 16534,
  [17150] = 15961,
  [17151] = 15962,
  [17152] = 16697,
  [17153] = 15916,
  [17154] = 15934,
  [17155] = 15910,
  [17156] = 15965,
  [17157] = 17157,
  [17158] = 15935,
  [17159] = 15954,
  [17160] = 15921,
  [17161] = 15968,
  [17162] = 15969,
  [17163] = 16459,
  [17164] = 15926,
  [17165] = 16534,
  [17166] = 15971,
  [17167] = 15913,
  [17168] = 15914,
  [17169] = 16264,
  [17170] = 15998,
  [17171] = 15912,
  [17172] = 16277,
  [17173] = 15924,
  [17174] = 15915,
  [17175] = 15973,
  [17176] = 15954,
  [17177] = 15911,
  [17178] = 15998,
  [17179] = 15912,
  [17180] = 15935,
  [17181] = 15916,
  [17182] = 16264,
  [17183] = 16086,
  [17184] = 15922,
  [17185] = 16846,
  [17186] = 15954,
  [17187] = 15926,
  [17188] = 16277,
  [17189] = 15936,
  [17190] = 17190,
  [17191] = 17191,
  [17192] = 17192,
  [17193] = 17193,
  [17194] = 17194,
  [17195] = 17195,
  [17196] = 17196,
  [17197] = 17197,
  [17198] = 17192,
  [17199] = 17199,
  [17200] = 17200,
  [17201] = 17201,
  [17202] = 17202,
  [17203] = 17203,
  [17204] = 17204,
  [17205] = 17200,
  [17206] = 17206,
  [17207] = 17199,
  [17208] = 17208,
  [17209] = 17201,
  [17210] = 17202,
  [17211] = 17211,
  [17212] = 17208,
  [17213] = 17195,
  [17214] = 17201,
  [17215] = 17190,
  [17216] = 17216,
  [17217] = 17217,
  [17218] = 17197,
  [17219] = 17194,
  [17220] = 17220,
  [17221] = 17216,
  [17222] = 17222,
  [17223] = 17206,
  [17224] = 17194,
  [17225] = 17199,
  [17226] = 17226,
  [17227] = 17206,
  [17228] = 17228,
  [17229] = 17229,
  [17230] = 17230,
  [17231] = 17216,
  [17232] = 17228,
  [17233] = 17230,
  [17234] = 17234,
  [17235] = 17235,
  [17236] = 17201,
  [17237] = 17197,
  [17238] = 17191,
  [17239] = 17200,
  [17240] = 17192,
  [17241] = 17200,
  [17242] = 17191,
  [17243] = 17202,
  [17244] = 17228,
  [17245] = 17192,
  [17246] = 17246,
  [17247] = 17200,
  [17248] = 17206,
  [17249] = 17200,
  [17250] = 17206,
  [17251] = 17206,
  [17252] = 17206,
  [17253] = 17200,
  [17254] = 17206,
  [17255] = 17195,
  [17256] = 17256,
  [17257] = 17197,
  [17258] = 17195,
  [17259] = 17259,
  [17260] = 17228,
  [17261] = 17235,
  [17262] = 17262,
  [17263] = 17202,
  [17264] = 17194,
  [17265] = 17206,
  [17266] = 17192,
  [17267] = 17256,
  [17268] = 17268,
  [17269] = 17208,
  [17270] = 17270,
  [17271] = 17206,
  [17272] = 17272,
  [17273] = 17206,
  [17274] = 17274,
  [17275] = 17275,
  [17276] = 17276,
  [17277] = 17277,
  [17278] = 17196,
  [17279] = 17279,
  [17280] = 17280,
  [17281] = 17281,
  [17282] = 17201,
  [17283] = 17283,
  [17284] = 17192,
  [17285] = 17275,
  [17286] = 17286,
  [17287] = 17193,
  [17288] = 17204,
  [17289] = 17194,
  [17290] = 17283,
  [17291] = 17291,
  [17292] = 17222,
  [17293] = 17246,
  [17294] = 17280,
  [17295] = 17295,
  [17296] = 17201,
  [17297] = 17190,
  [17298] = 17208,
  [17299] = 17299,
  [17300] = 17300,
  [17301] = 17201,
  [17302] = 17190,
  [17303] = 17303,
  [17304] = 17304,
  [17305] = 17305,
  [17306] = 17208,
  [17307] = 17195,
  [17308] = 17308,
  [17309] = 17309,
  [17310] = 17295,
  [17311] = 17311,
  [17312] = 17208,
  [17313] = 17216,
  [17314] = 17216,
  [17315] = 17235,
  [17316] = 17316,
  [17317] = 17216,
  [17318] = 17194,
  [17319] = 17197,
  [17320] = 17194,
  [17321] = 17190,
  [17322] = 17208,
  [17323] = 17199,
  [17324] = 17228,
  [17325] = 17230,
  [17326] = 17326,
  [17327] = 17228,
  [17328] = 17230,
  [17329] = 17228,
  [17330] = 17256,
  [17331] = 17230,
  [17332] = 17230,
  [17333] = 17262,
  [17334] = 17235,
  [17335] = 17195,
  [17336] = 17195,
  [17337] = 17206,
  [17338] = 17200,
  [17339] = 17268,
  [17340] = 17270,
  [17341] = 17191,
  [17342] = 17272,
  [17343] = 17191,
  [17344] = 17276,
  [17345] = 17277,
  [17346] = 17216,
  [17347] = 17196,
  [17348] = 17279,
  [17349] = 17200,
  [17350] = 17202,
  [17351] = 17281,
  [17352] = 17195,
  [17353] = 17190,
  [17354] = 17286,
  [17355] = 17193,
  [17356] = 17204,
  [17357] = 17195,
  [17358] = 17304,
  [17359] = 17291,
  [17360] = 17222,
  [17361] = 17246,
  [17362] = 17280,
  [17363] = 17206,
  [17364] = 17305,
  [17365] = 17365,
  [17366] = 17192,
  [17367] = 17299,
  [17368] = 17304,
  [17369] = 17305,
  [17370] = 17197,
  [17371] = 17308,
  [17372] = 17201,
  [17373] = 17195,
  [17374] = 17197,
  [17375] = 17230,
  [17376] = 17191,
  [17377] = 17197,
  [17378] = 17202,
  [17379] = 17216,
  [17380] = 17201,
  [17381] = 17194,
  [17382] = 17206,
  [17383] = 17201,
  [17384] = 17201,
  [17385] = 17208,
  [17386] = 17208,
  [17387] = 17256,
  [17388] = 17190,
  [17389] = 17235,
  [17390] = 17275,
  [17391] = 17208,
  [17392] = 17199,
  [17393] = 17202,
  [17394] = 17194,
  [17395] = 17206,
  [17396] = 17216,
  [17397] = 17194,
  [17398] = 17268,
  [17399] = 17270,
  [17400] = 17272,
  [17401] = 17216,
  [17402] = 17276,
  [17403] = 17277,
  [17404] = 17195,
  [17405] = 17281,
  [17406] = 10855,
  [17407] = 17194,
  [17408] = 17286,
  [17409] = 17193,
  [17410] = 17204,
  [17411] = 17208,
  [17412] = 17291,
  [17413] = 17222,
  [17414] = 17194,
  [17415] = 17190,
  [17416] = 17197,
  [17417] = 17299,
  [17418] = 10669,
  [17419] = 17199,
  [17420] = 17199,
  [17421] = 17228,
  [17422] = 17422,
  [17423] = 17230,
  [17424] = 10819,
  [17425] = 17200,
  [17426] = 17274,
  [17427] = 17228,
  [17428] = 17216,
  [17429] = 17230,
  [17430] = 17235,
  [17431] = 17422,
  [17432] = 17256,
  [17433] = 17191,
  [17434] = 17235,
  [17435] = 17208,
  [17436] = 17206,
  [17437] = 17268,
  [17438] = 17270,
  [17439] = 17272,
  [17440] = 17276,
  [17441] = 17228,
  [17442] = 17195,
  [17443] = 17281,
  [17444] = 17286,
  [17445] = 17193,
  [17446] = 17204,
  [17447] = 17291,
  [17448] = 17222,
  [17449] = 17228,
  [17450] = 17191,
  [17451] = 17299,
  [17452] = 17262,
  [17453] = 17230,
  [17454] = 17202,
  [17455] = 12300,
  [17456] = 17295,
  [17457] = 17190,
  [17458] = 17200,
  [17459] = 17194,
  [17460] = 17191,
  [17461] = 17199,
  [17462] = 17201,
  [17463] = 17230,
  [17464] = 17192,
  [17465] = 17256,
  [17466] = 17466,
  [17467] = 17467,
  [17468] = 17208,
  [17469] = 17195,
  [17470] = 17206,
  [17471] = 17268,
  [17472] = 17270,
  [17473] = 17272,
  [17474] = 17201,
  [17475] = 17228,
  [17476] = 17197,
  [17477] = 17281,
  [17478] = 17286,
  [17479] = 17193,
  [17480] = 17204,
  [17481] = 17291,
  [17482] = 17222,
  [17483] = 17235,
  [17484] = 17303,
  [17485] = 17485,
  [17486] = 17299,
  [17487] = 17487,
  [17488] = 17316,
  [17489] = 17216,
  [17490] = 17326,
  [17491] = 17308,
  [17492] = 17206,
  [17493] = 17202,
  [17494] = 17256,
  [17495] = 17208,
  [17496] = 17230,
  [17497] = 17230,
  [17498] = 17194,
  [17499] = 17206,
  [17500] = 17206,
  [17501] = 17235,
  [17502] = 17235,
  [17503] = 17268,
  [17504] = 17270,
  [17505] = 17272,
  [17506] = 17281,
  [17507] = 17201,
  [17508] = 17286,
  [17509] = 17193,
  [17510] = 17204,
  [17511] = 17291,
  [17512] = 17299,
  [17513] = 17228,
  [17514] = 17199,
  [17515] = 17208,
  [17516] = 17230,
  [17517] = 17467,
  [17518] = 17485,
  [17519] = 17194,
  [17520] = 17256,
  [17521] = 17190,
  [17522] = 17522,
  [17523] = 17191,
  [17524] = 17206,
  [17525] = 17270,
  [17526] = 17272,
  [17527] = 17281,
  [17528] = 17528,
  [17529] = 17522,
  [17530] = 17286,
  [17531] = 17193,
  [17532] = 17204,
  [17533] = 17291,
  [17534] = 17191,
  [17535] = 17191,
  [17536] = 17299,
  [17537] = 17216,
  [17538] = 17283,
  [17539] = 17191,
  [17540] = 17200,
  [17541] = 17194,
  [17542] = 17256,
  [17543] = 17195,
  [17544] = 17202,
  [17545] = 17199,
  [17546] = 17206,
  [17547] = 17211,
  [17548] = 17270,
  [17549] = 17272,
  [17550] = 17216,
  [17551] = 17281,
  [17552] = 17216,
  [17553] = 17286,
  [17554] = 17193,
  [17555] = 17204,
  [17556] = 17291,
  [17557] = 17228,
  [17558] = 17200,
  [17559] = 17291,
  [17560] = 17299,
  [17561] = 17230,
  [17562] = 17194,
  [17563] = 17191,
  [17564] = 17235,
  [17565] = 17256,
  [17566] = 17200,
  [17567] = 17208,
  [17568] = 17206,
  [17569] = 17199,
  [17570] = 17206,
  [17571] = 17201,
  [17572] = 17572,
  [17573] = 17272,
  [17574] = 17365,
  [17575] = 17199,
  [17576] = 17281,
  [17577] = 17192,
  [17578] = 17191,
  [17579] = 17286,
  [17580] = 17193,
  [17581] = 17204,
  [17582] = 17291,
  [17583] = 17200,
  [17584] = 17216,
  [17585] = 17200,
  [17586] = 17299,
  [17587] = 17528,
  [17588] = 17192,
  [17589] = 17589,
  [17590] = 17228,
  [17591] = 17256,
  [17592] = 17195,
  [17593] = 17197,
  [17594] = 17206,
  [17595] = 17200,
  [17596] = 17272,
  [17597] = 17194,
  [17598] = 17272,
  [17599] = 17281,
  [17600] = 17200,
  [17601] = 17601,
  [17602] = 17230,
  [17603] = 17286,
  [17604] = 17193,
  [17605] = 17204,
  [17606] = 17291,
  [17607] = 17202,
  [17608] = 17299,
  [17609] = 17228,
  [17610] = 17230,
  [17611] = 17206,
  [17612] = 17191,
  [17613] = 17228,
  [17614] = 17256,
  [17615] = 17216,
  [17616] = 17202,
  [17617] = 17192,
  [17618] = 17283,
  [17619] = 17201,
  [17620] = 17272,
  [17621] = 17195,
  [17622] = 17281,
  [17623] = 17274,
  [17624] = 17208,
  [17625] = 17200,
  [17626] = 17286,
  [17627] = 17193,
  [17628] = 17204,
  [17629] = 17291,
  [17630] = 17195,
  [17631] = 17191,
  [17632] = 17190,
  [17633] = 17299,
  [17634] = 17201,
  [17635] = 17230,
  [17636] = 17201,
  [17637] = 17197,
  [17638] = 17256,
  [17639] = 17197,
  [17640] = 17192,
  [17641] = 17195,
  [17642] = 17272,
  [17643] = 17281,
  [17644] = 17286,
  [17645] = 17193,
  [17646] = 17204,
  [17647] = 17262,
  [17648] = 17299,
  [17649] = 17216,
  [17650] = 17256,
  [17651] = 10906,
  [17652] = 17272,
  [17653] = 17281,
  [17654] = 17194,
  [17655] = 17202,
  [17656] = 17286,
  [17657] = 17193,
  [17658] = 17204,
  [17659] = 17216,
  [17660] = 17299,
  [17661] = 17206,
  [17662] = 17208,
  [17663] = 17256,
  [17664] = 17202,
  [17665] = 17199,
  [17666] = 17208,
  [17667] = 17201,
  [17668] = 17235,
  [17669] = 17272,
  [17670] = 17467,
  [17671] = 17281,
  [17672] = 17672,
  [17673] = 17673,
  [17674] = 17286,
  [17675] = 17193,
  [17676] = 17204,
  [17677] = 17194,
  [17678] = 17216,
  [17679] = 17191,
  [17680] = 17299,
  [17681] = 17256,
  [17682] = 17228,
  [17683] = 17230,
  [17684] = 17194,
  [17685] = 17272,
  [17686] = 17190,
  [17687] = 17281,
  [17688] = 17235,
  [17689] = 17206,
  [17690] = 17690,
  [17691] = 17286,
  [17692] = 17193,
  [17693] = 17204,
  [17694] = 17200,
  [17695] = 17299,
  [17696] = 17192,
  [17697] = 17208,
  [17698] = 17256,
  [17699] = 17228,
  [17700] = 17230,
  [17701] = 17206,
  [17702] = 17206,
  [17703] = 17272,
  [17704] = 17192,
  [17705] = 17191,
  [17706] = 17281,
  [17707] = 17707,
  [17708] = 17200,
  [17709] = 17286,
  [17710] = 17193,
  [17711] = 17204,
  [17712] = 17283,
  [17713] = 17299,
  [17714] = 17192,
  [17715] = 17200,
  [17716] = 17211,
  [17717] = 17256,
  [17718] = 17191,
  [17719] = 17195,
  [17720] = 17216,
  [17721] = 17201,
  [17722] = 17722,
  [17723] = 17272,
  [17724] = 17206,
  [17725] = 17281,
  [17726] = 17195,
  [17727] = 17286,
  [17728] = 17193,
  [17729] = 17204,
  [17730] = 17730,
  [17731] = 17195,
  [17732] = 17197,
  [17733] = 17299,
  [17734] = 17734,
  [17735] = 17256,
  [17736] = 17197,
  [17737] = 17208,
  [17738] = 17272,
  [17739] = 17228,
  [17740] = 17281,
  [17741] = 17195,
  [17742] = 17286,
  [17743] = 17193,
  [17744] = 17204,
  [17745] = 17745,
  [17746] = 17194,
  [17747] = 17190,
  [17748] = 17299,
  [17749] = 17197,
  [17750] = 17256,
  [17751] = 17206,
  [17752] = 17199,
  [17753] = 17272,
  [17754] = 17208,
  [17755] = 17281,
  [17756] = 17201,
  [17757] = 17286,
  [17758] = 17193,
  [17759] = 17204,
  [17760] = 17228,
  [17761] = 17299,
  [17762] = 17199,
  [17763] = 17256,
  [17764] = 17303,
  [17765] = 17208,
  [17766] = 17211,
  [17767] = 17316,
  [17768] = 17272,
  [17769] = 17216,
  [17770] = 17467,
  [17771] = 17281,
  [17772] = 17326,
  [17773] = 17286,
  [17774] = 17193,
  [17775] = 17204,
  [17776] = 17230,
  [17777] = 17299,
  [17778] = 17194,
  [17779] = 17256,
  [17780] = 17216,
  [17781] = 17216,
  [17782] = 17235,
  [17783] = 17272,
  [17784] = 17281,
  [17785] = 17191,
  [17786] = 17194,
  [17787] = 17286,
  [17788] = 17193,
  [17789] = 17204,
  [17790] = 17199,
  [17791] = 17299,
  [17792] = 17256,
  [17793] = 17228,
  [17794] = 17272,
  [17795] = 17191,
  [17796] = 17467,
  [17797] = 17485,
  [17798] = 17286,
  [17799] = 17193,
  [17800] = 17204,
  [17801] = 17202,
  [17802] = 17299,
  [17803] = 17230,
  [17804] = 17256,
  [17805] = 17191,
  [17806] = 17272,
  [17807] = 17228,
  [17808] = 17230,
  [17809] = 17286,
  [17810] = 17193,
  [17811] = 17204,
  [17812] = 17299,
  [17813] = 17256,
  [17814] = 17200,
  [17815] = 17272,
  [17816] = 17206,
  [17817] = 17191,
  [17818] = 17286,
  [17819] = 17193,
  [17820] = 17204,
  [17821] = 17200,
  [17822] = 17299,
  [17823] = 17200,
  [17824] = 17194,
  [17825] = 17191,
  [17826] = 17256,
  [17827] = 17827,
  [17828] = 17192,
  [17829] = 17211,
  [17830] = 17272,
  [17831] = 17201,
  [17832] = 17281,
  [17833] = 17286,
  [17834] = 17193,
  [17835] = 17204,
  [17836] = 17195,
  [17837] = 17299,
  [17838] = 17201,
  [17839] = 17256,
  [17840] = 17216,
  [17841] = 17228,
  [17842] = 17197,
  [17843] = 17843,
  [17844] = 17272,
  [17845] = 17195,
  [17846] = 17286,
  [17847] = 17193,
  [17848] = 17204,
  [17849] = 17299,
  [17850] = 17256,
  [17851] = 17206,
  [17852] = 17208,
  [17853] = 17208,
  [17854] = 17272,
  [17855] = 17230,
  [17856] = 17199,
  [17857] = 17286,
  [17858] = 17193,
  [17859] = 17204,
  [17860] = 17201,
  [17861] = 17299,
  [17862] = 17256,
  [17863] = 17197,
  [17864] = 17864,
  [17865] = 17208,
  [17866] = 17206,
  [17867] = 17867,
  [17868] = 17272,
  [17869] = 17208,
  [17870] = 17365,
  [17871] = 17190,
  [17872] = 17872,
  [17873] = 17286,
  [17874] = 17193,
  [17875] = 17204,
  [17876] = 17299,
  [17877] = 17190,
  [17878] = 17256,
  [17879] = 17216,
  [17880] = 17299,
  [17881] = 17272,
  [17882] = 17882,
  [17883] = 17208,
  [17884] = 17286,
  [17885] = 17193,
  [17886] = 17204,
  [17887] = 17299,
  [17888] = 17194,
  [17889] = 17194,
  [17890] = 17208,
  [17891] = 17216,
  [17892] = 17191,
  [17893] = 17200,
  [17894] = 17228,
  [17895] = 17272,
  [17896] = 17286,
  [17897] = 17193,
  [17898] = 17204,
  [17899] = 17216,
  [17900] = 17228,
  [17901] = 17299,
  [17902] = 17230,
  [17903] = 17256,
  [17904] = 17276,
  [17905] = 17422,
  [17906] = 17262,
  [17907] = 17272,
  [17908] = 17286,
  [17909] = 17193,
  [17910] = 17204,
  [17911] = 17228,
  [17912] = 17200,
  [17913] = 17299,
  [17914] = 17194,
  [17915] = 17192,
  [17916] = 17283,
  [17917] = 17917,
  [17918] = 17191,
  [17919] = 17272,
  [17920] = 17200,
  [17921] = 17228,
  [17922] = 17216,
  [17923] = 17195,
  [17924] = 17286,
  [17925] = 17193,
  [17926] = 17204,
  [17927] = 17194,
  [17928] = 17299,
  [17929] = 17197,
  [17930] = 17272,
  [17931] = 17192,
  [17932] = 17300,
  [17933] = 17228,
  [17934] = 17230,
  [17935] = 17286,
  [17936] = 17193,
  [17937] = 17204,
  [17938] = 17938,
  [17939] = 17195,
  [17940] = 17299,
  [17941] = 17230,
  [17942] = 17942,
  [17943] = 17262,
  [17944] = 17944,
  [17945] = 17272,
  [17946] = 17197,
  [17947] = 17286,
  [17948] = 17193,
  [17949] = 17204,
  [17950] = 17299,
  [17951] = 17199,
  [17952] = 17200,
  [17953] = 17272,
  [17954] = 17191,
  [17955] = 17194,
  [17956] = 17202,
  [17957] = 17286,
  [17958] = 17193,
  [17959] = 17204,
  [17960] = 17235,
  [17961] = 17299,
  [17962] = 17206,
  [17963] = 17195,
  [17964] = 17206,
  [17965] = 17272,
  [17966] = 17201,
  [17967] = 17286,
  [17968] = 17193,
  [17969] = 17204,
  [17970] = 17299,
  [17971] = 17201,
  [17972] = 17228,
  [17973] = 17200,
  [17974] = 10773,
  [17975] = 17272,
  [17976] = 17208,
  [17977] = 17199,
  [17978] = 17201,
  [17979] = 17286,
  [17980] = 17193,
  [17981] = 17204,
  [17982] = 17274,
  [17983] = 17983,
  [17984] = 17272,
  [17985] = 17216,
  [17986] = 17270,
  [17987] = 17286,
  [17988] = 17193,
  [17989] = 17204,
  [17990] = 17277,
  [17991] = 17216,
  [17992] = 17230,
  [17993] = 17485,
  [17994] = 17216,
  [17995] = 17272,
  [17996] = 17194,
  [17997] = 17191,
  [17998] = 17208,
  [17999] = 17228,
  [18000] = 17286,
  [18001] = 17193,
  [18002] = 17204,
  [18003] = 17200,
  [18004] = 17190,
  [18005] = 17228,
  [18006] = 17191,
  [18007] = 17272,
  [18008] = 17200,
  [18009] = 17228,
  [18010] = 17286,
  [18011] = 17193,
  [18012] = 17204,
  [18013] = 17230,
  [18014] = 17195,
  [18015] = 17200,
  [18016] = 17272,
  [18017] = 17286,
  [18018] = 17193,
  [18019] = 17204,
  [18020] = 17272,
  [18021] = 17286,
  [18022] = 17193,
  [18023] = 17204,
  [18024] = 17230,
  [18025] = 17216,
  [18026] = 17272,
  [18027] = 17286,
  [18028] = 17193,
  [18029] = 17204,
  [18030] = 17191,
  [18031] = 17272,
  [18032] = 17286,
  [18033] = 17193,
  [18034] = 17204,
  [18035] = 17272,
  [18036] = 17286,
  [18037] = 17193,
  [18038] = 17204,
  [18039] = 17191,
  [18040] = 17202,
  [18041] = 17272,
  [18042] = 17286,
  [18043] = 17193,
  [18044] = 17204,
  [18045] = 17272,
  [18046] = 17286,
  [18047] = 17193,
  [18048] = 17204,
  [18049] = 17216,
  [18050] = 17272,
  [18051] = 17286,
  [18052] = 17193,
  [18053] = 17204,
  [18054] = 17200,
  [18055] = 17208,
  [18056] = 17272,
  [18057] = 17286,
  [18058] = 17193,
  [18059] = 17204,
  [18060] = 17272,
  [18061] = 17286,
  [18062] = 17193,
  [18063] = 17204,
  [18064] = 17228,
  [18065] = 17316,
  [18066] = 17200,
  [18067] = 17272,
  [18068] = 17286,
  [18069] = 17193,
  [18070] = 17204,
  [18071] = 17200,
  [18072] = 17272,
  [18073] = 17286,
  [18074] = 17193,
  [18075] = 17204,
  [18076] = 17195,
  [18077] = 17272,
  [18078] = 17286,
  [18079] = 17193,
  [18080] = 17204,
  [18081] = 17191,
  [18082] = 17201,
  [18083] = 17272,
  [18084] = 17286,
  [18085] = 17193,
  [18086] = 17204,
  [18087] = 17191,
  [18088] = 17195,
  [18089] = 17272,
  [18090] = 17272,
  [18091] = 17272,
  [18092] = 17272,
  [18093] = 17272,
  [18094] = 17228,
  [18095] = 17272,
  [18096] = 17191,
  [18097] = 17272,
  [18098] = 17272,
  [18099] = 17195,
  [18100] = 17272,
  [18101] = 17272,
  [18102] = 17272,
  [18103] = 17272,
  [18104] = 17272,
  [18105] = 17228,
  [18106] = 17272,
  [18107] = 17191,
  [18108] = 17272,
  [18109] = 17195,
  [18110] = 17272,
  [18111] = 17272,
  [18112] = 17272,
  [18113] = 17272,
  [18114] = 17272,
  [18115] = 17228,
  [18116] = 17272,
  [18117] = 17191,
  [18118] = 17272,
  [18119] = 17192,
  [18120] = 17272,
  [18121] = 17195,
  [18122] = 17272,
  [18123] = 17235,
  [18124] = 17216,
  [18125] = 17300,
  [18126] = 17195,
  [18127] = 17228,
  [18128] = 17295,
  [18129] = 17191,
  [18130] = 17197,
  [18131] = 17195,
  [18132] = 18132,
  [18133] = 17228,
  [18134] = 17191,
  [18135] = 17195,
  [18136] = 17206,
  [18137] = 17235,
  [18138] = 17194,
  [18139] = 17228,
  [18140] = 17201,
  [18141] = 17191,
  [18142] = 17199,
  [18143] = 17191,
  [18144] = 17195,
  [18145] = 17208,
  [18146] = 17275,
  [18147] = 17827,
  [18148] = 17228,
  [18149] = 17228,
  [18150] = 17259,
  [18151] = 18151,
  [18152] = 17843,
  [18153] = 17191,
  [18154] = 17303,
  [18155] = 17216,
  [18156] = 17316,
  [18157] = 17195,
  [18158] = 17326,
  [18159] = 17200,
  [18160] = 17283,
  [18161] = 17194,
  [18162] = 17295,
  [18163] = 17230,
  [18164] = 17300,
  [18165] = 17228,
  [18166] = 17191,
  [18167] = 18167,
  [18168] = 17522,
  [18169] = 17195,
  [18170] = 17228,
  [18171] = 17230,
  [18172] = 17300,
  [18173] = 18173,
  [18174] = 18174,
  [18175] = 17235,
  [18176] = 18132,
  [18177] = 17467,
  [18178] = 17485,
  [18179] = 17228,
  [18180] = 17191,
  [18181] = 18174,
  [18182] = 17191,
  [18183] = 17200,
  [18184] = 17195,
  [18185] = 17191,
  [18186] = 17827,
  [18187] = 17195,
  [18188] = 17195,
  [18189] = 17200,
  [18190] = 17843,
  [18191] = 17195,
  [18192] = 17195,
  [18193] = 17197,
  [18194] = 17308,
  [18195] = 17300,
  [18196] = 17422,
  [18197] = 17197,
  [18198] = 17228,
  [18199] = 17300,
  [18200] = 17191,
  [18201] = 17195,
  [18202] = 17192,
  [18203] = 17206,
  [18204] = 17228,
  [18205] = 17201,
  [18206] = 17228,
  [18207] = 17191,
  [18208] = 17208,
  [18209] = 17192,
  [18210] = 17195,
  [18211] = 17259,
  [18212] = 17827,
  [18213] = 18151,
  [18214] = 5494,
  [18215] = 17190,
  [18216] = 17843,
  [18217] = 17216,
  [18218] = 10758,
  [18219] = 17195,
  [18220] = 17300,
  [18221] = 17194,
  [18222] = 17228,
  [18223] = 17300,
  [18224] = 17197,
  [18225] = 8181,
  [18226] = 17191,
  [18227] = 17195,
  [18228] = 17197,
  [18229] = 18132,
  [18230] = 17228,
  [18231] = 17300,
  [18232] = 17300,
  [18233] = 17230,
  [18234] = 17229,
  [18235] = 17195,
  [18236] = 17303,
  [18237] = 17192,
  [18238] = 17283,
  [18239] = 17300,
  [18240] = 17300,
  [18241] = 17230,
  [18242] = 17195,
  [18243] = 17197,
  [18244] = 17191,
  [18245] = 17196,
  [18246] = 17200,
  [18247] = 17528,
  [18248] = 17262,
  [18249] = 18249,
  [18250] = 18250,
  [18251] = 17268,
  [18252] = 17202,
  [18253] = 17195,
  [18254] = 17206,
  [18255] = 17195,
  [18256] = 17201,
  [18257] = 17197,
  [18258] = 18258,
  [18259] = 17202,
  [18260] = 17206,
  [18261] = 17208,
  [18262] = 17197,
  [18263] = 17190,
  [18264] = 17316,
  [18265] = 10685,
  [18266] = 17206,
  [18267] = 17202,
  [18268] = 17197,
  [18269] = 17256,
  [18270] = 17300,
  [18271] = 18271,
  [18272] = 17202,
  [18273] = 17200,
  [18274] = 17201,
  [18275] = 17216,
  [18276] = 17206,
  [18277] = 17194,
  [18278] = 18173,
  [18279] = 17672,
  [18280] = 17216,
  [18281] = 17211,
  [18282] = 17235,
  [18283] = 17220,
  [18284] = 17262,
  [18285] = 17208,
  [18286] = 17201,
  [18287] = 17192,
  [18288] = 17195,
  [18289] = 17230,
  [18290] = 17983,
  [18291] = 17199,
  [18292] = 17194,
  [18293] = 17208,
  [18294] = 17673,
  [18295] = 17262,
  [18296] = 17208,
  [18297] = 17201,
  [18298] = 17199,
  [18299] = 17190,
  [18300] = 17201,
  [18301] = 18301,
  [18302] = 17228,
  [18303] = 17206,
  [18304] = 17316,
  [18305] = 17216,
  [18306] = 17279,
  [18307] = 18307,
  [18308] = 17326,
  [18309] = 17268,
  [18310] = 17208,
  [18311] = 17230,
  [18312] = 17228,
  [18313] = 17197,
  [18314] = 17270,
  [18315] = 13969,
  [18316] = 17190,
  [18317] = 17235,
  [18318] = 17194,
  [18319] = 17467,
  [18320] = 17485,
  [18321] = 17272,
  [18322] = 17216,
  [18323] = 17216,
  [18324] = 17191,
  [18325] = 17303,
  [18326] = 17276,
  [18327] = 17938,
  [18328] = 17277,
  [18329] = 17200,
  [18330] = 17194,
  [18331] = 17201,
  [18332] = 17196,
  [18333] = 17228,
  [18334] = 17316,
  [18335] = 17230,
  [18336] = 17279,
  [18337] = 17326,
  [18338] = 17195,
  [18339] = 17208,
  [18340] = 17194,
  [18341] = 17326,
  [18342] = 17246,
  [18343] = 18343,
  [18344] = 17191,
  [18345] = 17281,
  [18346] = 17206,
  [18347] = 18347,
  [18348] = 17722,
  [18349] = 17230,
  [18350] = 17304,
  [18351] = 17190,
  [18352] = 17305,
  [18353] = 17286,
  [18354] = 17193,
  [18355] = 17204,
  [18356] = 17199,
  [18357] = 17228,
  [18358] = 17280,
  [18359] = 17230,
  [18360] = 17235,
  [18361] = 17365,
  [18362] = 17291,
  [18363] = 17222,
  [18364] = 17246,
  [18365] = 17280,
  [18366] = 17309,
  [18367] = 17228,
  [18368] = 17230,
  [18369] = 17197,
  [18370] = 17200,
  [18371] = 17191,
  [18372] = 17299,
  [18373] = 17734,
  [18374] = 17200,
  [18375] = 17194,
  [18376] = 17234,
  [18377] = 17191,
  [18378] = 17938,
  [18379] = 17230,
  [18380] = 17195,
  [18381] = 17197,
  [18382] = 17295,
  [18383] = 18132,
  [18384] = 17467,
  [18385] = 17192,
  [18386] = 17283,
  [18387] = 17216,
  [18388] = 17485,
  [18389] = 17228,
  [18390] = 17206,
  [18391] = 17230,
  [18392] = 17304,
  [18393] = 17208,
  [18394] = 17305,
  [18395] = 17195,
  [18396] = 17235,
  [18397] = 17197,
  [18398] = 17201,
  [18399] = 17208,
  [18400] = 17201,
  [18401] = 17190,
  [18402] = 17308,
  [18403] = 17522,
  [18404] = 17191,
  [18405] = 17194,
  [18406] = 17195,
  [18407] = 17882,
  [18408] = 17216,
  [18409] = 17202,
  [18410] = 17200,
  [18411] = 18411,
  [18412] = 17259,
  [18413] = 17194,
  [18414] = 18414,
  [18415] = 17734,
  [18416] = 17191,
  [18417] = 17528,
  [18418] = 17200,
  [18419] = 17734,
  [18420] = 17259,
  [18421] = 17259,
  [18422] = 17286,
  [18423] = 17256,
  [18424] = 18424,
  [18425] = 18425,
  [18426] = 18426,
  [18427] = 18427,
  [18428] = 18428,
  [18429] = 18429,
  [18430] = 18430,
  [18431] = 18431,
  [18432] = 18432,
  [18433] = 18433,
  [18434] = 18434,
  [18435] = 18435,
  [18436] = 18436,
  [18437] = 18437,
  [18438] = 18438,
  [18439] = 18439,
  [18440] = 18440,
  [18441] = 18441,
  [18442] = 18440,
  [18443] = 18443,
  [18444] = 18444,
  [18445] = 18445,
  [18446] = 18446,
  [18447] = 18447,
  [18448] = 18448,
  [18449] = 18449,
  [18450] = 18448,
  [18451] = 18445,
  [18452] = 18426,
  [18453] = 18453,
  [18454] = 18454,
  [18455] = 18432,
  [18456] = 18456,
  [18457] = 18426,
  [18458] = 18449,
  [18459] = 18459,
  [18460] = 18460,
  [18461] = 18461,
  [18462] = 18462,
  [18463] = 18441,
  [18464] = 18456,
  [18465] = 18465,
  [18466] = 18449,
  [18467] = 18453,
  [18468] = 18468,
  [18469] = 18449,
  [18470] = 18470,
  [18471] = 18471,
  [18472] = 18472,
  [18473] = 18425,
  [18474] = 18445,
  [18475] = 18475,
  [18476] = 18476,
  [18477] = 18432,
  [18478] = 18478,
  [18479] = 18479,
  [18480] = 18476,
  [18481] = 18481,
  [18482] = 18426,
  [18483] = 18483,
  [18484] = 18484,
  [18485] = 18485,
  [18486] = 18486,
  [18487] = 18441,
  [18488] = 18441,
  [18489] = 18489,
  [18490] = 18490,
  [18491] = 18449,
  [18492] = 18470,
  [18493] = 18493,
  [18494] = 18459,
  [18495] = 18440,
  [18496] = 18478,
  [18497] = 18449,
  [18498] = 18431,
  [18499] = 18454,
  [18500] = 18500,
  [18501] = 18501,
  [18502] = 18489,
  [18503] = 18503,
  [18504] = 18431,
  [18505] = 18470,
  [18506] = 18506,
  [18507] = 18471,
  [18508] = 18427,
  [18509] = 18509,
  [18510] = 18472,
  [18511] = 18439,
  [18512] = 18512,
  [18513] = 18443,
  [18514] = 18446,
  [18515] = 18447,
  [18516] = 18489,
  [18517] = 18437,
  [18518] = 18503,
  [18519] = 18519,
  [18520] = 18434,
  [18521] = 18521,
  [18522] = 18522,
  [18523] = 18448,
  [18524] = 18506,
  [18525] = 18453,
  [18526] = 18509,
  [18527] = 18459,
  [18528] = 18461,
  [18529] = 18512,
  [18530] = 18434,
  [18531] = 18427,
  [18532] = 18465,
  [18533] = 18503,
  [18534] = 18506,
  [18535] = 18535,
  [18536] = 18536,
  [18537] = 18509,
  [18538] = 18429,
  [18539] = 18438,
  [18540] = 18427,
  [18541] = 18430,
  [18542] = 18429,
  [18543] = 18476,
  [18544] = 18440,
  [18545] = 18489,
  [18546] = 18430,
  [18547] = 18501,
  [18548] = 18439,
  [18549] = 18489,
  [18550] = 18483,
  [18551] = 18484,
  [18552] = 18485,
  [18553] = 18486,
  [18554] = 18554,
  [18555] = 18456,
  [18556] = 18556,
  [18557] = 18443,
  [18558] = 18435,
  [18559] = 18521,
  [18560] = 18454,
  [18561] = 18561,
  [18562] = 18431,
  [18563] = 18435,
  [18564] = 18521,
  [18565] = 18437,
  [18566] = 18438,
  [18567] = 18512,
  [18568] = 18439,
  [18569] = 18427,
  [18570] = 18443,
  [18571] = 18446,
  [18572] = 18447,
  [18573] = 18429,
  [18574] = 18446,
  [18575] = 18575,
  [18576] = 18478,
  [18577] = 18430,
  [18578] = 18435,
  [18579] = 18579,
  [18580] = 18447,
  [18581] = 18437,
  [18582] = 18493,
  [18583] = 18459,
  [18584] = 18461,
  [18585] = 18462,
  [18586] = 18468,
  [18587] = 18587,
  [18588] = 18465,
  [18589] = 18456,
  [18590] = 18512,
  [18591] = 18561,
  [18592] = 18592,
  [18593] = 18438,
  [18594] = 18440,
  [18595] = 18433,
  [18596] = 18596,
  [18597] = 18456,
  [18598] = 18476,
  [18599] = 18440,
  [18600] = 18503,
  [18601] = 18587,
  [18602] = 18437,
  [18603] = 18438,
  [18604] = 18454,
  [18605] = 18483,
  [18606] = 18484,
  [18607] = 18485,
  [18608] = 18486,
  [18609] = 18561,
  [18610] = 18440,
  [18611] = 18561,
  [18612] = 18448,
  [18613] = 18453,
  [18614] = 18479,
  [18615] = 18615,
  [18616] = 18460,
  [18617] = 18431,
  [18618] = 18479,
  [18619] = 18587,
  [18620] = 18554,
  [18621] = 18454,
  [18622] = 18454,
  [18623] = 18439,
  [18624] = 18521,
  [18625] = 18443,
  [18626] = 18446,
  [18627] = 18447,
  [18628] = 18425,
  [18629] = 18506,
  [18630] = 18433,
  [18631] = 18512,
  [18632] = 18432,
  [18633] = 18633,
  [18634] = 18500,
  [18635] = 18503,
  [18636] = 18636,
  [18637] = 18506,
  [18638] = 18459,
  [18639] = 18461,
  [18640] = 18493,
  [18641] = 18503,
  [18642] = 18479,
  [18643] = 18465,
  [18644] = 18478,
  [18645] = 18645,
  [18646] = 18432,
  [18647] = 18470,
  [18648] = 18471,
  [18649] = 18472,
  [18650] = 18426,
  [18651] = 18521,
  [18652] = 18501,
  [18653] = 18476,
  [18654] = 18448,
  [18655] = 18655,
  [18656] = 18501,
  [18657] = 18453,
  [18658] = 18506,
  [18659] = 18435,
  [18660] = 18483,
  [18661] = 18484,
  [18662] = 18485,
  [18663] = 18486,
  [18664] = 18509,
  [18665] = 18489,
  [18666] = 18470,
  [18667] = 18509,
  [18668] = 18500,
  [18669] = 18429,
  [18670] = 18470,
  [18671] = 18509,
  [18672] = 18431,
  [18673] = 18471,
  [18674] = 18479,
  [18675] = 18471,
  [18676] = 18472,
  [18677] = 18633,
  [18678] = 18439,
  [18679] = 5533,
  [18680] = 18443,
  [18681] = 18446,
  [18682] = 18447,
  [18683] = 18521,
  [18684] = 18472,
  [18685] = 18685,
  [18686] = 18456,
  [18687] = 18478,
  [18688] = 18579,
  [18689] = 18689,
  [18690] = 18437,
  [18691] = 18512,
  [18692] = 18519,
  [18693] = 18459,
  [18694] = 18461,
  [18695] = 18489,
  [18696] = 18519,
  [18697] = 18445,
  [18698] = 18465,
  [18699] = 18459,
  [18700] = 18479,
  [18701] = 18461,
  [18702] = 18689,
  [18703] = 18427,
  [18704] = 18704,
  [18705] = 18704,
  [18706] = 18503,
  [18707] = 18429,
  [18708] = 18476,
  [18709] = 18432,
  [18710] = 18465,
  [18711] = 18448,
  [18712] = 18453,
  [18713] = 18713,
  [18714] = 18426,
  [18715] = 18483,
  [18716] = 18484,
  [18717] = 18485,
  [18718] = 18486,
  [18719] = 18460,
  [18720] = 18426,
  [18721] = 18506,
  [18722] = 18501,
  [18723] = 18448,
  [18724] = 18441,
  [18725] = 18725,
  [18726] = 18509,
  [18727] = 18431,
  [18728] = 18425,
  [18729] = 18449,
  [18730] = 18433,
  [18731] = 18489,
  [18732] = 18445,
  [18733] = 18429,
  [18734] = 18443,
  [18735] = 18446,
  [18736] = 18447,
  [18737] = 18453,
  [18738] = 18430,
  [18739] = 18432,
  [18740] = 18489,
  [18741] = 18556,
  [18742] = 18493,
  [18743] = 18460,
  [18744] = 18460,
  [18745] = 18685,
  [18746] = 18427,
  [18747] = 18459,
  [18748] = 18461,
  [18749] = 18456,
  [18750] = 18460,
  [18751] = 18751,
  [18752] = 18465,
  [18753] = 18556,
  [18754] = 18493,
  [18755] = 18521,
  [18756] = 18454,
  [18757] = 18713,
  [18758] = 18456,
  [18759] = 18512,
  [18760] = 18445,
  [18761] = 18503,
  [18762] = 18476,
  [18763] = 18506,
  [18764] = 18764,
  [18765] = 18509,
  [18766] = 18489,
  [18767] = 18432,
  [18768] = 18426,
  [18769] = 18483,
  [18770] = 18484,
  [18771] = 18485,
  [18772] = 18486,
  [18773] = 18500,
  [18774] = 18429,
  [18775] = 18689,
  [18776] = 18441,
  [18777] = 18430,
  [18778] = 18449,
  [18779] = 18506,
  [18780] = 18556,
  [18781] = 18431,
  [18782] = 18476,
  [18783] = 18561,
  [18784] = 18435,
  [18785] = 18556,
  [18786] = 18460,
  [18787] = 18441,
  [18788] = 18443,
  [18789] = 18446,
  [18790] = 18447,
  [18791] = 18561,
  [18792] = 18501,
  [18793] = 18430,
  [18794] = 18512,
  [18795] = 18470,
  [18796] = 18425,
  [18797] = 18503,
  [18798] = 18500,
  [18799] = 18437,
  [18800] = 18501,
  [18801] = 18459,
  [18802] = 18461,
  [18803] = 18803,
  [18804] = 18506,
  [18805] = 18509,
  [18806] = 18465,
  [18807] = 18438,
  [18808] = 18440,
  [18809] = 18426,
  [18810] = 18503,
  [18811] = 18478,
  [18812] = 18489,
  [18813] = 18506,
  [18814] = 18500,
  [18815] = 18470,
  [18816] = 18476,
  [18817] = 18509,
  [18818] = 18818,
  [18819] = 18489,
  [18820] = 18483,
  [18821] = 18470,
  [18822] = 18470,
  [18823] = 18483,
  [18824] = 18484,
  [18825] = 18485,
  [18826] = 18486,
  [18827] = 18471,
  [18828] = 18484,
  [18829] = 18485,
  [18830] = 18486,
  [18831] = 18831,
  [18832] = 18587,
  [18833] = 18519,
  [18834] = 18592,
  [18835] = 18431,
  [18836] = 18472,
  [18837] = 18501,
  [18838] = 18471,
  [18839] = 18471,
  [18840] = 18689,
  [18841] = 18460,
  [18842] = 18443,
  [18843] = 18446,
  [18844] = 18447,
  [18845] = 18427,
  [18846] = 18435,
  [18847] = 18521,
  [18848] = 18725,
  [18849] = 18429,
  [18850] = 18592,
  [18851] = 18472,
  [18852] = 18449,
  [18853] = 18425,
  [18854] = 18427,
  [18855] = 18459,
  [18856] = 18461,
  [18857] = 18425,
  [18858] = 18448,
  [18859] = 18429,
  [18860] = 18465,
  [18861] = 18472,
  [18862] = 18633,
  [18863] = 18427,
  [18864] = 18429,
  [18865] = 18453,
  [18866] = 18430,
  [18867] = 18596,
  [18868] = 18427,
  [18869] = 18430,
  [18870] = 18476,
  [18871] = 18501,
  [18872] = 18435,
  [18873] = 18429,
  [18874] = 18435,
  [18875] = 18425,
  [18876] = 18430,
  [18877] = 18483,
  [18878] = 18484,
  [18879] = 18485,
  [18880] = 18486,
  [18881] = 18435,
  [18882] = 18882,
  [18883] = 18437,
  [18884] = 18437,
  [18885] = 18437,
  [18886] = 18438,
  [18887] = 18438,
  [18888] = 18440,
  [18889] = 18431,
  [18890] = 18440,
  [18891] = 18430,
  [18892] = 18438,
  [18893] = 18893,
  [18894] = 18435,
  [18895] = 18440,
  [18896] = 18443,
  [18897] = 18446,
  [18898] = 18447,
  [18899] = 18454,
  [18900] = 18454,
  [18901] = 18437,
  [18902] = 18448,
  [18903] = 18454,
  [18904] = 18430,
  [18905] = 18905,
  [18906] = 18471,
  [18907] = 18454,
  [18908] = 18427,
  [18909] = 18459,
  [18910] = 18461,
  [18911] = 18479,
  [18912] = 18556,
  [18913] = 18433,
  [18914] = 18465,
  [18915] = 18501,
  [18916] = 18433,
  [18917] = 18521,
  [18918] = 18479,
  [18919] = 18587,
  [18920] = 18479,
  [18921] = 18921,
  [18922] = 18472,
  [18923] = 18923,
  [18924] = 18476,
  [18925] = 18636,
  [18926] = 18579,
  [18927] = 18429,
  [18928] = 18430,
  [18929] = 18441,
  [18930] = 18500,
  [18931] = 18483,
  [18932] = 18484,
  [18933] = 18485,
  [18934] = 18486,
  [18935] = 18435,
  [18936] = 18470,
  [18937] = 18633,
  [18938] = 18471,
  [18939] = 18433,
  [18940] = 18472,
  [18941] = 18479,
  [18942] = 18561,
  [18943] = 18431,
  [18944] = 18521,
  [18945] = 18945,
  [18946] = 18448,
  [18947] = 18453,
  [18948] = 18500,
  [18949] = 18426,
  [18950] = 18443,
  [18951] = 18446,
  [18952] = 18447,
  [18953] = 18456,
  [18954] = 18435,
  [18955] = 18470,
  [18956] = 18500,
  [18957] = 18471,
  [18958] = 18472,
  [18959] = 18439,
  [18960] = 18493,
  [18961] = 18689,
  [18962] = 18462,
  [18963] = 18459,
  [18964] = 18461,
  [18965] = 18445,
  [18966] = 18432,
  [18967] = 18426,
  [18968] = 18465,
  [18969] = 18521,
  [18970] = 18704,
  [18971] = 18470,
  [18972] = 18437,
  [18973] = 18441,
  [18974] = 18500,
  [18975] = 18448,
  [18976] = 18438,
  [18977] = 18923,
  [18978] = 18476,
  [18979] = 18521,
  [18980] = 18453,
  [18981] = 18945,
  [18982] = 18468,
  [18983] = 18983,
  [18984] = 18440,
  [18985] = 18483,
  [18986] = 18484,
  [18987] = 18485,
  [18988] = 18486,
  [18989] = 18751,
  [18990] = 18478,
  [18991] = 18479,
  [18992] = 18470,
  [18993] = 18448,
  [18994] = 18713,
  [18995] = 18453,
  [18996] = 18437,
  [18997] = 18431,
  [18998] = 18453,
  [18999] = 18445,
  [19000] = 18444,
  [19001] = 18478,
  [19002] = 18471,
  [19003] = 18587,
  [19004] = 18443,
  [19005] = 18446,
  [19006] = 18447,
  [19007] = 18478,
  [19008] = 18472,
  [19009] = 18438,
  [19010] = 18500,
  [19011] = 18440,
  [19012] = 19012,
  [19013] = 18479,
  [19014] = 18470,
  [19015] = 18478,
  [19016] = 18454,
  [19017] = 18459,
  [19018] = 18461,
  [19019] = 18471,
  [19020] = 18445,
  [19021] = 18460,
  [19022] = 18465,
  [19023] = 18472,
  [19024] = 18432,
  [19025] = 18462,
  [19026] = 18471,
  [19027] = 18449,
  [19028] = 18521,
  [19029] = 18481,
  [19030] = 18425,
  [19031] = 18476,
  [19032] = 18587,
  [19033] = 18521,
  [19034] = 18454,
  [19035] = 18433,
  [19036] = 18432,
  [19037] = 18448,
  [19038] = 18483,
  [19039] = 18484,
  [19040] = 18485,
  [19041] = 18486,
  [19042] = 18479,
  [19043] = 18426,
  [19044] = 18453,
  [19045] = 19045,
  [19046] = 18587,
  [19047] = 18493,
  [19048] = 18437,
  [19049] = 18456,
  [19050] = 18431,
  [19051] = 18575,
  [19052] = 18448,
  [19053] = 18460,
  [19054] = 18443,
  [19055] = 18446,
  [19056] = 18447,
  [19057] = 18448,
  [19058] = 18453,
  [19059] = 18751,
  [19060] = 18448,
  [19061] = 18725,
  [19062] = 18425,
  [19063] = 18433,
  [19064] = 18459,
  [19065] = 18461,
  [19066] = 18432,
  [19067] = 18460,
  [19068] = 18453,
  [19069] = 18465,
  [19070] = 18426,
  [19071] = 18438,
  [19072] = 18689,
  [19073] = 18445,
  [19074] = 18476,
  [19075] = 18561,
  [19076] = 18438,
  [19077] = 18512,
  [19078] = 18503,
  [19079] = 18506,
  [19080] = 18483,
  [19081] = 18484,
  [19082] = 18485,
  [19083] = 18486,
  [19084] = 18509,
  [19085] = 18440,
  [19086] = 18432,
  [19087] = 18489,
  [19088] = 18831,
  [19089] = 18426,
  [19090] = 18587,
  [19091] = 18431,
  [19092] = 18441,
  [19093] = 18561,
  [19094] = 18522,
  [19095] = 18443,
  [19096] = 18446,
  [19097] = 18447,
  [19098] = 18519,
  [19099] = 18438,
  [19100] = 18633,
  [19101] = 18636,
  [19102] = 18456,
  [19103] = 18425,
  [19104] = 18459,
  [19105] = 18461,
  [19106] = 18431,
  [19107] = 19107,
  [19108] = 18433,
  [19109] = 18465,
  [19110] = 18478,
  [19111] = 18493,
  [19112] = 18434,
  [19113] = 18449,
  [19114] = 18476,
  [19115] = 18440,
  [19116] = 18535,
  [19117] = 18536,
  [19118] = 18556,
  [19119] = 18713,
  [19120] = 18483,
  [19121] = 18484,
  [19122] = 18485,
  [19123] = 18486,
  [19124] = 18500,
  [19125] = 18433,
  [19126] = 18460,
  [19127] = 18445,
  [19128] = 18432,
  [19129] = 18478,
  [19130] = 18426,
  [19131] = 18431,
  [19132] = 18472,
  [19133] = 18592,
  [19134] = 18921,
  [19135] = 18443,
  [19136] = 18446,
  [19137] = 18447,
  [19138] = 19138,
  [19139] = 18923,
  [19140] = 18441,
  [19141] = 19141,
  [19142] = 18427,
  [19143] = 18449,
  [19144] = 18459,
  [19145] = 18461,
  [19146] = 18503,
  [19147] = 18439,
  [19148] = 18501,
  [19149] = 18465,
  [19150] = 18454,
  [19151] = 18429,
  [19152] = 18427,
  [19153] = 19153,
  [19154] = 18476,
  [19155] = 18479,
  [19156] = 18443,
  [19157] = 18818,
  [19158] = 18506,
  [19159] = 18501,
  [19160] = 18483,
  [19161] = 18484,
  [19162] = 18485,
  [19163] = 18486,
  [19164] = 19138,
  [19165] = 18512,
  [19166] = 18509,
  [19167] = 18489,
  [19168] = 18512,
  [19169] = 18587,
  [19170] = 18503,
  [19171] = 18431,
  [19172] = 18425,
  [19173] = 18506,
  [19174] = 18509,
  [19175] = 18443,
  [19176] = 18446,
  [19177] = 18447,
  [19178] = 18489,
  [19179] = 18446,
  [19180] = 18433,
  [19181] = 18447,
  [19182] = 18501,
  [19183] = 18453,
  [19184] = 18459,
  [19185] = 18461,
  [19186] = 18429,
  [19187] = 19187,
  [19188] = 19188,
  [19189] = 18465,
  [19190] = 18437,
  [19191] = 18438,
  [19192] = 18440,
  [19193] = 18454,
  [19194] = 18476,
  [19195] = 18501,
  [19196] = 18645,
  [19197] = 18704,
  [19198] = 18441,
  [19199] = 18521,
  [19200] = 18483,
  [19201] = 18484,
  [19202] = 18485,
  [19203] = 18486,
  [19204] = 18479,
  [19205] = 18427,
  [19206] = 18470,
  [19207] = 19138,
  [19208] = 18460,
  [19209] = 18500,
  [19210] = 18615,
  [19211] = 18431,
  [19212] = 18501,
  [19213] = 18478,
  [19214] = 19141,
  [19215] = 18443,
  [19216] = 18446,
  [19217] = 18447,
  [19218] = 18460,
  [19219] = 18512,
  [19220] = 18471,
  [19221] = 18470,
  [19222] = 18471,
  [19223] = 18472,
  [19224] = 18459,
  [19225] = 18461,
  [19226] = 18472,
  [19227] = 18456,
  [19228] = 18503,
  [19229] = 18465,
  [19230] = 18425,
  [19231] = 18459,
  [19232] = 18433,
  [19233] = 18521,
  [19234] = 18476,
  [19235] = 18461,
  [19236] = 18456,
  [19237] = 18427,
  [19238] = 18429,
  [19239] = 18478,
  [19240] = 18483,
  [19241] = 18484,
  [19242] = 18485,
  [19243] = 18486,
  [19244] = 18430,
  [19245] = 18447,
  [19246] = 18465,
  [19247] = 18521,
  [19248] = 18945,
  [19249] = 18427,
  [19250] = 18435,
  [19251] = 18431,
  [19252] = 18448,
  [19253] = 18429,
  [19254] = 18453,
  [19255] = 18443,
  [19256] = 18446,
  [19257] = 18447,
  [19258] = 18437,
  [19259] = 18427,
  [19260] = 18438,
  [19261] = 18440,
  [19262] = 18685,
  [19263] = 18427,
  [19264] = 18459,
  [19265] = 18461,
  [19266] = 18500,
  [19267] = 18751,
  [19268] = 18454,
  [19269] = 18465,
  [19270] = 18425,
  [19271] = 18448,
  [19272] = 18456,
  [19273] = 18429,
  [19274] = 18476,
  [19275] = 18430,
  [19276] = 18441,
  [19277] = 18435,
  [19278] = 18479,
  [19279] = 18689,
  [19280] = 18483,
  [19281] = 18484,
  [19282] = 18485,
  [19283] = 18486,
  [19284] = 18449,
  [19285] = 18506,
  [19286] = 18437,
  [19287] = 18704,
  [19288] = 18438,
  [19289] = 18440,
  [19290] = 18433,
  [19291] = 18431,
  [19292] = 18429,
  [19293] = 18427,
  [19294] = 18460,
  [19295] = 18443,
  [19296] = 18446,
  [19297] = 18447,
  [19298] = 18448,
  [19299] = 18430,
  [19300] = 18453,
  [19301] = 18454,
  [19302] = 18500,
  [19303] = 18478,
  [19304] = 18459,
  [19305] = 18461,
  [19306] = 18470,
  [19307] = 18476,
  [19308] = 18471,
  [19309] = 18465,
  [19310] = 18429,
  [19311] = 18430,
  [19312] = 18454,
  [19313] = 18472,
  [19314] = 18476,
  [19315] = 18435,
  [19316] = 18493,
  [19317] = 18478,
  [19318] = 19318,
  [19319] = 18521,
  [19320] = 18483,
  [19321] = 18484,
  [19322] = 18485,
  [19323] = 18486,
  [19324] = 19324,
  [19325] = 18456,
  [19326] = 18449,
  [19327] = 19327,
  [19328] = 18448,
  [19329] = 18561,
  [19330] = 18453,
  [19331] = 18431,
  [19332] = 18479,
  [19333] = 18437,
  [19334] = 18483,
  [19335] = 18443,
  [19336] = 18446,
  [19337] = 18447,
  [19338] = 18484,
  [19339] = 18485,
  [19340] = 18486,
  [19341] = 18500,
  [19342] = 18438,
  [19343] = 18425,
  [19344] = 18459,
  [19345] = 18461,
  [19346] = 18445,
  [19347] = 18645,
  [19348] = 18478,
  [19349] = 18465,
  [19350] = 18432,
  [19351] = 18426,
  [19352] = 18440,
  [19353] = 18500,
  [19354] = 18476,
  [19355] = 18433,
  [19356] = 18509,
  [19357] = 18441,
  [19358] = 18478,
  [19359] = 18470,
  [19360] = 18483,
  [19361] = 18484,
  [19362] = 18485,
  [19363] = 18486,
  [19364] = 18471,
  [19365] = 18435,
  [19366] = 18472,
  [19367] = 18456,
  [19368] = 18521,
  [19369] = 18587,
  [19370] = 18561,
  [19371] = 18431,
  [19372] = 18448,
  [19373] = 18427,
  [19374] = 18453,
  [19375] = 18443,
  [19376] = 18446,
  [19377] = 18447,
  [19378] = 18449,
  [19379] = 18437,
  [19380] = 18438,
  [19381] = 19381,
  [19382] = 18460,
  [19383] = 18456,
  [19384] = 18459,
  [19385] = 18461,
  [19386] = 18445,
  [19387] = 18441,
  [19388] = 18425,
  [19389] = 18465,
  [19390] = 18489,
  [19391] = 19391,
  [19392] = 18831,
  [19393] = 18433,
  [19394] = 18476,
  [19395] = 18478,
  [19396] = 18448,
  [19397] = 18445,
  [19398] = 18521,
  [19399] = 18425,
  [19400] = 18483,
  [19401] = 18484,
  [19402] = 18485,
  [19403] = 18486,
  [19404] = 18633,
  [19405] = 18432,
  [19406] = 18454,
  [19407] = 18478,
  [19408] = 18456,
  [19409] = 18592,
  [19410] = 18440,
  [19411] = 18431,
  [19412] = 18478,
  [19413] = 18561,
  [19414] = 18456,
  [19415] = 18443,
  [19416] = 18446,
  [19417] = 18447,
  [19418] = 18445,
  [19419] = 18426,
  [19420] = 18432,
  [19421] = 18426,
  [19422] = 18460,
  [19423] = 18441,
  [19424] = 18459,
  [19425] = 18461,
  [19426] = 18432,
  [19427] = 18426,
  [19428] = 18435,
  [19429] = 18465,
  [19430] = 18512,
  [19431] = 18429,
  [19432] = 18503,
  [19433] = 18431,
  [19434] = 18476,
  [19435] = 18441,
  [19436] = 18430,
  [19437] = 18449,
  [19438] = 18587,
  [19439] = 18923,
  [19440] = 18483,
  [19441] = 18484,
  [19442] = 18485,
  [19443] = 18486,
  [19444] = 18478,
  [19445] = 18449,
  [19446] = 18425,
  [19447] = 18454,
  [19448] = 18460,
  [19449] = 18445,
  [19450] = 19450,
  [19451] = 18431,
  [19452] = 18506,
  [19453] = 18425,
  [19454] = 18433,
  [19455] = 18443,
  [19456] = 18446,
  [19457] = 18447,
  [19458] = 18509,
  [19459] = 18460,
  [19460] = 18512,
  [19461] = 18503,
  [19462] = 18506,
  [19463] = 18509,
  [19464] = 18459,
  [19465] = 18461,
  [19466] = 18489,
  [19467] = 18441,
  [19468] = 18432,
  [19469] = 18465,
  [19470] = 18435,
  [19471] = 18489,
  [19472] = 18454,
  [19473] = 19473,
  [19474] = 18476,
  [19475] = 18454,
  [19476] = 18437,
  [19477] = 18453,
  [19478] = 18438,
  [19479] = 18445,
  [19480] = 18483,
  [19481] = 18484,
  [19482] = 18485,
  [19483] = 18486,
  [19484] = 19484,
  [19485] = 18426,
  [19486] = 18433,
  [19487] = 19487,
  [19488] = 19488,
  [19489] = 19489,
  [19490] = 18431,
  [19491] = 18512,
  [19492] = 18587,
  [19493] = 18493,
  [19494] = 18443,
  [19495] = 18446,
  [19496] = 18447,
  [19497] = 18575,
  [19498] = 18501,
  [19499] = 18441,
  [19500] = 18501,
  [19501] = 18592,
  [19502] = 18456,
  [19503] = 18459,
  [19504] = 18461,
  [19505] = 18453,
  [19506] = 18431,
  [19507] = 18454,
  [19508] = 18465,
  [19509] = 18432,
  [19510] = 18633,
  [19511] = 18434,
  [19512] = 18445,
  [19513] = 18476,
  [19514] = 18449,
  [19515] = 18535,
  [19516] = 18427,
  [19517] = 18429,
  [19518] = 18430,
  [19519] = 18483,
  [19520] = 18484,
  [19521] = 18485,
  [19522] = 18486,
  [19523] = 18503,
  [19524] = 18445,
  [19525] = 18432,
  [19526] = 18536,
  [19527] = 18435,
  [19528] = 18460,
  [19529] = 18431,
  [19530] = 18426,
  [19531] = 18506,
  [19532] = 18441,
  [19533] = 18443,
  [19534] = 18446,
  [19535] = 18447,
  [19536] = 18713,
  [19537] = 18432,
  [19538] = 18426,
  [19539] = 18462,
  [19540] = 18592,
  [19541] = 18425,
  [19542] = 18459,
  [19543] = 18461,
  [19544] = 18449,
  [19545] = 18425,
  [19546] = 18439,
  [19547] = 18465,
  [19548] = 19548,
  [19549] = 18434,
  [19550] = 18426,
  [19551] = 18443,
  [19552] = 18476,
  [19553] = 18512,
  [19554] = 18479,
  [19555] = 18427,
  [19556] = 18446,
  [19557] = 18447,
  [19558] = 18483,
  [19559] = 18484,
  [19560] = 18485,
  [19561] = 18486,
  [19562] = 18462,
  [19563] = 18509,
  [19564] = 18468,
  [19565] = 18503,
  [19566] = 18429,
  [19567] = 18431,
  [19568] = 18489,
  [19569] = 18430,
  [19570] = 18427,
  [19571] = 18443,
  [19572] = 18446,
  [19573] = 18447,
  [19574] = 18456,
  [19575] = 19575,
  [19576] = 18440,
  [19577] = 18435,
  [19578] = 18725,
  [19579] = 18437,
  [19580] = 18459,
  [19581] = 18461,
  [19582] = 18503,
  [19583] = 18437,
  [19584] = 18438,
  [19585] = 18465,
  [19586] = 18441,
  [19587] = 18645,
  [19588] = 18535,
  [19589] = 18440,
  [19590] = 18476,
  [19591] = 18438,
  [19592] = 18468,
  [19593] = 18440,
  [19594] = 18433,
  [19595] = 18506,
  [19596] = 18483,
  [19597] = 18484,
  [19598] = 18485,
  [19599] = 18486,
  [19600] = 18454,
  [19601] = 18509,
  [19602] = 18489,
  [19603] = 18501,
  [19604] = 18454,
  [19605] = 18431,
  [19606] = 18506,
  [19607] = 18945,
  [19608] = 18536,
  [19609] = 18443,
  [19610] = 18446,
  [19611] = 18447,
  [19612] = 18493,
  [19613] = 18596,
  [19614] = 18479,
  [19615] = 18509,
  [19616] = 18445,
  [19617] = 18512,
  [19618] = 18459,
  [19619] = 18461,
  [19620] = 18633,
  [19621] = 19621,
  [19622] = 18923,
  [19623] = 18465,
  [19624] = 18489,
  [19625] = 18427,
  [19626] = 18459,
  [19627] = 18501,
  [19628] = 18476,
  [19629] = 18429,
  [19630] = 18461,
  [19631] = 18479,
  [19632] = 18556,
  [19633] = 18478,
  [19634] = 18483,
  [19635] = 18484,
  [19636] = 18485,
  [19637] = 18486,
  [19638] = 18432,
  [19639] = 18426,
  [19640] = 18430,
  [19641] = 18435,
  [19642] = 18500,
  [19643] = 18431,
  [19644] = 18430,
  [19645] = 18435,
  [19646] = 18725,
  [19647] = 18443,
  [19648] = 18446,
  [19649] = 18447,
  [19650] = 18470,
  [19651] = 18465,
  [19652] = 18471,
  [19653] = 18444,
  [19654] = 18472,
  [19655] = 18479,
  [19656] = 18459,
  [19657] = 18461,
  [19658] = 18500,
  [19659] = 18437,
  [19660] = 18470,
  [19661] = 18465,
  [19662] = 18587,
  [19663] = 18439,
  [19664] = 18685,
  [19665] = 18471,
  [19666] = 18476,
  [19667] = 18438,
  [19668] = 18449,
  [19669] = 18472,
  [19670] = 18437,
  [19671] = 18521,
  [19672] = 18483,
  [19673] = 18484,
  [19674] = 18485,
  [19675] = 18486,
  [19676] = 18521,
  [19677] = 18440,
  [19678] = 18441,
  [19679] = 18509,
  [19680] = 18448,
  [19681] = 18431,
  [19682] = 18470,
  [19683] = 18453,
  [19684] = 18454,
  [19685] = 18443,
  [19686] = 18446,
  [19687] = 18447,
  [19688] = 18441,
  [19689] = 18561,
  [19690] = 18479,
  [19691] = 18438,
  [19692] = 18923,
  [19693] = 18440,
  [19694] = 18459,
  [19695] = 18461,
  [19696] = 18689,
  [19697] = 18512,
  [19698] = 18704,
  [19699] = 18465,
  [19700] = 18893,
  [19701] = 18476,
  [19702] = 18454,
  [19703] = 18443,
  [19704] = 18476,
  [19705] = 18460,
  [19706] = 18448,
  [19707] = 18453,
  [19708] = 18713,
  [19709] = 18483,
  [19710] = 18484,
  [19711] = 18485,
  [19712] = 18486,
  [19713] = 18471,
  [19714] = 18472,
  [19715] = 18503,
  [19716] = 18448,
  [19717] = 18453,
  [19718] = 18431,
  [19719] = 18506,
  [19720] = 18478,
  [19721] = 18449,
  [19722] = 18443,
  [19723] = 18446,
  [19724] = 18447,
  [19725] = 18478,
  [19726] = 18704,
  [19727] = 18456,
  [19728] = 19107,
  [19729] = 18587,
  [19730] = 18443,
  [19731] = 18459,
  [19732] = 18461,
  [19733] = 18945,
  [19734] = 18446,
  [19735] = 18587,
  [19736] = 18465,
  [19737] = 18454,
  [19738] = 18479,
  [19739] = 18483,
  [19740] = 18484,
  [19741] = 18476,
  [19742] = 18485,
  [19743] = 18460,
  [19744] = 18486,
  [19745] = 18425,
  [19746] = 18483,
  [19747] = 18484,
  [19748] = 18485,
  [19749] = 18486,
  [19750] = 18447,
  [19751] = 18509,
  [19752] = 18456,
  [19753] = 18425,
  [19754] = 18433,
  [19755] = 18431,
  [19756] = 18479,
  [19757] = 18445,
  [19758] = 18441,
  [19759] = 18443,
  [19760] = 18446,
  [19761] = 18447,
  [19762] = 19762,
  [19763] = 18475,
  [19764] = 18479,
  [19765] = 18432,
  [19766] = 18704,
  [19767] = 18426,
  [19768] = 18459,
  [19769] = 18461,
  [19770] = 18905,
  [19771] = 18501,
  [19772] = 18489,
  [19773] = 18465,
  [19774] = 18444,
  [19775] = 19775,
  [19776] = 18429,
  [19777] = 18433,
  [19778] = 18476,
  [19779] = 18456,
  [19780] = 18479,
  [19781] = 18437,
  [19782] = 18501,
  [19783] = 18483,
  [19784] = 18484,
  [19785] = 18485,
  [19786] = 18486,
  [19787] = 18489,
  [19788] = 18556,
  [19789] = 18561,
  [19790] = 18441,
  [19791] = 18500,
  [19792] = 18444,
  [19793] = 18923,
  [19794] = 18521,
  [19795] = 18443,
  [19796] = 18446,
  [19797] = 18447,
  [19798] = 18430,
  [19799] = 18500,
  [19800] = 18445,
  [19801] = 18432,
  [19802] = 18426,
  [19803] = 18437,
  [19804] = 18459,
  [19805] = 18461,
  [19806] = 18441,
  [19807] = 18501,
  [19808] = 18500,
  [19809] = 18465,
  [19810] = 18484,
  [19811] = 18470,
  [19812] = 18471,
  [19813] = 18449,
  [19814] = 18476,
  [19815] = 18472,
  [19816] = 18478,
  [19817] = 18945,
  [19818] = 18512,
  [19819] = 18483,
  [19820] = 18484,
  [19821] = 18485,
  [19822] = 18486,
  [19823] = 18438,
  [19824] = 18503,
  [19825] = 19825,
  [19826] = 18449,
  [19827] = 18444,
  [19828] = 18430,
  [19829] = 18435,
  [19830] = 18443,
  [19831] = 18446,
  [19832] = 18447,
  [19833] = 18983,
  [19834] = 18449,
  [19835] = 18459,
  [19836] = 18461,
  [19837] = 18465,
  [19838] = 18554,
  [19839] = 18470,
  [19840] = 18425,
  [19841] = 18476,
  [19842] = 18512,
  [19843] = 18483,
  [19844] = 18484,
  [19845] = 18485,
  [19846] = 18486,
  [19847] = 18503,
  [19848] = 18460,
  [19849] = 18587,
  [19850] = 18506,
  [19851] = 18437,
  [19852] = 18509,
  [19853] = 18443,
  [19854] = 18446,
  [19855] = 18447,
  [19856] = 18522,
  [19857] = 18489,
  [19858] = 18459,
  [19859] = 18461,
  [19860] = 18433,
  [19861] = 18519,
  [19862] = 18521,
  [19863] = 18476,
  [19864] = 18471,
  [19865] = 18483,
  [19866] = 18484,
  [19867] = 18485,
  [19868] = 18486,
  [19869] = 18438,
  [19870] = 18636,
  [19871] = 18440,
  [19872] = 18454,
  [19873] = 18479,
  [19874] = 18456,
  [19875] = 18479,
  [19876] = 19188,
  [19877] = 18448,
  [19878] = 18484,
  [19879] = 18485,
  [19880] = 18486,
  [19881] = 18506,
  [19882] = 18431,
  [19883] = 19883,
  [19884] = 18509,
  [19885] = 18460,
  [19886] = 18453,
  [19887] = 18493,
  [19888] = 18471,
  [19889] = 18434,
  [19890] = 18484,
  [19891] = 18485,
  [19892] = 18486,
  [19893] = 18471,
  [19894] = 18472,
  [19895] = 18448,
  [19896] = 18478,
  [19897] = 18535,
  [19898] = 18536,
  [19899] = 18645,
  [19900] = 18484,
  [19901] = 18485,
  [19902] = 18486,
  [19903] = 18453,
  [19904] = 18427,
  [19905] = 18429,
  [19906] = 18438,
  [19907] = 18439,
  [19908] = 18445,
  [19909] = 19548,
  [19910] = 18484,
  [19911] = 18485,
  [19912] = 18486,
  [19913] = 18575,
  [19914] = 18478,
  [19915] = 18501,
  [19916] = 18432,
  [19917] = 18443,
  [19918] = 18426,
  [19919] = 18472,
  [19920] = 18484,
  [19921] = 18485,
  [19922] = 18486,
  [19923] = 18592,
  [19924] = 18501,
  [19925] = 18446,
  [19926] = 18447,
  [19927] = 18441,
  [19928] = 18579,
  [19929] = 18435,
  [19930] = 18484,
  [19931] = 18485,
  [19932] = 18486,
  [19933] = 18425,
  [19934] = 18424,
  [19935] = 18470,
  [19936] = 18430,
  [19937] = 18456,
  [19938] = 18923,
  [19939] = 18945,
  [19940] = 18484,
  [19941] = 18485,
  [19942] = 18486,
  [19943] = 18456,
  [19944] = 18489,
  [19945] = 18456,
  [19946] = 18500,
  [19947] = 18486,
  [19948] = 18435,
  [19949] = 18689,
  [19950] = 18484,
  [19951] = 18485,
  [19952] = 18486,
  [19953] = 18459,
  [19954] = 19575,
  [19955] = 18461,
  [19956] = 18437,
  [19957] = 18438,
  [19958] = 18983,
  [19959] = 18465,
  [19960] = 18484,
  [19961] = 18485,
  [19962] = 18486,
  [19963] = 18704,
  [19964] = 18489,
  [19965] = 18471,
  [19966] = 19966,
  [19967] = 18470,
  [19968] = 18587,
  [19969] = 18471,
  [19970] = 18484,
  [19971] = 18485,
  [19972] = 18486,
  [19973] = 18905,
  [19974] = 18493,
  [19975] = 19548,
  [19976] = 18440,
  [19977] = 18440,
  [19978] = 18472,
  [19979] = 18478,
  [19980] = 18484,
  [19981] = 18485,
  [19982] = 18486,
  [19983] = 19107,
  [19984] = 18476,
  [19985] = 18501,
  [19986] = 19986,
  [19987] = 18472,
  [19988] = 18444,
  [19989] = 18521,
  [19990] = 18484,
  [19991] = 18485,
  [19992] = 18486,
  [19993] = 18579,
  [19994] = 18448,
  [19995] = 18483,
  [19996] = 18430,
  [19997] = 18435,
  [19998] = 18484,
  [19999] = 18425,
  [20000] = 18479,
  [20001] = 18485,
  [20002] = 18471,
  [20003] = 18472,
  [20004] = 18486,
  [20005] = 18448,
  [20006] = 18453,
  [20007] = 20007,
  [20008] = 18425,
  [20009] = 18459,
  [20010] = 18454,
  [20011] = 18489,
  [20012] = 18500,
  [20013] = 18453,
  [20014] = 18501,
  [20015] = 18633,
  [20016] = 19012,
  [20017] = 18493,
  [20018] = 18430,
  [20019] = 18461,
  [20020] = 18435,
  [20021] = 19548,
  [20022] = 18437,
  [20023] = 18479,
  [20024] = 18471,
  [20025] = 18456,
  [20026] = 18472,
  [20027] = 18448,
  [20028] = 18521,
  [20029] = 18453,
  [20030] = 18425,
  [20031] = 18460,
  [20032] = 18479,
  [20033] = 18489,
  [20034] = 18465,
  [20035] = 18460,
  [20036] = 18501,
  [20037] = 18449,
  [20038] = 13642,
  [20039] = 19188,
  [20040] = 18893,
  [20041] = 18430,
  [20042] = 18435,
  [20043] = 18425,
  [20044] = 18501,
  [20045] = 18479,
  [20046] = 18433,
  [20047] = 18471,
  [20048] = 18472,
  [20049] = 18512,
  [20050] = 18448,
  [20051] = 18453,
  [20052] = 18425,
  [20053] = 18431,
  [20054] = 18512,
  [20055] = 18489,
  [20056] = 18503,
  [20057] = 18503,
  [20058] = 18501,
  [20059] = 18434,
  [20060] = 18535,
  [20061] = 18536,
  [20062] = 18430,
  [20063] = 18470,
  [20064] = 18435,
  [20065] = 18512,
  [20066] = 18471,
  [20067] = 18479,
  [20068] = 18587,
  [20069] = 18471,
  [20070] = 18456,
  [20071] = 18512,
  [20072] = 18424,
  [20073] = 18493,
  [20074] = 19621,
  [20075] = 18592,
  [20076] = 18472,
  [20077] = 18439,
  [20078] = 18448,
  [20079] = 18453,
  [20080] = 18425,
  [20081] = 18427,
  [20082] = 18556,
  [20083] = 18489,
  [20084] = 18425,
  [20085] = 18471,
  [20086] = 18425,
  [20087] = 18429,
  [20088] = 18501,
  [20089] = 18500,
  [20090] = 18430,
  [20091] = 18596,
  [20092] = 18443,
  [20093] = 18685,
  [20094] = 19391,
  [20095] = 18435,
  [20096] = 18503,
  [20097] = 18430,
  [20098] = 18435,
  [20099] = 18437,
  [20100] = 18445,
  [20101] = 18479,
  [20102] = 18438,
  [20103] = 20103,
  [20104] = 18471,
  [20105] = 18655,
  [20106] = 18472,
  [20107] = 18440,
  [20108] = 18448,
  [20109] = 20109,
  [20110] = 18454,
  [20111] = 18506,
  [20112] = 20112,
  [20113] = 18454,
  [20114] = 18453,
  [20115] = 18509,
  [20116] = 18893,
  [20117] = 18489,
  [20118] = 18425,
  [20119] = 18446,
  [20120] = 18454,
  [20121] = 18489,
  [20122] = 18447,
  [20123] = 19775,
  [20124] = 18501,
  [20125] = 18905,
  [20126] = 18427,
  [20127] = 18479,
  [20128] = 18519,
  [20129] = 18478,
  [20130] = 18430,
  [20131] = 18433,
  [20132] = 18556,
  [20133] = 18472,
  [20134] = 18435,
  [20135] = 20135,
  [20136] = 19187,
  [20137] = 18596,
  [20138] = 18448,
  [20139] = 18500,
  [20140] = 18433,
  [20141] = 18479,
  [20142] = 18471,
  [20143] = 20143,
  [20144] = 18472,
  [20145] = 20145,
  [20146] = 18470,
  [20147] = 20147,
  [20148] = 18448,
  [20149] = 19450,
  [20150] = 18453,
  [20151] = 18425,
  [20152] = 18503,
  [20153] = 18471,
  [20154] = 18472,
  [20155] = 18500,
  [20156] = 18489,
  [20157] = 18506,
  [20158] = 18470,
  [20159] = 18521,
  [20160] = 18501,
  [20161] = 18471,
  [20162] = 18448,
  [20163] = 18453,
  [20164] = 18432,
  [20165] = 18512,
  [20166] = 20166,
  [20167] = 18430,
  [20168] = 18435,
  [20169] = 18501,
  [20170] = 19883,
  [20171] = 18426,
  [20172] = 18456,
  [20173] = 18472,
  [20174] = 18479,
  [20175] = 18433,
  [20176] = 19484,
  [20177] = 19487,
  [20178] = 19488,
  [20179] = 18460,
  [20180] = 18478,
  [20181] = 18471,
  [20182] = 18472,
  [20183] = 18448,
  [20184] = 18453,
  [20185] = 18445,
  [20186] = 18432,
  [20187] = 18426,
  [20188] = 18425,
  [20189] = 18441,
  [20190] = 18459,
  [20191] = 18503,
  [20192] = 18923,
  [20193] = 18945,
  [20194] = 18461,
  [20195] = 18587,
  [20196] = 20196,
  [20197] = 18506,
  [20198] = 18509,
  [20199] = 18983,
  [20200] = 18489,
  [20201] = 18489,
  [20202] = 18465,
  [20203] = 18478,
  [20204] = 18444,
  [20205] = 18501,
  [20206] = 18689,
  [20207] = 18438,
  [20208] = 18453,
  [20209] = 20166,
  [20210] = 18440,
  [20211] = 18460,
  [20212] = 19012,
  [20213] = 18436,
  [20214] = 20214,
  [20215] = 18440,
  [20216] = 18831,
  [20217] = 18430,
  [20218] = 18445,
  [20219] = 18425,
  [20220] = 18433,
  [20221] = 18435,
  [20222] = 18432,
  [20223] = 18433,
  [20224] = 18449,
  [20225] = 18426,
  [20226] = 18425,
  [20227] = 18479,
  [20228] = 18471,
  [20229] = 18472,
  [20230] = 18448,
  [20231] = 18453,
  [20232] = 18521,
  [20233] = 18425,
  [20234] = 18476,
  [20235] = 18489,
  [20236] = 19153,
  [20237] = 18456,
  [20238] = 18512,
  [20239] = 18500,
  [20240] = 18501,
  [20241] = 18441,
  [20242] = 18445,
  [20243] = 18432,
  [20244] = 18426,
  [20245] = 18522,
  [20246] = 18441,
  [20247] = 18519,
  [20248] = 18449,
  [20249] = 18472,
  [20250] = 18592,
  [20251] = 18430,
  [20252] = 18424,
  [20253] = 18483,
  [20254] = 19621,
  [20255] = 18435,
  [20256] = 18596,
  [20257] = 18493,
  [20258] = 18484,
  [20259] = 18485,
  [20260] = 18486,
  [20261] = 18479,
  [20262] = 18512,
  [20263] = 18471,
  [20264] = 18503,
  [20265] = 19391,
  [20266] = 18506,
  [20267] = 20109,
  [20268] = 18449,
  [20269] = 18509,
  [20270] = 18472,
  [20271] = 18489,
  [20272] = 18512,
  [20273] = 18503,
  [20274] = 18448,
  [20275] = 18506,
  [20276] = 18509,
  [20277] = 8554,
  [20278] = 18489,
  [20279] = 18831,
  [20280] = 18453,
  [20281] = 18522,
  [20282] = 18425,
  [20283] = 18519,
  [20284] = 18636,
  [20285] = 18448,
  [20286] = 20143,
  [20287] = 19107,
  [20288] = 20147,
  [20289] = 18453,
  [20290] = 19450,
  [20291] = 18587,
  [20292] = 18489,
  [20293] = 18476,
  [20294] = 18501,
  [20295] = 18521,
  [20296] = 18636,
  [20297] = 18556,
  [20298] = 18831,
  [20299] = 18501,
  [20300] = 18445,
  [20301] = 19107,
  [20302] = 18430,
  [20303] = 18435,
  [20304] = 18435,
  [20305] = 18921,
  [20306] = 19138,
  [20307] = 18506,
  [20308] = 19484,
  [20309] = 19487,
  [20310] = 19488,
  [20311] = 19141,
  [20312] = 18432,
  [20313] = 18448,
  [20314] = 18479,
  [20315] = 18501,
  [20316] = 19153,
  [20317] = 18818,
  [20318] = 18471,
  [20319] = 18465,
  [20320] = 18427,
  [20321] = 18431,
  [20322] = 18429,
  [20323] = 18478,
  [20324] = 18430,
  [20325] = 18472,
  [20326] = 18509,
  [20327] = 18448,
  [20328] = 18489,
  [20329] = 18427,
  [20330] = 18556,
  [20331] = 18429,
  [20332] = 18430,
  [20333] = 18535,
  [20334] = 18501,
  [20335] = 18435,
  [20336] = 18453,
  [20337] = 18437,
  [20338] = 18438,
  [20339] = 18453,
  [20340] = 18512,
  [20341] = 18440,
  [20342] = 18425,
  [20343] = 18923,
  [20344] = 18512,
  [20345] = 18431,
  [20346] = 18454,
  [20347] = 18425,
  [20348] = 18435,
  [20349] = 18503,
  [20350] = 18506,
  [20351] = 19621,
  [20352] = 18489,
  [20353] = 18479,
  [20354] = 18434,
  [20355] = 18501,
  [20356] = 18441,
  [20357] = 18536,
  [20358] = 18561,
  [20359] = 18430,
  [20360] = 18503,
  [20361] = 18435,
  [20362] = 18468,
  [20363] = 20109,
  [20364] = 18945,
  [20365] = 18945,
  [20366] = 18596,
  [20367] = 18479,
  [20368] = 18471,
  [20369] = 18472,
  [20370] = 20370,
  [20371] = 18500,
  [20372] = 18448,
  [20373] = 18453,
  [20374] = 18470,
  [20375] = 18471,
  [20376] = 18472,
  [20377] = 20377,
  [20378] = 18425,
  [20379] = 18509,
  [20380] = 20143,
  [20381] = 20147,
  [20382] = 20147,
  [20383] = 18521,
  [20384] = 19450,
  [20385] = 18439,
  [20386] = 20386,
  [20387] = 18489,
  [20388] = 18503,
  [20389] = 18448,
  [20390] = 18453,
  [20391] = 20391,
  [20392] = 18426,
  [20393] = 18489,
  [20394] = 20394,
  [20395] = 18501,
  [20396] = 18427,
  [20397] = 18446,
  [20398] = 18443,
  [20399] = 18430,
  [20400] = 19621,
  [20401] = 18921,
  [20402] = 19484,
  [20403] = 19487,
  [20404] = 19488,
  [20405] = 18506,
  [20406] = 20007,
  [20407] = 18478,
  [20408] = 18446,
  [20409] = 20143,
  [20410] = 18447,
  [20411] = 20196,
  [20412] = 20412,
  [20413] = 18435,
  [20414] = 18429,
  [20415] = 18479,
  [20416] = 18471,
  [20417] = 20417,
  [20418] = 19138,
  [20419] = 18472,
  [20420] = 18448,
  [20421] = 20421,
  [20422] = 18587,
  [20423] = 20103,
  [20424] = 18500,
  [20425] = 19575,
  [20426] = 18453,
  [20427] = 18536,
  [20428] = 18509,
  [20429] = 18425,
  [20430] = 18427,
  [20431] = 18460,
  [20432] = 20109,
  [20433] = 18509,
  [20434] = 18556,
  [20435] = 19141,
  [20436] = 18425,
  [20437] = 18433,
  [20438] = 19986,
  [20439] = 18506,
  [20440] = 18427,
  [20441] = 18506,
  [20442] = 18509,
  [20443] = 19621,
  [20444] = 18489,
  [20445] = 18429,
  [20446] = 18430,
  [20447] = 18456,
  [20448] = 18456,
  [20449] = 18509,
  [20450] = 18489,
  [20451] = 18435,
  [20452] = 18983,
  [20453] = 18501,
  [20454] = 18430,
  [20455] = 18459,
  [20456] = 18435,
  [20457] = 18483,
  [20458] = 18461,
  [20459] = 18445,
  [20460] = 18432,
  [20461] = 20143,
  [20462] = 20147,
  [20463] = 18426,
  [20464] = 19450,
  [20465] = 18472,
  [20466] = 18448,
  [20467] = 18453,
  [20468] = 18441,
  [20469] = 18501,
  [20470] = 19484,
  [20471] = 19487,
  [20472] = 19488,
  [20473] = 18449,
  [20474] = 18478,
  [20475] = 18521,
  [20476] = 19621,
  [20477] = 18425,
  [20478] = 18465,
  [20479] = 18435,
  [20480] = 18449,
  [20481] = 18448,
  [20482] = 18484,
  [20483] = 18453,
  [20484] = 18485,
  [20485] = 18425,
  [20486] = 18486,
  [20487] = 18435,
  [20488] = 18512,
  [20489] = 18435,
  [20490] = 19775,
  [20491] = 18521,
  [20492] = 20143,
  [20493] = 20147,
  [20494] = 18503,
  [20495] = 19450,
  [20496] = 18448,
  [20497] = 19484,
  [20498] = 19487,
  [20499] = 19488,
  [20500] = 19153,
  [20501] = 18489,
  [20502] = 19621,
  [20503] = 18453,
  [20504] = 18425,
  [20505] = 18506,
  [20506] = 18509,
  [20507] = 18444,
  [20508] = 18489,
  [20509] = 18456,
  [20510] = 18448,
  [20511] = 18462,
  [20512] = 18468,
  [20513] = 18453,
  [20514] = 18501,
  [20515] = 20143,
  [20516] = 20147,
  [20517] = 18425,
  [20518] = 19450,
  [20519] = 18429,
  [20520] = 19484,
  [20521] = 19487,
  [20522] = 19488,
  [20523] = 19621,
  [20524] = 18448,
  [20525] = 18427,
  [20526] = 18429,
  [20527] = 18430,
  [20528] = 18437,
  [20529] = 18818,
  [20530] = 18453,
  [20531] = 18435,
  [20532] = 18476,
  [20533] = 18831,
  [20534] = 18425,
  [20535] = 18438,
  [20536] = 20147,
  [20537] = 18501,
  [20538] = 19450,
  [20539] = 19883,
  [20540] = 19484,
  [20541] = 19487,
  [20542] = 19488,
  [20543] = 19621,
  [20544] = 18448,
  [20545] = 18521,
  [20546] = 18453,
  [20547] = 18440,
  [20548] = 18425,
  [20549] = 18587,
  [20550] = 18437,
  [20551] = 18462,
  [20552] = 18468,
  [20553] = 18519,
  [20554] = 18448,
  [20555] = 18453,
  [20556] = 20147,
  [20557] = 18425,
  [20558] = 19450,
  [20559] = 18438,
  [20560] = 19484,
  [20561] = 19487,
  [20562] = 19488,
  [20563] = 19621,
  [20564] = 18448,
  [20565] = 18453,
  [20566] = 18425,
  [20567] = 18437,
  [20568] = 18438,
  [20569] = 18440,
  [20570] = 18893,
  [20571] = 18448,
  [20572] = 18453,
  [20573] = 18444,
  [20574] = 18425,
  [20575] = 20147,
  [20576] = 18454,
  [20577] = 19450,
  [20578] = 18440,
  [20579] = 19484,
  [20580] = 19487,
  [20581] = 19488,
  [20582] = 19621,
  [20583] = 18448,
  [20584] = 18453,
  [20585] = 18427,
  [20586] = 18454,
  [20587] = 18427,
  [20588] = 18425,
  [20589] = 18587,
  [20590] = 18633,
  [20591] = 18483,
  [20592] = 18448,
  [20593] = 20147,
  [20594] = 18484,
  [20595] = 19450,
  [20596] = 18453,
  [20597] = 19484,
  [20598] = 19487,
  [20599] = 19488,
  [20600] = 19621,
  [20601] = 18425,
  [20602] = 18485,
  [20603] = 18479,
  [20604] = 18448,
  [20605] = 18429,
  [20606] = 18453,
  [20607] = 18425,
  [20608] = 18430,
  [20609] = 18486,
  [20610] = 18427,
  [20611] = 20147,
  [20612] = 18831,
  [20613] = 19450,
  [20614] = 18448,
  [20615] = 19484,
  [20616] = 19487,
  [20617] = 19488,
  [20618] = 19621,
  [20619] = 18453,
  [20620] = 18427,
  [20621] = 18429,
  [20622] = 18500,
  [20623] = 18425,
  [20624] = 18479,
  [20625] = 18470,
  [20626] = 18471,
  [20627] = 18448,
  [20628] = 20147,
  [20629] = 18472,
  [20630] = 19450,
  [20631] = 18453,
  [20632] = 19484,
  [20633] = 19487,
  [20634] = 19488,
  [20635] = 18425,
  [20636] = 18429,
  [20637] = 18430,
  [20638] = 18521,
  [20639] = 18429,
  [20640] = 18704,
  [20641] = 18435,
  [20642] = 18501,
  [20643] = 18448,
  [20644] = 20147,
  [20645] = 18460,
  [20646] = 19450,
  [20647] = 18453,
  [20648] = 19484,
  [20649] = 19487,
  [20650] = 19488,
  [20651] = 18425,
  [20652] = 18430,
  [20653] = 18689,
  [20654] = 18448,
  [20655] = 18453,
  [20656] = 18704,
  [20657] = 18425,
  [20658] = 18448,
  [20659] = 18454,
  [20660] = 20147,
  [20661] = 18453,
  [20662] = 19450,
  [20663] = 18448,
  [20664] = 19484,
  [20665] = 19487,
  [20666] = 19488,
  [20667] = 18453,
  [20668] = 18713,
  [20669] = 18437,
  [20670] = 18438,
  [20671] = 18425,
  [20672] = 18435,
  [20673] = 18440,
  [20674] = 18448,
  [20675] = 18453,
  [20676] = 20147,
  [20677] = 18633,
  [20678] = 19450,
  [20679] = 18425,
  [20680] = 19484,
  [20681] = 19487,
  [20682] = 19488,
  [20683] = 18704,
  [20684] = 18462,
  [20685] = 18448,
  [20686] = 18454,
  [20687] = 18453,
  [20688] = 18425,
  [20689] = 18633,
  [20690] = 18905,
  [20691] = 18448,
  [20692] = 20147,
  [20693] = 18453,
  [20694] = 19450,
  [20695] = 18425,
  [20696] = 19484,
  [20697] = 19487,
  [20698] = 19488,
  [20699] = 18430,
  [20700] = 18479,
  [20701] = 18448,
  [20702] = 18479,
  [20703] = 18453,
  [20704] = 18468,
  [20705] = 18493,
  [20706] = 18587,
  [20707] = 18425,
  [20708] = 20147,
  [20709] = 18519,
  [20710] = 19450,
  [20711] = 18437,
  [20712] = 19484,
  [20713] = 19487,
  [20714] = 19488,
  [20715] = 18448,
  [20716] = 18425,
  [20717] = 18453,
  [20718] = 18425,
  [20719] = 19775,
  [20720] = 18430,
  [20721] = 18433,
  [20722] = 18448,
  [20723] = 18453,
  [20724] = 20147,
  [20725] = 18425,
  [20726] = 19450,
  [20727] = 18438,
  [20728] = 19484,
  [20729] = 19487,
  [20730] = 19488,
  [20731] = 18448,
  [20732] = 18561,
  [20733] = 18435,
  [20734] = 18453,
  [20735] = 18425,
  [20736] = 18556,
  [20737] = 20112,
  [20738] = 18445,
  [20739] = 18440,
  [20740] = 20147,
  [20741] = 18556,
  [20742] = 19450,
  [20743] = 18921,
  [20744] = 19484,
  [20745] = 19487,
  [20746] = 19488,
  [20747] = 18435,
  [20748] = 18500,
  [20749] = 18501,
  [20750] = 18478,
  [20751] = 18500,
  [20752] = 18470,
  [20753] = 18479,
  [20754] = 18561,
  [20755] = 18427,
  [20756] = 20147,
  [20757] = 18429,
  [20758] = 19450,
  [20759] = 18448,
  [20760] = 19484,
  [20761] = 19487,
  [20762] = 19488,
  [20763] = 18453,
  [20764] = 18471,
  [20765] = 18472,
  [20766] = 18587,
  [20767] = 18454,
  [20768] = 18430,
  [20769] = 19138,
  [20770] = 18449,
  [20771] = 18433,
  [20772] = 20147,
  [20773] = 18493,
  [20774] = 19450,
  [20775] = 18431,
  [20776] = 19484,
  [20777] = 19487,
  [20778] = 19488,
  [20779] = 18435,
  [20780] = 18460,
  [20781] = 20781,
  [20782] = 20782,
  [20783] = 18434,
  [20784] = 18521,
  [20785] = 18592,
  [20786] = 18478,
  [20787] = 20787,
  [20788] = 18425,
  [20789] = 19450,
  [20790] = 18479,
  [20791] = 19484,
  [20792] = 19487,
  [20793] = 19488,
  [20794] = 18479,
  [20795] = 20795,
  [20796] = 18596,
  [20797] = 18470,
  [20798] = 18449,
  [20799] = 18431,
  [20800] = 18448,
  [20801] = 18536,
  [20802] = 18500,
  [20803] = 18448,
  [20804] = 19450,
  [20805] = 5471,
  [20806] = 19484,
  [20807] = 19487,
  [20808] = 19488,
  [20809] = 18470,
  [20810] = 18437,
  [20811] = 18453,
  [20812] = 18438,
  [20813] = 18471,
  [20814] = 18893,
  [20815] = 18439,
  [20816] = 18472,
  [20817] = 18503,
  [20818] = 18500,
  [20819] = 19450,
  [20820] = 18441,
  [20821] = 19484,
  [20822] = 19487,
  [20823] = 19488,
  [20824] = 18521,
  [20825] = 18440,
  [20826] = 18427,
  [20827] = 18443,
  [20828] = 18500,
  [20829] = 18905,
  [20830] = 18448,
  [20831] = 18429,
  [20832] = 18456,
  [20833] = 18433,
  [20834] = 19450,
  [20835] = 19141,
  [20836] = 19484,
  [20837] = 19487,
  [20838] = 19488,
  [20839] = 18453,
  [20840] = 18470,
  [20841] = 18446,
  [20842] = 18471,
  [20843] = 18470,
  [20844] = 18447,
  [20845] = 18471,
  [20846] = 18434,
  [20847] = 18478,
  [20848] = 18453,
  [20849] = 19450,
  [20850] = 18431,
  [20851] = 19484,
  [20852] = 19487,
  [20853] = 19488,
  [20854] = 18472,
  [20855] = 18535,
  [20856] = 18478,
  [20857] = 18536,
  [20858] = 18478,
  [20859] = 18506,
  [20860] = 18472,
  [20861] = 18430,
  [20862] = 18456,
  [20863] = 18479,
  [20864] = 19450,
  [20865] = 20112,
  [20866] = 19484,
  [20867] = 19487,
  [20868] = 19488,
  [20869] = 20103,
  [20870] = 18587,
  [20871] = 18456,
  [20872] = 19188,
  [20873] = 18893,
  [20874] = 18587,
  [20875] = 20875,
  [20876] = 18521,
  [20877] = 18454,
  [20878] = 18445,
  [20879] = 19450,
  [20880] = 18460,
  [20881] = 19484,
  [20882] = 19487,
  [20883] = 19488,
  [20884] = 18448,
  [20885] = 18432,
  [20886] = 18426,
  [20887] = 18633,
  [20888] = 18439,
  [20889] = 18441,
  [20890] = 18445,
  [20891] = 18923,
  [20892] = 18561,
  [20893] = 18945,
  [20894] = 19450,
  [20895] = 18444,
  [20896] = 19484,
  [20897] = 19487,
  [20898] = 19488,
  [20899] = 18453,
  [20900] = 18444,
  [20901] = 18445,
  [20902] = 18521,
  [20903] = 18443,
  [20904] = 18432,
  [20905] = 18426,
  [20906] = 18459,
  [20907] = 18432,
  [20908] = 18426,
  [20909] = 19450,
  [20910] = 18446,
  [20911] = 19484,
  [20912] = 19487,
  [20913] = 19488,
  [20914] = 18447,
  [20915] = 19012,
  [20916] = 18489,
  [20917] = 18461,
  [20918] = 18460,
  [20919] = 18460,
  [20920] = 18471,
  [20921] = 18472,
  [20922] = 18579,
  [20923] = 18449,
  [20924] = 19450,
  [20925] = 18441,
  [20926] = 19484,
  [20927] = 19487,
  [20928] = 19488,
  [20929] = 18441,
  [20930] = 18448,
  [20931] = 18512,
  [20932] = 18425,
  [20933] = 18465,
  [20934] = 18923,
  [20935] = 18945,
  [20936] = 18453,
  [20937] = 18561,
  [20938] = 18503,
  [20939] = 19450,
  [20940] = 18435,
  [20941] = 19484,
  [20942] = 19487,
  [20943] = 19488,
  [20944] = 18506,
  [20945] = 18493,
  [20946] = 20145,
  [20947] = 18587,
  [20948] = 18445,
  [20949] = 18462,
  [20950] = 18433,
  [20951] = 18483,
  [20952] = 18478,
  [20953] = 18554,
  [20954] = 19450,
  [20955] = 18509,
  [20956] = 19484,
  [20957] = 19487,
  [20958] = 19488,
  [20959] = 19575,
  [20960] = 18427,
  [20961] = 18689,
  [20962] = 18512,
  [20963] = 18478,
  [20964] = 18503,
  [20965] = 18506,
  [20966] = 18509,
  [20967] = 18489,
  [20968] = 18489,
  [20969] = 19450,
  [20970] = 18470,
  [20971] = 19484,
  [20972] = 19487,
  [20973] = 19488,
  [20974] = 18437,
  [20975] = 18831,
  [20976] = 18519,
  [20977] = 18636,
  [20978] = 18438,
  [20979] = 18479,
  [20980] = 19107,
  [20981] = 18479,
  [20982] = 18587,
  [20983] = 18556,
  [20984] = 19450,
  [20985] = 18432,
  [20986] = 19484,
  [20987] = 19487,
  [20988] = 19488,
  [20989] = 18983,
  [20990] = 18440,
  [20991] = 18556,
  [20992] = 18476,
  [20993] = 18471,
  [20994] = 18460,
  [20995] = 18704,
  [20996] = 18456,
  [20997] = 18556,
  [20998] = 18449,
  [20999] = 19450,
  [21000] = 18689,
  [21001] = 19484,
  [21002] = 19487,
  [21003] = 19488,
  [21004] = 18425,
  [21005] = 19138,
  [21006] = 19141,
  [21007] = 18460,
  [21008] = 18460,
  [21009] = 18645,
  [21010] = 18501,
  [21011] = 18448,
  [21012] = 18470,
  [21013] = 19012,
  [21014] = 19450,
  [21015] = 18433,
  [21016] = 19484,
  [21017] = 19487,
  [21018] = 19488,
  [21019] = 18425,
  [21020] = 18453,
  [21021] = 18444,
  [21022] = 18445,
  [21023] = 18500,
  [21024] = 18433,
  [21025] = 18432,
  [21026] = 18426,
  [21027] = 18472,
  [21028] = 18483,
  [21029] = 18484,
  [21030] = 19484,
  [21031] = 19487,
  [21032] = 19488,
  [21033] = 18485,
  [21034] = 18441,
  [21035] = 18486,
  [21036] = 18449,
  [21037] = 18470,
  [21038] = 18429,
  [21039] = 18462,
  [21040] = 18471,
  [21041] = 18425,
  [21042] = 18456,
  [21043] = 18433,
  [21044] = 19484,
  [21045] = 19487,
  [21046] = 19488,
  [21047] = 18472,
  [21048] = 19966,
  [21049] = 18471,
  [21050] = 18521,
  [21051] = 19012,
  [21052] = 18454,
  [21053] = 18475,
  [21054] = 18512,
  [21055] = 18493,
  [21056] = 19966,
  [21057] = 18592,
  [21058] = 19484,
  [21059] = 19487,
  [21060] = 19488,
  [21061] = 18437,
  [21062] = 18882,
  [21063] = 18503,
  [21064] = 18456,
  [21065] = 18425,
  [21066] = 18506,
  [21067] = 18433,
  [21068] = 18445,
  [21069] = 18448,
  [21070] = 18468,
  [21071] = 18459,
  [21072] = 19484,
  [21073] = 19487,
  [21074] = 19488,
  [21075] = 18438,
  [21076] = 18509,
  [21077] = 20781,
  [21078] = 18489,
  [21079] = 18431,
  [21080] = 18461,
  [21081] = 18429,
  [21082] = 18561,
  [21083] = 18449,
  [21084] = 19484,
  [21085] = 19487,
  [21086] = 19488,
  [21087] = 18453,
  [21088] = 18465,
  [21089] = 18426,
  [21090] = 21090,
  [21091] = 18509,
  [21092] = 18468,
  [21093] = 18501,
  [21094] = 18489,
  [21095] = 18454,
  [21096] = 19484,
  [21097] = 19487,
  [21098] = 19488,
  [21099] = 18512,
  [21100] = 18431,
  [21101] = 19484,
  [21102] = 19487,
  [21103] = 19488,
  [21104] = 18445,
  [21105] = 18432,
  [21106] = 19484,
  [21107] = 19487,
  [21108] = 19488,
  [21109] = 18503,
  [21110] = 18426,
  [21111] = 19484,
  [21112] = 19487,
  [21113] = 19488,
  [21114] = 18427,
  [21115] = 18429,
  [21116] = 19484,
  [21117] = 19487,
  [21118] = 19488,
  [21119] = 18456,
  [21120] = 18479,
  [21121] = 19484,
  [21122] = 19487,
  [21123] = 19488,
  [21124] = 18441,
  [21125] = 18460,
  [21126] = 19484,
  [21127] = 19487,
  [21128] = 19488,
  [21129] = 18449,
  [21130] = 18472,
  [21131] = 19484,
  [21132] = 19487,
  [21133] = 19488,
  [21134] = 18434,
  [21135] = 18493,
  [21136] = 19484,
  [21137] = 19487,
  [21138] = 19488,
  [21139] = 18430,
  [21140] = 18536,
  [21141] = 19484,
  [21142] = 19487,
  [21143] = 19488,
  [21144] = 18506,
  [21145] = 18425,
  [21146] = 19484,
  [21147] = 19487,
  [21148] = 19488,
  [21149] = 18440,
  [21150] = 18501,
  [21151] = 19484,
  [21152] = 19487,
  [21153] = 19488,
  [21154] = 18445,
  [21155] = 18432,
  [21156] = 19484,
  [21157] = 19487,
  [21158] = 19488,
  [21159] = 18509,
  [21160] = 18433,
  [21161] = 18685,
  [21162] = 18512,
  [21163] = 18426,
  [21164] = 18489,
  [21165] = 18449,
  [21166] = 18439,
  [21167] = 18503,
  [21168] = 18441,
  [21169] = 18432,
  [21170] = 18512,
  [21171] = 18425,
  [21172] = 18472,
  [21173] = 18449,
  [21174] = 18443,
  [21175] = 18506,
  [21176] = 18433,
  [21177] = 18503,
  [21178] = 18506,
  [21179] = 18509,
  [21180] = 18509,
  [21181] = 18489,
  [21182] = 18521,
  [21183] = 18489,
  [21184] = 18445,
  [21185] = 18476,
  [21186] = 18478,
  [21187] = 18446,
  [21188] = 18447,
  [21189] = 20781,
  [21190] = 18831,
  [21191] = 20135,
  [21192] = 19391,
  [21193] = 18501,
  [21194] = 18449,
  [21195] = 18435,
  [21196] = 18633,
  [21197] = 18478,
  [21198] = 18561,
  [21199] = 18437,
  [21200] = 18485,
  [21201] = 18556,
  [21202] = 18437,
  [21203] = 18438,
  [21204] = 18426,
  [21205] = 18438,
  [21206] = 18456,
  [21207] = 18440,
  [21208] = 18440,
  [21209] = 18493,
  [21210] = 21210,
  [21211] = 18478,
  [21212] = 18522,
  [21213] = 18430,
  [21214] = 20412,
  [21215] = 18427,
  [21216] = 18429,
  [21217] = 20421,
  [21218] = 18430,
  [21219] = 18503,
  [21220] = 18435,
  [21221] = 18519,
  [21222] = 18437,
  [21223] = 18438,
  [21224] = 18803,
  [21225] = 18831,
  [21226] = 20135,
  [21227] = 18440,
  [21228] = 18500,
  [21229] = 18433,
  [21230] = 18587,
  [21231] = 18454,
  [21232] = 18636,
  [21233] = 18459,
  [21234] = 18501,
  [21235] = 18479,
  [21236] = 19107,
  [21237] = 18500,
  [21238] = 18445,
  [21239] = 18461,
  [21240] = 18449,
  [21241] = 20135,
  [21242] = 18432,
  [21243] = 18427,
  [21244] = 18460,
  [21245] = 18460,
  [21246] = 18465,
  [21247] = 18905,
  [21248] = 18441,
  [21249] = 18500,
  [21250] = 18456,
  [21251] = 18429,
  [21252] = 20135,
  [21253] = 18441,
  [21254] = 18500,
  [21255] = 18449,
  [21256] = 18501,
  [21257] = 18427,
  [21258] = 18429,
  [21259] = 20135,
  [21260] = 20135,
  [21261] = 20135,
  [21262] = 20135,
  [21263] = 20135,
  [21264] = 20135,
  [21265] = 20135,
  [21266] = 20135,
  [21267] = 20135,
  [21268] = 20135,
  [21269] = 20135,
  [21270] = 20135,
  [21271] = 20135,
  [21272] = 20135,
  [21273] = 20135,
  [21274] = 20135,
  [21275] = 20135,
  [21276] = 20135,
  [21277] = 20135,
  [21278] = 20135,
  [21279] = 20135,
  [21280] = 20135,
  [21281] = 20135,
  [21282] = 20135,
  [21283] = 20135,
  [21284] = 20135,
  [21285] = 20135,
  [21286] = 20135,
  [21287] = 20135,
  [21288] = 20135,
  [21289] = 20135,
  [21290] = 20135,
  [21291] = 20135,
  [21292] = 20135,
  [21293] = 20135,
  [21294] = 20135,
  [21295] = 20135,
  [21296] = 20135,
  [21297] = 20135,
  [21298] = 20135,
  [21299] = 20135,
  [21300] = 20135,
  [21301] = 20135,
  [21302] = 20135,
  [21303] = 20135,
  [21304] = 20135,
  [21305] = 20135,
  [21306] = 20135,
  [21307] = 20135,
  [21308] = 20135,
  [21309] = 20135,
  [21310] = 18470,
  [21311] = 18430,
  [21312] = 21312,
  [21313] = 18561,
  [21314] = 18471,
  [21315] = 18435,
  [21316] = 18472,
  [21317] = 19489,
  [21318] = 21318,
  [21319] = 18426,
  [21320] = 18435,
  [21321] = 18633,
  [21322] = 20782,
  [21323] = 18592,
  [21324] = 18483,
  [21325] = 18470,
  [21326] = 18484,
  [21327] = 18485,
  [21328] = 18486,
  [21329] = 18521,
  [21330] = 18471,
  [21331] = 18472,
  [21332] = 18462,
  [21333] = 18468,
  [21334] = 18448,
  [21335] = 18453,
  [21336] = 18425,
  [21337] = 18437,
  [21338] = 19489,
  [21339] = 18438,
  [21340] = 20782,
  [21341] = 19489,
  [21342] = 20782,
  [21343] = 18440,
  [21344] = 18831,
  [21345] = 18556,
  [21346] = 18456,
  [21347] = 18476,
  [21348] = 21210,
  [21349] = 18470,
  [21350] = 18433,
  [21351] = 18521,
  [21352] = 18512,
  [21353] = 18503,
  [21354] = 19012,
  [21355] = 18430,
  [21356] = 18437,
  [21357] = 18501,
  [21358] = 18478,
  [21359] = 18506,
  [21360] = 18460,
  [21361] = 5468,
  [21362] = 20391,
  [21363] = 18587,
  [21364] = 18454,
  [21365] = 18509,
  [21366] = 21366,
  [21367] = 18483,
  [21368] = 18489,
  [21369] = 18427,
  [21370] = 18633,
  [21371] = 18429,
  [21372] = 18484,
  [21373] = 18485,
  [21374] = 18556,
  [21375] = 18486,
  [21376] = 18430,
  [21377] = 18479,
  [21378] = 18435,
  [21379] = 18471,
  [21380] = 18462,
  [21381] = 18921,
  [21382] = 18460,
  [21383] = 18454,
  [21384] = 19138,
  [21385] = 18425,
  [21386] = 18433,
  [21387] = 18500,
  [21388] = 19141,
  [21389] = 18437,
  [21390] = 18438,
  [21391] = 18441,
  [21392] = 18438,
  [21393] = 21393,
  [21394] = 19153,
  [21395] = 18445,
  [21396] = 18501,
  [21397] = 18440,
  [21398] = 18468,
  [21399] = 18501,
  [21400] = 19153,
  [21401] = 18437,
  [21402] = 18456,
  [21403] = 18818,
  [21404] = 18438,
  [21405] = 18462,
  [21406] = 18818,
  [21407] = 18440,
  [21408] = 18448,
  [21409] = 18453,
  [21410] = 18445,
  [21411] = 18461,
  [21412] = 18432,
  [21413] = 18923,
  [21414] = 18454,
  [21415] = 18472,
  [21416] = 18945,
  [21417] = 18831,
  [21418] = 21418,
  [21419] = 21419,
};

static TSCharacterRange sym_conversion_specification_character_set_6[] = {
  {'!', '!'}, {'%', '%'}, {',', ','}, {'@', '@'}, {'B', 'C'}, {'E', 'H'}, {'L', 'L'}, {'N', 'N'},
  {'S', 'S'}, {'X', 'X'}, {'a', 'i'}, {'l', 'l'}, {'n', 'o'}, {'s', 'u'}, {'x', 'x'},
};

static TSCharacterRange sym_conversion_specification_character_set_7[] = {
  {'!', '!'}, {'%', '%'}, {',', ','}, {'0', '9'}, {'@', '@'}, {'B', 'C'}, {'E', 'H'}, {'L', 'L'},
  {'N', 'N'}, {'S', 'S'}, {'X', 'X'}, {'a', 'i'}, {'l', 'l'}, {'n', 'o'}, {'s', 'u'}, {'x', 'x'},
};

static TSCharacterRange sym_prefix_operator_character_set_1[] = {
  {'!', '!'}, {'#', '&'}, {'*', '+'}, {'-', '/'}, {':', ':'}, {'<', '@'}, {'^', '^'}, {'|', '|'},
  {'~', '~'},
};

static TSCharacterRange sym_pow_operator_character_set_1[] = {
  {'!', '!'}, {'$', '&'}, {'*', '+'}, {'-', '/'}, {':', ':'}, {'<', '@'}, {'^', '^'}, {'|', '|'},
  {'~', '~'},
};

static TSCharacterRange sym_indexing_operator_character_set_1[] = {
  {'!', '!'}, {'$', '&'}, {'*', '+'}, {'-', '-'}, {'/', '/'}, {':', ':'}, {'=', '@'}, {'^', '^'},
  {'|', '|'},
};

static TSCharacterRange sym_let_operator_character_set_1[] = {
  {'$', '$'}, {'&', '&'}, {'*', '+'}, {'-', '-'}, {'/', '/'}, {'<', '>'}, {'@', '@'}, {'^', '^'},
  {'|', '|'},
};

static TSCharacterRange sym__lowercase_identifier_character_set_2[] = {
  {'\'', '\''}, {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xb7, 0xb7},
  {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee},
  {0x300, 0x374}, {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd}, {0x5bf, 0x5bf},
  {0x5c1, 0x5c2}, {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669}, {0x66e, 0x6d3},
  {0x6d5, 0x6dc}, {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5}, {0x7fa, 0x7fa},
  {0x7fd, 0x7fd}, {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1}, {0x8e3, 0x963},
  {0x966, 0x96f}, {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bc, 0x9c4}, {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1}, {0x9fc, 0x9fc},
  {0x9fe, 0x9fe}, {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36},
  {0xa38, 0xa39}, {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa66, 0xa75}, {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabc, 0xac5}, {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff}, {0xb01, 0xb03},
  {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44}, {0xb47, 0xb48},
  {0xb4b, 0xb4d}, {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbbe, 0xbc2}, {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c}, {0xc0e, 0xc10},
  {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc63}, {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9},
  {0xcbc, 0xcc4}, {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef}, {0xcf1, 0xcf3},
  {0xd00, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63}, {0xd66, 0xd6f},
  {0xd7a, 0xd7f}, {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xdca, 0xdca},
  {0xdcf, 0xdd4}, {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e}, {0xe50, 0xe59},
  {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6},
  {0xec8, 0xece}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35}, {0xf37, 0xf37},
  {0xf39, 0xf39}, {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6}, {0x1000, 0x1049},
  {0x1050, 0x109d}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1715},
  {0x171f, 0x1734}, {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dd},
  {0x17e0, 0x17e9}, {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1920, 0x192b},
  {0x1930, 0x193b}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b}, {0x1a20, 0x1a5e},
  {0x1a60, 0x1a7c}, {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c}, {0x1b50, 0x1b59},
  {0x1b6b, 0x1b73}, {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf},
  {0x1cd0, 0x1cd2}, {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2054, 0x2054},
  {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107},
  {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f},
  {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d},
  {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6},
  {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c},
  {0x3041, 0x3096}, {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff},
  {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d}, {0xa67f, 0xa6f1},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827}, {0xa82c, 0xa82c},
  {0xa840, 0xa873}, {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953}, {0xa960, 0xa97c},
  {0xa980, 0xa9c0}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaac2},
  {0xaadb, 0xaadd}, {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e},
  {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb},
  {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e},
  {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9},
  {0xfe00, 0xfe0f}, {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79},
  {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a}, {0xff65, 0xffbe},
  {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d},
  {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x102e0, 0x102e0},
  {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d},
  {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592},
  {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767},
  {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c},
  {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7},
  {0x109be, 0x109bf}, {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f},
  {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91},
  {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1},
  {0x10efd, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075},
  {0x1107f, 0x110ba}, {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173},
  {0x11176, 0x11176}, {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241},
  {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303},
  {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348},
  {0x1134b, 0x1134d}, {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a}, {0x11450, 0x11459},
  {0x1145e, 0x11461}, {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640},
  {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739}, {0x11740, 0x11746},
  {0x11800, 0x1183a}, {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935}, {0x11937, 0x11938},
  {0x1193b, 0x11943}, {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e}, {0x11a47, 0x11a47},
  {0x11a50, 0x11a99}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f},
  {0x11c92, 0x11ca7}, {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47},
  {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6},
  {0x11f00, 0x11f10}, {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f59}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543},
  {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe},
  {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f},
  {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7},
  {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152},
  {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e},
  {0x1cf00, 0x1cf2d}, {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244},
  {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb},
  {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544},
  {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734},
  {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36},
  {0x1da3b, 0x1da6c}, {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006},
  {0x1e008, 0x1e018}, {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee},
  {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22},
  {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47},
  {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b},
  {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c},
  {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df},
  {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
  {0xe0100, 0xe01ef},
};

static TSCharacterRange sym__lowercase_identifier_character_set_3[] = {
  {'_', '_'}, {'a', 'z'}, {0xb5, 0xb5}, {0xdf, 0xf6}, {0xf8, 0xff}, {0x101, 0x101}, {0x103, 0x103}, {0x105, 0x105},
  {0x107, 0x107}, {0x109, 0x109}, {0x10b, 0x10b}, {0x10d, 0x10d}, {0x10f, 0x10f}, {0x111, 0x111}, {0x113, 0x113}, {0x115, 0x115},
  {0x117, 0x117}, {0x119, 0x119}, {0x11b, 0x11b}, {0x11d, 0x11d}, {0x11f, 0x11f}, {0x121, 0x121}, {0x123, 0x123}, {0x125, 0x125},
  {0x127, 0x127}, {0x129, 0x129}, {0x12b, 0x12b}, {0x12d, 0x12d}, {0x12f, 0x12f}, {0x131, 0x131}, {0x133, 0x133}, {0x135, 0x135},
  {0x137, 0x138}, {0x13a, 0x13a}, {0x13c, 0x13c}, {0x13e, 0x13e}, {0x140, 0x140}, {0x142, 0x142}, {0x144, 0x144}, {0x146, 0x146},
  {0x148, 0x149}, {0x14b, 0x14b}, {0x14d, 0x14d}, {0x14f, 0x14f}, {0x151, 0x151}, {0x153, 0x153}, {0x155, 0x155}, {0x157, 0x157},
  {0x159, 0x159}, {0x15b, 0x15b}, {0x15d, 0x15d}, {0x15f, 0x15f}, {0x161, 0x161}, {0x163, 0x163}, {0x165, 0x165}, {0x167, 0x167},
  {0x169, 0x169}, {0x16b, 0x16b}, {0x16d, 0x16d}, {0x16f, 0x16f}, {0x171, 0x171}, {0x173, 0x173}, {0x175, 0x175}, {0x177, 0x177},
  {0x17a, 0x17a}, {0x17c, 0x17c}, {0x17e, 0x180}, {0x183, 0x183}, {0x185, 0x185}, {0x188, 0x188}, {0x18c, 0x18d}, {0x192, 0x192},
  {0x195, 0x195}, {0x199, 0x19b}, {0x19e, 0x19e}, {0x1a1, 0x1a1}, {0x1a3, 0x1a3}, {0x1a5, 0x1a5}, {0x1a8, 0x1a8}, {0x1aa, 0x1ab},
  {0x1ad, 0x1ad}, {0x1b0, 0x1b0}, {0x1b4, 0x1b4}, {0x1b6, 0x1b6}, {0x1b9, 0x1ba}, {0x1bd, 0x1bf}, {0x1c6, 0x1c6}, {0x1c9, 0x1c9},
  {0x1cc, 0x1cc}, {0x1ce, 0x1ce}, {0x1d0, 0x1d0}, {0x1d2, 0x1d2}, {0x1d4, 0x1d4}, {0x1d6, 0x1d6}, {0x1d8, 0x1d8}, {0x1da, 0x1da},
  {0x1dc, 0x1dd}, {0x1df, 0x1df}, {0x1e1, 0x1e1}, {0x1e3, 0x1e3}, {0x1e5, 0x1e5}, {0x1e7, 0x1e7}, {0x1e9, 0x1e9}, {0x1eb, 0x1eb},
  {0x1ed, 0x1ed}, {0x1ef, 0x1f0}, {0x1f3, 0x1f3}, {0x1f5, 0x1f5}, {0x1f9, 0x1f9}, {0x1fb, 0x1fb}, {0x1fd, 0x1fd}, {0x1ff, 0x1ff},
  {0x201, 0x201}, {0x203, 0x203}, {0x205, 0x205}, {0x207, 0x207}, {0x209, 0x209}, {0x20b, 0x20b}, {0x20d, 0x20d}, {0x20f, 0x20f},
  {0x211, 0x211}, {0x213, 0x213}, {0x215, 0x215}, {0x217, 0x217}, {0x219, 0x219}, {0x21b, 0x21b}, {0x21d, 0x21d}, {0x21f, 0x21f},
  {0x221, 0x221}, {0x223, 0x223}, {0x225, 0x225}, {0x227, 0x227}, {0x229, 0x229}, {0x22b, 0x22b}, {0x22d, 0x22d}, {0x22f, 0x22f},
  {0x231, 0x231}, {0x233, 0x239}, {0x23c, 0x23c}, {0x23f, 0x240}, {0x242, 0x242}, {0x247, 0x247}, {0x249, 0x249}, {0x24b, 0x24b},
  {0x24d, 0x24d}, {0x24f, 0x293}, {0x295, 0x2af}, {0x371, 0x371}, {0x373, 0x373}, {0x377, 0x377}, {0x37b, 0x37d}, {0x390, 0x390},
  {0x3ac, 0x3ce}, {0x3d0, 0x3d1}, {0x3d5, 0x3d7}, {0x3d9, 0x3d9}, {0x3db, 0x3db}, {0x3dd, 0x3dd}, {0x3df, 0x3df}, {0x3e1, 0x3e1},
  {0x3e3, 0x3e3}, {0x3e5, 0x3e5}, {0x3e7, 0x3e7}, {0x3e9, 0x3e9}, {0x3eb, 0x3eb}, {0x3ed, 0x3ed}, {0x3ef, 0x3f3}, {0x3f5, 0x3f5},
  {0x3f8, 0x3f8}, {0x3fb, 0x3fc}, {0x430, 0x45f}, {0x461, 0x461}, {0x463, 0x463}, {0x465, 0x465}, {0x467, 0x467}, {0x469, 0x469},
  {0x46b, 0x46b}, {0x46d, 0x46d}, {0x46f, 0x46f}, {0x471, 0x471}, {0x473, 0x473}, {0x475, 0x475}, {0x477, 0x477}, {0x479, 0x479},
  {0x47b, 0x47b}, {0x47d, 0x47d}, {0x47f, 0x47f}, {0x481, 0x481}, {0x48b, 0x48b}, {0x48d, 0x48d}, {0x48f, 0x48f}, {0x491, 0x491},
  {0x493, 0x493}, {0x495, 0x495}, {0x497, 0x497}, {0x499, 0x499}, {0x49b, 0x49b}, {0x49d, 0x49d}, {0x49f, 0x49f}, {0x4a1, 0x4a1},
  {0x4a3, 0x4a3}, {0x4a5, 0x4a5}, {0x4a7, 0x4a7}, {0x4a9, 0x4a9}, {0x4ab, 0x4ab}, {0x4ad, 0x4ad}, {0x4af, 0x4af}, {0x4b1, 0x4b1},
  {0x4b3, 0x4b3}, {0x4b5, 0x4b5}, {0x4b7, 0x4b7}, {0x4b9, 0x4b9}, {0x4bb, 0x4bb}, {0x4bd, 0x4bd}, {0x4bf, 0x4bf}, {0x4c2, 0x4c2},
  {0x4c4, 0x4c4}, {0x4c6, 0x4c6}, {0x4c8, 0x4c8}, {0x4ca, 0x4ca}, {0x4cc, 0x4cc}, {0x4ce, 0x4cf}, {0x4d1, 0x4d1}, {0x4d3, 0x4d3},
  {0x4d5, 0x4d5}, {0x4d7, 0x4d7}, {0x4d9, 0x4d9}, {0x4db, 0x4db}, {0x4dd, 0x4dd}, {0x4df, 0x4df}, {0x4e1, 0x4e1}, {0x4e3, 0x4e3},
  {0x4e5, 0x4e5}, {0x4e7, 0x4e7}, {0x4e9, 0x4e9}, {0x4eb, 0x4eb}, {0x4ed, 0x4ed}, {0x4ef, 0x4ef}, {0x4f1, 0x4f1}, {0x4f3, 0x4f3},
  {0x4f5, 0x4f5}, {0x4f7, 0x4f7}, {0x4f9, 0x4f9}, {0x4fb, 0x4fb}, {0x4fd, 0x4fd}, {0x4ff, 0x4ff}, {0x501, 0x501}, {0x503, 0x503},
  {0x505, 0x505}, {0x507, 0x507}, {0x509, 0x509}, {0x50b, 0x50b}, {0x50d, 0x50d}, {0x50f, 0x50f}, {0x511, 0x511}, {0x513, 0x513},
  {0x515, 0x515}, {0x517, 0x517}, {0x519, 0x519}, {0x51b, 0x51b}, {0x51d, 0x51d}, {0x51f, 0x51f}, {0x521, 0x521}, {0x523, 0x523},
  {0x525, 0x525}, {0x527, 0x527}, {0x529, 0x529}, {0x52b, 0x52b}, {0x52d, 0x52d}, {0x52f, 0x52f}, {0x560, 0x588}, {0x10d0, 0x10fa},
  {0x10fd, 0x10ff}, {0x13f8, 0x13fd}, {0x1c80, 0x1c88}, {0x1d00, 0x1d2b}, {0x1d6b, 0x1d77}, {0x1d79, 0x1d9a}, {0x1e01, 0x1e01}, {0x1e03, 0x1e03},
  {0x1e05, 0x1e05}, {0x1e07, 0x1e07}, {0x1e09, 0x1e09}, {0x1e0b, 0x1e0b}, {0x1e0d, 0x1e0d}, {0x1e0f, 0x1e0f}, {0x1e11, 0x1e11}, {0x1e13, 0x1e13},
  {0x1e15, 0x1e15}, {0x1e17, 0x1e17}, {0x1e19, 0x1e19}, {0x1e1b, 0x1e1b}, {0x1e1d, 0x1e1d}, {0x1e1f, 0x1e1f}, {0x1e21, 0x1e21}, {0x1e23, 0x1e23},
  {0x1e25, 0x1e25}, {0x1e27, 0x1e27}, {0x1e29, 0x1e29}, {0x1e2b, 0x1e2b}, {0x1e2d, 0x1e2d}, {0x1e2f, 0x1e2f}, {0x1e31, 0x1e31}, {0x1e33, 0x1e33},
  {0x1e35, 0x1e35}, {0x1e37, 0x1e37}, {0x1e39, 0x1e39}, {0x1e3b, 0x1e3b}, {0x1e3d, 0x1e3d}, {0x1e3f, 0x1e3f}, {0x1e41, 0x1e41}, {0x1e43, 0x1e43},
  {0x1e45, 0x1e45}, {0x1e47, 0x1e47}, {0x1e49, 0x1e49}, {0x1e4b, 0x1e4b}, {0x1e4d, 0x1e4d}, {0x1e4f, 0x1e4f}, {0x1e51, 0x1e51}, {0x1e53, 0x1e53},
  {0x1e55, 0x1e55}, {0x1e57, 0x1e57}, {0x1e59, 0x1e59}, {0x1e5b, 0x1e5b}, {0x1e5d, 0x1e5d}, {0x1e5f, 0x1e5f}, {0x1e61, 0x1e61}, {0x1e63, 0x1e63},
  {0x1e65, 0x1e65}, {0x1e67, 0x1e67}, {0x1e69, 0x1e69}, {0x1e6b, 0x1e6b}, {0x1e6d, 0x1e6d}, {0x1e6f, 0x1e6f}, {0x1e71, 0x1e71}, {0x1e73, 0x1e73},
  {0x1e75, 0x1e75}, {0x1e77, 0x1e77}, {0x1e79, 0x1e79}, {0x1e7b, 0x1e7b}, {0x1e7d, 0x1e7d}, {0x1e7f, 0x1e7f}, {0x1e81, 0x1e81}, {0x1e83, 0x1e83},
  {0x1e85, 0x1e85}, {0x1e87, 0x1e87}, {0x1e89, 0x1e89}, {0x1e8b, 0x1e8b}, {0x1e8d, 0x1e8d}, {0x1e8f, 0x1e8f}, {0x1e91, 0x1e91}, {0x1e93, 0x1e93},
  {0x1e95, 0x1e9d}, {0x1e9f, 0x1e9f}, {0x1ea1, 0x1ea1}, {0x1ea3, 0x1ea3}, {0x1ea5, 0x1ea5}, {0x1ea7, 0x1ea7}, {0x1ea9, 0x1ea9}, {0x1eab, 0x1eab},
  {0x1ead, 0x1ead}, {0x1eaf, 0x1eaf}, {0x1eb1, 0x1eb1}, {0x1eb3, 0x1eb3}, {0x1eb5, 0x1eb5}, {0x1eb7, 0x1eb7}, {0x1eb9, 0x1eb9}, {0x1ebb, 0x1ebb},
  {0x1ebd, 0x1ebd}, {0x1ebf, 0x1ebf}, {0x1ec1, 0x1ec1}, {0x1ec3, 0x1ec3}, {0x1ec5, 0x1ec5}, {0x1ec7, 0x1ec7}, {0x1ec9, 0x1ec9}, {0x1ecb, 0x1ecb},
  {0x1ecd, 0x1ecd}, {0x1ecf, 0x1ecf}, {0x1ed1, 0x1ed1}, {0x1ed3, 0x1ed3}, {0x1ed5, 0x1ed5}, {0x1ed7, 0x1ed7}, {0x1ed9, 0x1ed9}, {0x1edb, 0x1edb},
  {0x1edd, 0x1edd}, {0x1edf, 0x1edf}, {0x1ee1, 0x1ee1}, {0x1ee3, 0x1ee3}, {0x1ee5, 0x1ee5}, {0x1ee7, 0x1ee7}, {0x1ee9, 0x1ee9}, {0x1eeb, 0x1eeb},
  {0x1eed, 0x1eed}, {0x1eef, 0x1eef}, {0x1ef1, 0x1ef1}, {0x1ef3, 0x1ef3}, {0x1ef5, 0x1ef5}, {0x1ef7, 0x1ef7}, {0x1ef9, 0x1ef9}, {0x1efb, 0x1efb},
  {0x1efd, 0x1efd}, {0x1eff, 0x1f07}, {0x1f10, 0x1f15}, {0x1f20, 0x1f27}, {0x1f30, 0x1f37}, {0x1f40, 0x1f45}, {0x1f50, 0x1f57}, {0x1f60, 0x1f67},
  {0x1f70, 0x1f7d}, {0x1f80, 0x1f87}, {0x1f90, 0x1f97}, {0x1fa0, 0x1fa7}, {0x1fb0, 0x1fb4}, {0x1fb6, 0x1fb7}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fc7}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fd7}, {0x1fe0, 0x1fe7}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ff7}, {0x210a, 0x210a}, {0x210e, 0x210f},
  {0x2113, 0x2113}, {0x212f, 0x212f}, {0x2134, 0x2134}, {0x2139, 0x2139}, {0x213c, 0x213d}, {0x2146, 0x2149}, {0x214e, 0x214e}, {0x2184, 0x2184},
  {0x2c30, 0x2c5f}, {0x2c61, 0x2c61}, {0x2c65, 0x2c66}, {0x2c68, 0x2c68}, {0x2c6a, 0x2c6a}, {0x2c6c, 0x2c6c}, {0x2c71, 0x2c71}, {0x2c73, 0x2c74},
  {0x2c76, 0x2c7b}, {0x2c81, 0x2c81}, {0x2c83, 0x2c83}, {0x2c85, 0x2c85}, {0x2c87, 0x2c87}, {0x2c89, 0x2c89}, {0x2c8b, 0x2c8b}, {0x2c8d, 0x2c8d},
  {0x2c8f, 0x2c8f}, {0x2c91, 0x2c91}, {0x2c93, 0x2c93}, {0x2c95, 0x2c95}, {0x2c97, 0x2c97}, {0x2c99, 0x2c99}, {0x2c9b, 0x2c9b}, {0x2c9d, 0x2c9d},
  {0x2c9f, 0x2c9f}, {0x2ca1, 0x2ca1}, {0x2ca3, 0x2ca3}, {0x2ca5, 0x2ca5}, {0x2ca7, 0x2ca7}, {0x2ca9, 0x2ca9}, {0x2cab, 0x2cab}, {0x2cad, 0x2cad},
  {0x2caf, 0x2caf}, {0x2cb1, 0x2cb1}, {0x2cb3, 0x2cb3}, {0x2cb5, 0x2cb5}, {0x2cb7, 0x2cb7}, {0x2cb9, 0x2cb9}, {0x2cbb, 0x2cbb}, {0x2cbd, 0x2cbd},
  {0x2cbf, 0x2cbf}, {0x2cc1, 0x2cc1}, {0x2cc3, 0x2cc3}, {0x2cc5, 0x2cc5}, {0x2cc7, 0x2cc7}, {0x2cc9, 0x2cc9}, {0x2ccb, 0x2ccb}, {0x2ccd, 0x2ccd},
  {0x2ccf, 0x2ccf}, {0x2cd1, 0x2cd1}, {0x2cd3, 0x2cd3}, {0x2cd5, 0x2cd5}, {0x2cd7, 0x2cd7}, {0x2cd9, 0x2cd9}, {0x2cdb, 0x2cdb}, {0x2cdd, 0x2cdd},
  {0x2cdf, 0x2cdf}, {0x2ce1, 0x2ce1}, {0x2ce3, 0x2ce4}, {0x2cec, 0x2cec}, {0x2cee, 0x2cee}, {0x2cf3, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27},
  {0x2d2d, 0x2d2d}, {0xa641, 0xa641}, {0xa643, 0xa643}, {0xa645, 0xa645}, {0xa647, 0xa647}, {0xa649, 0xa649}, {0xa64b, 0xa64b}, {0xa64d, 0xa64d},
  {0xa64f, 0xa64f}, {0xa651, 0xa651}, {0xa653, 0xa653}, {0xa655, 0xa655}, {0xa657, 0xa657}, {0xa659, 0xa659}, {0xa65b, 0xa65b}, {0xa65d, 0xa65d},
  {0xa65f, 0xa65f}, {0xa661, 0xa661}, {0xa663, 0xa663}, {0xa665, 0xa665}, {0xa667, 0xa667}, {0xa669, 0xa669}, {0xa66b, 0xa66b}, {0xa66d, 0xa66d},
  {0xa681, 0xa681}, {0xa683, 0xa683}, {0xa685, 0xa685}, {0xa687, 0xa687}, {0xa689, 0xa689}, {0xa68b, 0xa68b}, {0xa68d, 0xa68d}, {0xa68f, 0xa68f},
  {0xa691, 0xa691}, {0xa693, 0xa693}, {0xa695, 0xa695}, {0xa697, 0xa697}, {0xa699, 0xa699}, {0xa69b, 0xa69b}, {0xa723, 0xa723}, {0xa725, 0xa725},
  {0xa727, 0xa727}, {0xa729, 0xa729}, {0xa72b, 0xa72b}, {0xa72d, 0xa72d}, {0xa72f, 0xa731}, {0xa733, 0xa733}, {0xa735, 0xa735}, {0xa737, 0xa737},
  {0xa739, 0xa739}, {0xa73b, 0xa73b}, {0xa73d, 0xa73d}, {0xa73f, 0xa73f}, {0xa741, 0xa741}, {0xa743, 0xa743}, {0xa745, 0xa745}, {0xa747, 0xa747},
  {0xa749, 0xa749}, {0xa74b, 0xa74b}, {0xa74d, 0xa74d}, {0xa74f, 0xa74f}, {0xa751, 0xa751}, {0xa753, 0xa753}, {0xa755, 0xa755}, {0xa757, 0xa757},
  {0xa759, 0xa759}, {0xa75b, 0xa75b}, {0xa75d, 0xa75d}, {0xa75f, 0xa75f}, {0xa761, 0xa761}, {0xa763, 0xa763}, {0xa765, 0xa765}, {0xa767, 0xa767},
  {0xa769, 0xa769}, {0xa76b, 0xa76b}, {0xa76d, 0xa76d}, {0xa76f, 0xa76f}, {0xa771, 0xa778}, {0xa77a, 0xa77a}, {0xa77c, 0xa77c}, {0xa77f, 0xa77f},
  {0xa781, 0xa781}, {0xa783, 0xa783}, {0xa785, 0xa785}, {0xa787, 0xa787}, {0xa78c, 0xa78c}, {0xa78e, 0xa78e}, {0xa791, 0xa791}, {0xa793, 0xa795},
  {0xa797, 0xa797}, {0xa799, 0xa799}, {0xa79b, 0xa79b}, {0xa79d, 0xa79d}, {0xa79f, 0xa79f}, {0xa7a1, 0xa7a1}, {0xa7a3, 0xa7a3}, {0xa7a5, 0xa7a5},
  {0xa7a7, 0xa7a7}, {0xa7a9, 0xa7a9}, {0xa7af, 0xa7af}, {0xa7b5, 0xa7b5}, {0xa7b7, 0xa7b7}, {0xa7b9, 0xa7b9}, {0xa7bb, 0xa7bb}, {0xa7bd, 0xa7bd},
  {0xa7bf, 0xa7bf}, {0xa7c1, 0xa7c1}, {0xa7c3, 0xa7c3}, {0xa7c8, 0xa7c8}, {0xa7ca, 0xa7ca}, {0xa7d1, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d5},
  {0xa7d7, 0xa7d7}, {0xa7d9, 0xa7d9}, {0xa7f6, 0xa7f6}, {0xa7fa, 0xa7fa}, {0xab30, 0xab5a}, {0xab60, 0xab68}, {0xab70, 0xabbf}, {0xfb00, 0xfb06},
  {0xfb13, 0xfb17}, {0xff41, 0xff5a}, {0x10428, 0x1044f}, {0x104d8, 0x104fb}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
};

static TSCharacterRange sym__uppercase_identifier_character_set_1[] = {
  {'A', 'Z'}, {0xc0, 0xd6}, {0xd8, 0xde}, {0x100, 0x100}, {0x102, 0x102}, {0x104, 0x104}, {0x106, 0x106}, {0x108, 0x108},
  {0x10a, 0x10a}, {0x10c, 0x10c}, {0x10e, 0x10e}, {0x110, 0x110}, {0x112, 0x112}, {0x114, 0x114}, {0x116, 0x116}, {0x118, 0x118},
  {0x11a, 0x11a}, {0x11c, 0x11c}, {0x11e, 0x11e}, {0x120, 0x120}, {0x122, 0x122}, {0x124, 0x124}, {0x126, 0x126}, {0x128, 0x128},
  {0x12a, 0x12a}, {0x12c, 0x12c}, {0x12e, 0x12e}, {0x130, 0x130}, {0x132, 0x132}, {0x134, 0x134}, {0x136, 0x136}, {0x139, 0x139},
  {0x13b, 0x13b}, {0x13d, 0x13d}, {0x13f, 0x13f}, {0x141, 0x141}, {0x143, 0x143}, {0x145, 0x145}, {0x147, 0x147}, {0x14a, 0x14a},
  {0x14c, 0x14c}, {0x14e, 0x14e}, {0x150, 0x150}, {0x152, 0x152}, {0x154, 0x154}, {0x156, 0x156}, {0x158, 0x158}, {0x15a, 0x15a},
  {0x15c, 0x15c}, {0x15e, 0x15e}, {0x160, 0x160}, {0x162, 0x162}, {0x164, 0x164}, {0x166, 0x166}, {0x168, 0x168}, {0x16a, 0x16a},
  {0x16c, 0x16c}, {0x16e, 0x16e}, {0x170, 0x170}, {0x172, 0x172}, {0x174, 0x174}, {0x176, 0x176}, {0x178, 0x179}, {0x17b, 0x17b},
  {0x17d, 0x17d}, {0x181, 0x182}, {0x184, 0x184}, {0x186, 0x187}, {0x189, 0x18b}, {0x18e, 0x191}, {0x193, 0x194}, {0x196, 0x198},
  {0x19c, 0x19d}, {0x19f, 0x1a0}, {0x1a2, 0x1a2}, {0x1a4, 0x1a4}, {0x1a6, 0x1a7}, {0x1a9, 0x1a9}, {0x1ac, 0x1ac}, {0x1ae, 0x1af},
  {0x1b1, 0x1b3}, {0x1b5, 0x1b5}, {0x1b7, 0x1b8}, {0x1bc, 0x1bc}, {0x1c4, 0x1c4}, {0x1c7, 0x1c7}, {0x1ca, 0x1ca}, {0x1cd, 0x1cd},
  {0x1cf, 0x1cf}, {0x1d1, 0x1d1}, {0x1d3, 0x1d3}, {0x1d5, 0x1d5}, {0x1d7, 0x1d7}, {0x1d9, 0x1d9}, {0x1db, 0x1db}, {0x1de, 0x1de},
  {0x1e0, 0x1e0}, {0x1e2, 0x1e2}, {0x1e4, 0x1e4}, {0x1e6, 0x1e6}, {0x1e8, 0x1e8}, {0x1ea, 0x1ea}, {0x1ec, 0x1ec}, {0x1ee, 0x1ee},
  {0x1f1, 0x1f1}, {0x1f4, 0x1f4}, {0x1f6, 0x1f8}, {0x1fa, 0x1fa}, {0x1fc, 0x1fc}, {0x1fe, 0x1fe}, {0x200, 0x200}, {0x202, 0x202},
  {0x204, 0x204}, {0x206, 0x206}, {0x208, 0x208}, {0x20a, 0x20a}, {0x20c, 0x20c}, {0x20e, 0x20e}, {0x210, 0x210}, {0x212, 0x212},
  {0x214, 0x214}, {0x216, 0x216}, {0x218, 0x218}, {0x21a, 0x21a}, {0x21c, 0x21c}, {0x21e, 0x21e}, {0x220, 0x220}, {0x222, 0x222},
  {0x224, 0x224}, {0x226, 0x226}, {0x228, 0x228}, {0x22a, 0x22a}, {0x22c, 0x22c}, {0x22e, 0x22e}, {0x230, 0x230}, {0x232, 0x232},
  {0x23a, 0x23b}, {0x23d, 0x23e}, {0x241, 0x241}, {0x243, 0x246}, {0x248, 0x248}, {0x24a, 0x24a}, {0x24c, 0x24c}, {0x24e, 0x24e},
  {0x370, 0x370}, {0x372, 0x372}, {0x376, 0x376}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x38f},
  {0x391, 0x3a1}, {0x3a3, 0x3ab}, {0x3cf, 0x3cf}, {0x3d2, 0x3d4}, {0x3d8, 0x3d8}, {0x3da, 0x3da}, {0x3dc, 0x3dc}, {0x3de, 0x3de},
  {0x3e0, 0x3e0}, {0x3e2, 0x3e2}, {0x3e4, 0x3e4}, {0x3e6, 0x3e6}, {0x3e8, 0x3e8}, {0x3ea, 0x3ea}, {0x3ec, 0x3ec}, {0x3ee, 0x3ee},
  {0x3f4, 0x3f4}, {0x3f7, 0x3f7}, {0x3f9, 0x3fa}, {0x3fd, 0x42f}, {0x460, 0x460}, {0x462, 0x462}, {0x464, 0x464}, {0x466, 0x466},
  {0x468, 0x468}, {0x46a, 0x46a}, {0x46c, 0x46c}, {0x46e, 0x46e}, {0x470, 0x470}, {0x472, 0x472}, {0x474, 0x474}, {0x476, 0x476},
  {0x478, 0x478}, {0x47a, 0x47a}, {0x47c, 0x47c}, {0x47e, 0x47e}, {0x480, 0x480}, {0x48a, 0x48a}, {0x48c, 0x48c}, {0x48e, 0x48e},
  {0x490, 0x490}, {0x492, 0x492}, {0x494, 0x494}, {0x496, 0x496}, {0x498, 0x498}, {0x49a, 0x49a}, {0x49c, 0x49c}, {0x49e, 0x49e},
  {0x4a0, 0x4a0}, {0x4a2, 0x4a2}, {0x4a4, 0x4a4}, {0x4a6, 0x4a6}, {0x4a8, 0x4a8}, {0x4aa, 0x4aa}, {0x4ac, 0x4ac}, {0x4ae, 0x4ae},
  {0x4b0, 0x4b0}, {0x4b2, 0x4b2}, {0x4b4, 0x4b4}, {0x4b6, 0x4b6}, {0x4b8, 0x4b8}, {0x4ba, 0x4ba}, {0x4bc, 0x4bc}, {0x4be, 0x4be},
  {0x4c0, 0x4c1}, {0x4c3, 0x4c3}, {0x4c5, 0x4c5}, {0x4c7, 0x4c7}, {0x4c9, 0x4c9}, {0x4cb, 0x4cb}, {0x4cd, 0x4cd}, {0x4d0, 0x4d0},
  {0x4d2, 0x4d2}, {0x4d4, 0x4d4}, {0x4d6, 0x4d6}, {0x4d8, 0x4d8}, {0x4da, 0x4da}, {0x4dc, 0x4dc}, {0x4de, 0x4de}, {0x4e0, 0x4e0},
  {0x4e2, 0x4e2}, {0x4e4, 0x4e4}, {0x4e6, 0x4e6}, {0x4e8, 0x4e8}, {0x4ea, 0x4ea}, {0x4ec, 0x4ec}, {0x4ee, 0x4ee}, {0x4f0, 0x4f0},
  {0x4f2, 0x4f2}, {0x4f4, 0x4f4}, {0x4f6, 0x4f6}, {0x4f8, 0x4f8}, {0x4fa, 0x4fa}, {0x4fc, 0x4fc}, {0x4fe, 0x4fe}, {0x500, 0x500},
  {0x502, 0x502}, {0x504, 0x504}, {0x506, 0x506}, {0x508, 0x508}, {0x50a, 0x50a}, {0x50c, 0x50c}, {0x50e, 0x50e}, {0x510, 0x510},
  {0x512, 0x512}, {0x514, 0x514}, {0x516, 0x516}, {0x518, 0x518}, {0x51a, 0x51a}, {0x51c, 0x51c}, {0x51e, 0x51e}, {0x520, 0x520},
  {0x522, 0x522}, {0x524, 0x524}, {0x526, 0x526}, {0x528, 0x528}, {0x52a, 0x52a}, {0x52c, 0x52c}, {0x52e, 0x52e}, {0x531, 0x556},
  {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x13a0, 0x13f5}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1e00, 0x1e00}, {0x1e02, 0x1e02},
  {0x1e04, 0x1e04}, {0x1e06, 0x1e06}, {0x1e08, 0x1e08}, {0x1e0a, 0x1e0a}, {0x1e0c, 0x1e0c}, {0x1e0e, 0x1e0e}, {0x1e10, 0x1e10}, {0x1e12, 0x1e12},
  {0x1e14, 0x1e14}, {0x1e16, 0x1e16}, {0x1e18, 0x1e18}, {0x1e1a, 0x1e1a}, {0x1e1c, 0x1e1c}, {0x1e1e, 0x1e1e}, {0x1e20, 0x1e20}, {0x1e22, 0x1e22},
  {0x1e24, 0x1e24}, {0x1e26, 0x1e26}, {0x1e28, 0x1e28}, {0x1e2a, 0x1e2a}, {0x1e2c, 0x1e2c}, {0x1e2e, 0x1e2e}, {0x1e30, 0x1e30}, {0x1e32, 0x1e32},
  {0x1e34, 0x1e34}, {0x1e36, 0x1e36}, {0x1e38, 0x1e38}, {0x1e3a, 0x1e3a}, {0x1e3c, 0x1e3c}, {0x1e3e, 0x1e3e}, {0x1e40, 0x1e40}, {0x1e42, 0x1e42},
  {0x1e44, 0x1e44}, {0x1e46, 0x1e46}, {0x1e48, 0x1e48}, {0x1e4a, 0x1e4a}, {0x1e4c, 0x1e4c}, {0x1e4e, 0x1e4e}, {0x1e50, 0x1e50}, {0x1e52, 0x1e52},
  {0x1e54, 0x1e54}, {0x1e56, 0x1e56}, {0x1e58, 0x1e58}, {0x1e5a, 0x1e5a}, {0x1e5c, 0x1e5c}, {0x1e5e, 0x1e5e}, {0x1e60, 0x1e60}, {0x1e62, 0x1e62},
  {0x1e64, 0x1e64}, {0x1e66, 0x1e66}, {0x1e68, 0x1e68}, {0x1e6a, 0x1e6a}, {0x1e6c, 0x1e6c}, {0x1e6e, 0x1e6e}, {0x1e70, 0x1e70}, {0x1e72, 0x1e72},
  {0x1e74, 0x1e74}, {0x1e76, 0x1e76}, {0x1e78, 0x1e78}, {0x1e7a, 0x1e7a}, {0x1e7c, 0x1e7c}, {0x1e7e, 0x1e7e}, {0x1e80, 0x1e80}, {0x1e82, 0x1e82},
  {0x1e84, 0x1e84}, {0x1e86, 0x1e86}, {0x1e88, 0x1e88}, {0x1e8a, 0x1e8a}, {0x1e8c, 0x1e8c}, {0x1e8e, 0x1e8e}, {0x1e90, 0x1e90}, {0x1e92, 0x1e92},
  {0x1e94, 0x1e94}, {0x1e9e, 0x1e9e}, {0x1ea0, 0x1ea0}, {0x1ea2, 0x1ea2}, {0x1ea4, 0x1ea4}, {0x1ea6, 0x1ea6}, {0x1ea8, 0x1ea8}, {0x1eaa, 0x1eaa},
  {0x1eac, 0x1eac}, {0x1eae, 0x1eae}, {0x1eb0, 0x1eb0}, {0x1eb2, 0x1eb2}, {0x1eb4, 0x1eb4}, {0x1eb6, 0x1eb6}, {0x1eb8, 0x1eb8}, {0x1eba, 0x1eba},
  {0x1ebc, 0x1ebc}, {0x1ebe, 0x1ebe}, {0x1ec0, 0x1ec0}, {0x1ec2, 0x1ec2}, {0x1ec4, 0x1ec4}, {0x1ec6, 0x1ec6}, {0x1ec8, 0x1ec8}, {0x1eca, 0x1eca},
  {0x1ecc, 0x1ecc}, {0x1ece, 0x1ece}, {0x1ed0, 0x1ed0}, {0x1ed2, 0x1ed2}, {0x1ed4, 0x1ed4}, {0x1ed6, 0x1ed6}, {0x1ed8, 0x1ed8}, {0x1eda, 0x1eda},
  {0x1edc, 0x1edc}, {0x1ede, 0x1ede}, {0x1ee0, 0x1ee0}, {0x1ee2, 0x1ee2}, {0x1ee4, 0x1ee4}, {0x1ee6, 0x1ee6}, {0x1ee8, 0x1ee8}, {0x1eea, 0x1eea},
  {0x1eec, 0x1eec}, {0x1eee, 0x1eee}, {0x1ef0, 0x1ef0}, {0x1ef2, 0x1ef2}, {0x1ef4, 0x1ef4}, {0x1ef6, 0x1ef6}, {0x1ef8, 0x1ef8}, {0x1efa, 0x1efa},
  {0x1efc, 0x1efc}, {0x1efe, 0x1efe}, {0x1f08, 0x1f0f}, {0x1f18, 0x1f1d}, {0x1f28, 0x1f2f}, {0x1f38, 0x1f3f}, {0x1f48, 0x1f4d}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f5f}, {0x1f68, 0x1f6f}, {0x1fb8, 0x1fbb}, {0x1fc8, 0x1fcb}, {0x1fd8, 0x1fdb}, {0x1fe8, 0x1fec},
  {0x1ff8, 0x1ffb}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210b, 0x210d}, {0x2110, 0x2112}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124},
  {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x2130, 0x2133}, {0x213e, 0x213f}, {0x2145, 0x2145}, {0x2183, 0x2183}, {0x2c00, 0x2c2f},
  {0x2c60, 0x2c60}, {0x2c62, 0x2c64}, {0x2c67, 0x2c67}, {0x2c69, 0x2c69}, {0x2c6b, 0x2c6b}, {0x2c6d, 0x2c70}, {0x2c72, 0x2c72}, {0x2c75, 0x2c75},
  {0x2c7e, 0x2c80}, {0x2c82, 0x2c82}, {0x2c84, 0x2c84}, {0x2c86, 0x2c86}, {0x2c88, 0x2c88}, {0x2c8a, 0x2c8a}, {0x2c8c, 0x2c8c}, {0x2c8e, 0x2c8e},
  {0x2c90, 0x2c90}, {0x2c92, 0x2c92}, {0x2c94, 0x2c94}, {0x2c96, 0x2c96}, {0x2c98, 0x2c98}, {0x2c9a, 0x2c9a}, {0x2c9c, 0x2c9c}, {0x2c9e, 0x2c9e},
  {0x2ca0, 0x2ca0}, {0x2ca2, 0x2ca2}, {0x2ca4, 0x2ca4}, {0x2ca6, 0x2ca6}, {0x2ca8, 0x2ca8}, {0x2caa, 0x2caa}, {0x2cac, 0x2cac}, {0x2cae, 0x2cae},
  {0x2cb0, 0x2cb0}, {0x2cb2, 0x2cb2}, {0x2cb4, 0x2cb4}, {0x2cb6, 0x2cb6}, {0x2cb8, 0x2cb8}, {0x2cba, 0x2cba}, {0x2cbc, 0x2cbc}, {0x2cbe, 0x2cbe},
  {0x2cc0, 0x2cc0}, {0x2cc2, 0x2cc2}, {0x2cc4, 0x2cc4}, {0x2cc6, 0x2cc6}, {0x2cc8, 0x2cc8}, {0x2cca, 0x2cca}, {0x2ccc, 0x2ccc}, {0x2cce, 0x2cce},
  {0x2cd0, 0x2cd0}, {0x2cd2, 0x2cd2}, {0x2cd4, 0x2cd4}, {0x2cd6, 0x2cd6}, {0x2cd8, 0x2cd8}, {0x2cda, 0x2cda}, {0x2cdc, 0x2cdc}, {0x2cde, 0x2cde},
  {0x2ce0, 0x2ce0}, {0x2ce2, 0x2ce2}, {0x2ceb, 0x2ceb}, {0x2ced, 0x2ced}, {0x2cf2, 0x2cf2}, {0xa640, 0xa640}, {0xa642, 0xa642}, {0xa644, 0xa644},
  {0xa646, 0xa646}, {0xa648, 0xa648}, {0xa64a, 0xa64a}, {0xa64c, 0xa64c}, {0xa64e, 0xa64e}, {0xa650, 0xa650}, {0xa652, 0xa652}, {0xa654, 0xa654},
  {0xa656, 0xa656}, {0xa658, 0xa658}, {0xa65a, 0xa65a}, {0xa65c, 0xa65c}, {0xa65e, 0xa65e}, {0xa660, 0xa660}, {0xa662, 0xa662}, {0xa664, 0xa664},
  {0xa666, 0xa666}, {0xa668, 0xa668}, {0xa66a, 0xa66a}, {0xa66c, 0xa66c}, {0xa680, 0xa680}, {0xa682, 0xa682}, {0xa684, 0xa684}, {0xa686, 0xa686},
  {0xa688, 0xa688}, {0xa68a, 0xa68a}, {0xa68c, 0xa68c}, {0xa68e, 0xa68e}, {0xa690, 0xa690}, {0xa692, 0xa692}, {0xa694, 0xa694}, {0xa696, 0xa696},
  {0xa698, 0xa698}, {0xa69a, 0xa69a}, {0xa722, 0xa722}, {0xa724, 0xa724}, {0xa726, 0xa726}, {0xa728, 0xa728}, {0xa72a, 0xa72a}, {0xa72c, 0xa72c},
  {0xa72e, 0xa72e}, {0xa732, 0xa732}, {0xa734, 0xa734}, {0xa736, 0xa736}, {0xa738, 0xa738}, {0xa73a, 0xa73a}, {0xa73c, 0xa73c}, {0xa73e, 0xa73e},
  {0xa740, 0xa740}, {0xa742, 0xa742}, {0xa744, 0xa744}, {0xa746, 0xa746}, {0xa748, 0xa748}, {0xa74a, 0xa74a}, {0xa74c, 0xa74c}, {0xa74e, 0xa74e},
  {0xa750, 0xa750}, {0xa752, 0xa752}, {0xa754, 0xa754}, {0xa756, 0xa756}, {0xa758, 0xa758}, {0xa75a, 0xa75a}, {0xa75c, 0xa75c}, {0xa75e, 0xa75e},
  {0xa760, 0xa760}, {0xa762, 0xa762}, {0xa764, 0xa764}, {0xa766, 0xa766}, {0xa768, 0xa768}, {0xa76a, 0xa76a}, {0xa76c, 0xa76c}, {0xa76e, 0xa76e},
  {0xa779, 0xa779}, {0xa77b, 0xa77b}, {0xa77d, 0xa77e}, {0xa780, 0xa780}, {0xa782, 0xa782}, {0xa784, 0xa784}, {0xa786, 0xa786}, {0xa78b, 0xa78b},
  {0xa78d, 0xa78d}, {0xa790, 0xa790}, {0xa792, 0xa792}, {0xa796, 0xa796}, {0xa798, 0xa798}, {0xa79a, 0xa79a}, {0xa79c, 0xa79c}, {0xa79e, 0xa79e},
  {0xa7a0, 0xa7a0}, {0xa7a2, 0xa7a2}, {0xa7a4, 0xa7a4}, {0xa7a6, 0xa7a6}, {0xa7a8, 0xa7a8}, {0xa7aa, 0xa7ae}, {0xa7b0, 0xa7b4}, {0xa7b6, 0xa7b6},
  {0xa7b8, 0xa7b8}, {0xa7ba, 0xa7ba}, {0xa7bc, 0xa7bc}, {0xa7be, 0xa7be}, {0xa7c0, 0xa7c0}, {0xa7c2, 0xa7c2}, {0xa7c4, 0xa7c7}, {0xa7c9, 0xa7c9},
  {0xa7d0, 0xa7d0}, {0xa7d6, 0xa7d6}, {0xa7d8, 0xa7d8}, {0xa7f5, 0xa7f5}, {0xff21, 0xff3a}, {0x10400, 0x10427}, {0x104b0, 0x104d3}, {0x10570, 0x1057a},
  {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '!', 488,
        '"', 628,
        '#', 568,
        '$', 420,
        '%', 602,
        '&', 564,
        '\'', 624,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 487,
        ',', 485,
        '-', 490,
        '.', 519,
        '0', 605,
        ':', 472,
        ';', 530,
        '<', 566,
        '=', 465,
        '>', 562,
        '?', 468,
        '@', 668,
        '[', 497,
        '\\', 2,
        ']', 507,
        '^', 670,
        '`', 836,
        'a', 760,
        'c', 754,
        'd', 781,
        'e', 748,
        'i', 761,
        'l', 719,
        'm', 691,
        'o', 793,
        't', 740,
        'v', 689,
        'w', 744,
        '{', 525,
        '|', 494,
        '}', 531,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(436);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(636);
      if (lookahead == '\r') ADVANCE(1);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 636,
        '\r', 1,
        '#', 435,
        'o', 417,
        'u', 408,
        'x', 434,
        ' ', 642,
        '"', 642,
        '\'', 642,
        '\\', 642,
        'b', 642,
        'n', 642,
        'r', 642,
        't', 642,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(424);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 636,
        '\r', 1,
        'o', 417,
        'u', 408,
        'x', 434,
        ' ', 642,
        '"', 642,
        '\'', 642,
        '\\', 642,
        'b', 642,
        'n', 642,
        'r', 642,
        't', 642,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(424);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(625);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '[') ADVANCE(627);
      if (lookahead == '\\') ADVANCE(365);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(626);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(625);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '[') ADVANCE(280);
      if (lookahead == '\\') ADVANCE(365);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(283);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 488,
        '"', 628,
        '#', 567,
        '%', 602,
        '\'', 623,
        '(', 477,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 837,
        '0', 605,
        ':', 514,
        ';', 529,
        '=', 465,
        '>', 411,
        '?', 468,
        '[', 503,
        '\\', 219,
        '`', 836,
        '{', 526,
        '|', 493,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 488,
        '#', 567,
        '&', 563,
        '\'', 835,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 272,
        ',', 485,
        '-', 277,
        '.', 264,
        ':', 511,
        ';', 529,
        '<', 565,
        '=', 465,
        '>', 562,
        '?', 468,
        '[', 501,
        '\\', 219,
        ']', 507,
        '`', 836,
        '{', 526,
        '|', 492,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 488,
        '%', 602,
        '\'', 835,
        '(', 477,
        '+', 486,
        '-', 489,
        '.', 837,
        '[', 502,
        '\\', 219,
        '{', 253,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 9:
      if (lookahead == '!') ADVANCE(488);
      if (lookahead == '(') ADVANCE(477);
      if (lookahead == '[') ADVANCE(502);
      if (lookahead == '\\') ADVANCE(219);
      if (lookahead == 'l') ADVANCE(719);
      if (lookahead == '{') ADVANCE(253);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        '\'', 624,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        ':', 512,
        ';', 530,
        '<', 673,
        '[', 505,
        ']', 507,
        '`', 836,
        'a', 346,
        'c', 341,
        'd', 367,
        'e', 337,
        'i', 351,
        'l', 288,
        'm', 373,
        'o', 378,
        't', 369,
        'v', 286,
        'w', 330,
        '{', 528,
        '|', 496,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        ':', 513,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 252,
        ']', 507,
        'a', 359,
        'd', 366,
        'e', 336,
        'i', 353,
        'l', 290,
        'm', 374,
        'o', 381,
        't', 327,
        'w', 330,
        '{', 253,
        '|', 495,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        ':', 512,
        ';', 530,
        '<', 673,
        '[', 505,
        ']', 507,
        '`', 836,
        'a', 346,
        'c', 341,
        'd', 367,
        'e', 337,
        'i', 351,
        'l', 288,
        'm', 373,
        'o', 378,
        't', 369,
        'v', 286,
        'w', 330,
        '{', 528,
        '|', 496,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        ':', 513,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 255,
        ']', 507,
        'a', 388,
        'c', 372,
        'd', 366,
        'e', 336,
        'i', 352,
        'l', 290,
        'm', 315,
        'o', 381,
        't', 327,
        'v', 286,
        'w', 330,
        '{', 256,
        '|', 496,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        ':', 513,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 255,
        ']', 507,
        'a', 388,
        'c', 372,
        'd', 366,
        'e', 336,
        'i', 352,
        'l', 290,
        'm', 315,
        'o', 381,
        't', 327,
        'v', 286,
        'w', 330,
        '{', 256,
        '|', 495,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        ':', 473,
        ';', 529,
        '<', 673,
        '[', 281,
        'a', 346,
        'd', 367,
        'e', 335,
        'i', 353,
        'l', 290,
        'm', 374,
        'o', 381,
        't', 368,
        '|', 496,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 275,
        '#', 568,
        '&', 679,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        ':', 269,
        ';', 529,
        '<', 673,
        '[', 281,
        'a', 346,
        'd', 367,
        'e', 335,
        'i', 353,
        'l', 290,
        'm', 374,
        'o', 381,
        't', 368,
        '|', 496,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '!', 275,
        '#', 834,
        '&', 679,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        ':', 473,
        ';', 530,
        '<', 673,
        '[', 255,
        ']', 507,
        'a', 346,
        'c', 341,
        'd', 367,
        'e', 337,
        'i', 351,
        'l', 288,
        'm', 373,
        'o', 378,
        't', 369,
        '{', 256,
        '|', 496,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '!', 275,
        '#', 834,
        '&', 679,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        ':', 269,
        ';', 530,
        '<', 673,
        '[', 255,
        ']', 507,
        'a', 346,
        'c', 341,
        'd', 367,
        'e', 337,
        'i', 351,
        'l', 288,
        'm', 373,
        'o', 378,
        't', 369,
        '{', 256,
        '|', 496,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '!', 275,
        '&', 679,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 837,
        ':', 474,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 255,
        ']', 507,
        'a', 388,
        'c', 372,
        'd', 366,
        'e', 336,
        'i', 352,
        'l', 290,
        'm', 315,
        'o', 381,
        't', 327,
        'v', 286,
        'w', 330,
        '{', 256,
        '|', 496,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '!', 275,
        '&', 679,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 837,
        ':', 513,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 255,
        ']', 507,
        'a', 388,
        'c', 372,
        'd', 366,
        'e', 336,
        'i', 352,
        'l', 290,
        'm', 315,
        'o', 381,
        't', 327,
        'v', 286,
        'w', 330,
        '{', 256,
        '|', 496,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '!', 275,
        '&', 679,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        ':', 474,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 280,
        ']', 507,
        'a', 388,
        'd', 366,
        'e', 336,
        'l', 290,
        'm', 374,
        'o', 381,
        't', 327,
        'w', 330,
        '|', 495,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '!', 275,
        '&', 679,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        ':', 513,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 281,
        ']', 507,
        'a', 346,
        'd', 366,
        'e', 336,
        'i', 353,
        'l', 290,
        'm', 374,
        'o', 381,
        't', 327,
        'w', 330,
        '|', 495,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '!', 275,
        '&', 679,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        ':', 513,
        ';', 529,
        '<', 673,
        '>', 674,
        '[', 280,
        ']', 507,
        'a', 388,
        'd', 366,
        'e', 336,
        'l', 290,
        'm', 374,
        'o', 381,
        't', 327,
        'w', 330,
        '|', 495,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '%', 602,
        '&', 563,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 529,
        '=', 465,
        '>', 562,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        '{', 527,
        '|', 492,
        '}', 531,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        ')', 478,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 509,
        ';', 529,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        '{', 527,
        '|', 493,
        '~', 467,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        '0', 605,
        ':', 470,
        ';', 271,
        '=', 465,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 525,
        '|', 492,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        '0', 605,
        ':', 476,
        '=', 465,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        '0', 605,
        ':', 278,
        '=', 465,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        '0', 605,
        ';', 271,
        '=', 465,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 525,
        '|', 492,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '.', 518,
        '0', 605,
        ';', 271,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(30);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '.', 518,
        '0', 605,
        ';', 271,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(31);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '%', 602,
        '&', 563,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 617,
        '-', 618,
        '.', 837,
        '0', 605,
        ':', 516,
        ';', 271,
        '<', 263,
        '=', 465,
        '>', 562,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 694,
        'o', 794,
        't', 826,
        '{', 525,
        '|', 492,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(32);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '.', 518,
        '0', 605,
        ':', 273,
        ';', 271,
        '=', 465,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 694,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(33);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        ';', 271,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 719,
        'm', 694,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 35:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        ';', 271,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 694,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        ';', 271,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 719,
        'm', 694,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(36);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 37:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        ';', 271,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 694,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(37);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '\'', 623,
        '(', 477,
        '+', 272,
        '0', 605,
        ':', 470,
        ';', 271,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(39);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 39:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '\'', 623,
        '(', 477,
        '+', 272,
        '0', 605,
        ';', 271,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(39);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 40:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 470,
        ';', 271,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(41);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 41:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 834,
        '$', 420,
        '\'', 623,
        '(', 477,
        '0', 605,
        ';', 271,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 525,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(41);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 42:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        ')', 478,
        '+', 617,
        '-', 618,
        '.', 518,
        '0', 605,
        ':', 517,
        ';', 529,
        '=', 465,
        '>', 411,
        '?', 431,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'l', 719,
        'm', 697,
        '{', 527,
        '|', 284,
        '}', 531,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(42);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 43:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        ';', 529,
        '=', 465,
        '>', 562,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'c', 785,
        'e', 770,
        'i', 765,
        'l', 719,
        'm', 693,
        'v', 689,
        '{', 525,
        '}', 531,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(43);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 44:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'd', 781,
        'l', 719,
        'm', 697,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(44);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 45:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'd', 783,
        'l', 719,
        'm', 697,
        't', 782,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'd', 792,
        'l', 719,
        'm', 697,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(46);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 47:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'e', 770,
        'l', 719,
        'm', 697,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 48:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'l', 719,
        'm', 697,
        't', 741,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(48);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'l', 719,
        'm', 697,
        'w', 744,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '?', 431,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 760,
        'i', 766,
        'l', 719,
        'm', 697,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(50);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '\'', 623,
        '(', 477,
        ')', 478,
        ',', 485,
        '-', 277,
        '.', 837,
        '0', 605,
        ':', 509,
        ';', 529,
        '=', 465,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        '{', 527,
        '|', 492,
        '}', 531,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(51);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '\'', 623,
        '(', 477,
        ')', 478,
        ',', 485,
        '-', 277,
        '.', 837,
        '0', 605,
        ':', 471,
        ';', 529,
        '=', 465,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        '{', 527,
        '|', 492,
        '}', 531,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(51);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 53:
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '$', 420,
        '\'', 623,
        '(', 477,
        '.', 837,
        '0', 605,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'l', 719,
        'm', 697,
        '{', 527,
        '~', 467,
        '+', 617,
        '-', 617,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(53);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 54:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 785,
        'e', 749,
        'i', 765,
        'l', 701,
        'm', 692,
        'o', 797,
        'v', 689,
        '{', 525,
        '|', 496,
        '}', 531,
        '~', 467,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(54);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 672,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(55);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 56:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 672,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 495,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(56);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 57:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 672,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(57);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 58:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '.', 518,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 672,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 495,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(58);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 59:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 785,
        'e', 749,
        'i', 765,
        'l', 703,
        'm', 728,
        'o', 797,
        'v', 689,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(87);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 60:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 785,
        'e', 770,
        'i', 765,
        'l', 703,
        'm', 728,
        'o', 797,
        'v', 689,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(88);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 781,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(89);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 62:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 781,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(90);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 63:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 783,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 782,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(91);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 783,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 782,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 65:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 792,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 66:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 792,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(94);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 67:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 749,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 68:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 741,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(96);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 69:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        'w', 744,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(97);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 70:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 770,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(98);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 71:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 741,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(99);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 72:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        'w', 744,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(100);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 73:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 759,
        'e', 751,
        'i', 766,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(101);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 74:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 473,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 759,
        'i', 766,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(102);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 75:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(75);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 76:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(76);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 77:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(77);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 78:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(78);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 79:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(79);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 80:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(80);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 81:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(81);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 82:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(82);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 83:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(83);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 84:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(84);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 85:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(85);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 86:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(86);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 87:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 785,
        'e', 749,
        'i', 765,
        'l', 703,
        'm', 728,
        'o', 797,
        'v', 689,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(87);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 88:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 785,
        'e', 770,
        'i', 765,
        'l', 703,
        'm', 728,
        'o', 797,
        'v', 689,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(88);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 89:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 781,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(89);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 90:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 781,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(90);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 91:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 783,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 782,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(91);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 92:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 783,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 782,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 93:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 792,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 94:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 792,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(94);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 95:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 749,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 96:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 741,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(96);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 97:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        'w', 744,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(97);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 98:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 770,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(98);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 99:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        't', 741,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(99);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 100:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        'w', 744,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(100);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 101:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 759,
        'e', 751,
        'i', 766,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(101);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 102:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 672,
        '?', 469,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 759,
        'i', 766,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(102);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 103:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 776,
        'e', 825,
        'l', 702,
        'm', 695,
        'o', 797,
        't', 826,
        '{', 526,
        '|', 409,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(103);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 104:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 776,
        'e', 825,
        'l', 702,
        'm', 695,
        'o', 797,
        '{', 526,
        '|', 409,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(104);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 105:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 776,
        'l', 702,
        'm', 695,
        'o', 797,
        't', 826,
        '{', 526,
        '|', 409,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(105);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 106:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 568,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 776,
        'l', 702,
        'm', 695,
        'o', 797,
        '{', 526,
        '|', 409,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 107:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 264,
        '/', 664,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 761,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(108);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 108:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 264,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 761,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(108);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 109:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(109);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 110:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(110);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 111:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(111);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 112:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(112);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 113:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(113);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 114:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 761,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(114);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 115:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(115);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 116:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(116);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 117:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(117);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 118:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(118);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 119:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 695,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(119);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 120:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(132);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 121:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(133);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 122:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(134);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 123:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(135);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 124:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(136);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 125:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(137);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 126:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(138);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 127:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(139);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 128:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(140);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 129:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(141);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 130:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(142);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 131:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 473,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(143);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 132:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(132);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 133:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(133);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 134:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(134);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 135:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(135);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 136:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(136);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 137:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 750,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(137);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 138:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(138);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 139:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(139);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 140:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(140);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 141:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 759,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(141);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 142:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 748,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(142);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 143:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 834,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '0', 605,
        ':', 269,
        ';', 530,
        '<', 673,
        '?', 469,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 701,
        'm', 789,
        'o', 793,
        't', 826,
        '{', 525,
        '|', 496,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(143);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 144:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '#', 430,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 776,
        'l', 701,
        'm', 695,
        'o', 797,
        '{', 527,
        '|', 285,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(144);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 145:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '/', 664,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 431,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(145);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 146:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '/', 664,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 431,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(146);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 147:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 806,
        'c', 785,
        'e', 770,
        'i', 765,
        'l', 701,
        'm', 692,
        'o', 797,
        'v', 689,
        '{', 525,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(147);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 148:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 781,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(148);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 149:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 781,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(149);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 150:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 783,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        't', 782,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(150);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 151:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 783,
        'l', 701,
        'm', 696,
        'o', 797,
        't', 782,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(151);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 152:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 792,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(152);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 153:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'd', 792,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(153);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 154:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 749,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(154);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 155:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        't', 741,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(155);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 156:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        'w', 744,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(156);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 157:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 495,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(157);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 158:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'e', 770,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(158);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 159:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 701,
        'm', 696,
        'o', 797,
        't', 741,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(159);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 160:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 701,
        'm', 696,
        'o', 797,
        'w', 744,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(160);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 161:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 503,
        '\\', 219,
        '`', 836,
        'a', 806,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 495,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(161);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 162:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 759,
        'e', 751,
        'i', 766,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(162);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 163:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '%', 603,
        '&', 679,
        '\'', 623,
        '(', 477,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '/', 664,
        '0', 605,
        ':', 269,
        ';', 529,
        '<', 673,
        '?', 431,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 759,
        'i', 766,
        'l', 701,
        'm', 696,
        'o', 797,
        '{', 527,
        '|', 496,
        '~', 467,
        '@', 670,
        '^', 670,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(163);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 164:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 474,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(168);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 165:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 474,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 495,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(169);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 166:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 474,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(170);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 167:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 474,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 495,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(171);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 168:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(168);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 169:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'e', 751,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 495,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(169);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 170:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 496,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(170);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 171:
      ADVANCE_MAP(
        '!', 651,
        '"', 628,
        '$', 675,
        '&', 679,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 621,
        '0', 605,
        ':', 513,
        ';', 529,
        '<', 673,
        '=', 676,
        '>', 674,
        '?', 469,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 806,
        'l', 703,
        'm', 790,
        'o', 797,
        '{', 527,
        '|', 495,
        '}', 531,
        '~', 467,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(171);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 172:
      ADVANCE_MAP(
        '!', 651,
        '#', 430,
        '&', 679,
        ')', 478,
        '*', 661,
        '+', 619,
        '-', 620,
        '.', 518,
        ':', 276,
        '<', 673,
        '[', 280,
        'a', 361,
        'l', 289,
        'm', 294,
        'o', 381,
        '|', 409,
        '%', 664,
        '/', 664,
        '?', 431,
        '~', 431,
        '@', 670,
        '^', 670,
        '$', 676,
        '=', 676,
        '>', 676,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(172);
      END_STATE();
    case 173:
      ADVANCE_MAP(
        '"', 628,
        '#', 834,
        '\'', 623,
        '(', 477,
        ')', 478,
        ',', 485,
        '0', 605,
        ':', 509,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 528,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(173);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 174:
      ADVANCE_MAP(
        '"', 628,
        '#', 834,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 528,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(174);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 175:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '%', 602,
        '\'', 623,
        '(', 477,
        ')', 478,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 509,
        ';', 529,
        '=', 465,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        'e', 825,
        '{', 526,
        '|', 492,
        '}', 531,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(175);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 176:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '[', 503,
        '\\', 219,
        '`', 836,
        'e', 825,
        'm', 786,
        'o', 794,
        '{', 526,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(176);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 177:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '%', 602,
        '\'', 623,
        '(', 477,
        '0', 605,
        '[', 503,
        '\\', 219,
        '`', 836,
        'o', 794,
        '{', 526,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(177);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 178:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 529,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        '{', 524,
        '|', 492,
        '}', 531,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(178);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 179:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ')', 478,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 529,
        '=', 465,
        '?', 468,
        '[', 503,
        '\\', 219,
        ']', 507,
        '`', 836,
        '{', 526,
        '|', 492,
        '}', 531,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(179);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 180:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '*', 522,
        '+', 616,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(180);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 181:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '*', 522,
        '+', 616,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(181);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 182:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '*', 522,
        '+', 616,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 524,
        '|', 492,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 183:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 264,
        '0', 605,
        ':', 514,
        ';', 529,
        '=', 465,
        '?', 468,
        '[', 503,
        '\\', 219,
        '`', 836,
        '{', 526,
        '|', 493,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(183);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 184:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '+', 616,
        ',', 485,
        '-', 622,
        '.', 264,
        '0', 605,
        ':', 475,
        ';', 529,
        '=', 465,
        '?', 468,
        '[', 503,
        '\\', 219,
        '`', 836,
        '{', 526,
        '|', 493,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(183);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 185:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(185);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 186:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(186);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 187:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(187);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 188:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(188);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 189:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 514,
        '=', 465,
        '?', 468,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 760,
        'i', 766,
        '{', 526,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(189);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 190:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 518,
        '0', 605,
        ':', 268,
        ';', 529,
        '[', 503,
        '\\', 219,
        '`', 836,
        'e', 825,
        '{', 526,
        '|', 493,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(190);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 191:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 264,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(191);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 192:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 264,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(192);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 193:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 264,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(193);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 194:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 264,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(194);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 195:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '.', 264,
        '0', 605,
        ':', 514,
        '=', 465,
        '?', 468,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 760,
        'i', 766,
        '{', 526,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(195);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 196:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(196);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 197:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(197);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 198:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(198);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 199:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 514,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(199);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 200:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 514,
        '=', 465,
        '?', 468,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 760,
        'i', 766,
        '{', 526,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(200);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 201:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 475,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(196);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 202:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 475,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(197);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 203:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 475,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 761,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(198);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 204:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 475,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 760,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(199);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 205:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        ',', 485,
        '0', 605,
        ':', 475,
        '=', 465,
        '?', 468,
        '[', 504,
        '\\', 219,
        '`', 836,
        'a', 760,
        'i', 766,
        '{', 526,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(200);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 206:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '.', 837,
        '0', 605,
        '[', 503,
        '\\', 219,
        '`', 836,
        'e', 825,
        '{', 526,
        '|', 492,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(206);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 207:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(207);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 208:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(208);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 209:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(209);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 210:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(210);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 211:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 470,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(207);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 212:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 470,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(208);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 213:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 470,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(209);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 214:
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 470,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        '`', 836,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(210);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 215:
      if (lookahead == '"') ADVANCE(628);
      if (lookahead == '%') ADVANCE(631);
      if (lookahead == '@') ADVANCE(632);
      if (lookahead == '[') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(3);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(629);
      if (lookahead != 0) ADVANCE(634);
      END_STATE();
    case 216:
      ADVANCE_MAP(
        '#', 568,
        '(', 477,
        '*', 522,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 515,
        ';', 529,
        '=', 465,
        '[', 252,
        'a', 358,
        'c', 372,
        'i', 353,
        'w', 330,
        '{', 253,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(216);
      END_STATE();
    case 217:
      ADVANCE_MAP(
        '#', 568,
        ')', 478,
        ',', 485,
        '-', 277,
        '.', 519,
        ':', 509,
        ';', 529,
        '=', 465,
        '[', 280,
        '\\', 219,
        ']', 507,
        'w', 744,
        '|', 492,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(217);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 218:
      ADVANCE_MAP(
        '#', 568,
        ')', 478,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 509,
        ';', 529,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        'w', 744,
        '{', 256,
        '|', 492,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(218);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 219:
      if (lookahead == '#') ADVANCE(435);
      END_STATE();
    case 220:
      ADVANCE_MAP(
        '#', 834,
        '(', 477,
        '*', 522,
        '-', 277,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 505,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(220);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 221:
      ADVANCE_MAP(
        '#', 834,
        '(', 477,
        '*', 522,
        '-', 277,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 505,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(221);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 222:
      ADVANCE_MAP(
        '#', 834,
        '(', 477,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 505,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(222);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 223:
      ADVANCE_MAP(
        '#', 834,
        '(', 477,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 505,
        '\\', 219,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(223);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 224:
      ADVANCE_MAP(
        '#', 834,
        '*', 522,
        '-', 277,
        ':', 273,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        'w', 744,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(224);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 225:
      ADVANCE_MAP(
        '#', 834,
        '*', 522,
        '-', 277,
        ':', 273,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        'w', 744,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(225);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 226:
      ADVANCE_MAP(
        '#', 567,
        '%', 602,
        '\'', 835,
        '(', 477,
        ')', 478,
        '-', 277,
        '.', 837,
        ':', 268,
        '<', 565,
        '?', 468,
        '[', 501,
        '\\', 219,
        'm', 786,
        '{', 253,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(226);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 227:
      ADVANCE_MAP(
        '#', 567,
        '%', 602,
        '\'', 835,
        '(', 477,
        '<', 565,
        '?', 468,
        '[', 501,
        '\\', 219,
        't', 826,
        '{', 253,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(227);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 228:
      ADVANCE_MAP(
        '#', 567,
        '&', 563,
        '\'', 835,
        ')', 478,
        '*', 522,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 278,
        ';', 529,
        '=', 465,
        '>', 562,
        '[', 280,
        '\\', 219,
        ']', 507,
        '|', 492,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(228);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 229:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 505,
        '\\', 219,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(229);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 230:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        ';', 271,
        '[', 505,
        '\\', 219,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(230);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 231:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '(', 477,
        '<', 565,
        '?', 468,
        '[', 501,
        '\\', 219,
        'l', 734,
        '{', 253,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(231);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 232:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 509,
        ';', 529,
        '=', 465,
        '[', 281,
        '\\', 219,
        'i', 766,
        '|', 493,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(232);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 233:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(233);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 234:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(234);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 235:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        'c', 755,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(235);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 236:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 508,
        '[', 255,
        '\\', 219,
        'c', 785,
        'e', 770,
        'i', 773,
        'm', 729,
        'v', 689,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 237:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 278,
        '=', 465,
        '[', 255,
        '\\', 219,
        'c', 785,
        'e', 770,
        'i', 765,
        'm', 729,
        'v', 689,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(237);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 238:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ';', 271,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(238);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 239:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ';', 271,
        '[', 255,
        '\\', 219,
        ']', 507,
        'c', 755,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(239);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 240:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ';', 271,
        '[', 255,
        '\\', 219,
        'a', 777,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(240);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 241:
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '*', 522,
        '-', 277,
        '.', 518,
        ';', 271,
        '[', 255,
        '\\', 219,
        'c', 755,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(241);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 242:
      ADVANCE_MAP(
        '#', 567,
        ')', 478,
        '*', 522,
        '-', 277,
        ':', 517,
        '[', 280,
        '\\', 219,
        'a', 777,
        'c', 785,
        'w', 744,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(242);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 243:
      ADVANCE_MAP(
        '#', 567,
        '*', 522,
        '-', 277,
        ':', 515,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 824,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        'w', 744,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(243);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 244:
      ADVANCE_MAP(
        '#', 567,
        '*', 522,
        '-', 277,
        ':', 515,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        'w', 744,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(244);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 245:
      ADVANCE_MAP(
        '#', 567,
        '*', 522,
        '-', 277,
        ':', 515,
        ';', 529,
        '=', 465,
        '>', 562,
        '[', 281,
        '\\', 219,
        'a', 777,
        'c', 785,
        'i', 766,
        'w', 744,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(245);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 246:
      if (lookahead == '%') ADVANCE(602);
      if (lookahead == '[') ADVANCE(506);
      if (lookahead == '\\') ADVANCE(219);
      if (lookahead == 't') ADVANCE(826);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(246);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 247:
      if (lookahead == '%') ADVANCE(596);
      if (lookahead == '@') ADVANCE(590);
      END_STATE();
    case 248:
      if (lookahead == '%') ADVANCE(598);
      END_STATE();
    case 249:
      if (lookahead == '%') ADVANCE(600);
      END_STATE();
    case 250:
      if (lookahead == '%') ADVANCE(601);
      END_STATE();
    case 251:
      if (lookahead == '%') ADVANCE(595);
      if (lookahead == '@') ADVANCE(589);
      END_STATE();
    case 252:
      if (lookahead == '%') ADVANCE(595);
      if (lookahead == '@') ADVANCE(591);
      END_STATE();
    case 253:
      if (lookahead == '%') ADVANCE(597);
      END_STATE();
    case 254:
      if (lookahead == '%') ADVANCE(638);
      if (lookahead == '@') ADVANCE(639);
      if (lookahead == '[') ADVANCE(640);
      if (lookahead == '|') ADVANCE(637);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(629);
      if (lookahead != 0) ADVANCE(641);
      END_STATE();
    case 255:
      if (lookahead == '%') ADVANCE(249);
      if (lookahead == '@') ADVANCE(590);
      END_STATE();
    case 256:
      if (lookahead == '%') ADVANCE(250);
      END_STATE();
    case 257:
      if (lookahead == '(') ADVANCE(477);
      if (lookahead == ')') ADVANCE(478);
      if (lookahead == '[') ADVANCE(251);
      if (lookahead == '\\') ADVANCE(219);
      if (lookahead == 'v') ADVANCE(689);
      if (lookahead == '{') ADVANCE(253);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(257);
      if (set_contains(sym_indexing_operator_character_set_1, 9, lookahead)) ADVANCE(685);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 258:
      if (lookahead == '(') ADVANCE(477);
      if (lookahead == '.') ADVANCE(264);
      if (lookahead == '[') ADVANCE(506);
      if (lookahead == '\\') ADVANCE(219);
      if (lookahead == '{') ADVANCE(523);
      if (lookahead == '|') ADVANCE(492);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(258);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 259:
      if (lookahead == '(') ADVANCE(477);
      if (lookahead == '[') ADVANCE(506);
      if (lookahead == '\\') ADVANCE(219);
      if (lookahead == '{') ADVANCE(523);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(259);
      if (set_contains(sym_indexing_operator_character_set_1, 9, lookahead)) ADVANCE(685);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 260:
      if (lookahead == '*') ADVANCE(267);
      if (lookahead == '.') ADVANCE(261);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(647);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(266);
      if (set_contains(sym_conversion_specification_character_set_6, 15, lookahead)) ADVANCE(646);
      END_STATE();
    case 261:
      if (lookahead == '*') ADVANCE(416);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(647);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(415);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(646);
      END_STATE();
    case 262:
      ADVANCE_MAP(
        ',', 485,
        '.', 518,
        ':', 509,
        ';', 529,
        '=', 465,
        '[', 281,
        '\\', 219,
        ']', 507,
        'i', 766,
        '|', 492,
        '}', 531,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(262);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 263:
      if (lookahead == '-') ADVANCE(572);
      END_STATE();
    case 264:
      if (lookahead == '.') ADVANCE(483);
      END_STATE();
    case 265:
      if (lookahead == '.') ADVANCE(837);
      if (lookahead == '[') ADVANCE(280);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(599);
      END_STATE();
    case 266:
      if (lookahead == '.') ADVANCE(261);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(647);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(266);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(646);
      END_STATE();
    case 267:
      if (lookahead == '.') ADVANCE(261);
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(647);
      if (set_contains(sym_conversion_specification_character_set_6, 15, lookahead)) ADVANCE(646);
      END_STATE();
    case 268:
      if (lookahead == ':') ADVANCE(569);
      END_STATE();
    case 269:
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(684);
      END_STATE();
    case 270:
      ADVANCE_MAP(
        ':', 517,
        ';', 529,
        '=', 465,
        '>', 411,
        '[', 255,
        'c', 372,
        'e', 354,
        'i', 352,
        'm', 313,
        'v', 286,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(270);
      END_STATE();
    case 271:
      if (lookahead == ';') ADVANCE(456);
      END_STATE();
    case 272:
      if (lookahead == '=') ADVANCE(484);
      END_STATE();
    case 273:
      if (lookahead == '=') ADVANCE(491);
      END_STATE();
    case 274:
      if (lookahead == '=') ADVANCE(491);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 275:
      if (lookahead == '=') ADVANCE(671);
      END_STATE();
    case 276:
      if (lookahead == '=') ADVANCE(684);
      END_STATE();
    case 277:
      if (lookahead == '>') ADVANCE(520);
      END_STATE();
    case 278:
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 279:
      if (lookahead == '>') ADVANCE(648);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(279);
      END_STATE();
    case 280:
      if (lookahead == '@') ADVANCE(589);
      END_STATE();
    case 281:
      if (lookahead == '@') ADVANCE(591);
      END_STATE();
    case 282:
      if (lookahead == '[') ADVANCE(502);
      if (lookahead == '\\') ADVANCE(219);
      if (lookahead == 'l') ADVANCE(734);
      if (lookahead == '{') ADVANCE(253);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(282);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 283:
      if (lookahead == '[') ADVANCE(280);
      if (lookahead == '\\') ADVANCE(365);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(283);
      END_STATE();
    case 284:
      if (lookahead == ']') ADVANCE(571);
      END_STATE();
    case 285:
      if (lookahead == ']') ADVANCE(571);
      if (lookahead == '|') ADVANCE(682);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 286:
      if (lookahead == 'a') ADVANCE(338);
      END_STATE();
    case 287:
      if (lookahead == 'a') ADVANCE(391);
      END_STATE();
    case 288:
      if (lookahead == 'a') ADVANCE(357);
      if (lookahead == 'e') ADVANCE(393);
      if (lookahead == 'o') ADVANCE(383);
      if (lookahead == 's') ADVANCE(413);
      if (lookahead == 'x') ADVANCE(371);
      END_STATE();
    case 289:
      if (lookahead == 'a') ADVANCE(357);
      if (lookahead == 'e') ADVANCE(400);
      if (lookahead == 'o') ADVANCE(383);
      if (lookahead == 's') ADVANCE(413);
      if (lookahead == 'x') ADVANCE(371);
      END_STATE();
    case 290:
      if (lookahead == 'a') ADVANCE(357);
      if (lookahead == 'o') ADVANCE(383);
      if (lookahead == 's') ADVANCE(413);
      if (lookahead == 'x') ADVANCE(371);
      END_STATE();
    case 291:
      if (lookahead == 'a') ADVANCE(333);
      END_STATE();
    case 292:
      if (lookahead == 'a') ADVANCE(343);
      END_STATE();
    case 293:
      if (lookahead == 'a') ADVANCE(340);
      END_STATE();
    case 294:
      if (lookahead == 'a') ADVANCE(397);
      if (lookahead == 'o') ADVANCE(300);
      END_STATE();
    case 295:
      if (lookahead == 'c') ADVANCE(339);
      if (lookahead == 'h') ADVANCE(319);
      if (lookahead == 'i') ADVANCE(398);
      END_STATE();
    case 296:
      if (lookahead == 'c') ADVANCE(317);
      if (lookahead == 't') ADVANCE(318);
      END_STATE();
    case 297:
      if (lookahead == 'c') ADVANCE(325);
      END_STATE();
    case 298:
      if (lookahead == 'd') ADVANCE(461);
      END_STATE();
    case 299:
      if (lookahead == 'd') ADVANCE(546);
      END_STATE();
    case 300:
      if (lookahead == 'd') ADVANCE(660);
      END_STATE();
    case 301:
      if (lookahead == 'd') ADVANCE(663);
      END_STATE();
    case 302:
      if (lookahead == 'd') ADVANCE(552);
      END_STATE();
    case 303:
      if (lookahead == 'd') ADVANCE(460);
      END_STATE();
    case 304:
      if (lookahead == 'd') ADVANCE(425);
      END_STATE();
    case 305:
      if (lookahead == 'd') ADVANCE(404);
      END_STATE();
    case 306:
      if (lookahead == 'd') ADVANCE(311);
      END_STATE();
    case 307:
      if (lookahead == 'e') ADVANCE(393);
      END_STATE();
    case 308:
      if (lookahead == 'e') ADVANCE(576);
      END_STATE();
    case 309:
      if (lookahead == 'e') ADVANCE(481);
      END_STATE();
    case 310:
      if (lookahead == 'e') ADVANCE(536);
      END_STATE();
    case 311:
      if (lookahead == 'e') ADVANCE(540);
      END_STATE();
    case 312:
      if (lookahead == 'e') ADVANCE(580);
      END_STATE();
    case 313:
      if (lookahead == 'e') ADVANCE(394);
      END_STATE();
    case 314:
      if (lookahead == 'e') ADVANCE(394);
      if (lookahead == 'o') ADVANCE(301);
      END_STATE();
    case 315:
      if (lookahead == 'e') ADVANCE(394);
      if (lookahead == 'o') ADVANCE(300);
      END_STATE();
    case 316:
      if (lookahead == 'e') ADVANCE(394);
      if (lookahead == 'o') ADVANCE(305);
      END_STATE();
    case 317:
      if (lookahead == 'e') ADVANCE(379);
      END_STATE();
    case 318:
      if (lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 319:
      if (lookahead == 'e') ADVANCE(387);
      END_STATE();
    case 320:
      if (lookahead == 'e') ADVANCE(348);
      END_STATE();
    case 321:
      if (lookahead == 'e') ADVANCE(349);
      END_STATE();
    case 322:
      if (lookahead == 'e') ADVANCE(384);
      END_STATE();
    case 323:
      if (lookahead == 'h') ADVANCE(548);
      END_STATE();
    case 324:
      if (lookahead == 'h') ADVANCE(375);
      END_STATE();
    case 325:
      if (lookahead == 'h') ADVANCE(427);
      END_STATE();
    case 326:
      if (lookahead == 'h') ADVANCE(319);
      if (lookahead == 'i') ADVANCE(398);
      END_STATE();
    case 327:
      if (lookahead == 'h') ADVANCE(321);
      END_STATE();
    case 328:
      if (lookahead == 'h') ADVANCE(321);
      if (lookahead == 'y') ADVANCE(380);
      END_STATE();
    case 329:
      if (lookahead == 'i') ADVANCE(407);
      END_STATE();
    case 330:
      if (lookahead == 'i') ADVANCE(399);
      END_STATE();
    case 331:
      if (lookahead == 'i') ADVANCE(376);
      END_STATE();
    case 332:
      if (lookahead == 'i') ADVANCE(395);
      END_STATE();
    case 333:
      if (lookahead == 'i') ADVANCE(360);
      END_STATE();
    case 334:
      if (lookahead == 'i') ADVANCE(292);
      END_STATE();
    case 335:
      if (lookahead == 'l') ADVANCE(390);
      END_STATE();
    case 336:
      if (lookahead == 'l') ADVANCE(390);
      if (lookahead == 'n') ADVANCE(299);
      END_STATE();
    case 337:
      if (lookahead == 'l') ADVANCE(390);
      if (lookahead == 'n') ADVANCE(299);
      if (lookahead == 'x') ADVANCE(296);
      END_STATE();
    case 338:
      if (lookahead == 'l') ADVANCE(544);
      END_STATE();
    case 339:
      if (lookahead == 'l') ADVANCE(405);
      END_STATE();
    case 340:
      if (lookahead == 'l') ADVANCE(479);
      END_STATE();
    case 341:
      if (lookahead == 'l') ADVANCE(287);
      END_STATE();
    case 342:
      if (lookahead == 'l') ADVANCE(287);
      if (lookahead == 'o') ADVANCE(356);
      END_STATE();
    case 343:
      if (lookahead == 'l') ADVANCE(329);
      END_STATE();
    case 344:
      if (lookahead == 'l') ADVANCE(310);
      END_STATE();
    case 345:
      if (lookahead == 'n') ADVANCE(648);
      END_STATE();
    case 346:
      if (lookahead == 'n') ADVANCE(298);
      if (lookahead == 's') ADVANCE(382);
      END_STATE();
    case 347:
      if (lookahead == 'n') ADVANCE(295);
      END_STATE();
    case 348:
      if (lookahead == 'n') ADVANCE(538);
      END_STATE();
    case 349:
      if (lookahead == 'n') ADVANCE(574);
      END_STATE();
    case 350:
      if (lookahead == 'n') ADVANCE(534);
      END_STATE();
    case 351:
      if (lookahead == 'n') ADVANCE(556);
      END_STATE();
    case 352:
      if (lookahead == 'n') ADVANCE(326);
      END_STATE();
    case 353:
      if (lookahead == 'n') ADVANCE(554);
      END_STATE();
    case 354:
      if (lookahead == 'n') ADVANCE(299);
      END_STATE();
    case 355:
      if (lookahead == 'n') ADVANCE(299);
      if (lookahead == 'x') ADVANCE(296);
      END_STATE();
    case 356:
      if (lookahead == 'n') ADVANCE(392);
      END_STATE();
    case 357:
      if (lookahead == 'n') ADVANCE(300);
      END_STATE();
    case 358:
      if (lookahead == 'n') ADVANCE(303);
      END_STATE();
    case 359:
      if (lookahead == 'n') ADVANCE(303);
      if (lookahead == 's') ADVANCE(382);
      END_STATE();
    case 360:
      if (lookahead == 'n') ADVANCE(396);
      END_STATE();
    case 361:
      if (lookahead == 'n') ADVANCE(304);
      if (lookahead == 's') ADVANCE(382);
      END_STATE();
    case 362:
      if (lookahead == 'n') ADVANCE(403);
      END_STATE();
    case 363:
      if (lookahead == 'n') ADVANCE(312);
      if (lookahead == 'w') ADVANCE(362);
      END_STATE();
    case 364:
      if (lookahead == 'n') ADVANCE(293);
      END_STATE();
    case 365:
      ADVANCE_MAP(
        'o', 417,
        'x', 434,
        ' ', 642,
        '"', 642,
        '\'', 642,
        '\\', 642,
        'b', 642,
        'n', 642,
        'r', 642,
        't', 642,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(424);
      END_STATE();
    case 366:
      if (lookahead == 'o') ADVANCE(578);
      END_STATE();
    case 367:
      if (lookahead == 'o') ADVANCE(363);
      END_STATE();
    case 368:
      if (lookahead == 'o') ADVANCE(582);
      END_STATE();
    case 369:
      if (lookahead == 'o') ADVANCE(582);
      if (lookahead == 'y') ADVANCE(380);
      END_STATE();
    case 370:
      if (lookahead == 'o') ADVANCE(584);
      END_STATE();
    case 371:
      if (lookahead == 'o') ADVANCE(383);
      END_STATE();
    case 372:
      if (lookahead == 'o') ADVANCE(356);
      END_STATE();
    case 373:
      if (lookahead == 'o') ADVANCE(301);
      END_STATE();
    case 374:
      if (lookahead == 'o') ADVANCE(300);
      END_STATE();
    case 375:
      if (lookahead == 'o') ADVANCE(302);
      END_STATE();
    case 376:
      if (lookahead == 'o') ADVANCE(350);
      END_STATE();
    case 377:
      if (lookahead == 'p') ADVANCE(320);
      END_STATE();
    case 378:
      if (lookahead == 'p') ADVANCE(320);
      if (lookahead == 'r') ADVANCE(681);
      END_STATE();
    case 379:
      if (lookahead == 'p') ADVANCE(401);
      END_STATE();
    case 380:
      if (lookahead == 'p') ADVANCE(309);
      END_STATE();
    case 381:
      if (lookahead == 'r') ADVANCE(681);
      END_STATE();
    case 382:
      if (lookahead == 'r') ADVANCE(657);
      END_STATE();
    case 383:
      if (lookahead == 'r') ADVANCE(660);
      END_STATE();
    case 384:
      if (lookahead == 'r') ADVANCE(558);
      END_STATE();
    case 385:
      if (lookahead == 'r') ADVANCE(291);
      END_STATE();
    case 386:
      if (lookahead == 'r') ADVANCE(364);
      END_STATE();
    case 387:
      if (lookahead == 'r') ADVANCE(332);
      END_STATE();
    case 388:
      if (lookahead == 's') ADVANCE(382);
      END_STATE();
    case 389:
      if (lookahead == 's') ADVANCE(542);
      END_STATE();
    case 390:
      if (lookahead == 's') ADVANCE(308);
      END_STATE();
    case 391:
      if (lookahead == 's') ADVANCE(389);
      END_STATE();
    case 392:
      if (lookahead == 's') ADVANCE(402);
      END_STATE();
    case 393:
      if (lookahead == 't') ADVANCE(457);
      END_STATE();
    case 394:
      if (lookahead == 't') ADVANCE(324);
      END_STATE();
    case 395:
      if (lookahead == 't') ADVANCE(550);
      END_STATE();
    case 396:
      if (lookahead == 't') ADVANCE(532);
      END_STATE();
    case 397:
      if (lookahead == 't') ADVANCE(297);
      END_STATE();
    case 398:
      if (lookahead == 't') ADVANCE(334);
      END_STATE();
    case 399:
      if (lookahead == 't') ADVANCE(323);
      END_STATE();
    case 400:
      if (lookahead == 't') ADVANCE(426);
      END_STATE();
    case 401:
      if (lookahead == 't') ADVANCE(331);
      END_STATE();
    case 402:
      if (lookahead == 't') ADVANCE(385);
      END_STATE();
    case 403:
      if (lookahead == 't') ADVANCE(370);
      END_STATE();
    case 404:
      if (lookahead == 'u') ADVANCE(344);
      END_STATE();
    case 405:
      if (lookahead == 'u') ADVANCE(306);
      END_STATE();
    case 406:
      if (lookahead == 'y') ADVANCE(380);
      END_STATE();
    case 407:
      if (lookahead == 'z') ADVANCE(322);
      END_STATE();
    case 408:
      if (lookahead == '{') ADVANCE(432);
      END_STATE();
    case 409:
      if (lookahead == '|') ADVANCE(682);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 410:
      if (lookahead == '}') ADVANCE(635);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(410);
      END_STATE();
    case 411:
      if (lookahead == '}') ADVANCE(587);
      END_STATE();
    case 412:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(421);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(614);
      END_STATE();
    case 413:
      if (lookahead == 'l' ||
          lookahead == 'r') ADVANCE(657);
      END_STATE();
    case 414:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(611);
      END_STATE();
    case 415:
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(647);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(415);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(646);
      END_STATE();
    case 416:
      if (lookahead == 'L' ||
          lookahead == 'l' ||
          lookahead == 'n') ADVANCE(647);
      if (set_contains(sym_conversion_specification_character_set_6, 15, lookahead)) ADVANCE(646);
      END_STATE();
    case 417:
      if (('0' <= lookahead && lookahead <= '3')) ADVANCE(419);
      END_STATE();
    case 418:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(645);
      END_STATE();
    case 419:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(418);
      END_STATE();
    case 420:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(588);
      END_STATE();
    case 421:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(614);
      END_STATE();
    case 422:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(279);
      END_STATE();
    case 423:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(643);
      END_STATE();
    case 424:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(423);
      END_STATE();
    case 425:
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(687);
      END_STATE();
    case 426:
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(686);
      END_STATE();
    case 427:
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(688);
      END_STATE();
    case 428:
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 429:
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      END_STATE();
    case 430:
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(656);
      END_STATE();
    case 431:
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 432:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(410);
      END_STATE();
    case 433:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(644);
      END_STATE();
    case 434:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(433);
      END_STATE();
    case 435:
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 436:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '!', 488,
        '"', 628,
        '#', 568,
        '$', 420,
        '%', 602,
        '&', 564,
        '\'', 623,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 487,
        ',', 485,
        '-', 490,
        '.', 519,
        '0', 605,
        ':', 511,
        ';', 530,
        '<', 566,
        '=', 465,
        '>', 562,
        '?', 468,
        '@', 668,
        '[', 498,
        '\\', 2,
        ']', 507,
        '^', 670,
        '`', 836,
        'a', 760,
        'c', 754,
        'd', 781,
        'e', 748,
        'i', 761,
        'l', 719,
        'm', 691,
        'o', 793,
        't', 740,
        'v', 689,
        'w', 744,
        '{', 525,
        '|', 494,
        '}', 531,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(436);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 437:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '!', 275,
        '"', 628,
        '#', 834,
        '&', 679,
        '\'', 835,
        '(', 477,
        ')', 478,
        '*', 661,
        '+', 619,
        ',', 485,
        '-', 620,
        '.', 518,
        '0', 605,
        ':', 513,
        ';', 530,
        '<', 673,
        '>', 674,
        '[', 500,
        ']', 507,
        '`', 836,
        'a', 346,
        'c', 342,
        'd', 366,
        'e', 337,
        'i', 347,
        'l', 288,
        'm', 314,
        'o', 378,
        't', 328,
        'v', 286,
        'w', 330,
        '{', 524,
        '|', 496,
        '}', 531,
        '$', 676,
        '=', 676,
        '%', 664,
        '/', 664,
        '@', 670,
        '^', 670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(437);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      END_STATE();
    case 438:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        '0', 605,
        ':', 470,
        ';', 271,
        '=', 465,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 525,
        '|', 492,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(439);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 439:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '!', 650,
        '"', 628,
        '#', 568,
        '$', 420,
        '\'', 623,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        '0', 605,
        ';', 271,
        '=', 465,
        '?', 469,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 525,
        '|', 492,
        '~', 467,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(439);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 440:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '*', 522,
        '+', 616,
        '-', 622,
        '.', 518,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 524,
        '|', 492,
        '~', 466,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(440);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 441:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 508,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(441);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 442:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '"', 628,
        '#', 567,
        '\'', 623,
        '(', 477,
        '0', 605,
        ':', 470,
        ';', 271,
        '=', 465,
        '?', 468,
        '[', 500,
        '\\', 219,
        ']', 507,
        '`', 836,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 524,
        '~', 466,
        '+', 616,
        '-', 616,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(441);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(606);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 443:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 568,
        '(', 477,
        ')', 478,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 511,
        ';', 271,
        '=', 465,
        '[', 247,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 767,
        'm', 727,
        'o', 794,
        't', 826,
        'v', 689,
        'w', 744,
        '{', 248,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(443);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 444:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 568,
        ')', 478,
        '*', 522,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 510,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        'w', 744,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(444);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 445:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 834,
        '%', 602,
        '(', 477,
        ')', 478,
        '*', 522,
        '+', 272,
        '-', 277,
        '.', 518,
        ':', 516,
        ';', 271,
        '=', 465,
        '[', 247,
        ']', 507,
        'a', 358,
        'c', 342,
        'e', 355,
        'i', 347,
        'l', 307,
        'm', 316,
        'o', 377,
        't', 406,
        'v', 286,
        'w', 330,
        '{', 248,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(445);
      END_STATE();
    case 446:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 834,
        '&', 563,
        ')', 478,
        ',', 485,
        '-', 277,
        ':', 274,
        ';', 271,
        '=', 465,
        '>', 562,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 768,
        'l', 719,
        'm', 727,
        'o', 794,
        't', 826,
        'v', 689,
        'w', 744,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(446);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 447:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 834,
        '(', 477,
        ')', 478,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 509,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(447);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 448:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 834,
        ')', 478,
        '-', 277,
        ':', 274,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 771,
        'l', 719,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        'w', 744,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(448);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 449:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 834,
        ')', 478,
        ':', 508,
        ';', 271,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 769,
        'i', 768,
        'l', 719,
        'm', 727,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(449);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 450:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '(', 477,
        ')', 478,
        '*', 522,
        ',', 485,
        '-', 277,
        '.', 518,
        ':', 510,
        ';', 271,
        '<', 565,
        '=', 465,
        '?', 468,
        '[', 499,
        '\\', 219,
        ']', 507,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 248,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(450);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 451:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        ':', 508,
        ';', 271,
        '=', 465,
        '[', 505,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(451);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 452:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 567,
        '\'', 835,
        '(', 477,
        '*', 522,
        '-', 277,
        '.', 518,
        ';', 271,
        '[', 505,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 755,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
        '|', 492,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(452);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 453:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        '#', 567,
        '*', 522,
        '-', 277,
        ':', 515,
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'a', 777,
        'c', 754,
        'e', 824,
        'i', 771,
        'm', 786,
        'o', 794,
        't', 826,
        'v', 689,
        'w', 744,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(453);
      if (set_contains(sym__uppercase_identifier_character_set_1, 611, lookahead)) ADVANCE(833);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 454:
      if (eof) ADVANCE(455);
      ADVANCE_MAP(
        ';', 271,
        '=', 465,
        '[', 255,
        '\\', 219,
        ']', 507,
        'c', 754,
        'e', 769,
        'i', 768,
        'm', 727,
        'o', 794,
        't', 826,
        'v', 689,
        '{', 256,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(454);
      if (set_contains(sym__lowercase_identifier_character_set_3, 624, lookahead)) ADVANCE(832);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_SEMI_SEMI);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_let);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(686);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_let);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(686);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_let);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_and);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(687);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_and);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(687);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_and);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_COLON_GT);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(569);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(491);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(684);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(684);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_external);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_external);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_type);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(653);
      if (lookahead == '=') ADVANCE(484);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(653);
      if (lookahead == '>') ADVANCE(520);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(571);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(571);
      if (lookahead == '|') ADVANCE(681);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(571);
      if (lookahead == '|') ADVANCE(682);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(682);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(596);
      if (lookahead == '<') ADVANCE(561);
      if (lookahead == '>') ADVANCE(560);
      if (lookahead == '@') ADVANCE(630);
      if (lookahead == '|') ADVANCE(570);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(596);
      if (lookahead == '<') ADVANCE(561);
      if (lookahead == '>') ADVANCE(560);
      if (lookahead == '@') ADVANCE(589);
      if (lookahead == '|') ADVANCE(570);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(596);
      if (lookahead == '<') ADVANCE(561);
      if (lookahead == '>') ADVANCE(560);
      if (lookahead == '@') ADVANCE(590);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(596);
      if (lookahead == '@') ADVANCE(590);
      if (lookahead == '|') ADVANCE(570);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(595);
      if (lookahead == '<') ADVANCE(561);
      if (lookahead == '>') ADVANCE(560);
      if (lookahead == '@') ADVANCE(589);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(595);
      if (lookahead == '@') ADVANCE(589);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(595);
      if (lookahead == '@') ADVANCE(589);
      if (lookahead == '|') ADVANCE(570);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(595);
      if (lookahead == '@') ADVANCE(591);
      if (lookahead == '|') ADVANCE(570);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(249);
      if (lookahead == '@') ADVANCE(590);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '@') ADVANCE(589);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_COLON2);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(569);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(491);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(491);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(684);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '=') ADVANCE(684);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(569);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '=') ADVANCE(491);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '=') ADVANCE(491);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '>') ADVANCE(464);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(483);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(598);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(598);
      if (lookahead == '<') ADVANCE(586);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(597);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(597);
      if (lookahead == '<') ADVANCE(586);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '%') ADVANCE(250);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_SEMI);
      if (lookahead == ';') ADVANCE(456);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_constraint);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_constraint);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_exception);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_exception);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_module);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_open);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_open);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_include);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_include);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_class);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_val);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_val);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_end);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_with);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_inherit);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_inherit);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_method);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_method);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'c') ADVANCE(756);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'c') ADVANCE(339);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_in);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_initializer);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_initializer);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_LBRACK_GT);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_LBRACK_LT);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(678);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(572);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(656);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_LBRACK_PIPE);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_PIPE_RBRACK);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_then);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_else);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_do);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_done);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_done);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_to);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_downto);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_downto);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_LBRACE_LT);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_GT_RBRACE);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_ocamlyacc_value);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(588);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(aux_sym_attribute_token1);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(aux_sym_attribute_token1);
      if (lookahead == '@') ADVANCE(593);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(aux_sym_attribute_token1);
      if (lookahead == '@') ADVANCE(592);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_LBRACK_AT_AT);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_LBRACK_AT_AT);
      if (lookahead == '@') ADVANCE(594);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_LBRACK_AT_AT_AT);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_LBRACK_PERCENT);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_LBRACK_PERCENT);
      if (lookahead == '%') ADVANCE(600);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_LBRACE_PERCENT);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_LBRACE_PERCENT);
      if (lookahead == '%') ADVANCE(601);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(aux_sym_quoted_extension_token1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(599);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_LBRACK_PERCENT_PERCENT);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_LBRACE_PERCENT_PERCENT);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(664);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(aux_sym_number_token1);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(aux_sym_number_token1);
      ADVANCE_MAP(
        '.', 609,
        'B', 414,
        'b', 414,
        'E', 412,
        'e', 412,
        'O', 612,
        'o', 612,
        'X', 615,
        'x', 615,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(606);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(609);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(606);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(610);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(608);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(607);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(421);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(614);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(609);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(608);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(610);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '_') ADVANCE(611);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(613);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == '_') ADVANCE(613);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(614);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(604);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(607);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(653);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(653);
      if (lookahead == '>') ADVANCE(520);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(655);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(654);
      if (lookahead == '>') ADVANCE(429);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(666);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '.') ADVANCE(654);
      if (lookahead == '>') ADVANCE(521);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(666);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(aux_sym_signed_number_token1);
      if (lookahead == '>') ADVANCE(520);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym_SQUOTE2);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(aux_sym_character_content_token1);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(aux_sym_character_content_token2);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(aux_sym_character_content_token2);
      if (lookahead == '@') ADVANCE(589);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(aux_sym_string_content_token2);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      ADVANCE_MAP(
        '*', 267,
        '.', 261,
        'L', 647,
        'l', 647,
        'n', 647,
        ' ', 260,
        '#', 260,
        '+', 260,
        '-', 260,
        '0', 260,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(266);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(646);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      ADVANCE_MAP(
        '<', 422,
        '\\', 345,
        ' ', 648,
        ',', 648,
        '.', 648,
        ';', 648,
        '?', 648,
        '[', 648,
        ']', 648,
        '{', 648,
        '}', 648,
      );
      END_STATE();
    case 633:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      if (lookahead == '@') ADVANCE(630);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(634);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(aux_sym_string_content_token3);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '@' &&
          lookahead != '\\') ADVANCE(634);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(aux_sym_string_content_token4);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(aux_sym_string_content_token5);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(636);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      ADVANCE_MAP(
        '*', 267,
        '.', 261,
        'L', 647,
        'l', 647,
        'n', 647,
        ' ', 260,
        '#', 260,
        '+', 260,
        '-', 260,
        '0', 260,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(266);
      if (set_contains(sym_conversion_specification_character_set_7, 16, lookahead)) ADVANCE(646);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      ADVANCE_MAP(
        '<', 422,
        '\\', 345,
        ' ', 648,
        ',', 648,
        '.', 648,
        ';', 648,
        '?', 648,
        '[', 648,
        ']', 648,
        '{', 648,
        '}', 648,
      );
      END_STATE();
    case 640:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      if (lookahead == '@') ADVANCE(630);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '|') ADVANCE(641);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(aux_sym_quoted_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '@' &&
          lookahead != '|') ADVANCE(641);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token1);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token3);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token4);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(sym_conversion_specification);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(sym_conversion_specification);
      if (lookahead == 'X' ||
          lookahead == 'd' ||
          lookahead == 'i' ||
          lookahead == 'o' ||
          lookahead == 'u' ||
          lookahead == 'x') ADVANCE(646);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym_pretty_printing_indication);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(sym_pretty_printing_indication);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(670);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_prefix_operator);
      if (lookahead == '=') ADVANCE(431);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_prefix_operator);
      if (lookahead == '=') ADVANCE(677);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_prefix_operator);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(aux_sym_sign_operator_token1);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(aux_sym_sign_operator_token1);
      if (lookahead == '>') ADVANCE(667);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(666);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(aux_sym_sign_operator_token1);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_hash_operator);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(656);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_pow_operator);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_pow_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(658);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_pow_operator);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(sym_mult_operator);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym_mult_operator);
      if (lookahead == '*') ADVANCE(658);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(664);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym_mult_operator);
      if (lookahead == 'u') ADVANCE(758);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym_mult_operator);
      if (lookahead == 'u') ADVANCE(344);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(sym_mult_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(664);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(sym_mult_operator);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(aux_sym_add_operator_token1);
      if (lookahead == '>') ADVANCE(667);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(666);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(aux_sym_add_operator_token1);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(667);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(sym_concat_operator);
      ADVANCE_MAP(
        '<', 669,
        '\\', 345,
        '.', 649,
        '?', 649,
        ' ', 648,
        ',', 648,
        ';', 648,
        '[', 648,
        ']', 648,
        '{', 648,
        '}', 648,
      );
      if (lookahead == '!' ||
          ('$' <= lookahead && lookahead <= '&') ||
          ('*' <= lookahead && lookahead <= '/') ||
          (':' <= lookahead && lookahead <= '@') ||
          lookahead == '^' ||
          ('|' <= lookahead && lookahead <= '~')) ADVANCE(670);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(sym_concat_operator);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(279);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(670);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(sym_concat_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(670);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(sym_rel_operator);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym_rel_operator);
      if (lookahead == '-') ADVANCE(573);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(sym_rel_operator);
      if (lookahead == '-') ADVANCE(428);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym_rel_operator);
      if (lookahead == '}') ADVANCE(587);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(sym_rel_operator);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(588);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(sym_rel_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym_rel_operator);
      if (set_contains(sym_prefix_operator_character_set_1, 9, lookahead)) ADVANCE(652);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym_and_operator);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(sym_and_operator);
      if (lookahead == '&') ADVANCE(680);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(sym_and_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(sym_or_operator);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(sym_or_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(676);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(sym_or_operator);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(sym_assign_operator);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(sym_indexing_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(685);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(sym_let_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(686);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(sym_let_and_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(687);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(sym_match_operator);
      if (set_contains(sym_pow_operator_character_set_1, 9, lookahead)) ADVANCE(688);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(752);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(807);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == 'e') ADVANCE(811);
      if (lookahead == 'o') ADVANCE(712);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == 'e') ADVANCE(811);
      if (lookahead == 'o') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == 'e') ADVANCE(811);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == 'o') ADVANCE(712);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == 'o') ADVANCE(715);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == 'o') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(745);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(753);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(757);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(774);
      if (lookahead == 'e') ADVANCE(809);
      if (lookahead == 'o') ADVANCE(799);
      if (lookahead == 's') ADVANCE(828);
      if (lookahead == 'x') ADVANCE(787);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(774);
      if (lookahead == 'e') ADVANCE(818);
      if (lookahead == 'o') ADVANCE(799);
      if (lookahead == 's') ADVANCE(828);
      if (lookahead == 'x') ADVANCE(787);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'a') ADVANCE(774);
      if (lookahead == 'o') ADVANCE(799);
      if (lookahead == 's') ADVANCE(828);
      if (lookahead == 'x') ADVANCE(787);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(756);
      if (lookahead == 'h') ADVANCE(732);
      if (lookahead == 'i') ADVANCE(819);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(756);
      if (lookahead == 'h') ADVANCE(732);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(756);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(736);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(726);
      if (lookahead == 't') ADVANCE(721);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'c') ADVANCE(726);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(462);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(547);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(821);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(553);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(665);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(662);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(463);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(829);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'd') ADVANCE(724);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(809);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(577);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(802);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(482);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 723:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(537);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(541);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(581);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(796);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(811);
      if (lookahead == 'o') ADVANCE(712);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(811);
      if (lookahead == 'o') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(811);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(762);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(763);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(803);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(800);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'e') ADVANCE(814);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(549);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(831);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(788);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(732);
      if (lookahead == 'i') ADVANCE(819);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(732);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(731);
      if (lookahead == 'o') ADVANCE(583);
      if (lookahead == 'y') ADVANCE(795);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'h') ADVANCE(731);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(827);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(791);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(816);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(775);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(813);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'i') ADVANCE(700);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(805);
      if (lookahead == 'n') ADVANCE(711);
      if (lookahead == 'x') ADVANCE(708);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(805);
      if (lookahead == 'n') ADVANCE(711);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(805);
      if (lookahead == 'x') ADVANCE(708);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(805);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(545);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(480);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(690);
      if (lookahead == 'o') ADVANCE(772);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(690);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(822);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(742);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l') ADVANCE(723);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(710);
      if (lookahead == 's') ADVANCE(798);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(710);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(555);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(539);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(575);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(535);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(738);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(557);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(705);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(704);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(711);
      if (lookahead == 'x') ADVANCE(708);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(711);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(706);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(808);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(739);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(812);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(717);
      if (lookahead == 's') ADVANCE(798);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(716);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(820);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(725);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'n') ADVANCE(699);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(579);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(583);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(823);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(585);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(772);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(712);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(799);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(713);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(715);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(714);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(764);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'o') ADVANCE(779);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(730);
      if (lookahead == 'r') ADVANCE(683);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(730);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(722);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'p') ADVANCE(815);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(683);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(659);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(665);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(559);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(698);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(780);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'r') ADVANCE(746);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(543);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(720);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(798);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(804);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 's') ADVANCE(817);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(458);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(707);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(737);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(533);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(551);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(459);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(743);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(735);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(801);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(830);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(747);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 't') ADVANCE(784);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 821:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'u') ADVANCE(758);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 822:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'u') ADVANCE(718);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 823:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'w') ADVANCE(778);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 824:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'x') ADVANCE(708);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 825:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'x') ADVANCE(709);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 826:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'y') ADVANCE(795);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 827:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'z') ADVANCE(733);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (lookahead == 'l' ||
          lookahead == 'r') ADVANCE(659);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(687);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(686);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym_let_operator_character_set_1, 9, lookahead)) ADVANCE(688);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(sym__lowercase_identifier);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(832);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(sym__uppercase_identifier);
      if (set_contains(sym__lowercase_identifier_character_set_2, 777, lookahead)) ADVANCE(833);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(aux_sym_directive_token1);
      END_STATE();
    case 835:
      ACCEPT_TOKEN(aux_sym_type_variable_token1);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(aux_sym_attribute_id_token1);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        '_', 1,
        'a', 2,
        'b', 3,
        'e', 4,
        'f', 5,
        'i', 6,
        'l', 7,
        'm', 8,
        'n', 9,
        'o', 10,
        'p', 11,
        'r', 12,
        's', 13,
        't', 14,
        'v', 15,
        'w', 16,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      ACCEPT_TOKEN(anon_sym__);
      END_STATE();
    case 2:
      if (lookahead == 's') ADVANCE(17);
      END_STATE();
    case 3:
      if (lookahead == 'e') ADVANCE(18);
      END_STATE();
    case 4:
      if (lookahead == 'f') ADVANCE(19);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(20);
      if (lookahead == 'o') ADVANCE(21);
      if (lookahead == 'u') ADVANCE(22);
      END_STATE();
    case 6:
      if (lookahead == 'f') ADVANCE(23);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(24);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(25);
      if (lookahead == 'u') ADVANCE(26);
      END_STATE();
    case 9:
      if (lookahead == 'e') ADVANCE(27);
      if (lookahead == 'o') ADVANCE(28);
      END_STATE();
    case 10:
      if (lookahead == 'b') ADVANCE(29);
      if (lookahead == 'f') ADVANCE(30);
      END_STATE();
    case 11:
      if (lookahead == 'r') ADVANCE(31);
      END_STATE();
    case 12:
      if (lookahead == 'e') ADVANCE(32);
      END_STATE();
    case 13:
      if (lookahead == 'i') ADVANCE(33);
      if (lookahead == 't') ADVANCE(34);
      END_STATE();
    case 14:
      if (lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 15:
      if (lookahead == 'i') ADVANCE(36);
      END_STATE();
    case 16:
      if (lookahead == 'h') ADVANCE(37);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(38);
      END_STATE();
    case 18:
      if (lookahead == 'g') ADVANCE(39);
      END_STATE();
    case 19:
      if (lookahead == 'f') ADVANCE(40);
      END_STATE();
    case 20:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 21:
      if (lookahead == 'r') ADVANCE(42);
      END_STATE();
    case 22:
      if (lookahead == 'n') ADVANCE(43);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 24:
      if (lookahead == 'z') ADVANCE(44);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(45);
      END_STATE();
    case 26:
      if (lookahead == 't') ADVANCE(46);
      END_STATE();
    case 27:
      if (lookahead == 'w') ADVANCE(47);
      END_STATE();
    case 28:
      if (lookahead == 'n') ADVANCE(48);
      END_STATE();
    case 29:
      if (lookahead == 'j') ADVANCE(49);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 31:
      if (lookahead == 'i') ADVANCE(50);
      END_STATE();
    case 32:
      if (lookahead == 'c') ADVANCE(51);
      END_STATE();
    case 33:
      if (lookahead == 'g') ADVANCE(52);
      END_STATE();
    case 34:
      if (lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(54);
      if (lookahead == 'y') ADVANCE(55);
      END_STATE();
    case 36:
      if (lookahead == 'r') ADVANCE(56);
      END_STATE();
    case 37:
      if (lookahead == 'e') ADVANCE(57);
      if (lookahead == 'i') ADVANCE(58);
      END_STATE();
    case 38:
      if (lookahead == 'e') ADVANCE(59);
      END_STATE();
    case 39:
      if (lookahead == 'i') ADVANCE(60);
      END_STATE();
    case 40:
      if (lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(62);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_fun);
      if (lookahead == 'c') ADVANCE(63);
      END_STATE();
    case 44:
      if (lookahead == 'y') ADVANCE(64);
      END_STATE();
    case 45:
      if (lookahead == 'c') ADVANCE(65);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(66);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 48:
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(68);
      END_STATE();
    case 50:
      if (lookahead == 'v') ADVANCE(69);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_rec);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_sig);
      END_STATE();
    case 53:
      if (lookahead == 'u') ADVANCE(70);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(71);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 56:
      if (lookahead == 't') ADVANCE(72);
      END_STATE();
    case 57:
      if (lookahead == 'n') ADVANCE(73);
      END_STATE();
    case 58:
      if (lookahead == 'l') ADVANCE(74);
      END_STATE();
    case 59:
      if (lookahead == 'r') ADVANCE(75);
      END_STATE();
    case 60:
      if (lookahead == 'n') ADVANCE(76);
      END_STATE();
    case 61:
      if (lookahead == 'c') ADVANCE(77);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(78);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_lazy);
      END_STATE();
    case 65:
      if (lookahead == 'h') ADVANCE(80);
      END_STATE();
    case 66:
      if (lookahead == 'b') ADVANCE(81);
      END_STATE();
    case 67:
      if (lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 68:
      if (lookahead == 'c') ADVANCE(83);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 70:
      if (lookahead == 'c') ADVANCE(85);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 72:
      if (lookahead == 'u') ADVANCE(86);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 75:
      if (lookahead == 't') ADVANCE(88);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_begin);
      END_STATE();
    case 77:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(90);
      if (lookahead == 'o') ADVANCE(91);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 81:
      if (lookahead == 'l') ADVANCE(92);
      END_STATE();
    case 82:
      if (lookahead == 'c') ADVANCE(93);
      END_STATE();
    case 83:
      if (lookahead == 't') ADVANCE(94);
      END_STATE();
    case 84:
      if (lookahead == 't') ADVANCE(95);
      END_STATE();
    case 85:
      if (lookahead == 't') ADVANCE(96);
      END_STATE();
    case 86:
      if (lookahead == 'a') ADVANCE(97);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_effect);
      END_STATE();
    case 90:
      if (lookahead == 'o') ADVANCE(98);
      END_STATE();
    case 91:
      if (lookahead == 'r') ADVANCE(99);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_nonrec);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 97:
      if (lookahead == 'l') ADVANCE(102);
      END_STATE();
    case 98:
      if (lookahead == 'n') ADVANCE(103);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_functor);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_mutable);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_virtual);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 437, .external_lex_state = 2},
  [2] = {.lex_state = 32, .external_lex_state = 3},
  [3] = {.lex_state = 32, .external_lex_state = 3},
  [4] = {.lex_state = 32, .external_lex_state = 3},
  [5] = {.lex_state = 32, .external_lex_state = 3},
  [6] = {.lex_state = 32, .external_lex_state = 3},
  [7] = {.lex_state = 32, .external_lex_state = 3},
  [8] = {.lex_state = 32, .external_lex_state = 3},
  [9] = {.lex_state = 32, .external_lex_state = 3},
  [10] = {.lex_state = 32, .external_lex_state = 3},
  [11] = {.lex_state = 32, .external_lex_state = 3},
  [12] = {.lex_state = 32, .external_lex_state = 3},
  [13] = {.lex_state = 32, .external_lex_state = 3},
  [14] = {.lex_state = 32, .external_lex_state = 3},
  [15] = {.lex_state = 32, .external_lex_state = 3},
  [16] = {.lex_state = 32, .external_lex_state = 3},
  [17] = {.lex_state = 32, .external_lex_state = 3},
  [18] = {.lex_state = 32, .external_lex_state = 3},
  [19] = {.lex_state = 32, .external_lex_state = 3},
  [20] = {.lex_state = 32, .external_lex_state = 3},
  [21] = {.lex_state = 32, .external_lex_state = 3},
  [22] = {.lex_state = 32, .external_lex_state = 3},
  [23] = {.lex_state = 32, .external_lex_state = 3},
  [24] = {.lex_state = 32, .external_lex_state = 3},
  [25] = {.lex_state = 32, .external_lex_state = 3},
  [26] = {.lex_state = 32, .external_lex_state = 3},
  [27] = {.lex_state = 32, .external_lex_state = 3},
  [28] = {.lex_state = 32, .external_lex_state = 3},
  [29] = {.lex_state = 32, .external_lex_state = 3},
  [30] = {.lex_state = 32, .external_lex_state = 3},
  [31] = {.lex_state = 32, .external_lex_state = 3},
  [32] = {.lex_state = 32, .external_lex_state = 3},
  [33] = {.lex_state = 32, .external_lex_state = 3},
  [34] = {.lex_state = 32, .external_lex_state = 3},
  [35] = {.lex_state = 32, .external_lex_state = 3},
  [36] = {.lex_state = 32, .external_lex_state = 3},
  [37] = {.lex_state = 32, .external_lex_state = 3},
  [38] = {.lex_state = 32, .external_lex_state = 3},
  [39] = {.lex_state = 32, .external_lex_state = 3},
  [40] = {.lex_state = 32, .external_lex_state = 3},
  [41] = {.lex_state = 32, .external_lex_state = 3},
  [42] = {.lex_state = 32, .external_lex_state = 3},
  [43] = {.lex_state = 32, .external_lex_state = 3},
  [44] = {.lex_state = 32, .external_lex_state = 3},
  [45] = {.lex_state = 32, .external_lex_state = 3},
  [46] = {.lex_state = 32, .external_lex_state = 3},
  [47] = {.lex_state = 32, .external_lex_state = 3},
  [48] = {.lex_state = 32, .external_lex_state = 3},
  [49] = {.lex_state = 32, .external_lex_state = 3},
  [50] = {.lex_state = 32, .external_lex_state = 3},
  [51] = {.lex_state = 32, .external_lex_state = 3},
  [52] = {.lex_state = 32, .external_lex_state = 3},
  [53] = {.lex_state = 32, .external_lex_state = 3},
  [54] = {.lex_state = 32, .external_lex_state = 3},
  [55] = {.lex_state = 32, .external_lex_state = 3},
  [56] = {.lex_state = 32, .external_lex_state = 3},
  [57] = {.lex_state = 32, .external_lex_state = 3},
  [58] = {.lex_state = 32, .external_lex_state = 3},
  [59] = {.lex_state = 32, .external_lex_state = 3},
  [60] = {.lex_state = 32, .external_lex_state = 3},
  [61] = {.lex_state = 32, .external_lex_state = 3},
  [62] = {.lex_state = 32, .external_lex_state = 3},
  [63] = {.lex_state = 32, .external_lex_state = 3},
  [64] = {.lex_state = 32, .external_lex_state = 3},
  [65] = {.lex_state = 32, .external_lex_state = 3},
  [66] = {.lex_state = 32, .external_lex_state = 3},
  [67] = {.lex_state = 32, .external_lex_state = 3},
  [68] = {.lex_state = 32, .external_lex_state = 3},
  [69] = {.lex_state = 32, .external_lex_state = 3},
  [70] = {.lex_state = 32, .external_lex_state = 3},
  [71] = {.lex_state = 32, .external_lex_state = 3},
  [72] = {.lex_state = 32, .external_lex_state = 3},
  [73] = {.lex_state = 32, .external_lex_state = 3},
  [74] = {.lex_state = 32, .external_lex_state = 3},
  [75] = {.lex_state = 32, .external_lex_state = 3},
  [76] = {.lex_state = 32, .external_lex_state = 3},
  [77] = {.lex_state = 32, .external_lex_state = 3},
  [78] = {.lex_state = 32, .external_lex_state = 3},
  [79] = {.lex_state = 32, .external_lex_state = 3},
  [80] = {.lex_state = 32, .external_lex_state = 3},
  [81] = {.lex_state = 32, .external_lex_state = 3},
  [82] = {.lex_state = 32, .external_lex_state = 3},
  [83] = {.lex_state = 32, .external_lex_state = 3},
  [84] = {.lex_state = 32, .external_lex_state = 3},
  [85] = {.lex_state = 32, .external_lex_state = 3},
  [86] = {.lex_state = 32, .external_lex_state = 3},
  [87] = {.lex_state = 32, .external_lex_state = 3},
  [88] = {.lex_state = 32, .external_lex_state = 3},
  [89] = {.lex_state = 33, .external_lex_state = 3},
  [90] = {.lex_state = 33, .external_lex_state = 3},
  [91] = {.lex_state = 107, .external_lex_state = 3},
  [92] = {.lex_state = 114, .external_lex_state = 3},
  [93] = {.lex_state = 32, .external_lex_state = 3},
  [94] = {.lex_state = 33, .external_lex_state = 3},
  [95] = {.lex_state = 109, .external_lex_state = 3},
  [96] = {.lex_state = 116, .external_lex_state = 3},
  [97] = {.lex_state = 33, .external_lex_state = 3},
  [98] = {.lex_state = 111, .external_lex_state = 3},
  [99] = {.lex_state = 115, .external_lex_state = 3},
  [100] = {.lex_state = 32, .external_lex_state = 3},
  [101] = {.lex_state = 32, .external_lex_state = 3},
  [102] = {.lex_state = 32, .external_lex_state = 3},
  [103] = {.lex_state = 33, .external_lex_state = 3},
  [104] = {.lex_state = 33, .external_lex_state = 3},
  [105] = {.lex_state = 32, .external_lex_state = 3},
  [106] = {.lex_state = 117, .external_lex_state = 3},
  [107] = {.lex_state = 32, .external_lex_state = 3},
  [108] = {.lex_state = 110, .external_lex_state = 3},
  [109] = {.lex_state = 113, .external_lex_state = 3},
  [110] = {.lex_state = 118, .external_lex_state = 3},
  [111] = {.lex_state = 112, .external_lex_state = 3},
  [112] = {.lex_state = 119, .external_lex_state = 3},
  [113] = {.lex_state = 54, .external_lex_state = 3},
  [114] = {.lex_state = 54, .external_lex_state = 3},
  [115] = {.lex_state = 147, .external_lex_state = 3},
  [116] = {.lex_state = 147, .external_lex_state = 3},
  [117] = {.lex_state = 145, .external_lex_state = 3},
  [118] = {.lex_state = 146, .external_lex_state = 3},
  [119] = {.lex_state = 145, .external_lex_state = 3},
  [120] = {.lex_state = 146, .external_lex_state = 3},
  [121] = {.lex_state = 36, .external_lex_state = 3},
  [122] = {.lex_state = 34, .external_lex_state = 3},
  [123] = {.lex_state = 162, .external_lex_state = 3},
  [124] = {.lex_state = 162, .external_lex_state = 3},
  [125] = {.lex_state = 35, .external_lex_state = 3},
  [126] = {.lex_state = 37, .external_lex_state = 3},
  [127] = {.lex_state = 163, .external_lex_state = 3},
  [128] = {.lex_state = 144, .external_lex_state = 3},
  [129] = {.lex_state = 144, .external_lex_state = 3},
  [130] = {.lex_state = 144, .external_lex_state = 3},
  [131] = {.lex_state = 144, .external_lex_state = 3},
  [132] = {.lex_state = 144, .external_lex_state = 3},
  [133] = {.lex_state = 144, .external_lex_state = 3},
  [134] = {.lex_state = 144, .external_lex_state = 3},
  [135] = {.lex_state = 144, .external_lex_state = 3},
  [136] = {.lex_state = 144, .external_lex_state = 3},
  [137] = {.lex_state = 144, .external_lex_state = 3},
  [138] = {.lex_state = 144, .external_lex_state = 3},
  [139] = {.lex_state = 144, .external_lex_state = 3},
  [140] = {.lex_state = 144, .external_lex_state = 3},
  [141] = {.lex_state = 144, .external_lex_state = 3},
  [142] = {.lex_state = 144, .external_lex_state = 3},
  [143] = {.lex_state = 144, .external_lex_state = 3},
  [144] = {.lex_state = 144, .external_lex_state = 3},
  [145] = {.lex_state = 144, .external_lex_state = 3},
  [146] = {.lex_state = 144, .external_lex_state = 3},
  [147] = {.lex_state = 144, .external_lex_state = 3},
  [148] = {.lex_state = 144, .external_lex_state = 3},
  [149] = {.lex_state = 144, .external_lex_state = 3},
  [150] = {.lex_state = 144, .external_lex_state = 3},
  [151] = {.lex_state = 144, .external_lex_state = 3},
  [152] = {.lex_state = 144, .external_lex_state = 3},
  [153] = {.lex_state = 144, .external_lex_state = 3},
  [154] = {.lex_state = 144, .external_lex_state = 3},
  [155] = {.lex_state = 144, .external_lex_state = 3},
  [156] = {.lex_state = 144, .external_lex_state = 3},
  [157] = {.lex_state = 144, .external_lex_state = 3},
  [158] = {.lex_state = 144, .external_lex_state = 3},
  [159] = {.lex_state = 144, .external_lex_state = 3},
  [160] = {.lex_state = 144, .external_lex_state = 3},
  [161] = {.lex_state = 144, .external_lex_state = 3},
  [162] = {.lex_state = 144, .external_lex_state = 3},
  [163] = {.lex_state = 144, .external_lex_state = 3},
  [164] = {.lex_state = 144, .external_lex_state = 3},
  [165] = {.lex_state = 163, .external_lex_state = 3},
  [166] = {.lex_state = 144, .external_lex_state = 3},
  [167] = {.lex_state = 144, .external_lex_state = 3},
  [168] = {.lex_state = 144, .external_lex_state = 3},
  [169] = {.lex_state = 144, .external_lex_state = 3},
  [170] = {.lex_state = 144, .external_lex_state = 3},
  [171] = {.lex_state = 144, .external_lex_state = 3},
  [172] = {.lex_state = 144, .external_lex_state = 3},
  [173] = {.lex_state = 144, .external_lex_state = 3},
  [174] = {.lex_state = 144, .external_lex_state = 3},
  [175] = {.lex_state = 144, .external_lex_state = 3},
  [176] = {.lex_state = 144, .external_lex_state = 3},
  [177] = {.lex_state = 144, .external_lex_state = 3},
  [178] = {.lex_state = 144, .external_lex_state = 3},
  [179] = {.lex_state = 144, .external_lex_state = 3},
  [180] = {.lex_state = 144, .external_lex_state = 3},
  [181] = {.lex_state = 144, .external_lex_state = 3},
  [182] = {.lex_state = 144, .external_lex_state = 3},
  [183] = {.lex_state = 144, .external_lex_state = 3},
  [184] = {.lex_state = 144, .external_lex_state = 3},
  [185] = {.lex_state = 144, .external_lex_state = 3},
  [186] = {.lex_state = 144, .external_lex_state = 3},
  [187] = {.lex_state = 144, .external_lex_state = 3},
  [188] = {.lex_state = 144, .external_lex_state = 3},
  [189] = {.lex_state = 144, .external_lex_state = 3},
  [190] = {.lex_state = 150, .external_lex_state = 3},
  [191] = {.lex_state = 144, .external_lex_state = 3},
  [192] = {.lex_state = 144, .external_lex_state = 3},
  [193] = {.lex_state = 144, .external_lex_state = 3},
  [194] = {.lex_state = 144, .external_lex_state = 3},
  [195] = {.lex_state = 144, .external_lex_state = 3},
  [196] = {.lex_state = 144, .external_lex_state = 3},
  [197] = {.lex_state = 144, .external_lex_state = 3},
  [198] = {.lex_state = 144, .external_lex_state = 3},
  [199] = {.lex_state = 144, .external_lex_state = 3},
  [200] = {.lex_state = 144, .external_lex_state = 3},
  [201] = {.lex_state = 144, .external_lex_state = 3},
  [202] = {.lex_state = 144, .external_lex_state = 3},
  [203] = {.lex_state = 144, .external_lex_state = 3},
  [204] = {.lex_state = 144, .external_lex_state = 3},
  [205] = {.lex_state = 144, .external_lex_state = 3},
  [206] = {.lex_state = 144, .external_lex_state = 3},
  [207] = {.lex_state = 144, .external_lex_state = 3},
  [208] = {.lex_state = 144, .external_lex_state = 3},
  [209] = {.lex_state = 144, .external_lex_state = 3},
  [210] = {.lex_state = 144, .external_lex_state = 3},
  [211] = {.lex_state = 144, .external_lex_state = 3},
  [212] = {.lex_state = 144, .external_lex_state = 3},
  [213] = {.lex_state = 144, .external_lex_state = 3},
  [214] = {.lex_state = 144, .external_lex_state = 3},
  [215] = {.lex_state = 144, .external_lex_state = 3},
  [216] = {.lex_state = 157, .external_lex_state = 3},
  [217] = {.lex_state = 33, .external_lex_state = 3},
  [218] = {.lex_state = 32, .external_lex_state = 3},
  [219] = {.lex_state = 148, .external_lex_state = 3},
  [220] = {.lex_state = 154, .external_lex_state = 3},
  [221] = {.lex_state = 155, .external_lex_state = 3},
  [222] = {.lex_state = 152, .external_lex_state = 3},
  [223] = {.lex_state = 151, .external_lex_state = 3},
  [224] = {.lex_state = 156, .external_lex_state = 3},
  [225] = {.lex_state = 148, .external_lex_state = 3},
  [226] = {.lex_state = 153, .external_lex_state = 3},
  [227] = {.lex_state = 155, .external_lex_state = 3},
  [228] = {.lex_state = 156, .external_lex_state = 3},
  [229] = {.lex_state = 159, .external_lex_state = 3},
  [230] = {.lex_state = 160, .external_lex_state = 3},
  [231] = {.lex_state = 149, .external_lex_state = 3},
  [232] = {.lex_state = 158, .external_lex_state = 3},
  [233] = {.lex_state = 154, .external_lex_state = 3},
  [234] = {.lex_state = 161, .external_lex_state = 3},
  [235] = {.lex_state = 158, .external_lex_state = 3},
  [236] = {.lex_state = 160, .external_lex_state = 3},
  [237] = {.lex_state = 159, .external_lex_state = 3},
  [238] = {.lex_state = 149, .external_lex_state = 3},
  [239] = {.lex_state = 43, .external_lex_state = 3},
  [240] = {.lex_state = 42, .external_lex_state = 3},
  [241] = {.lex_state = 50, .external_lex_state = 3},
  [242] = {.lex_state = 47, .external_lex_state = 3},
  [243] = {.lex_state = 47, .external_lex_state = 3},
  [244] = {.lex_state = 47, .external_lex_state = 3},
  [245] = {.lex_state = 47, .external_lex_state = 3},
  [246] = {.lex_state = 47, .external_lex_state = 3},
  [247] = {.lex_state = 47, .external_lex_state = 3},
  [248] = {.lex_state = 47, .external_lex_state = 3},
  [249] = {.lex_state = 47, .external_lex_state = 3},
  [250] = {.lex_state = 47, .external_lex_state = 3},
  [251] = {.lex_state = 47, .external_lex_state = 3},
  [252] = {.lex_state = 47, .external_lex_state = 3},
  [253] = {.lex_state = 47, .external_lex_state = 3},
  [254] = {.lex_state = 47, .external_lex_state = 3},
  [255] = {.lex_state = 47, .external_lex_state = 3},
  [256] = {.lex_state = 47, .external_lex_state = 3},
  [257] = {.lex_state = 47, .external_lex_state = 3},
  [258] = {.lex_state = 47, .external_lex_state = 3},
  [259] = {.lex_state = 47, .external_lex_state = 3},
  [260] = {.lex_state = 47, .external_lex_state = 3},
  [261] = {.lex_state = 47, .external_lex_state = 3},
  [262] = {.lex_state = 47, .external_lex_state = 3},
  [263] = {.lex_state = 47, .external_lex_state = 3},
  [264] = {.lex_state = 47, .external_lex_state = 3},
  [265] = {.lex_state = 47, .external_lex_state = 3},
  [266] = {.lex_state = 47, .external_lex_state = 3},
  [267] = {.lex_state = 47, .external_lex_state = 3},
  [268] = {.lex_state = 47, .external_lex_state = 3},
  [269] = {.lex_state = 47, .external_lex_state = 3},
  [270] = {.lex_state = 47, .external_lex_state = 3},
  [271] = {.lex_state = 47, .external_lex_state = 3},
  [272] = {.lex_state = 47, .external_lex_state = 3},
  [273] = {.lex_state = 47, .external_lex_state = 3},
  [274] = {.lex_state = 47, .external_lex_state = 3},
  [275] = {.lex_state = 47, .external_lex_state = 3},
  [276] = {.lex_state = 47, .external_lex_state = 3},
  [277] = {.lex_state = 47, .external_lex_state = 3},
  [278] = {.lex_state = 47, .external_lex_state = 3},
  [279] = {.lex_state = 47, .external_lex_state = 3},
  [280] = {.lex_state = 47, .external_lex_state = 3},
  [281] = {.lex_state = 47, .external_lex_state = 3},
  [282] = {.lex_state = 45, .external_lex_state = 3},
  [283] = {.lex_state = 47, .external_lex_state = 3},
  [284] = {.lex_state = 47, .external_lex_state = 3},
  [285] = {.lex_state = 47, .external_lex_state = 3},
  [286] = {.lex_state = 42, .external_lex_state = 3},
  [287] = {.lex_state = 42, .external_lex_state = 3},
  [288] = {.lex_state = 42, .external_lex_state = 3},
  [289] = {.lex_state = 42, .external_lex_state = 3},
  [290] = {.lex_state = 42, .external_lex_state = 3},
  [291] = {.lex_state = 42, .external_lex_state = 3},
  [292] = {.lex_state = 42, .external_lex_state = 3},
  [293] = {.lex_state = 42, .external_lex_state = 3},
  [294] = {.lex_state = 42, .external_lex_state = 3},
  [295] = {.lex_state = 42, .external_lex_state = 3},
  [296] = {.lex_state = 42, .external_lex_state = 3},
  [297] = {.lex_state = 42, .external_lex_state = 3},
  [298] = {.lex_state = 48, .external_lex_state = 3},
  [299] = {.lex_state = 42, .external_lex_state = 3},
  [300] = {.lex_state = 42, .external_lex_state = 3},
  [301] = {.lex_state = 42, .external_lex_state = 3},
  [302] = {.lex_state = 42, .external_lex_state = 3},
  [303] = {.lex_state = 42, .external_lex_state = 3},
  [304] = {.lex_state = 42, .external_lex_state = 3},
  [305] = {.lex_state = 42, .external_lex_state = 3},
  [306] = {.lex_state = 42, .external_lex_state = 3},
  [307] = {.lex_state = 42, .external_lex_state = 3},
  [308] = {.lex_state = 42, .external_lex_state = 3},
  [309] = {.lex_state = 42, .external_lex_state = 3},
  [310] = {.lex_state = 42, .external_lex_state = 3},
  [311] = {.lex_state = 42, .external_lex_state = 3},
  [312] = {.lex_state = 42, .external_lex_state = 3},
  [313] = {.lex_state = 44, .external_lex_state = 3},
  [314] = {.lex_state = 42, .external_lex_state = 3},
  [315] = {.lex_state = 42, .external_lex_state = 3},
  [316] = {.lex_state = 42, .external_lex_state = 3},
  [317] = {.lex_state = 42, .external_lex_state = 3},
  [318] = {.lex_state = 46, .external_lex_state = 3},
  [319] = {.lex_state = 49, .external_lex_state = 3},
  [320] = {.lex_state = 42, .external_lex_state = 3},
  [321] = {.lex_state = 42, .external_lex_state = 3},
  [322] = {.lex_state = 42, .external_lex_state = 3},
  [323] = {.lex_state = 42, .external_lex_state = 3},
  [324] = {.lex_state = 42, .external_lex_state = 3},
  [325] = {.lex_state = 42, .external_lex_state = 3},
  [326] = {.lex_state = 42, .external_lex_state = 3},
  [327] = {.lex_state = 42, .external_lex_state = 3},
  [328] = {.lex_state = 42, .external_lex_state = 3},
  [329] = {.lex_state = 42, .external_lex_state = 3},
  [330] = {.lex_state = 42, .external_lex_state = 3},
  [331] = {.lex_state = 42, .external_lex_state = 3},
  [332] = {.lex_state = 47, .external_lex_state = 3},
  [333] = {.lex_state = 42, .external_lex_state = 3},
  [334] = {.lex_state = 42, .external_lex_state = 3},
  [335] = {.lex_state = 42, .external_lex_state = 3},
  [336] = {.lex_state = 42, .external_lex_state = 3},
  [337] = {.lex_state = 42, .external_lex_state = 3},
  [338] = {.lex_state = 42, .external_lex_state = 3},
  [339] = {.lex_state = 42, .external_lex_state = 3},
  [340] = {.lex_state = 42, .external_lex_state = 3},
  [341] = {.lex_state = 42, .external_lex_state = 3},
  [342] = {.lex_state = 42, .external_lex_state = 3},
  [343] = {.lex_state = 42, .external_lex_state = 3},
  [344] = {.lex_state = 42, .external_lex_state = 3},
  [345] = {.lex_state = 42, .external_lex_state = 3},
  [346] = {.lex_state = 42, .external_lex_state = 3},
  [347] = {.lex_state = 42, .external_lex_state = 3},
  [348] = {.lex_state = 42, .external_lex_state = 3},
  [349] = {.lex_state = 42, .external_lex_state = 3},
  [350] = {.lex_state = 42, .external_lex_state = 3},
  [351] = {.lex_state = 42, .external_lex_state = 3},
  [352] = {.lex_state = 42, .external_lex_state = 3},
  [353] = {.lex_state = 42, .external_lex_state = 3},
  [354] = {.lex_state = 42, .external_lex_state = 3},
  [355] = {.lex_state = 42, .external_lex_state = 3},
  [356] = {.lex_state = 42, .external_lex_state = 3},
  [357] = {.lex_state = 42, .external_lex_state = 3},
  [358] = {.lex_state = 42, .external_lex_state = 3},
  [359] = {.lex_state = 42, .external_lex_state = 3},
  [360] = {.lex_state = 42, .external_lex_state = 3},
  [361] = {.lex_state = 42, .external_lex_state = 3},
  [362] = {.lex_state = 42, .external_lex_state = 3},
  [363] = {.lex_state = 42, .external_lex_state = 3},
  [364] = {.lex_state = 42, .external_lex_state = 3},
  [365] = {.lex_state = 42, .external_lex_state = 3},
  [366] = {.lex_state = 42, .external_lex_state = 3},
  [367] = {.lex_state = 42, .external_lex_state = 3},
  [368] = {.lex_state = 42, .external_lex_state = 3},
  [369] = {.lex_state = 42, .external_lex_state = 3},
  [370] = {.lex_state = 42, .external_lex_state = 3},
  [371] = {.lex_state = 42, .external_lex_state = 3},
  [372] = {.lex_state = 42, .external_lex_state = 3},
  [373] = {.lex_state = 42, .external_lex_state = 3},
  [374] = {.lex_state = 42, .external_lex_state = 3},
  [375] = {.lex_state = 42, .external_lex_state = 3},
  [376] = {.lex_state = 42, .external_lex_state = 3},
  [377] = {.lex_state = 42, .external_lex_state = 3},
  [378] = {.lex_state = 42, .external_lex_state = 3},
  [379] = {.lex_state = 42, .external_lex_state = 3},
  [380] = {.lex_state = 42, .external_lex_state = 3},
  [381] = {.lex_state = 42, .external_lex_state = 3},
  [382] = {.lex_state = 42, .external_lex_state = 3},
  [383] = {.lex_state = 42, .external_lex_state = 3},
  [384] = {.lex_state = 42, .external_lex_state = 3},
  [385] = {.lex_state = 42, .external_lex_state = 3},
  [386] = {.lex_state = 42, .external_lex_state = 3},
  [387] = {.lex_state = 42, .external_lex_state = 3},
  [388] = {.lex_state = 42, .external_lex_state = 3},
  [389] = {.lex_state = 42, .external_lex_state = 3},
  [390] = {.lex_state = 42, .external_lex_state = 3},
  [391] = {.lex_state = 42, .external_lex_state = 3},
  [392] = {.lex_state = 42, .external_lex_state = 3},
  [393] = {.lex_state = 42, .external_lex_state = 3},
  [394] = {.lex_state = 42, .external_lex_state = 3},
  [395] = {.lex_state = 42, .external_lex_state = 3},
  [396] = {.lex_state = 42, .external_lex_state = 3},
  [397] = {.lex_state = 42, .external_lex_state = 3},
  [398] = {.lex_state = 42, .external_lex_state = 3},
  [399] = {.lex_state = 42, .external_lex_state = 3},
  [400] = {.lex_state = 42, .external_lex_state = 3},
  [401] = {.lex_state = 42, .external_lex_state = 3},
  [402] = {.lex_state = 42, .external_lex_state = 3},
  [403] = {.lex_state = 42, .external_lex_state = 3},
  [404] = {.lex_state = 42, .external_lex_state = 3},
  [405] = {.lex_state = 42, .external_lex_state = 3},
  [406] = {.lex_state = 42, .external_lex_state = 3},
  [407] = {.lex_state = 42, .external_lex_state = 3},
  [408] = {.lex_state = 42, .external_lex_state = 3},
  [409] = {.lex_state = 42, .external_lex_state = 3},
  [410] = {.lex_state = 42, .external_lex_state = 3},
  [411] = {.lex_state = 42, .external_lex_state = 3},
  [412] = {.lex_state = 42, .external_lex_state = 3},
  [413] = {.lex_state = 42, .external_lex_state = 3},
  [414] = {.lex_state = 42, .external_lex_state = 3},
  [415] = {.lex_state = 42, .external_lex_state = 3},
  [416] = {.lex_state = 42, .external_lex_state = 3},
  [417] = {.lex_state = 42, .external_lex_state = 3},
  [418] = {.lex_state = 42, .external_lex_state = 3},
  [419] = {.lex_state = 42, .external_lex_state = 3},
  [420] = {.lex_state = 42, .external_lex_state = 3},
  [421] = {.lex_state = 42, .external_lex_state = 3},
  [422] = {.lex_state = 42, .external_lex_state = 3},
  [423] = {.lex_state = 42, .external_lex_state = 3},
  [424] = {.lex_state = 42, .external_lex_state = 3},
  [425] = {.lex_state = 42, .external_lex_state = 3},
  [426] = {.lex_state = 42, .external_lex_state = 3},
  [427] = {.lex_state = 42, .external_lex_state = 3},
  [428] = {.lex_state = 42, .external_lex_state = 3},
  [429] = {.lex_state = 42, .external_lex_state = 3},
  [430] = {.lex_state = 42, .external_lex_state = 3},
  [431] = {.lex_state = 42, .external_lex_state = 3},
  [432] = {.lex_state = 42, .external_lex_state = 3},
  [433] = {.lex_state = 42, .external_lex_state = 3},
  [434] = {.lex_state = 42, .external_lex_state = 3},
  [435] = {.lex_state = 42, .external_lex_state = 3},
  [436] = {.lex_state = 42, .external_lex_state = 3},
  [437] = {.lex_state = 42, .external_lex_state = 3},
  [438] = {.lex_state = 42, .external_lex_state = 3},
  [439] = {.lex_state = 42, .external_lex_state = 3},
  [440] = {.lex_state = 42, .external_lex_state = 3},
  [441] = {.lex_state = 42, .external_lex_state = 3},
  [442] = {.lex_state = 42, .external_lex_state = 3},
  [443] = {.lex_state = 42, .external_lex_state = 3},
  [444] = {.lex_state = 42, .external_lex_state = 3},
  [445] = {.lex_state = 42, .external_lex_state = 3},
  [446] = {.lex_state = 42, .external_lex_state = 3},
  [447] = {.lex_state = 42, .external_lex_state = 3},
  [448] = {.lex_state = 42, .external_lex_state = 3},
  [449] = {.lex_state = 42, .external_lex_state = 3},
  [450] = {.lex_state = 42, .external_lex_state = 3},
  [451] = {.lex_state = 42, .external_lex_state = 3},
  [452] = {.lex_state = 42, .external_lex_state = 3},
  [453] = {.lex_state = 42, .external_lex_state = 3},
  [454] = {.lex_state = 42, .external_lex_state = 3},
  [455] = {.lex_state = 42, .external_lex_state = 3},
  [456] = {.lex_state = 42, .external_lex_state = 3},
  [457] = {.lex_state = 42, .external_lex_state = 3},
  [458] = {.lex_state = 42, .external_lex_state = 3},
  [459] = {.lex_state = 42, .external_lex_state = 3},
  [460] = {.lex_state = 42, .external_lex_state = 3},
  [461] = {.lex_state = 42, .external_lex_state = 3},
  [462] = {.lex_state = 42, .external_lex_state = 3},
  [463] = {.lex_state = 42, .external_lex_state = 3},
  [464] = {.lex_state = 42, .external_lex_state = 3},
  [465] = {.lex_state = 42, .external_lex_state = 3},
  [466] = {.lex_state = 42, .external_lex_state = 3},
  [467] = {.lex_state = 42, .external_lex_state = 3},
  [468] = {.lex_state = 42, .external_lex_state = 3},
  [469] = {.lex_state = 42, .external_lex_state = 3},
  [470] = {.lex_state = 42, .external_lex_state = 3},
  [471] = {.lex_state = 42, .external_lex_state = 3},
  [472] = {.lex_state = 42, .external_lex_state = 3},
  [473] = {.lex_state = 42, .external_lex_state = 3},
  [474] = {.lex_state = 42, .external_lex_state = 3},
  [475] = {.lex_state = 42, .external_lex_state = 3},
  [476] = {.lex_state = 42, .external_lex_state = 3},
  [477] = {.lex_state = 42, .external_lex_state = 3},
  [478] = {.lex_state = 42, .external_lex_state = 3},
  [479] = {.lex_state = 42, .external_lex_state = 3},
  [480] = {.lex_state = 42, .external_lex_state = 3},
  [481] = {.lex_state = 42, .external_lex_state = 3},
  [482] = {.lex_state = 42, .external_lex_state = 3},
  [483] = {.lex_state = 42, .external_lex_state = 3},
  [484] = {.lex_state = 42, .external_lex_state = 3},
  [485] = {.lex_state = 42, .external_lex_state = 3},
  [486] = {.lex_state = 42, .external_lex_state = 3},
  [487] = {.lex_state = 42, .external_lex_state = 3},
  [488] = {.lex_state = 42, .external_lex_state = 3},
  [489] = {.lex_state = 42, .external_lex_state = 3},
  [490] = {.lex_state = 42, .external_lex_state = 3},
  [491] = {.lex_state = 42, .external_lex_state = 3},
  [492] = {.lex_state = 42, .external_lex_state = 3},
  [493] = {.lex_state = 42, .external_lex_state = 3},
  [494] = {.lex_state = 42, .external_lex_state = 3},
  [495] = {.lex_state = 42, .external_lex_state = 3},
  [496] = {.lex_state = 42, .external_lex_state = 3},
  [497] = {.lex_state = 42, .external_lex_state = 3},
  [498] = {.lex_state = 42, .external_lex_state = 3},
  [499] = {.lex_state = 42, .external_lex_state = 3},
  [500] = {.lex_state = 42, .external_lex_state = 3},
  [501] = {.lex_state = 42, .external_lex_state = 3},
  [502] = {.lex_state = 42, .external_lex_state = 3},
  [503] = {.lex_state = 42, .external_lex_state = 3},
  [504] = {.lex_state = 42, .external_lex_state = 3},
  [505] = {.lex_state = 42, .external_lex_state = 3},
  [506] = {.lex_state = 42, .external_lex_state = 3},
  [507] = {.lex_state = 42, .external_lex_state = 3},
  [508] = {.lex_state = 42, .external_lex_state = 3},
  [509] = {.lex_state = 46, .external_lex_state = 3},
  [510] = {.lex_state = 42, .external_lex_state = 3},
  [511] = {.lex_state = 42, .external_lex_state = 3},
  [512] = {.lex_state = 42, .external_lex_state = 3},
  [513] = {.lex_state = 42, .external_lex_state = 3},
  [514] = {.lex_state = 42, .external_lex_state = 3},
  [515] = {.lex_state = 42, .external_lex_state = 3},
  [516] = {.lex_state = 46, .external_lex_state = 3},
  [517] = {.lex_state = 42, .external_lex_state = 3},
  [518] = {.lex_state = 42, .external_lex_state = 3},
  [519] = {.lex_state = 42, .external_lex_state = 3},
  [520] = {.lex_state = 42, .external_lex_state = 3},
  [521] = {.lex_state = 42, .external_lex_state = 3},
  [522] = {.lex_state = 46, .external_lex_state = 3},
  [523] = {.lex_state = 42, .external_lex_state = 3},
  [524] = {.lex_state = 42, .external_lex_state = 3},
  [525] = {.lex_state = 42, .external_lex_state = 3},
  [526] = {.lex_state = 42, .external_lex_state = 3},
  [527] = {.lex_state = 42, .external_lex_state = 3},
  [528] = {.lex_state = 42, .external_lex_state = 3},
  [529] = {.lex_state = 42, .external_lex_state = 3},
  [530] = {.lex_state = 42, .external_lex_state = 3},
  [531] = {.lex_state = 42, .external_lex_state = 3},
  [532] = {.lex_state = 42, .external_lex_state = 3},
  [533] = {.lex_state = 42, .external_lex_state = 3},
  [534] = {.lex_state = 42, .external_lex_state = 3},
  [535] = {.lex_state = 42, .external_lex_state = 3},
  [536] = {.lex_state = 46, .external_lex_state = 3},
  [537] = {.lex_state = 42, .external_lex_state = 3},
  [538] = {.lex_state = 42, .external_lex_state = 3},
  [539] = {.lex_state = 42, .external_lex_state = 3},
  [540] = {.lex_state = 42, .external_lex_state = 3},
  [541] = {.lex_state = 42, .external_lex_state = 3},
  [542] = {.lex_state = 42, .external_lex_state = 3},
  [543] = {.lex_state = 42, .external_lex_state = 3},
  [544] = {.lex_state = 42, .external_lex_state = 3},
  [545] = {.lex_state = 42, .external_lex_state = 3},
  [546] = {.lex_state = 42, .external_lex_state = 3},
  [547] = {.lex_state = 42, .external_lex_state = 3},
  [548] = {.lex_state = 42, .external_lex_state = 3},
  [549] = {.lex_state = 42, .external_lex_state = 3},
  [550] = {.lex_state = 42, .external_lex_state = 3},
  [551] = {.lex_state = 42, .external_lex_state = 3},
  [552] = {.lex_state = 42, .external_lex_state = 3},
  [553] = {.lex_state = 42, .external_lex_state = 3},
  [554] = {.lex_state = 42, .external_lex_state = 3},
  [555] = {.lex_state = 42, .external_lex_state = 3},
  [556] = {.lex_state = 42, .external_lex_state = 3},
  [557] = {.lex_state = 42, .external_lex_state = 3},
  [558] = {.lex_state = 42, .external_lex_state = 3},
  [559] = {.lex_state = 42, .external_lex_state = 3},
  [560] = {.lex_state = 42, .external_lex_state = 3},
  [561] = {.lex_state = 42, .external_lex_state = 3},
  [562] = {.lex_state = 42, .external_lex_state = 3},
  [563] = {.lex_state = 42, .external_lex_state = 3},
  [564] = {.lex_state = 42, .external_lex_state = 3},
  [565] = {.lex_state = 42, .external_lex_state = 3},
  [566] = {.lex_state = 42, .external_lex_state = 3},
  [567] = {.lex_state = 42, .external_lex_state = 3},
  [568] = {.lex_state = 42, .external_lex_state = 3},
  [569] = {.lex_state = 42, .external_lex_state = 3},
  [570] = {.lex_state = 42, .external_lex_state = 3},
  [571] = {.lex_state = 42, .external_lex_state = 3},
  [572] = {.lex_state = 42, .external_lex_state = 3},
  [573] = {.lex_state = 42, .external_lex_state = 3},
  [574] = {.lex_state = 42, .external_lex_state = 3},
  [575] = {.lex_state = 42, .external_lex_state = 3},
  [576] = {.lex_state = 42, .external_lex_state = 3},
  [577] = {.lex_state = 42, .external_lex_state = 3},
  [578] = {.lex_state = 42, .external_lex_state = 3},
  [579] = {.lex_state = 42, .external_lex_state = 3},
  [580] = {.lex_state = 42, .external_lex_state = 3},
  [581] = {.lex_state = 42, .external_lex_state = 3},
  [582] = {.lex_state = 42, .external_lex_state = 3},
  [583] = {.lex_state = 42, .external_lex_state = 3},
  [584] = {.lex_state = 42, .external_lex_state = 3},
  [585] = {.lex_state = 42, .external_lex_state = 3},
  [586] = {.lex_state = 42, .external_lex_state = 3},
  [587] = {.lex_state = 42, .external_lex_state = 3},
  [588] = {.lex_state = 42, .external_lex_state = 3},
  [589] = {.lex_state = 42, .external_lex_state = 3},
  [590] = {.lex_state = 42, .external_lex_state = 3},
  [591] = {.lex_state = 42, .external_lex_state = 3},
  [592] = {.lex_state = 42, .external_lex_state = 3},
  [593] = {.lex_state = 42, .external_lex_state = 3},
  [594] = {.lex_state = 42, .external_lex_state = 3},
  [595] = {.lex_state = 42, .external_lex_state = 3},
  [596] = {.lex_state = 42, .external_lex_state = 3},
  [597] = {.lex_state = 42, .external_lex_state = 3},
  [598] = {.lex_state = 42, .external_lex_state = 3},
  [599] = {.lex_state = 42, .external_lex_state = 3},
  [600] = {.lex_state = 42, .external_lex_state = 3},
  [601] = {.lex_state = 42, .external_lex_state = 3},
  [602] = {.lex_state = 42, .external_lex_state = 3},
  [603] = {.lex_state = 42, .external_lex_state = 3},
  [604] = {.lex_state = 42, .external_lex_state = 3},
  [605] = {.lex_state = 42, .external_lex_state = 3},
  [606] = {.lex_state = 42, .external_lex_state = 3},
  [607] = {.lex_state = 42, .external_lex_state = 3},
  [608] = {.lex_state = 42, .external_lex_state = 3},
  [609] = {.lex_state = 42, .external_lex_state = 3},
  [610] = {.lex_state = 42, .external_lex_state = 3},
  [611] = {.lex_state = 42, .external_lex_state = 3},
  [612] = {.lex_state = 42, .external_lex_state = 3},
  [613] = {.lex_state = 42, .external_lex_state = 3},
  [614] = {.lex_state = 42, .external_lex_state = 3},
  [615] = {.lex_state = 42, .external_lex_state = 3},
  [616] = {.lex_state = 42, .external_lex_state = 3},
  [617] = {.lex_state = 42, .external_lex_state = 3},
  [618] = {.lex_state = 42, .external_lex_state = 3},
  [619] = {.lex_state = 42, .external_lex_state = 3},
  [620] = {.lex_state = 42, .external_lex_state = 3},
  [621] = {.lex_state = 42, .external_lex_state = 3},
  [622] = {.lex_state = 42, .external_lex_state = 3},
  [623] = {.lex_state = 42, .external_lex_state = 3},
  [624] = {.lex_state = 42, .external_lex_state = 3},
  [625] = {.lex_state = 42, .external_lex_state = 3},
  [626] = {.lex_state = 42, .external_lex_state = 3},
  [627] = {.lex_state = 42, .external_lex_state = 3},
  [628] = {.lex_state = 42, .external_lex_state = 3},
  [629] = {.lex_state = 42, .external_lex_state = 3},
  [630] = {.lex_state = 42, .external_lex_state = 3},
  [631] = {.lex_state = 42, .external_lex_state = 3},
  [632] = {.lex_state = 42, .external_lex_state = 3},
  [633] = {.lex_state = 42, .external_lex_state = 3},
  [634] = {.lex_state = 42, .external_lex_state = 3},
  [635] = {.lex_state = 42, .external_lex_state = 3},
  [636] = {.lex_state = 42, .external_lex_state = 3},
  [637] = {.lex_state = 42, .external_lex_state = 3},
  [638] = {.lex_state = 42, .external_lex_state = 3},
  [639] = {.lex_state = 42, .external_lex_state = 3},
  [640] = {.lex_state = 42, .external_lex_state = 3},
  [641] = {.lex_state = 42, .external_lex_state = 3},
  [642] = {.lex_state = 42, .external_lex_state = 3},
  [643] = {.lex_state = 42, .external_lex_state = 3},
  [644] = {.lex_state = 42, .external_lex_state = 3},
  [645] = {.lex_state = 42, .external_lex_state = 3},
  [646] = {.lex_state = 42, .external_lex_state = 3},
  [647] = {.lex_state = 42, .external_lex_state = 3},
  [648] = {.lex_state = 42, .external_lex_state = 3},
  [649] = {.lex_state = 42, .external_lex_state = 3},
  [650] = {.lex_state = 42, .external_lex_state = 3},
  [651] = {.lex_state = 42, .external_lex_state = 3},
  [652] = {.lex_state = 42, .external_lex_state = 3},
  [653] = {.lex_state = 42, .external_lex_state = 3},
  [654] = {.lex_state = 42, .external_lex_state = 3},
  [655] = {.lex_state = 42, .external_lex_state = 3},
  [656] = {.lex_state = 42, .external_lex_state = 3},
  [657] = {.lex_state = 42, .external_lex_state = 3},
  [658] = {.lex_state = 42, .external_lex_state = 3},
  [659] = {.lex_state = 42, .external_lex_state = 3},
  [660] = {.lex_state = 42, .external_lex_state = 3},
  [661] = {.lex_state = 42, .external_lex_state = 3},
  [662] = {.lex_state = 42, .external_lex_state = 3},
  [663] = {.lex_state = 42, .external_lex_state = 3},
  [664] = {.lex_state = 42, .external_lex_state = 3},
  [665] = {.lex_state = 42, .external_lex_state = 3},
  [666] = {.lex_state = 42, .external_lex_state = 3},
  [667] = {.lex_state = 42, .external_lex_state = 3},
  [668] = {.lex_state = 42, .external_lex_state = 3},
  [669] = {.lex_state = 42, .external_lex_state = 3},
  [670] = {.lex_state = 42, .external_lex_state = 3},
  [671] = {.lex_state = 42, .external_lex_state = 3},
  [672] = {.lex_state = 42, .external_lex_state = 3},
  [673] = {.lex_state = 42, .external_lex_state = 3},
  [674] = {.lex_state = 42, .external_lex_state = 3},
  [675] = {.lex_state = 42, .external_lex_state = 3},
  [676] = {.lex_state = 42, .external_lex_state = 3},
  [677] = {.lex_state = 42, .external_lex_state = 3},
  [678] = {.lex_state = 42, .external_lex_state = 3},
  [679] = {.lex_state = 42, .external_lex_state = 3},
  [680] = {.lex_state = 42, .external_lex_state = 3},
  [681] = {.lex_state = 42, .external_lex_state = 3},
  [682] = {.lex_state = 42, .external_lex_state = 3},
  [683] = {.lex_state = 42, .external_lex_state = 3},
  [684] = {.lex_state = 42, .external_lex_state = 3},
  [685] = {.lex_state = 42, .external_lex_state = 3},
  [686] = {.lex_state = 42, .external_lex_state = 3},
  [687] = {.lex_state = 42, .external_lex_state = 3},
  [688] = {.lex_state = 42, .external_lex_state = 3},
  [689] = {.lex_state = 42, .external_lex_state = 3},
  [690] = {.lex_state = 42, .external_lex_state = 3},
  [691] = {.lex_state = 42, .external_lex_state = 3},
  [692] = {.lex_state = 42, .external_lex_state = 3},
  [693] = {.lex_state = 42, .external_lex_state = 3},
  [694] = {.lex_state = 42, .external_lex_state = 3},
  [695] = {.lex_state = 42, .external_lex_state = 3},
  [696] = {.lex_state = 42, .external_lex_state = 3},
  [697] = {.lex_state = 42, .external_lex_state = 3},
  [698] = {.lex_state = 42, .external_lex_state = 3},
  [699] = {.lex_state = 42, .external_lex_state = 3},
  [700] = {.lex_state = 42, .external_lex_state = 3},
  [701] = {.lex_state = 42, .external_lex_state = 3},
  [702] = {.lex_state = 42, .external_lex_state = 3},
  [703] = {.lex_state = 42, .external_lex_state = 3},
  [704] = {.lex_state = 42, .external_lex_state = 3},
  [705] = {.lex_state = 42, .external_lex_state = 3},
  [706] = {.lex_state = 42, .external_lex_state = 3},
  [707] = {.lex_state = 42, .external_lex_state = 3},
  [708] = {.lex_state = 42, .external_lex_state = 3},
  [709] = {.lex_state = 42, .external_lex_state = 3},
  [710] = {.lex_state = 42, .external_lex_state = 3},
  [711] = {.lex_state = 42, .external_lex_state = 3},
  [712] = {.lex_state = 42, .external_lex_state = 3},
  [713] = {.lex_state = 42, .external_lex_state = 3},
  [714] = {.lex_state = 42, .external_lex_state = 3},
  [715] = {.lex_state = 42, .external_lex_state = 3},
  [716] = {.lex_state = 42, .external_lex_state = 3},
  [717] = {.lex_state = 42, .external_lex_state = 3},
  [718] = {.lex_state = 42, .external_lex_state = 3},
  [719] = {.lex_state = 42, .external_lex_state = 3},
  [720] = {.lex_state = 42, .external_lex_state = 3},
  [721] = {.lex_state = 42, .external_lex_state = 3},
  [722] = {.lex_state = 42, .external_lex_state = 3},
  [723] = {.lex_state = 42, .external_lex_state = 3},
  [724] = {.lex_state = 42, .external_lex_state = 3},
  [725] = {.lex_state = 42, .external_lex_state = 3},
  [726] = {.lex_state = 42, .external_lex_state = 3},
  [727] = {.lex_state = 42, .external_lex_state = 3},
  [728] = {.lex_state = 42, .external_lex_state = 3},
  [729] = {.lex_state = 42, .external_lex_state = 3},
  [730] = {.lex_state = 42, .external_lex_state = 3},
  [731] = {.lex_state = 42, .external_lex_state = 3},
  [732] = {.lex_state = 42, .external_lex_state = 3},
  [733] = {.lex_state = 42, .external_lex_state = 3},
  [734] = {.lex_state = 42, .external_lex_state = 3},
  [735] = {.lex_state = 42, .external_lex_state = 3},
  [736] = {.lex_state = 42, .external_lex_state = 3},
  [737] = {.lex_state = 42, .external_lex_state = 3},
  [738] = {.lex_state = 42, .external_lex_state = 3},
  [739] = {.lex_state = 42, .external_lex_state = 3},
  [740] = {.lex_state = 42, .external_lex_state = 3},
  [741] = {.lex_state = 42, .external_lex_state = 3},
  [742] = {.lex_state = 42, .external_lex_state = 3},
  [743] = {.lex_state = 42, .external_lex_state = 3},
  [744] = {.lex_state = 42, .external_lex_state = 3},
  [745] = {.lex_state = 42, .external_lex_state = 3},
  [746] = {.lex_state = 42, .external_lex_state = 3},
  [747] = {.lex_state = 42, .external_lex_state = 3},
  [748] = {.lex_state = 42, .external_lex_state = 3},
  [749] = {.lex_state = 42, .external_lex_state = 3},
  [750] = {.lex_state = 42, .external_lex_state = 3},
  [751] = {.lex_state = 42, .external_lex_state = 3},
  [752] = {.lex_state = 42, .external_lex_state = 3},
  [753] = {.lex_state = 42, .external_lex_state = 3},
  [754] = {.lex_state = 42, .external_lex_state = 3},
  [755] = {.lex_state = 42, .external_lex_state = 3},
  [756] = {.lex_state = 42, .external_lex_state = 3},
  [757] = {.lex_state = 42, .external_lex_state = 3},
  [758] = {.lex_state = 42, .external_lex_state = 3},
  [759] = {.lex_state = 42, .external_lex_state = 3},
  [760] = {.lex_state = 42, .external_lex_state = 3},
  [761] = {.lex_state = 42, .external_lex_state = 3},
  [762] = {.lex_state = 42, .external_lex_state = 3},
  [763] = {.lex_state = 42, .external_lex_state = 3},
  [764] = {.lex_state = 42, .external_lex_state = 3},
  [765] = {.lex_state = 42, .external_lex_state = 3},
  [766] = {.lex_state = 42, .external_lex_state = 3},
  [767] = {.lex_state = 42, .external_lex_state = 3},
  [768] = {.lex_state = 42, .external_lex_state = 3},
  [769] = {.lex_state = 42, .external_lex_state = 3},
  [770] = {.lex_state = 42, .external_lex_state = 3},
  [771] = {.lex_state = 42, .external_lex_state = 3},
  [772] = {.lex_state = 42, .external_lex_state = 3},
  [773] = {.lex_state = 42, .external_lex_state = 3},
  [774] = {.lex_state = 42, .external_lex_state = 3},
  [775] = {.lex_state = 42, .external_lex_state = 3},
  [776] = {.lex_state = 42, .external_lex_state = 3},
  [777] = {.lex_state = 42, .external_lex_state = 3},
  [778] = {.lex_state = 42, .external_lex_state = 3},
  [779] = {.lex_state = 42, .external_lex_state = 3},
  [780] = {.lex_state = 42, .external_lex_state = 3},
  [781] = {.lex_state = 42, .external_lex_state = 3},
  [782] = {.lex_state = 42, .external_lex_state = 3},
  [783] = {.lex_state = 42, .external_lex_state = 3},
  [784] = {.lex_state = 42, .external_lex_state = 3},
  [785] = {.lex_state = 42, .external_lex_state = 3},
  [786] = {.lex_state = 42, .external_lex_state = 3},
  [787] = {.lex_state = 42, .external_lex_state = 3},
  [788] = {.lex_state = 42, .external_lex_state = 3},
  [789] = {.lex_state = 42, .external_lex_state = 3},
  [790] = {.lex_state = 42, .external_lex_state = 3},
  [791] = {.lex_state = 42, .external_lex_state = 3},
  [792] = {.lex_state = 42, .external_lex_state = 3},
  [793] = {.lex_state = 42, .external_lex_state = 3},
  [794] = {.lex_state = 42, .external_lex_state = 3},
  [795] = {.lex_state = 42, .external_lex_state = 3},
  [796] = {.lex_state = 42, .external_lex_state = 3},
  [797] = {.lex_state = 42, .external_lex_state = 3},
  [798] = {.lex_state = 42, .external_lex_state = 3},
  [799] = {.lex_state = 42, .external_lex_state = 3},
  [800] = {.lex_state = 42, .external_lex_state = 3},
  [801] = {.lex_state = 42, .external_lex_state = 3},
  [802] = {.lex_state = 42, .external_lex_state = 3},
  [803] = {.lex_state = 42, .external_lex_state = 3},
  [804] = {.lex_state = 42, .external_lex_state = 3},
  [805] = {.lex_state = 42, .external_lex_state = 3},
  [806] = {.lex_state = 42, .external_lex_state = 3},
  [807] = {.lex_state = 42, .external_lex_state = 3},
  [808] = {.lex_state = 42, .external_lex_state = 3},
  [809] = {.lex_state = 42, .external_lex_state = 3},
  [810] = {.lex_state = 42, .external_lex_state = 3},
  [811] = {.lex_state = 42, .external_lex_state = 3},
  [812] = {.lex_state = 42, .external_lex_state = 3},
  [813] = {.lex_state = 42, .external_lex_state = 3},
  [814] = {.lex_state = 42, .external_lex_state = 3},
  [815] = {.lex_state = 42, .external_lex_state = 3},
  [816] = {.lex_state = 77, .external_lex_state = 3},
  [817] = {.lex_state = 42, .external_lex_state = 3},
  [818] = {.lex_state = 42, .external_lex_state = 3},
  [819] = {.lex_state = 42, .external_lex_state = 3},
  [820] = {.lex_state = 42, .external_lex_state = 3},
  [821] = {.lex_state = 81, .external_lex_state = 3},
  [822] = {.lex_state = 42, .external_lex_state = 3},
  [823] = {.lex_state = 42, .external_lex_state = 3},
  [824] = {.lex_state = 42, .external_lex_state = 3},
  [825] = {.lex_state = 42, .external_lex_state = 3},
  [826] = {.lex_state = 42, .external_lex_state = 3},
  [827] = {.lex_state = 42, .external_lex_state = 3},
  [828] = {.lex_state = 42, .external_lex_state = 3},
  [829] = {.lex_state = 42, .external_lex_state = 3},
  [830] = {.lex_state = 42, .external_lex_state = 3},
  [831] = {.lex_state = 42, .external_lex_state = 3},
  [832] = {.lex_state = 42, .external_lex_state = 3},
  [833] = {.lex_state = 42, .external_lex_state = 3},
  [834] = {.lex_state = 42, .external_lex_state = 3},
  [835] = {.lex_state = 42, .external_lex_state = 3},
  [836] = {.lex_state = 42, .external_lex_state = 3},
  [837] = {.lex_state = 42, .external_lex_state = 3},
  [838] = {.lex_state = 42, .external_lex_state = 3},
  [839] = {.lex_state = 42, .external_lex_state = 3},
  [840] = {.lex_state = 42, .external_lex_state = 3},
  [841] = {.lex_state = 42, .external_lex_state = 3},
  [842] = {.lex_state = 42, .external_lex_state = 3},
  [843] = {.lex_state = 42, .external_lex_state = 3},
  [844] = {.lex_state = 42, .external_lex_state = 3},
  [845] = {.lex_state = 42, .external_lex_state = 3},
  [846] = {.lex_state = 42, .external_lex_state = 3},
  [847] = {.lex_state = 42, .external_lex_state = 3},
  [848] = {.lex_state = 42, .external_lex_state = 3},
  [849] = {.lex_state = 42, .external_lex_state = 3},
  [850] = {.lex_state = 42, .external_lex_state = 3},
  [851] = {.lex_state = 42, .external_lex_state = 3},
  [852] = {.lex_state = 42, .external_lex_state = 3},
  [853] = {.lex_state = 42, .external_lex_state = 3},
  [854] = {.lex_state = 42, .external_lex_state = 3},
  [855] = {.lex_state = 42, .external_lex_state = 3},
  [856] = {.lex_state = 42, .external_lex_state = 3},
  [857] = {.lex_state = 42, .external_lex_state = 3},
  [858] = {.lex_state = 42, .external_lex_state = 3},
  [859] = {.lex_state = 42, .external_lex_state = 3},
  [860] = {.lex_state = 42, .external_lex_state = 3},
  [861] = {.lex_state = 42, .external_lex_state = 3},
  [862] = {.lex_state = 42, .external_lex_state = 3},
  [863] = {.lex_state = 42, .external_lex_state = 3},
  [864] = {.lex_state = 42, .external_lex_state = 3},
  [865] = {.lex_state = 42, .external_lex_state = 3},
  [866] = {.lex_state = 42, .external_lex_state = 3},
  [867] = {.lex_state = 42, .external_lex_state = 3},
  [868] = {.lex_state = 42, .external_lex_state = 3},
  [869] = {.lex_state = 42, .external_lex_state = 3},
  [870] = {.lex_state = 42, .external_lex_state = 3},
  [871] = {.lex_state = 42, .external_lex_state = 3},
  [872] = {.lex_state = 42, .external_lex_state = 3},
  [873] = {.lex_state = 42, .external_lex_state = 3},
  [874] = {.lex_state = 42, .external_lex_state = 3},
  [875] = {.lex_state = 42, .external_lex_state = 3},
  [876] = {.lex_state = 42, .external_lex_state = 3},
  [877] = {.lex_state = 42, .external_lex_state = 3},
  [878] = {.lex_state = 42, .external_lex_state = 3},
  [879] = {.lex_state = 42, .external_lex_state = 3},
  [880] = {.lex_state = 42, .external_lex_state = 3},
  [881] = {.lex_state = 42, .external_lex_state = 3},
  [882] = {.lex_state = 42, .external_lex_state = 3},
  [883] = {.lex_state = 42, .external_lex_state = 3},
  [884] = {.lex_state = 42, .external_lex_state = 3},
  [885] = {.lex_state = 42, .external_lex_state = 3},
  [886] = {.lex_state = 42, .external_lex_state = 3},
  [887] = {.lex_state = 42, .external_lex_state = 3},
  [888] = {.lex_state = 42, .external_lex_state = 3},
  [889] = {.lex_state = 42, .external_lex_state = 3},
  [890] = {.lex_state = 42, .external_lex_state = 3},
  [891] = {.lex_state = 42, .external_lex_state = 3},
  [892] = {.lex_state = 42, .external_lex_state = 3},
  [893] = {.lex_state = 42, .external_lex_state = 3},
  [894] = {.lex_state = 42, .external_lex_state = 3},
  [895] = {.lex_state = 42, .external_lex_state = 3},
  [896] = {.lex_state = 42, .external_lex_state = 3},
  [897] = {.lex_state = 42, .external_lex_state = 3},
  [898] = {.lex_state = 42, .external_lex_state = 3},
  [899] = {.lex_state = 42, .external_lex_state = 3},
  [900] = {.lex_state = 42, .external_lex_state = 3},
  [901] = {.lex_state = 42, .external_lex_state = 3},
  [902] = {.lex_state = 42, .external_lex_state = 3},
  [903] = {.lex_state = 42, .external_lex_state = 3},
  [904] = {.lex_state = 42, .external_lex_state = 3},
  [905] = {.lex_state = 42, .external_lex_state = 3},
  [906] = {.lex_state = 42, .external_lex_state = 3},
  [907] = {.lex_state = 42, .external_lex_state = 3},
  [908] = {.lex_state = 42, .external_lex_state = 3},
  [909] = {.lex_state = 42, .external_lex_state = 3},
  [910] = {.lex_state = 42, .external_lex_state = 3},
  [911] = {.lex_state = 42, .external_lex_state = 3},
  [912] = {.lex_state = 42, .external_lex_state = 3},
  [913] = {.lex_state = 42, .external_lex_state = 3},
  [914] = {.lex_state = 42, .external_lex_state = 3},
  [915] = {.lex_state = 42, .external_lex_state = 3},
  [916] = {.lex_state = 42, .external_lex_state = 3},
  [917] = {.lex_state = 42, .external_lex_state = 3},
  [918] = {.lex_state = 42, .external_lex_state = 3},
  [919] = {.lex_state = 42, .external_lex_state = 3},
  [920] = {.lex_state = 42, .external_lex_state = 3},
  [921] = {.lex_state = 42, .external_lex_state = 3},
  [922] = {.lex_state = 42, .external_lex_state = 3},
  [923] = {.lex_state = 42, .external_lex_state = 3},
  [924] = {.lex_state = 42, .external_lex_state = 3},
  [925] = {.lex_state = 42, .external_lex_state = 3},
  [926] = {.lex_state = 42, .external_lex_state = 3},
  [927] = {.lex_state = 42, .external_lex_state = 3},
  [928] = {.lex_state = 42, .external_lex_state = 3},
  [929] = {.lex_state = 42, .external_lex_state = 3},
  [930] = {.lex_state = 42, .external_lex_state = 3},
  [931] = {.lex_state = 42, .external_lex_state = 3},
  [932] = {.lex_state = 42, .external_lex_state = 3},
  [933] = {.lex_state = 42, .external_lex_state = 3},
  [934] = {.lex_state = 42, .external_lex_state = 3},
  [935] = {.lex_state = 42, .external_lex_state = 3},
  [936] = {.lex_state = 42, .external_lex_state = 3},
  [937] = {.lex_state = 42, .external_lex_state = 3},
  [938] = {.lex_state = 42, .external_lex_state = 3},
  [939] = {.lex_state = 42, .external_lex_state = 3},
  [940] = {.lex_state = 42, .external_lex_state = 3},
  [941] = {.lex_state = 42, .external_lex_state = 3},
  [942] = {.lex_state = 42, .external_lex_state = 3},
  [943] = {.lex_state = 42, .external_lex_state = 3},
  [944] = {.lex_state = 42, .external_lex_state = 3},
  [945] = {.lex_state = 42, .external_lex_state = 3},
  [946] = {.lex_state = 42, .external_lex_state = 3},
  [947] = {.lex_state = 42, .external_lex_state = 3},
  [948] = {.lex_state = 42, .external_lex_state = 3},
  [949] = {.lex_state = 42, .external_lex_state = 3},
  [950] = {.lex_state = 42, .external_lex_state = 3},
  [951] = {.lex_state = 42, .external_lex_state = 3},
  [952] = {.lex_state = 42, .external_lex_state = 3},
  [953] = {.lex_state = 42, .external_lex_state = 3},
  [954] = {.lex_state = 42, .external_lex_state = 3},
  [955] = {.lex_state = 42, .external_lex_state = 3},
  [956] = {.lex_state = 42, .external_lex_state = 3},
  [957] = {.lex_state = 42, .external_lex_state = 3},
  [958] = {.lex_state = 42, .external_lex_state = 3},
  [959] = {.lex_state = 42, .external_lex_state = 3},
  [960] = {.lex_state = 42, .external_lex_state = 3},
  [961] = {.lex_state = 42, .external_lex_state = 3},
  [962] = {.lex_state = 42, .external_lex_state = 3},
  [963] = {.lex_state = 42, .external_lex_state = 3},
  [964] = {.lex_state = 42, .external_lex_state = 3},
  [965] = {.lex_state = 42, .external_lex_state = 3},
  [966] = {.lex_state = 42, .external_lex_state = 3},
  [967] = {.lex_state = 42, .external_lex_state = 3},
  [968] = {.lex_state = 42, .external_lex_state = 3},
  [969] = {.lex_state = 42, .external_lex_state = 3},
  [970] = {.lex_state = 42, .external_lex_state = 3},
  [971] = {.lex_state = 42, .external_lex_state = 3},
  [972] = {.lex_state = 42, .external_lex_state = 3},
  [973] = {.lex_state = 42, .external_lex_state = 3},
  [974] = {.lex_state = 42, .external_lex_state = 3},
  [975] = {.lex_state = 42, .external_lex_state = 3},
  [976] = {.lex_state = 42, .external_lex_state = 3},
  [977] = {.lex_state = 42, .external_lex_state = 3},
  [978] = {.lex_state = 42, .external_lex_state = 3},
  [979] = {.lex_state = 42, .external_lex_state = 3},
  [980] = {.lex_state = 42, .external_lex_state = 3},
  [981] = {.lex_state = 42, .external_lex_state = 3},
  [982] = {.lex_state = 42, .external_lex_state = 3},
  [983] = {.lex_state = 42, .external_lex_state = 3},
  [984] = {.lex_state = 42, .external_lex_state = 3},
  [985] = {.lex_state = 42, .external_lex_state = 3},
  [986] = {.lex_state = 42, .external_lex_state = 3},
  [987] = {.lex_state = 42, .external_lex_state = 3},
  [988] = {.lex_state = 42, .external_lex_state = 3},
  [989] = {.lex_state = 42, .external_lex_state = 3},
  [990] = {.lex_state = 42, .external_lex_state = 3},
  [991] = {.lex_state = 42, .external_lex_state = 3},
  [992] = {.lex_state = 42, .external_lex_state = 3},
  [993] = {.lex_state = 42, .external_lex_state = 3},
  [994] = {.lex_state = 42, .external_lex_state = 3},
  [995] = {.lex_state = 42, .external_lex_state = 3},
  [996] = {.lex_state = 42, .external_lex_state = 3},
  [997] = {.lex_state = 42, .external_lex_state = 3},
  [998] = {.lex_state = 42, .external_lex_state = 3},
  [999] = {.lex_state = 42, .external_lex_state = 3},
  [1000] = {.lex_state = 42, .external_lex_state = 3},
  [1001] = {.lex_state = 42, .external_lex_state = 3},
  [1002] = {.lex_state = 42, .external_lex_state = 3},
  [1003] = {.lex_state = 42, .external_lex_state = 3},
  [1004] = {.lex_state = 42, .external_lex_state = 3},
  [1005] = {.lex_state = 42, .external_lex_state = 3},
  [1006] = {.lex_state = 42, .external_lex_state = 3},
  [1007] = {.lex_state = 42, .external_lex_state = 3},
  [1008] = {.lex_state = 42, .external_lex_state = 3},
  [1009] = {.lex_state = 42, .external_lex_state = 3},
  [1010] = {.lex_state = 42, .external_lex_state = 3},
  [1011] = {.lex_state = 42, .external_lex_state = 3},
  [1012] = {.lex_state = 42, .external_lex_state = 3},
  [1013] = {.lex_state = 42, .external_lex_state = 3},
  [1014] = {.lex_state = 42, .external_lex_state = 3},
  [1015] = {.lex_state = 42, .external_lex_state = 3},
  [1016] = {.lex_state = 42, .external_lex_state = 3},
  [1017] = {.lex_state = 42, .external_lex_state = 3},
  [1018] = {.lex_state = 42, .external_lex_state = 3},
  [1019] = {.lex_state = 42, .external_lex_state = 3},
  [1020] = {.lex_state = 42, .external_lex_state = 3},
  [1021] = {.lex_state = 42, .external_lex_state = 3},
  [1022] = {.lex_state = 42, .external_lex_state = 3},
  [1023] = {.lex_state = 42, .external_lex_state = 3},
  [1024] = {.lex_state = 42, .external_lex_state = 3},
  [1025] = {.lex_state = 42, .external_lex_state = 3},
  [1026] = {.lex_state = 42, .external_lex_state = 3},
  [1027] = {.lex_state = 42, .external_lex_state = 3},
  [1028] = {.lex_state = 42, .external_lex_state = 3},
  [1029] = {.lex_state = 42, .external_lex_state = 3},
  [1030] = {.lex_state = 42, .external_lex_state = 3},
  [1031] = {.lex_state = 42, .external_lex_state = 3},
  [1032] = {.lex_state = 42, .external_lex_state = 3},
  [1033] = {.lex_state = 42, .external_lex_state = 3},
  [1034] = {.lex_state = 42, .external_lex_state = 3},
  [1035] = {.lex_state = 42, .external_lex_state = 3},
  [1036] = {.lex_state = 42, .external_lex_state = 3},
  [1037] = {.lex_state = 42, .external_lex_state = 3},
  [1038] = {.lex_state = 42, .external_lex_state = 3},
  [1039] = {.lex_state = 42, .external_lex_state = 3},
  [1040] = {.lex_state = 42, .external_lex_state = 3},
  [1041] = {.lex_state = 42, .external_lex_state = 3},
  [1042] = {.lex_state = 42, .external_lex_state = 3},
  [1043] = {.lex_state = 42, .external_lex_state = 3},
  [1044] = {.lex_state = 42, .external_lex_state = 3},
  [1045] = {.lex_state = 42, .external_lex_state = 3},
  [1046] = {.lex_state = 42, .external_lex_state = 3},
  [1047] = {.lex_state = 42, .external_lex_state = 3},
  [1048] = {.lex_state = 42, .external_lex_state = 3},
  [1049] = {.lex_state = 42, .external_lex_state = 3},
  [1050] = {.lex_state = 42, .external_lex_state = 3},
  [1051] = {.lex_state = 42, .external_lex_state = 3},
  [1052] = {.lex_state = 42, .external_lex_state = 3},
  [1053] = {.lex_state = 42, .external_lex_state = 3},
  [1054] = {.lex_state = 42, .external_lex_state = 3},
  [1055] = {.lex_state = 42, .external_lex_state = 3},
  [1056] = {.lex_state = 42, .external_lex_state = 3},
  [1057] = {.lex_state = 42, .external_lex_state = 3},
  [1058] = {.lex_state = 42, .external_lex_state = 3},
  [1059] = {.lex_state = 42, .external_lex_state = 3},
  [1060] = {.lex_state = 42, .external_lex_state = 3},
  [1061] = {.lex_state = 42, .external_lex_state = 3},
  [1062] = {.lex_state = 42, .external_lex_state = 3},
  [1063] = {.lex_state = 42, .external_lex_state = 3},
  [1064] = {.lex_state = 42, .external_lex_state = 3},
  [1065] = {.lex_state = 42, .external_lex_state = 3},
  [1066] = {.lex_state = 42, .external_lex_state = 3},
  [1067] = {.lex_state = 42, .external_lex_state = 3},
  [1068] = {.lex_state = 42, .external_lex_state = 3},
  [1069] = {.lex_state = 42, .external_lex_state = 3},
  [1070] = {.lex_state = 42, .external_lex_state = 3},
  [1071] = {.lex_state = 42, .external_lex_state = 3},
  [1072] = {.lex_state = 42, .external_lex_state = 3},
  [1073] = {.lex_state = 42, .external_lex_state = 3},
  [1074] = {.lex_state = 42, .external_lex_state = 3},
  [1075] = {.lex_state = 42, .external_lex_state = 3},
  [1076] = {.lex_state = 42, .external_lex_state = 3},
  [1077] = {.lex_state = 42, .external_lex_state = 3},
  [1078] = {.lex_state = 42, .external_lex_state = 3},
  [1079] = {.lex_state = 42, .external_lex_state = 3},
  [1080] = {.lex_state = 42, .external_lex_state = 3},
  [1081] = {.lex_state = 42, .external_lex_state = 3},
  [1082] = {.lex_state = 42, .external_lex_state = 3},
  [1083] = {.lex_state = 42, .external_lex_state = 3},
  [1084] = {.lex_state = 42, .external_lex_state = 3},
  [1085] = {.lex_state = 42, .external_lex_state = 3},
  [1086] = {.lex_state = 42, .external_lex_state = 3},
  [1087] = {.lex_state = 42, .external_lex_state = 3},
  [1088] = {.lex_state = 42, .external_lex_state = 3},
  [1089] = {.lex_state = 42, .external_lex_state = 3},
  [1090] = {.lex_state = 42, .external_lex_state = 3},
  [1091] = {.lex_state = 42, .external_lex_state = 3},
  [1092] = {.lex_state = 42, .external_lex_state = 3},
  [1093] = {.lex_state = 42, .external_lex_state = 3},
  [1094] = {.lex_state = 42, .external_lex_state = 3},
  [1095] = {.lex_state = 42, .external_lex_state = 3},
  [1096] = {.lex_state = 42, .external_lex_state = 3},
  [1097] = {.lex_state = 42, .external_lex_state = 3},
  [1098] = {.lex_state = 42, .external_lex_state = 3},
  [1099] = {.lex_state = 42, .external_lex_state = 3},
  [1100] = {.lex_state = 42, .external_lex_state = 3},
  [1101] = {.lex_state = 42, .external_lex_state = 3},
  [1102] = {.lex_state = 42, .external_lex_state = 3},
  [1103] = {.lex_state = 42, .external_lex_state = 3},
  [1104] = {.lex_state = 42, .external_lex_state = 3},
  [1105] = {.lex_state = 42, .external_lex_state = 3},
  [1106] = {.lex_state = 42, .external_lex_state = 3},
  [1107] = {.lex_state = 42, .external_lex_state = 3},
  [1108] = {.lex_state = 42, .external_lex_state = 3},
  [1109] = {.lex_state = 42, .external_lex_state = 3},
  [1110] = {.lex_state = 42, .external_lex_state = 3},
  [1111] = {.lex_state = 42, .external_lex_state = 3},
  [1112] = {.lex_state = 42, .external_lex_state = 3},
  [1113] = {.lex_state = 42, .external_lex_state = 3},
  [1114] = {.lex_state = 42, .external_lex_state = 3},
  [1115] = {.lex_state = 42, .external_lex_state = 3},
  [1116] = {.lex_state = 42, .external_lex_state = 3},
  [1117] = {.lex_state = 42, .external_lex_state = 3},
  [1118] = {.lex_state = 42, .external_lex_state = 3},
  [1119] = {.lex_state = 42, .external_lex_state = 3},
  [1120] = {.lex_state = 42, .external_lex_state = 3},
  [1121] = {.lex_state = 42, .external_lex_state = 3},
  [1122] = {.lex_state = 42, .external_lex_state = 3},
  [1123] = {.lex_state = 42, .external_lex_state = 3},
  [1124] = {.lex_state = 42, .external_lex_state = 3},
  [1125] = {.lex_state = 42, .external_lex_state = 3},
  [1126] = {.lex_state = 42, .external_lex_state = 3},
  [1127] = {.lex_state = 42, .external_lex_state = 3},
  [1128] = {.lex_state = 42, .external_lex_state = 3},
  [1129] = {.lex_state = 42, .external_lex_state = 3},
  [1130] = {.lex_state = 42, .external_lex_state = 3},
  [1131] = {.lex_state = 42, .external_lex_state = 3},
  [1132] = {.lex_state = 42, .external_lex_state = 3},
  [1133] = {.lex_state = 42, .external_lex_state = 3},
  [1134] = {.lex_state = 42, .external_lex_state = 3},
  [1135] = {.lex_state = 42, .external_lex_state = 3},
  [1136] = {.lex_state = 42, .external_lex_state = 3},
  [1137] = {.lex_state = 42, .external_lex_state = 3},
  [1138] = {.lex_state = 42, .external_lex_state = 3},
  [1139] = {.lex_state = 42, .external_lex_state = 3},
  [1140] = {.lex_state = 42, .external_lex_state = 3},
  [1141] = {.lex_state = 42, .external_lex_state = 3},
  [1142] = {.lex_state = 42, .external_lex_state = 3},
  [1143] = {.lex_state = 42, .external_lex_state = 3},
  [1144] = {.lex_state = 42, .external_lex_state = 3},
  [1145] = {.lex_state = 42, .external_lex_state = 3},
  [1146] = {.lex_state = 42, .external_lex_state = 3},
  [1147] = {.lex_state = 42, .external_lex_state = 3},
  [1148] = {.lex_state = 42, .external_lex_state = 3},
  [1149] = {.lex_state = 42, .external_lex_state = 3},
  [1150] = {.lex_state = 42, .external_lex_state = 3},
  [1151] = {.lex_state = 42, .external_lex_state = 3},
  [1152] = {.lex_state = 42, .external_lex_state = 3},
  [1153] = {.lex_state = 42, .external_lex_state = 3},
  [1154] = {.lex_state = 42, .external_lex_state = 3},
  [1155] = {.lex_state = 42, .external_lex_state = 3},
  [1156] = {.lex_state = 42, .external_lex_state = 3},
  [1157] = {.lex_state = 42, .external_lex_state = 3},
  [1158] = {.lex_state = 42, .external_lex_state = 3},
  [1159] = {.lex_state = 42, .external_lex_state = 3},
  [1160] = {.lex_state = 42, .external_lex_state = 3},
  [1161] = {.lex_state = 42, .external_lex_state = 3},
  [1162] = {.lex_state = 42, .external_lex_state = 3},
  [1163] = {.lex_state = 42, .external_lex_state = 3},
  [1164] = {.lex_state = 42, .external_lex_state = 3},
  [1165] = {.lex_state = 42, .external_lex_state = 3},
  [1166] = {.lex_state = 42, .external_lex_state = 3},
  [1167] = {.lex_state = 42, .external_lex_state = 3},
  [1168] = {.lex_state = 42, .external_lex_state = 3},
  [1169] = {.lex_state = 42, .external_lex_state = 3},
  [1170] = {.lex_state = 42, .external_lex_state = 3},
  [1171] = {.lex_state = 42, .external_lex_state = 3},
  [1172] = {.lex_state = 42, .external_lex_state = 3},
  [1173] = {.lex_state = 42, .external_lex_state = 3},
  [1174] = {.lex_state = 42, .external_lex_state = 3},
  [1175] = {.lex_state = 42, .external_lex_state = 3},
  [1176] = {.lex_state = 42, .external_lex_state = 3},
  [1177] = {.lex_state = 42, .external_lex_state = 3},
  [1178] = {.lex_state = 42, .external_lex_state = 3},
  [1179] = {.lex_state = 42, .external_lex_state = 3},
  [1180] = {.lex_state = 42, .external_lex_state = 3},
  [1181] = {.lex_state = 42, .external_lex_state = 3},
  [1182] = {.lex_state = 42, .external_lex_state = 3},
  [1183] = {.lex_state = 42, .external_lex_state = 3},
  [1184] = {.lex_state = 42, .external_lex_state = 3},
  [1185] = {.lex_state = 42, .external_lex_state = 3},
  [1186] = {.lex_state = 42, .external_lex_state = 3},
  [1187] = {.lex_state = 42, .external_lex_state = 3},
  [1188] = {.lex_state = 42, .external_lex_state = 3},
  [1189] = {.lex_state = 42, .external_lex_state = 3},
  [1190] = {.lex_state = 42, .external_lex_state = 3},
  [1191] = {.lex_state = 42, .external_lex_state = 3},
  [1192] = {.lex_state = 42, .external_lex_state = 3},
  [1193] = {.lex_state = 42, .external_lex_state = 3},
  [1194] = {.lex_state = 42, .external_lex_state = 3},
  [1195] = {.lex_state = 42, .external_lex_state = 3},
  [1196] = {.lex_state = 42, .external_lex_state = 3},
  [1197] = {.lex_state = 42, .external_lex_state = 3},
  [1198] = {.lex_state = 42, .external_lex_state = 3},
  [1199] = {.lex_state = 42, .external_lex_state = 3},
  [1200] = {.lex_state = 42, .external_lex_state = 3},
  [1201] = {.lex_state = 42, .external_lex_state = 3},
  [1202] = {.lex_state = 42, .external_lex_state = 3},
  [1203] = {.lex_state = 42, .external_lex_state = 3},
  [1204] = {.lex_state = 42, .external_lex_state = 3},
  [1205] = {.lex_state = 42, .external_lex_state = 3},
  [1206] = {.lex_state = 42, .external_lex_state = 3},
  [1207] = {.lex_state = 42, .external_lex_state = 3},
  [1208] = {.lex_state = 42, .external_lex_state = 3},
  [1209] = {.lex_state = 42, .external_lex_state = 3},
  [1210] = {.lex_state = 42, .external_lex_state = 3},
  [1211] = {.lex_state = 42, .external_lex_state = 3},
  [1212] = {.lex_state = 42, .external_lex_state = 3},
  [1213] = {.lex_state = 42, .external_lex_state = 3},
  [1214] = {.lex_state = 42, .external_lex_state = 3},
  [1215] = {.lex_state = 42, .external_lex_state = 3},
  [1216] = {.lex_state = 42, .external_lex_state = 3},
  [1217] = {.lex_state = 42, .external_lex_state = 3},
  [1218] = {.lex_state = 42, .external_lex_state = 3},
  [1219] = {.lex_state = 42, .external_lex_state = 3},
  [1220] = {.lex_state = 42, .external_lex_state = 3},
  [1221] = {.lex_state = 42, .external_lex_state = 3},
  [1222] = {.lex_state = 42, .external_lex_state = 3},
  [1223] = {.lex_state = 42, .external_lex_state = 3},
  [1224] = {.lex_state = 42, .external_lex_state = 3},
  [1225] = {.lex_state = 42, .external_lex_state = 3},
  [1226] = {.lex_state = 42, .external_lex_state = 3},
  [1227] = {.lex_state = 42, .external_lex_state = 3},
  [1228] = {.lex_state = 42, .external_lex_state = 3},
  [1229] = {.lex_state = 42, .external_lex_state = 3},
  [1230] = {.lex_state = 42, .external_lex_state = 3},
  [1231] = {.lex_state = 42, .external_lex_state = 3},
  [1232] = {.lex_state = 42, .external_lex_state = 3},
  [1233] = {.lex_state = 42, .external_lex_state = 3},
  [1234] = {.lex_state = 42, .external_lex_state = 3},
  [1235] = {.lex_state = 42, .external_lex_state = 3},
  [1236] = {.lex_state = 42, .external_lex_state = 3},
  [1237] = {.lex_state = 42, .external_lex_state = 3},
  [1238] = {.lex_state = 42, .external_lex_state = 3},
  [1239] = {.lex_state = 42, .external_lex_state = 3},
  [1240] = {.lex_state = 42, .external_lex_state = 3},
  [1241] = {.lex_state = 42, .external_lex_state = 3},
  [1242] = {.lex_state = 42, .external_lex_state = 3},
  [1243] = {.lex_state = 42, .external_lex_state = 3},
  [1244] = {.lex_state = 42, .external_lex_state = 3},
  [1245] = {.lex_state = 42, .external_lex_state = 3},
  [1246] = {.lex_state = 42, .external_lex_state = 3},
  [1247] = {.lex_state = 42, .external_lex_state = 3},
  [1248] = {.lex_state = 42, .external_lex_state = 3},
  [1249] = {.lex_state = 42, .external_lex_state = 3},
  [1250] = {.lex_state = 42, .external_lex_state = 3},
  [1251] = {.lex_state = 42, .external_lex_state = 3},
  [1252] = {.lex_state = 42, .external_lex_state = 3},
  [1253] = {.lex_state = 42, .external_lex_state = 3},
  [1254] = {.lex_state = 42, .external_lex_state = 3},
  [1255] = {.lex_state = 42, .external_lex_state = 3},
  [1256] = {.lex_state = 42, .external_lex_state = 3},
  [1257] = {.lex_state = 42, .external_lex_state = 3},
  [1258] = {.lex_state = 42, .external_lex_state = 3},
  [1259] = {.lex_state = 42, .external_lex_state = 3},
  [1260] = {.lex_state = 42, .external_lex_state = 3},
  [1261] = {.lex_state = 42, .external_lex_state = 3},
  [1262] = {.lex_state = 42, .external_lex_state = 3},
  [1263] = {.lex_state = 42, .external_lex_state = 3},
  [1264] = {.lex_state = 42, .external_lex_state = 3},
  [1265] = {.lex_state = 42, .external_lex_state = 3},
  [1266] = {.lex_state = 42, .external_lex_state = 3},
  [1267] = {.lex_state = 42, .external_lex_state = 3},
  [1268] = {.lex_state = 42, .external_lex_state = 3},
  [1269] = {.lex_state = 42, .external_lex_state = 3},
  [1270] = {.lex_state = 42, .external_lex_state = 3},
  [1271] = {.lex_state = 42, .external_lex_state = 3},
  [1272] = {.lex_state = 42, .external_lex_state = 3},
  [1273] = {.lex_state = 42, .external_lex_state = 3},
  [1274] = {.lex_state = 42, .external_lex_state = 3},
  [1275] = {.lex_state = 42, .external_lex_state = 3},
  [1276] = {.lex_state = 42, .external_lex_state = 3},
  [1277] = {.lex_state = 42, .external_lex_state = 3},
  [1278] = {.lex_state = 42, .external_lex_state = 3},
  [1279] = {.lex_state = 42, .external_lex_state = 3},
  [1280] = {.lex_state = 42, .external_lex_state = 3},
  [1281] = {.lex_state = 42, .external_lex_state = 3},
  [1282] = {.lex_state = 42, .external_lex_state = 3},
  [1283] = {.lex_state = 42, .external_lex_state = 3},
  [1284] = {.lex_state = 42, .external_lex_state = 3},
  [1285] = {.lex_state = 42, .external_lex_state = 3},
  [1286] = {.lex_state = 42, .external_lex_state = 3},
  [1287] = {.lex_state = 42, .external_lex_state = 3},
  [1288] = {.lex_state = 42, .external_lex_state = 3},
  [1289] = {.lex_state = 42, .external_lex_state = 3},
  [1290] = {.lex_state = 42, .external_lex_state = 3},
  [1291] = {.lex_state = 42, .external_lex_state = 3},
  [1292] = {.lex_state = 42, .external_lex_state = 3},
  [1293] = {.lex_state = 42, .external_lex_state = 3},
  [1294] = {.lex_state = 42, .external_lex_state = 3},
  [1295] = {.lex_state = 42, .external_lex_state = 3},
  [1296] = {.lex_state = 42, .external_lex_state = 3},
  [1297] = {.lex_state = 42, .external_lex_state = 3},
  [1298] = {.lex_state = 42, .external_lex_state = 3},
  [1299] = {.lex_state = 42, .external_lex_state = 3},
  [1300] = {.lex_state = 42, .external_lex_state = 3},
  [1301] = {.lex_state = 42, .external_lex_state = 3},
  [1302] = {.lex_state = 42, .external_lex_state = 3},
  [1303] = {.lex_state = 42, .external_lex_state = 3},
  [1304] = {.lex_state = 42, .external_lex_state = 3},
  [1305] = {.lex_state = 42, .external_lex_state = 3},
  [1306] = {.lex_state = 42, .external_lex_state = 3},
  [1307] = {.lex_state = 42, .external_lex_state = 3},
  [1308] = {.lex_state = 42, .external_lex_state = 3},
  [1309] = {.lex_state = 42, .external_lex_state = 3},
  [1310] = {.lex_state = 42, .external_lex_state = 3},
  [1311] = {.lex_state = 42, .external_lex_state = 3},
  [1312] = {.lex_state = 42, .external_lex_state = 3},
  [1313] = {.lex_state = 42, .external_lex_state = 3},
  [1314] = {.lex_state = 42, .external_lex_state = 3},
  [1315] = {.lex_state = 42, .external_lex_state = 3},
  [1316] = {.lex_state = 42, .external_lex_state = 3},
  [1317] = {.lex_state = 42, .external_lex_state = 3},
  [1318] = {.lex_state = 42, .external_lex_state = 3},
  [1319] = {.lex_state = 42, .external_lex_state = 3},
  [1320] = {.lex_state = 42, .external_lex_state = 3},
  [1321] = {.lex_state = 42, .external_lex_state = 3},
  [1322] = {.lex_state = 42, .external_lex_state = 3},
  [1323] = {.lex_state = 42, .external_lex_state = 3},
  [1324] = {.lex_state = 42, .external_lex_state = 3},
  [1325] = {.lex_state = 42, .external_lex_state = 3},
  [1326] = {.lex_state = 42, .external_lex_state = 3},
  [1327] = {.lex_state = 42, .external_lex_state = 3},
  [1328] = {.lex_state = 42, .external_lex_state = 3},
  [1329] = {.lex_state = 42, .external_lex_state = 3},
  [1330] = {.lex_state = 42, .external_lex_state = 3},
  [1331] = {.lex_state = 42, .external_lex_state = 3},
  [1332] = {.lex_state = 42, .external_lex_state = 3},
  [1333] = {.lex_state = 42, .external_lex_state = 3},
  [1334] = {.lex_state = 42, .external_lex_state = 3},
  [1335] = {.lex_state = 42, .external_lex_state = 3},
  [1336] = {.lex_state = 42, .external_lex_state = 3},
  [1337] = {.lex_state = 42, .external_lex_state = 3},
  [1338] = {.lex_state = 42, .external_lex_state = 3},
  [1339] = {.lex_state = 42, .external_lex_state = 3},
  [1340] = {.lex_state = 42, .external_lex_state = 3},
  [1341] = {.lex_state = 42, .external_lex_state = 3},
  [1342] = {.lex_state = 42, .external_lex_state = 3},
  [1343] = {.lex_state = 42, .external_lex_state = 3},
  [1344] = {.lex_state = 42, .external_lex_state = 3},
  [1345] = {.lex_state = 42, .external_lex_state = 3},
  [1346] = {.lex_state = 42, .external_lex_state = 3},
  [1347] = {.lex_state = 42, .external_lex_state = 3},
  [1348] = {.lex_state = 42, .external_lex_state = 3},
  [1349] = {.lex_state = 42, .external_lex_state = 3},
  [1350] = {.lex_state = 42, .external_lex_state = 3},
  [1351] = {.lex_state = 42, .external_lex_state = 3},
  [1352] = {.lex_state = 42, .external_lex_state = 3},
  [1353] = {.lex_state = 42, .external_lex_state = 3},
  [1354] = {.lex_state = 42, .external_lex_state = 3},
  [1355] = {.lex_state = 42, .external_lex_state = 3},
  [1356] = {.lex_state = 42, .external_lex_state = 3},
  [1357] = {.lex_state = 42, .external_lex_state = 3},
  [1358] = {.lex_state = 42, .external_lex_state = 3},
  [1359] = {.lex_state = 42, .external_lex_state = 3},
  [1360] = {.lex_state = 42, .external_lex_state = 3},
  [1361] = {.lex_state = 42, .external_lex_state = 3},
  [1362] = {.lex_state = 42, .external_lex_state = 3},
  [1363] = {.lex_state = 42, .external_lex_state = 3},
  [1364] = {.lex_state = 42, .external_lex_state = 3},
  [1365] = {.lex_state = 42, .external_lex_state = 3},
  [1366] = {.lex_state = 42, .external_lex_state = 3},
  [1367] = {.lex_state = 42, .external_lex_state = 3},
  [1368] = {.lex_state = 42, .external_lex_state = 3},
  [1369] = {.lex_state = 42, .external_lex_state = 3},
  [1370] = {.lex_state = 42, .external_lex_state = 3},
  [1371] = {.lex_state = 42, .external_lex_state = 3},
  [1372] = {.lex_state = 42, .external_lex_state = 3},
  [1373] = {.lex_state = 42, .external_lex_state = 3},
  [1374] = {.lex_state = 42, .external_lex_state = 3},
  [1375] = {.lex_state = 42, .external_lex_state = 3},
  [1376] = {.lex_state = 42, .external_lex_state = 3},
  [1377] = {.lex_state = 42, .external_lex_state = 3},
  [1378] = {.lex_state = 42, .external_lex_state = 3},
  [1379] = {.lex_state = 42, .external_lex_state = 3},
  [1380] = {.lex_state = 42, .external_lex_state = 3},
  [1381] = {.lex_state = 42, .external_lex_state = 3},
  [1382] = {.lex_state = 42, .external_lex_state = 3},
  [1383] = {.lex_state = 42, .external_lex_state = 3},
  [1384] = {.lex_state = 42, .external_lex_state = 3},
  [1385] = {.lex_state = 42, .external_lex_state = 3},
  [1386] = {.lex_state = 42, .external_lex_state = 3},
  [1387] = {.lex_state = 42, .external_lex_state = 3},
  [1388] = {.lex_state = 42, .external_lex_state = 3},
  [1389] = {.lex_state = 42, .external_lex_state = 3},
  [1390] = {.lex_state = 42, .external_lex_state = 3},
  [1391] = {.lex_state = 42, .external_lex_state = 3},
  [1392] = {.lex_state = 42, .external_lex_state = 3},
  [1393] = {.lex_state = 42, .external_lex_state = 3},
  [1394] = {.lex_state = 42, .external_lex_state = 3},
  [1395] = {.lex_state = 42, .external_lex_state = 3},
  [1396] = {.lex_state = 42, .external_lex_state = 3},
  [1397] = {.lex_state = 42, .external_lex_state = 3},
  [1398] = {.lex_state = 42, .external_lex_state = 3},
  [1399] = {.lex_state = 42, .external_lex_state = 3},
  [1400] = {.lex_state = 42, .external_lex_state = 3},
  [1401] = {.lex_state = 42, .external_lex_state = 3},
  [1402] = {.lex_state = 42, .external_lex_state = 3},
  [1403] = {.lex_state = 42, .external_lex_state = 3},
  [1404] = {.lex_state = 42, .external_lex_state = 3},
  [1405] = {.lex_state = 42, .external_lex_state = 3},
  [1406] = {.lex_state = 42, .external_lex_state = 3},
  [1407] = {.lex_state = 42, .external_lex_state = 3},
  [1408] = {.lex_state = 42, .external_lex_state = 3},
  [1409] = {.lex_state = 42, .external_lex_state = 3},
  [1410] = {.lex_state = 42, .external_lex_state = 3},
  [1411] = {.lex_state = 42, .external_lex_state = 3},
  [1412] = {.lex_state = 42, .external_lex_state = 3},
  [1413] = {.lex_state = 42, .external_lex_state = 3},
  [1414] = {.lex_state = 42, .external_lex_state = 3},
  [1415] = {.lex_state = 42, .external_lex_state = 3},
  [1416] = {.lex_state = 42, .external_lex_state = 3},
  [1417] = {.lex_state = 42, .external_lex_state = 3},
  [1418] = {.lex_state = 42, .external_lex_state = 3},
  [1419] = {.lex_state = 42, .external_lex_state = 3},
  [1420] = {.lex_state = 42, .external_lex_state = 3},
  [1421] = {.lex_state = 42, .external_lex_state = 3},
  [1422] = {.lex_state = 42, .external_lex_state = 3},
  [1423] = {.lex_state = 42, .external_lex_state = 3},
  [1424] = {.lex_state = 42, .external_lex_state = 3},
  [1425] = {.lex_state = 42, .external_lex_state = 3},
  [1426] = {.lex_state = 42, .external_lex_state = 3},
  [1427] = {.lex_state = 42, .external_lex_state = 3},
  [1428] = {.lex_state = 42, .external_lex_state = 3},
  [1429] = {.lex_state = 42, .external_lex_state = 3},
  [1430] = {.lex_state = 42, .external_lex_state = 3},
  [1431] = {.lex_state = 42, .external_lex_state = 3},
  [1432] = {.lex_state = 42, .external_lex_state = 3},
  [1433] = {.lex_state = 42, .external_lex_state = 3},
  [1434] = {.lex_state = 42, .external_lex_state = 3},
  [1435] = {.lex_state = 42, .external_lex_state = 3},
  [1436] = {.lex_state = 42, .external_lex_state = 3},
  [1437] = {.lex_state = 42, .external_lex_state = 3},
  [1438] = {.lex_state = 42, .external_lex_state = 3},
  [1439] = {.lex_state = 42, .external_lex_state = 3},
  [1440] = {.lex_state = 42, .external_lex_state = 3},
  [1441] = {.lex_state = 42, .external_lex_state = 3},
  [1442] = {.lex_state = 42, .external_lex_state = 3},
  [1443] = {.lex_state = 42, .external_lex_state = 3},
  [1444] = {.lex_state = 42, .external_lex_state = 3},
  [1445] = {.lex_state = 42, .external_lex_state = 3},
  [1446] = {.lex_state = 42, .external_lex_state = 3},
  [1447] = {.lex_state = 42, .external_lex_state = 3},
  [1448] = {.lex_state = 42, .external_lex_state = 3},
  [1449] = {.lex_state = 42, .external_lex_state = 3},
  [1450] = {.lex_state = 42, .external_lex_state = 3},
  [1451] = {.lex_state = 42, .external_lex_state = 3},
  [1452] = {.lex_state = 42, .external_lex_state = 3},
  [1453] = {.lex_state = 42, .external_lex_state = 3},
  [1454] = {.lex_state = 42, .external_lex_state = 3},
  [1455] = {.lex_state = 42, .external_lex_state = 3},
  [1456] = {.lex_state = 42, .external_lex_state = 3},
  [1457] = {.lex_state = 42, .external_lex_state = 3},
  [1458] = {.lex_state = 42, .external_lex_state = 3},
  [1459] = {.lex_state = 42, .external_lex_state = 3},
  [1460] = {.lex_state = 42, .external_lex_state = 3},
  [1461] = {.lex_state = 42, .external_lex_state = 3},
  [1462] = {.lex_state = 42, .external_lex_state = 3},
  [1463] = {.lex_state = 42, .external_lex_state = 3},
  [1464] = {.lex_state = 42, .external_lex_state = 3},
  [1465] = {.lex_state = 42, .external_lex_state = 3},
  [1466] = {.lex_state = 42, .external_lex_state = 3},
  [1467] = {.lex_state = 42, .external_lex_state = 3},
  [1468] = {.lex_state = 42, .external_lex_state = 3},
  [1469] = {.lex_state = 42, .external_lex_state = 3},
  [1470] = {.lex_state = 42, .external_lex_state = 3},
  [1471] = {.lex_state = 42, .external_lex_state = 3},
  [1472] = {.lex_state = 42, .external_lex_state = 3},
  [1473] = {.lex_state = 42, .external_lex_state = 3},
  [1474] = {.lex_state = 42, .external_lex_state = 3},
  [1475] = {.lex_state = 42, .external_lex_state = 3},
  [1476] = {.lex_state = 42, .external_lex_state = 3},
  [1477] = {.lex_state = 42, .external_lex_state = 3},
  [1478] = {.lex_state = 42, .external_lex_state = 3},
  [1479] = {.lex_state = 42, .external_lex_state = 3},
  [1480] = {.lex_state = 42, .external_lex_state = 3},
  [1481] = {.lex_state = 42, .external_lex_state = 3},
  [1482] = {.lex_state = 42, .external_lex_state = 3},
  [1483] = {.lex_state = 42, .external_lex_state = 3},
  [1484] = {.lex_state = 42, .external_lex_state = 3},
  [1485] = {.lex_state = 42, .external_lex_state = 3},
  [1486] = {.lex_state = 42, .external_lex_state = 3},
  [1487] = {.lex_state = 42, .external_lex_state = 3},
  [1488] = {.lex_state = 42, .external_lex_state = 3},
  [1489] = {.lex_state = 42, .external_lex_state = 3},
  [1490] = {.lex_state = 42, .external_lex_state = 3},
  [1491] = {.lex_state = 42, .external_lex_state = 3},
  [1492] = {.lex_state = 42, .external_lex_state = 3},
  [1493] = {.lex_state = 42, .external_lex_state = 3},
  [1494] = {.lex_state = 42, .external_lex_state = 3},
  [1495] = {.lex_state = 42, .external_lex_state = 3},
  [1496] = {.lex_state = 42, .external_lex_state = 3},
  [1497] = {.lex_state = 42, .external_lex_state = 3},
  [1498] = {.lex_state = 42, .external_lex_state = 3},
  [1499] = {.lex_state = 42, .external_lex_state = 3},
  [1500] = {.lex_state = 42, .external_lex_state = 3},
  [1501] = {.lex_state = 42, .external_lex_state = 3},
  [1502] = {.lex_state = 42, .external_lex_state = 3},
  [1503] = {.lex_state = 42, .external_lex_state = 3},
  [1504] = {.lex_state = 42, .external_lex_state = 3},
  [1505] = {.lex_state = 42, .external_lex_state = 3},
  [1506] = {.lex_state = 42, .external_lex_state = 3},
  [1507] = {.lex_state = 42, .external_lex_state = 3},
  [1508] = {.lex_state = 42, .external_lex_state = 3},
  [1509] = {.lex_state = 42, .external_lex_state = 3},
  [1510] = {.lex_state = 42, .external_lex_state = 3},
  [1511] = {.lex_state = 42, .external_lex_state = 3},
  [1512] = {.lex_state = 42, .external_lex_state = 3},
  [1513] = {.lex_state = 42, .external_lex_state = 3},
  [1514] = {.lex_state = 42, .external_lex_state = 3},
  [1515] = {.lex_state = 42, .external_lex_state = 3},
  [1516] = {.lex_state = 42, .external_lex_state = 3},
  [1517] = {.lex_state = 42, .external_lex_state = 3},
  [1518] = {.lex_state = 42, .external_lex_state = 3},
  [1519] = {.lex_state = 42, .external_lex_state = 3},
  [1520] = {.lex_state = 42, .external_lex_state = 3},
  [1521] = {.lex_state = 42, .external_lex_state = 3},
  [1522] = {.lex_state = 42, .external_lex_state = 3},
  [1523] = {.lex_state = 42, .external_lex_state = 3},
  [1524] = {.lex_state = 42, .external_lex_state = 3},
  [1525] = {.lex_state = 42, .external_lex_state = 3},
  [1526] = {.lex_state = 42, .external_lex_state = 3},
  [1527] = {.lex_state = 42, .external_lex_state = 3},
  [1528] = {.lex_state = 42, .external_lex_state = 3},
  [1529] = {.lex_state = 42, .external_lex_state = 3},
  [1530] = {.lex_state = 42, .external_lex_state = 3},
  [1531] = {.lex_state = 42, .external_lex_state = 3},
  [1532] = {.lex_state = 42, .external_lex_state = 3},
  [1533] = {.lex_state = 42, .external_lex_state = 3},
  [1534] = {.lex_state = 42, .external_lex_state = 3},
  [1535] = {.lex_state = 42, .external_lex_state = 3},
  [1536] = {.lex_state = 42, .external_lex_state = 3},
  [1537] = {.lex_state = 42, .external_lex_state = 3},
  [1538] = {.lex_state = 42, .external_lex_state = 3},
  [1539] = {.lex_state = 42, .external_lex_state = 3},
  [1540] = {.lex_state = 42, .external_lex_state = 3},
  [1541] = {.lex_state = 42, .external_lex_state = 3},
  [1542] = {.lex_state = 42, .external_lex_state = 3},
  [1543] = {.lex_state = 42, .external_lex_state = 3},
  [1544] = {.lex_state = 42, .external_lex_state = 3},
  [1545] = {.lex_state = 42, .external_lex_state = 3},
  [1546] = {.lex_state = 42, .external_lex_state = 3},
  [1547] = {.lex_state = 42, .external_lex_state = 3},
  [1548] = {.lex_state = 42, .external_lex_state = 3},
  [1549] = {.lex_state = 42, .external_lex_state = 3},
  [1550] = {.lex_state = 42, .external_lex_state = 3},
  [1551] = {.lex_state = 42, .external_lex_state = 3},
  [1552] = {.lex_state = 42, .external_lex_state = 3},
  [1553] = {.lex_state = 42, .external_lex_state = 3},
  [1554] = {.lex_state = 42, .external_lex_state = 3},
  [1555] = {.lex_state = 42, .external_lex_state = 3},
  [1556] = {.lex_state = 42, .external_lex_state = 3},
  [1557] = {.lex_state = 42, .external_lex_state = 3},
  [1558] = {.lex_state = 42, .external_lex_state = 3},
  [1559] = {.lex_state = 42, .external_lex_state = 3},
  [1560] = {.lex_state = 42, .external_lex_state = 3},
  [1561] = {.lex_state = 42, .external_lex_state = 3},
  [1562] = {.lex_state = 42, .external_lex_state = 3},
  [1563] = {.lex_state = 42, .external_lex_state = 3},
  [1564] = {.lex_state = 42, .external_lex_state = 3},
  [1565] = {.lex_state = 42, .external_lex_state = 3},
  [1566] = {.lex_state = 42, .external_lex_state = 3},
  [1567] = {.lex_state = 42, .external_lex_state = 3},
  [1568] = {.lex_state = 42, .external_lex_state = 3},
  [1569] = {.lex_state = 42, .external_lex_state = 3},
  [1570] = {.lex_state = 42, .external_lex_state = 3},
  [1571] = {.lex_state = 42, .external_lex_state = 3},
  [1572] = {.lex_state = 42, .external_lex_state = 3},
  [1573] = {.lex_state = 42, .external_lex_state = 3},
  [1574] = {.lex_state = 42, .external_lex_state = 3},
  [1575] = {.lex_state = 42, .external_lex_state = 3},
  [1576] = {.lex_state = 42, .external_lex_state = 3},
  [1577] = {.lex_state = 42, .external_lex_state = 3},
  [1578] = {.lex_state = 42, .external_lex_state = 3},
  [1579] = {.lex_state = 42, .external_lex_state = 3},
  [1580] = {.lex_state = 42, .external_lex_state = 3},
  [1581] = {.lex_state = 42, .external_lex_state = 3},
  [1582] = {.lex_state = 42, .external_lex_state = 3},
  [1583] = {.lex_state = 42, .external_lex_state = 3},
  [1584] = {.lex_state = 42, .external_lex_state = 3},
  [1585] = {.lex_state = 42, .external_lex_state = 3},
  [1586] = {.lex_state = 42, .external_lex_state = 3},
  [1587] = {.lex_state = 42, .external_lex_state = 3},
  [1588] = {.lex_state = 42, .external_lex_state = 3},
  [1589] = {.lex_state = 42, .external_lex_state = 3},
  [1590] = {.lex_state = 42, .external_lex_state = 3},
  [1591] = {.lex_state = 42, .external_lex_state = 3},
  [1592] = {.lex_state = 42, .external_lex_state = 3},
  [1593] = {.lex_state = 42, .external_lex_state = 3},
  [1594] = {.lex_state = 42, .external_lex_state = 3},
  [1595] = {.lex_state = 42, .external_lex_state = 3},
  [1596] = {.lex_state = 42, .external_lex_state = 3},
  [1597] = {.lex_state = 42, .external_lex_state = 3},
  [1598] = {.lex_state = 42, .external_lex_state = 3},
  [1599] = {.lex_state = 42, .external_lex_state = 3},
  [1600] = {.lex_state = 42, .external_lex_state = 3},
  [1601] = {.lex_state = 42, .external_lex_state = 3},
  [1602] = {.lex_state = 42, .external_lex_state = 3},
  [1603] = {.lex_state = 42, .external_lex_state = 3},
  [1604] = {.lex_state = 42, .external_lex_state = 3},
  [1605] = {.lex_state = 42, .external_lex_state = 3},
  [1606] = {.lex_state = 42, .external_lex_state = 3},
  [1607] = {.lex_state = 42, .external_lex_state = 3},
  [1608] = {.lex_state = 78, .external_lex_state = 3},
  [1609] = {.lex_state = 42, .external_lex_state = 3},
  [1610] = {.lex_state = 42, .external_lex_state = 3},
  [1611] = {.lex_state = 42, .external_lex_state = 3},
  [1612] = {.lex_state = 42, .external_lex_state = 3},
  [1613] = {.lex_state = 42, .external_lex_state = 3},
  [1614] = {.lex_state = 42, .external_lex_state = 3},
  [1615] = {.lex_state = 82, .external_lex_state = 3},
  [1616] = {.lex_state = 42, .external_lex_state = 3},
  [1617] = {.lex_state = 42, .external_lex_state = 3},
  [1618] = {.lex_state = 42, .external_lex_state = 3},
  [1619] = {.lex_state = 42, .external_lex_state = 3},
  [1620] = {.lex_state = 42, .external_lex_state = 3},
  [1621] = {.lex_state = 42, .external_lex_state = 3},
  [1622] = {.lex_state = 42, .external_lex_state = 3},
  [1623] = {.lex_state = 42, .external_lex_state = 3},
  [1624] = {.lex_state = 42, .external_lex_state = 3},
  [1625] = {.lex_state = 42, .external_lex_state = 3},
  [1626] = {.lex_state = 42, .external_lex_state = 3},
  [1627] = {.lex_state = 42, .external_lex_state = 3},
  [1628] = {.lex_state = 42, .external_lex_state = 3},
  [1629] = {.lex_state = 42, .external_lex_state = 3},
  [1630] = {.lex_state = 42, .external_lex_state = 3},
  [1631] = {.lex_state = 42, .external_lex_state = 3},
  [1632] = {.lex_state = 42, .external_lex_state = 3},
  [1633] = {.lex_state = 42, .external_lex_state = 3},
  [1634] = {.lex_state = 42, .external_lex_state = 3},
  [1635] = {.lex_state = 42, .external_lex_state = 3},
  [1636] = {.lex_state = 83, .external_lex_state = 3},
  [1637] = {.lex_state = 42, .external_lex_state = 3},
  [1638] = {.lex_state = 42, .external_lex_state = 3},
  [1639] = {.lex_state = 42, .external_lex_state = 3},
  [1640] = {.lex_state = 42, .external_lex_state = 3},
  [1641] = {.lex_state = 42, .external_lex_state = 3},
  [1642] = {.lex_state = 42, .external_lex_state = 3},
  [1643] = {.lex_state = 42, .external_lex_state = 3},
  [1644] = {.lex_state = 42, .external_lex_state = 3},
  [1645] = {.lex_state = 42, .external_lex_state = 3},
  [1646] = {.lex_state = 42, .external_lex_state = 3},
  [1647] = {.lex_state = 42, .external_lex_state = 3},
  [1648] = {.lex_state = 42, .external_lex_state = 3},
  [1649] = {.lex_state = 42, .external_lex_state = 3},
  [1650] = {.lex_state = 42, .external_lex_state = 3},
  [1651] = {.lex_state = 42, .external_lex_state = 3},
  [1652] = {.lex_state = 42, .external_lex_state = 3},
  [1653] = {.lex_state = 42, .external_lex_state = 3},
  [1654] = {.lex_state = 42, .external_lex_state = 3},
  [1655] = {.lex_state = 42, .external_lex_state = 3},
  [1656] = {.lex_state = 42, .external_lex_state = 3},
  [1657] = {.lex_state = 42, .external_lex_state = 3},
  [1658] = {.lex_state = 42, .external_lex_state = 3},
  [1659] = {.lex_state = 42, .external_lex_state = 3},
  [1660] = {.lex_state = 42, .external_lex_state = 3},
  [1661] = {.lex_state = 42, .external_lex_state = 3},
  [1662] = {.lex_state = 42, .external_lex_state = 3},
  [1663] = {.lex_state = 42, .external_lex_state = 3},
  [1664] = {.lex_state = 42, .external_lex_state = 3},
  [1665] = {.lex_state = 42, .external_lex_state = 3},
  [1666] = {.lex_state = 42, .external_lex_state = 3},
  [1667] = {.lex_state = 42, .external_lex_state = 3},
  [1668] = {.lex_state = 42, .external_lex_state = 3},
  [1669] = {.lex_state = 42, .external_lex_state = 3},
  [1670] = {.lex_state = 42, .external_lex_state = 3},
  [1671] = {.lex_state = 42, .external_lex_state = 3},
  [1672] = {.lex_state = 42, .external_lex_state = 3},
  [1673] = {.lex_state = 42, .external_lex_state = 3},
  [1674] = {.lex_state = 42, .external_lex_state = 3},
  [1675] = {.lex_state = 42, .external_lex_state = 3},
  [1676] = {.lex_state = 42, .external_lex_state = 3},
  [1677] = {.lex_state = 42, .external_lex_state = 3},
  [1678] = {.lex_state = 42, .external_lex_state = 3},
  [1679] = {.lex_state = 42, .external_lex_state = 3},
  [1680] = {.lex_state = 42, .external_lex_state = 3},
  [1681] = {.lex_state = 42, .external_lex_state = 3},
  [1682] = {.lex_state = 42, .external_lex_state = 3},
  [1683] = {.lex_state = 42, .external_lex_state = 3},
  [1684] = {.lex_state = 42, .external_lex_state = 3},
  [1685] = {.lex_state = 42, .external_lex_state = 3},
  [1686] = {.lex_state = 42, .external_lex_state = 3},
  [1687] = {.lex_state = 42, .external_lex_state = 3},
  [1688] = {.lex_state = 42, .external_lex_state = 3},
  [1689] = {.lex_state = 42, .external_lex_state = 3},
  [1690] = {.lex_state = 42, .external_lex_state = 3},
  [1691] = {.lex_state = 42, .external_lex_state = 3},
  [1692] = {.lex_state = 42, .external_lex_state = 3},
  [1693] = {.lex_state = 42, .external_lex_state = 3},
  [1694] = {.lex_state = 42, .external_lex_state = 3},
  [1695] = {.lex_state = 42, .external_lex_state = 3},
  [1696] = {.lex_state = 42, .external_lex_state = 3},
  [1697] = {.lex_state = 42, .external_lex_state = 3},
  [1698] = {.lex_state = 42, .external_lex_state = 3},
  [1699] = {.lex_state = 42, .external_lex_state = 3},
  [1700] = {.lex_state = 42, .external_lex_state = 3},
  [1701] = {.lex_state = 42, .external_lex_state = 3},
  [1702] = {.lex_state = 42, .external_lex_state = 3},
  [1703] = {.lex_state = 42, .external_lex_state = 3},
  [1704] = {.lex_state = 42, .external_lex_state = 3},
  [1705] = {.lex_state = 42, .external_lex_state = 3},
  [1706] = {.lex_state = 42, .external_lex_state = 3},
  [1707] = {.lex_state = 42, .external_lex_state = 3},
  [1708] = {.lex_state = 42, .external_lex_state = 3},
  [1709] = {.lex_state = 42, .external_lex_state = 3},
  [1710] = {.lex_state = 42, .external_lex_state = 3},
  [1711] = {.lex_state = 42, .external_lex_state = 3},
  [1712] = {.lex_state = 42, .external_lex_state = 3},
  [1713] = {.lex_state = 42, .external_lex_state = 3},
  [1714] = {.lex_state = 42, .external_lex_state = 3},
  [1715] = {.lex_state = 42, .external_lex_state = 3},
  [1716] = {.lex_state = 42, .external_lex_state = 3},
  [1717] = {.lex_state = 42, .external_lex_state = 3},
  [1718] = {.lex_state = 42, .external_lex_state = 3},
  [1719] = {.lex_state = 42, .external_lex_state = 3},
  [1720] = {.lex_state = 42, .external_lex_state = 3},
  [1721] = {.lex_state = 42, .external_lex_state = 3},
  [1722] = {.lex_state = 42, .external_lex_state = 3},
  [1723] = {.lex_state = 42, .external_lex_state = 3},
  [1724] = {.lex_state = 42, .external_lex_state = 3},
  [1725] = {.lex_state = 42, .external_lex_state = 3},
  [1726] = {.lex_state = 42, .external_lex_state = 3},
  [1727] = {.lex_state = 42, .external_lex_state = 3},
  [1728] = {.lex_state = 42, .external_lex_state = 3},
  [1729] = {.lex_state = 42, .external_lex_state = 3},
  [1730] = {.lex_state = 42, .external_lex_state = 3},
  [1731] = {.lex_state = 42, .external_lex_state = 3},
  [1732] = {.lex_state = 42, .external_lex_state = 3},
  [1733] = {.lex_state = 42, .external_lex_state = 3},
  [1734] = {.lex_state = 42, .external_lex_state = 3},
  [1735] = {.lex_state = 42, .external_lex_state = 3},
  [1736] = {.lex_state = 42, .external_lex_state = 3},
  [1737] = {.lex_state = 42, .external_lex_state = 3},
  [1738] = {.lex_state = 42, .external_lex_state = 3},
  [1739] = {.lex_state = 42, .external_lex_state = 3},
  [1740] = {.lex_state = 42, .external_lex_state = 3},
  [1741] = {.lex_state = 42, .external_lex_state = 3},
  [1742] = {.lex_state = 42, .external_lex_state = 3},
  [1743] = {.lex_state = 42, .external_lex_state = 3},
  [1744] = {.lex_state = 42, .external_lex_state = 3},
  [1745] = {.lex_state = 42, .external_lex_state = 3},
  [1746] = {.lex_state = 42, .external_lex_state = 3},
  [1747] = {.lex_state = 42, .external_lex_state = 3},
  [1748] = {.lex_state = 42, .external_lex_state = 3},
  [1749] = {.lex_state = 42, .external_lex_state = 3},
  [1750] = {.lex_state = 42, .external_lex_state = 3},
  [1751] = {.lex_state = 42, .external_lex_state = 3},
  [1752] = {.lex_state = 42, .external_lex_state = 3},
  [1753] = {.lex_state = 42, .external_lex_state = 3},
  [1754] = {.lex_state = 42, .external_lex_state = 3},
  [1755] = {.lex_state = 42, .external_lex_state = 3},
  [1756] = {.lex_state = 42, .external_lex_state = 3},
  [1757] = {.lex_state = 42, .external_lex_state = 3},
  [1758] = {.lex_state = 42, .external_lex_state = 3},
  [1759] = {.lex_state = 42, .external_lex_state = 3},
  [1760] = {.lex_state = 42, .external_lex_state = 3},
  [1761] = {.lex_state = 42, .external_lex_state = 3},
  [1762] = {.lex_state = 42, .external_lex_state = 3},
  [1763] = {.lex_state = 42, .external_lex_state = 3},
  [1764] = {.lex_state = 42, .external_lex_state = 3},
  [1765] = {.lex_state = 42, .external_lex_state = 3},
  [1766] = {.lex_state = 42, .external_lex_state = 3},
  [1767] = {.lex_state = 42, .external_lex_state = 3},
  [1768] = {.lex_state = 42, .external_lex_state = 3},
  [1769] = {.lex_state = 42, .external_lex_state = 3},
  [1770] = {.lex_state = 42, .external_lex_state = 3},
  [1771] = {.lex_state = 75, .external_lex_state = 3},
  [1772] = {.lex_state = 42, .external_lex_state = 3},
  [1773] = {.lex_state = 42, .external_lex_state = 3},
  [1774] = {.lex_state = 42, .external_lex_state = 3},
  [1775] = {.lex_state = 42, .external_lex_state = 3},
  [1776] = {.lex_state = 42, .external_lex_state = 3},
  [1777] = {.lex_state = 42, .external_lex_state = 3},
  [1778] = {.lex_state = 42, .external_lex_state = 3},
  [1779] = {.lex_state = 42, .external_lex_state = 3},
  [1780] = {.lex_state = 42, .external_lex_state = 3},
  [1781] = {.lex_state = 42, .external_lex_state = 3},
  [1782] = {.lex_state = 42, .external_lex_state = 3},
  [1783] = {.lex_state = 42, .external_lex_state = 3},
  [1784] = {.lex_state = 42, .external_lex_state = 3},
  [1785] = {.lex_state = 42, .external_lex_state = 3},
  [1786] = {.lex_state = 42, .external_lex_state = 3},
  [1787] = {.lex_state = 42, .external_lex_state = 3},
  [1788] = {.lex_state = 42, .external_lex_state = 3},
  [1789] = {.lex_state = 42, .external_lex_state = 3},
  [1790] = {.lex_state = 42, .external_lex_state = 3},
  [1791] = {.lex_state = 42, .external_lex_state = 3},
  [1792] = {.lex_state = 42, .external_lex_state = 3},
  [1793] = {.lex_state = 42, .external_lex_state = 3},
  [1794] = {.lex_state = 42, .external_lex_state = 3},
  [1795] = {.lex_state = 42, .external_lex_state = 3},
  [1796] = {.lex_state = 42, .external_lex_state = 3},
  [1797] = {.lex_state = 42, .external_lex_state = 3},
  [1798] = {.lex_state = 42, .external_lex_state = 3},
  [1799] = {.lex_state = 42, .external_lex_state = 3},
  [1800] = {.lex_state = 42, .external_lex_state = 3},
  [1801] = {.lex_state = 42, .external_lex_state = 3},
  [1802] = {.lex_state = 42, .external_lex_state = 3},
  [1803] = {.lex_state = 42, .external_lex_state = 3},
  [1804] = {.lex_state = 42, .external_lex_state = 3},
  [1805] = {.lex_state = 42, .external_lex_state = 3},
  [1806] = {.lex_state = 42, .external_lex_state = 3},
  [1807] = {.lex_state = 42, .external_lex_state = 3},
  [1808] = {.lex_state = 42, .external_lex_state = 3},
  [1809] = {.lex_state = 42, .external_lex_state = 3},
  [1810] = {.lex_state = 42, .external_lex_state = 3},
  [1811] = {.lex_state = 42, .external_lex_state = 3},
  [1812] = {.lex_state = 42, .external_lex_state = 3},
  [1813] = {.lex_state = 42, .external_lex_state = 3},
  [1814] = {.lex_state = 76, .external_lex_state = 3},
  [1815] = {.lex_state = 84, .external_lex_state = 3},
  [1816] = {.lex_state = 42, .external_lex_state = 3},
  [1817] = {.lex_state = 42, .external_lex_state = 3},
  [1818] = {.lex_state = 42, .external_lex_state = 3},
  [1819] = {.lex_state = 42, .external_lex_state = 3},
  [1820] = {.lex_state = 42, .external_lex_state = 3},
  [1821] = {.lex_state = 42, .external_lex_state = 3},
  [1822] = {.lex_state = 42, .external_lex_state = 3},
  [1823] = {.lex_state = 42, .external_lex_state = 3},
  [1824] = {.lex_state = 42, .external_lex_state = 3},
  [1825] = {.lex_state = 42, .external_lex_state = 3},
  [1826] = {.lex_state = 42, .external_lex_state = 3},
  [1827] = {.lex_state = 42, .external_lex_state = 3},
  [1828] = {.lex_state = 42, .external_lex_state = 3},
  [1829] = {.lex_state = 42, .external_lex_state = 3},
  [1830] = {.lex_state = 42, .external_lex_state = 3},
  [1831] = {.lex_state = 42, .external_lex_state = 3},
  [1832] = {.lex_state = 42, .external_lex_state = 3},
  [1833] = {.lex_state = 42, .external_lex_state = 3},
  [1834] = {.lex_state = 42, .external_lex_state = 3},
  [1835] = {.lex_state = 42, .external_lex_state = 3},
  [1836] = {.lex_state = 42, .external_lex_state = 3},
  [1837] = {.lex_state = 42, .external_lex_state = 3},
  [1838] = {.lex_state = 42, .external_lex_state = 3},
  [1839] = {.lex_state = 42, .external_lex_state = 3},
  [1840] = {.lex_state = 42, .external_lex_state = 3},
  [1841] = {.lex_state = 42, .external_lex_state = 3},
  [1842] = {.lex_state = 42, .external_lex_state = 3},
  [1843] = {.lex_state = 42, .external_lex_state = 3},
  [1844] = {.lex_state = 42, .external_lex_state = 3},
  [1845] = {.lex_state = 42, .external_lex_state = 3},
  [1846] = {.lex_state = 42, .external_lex_state = 3},
  [1847] = {.lex_state = 42, .external_lex_state = 3},
  [1848] = {.lex_state = 42, .external_lex_state = 3},
  [1849] = {.lex_state = 42, .external_lex_state = 3},
  [1850] = {.lex_state = 42, .external_lex_state = 3},
  [1851] = {.lex_state = 42, .external_lex_state = 3},
  [1852] = {.lex_state = 42, .external_lex_state = 3},
  [1853] = {.lex_state = 42, .external_lex_state = 3},
  [1854] = {.lex_state = 42, .external_lex_state = 3},
  [1855] = {.lex_state = 42, .external_lex_state = 3},
  [1856] = {.lex_state = 42, .external_lex_state = 3},
  [1857] = {.lex_state = 42, .external_lex_state = 3},
  [1858] = {.lex_state = 42, .external_lex_state = 3},
  [1859] = {.lex_state = 42, .external_lex_state = 3},
  [1860] = {.lex_state = 42, .external_lex_state = 3},
  [1861] = {.lex_state = 42, .external_lex_state = 3},
  [1862] = {.lex_state = 42, .external_lex_state = 3},
  [1863] = {.lex_state = 42, .external_lex_state = 3},
  [1864] = {.lex_state = 42, .external_lex_state = 3},
  [1865] = {.lex_state = 42, .external_lex_state = 3},
  [1866] = {.lex_state = 42, .external_lex_state = 3},
  [1867] = {.lex_state = 42, .external_lex_state = 3},
  [1868] = {.lex_state = 42, .external_lex_state = 3},
  [1869] = {.lex_state = 42, .external_lex_state = 3},
  [1870] = {.lex_state = 42, .external_lex_state = 3},
  [1871] = {.lex_state = 42, .external_lex_state = 3},
  [1872] = {.lex_state = 42, .external_lex_state = 3},
  [1873] = {.lex_state = 42, .external_lex_state = 3},
  [1874] = {.lex_state = 42, .external_lex_state = 3},
  [1875] = {.lex_state = 42, .external_lex_state = 3},
  [1876] = {.lex_state = 42, .external_lex_state = 3},
  [1877] = {.lex_state = 42, .external_lex_state = 3},
  [1878] = {.lex_state = 42, .external_lex_state = 3},
  [1879] = {.lex_state = 42, .external_lex_state = 3},
  [1880] = {.lex_state = 42, .external_lex_state = 3},
  [1881] = {.lex_state = 42, .external_lex_state = 3},
  [1882] = {.lex_state = 42, .external_lex_state = 3},
  [1883] = {.lex_state = 42, .external_lex_state = 3},
  [1884] = {.lex_state = 42, .external_lex_state = 3},
  [1885] = {.lex_state = 42, .external_lex_state = 3},
  [1886] = {.lex_state = 42, .external_lex_state = 3},
  [1887] = {.lex_state = 42, .external_lex_state = 3},
  [1888] = {.lex_state = 42, .external_lex_state = 3},
  [1889] = {.lex_state = 42, .external_lex_state = 3},
  [1890] = {.lex_state = 42, .external_lex_state = 3},
  [1891] = {.lex_state = 42, .external_lex_state = 3},
  [1892] = {.lex_state = 42, .external_lex_state = 3},
  [1893] = {.lex_state = 42, .external_lex_state = 3},
  [1894] = {.lex_state = 42, .external_lex_state = 3},
  [1895] = {.lex_state = 42, .external_lex_state = 3},
  [1896] = {.lex_state = 42, .external_lex_state = 3},
  [1897] = {.lex_state = 42, .external_lex_state = 3},
  [1898] = {.lex_state = 42, .external_lex_state = 3},
  [1899] = {.lex_state = 42, .external_lex_state = 3},
  [1900] = {.lex_state = 42, .external_lex_state = 3},
  [1901] = {.lex_state = 42, .external_lex_state = 3},
  [1902] = {.lex_state = 42, .external_lex_state = 3},
  [1903] = {.lex_state = 42, .external_lex_state = 3},
  [1904] = {.lex_state = 42, .external_lex_state = 3},
  [1905] = {.lex_state = 42, .external_lex_state = 3},
  [1906] = {.lex_state = 42, .external_lex_state = 3},
  [1907] = {.lex_state = 42, .external_lex_state = 3},
  [1908] = {.lex_state = 42, .external_lex_state = 3},
  [1909] = {.lex_state = 42, .external_lex_state = 3},
  [1910] = {.lex_state = 42, .external_lex_state = 3},
  [1911] = {.lex_state = 42, .external_lex_state = 3},
  [1912] = {.lex_state = 42, .external_lex_state = 3},
  [1913] = {.lex_state = 42, .external_lex_state = 3},
  [1914] = {.lex_state = 42, .external_lex_state = 3},
  [1915] = {.lex_state = 42, .external_lex_state = 3},
  [1916] = {.lex_state = 42, .external_lex_state = 3},
  [1917] = {.lex_state = 42, .external_lex_state = 3},
  [1918] = {.lex_state = 42, .external_lex_state = 3},
  [1919] = {.lex_state = 42, .external_lex_state = 3},
  [1920] = {.lex_state = 42, .external_lex_state = 3},
  [1921] = {.lex_state = 42, .external_lex_state = 3},
  [1922] = {.lex_state = 42, .external_lex_state = 3},
  [1923] = {.lex_state = 42, .external_lex_state = 3},
  [1924] = {.lex_state = 42, .external_lex_state = 3},
  [1925] = {.lex_state = 42, .external_lex_state = 3},
  [1926] = {.lex_state = 42, .external_lex_state = 3},
  [1927] = {.lex_state = 42, .external_lex_state = 3},
  [1928] = {.lex_state = 42, .external_lex_state = 3},
  [1929] = {.lex_state = 42, .external_lex_state = 3},
  [1930] = {.lex_state = 42, .external_lex_state = 3},
  [1931] = {.lex_state = 42, .external_lex_state = 3},
  [1932] = {.lex_state = 42, .external_lex_state = 3},
  [1933] = {.lex_state = 42, .external_lex_state = 3},
  [1934] = {.lex_state = 42, .external_lex_state = 3},
  [1935] = {.lex_state = 42, .external_lex_state = 3},
  [1936] = {.lex_state = 42, .external_lex_state = 3},
  [1937] = {.lex_state = 42, .external_lex_state = 3},
  [1938] = {.lex_state = 42, .external_lex_state = 3},
  [1939] = {.lex_state = 42, .external_lex_state = 3},
  [1940] = {.lex_state = 42, .external_lex_state = 3},
  [1941] = {.lex_state = 42, .external_lex_state = 3},
  [1942] = {.lex_state = 42, .external_lex_state = 3},
  [1943] = {.lex_state = 42, .external_lex_state = 3},
  [1944] = {.lex_state = 42, .external_lex_state = 3},
  [1945] = {.lex_state = 42, .external_lex_state = 3},
  [1946] = {.lex_state = 42, .external_lex_state = 3},
  [1947] = {.lex_state = 42, .external_lex_state = 3},
  [1948] = {.lex_state = 42, .external_lex_state = 3},
  [1949] = {.lex_state = 42, .external_lex_state = 3},
  [1950] = {.lex_state = 42, .external_lex_state = 3},
  [1951] = {.lex_state = 42, .external_lex_state = 3},
  [1952] = {.lex_state = 42, .external_lex_state = 3},
  [1953] = {.lex_state = 42, .external_lex_state = 3},
  [1954] = {.lex_state = 42, .external_lex_state = 3},
  [1955] = {.lex_state = 42, .external_lex_state = 3},
  [1956] = {.lex_state = 42, .external_lex_state = 3},
  [1957] = {.lex_state = 42, .external_lex_state = 3},
  [1958] = {.lex_state = 42, .external_lex_state = 3},
  [1959] = {.lex_state = 42, .external_lex_state = 3},
  [1960] = {.lex_state = 42, .external_lex_state = 3},
  [1961] = {.lex_state = 42, .external_lex_state = 3},
  [1962] = {.lex_state = 42, .external_lex_state = 3},
  [1963] = {.lex_state = 42, .external_lex_state = 3},
  [1964] = {.lex_state = 42, .external_lex_state = 3},
  [1965] = {.lex_state = 42, .external_lex_state = 3},
  [1966] = {.lex_state = 42, .external_lex_state = 3},
  [1967] = {.lex_state = 42, .external_lex_state = 3},
  [1968] = {.lex_state = 42, .external_lex_state = 3},
  [1969] = {.lex_state = 42, .external_lex_state = 3},
  [1970] = {.lex_state = 42, .external_lex_state = 3},
  [1971] = {.lex_state = 42, .external_lex_state = 3},
  [1972] = {.lex_state = 42, .external_lex_state = 3},
  [1973] = {.lex_state = 42, .external_lex_state = 3},
  [1974] = {.lex_state = 42, .external_lex_state = 3},
  [1975] = {.lex_state = 42, .external_lex_state = 3},
  [1976] = {.lex_state = 42, .external_lex_state = 3},
  [1977] = {.lex_state = 42, .external_lex_state = 3},
  [1978] = {.lex_state = 42, .external_lex_state = 3},
  [1979] = {.lex_state = 42, .external_lex_state = 3},
  [1980] = {.lex_state = 42, .external_lex_state = 3},
  [1981] = {.lex_state = 42, .external_lex_state = 3},
  [1982] = {.lex_state = 42, .external_lex_state = 3},
  [1983] = {.lex_state = 42, .external_lex_state = 3},
  [1984] = {.lex_state = 42, .external_lex_state = 3},
  [1985] = {.lex_state = 42, .external_lex_state = 3},
  [1986] = {.lex_state = 42, .external_lex_state = 3},
  [1987] = {.lex_state = 42, .external_lex_state = 3},
  [1988] = {.lex_state = 42, .external_lex_state = 3},
  [1989] = {.lex_state = 42, .external_lex_state = 3},
  [1990] = {.lex_state = 42, .external_lex_state = 3},
  [1991] = {.lex_state = 42, .external_lex_state = 3},
  [1992] = {.lex_state = 42, .external_lex_state = 3},
  [1993] = {.lex_state = 42, .external_lex_state = 3},
  [1994] = {.lex_state = 42, .external_lex_state = 3},
  [1995] = {.lex_state = 42, .external_lex_state = 3},
  [1996] = {.lex_state = 42, .external_lex_state = 3},
  [1997] = {.lex_state = 42, .external_lex_state = 3},
  [1998] = {.lex_state = 42, .external_lex_state = 3},
  [1999] = {.lex_state = 42, .external_lex_state = 3},
  [2000] = {.lex_state = 42, .external_lex_state = 3},
  [2001] = {.lex_state = 42, .external_lex_state = 3},
  [2002] = {.lex_state = 42, .external_lex_state = 3},
  [2003] = {.lex_state = 42, .external_lex_state = 3},
  [2004] = {.lex_state = 42, .external_lex_state = 3},
  [2005] = {.lex_state = 42, .external_lex_state = 3},
  [2006] = {.lex_state = 42, .external_lex_state = 3},
  [2007] = {.lex_state = 42, .external_lex_state = 3},
  [2008] = {.lex_state = 42, .external_lex_state = 3},
  [2009] = {.lex_state = 42, .external_lex_state = 3},
  [2010] = {.lex_state = 42, .external_lex_state = 3},
  [2011] = {.lex_state = 42, .external_lex_state = 3},
  [2012] = {.lex_state = 42, .external_lex_state = 3},
  [2013] = {.lex_state = 42, .external_lex_state = 3},
  [2014] = {.lex_state = 42, .external_lex_state = 3},
  [2015] = {.lex_state = 42, .external_lex_state = 3},
  [2016] = {.lex_state = 42, .external_lex_state = 3},
  [2017] = {.lex_state = 42, .external_lex_state = 3},
  [2018] = {.lex_state = 42, .external_lex_state = 3},
  [2019] = {.lex_state = 42, .external_lex_state = 3},
  [2020] = {.lex_state = 42, .external_lex_state = 3},
  [2021] = {.lex_state = 42, .external_lex_state = 3},
  [2022] = {.lex_state = 42, .external_lex_state = 3},
  [2023] = {.lex_state = 42, .external_lex_state = 3},
  [2024] = {.lex_state = 42, .external_lex_state = 3},
  [2025] = {.lex_state = 42, .external_lex_state = 3},
  [2026] = {.lex_state = 42, .external_lex_state = 3},
  [2027] = {.lex_state = 42, .external_lex_state = 3},
  [2028] = {.lex_state = 42, .external_lex_state = 3},
  [2029] = {.lex_state = 42, .external_lex_state = 3},
  [2030] = {.lex_state = 42, .external_lex_state = 3},
  [2031] = {.lex_state = 42, .external_lex_state = 3},
  [2032] = {.lex_state = 42, .external_lex_state = 3},
  [2033] = {.lex_state = 42, .external_lex_state = 3},
  [2034] = {.lex_state = 42, .external_lex_state = 3},
  [2035] = {.lex_state = 42, .external_lex_state = 3},
  [2036] = {.lex_state = 42, .external_lex_state = 3},
  [2037] = {.lex_state = 42, .external_lex_state = 3},
  [2038] = {.lex_state = 42, .external_lex_state = 3},
  [2039] = {.lex_state = 42, .external_lex_state = 3},
  [2040] = {.lex_state = 42, .external_lex_state = 3},
  [2041] = {.lex_state = 42, .external_lex_state = 3},
  [2042] = {.lex_state = 42, .external_lex_state = 3},
  [2043] = {.lex_state = 42, .external_lex_state = 3},
  [2044] = {.lex_state = 42, .external_lex_state = 3},
  [2045] = {.lex_state = 42, .external_lex_state = 3},
  [2046] = {.lex_state = 42, .external_lex_state = 3},
  [2047] = {.lex_state = 42, .external_lex_state = 3},
  [2048] = {.lex_state = 42, .external_lex_state = 3},
  [2049] = {.lex_state = 42, .external_lex_state = 3},
  [2050] = {.lex_state = 42, .external_lex_state = 3},
  [2051] = {.lex_state = 42, .external_lex_state = 3},
  [2052] = {.lex_state = 42, .external_lex_state = 3},
  [2053] = {.lex_state = 42, .external_lex_state = 3},
  [2054] = {.lex_state = 42, .external_lex_state = 3},
  [2055] = {.lex_state = 42, .external_lex_state = 3},
  [2056] = {.lex_state = 42, .external_lex_state = 3},
  [2057] = {.lex_state = 42, .external_lex_state = 3},
  [2058] = {.lex_state = 42, .external_lex_state = 3},
  [2059] = {.lex_state = 42, .external_lex_state = 3},
  [2060] = {.lex_state = 42, .external_lex_state = 3},
  [2061] = {.lex_state = 42, .external_lex_state = 3},
  [2062] = {.lex_state = 42, .external_lex_state = 3},
  [2063] = {.lex_state = 42, .external_lex_state = 3},
  [2064] = {.lex_state = 42, .external_lex_state = 3},
  [2065] = {.lex_state = 42, .external_lex_state = 3},
  [2066] = {.lex_state = 42, .external_lex_state = 3},
  [2067] = {.lex_state = 42, .external_lex_state = 3},
  [2068] = {.lex_state = 42, .external_lex_state = 3},
  [2069] = {.lex_state = 42, .external_lex_state = 3},
  [2070] = {.lex_state = 42, .external_lex_state = 3},
  [2071] = {.lex_state = 42, .external_lex_state = 3},
  [2072] = {.lex_state = 42, .external_lex_state = 3},
  [2073] = {.lex_state = 42, .external_lex_state = 3},
  [2074] = {.lex_state = 42, .external_lex_state = 3},
  [2075] = {.lex_state = 42, .external_lex_state = 3},
  [2076] = {.lex_state = 42, .external_lex_state = 3},
  [2077] = {.lex_state = 42, .external_lex_state = 3},
  [2078] = {.lex_state = 42, .external_lex_state = 3},
  [2079] = {.lex_state = 42, .external_lex_state = 3},
  [2080] = {.lex_state = 42, .external_lex_state = 3},
  [2081] = {.lex_state = 42, .external_lex_state = 3},
  [2082] = {.lex_state = 42, .external_lex_state = 3},
  [2083] = {.lex_state = 42, .external_lex_state = 3},
  [2084] = {.lex_state = 42, .external_lex_state = 3},
  [2085] = {.lex_state = 42, .external_lex_state = 3},
  [2086] = {.lex_state = 42, .external_lex_state = 3},
  [2087] = {.lex_state = 42, .external_lex_state = 3},
  [2088] = {.lex_state = 42, .external_lex_state = 3},
  [2089] = {.lex_state = 42, .external_lex_state = 3},
  [2090] = {.lex_state = 42, .external_lex_state = 3},
  [2091] = {.lex_state = 42, .external_lex_state = 3},
  [2092] = {.lex_state = 42, .external_lex_state = 3},
  [2093] = {.lex_state = 42, .external_lex_state = 3},
  [2094] = {.lex_state = 42, .external_lex_state = 3},
  [2095] = {.lex_state = 42, .external_lex_state = 3},
  [2096] = {.lex_state = 42, .external_lex_state = 3},
  [2097] = {.lex_state = 42, .external_lex_state = 3},
  [2098] = {.lex_state = 42, .external_lex_state = 3},
  [2099] = {.lex_state = 42, .external_lex_state = 3},
  [2100] = {.lex_state = 42, .external_lex_state = 3},
  [2101] = {.lex_state = 42, .external_lex_state = 3},
  [2102] = {.lex_state = 42, .external_lex_state = 3},
  [2103] = {.lex_state = 42, .external_lex_state = 3},
  [2104] = {.lex_state = 42, .external_lex_state = 3},
  [2105] = {.lex_state = 42, .external_lex_state = 3},
  [2106] = {.lex_state = 42, .external_lex_state = 3},
  [2107] = {.lex_state = 42, .external_lex_state = 3},
  [2108] = {.lex_state = 42, .external_lex_state = 3},
  [2109] = {.lex_state = 42, .external_lex_state = 3},
  [2110] = {.lex_state = 42, .external_lex_state = 3},
  [2111] = {.lex_state = 42, .external_lex_state = 3},
  [2112] = {.lex_state = 42, .external_lex_state = 3},
  [2113] = {.lex_state = 42, .external_lex_state = 3},
  [2114] = {.lex_state = 42, .external_lex_state = 3},
  [2115] = {.lex_state = 42, .external_lex_state = 3},
  [2116] = {.lex_state = 42, .external_lex_state = 3},
  [2117] = {.lex_state = 42, .external_lex_state = 3},
  [2118] = {.lex_state = 42, .external_lex_state = 3},
  [2119] = {.lex_state = 42, .external_lex_state = 3},
  [2120] = {.lex_state = 42, .external_lex_state = 3},
  [2121] = {.lex_state = 42, .external_lex_state = 3},
  [2122] = {.lex_state = 42, .external_lex_state = 3},
  [2123] = {.lex_state = 42, .external_lex_state = 3},
  [2124] = {.lex_state = 42, .external_lex_state = 3},
  [2125] = {.lex_state = 42, .external_lex_state = 3},
  [2126] = {.lex_state = 42, .external_lex_state = 3},
  [2127] = {.lex_state = 42, .external_lex_state = 3},
  [2128] = {.lex_state = 42, .external_lex_state = 3},
  [2129] = {.lex_state = 42, .external_lex_state = 3},
  [2130] = {.lex_state = 42, .external_lex_state = 3},
  [2131] = {.lex_state = 42, .external_lex_state = 3},
  [2132] = {.lex_state = 42, .external_lex_state = 3},
  [2133] = {.lex_state = 42, .external_lex_state = 3},
  [2134] = {.lex_state = 42, .external_lex_state = 3},
  [2135] = {.lex_state = 42, .external_lex_state = 3},
  [2136] = {.lex_state = 42, .external_lex_state = 3},
  [2137] = {.lex_state = 42, .external_lex_state = 3},
  [2138] = {.lex_state = 42, .external_lex_state = 3},
  [2139] = {.lex_state = 42, .external_lex_state = 3},
  [2140] = {.lex_state = 42, .external_lex_state = 3},
  [2141] = {.lex_state = 42, .external_lex_state = 3},
  [2142] = {.lex_state = 42, .external_lex_state = 3},
  [2143] = {.lex_state = 42, .external_lex_state = 3},
  [2144] = {.lex_state = 42, .external_lex_state = 3},
  [2145] = {.lex_state = 42, .external_lex_state = 3},
  [2146] = {.lex_state = 42, .external_lex_state = 3},
  [2147] = {.lex_state = 42, .external_lex_state = 3},
  [2148] = {.lex_state = 42, .external_lex_state = 3},
  [2149] = {.lex_state = 42, .external_lex_state = 3},
  [2150] = {.lex_state = 42, .external_lex_state = 3},
  [2151] = {.lex_state = 42, .external_lex_state = 3},
  [2152] = {.lex_state = 42, .external_lex_state = 3},
  [2153] = {.lex_state = 42, .external_lex_state = 3},
  [2154] = {.lex_state = 42, .external_lex_state = 3},
  [2155] = {.lex_state = 42, .external_lex_state = 3},
  [2156] = {.lex_state = 42, .external_lex_state = 3},
  [2157] = {.lex_state = 42, .external_lex_state = 3},
  [2158] = {.lex_state = 42, .external_lex_state = 3},
  [2159] = {.lex_state = 42, .external_lex_state = 3},
  [2160] = {.lex_state = 42, .external_lex_state = 3},
  [2161] = {.lex_state = 42, .external_lex_state = 3},
  [2162] = {.lex_state = 42, .external_lex_state = 3},
  [2163] = {.lex_state = 42, .external_lex_state = 3},
  [2164] = {.lex_state = 42, .external_lex_state = 3},
  [2165] = {.lex_state = 42, .external_lex_state = 3},
  [2166] = {.lex_state = 42, .external_lex_state = 3},
  [2167] = {.lex_state = 42, .external_lex_state = 3},
  [2168] = {.lex_state = 42, .external_lex_state = 3},
  [2169] = {.lex_state = 42, .external_lex_state = 3},
  [2170] = {.lex_state = 42, .external_lex_state = 3},
  [2171] = {.lex_state = 42, .external_lex_state = 3},
  [2172] = {.lex_state = 42, .external_lex_state = 3},
  [2173] = {.lex_state = 42, .external_lex_state = 3},
  [2174] = {.lex_state = 42, .external_lex_state = 3},
  [2175] = {.lex_state = 42, .external_lex_state = 3},
  [2176] = {.lex_state = 42, .external_lex_state = 3},
  [2177] = {.lex_state = 42, .external_lex_state = 3},
  [2178] = {.lex_state = 42, .external_lex_state = 3},
  [2179] = {.lex_state = 42, .external_lex_state = 3},
  [2180] = {.lex_state = 42, .external_lex_state = 3},
  [2181] = {.lex_state = 42, .external_lex_state = 3},
  [2182] = {.lex_state = 42, .external_lex_state = 3},
  [2183] = {.lex_state = 42, .external_lex_state = 3},
  [2184] = {.lex_state = 42, .external_lex_state = 3},
  [2185] = {.lex_state = 42, .external_lex_state = 3},
  [2186] = {.lex_state = 42, .external_lex_state = 3},
  [2187] = {.lex_state = 42, .external_lex_state = 3},
  [2188] = {.lex_state = 42, .external_lex_state = 3},
  [2189] = {.lex_state = 42, .external_lex_state = 3},
  [2190] = {.lex_state = 42, .external_lex_state = 3},
  [2191] = {.lex_state = 42, .external_lex_state = 3},
  [2192] = {.lex_state = 42, .external_lex_state = 3},
  [2193] = {.lex_state = 42, .external_lex_state = 3},
  [2194] = {.lex_state = 42, .external_lex_state = 3},
  [2195] = {.lex_state = 42, .external_lex_state = 3},
  [2196] = {.lex_state = 42, .external_lex_state = 3},
  [2197] = {.lex_state = 42, .external_lex_state = 3},
  [2198] = {.lex_state = 42, .external_lex_state = 3},
  [2199] = {.lex_state = 42, .external_lex_state = 3},
  [2200] = {.lex_state = 42, .external_lex_state = 3},
  [2201] = {.lex_state = 42, .external_lex_state = 3},
  [2202] = {.lex_state = 42, .external_lex_state = 3},
  [2203] = {.lex_state = 42, .external_lex_state = 3},
  [2204] = {.lex_state = 42, .external_lex_state = 3},
  [2205] = {.lex_state = 42, .external_lex_state = 3},
  [2206] = {.lex_state = 42, .external_lex_state = 3},
  [2207] = {.lex_state = 42, .external_lex_state = 3},
  [2208] = {.lex_state = 42, .external_lex_state = 3},
  [2209] = {.lex_state = 42, .external_lex_state = 3},
  [2210] = {.lex_state = 42, .external_lex_state = 3},
  [2211] = {.lex_state = 42, .external_lex_state = 3},
  [2212] = {.lex_state = 42, .external_lex_state = 3},
  [2213] = {.lex_state = 42, .external_lex_state = 3},
  [2214] = {.lex_state = 42, .external_lex_state = 3},
  [2215] = {.lex_state = 42, .external_lex_state = 3},
  [2216] = {.lex_state = 42, .external_lex_state = 3},
  [2217] = {.lex_state = 42, .external_lex_state = 3},
  [2218] = {.lex_state = 42, .external_lex_state = 3},
  [2219] = {.lex_state = 42, .external_lex_state = 3},
  [2220] = {.lex_state = 42, .external_lex_state = 3},
  [2221] = {.lex_state = 42, .external_lex_state = 3},
  [2222] = {.lex_state = 42, .external_lex_state = 3},
  [2223] = {.lex_state = 42, .external_lex_state = 3},
  [2224] = {.lex_state = 42, .external_lex_state = 3},
  [2225] = {.lex_state = 42, .external_lex_state = 3},
  [2226] = {.lex_state = 42, .external_lex_state = 3},
  [2227] = {.lex_state = 42, .external_lex_state = 3},
  [2228] = {.lex_state = 42, .external_lex_state = 3},
  [2229] = {.lex_state = 42, .external_lex_state = 3},
  [2230] = {.lex_state = 42, .external_lex_state = 3},
  [2231] = {.lex_state = 42, .external_lex_state = 3},
  [2232] = {.lex_state = 42, .external_lex_state = 3},
  [2233] = {.lex_state = 42, .external_lex_state = 3},
  [2234] = {.lex_state = 42, .external_lex_state = 3},
  [2235] = {.lex_state = 42, .external_lex_state = 3},
  [2236] = {.lex_state = 42, .external_lex_state = 3},
  [2237] = {.lex_state = 42, .external_lex_state = 3},
  [2238] = {.lex_state = 42, .external_lex_state = 3},
  [2239] = {.lex_state = 42, .external_lex_state = 3},
  [2240] = {.lex_state = 42, .external_lex_state = 3},
  [2241] = {.lex_state = 42, .external_lex_state = 3},
  [2242] = {.lex_state = 42, .external_lex_state = 3},
  [2243] = {.lex_state = 42, .external_lex_state = 3},
  [2244] = {.lex_state = 42, .external_lex_state = 3},
  [2245] = {.lex_state = 42, .external_lex_state = 3},
  [2246] = {.lex_state = 42, .external_lex_state = 3},
  [2247] = {.lex_state = 42, .external_lex_state = 3},
  [2248] = {.lex_state = 42, .external_lex_state = 3},
  [2249] = {.lex_state = 42, .external_lex_state = 3},
  [2250] = {.lex_state = 42, .external_lex_state = 3},
  [2251] = {.lex_state = 42, .external_lex_state = 3},
  [2252] = {.lex_state = 42, .external_lex_state = 3},
  [2253] = {.lex_state = 42, .external_lex_state = 3},
  [2254] = {.lex_state = 42, .external_lex_state = 3},
  [2255] = {.lex_state = 42, .external_lex_state = 3},
  [2256] = {.lex_state = 42, .external_lex_state = 3},
  [2257] = {.lex_state = 42, .external_lex_state = 3},
  [2258] = {.lex_state = 42, .external_lex_state = 3},
  [2259] = {.lex_state = 42, .external_lex_state = 3},
  [2260] = {.lex_state = 42, .external_lex_state = 3},
  [2261] = {.lex_state = 42, .external_lex_state = 3},
  [2262] = {.lex_state = 42, .external_lex_state = 3},
  [2263] = {.lex_state = 42, .external_lex_state = 3},
  [2264] = {.lex_state = 42, .external_lex_state = 3},
  [2265] = {.lex_state = 42, .external_lex_state = 3},
  [2266] = {.lex_state = 42, .external_lex_state = 3},
  [2267] = {.lex_state = 42, .external_lex_state = 3},
  [2268] = {.lex_state = 42, .external_lex_state = 3},
  [2269] = {.lex_state = 42, .external_lex_state = 3},
  [2270] = {.lex_state = 42, .external_lex_state = 3},
  [2271] = {.lex_state = 42, .external_lex_state = 3},
  [2272] = {.lex_state = 42, .external_lex_state = 3},
  [2273] = {.lex_state = 42, .external_lex_state = 3},
  [2274] = {.lex_state = 42, .external_lex_state = 3},
  [2275] = {.lex_state = 42, .external_lex_state = 3},
  [2276] = {.lex_state = 42, .external_lex_state = 3},
  [2277] = {.lex_state = 42, .external_lex_state = 3},
  [2278] = {.lex_state = 42, .external_lex_state = 3},
  [2279] = {.lex_state = 42, .external_lex_state = 3},
  [2280] = {.lex_state = 42, .external_lex_state = 3},
  [2281] = {.lex_state = 42, .external_lex_state = 3},
  [2282] = {.lex_state = 42, .external_lex_state = 3},
  [2283] = {.lex_state = 42, .external_lex_state = 3},
  [2284] = {.lex_state = 42, .external_lex_state = 3},
  [2285] = {.lex_state = 42, .external_lex_state = 3},
  [2286] = {.lex_state = 42, .external_lex_state = 3},
  [2287] = {.lex_state = 42, .external_lex_state = 3},
  [2288] = {.lex_state = 42, .external_lex_state = 3},
  [2289] = {.lex_state = 42, .external_lex_state = 3},
  [2290] = {.lex_state = 42, .external_lex_state = 3},
  [2291] = {.lex_state = 42, .external_lex_state = 3},
  [2292] = {.lex_state = 42, .external_lex_state = 3},
  [2293] = {.lex_state = 42, .external_lex_state = 3},
  [2294] = {.lex_state = 42, .external_lex_state = 3},
  [2295] = {.lex_state = 42, .external_lex_state = 3},
  [2296] = {.lex_state = 42, .external_lex_state = 3},
  [2297] = {.lex_state = 42, .external_lex_state = 3},
  [2298] = {.lex_state = 42, .external_lex_state = 3},
  [2299] = {.lex_state = 42, .external_lex_state = 3},
  [2300] = {.lex_state = 42, .external_lex_state = 3},
  [2301] = {.lex_state = 42, .external_lex_state = 3},
  [2302] = {.lex_state = 42, .external_lex_state = 3},
  [2303] = {.lex_state = 42, .external_lex_state = 3},
  [2304] = {.lex_state = 42, .external_lex_state = 3},
  [2305] = {.lex_state = 42, .external_lex_state = 3},
  [2306] = {.lex_state = 42, .external_lex_state = 3},
  [2307] = {.lex_state = 42, .external_lex_state = 3},
  [2308] = {.lex_state = 42, .external_lex_state = 3},
  [2309] = {.lex_state = 42, .external_lex_state = 3},
  [2310] = {.lex_state = 42, .external_lex_state = 3},
  [2311] = {.lex_state = 42, .external_lex_state = 3},
  [2312] = {.lex_state = 42, .external_lex_state = 3},
  [2313] = {.lex_state = 42, .external_lex_state = 3},
  [2314] = {.lex_state = 42, .external_lex_state = 3},
  [2315] = {.lex_state = 42, .external_lex_state = 3},
  [2316] = {.lex_state = 42, .external_lex_state = 3},
  [2317] = {.lex_state = 42, .external_lex_state = 3},
  [2318] = {.lex_state = 42, .external_lex_state = 3},
  [2319] = {.lex_state = 42, .external_lex_state = 3},
  [2320] = {.lex_state = 42, .external_lex_state = 3},
  [2321] = {.lex_state = 42, .external_lex_state = 3},
  [2322] = {.lex_state = 42, .external_lex_state = 3},
  [2323] = {.lex_state = 42, .external_lex_state = 3},
  [2324] = {.lex_state = 42, .external_lex_state = 3},
  [2325] = {.lex_state = 42, .external_lex_state = 3},
  [2326] = {.lex_state = 42, .external_lex_state = 3},
  [2327] = {.lex_state = 42, .external_lex_state = 3},
  [2328] = {.lex_state = 42, .external_lex_state = 3},
  [2329] = {.lex_state = 42, .external_lex_state = 3},
  [2330] = {.lex_state = 42, .external_lex_state = 3},
  [2331] = {.lex_state = 42, .external_lex_state = 3},
  [2332] = {.lex_state = 42, .external_lex_state = 3},
  [2333] = {.lex_state = 42, .external_lex_state = 3},
  [2334] = {.lex_state = 42, .external_lex_state = 3},
  [2335] = {.lex_state = 42, .external_lex_state = 3},
  [2336] = {.lex_state = 42, .external_lex_state = 3},
  [2337] = {.lex_state = 42, .external_lex_state = 3},
  [2338] = {.lex_state = 42, .external_lex_state = 3},
  [2339] = {.lex_state = 42, .external_lex_state = 3},
  [2340] = {.lex_state = 42, .external_lex_state = 3},
  [2341] = {.lex_state = 42, .external_lex_state = 3},
  [2342] = {.lex_state = 42, .external_lex_state = 3},
  [2343] = {.lex_state = 42, .external_lex_state = 3},
  [2344] = {.lex_state = 42, .external_lex_state = 3},
  [2345] = {.lex_state = 42, .external_lex_state = 3},
  [2346] = {.lex_state = 42, .external_lex_state = 3},
  [2347] = {.lex_state = 42, .external_lex_state = 3},
  [2348] = {.lex_state = 42, .external_lex_state = 3},
  [2349] = {.lex_state = 42, .external_lex_state = 3},
  [2350] = {.lex_state = 42, .external_lex_state = 3},
  [2351] = {.lex_state = 42, .external_lex_state = 3},
  [2352] = {.lex_state = 42, .external_lex_state = 3},
  [2353] = {.lex_state = 42, .external_lex_state = 3},
  [2354] = {.lex_state = 42, .external_lex_state = 3},
  [2355] = {.lex_state = 42, .external_lex_state = 3},
  [2356] = {.lex_state = 42, .external_lex_state = 3},
  [2357] = {.lex_state = 42, .external_lex_state = 3},
  [2358] = {.lex_state = 42, .external_lex_state = 3},
  [2359] = {.lex_state = 42, .external_lex_state = 3},
  [2360] = {.lex_state = 42, .external_lex_state = 3},
  [2361] = {.lex_state = 42, .external_lex_state = 3},
  [2362] = {.lex_state = 42, .external_lex_state = 3},
  [2363] = {.lex_state = 42, .external_lex_state = 3},
  [2364] = {.lex_state = 42, .external_lex_state = 3},
  [2365] = {.lex_state = 42, .external_lex_state = 3},
  [2366] = {.lex_state = 42, .external_lex_state = 3},
  [2367] = {.lex_state = 42, .external_lex_state = 3},
  [2368] = {.lex_state = 42, .external_lex_state = 3},
  [2369] = {.lex_state = 42, .external_lex_state = 3},
  [2370] = {.lex_state = 42, .external_lex_state = 3},
  [2371] = {.lex_state = 42, .external_lex_state = 3},
  [2372] = {.lex_state = 42, .external_lex_state = 3},
  [2373] = {.lex_state = 42, .external_lex_state = 3},
  [2374] = {.lex_state = 42, .external_lex_state = 3},
  [2375] = {.lex_state = 42, .external_lex_state = 3},
  [2376] = {.lex_state = 42, .external_lex_state = 3},
  [2377] = {.lex_state = 42, .external_lex_state = 3},
  [2378] = {.lex_state = 42, .external_lex_state = 3},
  [2379] = {.lex_state = 42, .external_lex_state = 3},
  [2380] = {.lex_state = 42, .external_lex_state = 3},
  [2381] = {.lex_state = 42, .external_lex_state = 3},
  [2382] = {.lex_state = 42, .external_lex_state = 3},
  [2383] = {.lex_state = 42, .external_lex_state = 3},
  [2384] = {.lex_state = 42, .external_lex_state = 3},
  [2385] = {.lex_state = 42, .external_lex_state = 3},
  [2386] = {.lex_state = 42, .external_lex_state = 3},
  [2387] = {.lex_state = 42, .external_lex_state = 3},
  [2388] = {.lex_state = 42, .external_lex_state = 3},
  [2389] = {.lex_state = 42, .external_lex_state = 3},
  [2390] = {.lex_state = 42, .external_lex_state = 3},
  [2391] = {.lex_state = 42, .external_lex_state = 3},
  [2392] = {.lex_state = 42, .external_lex_state = 3},
  [2393] = {.lex_state = 42, .external_lex_state = 3},
  [2394] = {.lex_state = 42, .external_lex_state = 3},
  [2395] = {.lex_state = 42, .external_lex_state = 3},
  [2396] = {.lex_state = 42, .external_lex_state = 3},
  [2397] = {.lex_state = 42, .external_lex_state = 3},
  [2398] = {.lex_state = 42, .external_lex_state = 3},
  [2399] = {.lex_state = 42, .external_lex_state = 3},
  [2400] = {.lex_state = 42, .external_lex_state = 3},
  [2401] = {.lex_state = 42, .external_lex_state = 3},
  [2402] = {.lex_state = 42, .external_lex_state = 3},
  [2403] = {.lex_state = 42, .external_lex_state = 3},
  [2404] = {.lex_state = 42, .external_lex_state = 3},
  [2405] = {.lex_state = 42, .external_lex_state = 3},
  [2406] = {.lex_state = 42, .external_lex_state = 3},
  [2407] = {.lex_state = 42, .external_lex_state = 3},
  [2408] = {.lex_state = 42, .external_lex_state = 3},
  [2409] = {.lex_state = 42, .external_lex_state = 3},
  [2410] = {.lex_state = 42, .external_lex_state = 3},
  [2411] = {.lex_state = 42, .external_lex_state = 3},
  [2412] = {.lex_state = 42, .external_lex_state = 3},
  [2413] = {.lex_state = 42, .external_lex_state = 3},
  [2414] = {.lex_state = 42, .external_lex_state = 3},
  [2415] = {.lex_state = 42, .external_lex_state = 3},
  [2416] = {.lex_state = 42, .external_lex_state = 3},
  [2417] = {.lex_state = 42, .external_lex_state = 3},
  [2418] = {.lex_state = 42, .external_lex_state = 3},
  [2419] = {.lex_state = 42, .external_lex_state = 3},
  [2420] = {.lex_state = 42, .external_lex_state = 3},
  [2421] = {.lex_state = 42, .external_lex_state = 3},
  [2422] = {.lex_state = 42, .external_lex_state = 3},
  [2423] = {.lex_state = 42, .external_lex_state = 3},
  [2424] = {.lex_state = 42, .external_lex_state = 3},
  [2425] = {.lex_state = 42, .external_lex_state = 3},
  [2426] = {.lex_state = 42, .external_lex_state = 3},
  [2427] = {.lex_state = 42, .external_lex_state = 3},
  [2428] = {.lex_state = 42, .external_lex_state = 3},
  [2429] = {.lex_state = 42, .external_lex_state = 3},
  [2430] = {.lex_state = 42, .external_lex_state = 3},
  [2431] = {.lex_state = 42, .external_lex_state = 3},
  [2432] = {.lex_state = 42, .external_lex_state = 3},
  [2433] = {.lex_state = 42, .external_lex_state = 3},
  [2434] = {.lex_state = 42, .external_lex_state = 3},
  [2435] = {.lex_state = 42, .external_lex_state = 3},
  [2436] = {.lex_state = 42, .external_lex_state = 3},
  [2437] = {.lex_state = 42, .external_lex_state = 3},
  [2438] = {.lex_state = 42, .external_lex_state = 3},
  [2439] = {.lex_state = 42, .external_lex_state = 3},
  [2440] = {.lex_state = 42, .external_lex_state = 3},
  [2441] = {.lex_state = 42, .external_lex_state = 3},
  [2442] = {.lex_state = 126, .external_lex_state = 3},
  [2443] = {.lex_state = 122, .external_lex_state = 3},
  [2444] = {.lex_state = 85, .external_lex_state = 3},
  [2445] = {.lex_state = 80, .external_lex_state = 3},
  [2446] = {.lex_state = 126, .external_lex_state = 3},
  [2447] = {.lex_state = 122, .external_lex_state = 3},
  [2448] = {.lex_state = 79, .external_lex_state = 3},
  [2449] = {.lex_state = 123, .external_lex_state = 3},
  [2450] = {.lex_state = 127, .external_lex_state = 3},
  [2451] = {.lex_state = 120, .external_lex_state = 3},
  [2452] = {.lex_state = 123, .external_lex_state = 3},
  [2453] = {.lex_state = 120, .external_lex_state = 3},
  [2454] = {.lex_state = 128, .external_lex_state = 3},
  [2455] = {.lex_state = 86, .external_lex_state = 3},
  [2456] = {.lex_state = 128, .external_lex_state = 3},
  [2457] = {.lex_state = 127, .external_lex_state = 3},
  [2458] = {.lex_state = 121, .external_lex_state = 3},
  [2459] = {.lex_state = 129, .external_lex_state = 3},
  [2460] = {.lex_state = 129, .external_lex_state = 3},
  [2461] = {.lex_state = 121, .external_lex_state = 3},
  [2462] = {.lex_state = 125, .external_lex_state = 3},
  [2463] = {.lex_state = 130, .external_lex_state = 3},
  [2464] = {.lex_state = 130, .external_lex_state = 3},
  [2465] = {.lex_state = 125, .external_lex_state = 3},
  [2466] = {.lex_state = 131, .external_lex_state = 3},
  [2467] = {.lex_state = 124, .external_lex_state = 3},
  [2468] = {.lex_state = 124, .external_lex_state = 3},
  [2469] = {.lex_state = 131, .external_lex_state = 3},
  [2470] = {.lex_state = 59, .external_lex_state = 3},
  [2471] = {.lex_state = 60, .external_lex_state = 3},
  [2472] = {.lex_state = 56, .external_lex_state = 3},
  [2473] = {.lex_state = 59, .external_lex_state = 3},
  [2474] = {.lex_state = 59, .external_lex_state = 3},
  [2475] = {.lex_state = 58, .external_lex_state = 3},
  [2476] = {.lex_state = 55, .external_lex_state = 3},
  [2477] = {.lex_state = 187, .external_lex_state = 3},
  [2478] = {.lex_state = 57, .external_lex_state = 3},
  [2479] = {.lex_state = 60, .external_lex_state = 3},
  [2480] = {.lex_state = 185, .external_lex_state = 3},
  [2481] = {.lex_state = 60, .external_lex_state = 3},
  [2482] = {.lex_state = 187, .external_lex_state = 3},
  [2483] = {.lex_state = 103, .external_lex_state = 3},
  [2484] = {.lex_state = 103, .external_lex_state = 3},
  [2485] = {.lex_state = 103, .external_lex_state = 3},
  [2486] = {.lex_state = 103, .external_lex_state = 3},
  [2487] = {.lex_state = 56, .external_lex_state = 3},
  [2488] = {.lex_state = 103, .external_lex_state = 3},
  [2489] = {.lex_state = 185, .external_lex_state = 3},
  [2490] = {.lex_state = 56, .external_lex_state = 3},
  [2491] = {.lex_state = 188, .external_lex_state = 3},
  [2492] = {.lex_state = 103, .external_lex_state = 3},
  [2493] = {.lex_state = 103, .external_lex_state = 3},
  [2494] = {.lex_state = 186, .external_lex_state = 3},
  [2495] = {.lex_state = 103, .external_lex_state = 3},
  [2496] = {.lex_state = 186, .external_lex_state = 3},
  [2497] = {.lex_state = 55, .external_lex_state = 3},
  [2498] = {.lex_state = 58, .external_lex_state = 3},
  [2499] = {.lex_state = 73, .external_lex_state = 3},
  [2500] = {.lex_state = 188, .external_lex_state = 3},
  [2501] = {.lex_state = 55, .external_lex_state = 3},
  [2502] = {.lex_state = 58, .external_lex_state = 3},
  [2503] = {.lex_state = 57, .external_lex_state = 3},
  [2504] = {.lex_state = 104, .external_lex_state = 3},
  [2505] = {.lex_state = 104, .external_lex_state = 3},
  [2506] = {.lex_state = 104, .external_lex_state = 3},
  [2507] = {.lex_state = 57, .external_lex_state = 3},
  [2508] = {.lex_state = 104, .external_lex_state = 3},
  [2509] = {.lex_state = 104, .external_lex_state = 3},
  [2510] = {.lex_state = 104, .external_lex_state = 3},
  [2511] = {.lex_state = 104, .external_lex_state = 3},
  [2512] = {.lex_state = 104, .external_lex_state = 3},
  [2513] = {.lex_state = 104, .external_lex_state = 3},
  [2514] = {.lex_state = 104, .external_lex_state = 3},
  [2515] = {.lex_state = 104, .external_lex_state = 3},
  [2516] = {.lex_state = 74, .external_lex_state = 3},
  [2517] = {.lex_state = 63, .external_lex_state = 3},
  [2518] = {.lex_state = 64, .external_lex_state = 3},
  [2519] = {.lex_state = 73, .external_lex_state = 3},
  [2520] = {.lex_state = 67, .external_lex_state = 3},
  [2521] = {.lex_state = 68, .external_lex_state = 3},
  [2522] = {.lex_state = 61, .external_lex_state = 3},
  [2523] = {.lex_state = 65, .external_lex_state = 3},
  [2524] = {.lex_state = 69, .external_lex_state = 3},
  [2525] = {.lex_state = 73, .external_lex_state = 3},
  [2526] = {.lex_state = 185, .external_lex_state = 3},
  [2527] = {.lex_state = 105, .external_lex_state = 3},
  [2528] = {.lex_state = 66, .external_lex_state = 3},
  [2529] = {.lex_state = 74, .external_lex_state = 3},
  [2530] = {.lex_state = 105, .external_lex_state = 3},
  [2531] = {.lex_state = 70, .external_lex_state = 3},
  [2532] = {.lex_state = 105, .external_lex_state = 3},
  [2533] = {.lex_state = 71, .external_lex_state = 3},
  [2534] = {.lex_state = 105, .external_lex_state = 3},
  [2535] = {.lex_state = 72, .external_lex_state = 3},
  [2536] = {.lex_state = 105, .external_lex_state = 3},
  [2537] = {.lex_state = 74, .external_lex_state = 3},
  [2538] = {.lex_state = 187, .external_lex_state = 3},
  [2539] = {.lex_state = 105, .external_lex_state = 3},
  [2540] = {.lex_state = 105, .external_lex_state = 3},
  [2541] = {.lex_state = 62, .external_lex_state = 3},
  [2542] = {.lex_state = 38, .external_lex_state = 3},
  [2543] = {.lex_state = 38, .external_lex_state = 3},
  [2544] = {.lex_state = 186, .external_lex_state = 3},
  [2545] = {.lex_state = 63, .external_lex_state = 3},
  [2546] = {.lex_state = 40, .external_lex_state = 3},
  [2547] = {.lex_state = 40, .external_lex_state = 3},
  [2548] = {.lex_state = 188, .external_lex_state = 3},
  [2549] = {.lex_state = 40, .external_lex_state = 3},
  [2550] = {.lex_state = 38, .external_lex_state = 3},
  [2551] = {.lex_state = 63, .external_lex_state = 3},
  [2552] = {.lex_state = 106, .external_lex_state = 3},
  [2553] = {.lex_state = 438, .external_lex_state = 3},
  [2554] = {.lex_state = 68, .external_lex_state = 3},
  [2555] = {.lex_state = 61, .external_lex_state = 3},
  [2556] = {.lex_state = 65, .external_lex_state = 3},
  [2557] = {.lex_state = 106, .external_lex_state = 3},
  [2558] = {.lex_state = 106, .external_lex_state = 3},
  [2559] = {.lex_state = 69, .external_lex_state = 3},
  [2560] = {.lex_state = 106, .external_lex_state = 3},
  [2561] = {.lex_state = 106, .external_lex_state = 3},
  [2562] = {.lex_state = 438, .external_lex_state = 3},
  [2563] = {.lex_state = 64, .external_lex_state = 3},
  [2564] = {.lex_state = 106, .external_lex_state = 3},
  [2565] = {.lex_state = 106, .external_lex_state = 3},
  [2566] = {.lex_state = 67, .external_lex_state = 3},
  [2567] = {.lex_state = 438, .external_lex_state = 3},
  [2568] = {.lex_state = 106, .external_lex_state = 3},
  [2569] = {.lex_state = 67, .external_lex_state = 3},
  [2570] = {.lex_state = 65, .external_lex_state = 3},
  [2571] = {.lex_state = 64, .external_lex_state = 3},
  [2572] = {.lex_state = 106, .external_lex_state = 3},
  [2573] = {.lex_state = 69, .external_lex_state = 3},
  [2574] = {.lex_state = 68, .external_lex_state = 3},
  [2575] = {.lex_state = 106, .external_lex_state = 3},
  [2576] = {.lex_state = 61, .external_lex_state = 3},
  [2577] = {.lex_state = 26, .external_lex_state = 3},
  [2578] = {.lex_state = 71, .external_lex_state = 3},
  [2579] = {.lex_state = 62, .external_lex_state = 3},
  [2580] = {.lex_state = 70, .external_lex_state = 3},
  [2581] = {.lex_state = 62, .external_lex_state = 3},
  [2582] = {.lex_state = 66, .external_lex_state = 3},
  [2583] = {.lex_state = 26, .external_lex_state = 3},
  [2584] = {.lex_state = 72, .external_lex_state = 3},
  [2585] = {.lex_state = 70, .external_lex_state = 3},
  [2586] = {.lex_state = 71, .external_lex_state = 3},
  [2587] = {.lex_state = 26, .external_lex_state = 3},
  [2588] = {.lex_state = 66, .external_lex_state = 3},
  [2589] = {.lex_state = 72, .external_lex_state = 3},
  [2590] = {.lex_state = 175, .external_lex_state = 3},
  [2591] = {.lex_state = 27, .external_lex_state = 3},
  [2592] = {.lex_state = 180, .external_lex_state = 3},
  [2593] = {.lex_state = 181, .external_lex_state = 3},
  [2594] = {.lex_state = 180, .external_lex_state = 3},
  [2595] = {.lex_state = 181, .external_lex_state = 3},
  [2596] = {.lex_state = 180, .external_lex_state = 3},
  [2597] = {.lex_state = 27, .external_lex_state = 3},
  [2598] = {.lex_state = 181, .external_lex_state = 3},
  [2599] = {.lex_state = 181, .external_lex_state = 3},
  [2600] = {.lex_state = 27, .external_lex_state = 3},
  [2601] = {.lex_state = 181, .external_lex_state = 3},
  [2602] = {.lex_state = 181, .external_lex_state = 3},
  [2603] = {.lex_state = 180, .external_lex_state = 3},
  [2604] = {.lex_state = 180, .external_lex_state = 3},
  [2605] = {.lex_state = 181, .external_lex_state = 3},
  [2606] = {.lex_state = 180, .external_lex_state = 3},
  [2607] = {.lex_state = 180, .external_lex_state = 3},
  [2608] = {.lex_state = 180, .external_lex_state = 3},
  [2609] = {.lex_state = 181, .external_lex_state = 3},
  [2610] = {.lex_state = 180, .external_lex_state = 3},
  [2611] = {.lex_state = 181, .external_lex_state = 3},
  [2612] = {.lex_state = 180, .external_lex_state = 3},
  [2613] = {.lex_state = 181, .external_lex_state = 3},
  [2614] = {.lex_state = 175, .external_lex_state = 3},
  [2615] = {.lex_state = 440, .external_lex_state = 3},
  [2616] = {.lex_state = 440, .external_lex_state = 3},
  [2617] = {.lex_state = 440, .external_lex_state = 3},
  [2618] = {.lex_state = 440, .external_lex_state = 3},
  [2619] = {.lex_state = 440, .external_lex_state = 3},
  [2620] = {.lex_state = 440, .external_lex_state = 3},
  [2621] = {.lex_state = 440, .external_lex_state = 3},
  [2622] = {.lex_state = 440, .external_lex_state = 3},
  [2623] = {.lex_state = 440, .external_lex_state = 3},
  [2624] = {.lex_state = 440, .external_lex_state = 3},
  [2625] = {.lex_state = 189, .external_lex_state = 3},
  [2626] = {.lex_state = 182, .external_lex_state = 3},
  [2627] = {.lex_state = 182, .external_lex_state = 3},
  [2628] = {.lex_state = 182, .external_lex_state = 3},
  [2629] = {.lex_state = 182, .external_lex_state = 3},
  [2630] = {.lex_state = 175, .external_lex_state = 3},
  [2631] = {.lex_state = 182, .external_lex_state = 3},
  [2632] = {.lex_state = 182, .external_lex_state = 3},
  [2633] = {.lex_state = 182, .external_lex_state = 3},
  [2634] = {.lex_state = 182, .external_lex_state = 3},
  [2635] = {.lex_state = 182, .external_lex_state = 3},
  [2636] = {.lex_state = 182, .external_lex_state = 3},
  [2637] = {.lex_state = 181, .external_lex_state = 3},
  [2638] = {.lex_state = 189, .external_lex_state = 3},
  [2639] = {.lex_state = 175, .external_lex_state = 3},
  [2640] = {.lex_state = 190, .external_lex_state = 3},
  [2641] = {.lex_state = 180, .external_lex_state = 3},
  [2642] = {.lex_state = 190, .external_lex_state = 3},
  [2643] = {.lex_state = 440, .external_lex_state = 3},
  [2644] = {.lex_state = 176, .external_lex_state = 3},
  [2645] = {.lex_state = 176, .external_lex_state = 3},
  [2646] = {.lex_state = 175, .external_lex_state = 3},
  [2647] = {.lex_state = 176, .external_lex_state = 3},
  [2648] = {.lex_state = 175, .external_lex_state = 3},
  [2649] = {.lex_state = 175, .external_lex_state = 3},
  [2650] = {.lex_state = 175, .external_lex_state = 3},
  [2651] = {.lex_state = 175, .external_lex_state = 3},
  [2652] = {.lex_state = 176, .external_lex_state = 3},
  [2653] = {.lex_state = 175, .external_lex_state = 3},
  [2654] = {.lex_state = 175, .external_lex_state = 3},
  [2655] = {.lex_state = 175, .external_lex_state = 3},
  [2656] = {.lex_state = 176, .external_lex_state = 3},
  [2657] = {.lex_state = 175, .external_lex_state = 3},
  [2658] = {.lex_state = 175, .external_lex_state = 3},
  [2659] = {.lex_state = 176, .external_lex_state = 3},
  [2660] = {.lex_state = 175, .external_lex_state = 3},
  [2661] = {.lex_state = 175, .external_lex_state = 3},
  [2662] = {.lex_state = 176, .external_lex_state = 3},
  [2663] = {.lex_state = 175, .external_lex_state = 3},
  [2664] = {.lex_state = 175, .external_lex_state = 3},
  [2665] = {.lex_state = 175, .external_lex_state = 3},
  [2666] = {.lex_state = 176, .external_lex_state = 3},
  [2667] = {.lex_state = 175, .external_lex_state = 3},
  [2668] = {.lex_state = 175, .external_lex_state = 3},
  [2669] = {.lex_state = 176, .external_lex_state = 3},
  [2670] = {.lex_state = 175, .external_lex_state = 3},
  [2671] = {.lex_state = 175, .external_lex_state = 3},
  [2672] = {.lex_state = 176, .external_lex_state = 3},
  [2673] = {.lex_state = 176, .external_lex_state = 3},
  [2674] = {.lex_state = 176, .external_lex_state = 3},
  [2675] = {.lex_state = 176, .external_lex_state = 3},
  [2676] = {.lex_state = 176, .external_lex_state = 3},
  [2677] = {.lex_state = 175, .external_lex_state = 3},
  [2678] = {.lex_state = 175, .external_lex_state = 3},
  [2679] = {.lex_state = 175, .external_lex_state = 3},
  [2680] = {.lex_state = 176, .external_lex_state = 3},
  [2681] = {.lex_state = 176, .external_lex_state = 3},
  [2682] = {.lex_state = 176, .external_lex_state = 3},
  [2683] = {.lex_state = 176, .external_lex_state = 3},
  [2684] = {.lex_state = 176, .external_lex_state = 3},
  [2685] = {.lex_state = 176, .external_lex_state = 3},
  [2686] = {.lex_state = 175, .external_lex_state = 3},
  [2687] = {.lex_state = 182, .external_lex_state = 3},
  [2688] = {.lex_state = 176, .external_lex_state = 3},
  [2689] = {.lex_state = 176, .external_lex_state = 3},
  [2690] = {.lex_state = 176, .external_lex_state = 3},
  [2691] = {.lex_state = 175, .external_lex_state = 3},
  [2692] = {.lex_state = 175, .external_lex_state = 3},
  [2693] = {.lex_state = 175, .external_lex_state = 3},
  [2694] = {.lex_state = 175, .external_lex_state = 3},
  [2695] = {.lex_state = 176, .external_lex_state = 3},
  [2696] = {.lex_state = 176, .external_lex_state = 3},
  [2697] = {.lex_state = 176, .external_lex_state = 3},
  [2698] = {.lex_state = 176, .external_lex_state = 3},
  [2699] = {.lex_state = 175, .external_lex_state = 3},
  [2700] = {.lex_state = 176, .external_lex_state = 3},
  [2701] = {.lex_state = 176, .external_lex_state = 3},
  [2702] = {.lex_state = 176, .external_lex_state = 3},
  [2703] = {.lex_state = 175, .external_lex_state = 3},
  [2704] = {.lex_state = 175, .external_lex_state = 3},
  [2705] = {.lex_state = 175, .external_lex_state = 3},
  [2706] = {.lex_state = 176, .external_lex_state = 3},
  [2707] = {.lex_state = 176, .external_lex_state = 3},
  [2708] = {.lex_state = 176, .external_lex_state = 3},
  [2709] = {.lex_state = 175, .external_lex_state = 3},
  [2710] = {.lex_state = 176, .external_lex_state = 3},
  [2711] = {.lex_state = 176, .external_lex_state = 3},
  [2712] = {.lex_state = 176, .external_lex_state = 3},
  [2713] = {.lex_state = 176, .external_lex_state = 3},
  [2714] = {.lex_state = 176, .external_lex_state = 3},
  [2715] = {.lex_state = 175, .external_lex_state = 3},
  [2716] = {.lex_state = 176, .external_lex_state = 3},
  [2717] = {.lex_state = 176, .external_lex_state = 3},
  [2718] = {.lex_state = 176, .external_lex_state = 3},
  [2719] = {.lex_state = 175, .external_lex_state = 3},
  [2720] = {.lex_state = 176, .external_lex_state = 3},
  [2721] = {.lex_state = 175, .external_lex_state = 3},
  [2722] = {.lex_state = 175, .external_lex_state = 3},
  [2723] = {.lex_state = 176, .external_lex_state = 3},
  [2724] = {.lex_state = 176, .external_lex_state = 3},
  [2725] = {.lex_state = 176, .external_lex_state = 3},
  [2726] = {.lex_state = 176, .external_lex_state = 3},
  [2727] = {.lex_state = 176, .external_lex_state = 3},
  [2728] = {.lex_state = 175, .external_lex_state = 3},
  [2729] = {.lex_state = 175, .external_lex_state = 3},
  [2730] = {.lex_state = 175, .external_lex_state = 3},
  [2731] = {.lex_state = 175, .external_lex_state = 3},
  [2732] = {.lex_state = 175, .external_lex_state = 3},
  [2733] = {.lex_state = 176, .external_lex_state = 3},
  [2734] = {.lex_state = 175, .external_lex_state = 3},
  [2735] = {.lex_state = 175, .external_lex_state = 3},
  [2736] = {.lex_state = 175, .external_lex_state = 3},
  [2737] = {.lex_state = 175, .external_lex_state = 3},
  [2738] = {.lex_state = 175, .external_lex_state = 3},
  [2739] = {.lex_state = 175, .external_lex_state = 3},
  [2740] = {.lex_state = 175, .external_lex_state = 3},
  [2741] = {.lex_state = 175, .external_lex_state = 3},
  [2742] = {.lex_state = 175, .external_lex_state = 3},
  [2743] = {.lex_state = 175, .external_lex_state = 3},
  [2744] = {.lex_state = 175, .external_lex_state = 3},
  [2745] = {.lex_state = 175, .external_lex_state = 3},
  [2746] = {.lex_state = 175, .external_lex_state = 3},
  [2747] = {.lex_state = 175, .external_lex_state = 3},
  [2748] = {.lex_state = 175, .external_lex_state = 3},
  [2749] = {.lex_state = 175, .external_lex_state = 3},
  [2750] = {.lex_state = 175, .external_lex_state = 3},
  [2751] = {.lex_state = 175, .external_lex_state = 3},
  [2752] = {.lex_state = 175, .external_lex_state = 3},
  [2753] = {.lex_state = 175, .external_lex_state = 3},
  [2754] = {.lex_state = 175, .external_lex_state = 3},
  [2755] = {.lex_state = 175, .external_lex_state = 3},
  [2756] = {.lex_state = 175, .external_lex_state = 3},
  [2757] = {.lex_state = 175, .external_lex_state = 3},
  [2758] = {.lex_state = 175, .external_lex_state = 3},
  [2759] = {.lex_state = 175, .external_lex_state = 3},
  [2760] = {.lex_state = 175, .external_lex_state = 3},
  [2761] = {.lex_state = 175, .external_lex_state = 3},
  [2762] = {.lex_state = 175, .external_lex_state = 3},
  [2763] = {.lex_state = 175, .external_lex_state = 3},
  [2764] = {.lex_state = 175, .external_lex_state = 3},
  [2765] = {.lex_state = 175, .external_lex_state = 3},
  [2766] = {.lex_state = 175, .external_lex_state = 3},
  [2767] = {.lex_state = 175, .external_lex_state = 3},
  [2768] = {.lex_state = 175, .external_lex_state = 3},
  [2769] = {.lex_state = 175, .external_lex_state = 3},
  [2770] = {.lex_state = 175, .external_lex_state = 3},
  [2771] = {.lex_state = 24, .external_lex_state = 3},
  [2772] = {.lex_state = 175, .external_lex_state = 3},
  [2773] = {.lex_state = 175, .external_lex_state = 3},
  [2774] = {.lex_state = 175, .external_lex_state = 3},
  [2775] = {.lex_state = 175, .external_lex_state = 3},
  [2776] = {.lex_state = 175, .external_lex_state = 3},
  [2777] = {.lex_state = 175, .external_lex_state = 3},
  [2778] = {.lex_state = 175, .external_lex_state = 3},
  [2779] = {.lex_state = 175, .external_lex_state = 3},
  [2780] = {.lex_state = 175, .external_lex_state = 3},
  [2781] = {.lex_state = 175, .external_lex_state = 3},
  [2782] = {.lex_state = 175, .external_lex_state = 3},
  [2783] = {.lex_state = 175, .external_lex_state = 3},
  [2784] = {.lex_state = 175, .external_lex_state = 3},
  [2785] = {.lex_state = 175, .external_lex_state = 3},
  [2786] = {.lex_state = 175, .external_lex_state = 3},
  [2787] = {.lex_state = 175, .external_lex_state = 3},
  [2788] = {.lex_state = 175, .external_lex_state = 3},
  [2789] = {.lex_state = 175, .external_lex_state = 3},
  [2790] = {.lex_state = 178, .external_lex_state = 3},
  [2791] = {.lex_state = 175, .external_lex_state = 3},
  [2792] = {.lex_state = 175, .external_lex_state = 3},
  [2793] = {.lex_state = 175, .external_lex_state = 3},
  [2794] = {.lex_state = 175, .external_lex_state = 3},
  [2795] = {.lex_state = 175, .external_lex_state = 3},
  [2796] = {.lex_state = 175, .external_lex_state = 3},
  [2797] = {.lex_state = 175, .external_lex_state = 3},
  [2798] = {.lex_state = 175, .external_lex_state = 3},
  [2799] = {.lex_state = 175, .external_lex_state = 3},
  [2800] = {.lex_state = 175, .external_lex_state = 3},
  [2801] = {.lex_state = 175, .external_lex_state = 3},
  [2802] = {.lex_state = 175, .external_lex_state = 3},
  [2803] = {.lex_state = 175, .external_lex_state = 3},
  [2804] = {.lex_state = 175, .external_lex_state = 3},
  [2805] = {.lex_state = 175, .external_lex_state = 3},
  [2806] = {.lex_state = 175, .external_lex_state = 3},
  [2807] = {.lex_state = 175, .external_lex_state = 3},
  [2808] = {.lex_state = 175, .external_lex_state = 3},
  [2809] = {.lex_state = 175, .external_lex_state = 3},
  [2810] = {.lex_state = 175, .external_lex_state = 3},
  [2811] = {.lex_state = 175, .external_lex_state = 3},
  [2812] = {.lex_state = 175, .external_lex_state = 3},
  [2813] = {.lex_state = 175, .external_lex_state = 3},
  [2814] = {.lex_state = 175, .external_lex_state = 3},
  [2815] = {.lex_state = 175, .external_lex_state = 3},
  [2816] = {.lex_state = 175, .external_lex_state = 3},
  [2817] = {.lex_state = 175, .external_lex_state = 3},
  [2818] = {.lex_state = 175, .external_lex_state = 3},
  [2819] = {.lex_state = 175, .external_lex_state = 3},
  [2820] = {.lex_state = 175, .external_lex_state = 3},
  [2821] = {.lex_state = 175, .external_lex_state = 3},
  [2822] = {.lex_state = 175, .external_lex_state = 3},
  [2823] = {.lex_state = 175, .external_lex_state = 3},
  [2824] = {.lex_state = 175, .external_lex_state = 3},
  [2825] = {.lex_state = 175, .external_lex_state = 3},
  [2826] = {.lex_state = 175, .external_lex_state = 3},
  [2827] = {.lex_state = 175, .external_lex_state = 3},
  [2828] = {.lex_state = 175, .external_lex_state = 3},
  [2829] = {.lex_state = 175, .external_lex_state = 3},
  [2830] = {.lex_state = 175, .external_lex_state = 3},
  [2831] = {.lex_state = 175, .external_lex_state = 3},
  [2832] = {.lex_state = 175, .external_lex_state = 3},
  [2833] = {.lex_state = 175, .external_lex_state = 3},
  [2834] = {.lex_state = 175, .external_lex_state = 3},
  [2835] = {.lex_state = 178, .external_lex_state = 3},
  [2836] = {.lex_state = 175, .external_lex_state = 3},
  [2837] = {.lex_state = 175, .external_lex_state = 3},
  [2838] = {.lex_state = 175, .external_lex_state = 3},
  [2839] = {.lex_state = 175, .external_lex_state = 3},
  [2840] = {.lex_state = 175, .external_lex_state = 3},
  [2841] = {.lex_state = 178, .external_lex_state = 3},
  [2842] = {.lex_state = 175, .external_lex_state = 3},
  [2843] = {.lex_state = 175, .external_lex_state = 3},
  [2844] = {.lex_state = 175, .external_lex_state = 3},
  [2845] = {.lex_state = 175, .external_lex_state = 3},
  [2846] = {.lex_state = 175, .external_lex_state = 3},
  [2847] = {.lex_state = 175, .external_lex_state = 3},
  [2848] = {.lex_state = 175, .external_lex_state = 3},
  [2849] = {.lex_state = 175, .external_lex_state = 3},
  [2850] = {.lex_state = 175, .external_lex_state = 3},
  [2851] = {.lex_state = 175, .external_lex_state = 3},
  [2852] = {.lex_state = 175, .external_lex_state = 3},
  [2853] = {.lex_state = 175, .external_lex_state = 3},
  [2854] = {.lex_state = 175, .external_lex_state = 3},
  [2855] = {.lex_state = 175, .external_lex_state = 3},
  [2856] = {.lex_state = 175, .external_lex_state = 3},
  [2857] = {.lex_state = 175, .external_lex_state = 3},
  [2858] = {.lex_state = 175, .external_lex_state = 3},
  [2859] = {.lex_state = 175, .external_lex_state = 3},
  [2860] = {.lex_state = 175, .external_lex_state = 3},
  [2861] = {.lex_state = 175, .external_lex_state = 3},
  [2862] = {.lex_state = 175, .external_lex_state = 3},
  [2863] = {.lex_state = 175, .external_lex_state = 3},
  [2864] = {.lex_state = 175, .external_lex_state = 3},
  [2865] = {.lex_state = 175, .external_lex_state = 3},
  [2866] = {.lex_state = 175, .external_lex_state = 3},
  [2867] = {.lex_state = 175, .external_lex_state = 3},
  [2868] = {.lex_state = 175, .external_lex_state = 3},
  [2869] = {.lex_state = 175, .external_lex_state = 3},
  [2870] = {.lex_state = 175, .external_lex_state = 3},
  [2871] = {.lex_state = 175, .external_lex_state = 3},
  [2872] = {.lex_state = 175, .external_lex_state = 3},
  [2873] = {.lex_state = 175, .external_lex_state = 3},
  [2874] = {.lex_state = 175, .external_lex_state = 3},
  [2875] = {.lex_state = 175, .external_lex_state = 3},
  [2876] = {.lex_state = 175, .external_lex_state = 3},
  [2877] = {.lex_state = 175, .external_lex_state = 3},
  [2878] = {.lex_state = 175, .external_lex_state = 3},
  [2879] = {.lex_state = 175, .external_lex_state = 3},
  [2880] = {.lex_state = 175, .external_lex_state = 3},
  [2881] = {.lex_state = 175, .external_lex_state = 3},
  [2882] = {.lex_state = 175, .external_lex_state = 3},
  [2883] = {.lex_state = 175, .external_lex_state = 3},
  [2884] = {.lex_state = 175, .external_lex_state = 3},
  [2885] = {.lex_state = 175, .external_lex_state = 3},
  [2886] = {.lex_state = 175, .external_lex_state = 3},
  [2887] = {.lex_state = 175, .external_lex_state = 3},
  [2888] = {.lex_state = 175, .external_lex_state = 3},
  [2889] = {.lex_state = 175, .external_lex_state = 3},
  [2890] = {.lex_state = 175, .external_lex_state = 3},
  [2891] = {.lex_state = 175, .external_lex_state = 3},
  [2892] = {.lex_state = 175, .external_lex_state = 3},
  [2893] = {.lex_state = 175, .external_lex_state = 3},
  [2894] = {.lex_state = 175, .external_lex_state = 3},
  [2895] = {.lex_state = 175, .external_lex_state = 3},
  [2896] = {.lex_state = 175, .external_lex_state = 3},
  [2897] = {.lex_state = 175, .external_lex_state = 3},
  [2898] = {.lex_state = 175, .external_lex_state = 3},
  [2899] = {.lex_state = 175, .external_lex_state = 3},
  [2900] = {.lex_state = 175, .external_lex_state = 3},
  [2901] = {.lex_state = 175, .external_lex_state = 3},
  [2902] = {.lex_state = 175, .external_lex_state = 3},
  [2903] = {.lex_state = 175, .external_lex_state = 3},
  [2904] = {.lex_state = 175, .external_lex_state = 3},
  [2905] = {.lex_state = 175, .external_lex_state = 3},
  [2906] = {.lex_state = 175, .external_lex_state = 3},
  [2907] = {.lex_state = 175, .external_lex_state = 3},
  [2908] = {.lex_state = 175, .external_lex_state = 3},
  [2909] = {.lex_state = 175, .external_lex_state = 3},
  [2910] = {.lex_state = 175, .external_lex_state = 3},
  [2911] = {.lex_state = 175, .external_lex_state = 3},
  [2912] = {.lex_state = 175, .external_lex_state = 3},
  [2913] = {.lex_state = 175, .external_lex_state = 3},
  [2914] = {.lex_state = 175, .external_lex_state = 3},
  [2915] = {.lex_state = 175, .external_lex_state = 3},
  [2916] = {.lex_state = 175, .external_lex_state = 3},
  [2917] = {.lex_state = 175, .external_lex_state = 3},
  [2918] = {.lex_state = 175, .external_lex_state = 3},
  [2919] = {.lex_state = 175, .external_lex_state = 3},
  [2920] = {.lex_state = 175, .external_lex_state = 3},
  [2921] = {.lex_state = 175, .external_lex_state = 3},
  [2922] = {.lex_state = 175, .external_lex_state = 3},
  [2923] = {.lex_state = 175, .external_lex_state = 3},
  [2924] = {.lex_state = 175, .external_lex_state = 3},
  [2925] = {.lex_state = 175, .external_lex_state = 3},
  [2926] = {.lex_state = 175, .external_lex_state = 3},
  [2927] = {.lex_state = 175, .external_lex_state = 3},
  [2928] = {.lex_state = 175, .external_lex_state = 3},
  [2929] = {.lex_state = 175, .external_lex_state = 3},
  [2930] = {.lex_state = 175, .external_lex_state = 3},
  [2931] = {.lex_state = 175, .external_lex_state = 3},
  [2932] = {.lex_state = 175, .external_lex_state = 3},
  [2933] = {.lex_state = 175, .external_lex_state = 3},
  [2934] = {.lex_state = 178, .external_lex_state = 3},
  [2935] = {.lex_state = 175, .external_lex_state = 3},
  [2936] = {.lex_state = 175, .external_lex_state = 3},
  [2937] = {.lex_state = 175, .external_lex_state = 3},
  [2938] = {.lex_state = 175, .external_lex_state = 3},
  [2939] = {.lex_state = 175, .external_lex_state = 3},
  [2940] = {.lex_state = 175, .external_lex_state = 3},
  [2941] = {.lex_state = 175, .external_lex_state = 3},
  [2942] = {.lex_state = 175, .external_lex_state = 3},
  [2943] = {.lex_state = 175, .external_lex_state = 3},
  [2944] = {.lex_state = 175, .external_lex_state = 3},
  [2945] = {.lex_state = 175, .external_lex_state = 3},
  [2946] = {.lex_state = 175, .external_lex_state = 3},
  [2947] = {.lex_state = 178, .external_lex_state = 3},
  [2948] = {.lex_state = 178, .external_lex_state = 3},
  [2949] = {.lex_state = 175, .external_lex_state = 3},
  [2950] = {.lex_state = 175, .external_lex_state = 3},
  [2951] = {.lex_state = 175, .external_lex_state = 3},
  [2952] = {.lex_state = 175, .external_lex_state = 3},
  [2953] = {.lex_state = 175, .external_lex_state = 3},
  [2954] = {.lex_state = 175, .external_lex_state = 3},
  [2955] = {.lex_state = 175, .external_lex_state = 3},
  [2956] = {.lex_state = 175, .external_lex_state = 3},
  [2957] = {.lex_state = 175, .external_lex_state = 3},
  [2958] = {.lex_state = 175, .external_lex_state = 3},
  [2959] = {.lex_state = 175, .external_lex_state = 3},
  [2960] = {.lex_state = 175, .external_lex_state = 3},
  [2961] = {.lex_state = 175, .external_lex_state = 3},
  [2962] = {.lex_state = 175, .external_lex_state = 3},
  [2963] = {.lex_state = 175, .external_lex_state = 3},
  [2964] = {.lex_state = 175, .external_lex_state = 3},
  [2965] = {.lex_state = 450, .external_lex_state = 2},
  [2966] = {.lex_state = 24, .external_lex_state = 3},
  [2967] = {.lex_state = 175, .external_lex_state = 3},
  [2968] = {.lex_state = 24, .external_lex_state = 3},
  [2969] = {.lex_state = 175, .external_lex_state = 3},
  [2970] = {.lex_state = 175, .external_lex_state = 3},
  [2971] = {.lex_state = 175, .external_lex_state = 3},
  [2972] = {.lex_state = 175, .external_lex_state = 3},
  [2973] = {.lex_state = 175, .external_lex_state = 3},
  [2974] = {.lex_state = 189, .external_lex_state = 3},
  [2975] = {.lex_state = 175, .external_lex_state = 3},
  [2976] = {.lex_state = 175, .external_lex_state = 3},
  [2977] = {.lex_state = 175, .external_lex_state = 3},
  [2978] = {.lex_state = 6, .external_lex_state = 3},
  [2979] = {.lex_state = 175, .external_lex_state = 3},
  [2980] = {.lex_state = 175, .external_lex_state = 3},
  [2981] = {.lex_state = 175, .external_lex_state = 3},
  [2982] = {.lex_state = 175, .external_lex_state = 3},
  [2983] = {.lex_state = 175, .external_lex_state = 3},
  [2984] = {.lex_state = 175, .external_lex_state = 3},
  [2985] = {.lex_state = 175, .external_lex_state = 3},
  [2986] = {.lex_state = 175, .external_lex_state = 3},
  [2987] = {.lex_state = 175, .external_lex_state = 3},
  [2988] = {.lex_state = 175, .external_lex_state = 3},
  [2989] = {.lex_state = 175, .external_lex_state = 3},
  [2990] = {.lex_state = 175, .external_lex_state = 3},
  [2991] = {.lex_state = 175, .external_lex_state = 3},
  [2992] = {.lex_state = 190, .external_lex_state = 3},
  [2993] = {.lex_state = 175, .external_lex_state = 3},
  [2994] = {.lex_state = 175, .external_lex_state = 3},
  [2995] = {.lex_state = 175, .external_lex_state = 3},
  [2996] = {.lex_state = 190, .external_lex_state = 3},
  [2997] = {.lex_state = 175, .external_lex_state = 3},
  [2998] = {.lex_state = 175, .external_lex_state = 3},
  [2999] = {.lex_state = 175, .external_lex_state = 3},
  [3000] = {.lex_state = 190, .external_lex_state = 3},
  [3001] = {.lex_state = 175, .external_lex_state = 3},
  [3002] = {.lex_state = 175, .external_lex_state = 3},
  [3003] = {.lex_state = 175, .external_lex_state = 3},
  [3004] = {.lex_state = 175, .external_lex_state = 3},
  [3005] = {.lex_state = 190, .external_lex_state = 3},
  [3006] = {.lex_state = 175, .external_lex_state = 3},
  [3007] = {.lex_state = 24, .external_lex_state = 3},
  [3008] = {.lex_state = 175, .external_lex_state = 3},
  [3009] = {.lex_state = 175, .external_lex_state = 3},
  [3010] = {.lex_state = 175, .external_lex_state = 3},
  [3011] = {.lex_state = 190, .external_lex_state = 3},
  [3012] = {.lex_state = 175, .external_lex_state = 3},
  [3013] = {.lex_state = 190, .external_lex_state = 3},
  [3014] = {.lex_state = 175, .external_lex_state = 3},
  [3015] = {.lex_state = 175, .external_lex_state = 3},
  [3016] = {.lex_state = 190, .external_lex_state = 3},
  [3017] = {.lex_state = 175, .external_lex_state = 3},
  [3018] = {.lex_state = 190, .external_lex_state = 3},
  [3019] = {.lex_state = 175, .external_lex_state = 3},
  [3020] = {.lex_state = 175, .external_lex_state = 3},
  [3021] = {.lex_state = 175, .external_lex_state = 3},
  [3022] = {.lex_state = 175, .external_lex_state = 3},
  [3023] = {.lex_state = 175, .external_lex_state = 3},
  [3024] = {.lex_state = 190, .external_lex_state = 3},
  [3025] = {.lex_state = 175, .external_lex_state = 3},
  [3026] = {.lex_state = 6, .external_lex_state = 3},
  [3027] = {.lex_state = 175, .external_lex_state = 3},
  [3028] = {.lex_state = 175, .external_lex_state = 3},
  [3029] = {.lex_state = 190, .external_lex_state = 3},
  [3030] = {.lex_state = 24, .external_lex_state = 3},
  [3031] = {.lex_state = 175, .external_lex_state = 3},
  [3032] = {.lex_state = 190, .external_lex_state = 3},
  [3033] = {.lex_state = 175, .external_lex_state = 3},
  [3034] = {.lex_state = 175, .external_lex_state = 3},
  [3035] = {.lex_state = 175, .external_lex_state = 3},
  [3036] = {.lex_state = 175, .external_lex_state = 3},
  [3037] = {.lex_state = 175, .external_lex_state = 3},
  [3038] = {.lex_state = 175, .external_lex_state = 3},
  [3039] = {.lex_state = 175, .external_lex_state = 3},
  [3040] = {.lex_state = 175, .external_lex_state = 3},
  [3041] = {.lex_state = 190, .external_lex_state = 3},
  [3042] = {.lex_state = 190, .external_lex_state = 3},
  [3043] = {.lex_state = 175, .external_lex_state = 3},
  [3044] = {.lex_state = 190, .external_lex_state = 3},
  [3045] = {.lex_state = 175, .external_lex_state = 3},
  [3046] = {.lex_state = 175, .external_lex_state = 3},
  [3047] = {.lex_state = 175, .external_lex_state = 3},
  [3048] = {.lex_state = 175, .external_lex_state = 3},
  [3049] = {.lex_state = 175, .external_lex_state = 3},
  [3050] = {.lex_state = 175, .external_lex_state = 3},
  [3051] = {.lex_state = 24, .external_lex_state = 3},
  [3052] = {.lex_state = 190, .external_lex_state = 3},
  [3053] = {.lex_state = 175, .external_lex_state = 3},
  [3054] = {.lex_state = 190, .external_lex_state = 3},
  [3055] = {.lex_state = 175, .external_lex_state = 3},
  [3056] = {.lex_state = 175, .external_lex_state = 3},
  [3057] = {.lex_state = 175, .external_lex_state = 3},
  [3058] = {.lex_state = 175, .external_lex_state = 3},
  [3059] = {.lex_state = 175, .external_lex_state = 3},
  [3060] = {.lex_state = 175, .external_lex_state = 3},
  [3061] = {.lex_state = 190, .external_lex_state = 3},
  [3062] = {.lex_state = 177, .external_lex_state = 3},
  [3063] = {.lex_state = 175, .external_lex_state = 3},
  [3064] = {.lex_state = 177, .external_lex_state = 3},
  [3065] = {.lex_state = 177, .external_lex_state = 3},
  [3066] = {.lex_state = 177, .external_lex_state = 3},
  [3067] = {.lex_state = 175, .external_lex_state = 3},
  [3068] = {.lex_state = 177, .external_lex_state = 3},
  [3069] = {.lex_state = 177, .external_lex_state = 3},
  [3070] = {.lex_state = 175, .external_lex_state = 3},
  [3071] = {.lex_state = 175, .external_lex_state = 3},
  [3072] = {.lex_state = 175, .external_lex_state = 3},
  [3073] = {.lex_state = 175, .external_lex_state = 3},
  [3074] = {.lex_state = 175, .external_lex_state = 3},
  [3075] = {.lex_state = 190, .external_lex_state = 3},
  [3076] = {.lex_state = 175, .external_lex_state = 3},
  [3077] = {.lex_state = 175, .external_lex_state = 3},
  [3078] = {.lex_state = 175, .external_lex_state = 3},
  [3079] = {.lex_state = 175, .external_lex_state = 3},
  [3080] = {.lex_state = 24, .external_lex_state = 3},
  [3081] = {.lex_state = 190, .external_lex_state = 3},
  [3082] = {.lex_state = 175, .external_lex_state = 3},
  [3083] = {.lex_state = 175, .external_lex_state = 3},
  [3084] = {.lex_state = 175, .external_lex_state = 3},
  [3085] = {.lex_state = 175, .external_lex_state = 3},
  [3086] = {.lex_state = 175, .external_lex_state = 3},
  [3087] = {.lex_state = 175, .external_lex_state = 3},
  [3088] = {.lex_state = 175, .external_lex_state = 3},
  [3089] = {.lex_state = 175, .external_lex_state = 3},
  [3090] = {.lex_state = 175, .external_lex_state = 3},
  [3091] = {.lex_state = 190, .external_lex_state = 3},
  [3092] = {.lex_state = 190, .external_lex_state = 3},
  [3093] = {.lex_state = 175, .external_lex_state = 3},
  [3094] = {.lex_state = 175, .external_lex_state = 3},
  [3095] = {.lex_state = 175, .external_lex_state = 3},
  [3096] = {.lex_state = 175, .external_lex_state = 3},
  [3097] = {.lex_state = 175, .external_lex_state = 3},
  [3098] = {.lex_state = 175, .external_lex_state = 3},
  [3099] = {.lex_state = 175, .external_lex_state = 3},
  [3100] = {.lex_state = 175, .external_lex_state = 3},
  [3101] = {.lex_state = 190, .external_lex_state = 3},
  [3102] = {.lex_state = 175, .external_lex_state = 3},
  [3103] = {.lex_state = 175, .external_lex_state = 3},
  [3104] = {.lex_state = 175, .external_lex_state = 3},
  [3105] = {.lex_state = 175, .external_lex_state = 3},
  [3106] = {.lex_state = 175, .external_lex_state = 3},
  [3107] = {.lex_state = 190, .external_lex_state = 3},
  [3108] = {.lex_state = 175, .external_lex_state = 3},
  [3109] = {.lex_state = 190, .external_lex_state = 3},
  [3110] = {.lex_state = 175, .external_lex_state = 3},
  [3111] = {.lex_state = 175, .external_lex_state = 3},
  [3112] = {.lex_state = 175, .external_lex_state = 3},
  [3113] = {.lex_state = 175, .external_lex_state = 3},
  [3114] = {.lex_state = 81, .external_lex_state = 3},
  [3115] = {.lex_state = 81, .external_lex_state = 3},
  [3116] = {.lex_state = 175, .external_lex_state = 3},
  [3117] = {.lex_state = 175, .external_lex_state = 3},
  [3118] = {.lex_state = 175, .external_lex_state = 3},
  [3119] = {.lex_state = 175, .external_lex_state = 3},
  [3120] = {.lex_state = 175, .external_lex_state = 3},
  [3121] = {.lex_state = 175, .external_lex_state = 3},
  [3122] = {.lex_state = 175, .external_lex_state = 3},
  [3123] = {.lex_state = 77, .external_lex_state = 3},
  [3124] = {.lex_state = 175, .external_lex_state = 3},
  [3125] = {.lex_state = 175, .external_lex_state = 3},
  [3126] = {.lex_state = 175, .external_lex_state = 3},
  [3127] = {.lex_state = 175, .external_lex_state = 3},
  [3128] = {.lex_state = 175, .external_lex_state = 3},
  [3129] = {.lex_state = 175, .external_lex_state = 3},
  [3130] = {.lex_state = 77, .external_lex_state = 3},
  [3131] = {.lex_state = 77, .external_lex_state = 3},
  [3132] = {.lex_state = 77, .external_lex_state = 3},
  [3133] = {.lex_state = 77, .external_lex_state = 3},
  [3134] = {.lex_state = 77, .external_lex_state = 3},
  [3135] = {.lex_state = 77, .external_lex_state = 3},
  [3136] = {.lex_state = 77, .external_lex_state = 3},
  [3137] = {.lex_state = 77, .external_lex_state = 3},
  [3138] = {.lex_state = 175, .external_lex_state = 3},
  [3139] = {.lex_state = 77, .external_lex_state = 3},
  [3140] = {.lex_state = 77, .external_lex_state = 3},
  [3141] = {.lex_state = 175, .external_lex_state = 3},
  [3142] = {.lex_state = 81, .external_lex_state = 3},
  [3143] = {.lex_state = 175, .external_lex_state = 3},
  [3144] = {.lex_state = 175, .external_lex_state = 3},
  [3145] = {.lex_state = 81, .external_lex_state = 3},
  [3146] = {.lex_state = 81, .external_lex_state = 3},
  [3147] = {.lex_state = 81, .external_lex_state = 3},
  [3148] = {.lex_state = 81, .external_lex_state = 3},
  [3149] = {.lex_state = 81, .external_lex_state = 3},
  [3150] = {.lex_state = 81, .external_lex_state = 3},
  [3151] = {.lex_state = 175, .external_lex_state = 3},
  [3152] = {.lex_state = 175, .external_lex_state = 3},
  [3153] = {.lex_state = 175, .external_lex_state = 3},
  [3154] = {.lex_state = 175, .external_lex_state = 3},
  [3155] = {.lex_state = 175, .external_lex_state = 3},
  [3156] = {.lex_state = 81, .external_lex_state = 3},
  [3157] = {.lex_state = 81, .external_lex_state = 3},
  [3158] = {.lex_state = 175, .external_lex_state = 3},
  [3159] = {.lex_state = 175, .external_lex_state = 3},
  [3160] = {.lex_state = 178, .external_lex_state = 3},
  [3161] = {.lex_state = 175, .external_lex_state = 3},
  [3162] = {.lex_state = 175, .external_lex_state = 3},
  [3163] = {.lex_state = 175, .external_lex_state = 3},
  [3164] = {.lex_state = 175, .external_lex_state = 3},
  [3165] = {.lex_state = 175, .external_lex_state = 3},
  [3166] = {.lex_state = 175, .external_lex_state = 3},
  [3167] = {.lex_state = 175, .external_lex_state = 3},
  [3168] = {.lex_state = 175, .external_lex_state = 3},
  [3169] = {.lex_state = 175, .external_lex_state = 3},
  [3170] = {.lex_state = 175, .external_lex_state = 3},
  [3171] = {.lex_state = 175, .external_lex_state = 3},
  [3172] = {.lex_state = 175, .external_lex_state = 3},
  [3173] = {.lex_state = 175, .external_lex_state = 3},
  [3174] = {.lex_state = 175, .external_lex_state = 3},
  [3175] = {.lex_state = 175, .external_lex_state = 3},
  [3176] = {.lex_state = 175, .external_lex_state = 3},
  [3177] = {.lex_state = 175, .external_lex_state = 3},
  [3178] = {.lex_state = 175, .external_lex_state = 3},
  [3179] = {.lex_state = 175, .external_lex_state = 3},
  [3180] = {.lex_state = 175, .external_lex_state = 3},
  [3181] = {.lex_state = 175, .external_lex_state = 3},
  [3182] = {.lex_state = 175, .external_lex_state = 3},
  [3183] = {.lex_state = 175, .external_lex_state = 3},
  [3184] = {.lex_state = 175, .external_lex_state = 3},
  [3185] = {.lex_state = 175, .external_lex_state = 3},
  [3186] = {.lex_state = 175, .external_lex_state = 3},
  [3187] = {.lex_state = 175, .external_lex_state = 3},
  [3188] = {.lex_state = 175, .external_lex_state = 3},
  [3189] = {.lex_state = 175, .external_lex_state = 3},
  [3190] = {.lex_state = 175, .external_lex_state = 3},
  [3191] = {.lex_state = 175, .external_lex_state = 3},
  [3192] = {.lex_state = 175, .external_lex_state = 3},
  [3193] = {.lex_state = 175, .external_lex_state = 3},
  [3194] = {.lex_state = 175, .external_lex_state = 3},
  [3195] = {.lex_state = 175, .external_lex_state = 3},
  [3196] = {.lex_state = 175, .external_lex_state = 3},
  [3197] = {.lex_state = 175, .external_lex_state = 3},
  [3198] = {.lex_state = 175, .external_lex_state = 3},
  [3199] = {.lex_state = 175, .external_lex_state = 3},
  [3200] = {.lex_state = 175, .external_lex_state = 3},
  [3201] = {.lex_state = 175, .external_lex_state = 3},
  [3202] = {.lex_state = 175, .external_lex_state = 3},
  [3203] = {.lex_state = 175, .external_lex_state = 3},
  [3204] = {.lex_state = 175, .external_lex_state = 3},
  [3205] = {.lex_state = 175, .external_lex_state = 3},
  [3206] = {.lex_state = 175, .external_lex_state = 3},
  [3207] = {.lex_state = 175, .external_lex_state = 3},
  [3208] = {.lex_state = 175, .external_lex_state = 3},
  [3209] = {.lex_state = 175, .external_lex_state = 3},
  [3210] = {.lex_state = 175, .external_lex_state = 3},
  [3211] = {.lex_state = 175, .external_lex_state = 3},
  [3212] = {.lex_state = 175, .external_lex_state = 3},
  [3213] = {.lex_state = 175, .external_lex_state = 3},
  [3214] = {.lex_state = 175, .external_lex_state = 3},
  [3215] = {.lex_state = 175, .external_lex_state = 3},
  [3216] = {.lex_state = 175, .external_lex_state = 3},
  [3217] = {.lex_state = 175, .external_lex_state = 3},
  [3218] = {.lex_state = 175, .external_lex_state = 3},
  [3219] = {.lex_state = 175, .external_lex_state = 3},
  [3220] = {.lex_state = 175, .external_lex_state = 3},
  [3221] = {.lex_state = 175, .external_lex_state = 3},
  [3222] = {.lex_state = 175, .external_lex_state = 3},
  [3223] = {.lex_state = 175, .external_lex_state = 3},
  [3224] = {.lex_state = 175, .external_lex_state = 3},
  [3225] = {.lex_state = 175, .external_lex_state = 3},
  [3226] = {.lex_state = 175, .external_lex_state = 3},
  [3227] = {.lex_state = 175, .external_lex_state = 3},
  [3228] = {.lex_state = 175, .external_lex_state = 3},
  [3229] = {.lex_state = 175, .external_lex_state = 3},
  [3230] = {.lex_state = 175, .external_lex_state = 3},
  [3231] = {.lex_state = 175, .external_lex_state = 3},
  [3232] = {.lex_state = 175, .external_lex_state = 3},
  [3233] = {.lex_state = 175, .external_lex_state = 3},
  [3234] = {.lex_state = 175, .external_lex_state = 3},
  [3235] = {.lex_state = 175, .external_lex_state = 3},
  [3236] = {.lex_state = 175, .external_lex_state = 3},
  [3237] = {.lex_state = 175, .external_lex_state = 3},
  [3238] = {.lex_state = 175, .external_lex_state = 3},
  [3239] = {.lex_state = 175, .external_lex_state = 3},
  [3240] = {.lex_state = 175, .external_lex_state = 3},
  [3241] = {.lex_state = 175, .external_lex_state = 3},
  [3242] = {.lex_state = 175, .external_lex_state = 3},
  [3243] = {.lex_state = 175, .external_lex_state = 3},
  [3244] = {.lex_state = 175, .external_lex_state = 3},
  [3245] = {.lex_state = 175, .external_lex_state = 3},
  [3246] = {.lex_state = 175, .external_lex_state = 3},
  [3247] = {.lex_state = 175, .external_lex_state = 3},
  [3248] = {.lex_state = 77, .external_lex_state = 3},
  [3249] = {.lex_state = 24, .external_lex_state = 4},
  [3250] = {.lex_state = 77, .external_lex_state = 3},
  [3251] = {.lex_state = 77, .external_lex_state = 3},
  [3252] = {.lex_state = 77, .external_lex_state = 3},
  [3253] = {.lex_state = 77, .external_lex_state = 3},
  [3254] = {.lex_state = 77, .external_lex_state = 3},
  [3255] = {.lex_state = 81, .external_lex_state = 3},
  [3256] = {.lex_state = 81, .external_lex_state = 3},
  [3257] = {.lex_state = 75, .external_lex_state = 3},
  [3258] = {.lex_state = 75, .external_lex_state = 3},
  [3259] = {.lex_state = 75, .external_lex_state = 3},
  [3260] = {.lex_state = 77, .external_lex_state = 3},
  [3261] = {.lex_state = 77, .external_lex_state = 3},
  [3262] = {.lex_state = 77, .external_lex_state = 3},
  [3263] = {.lex_state = 77, .external_lex_state = 3},
  [3264] = {.lex_state = 77, .external_lex_state = 3},
  [3265] = {.lex_state = 77, .external_lex_state = 3},
  [3266] = {.lex_state = 77, .external_lex_state = 3},
  [3267] = {.lex_state = 77, .external_lex_state = 3},
  [3268] = {.lex_state = 77, .external_lex_state = 3},
  [3269] = {.lex_state = 77, .external_lex_state = 3},
  [3270] = {.lex_state = 75, .external_lex_state = 3},
  [3271] = {.lex_state = 75, .external_lex_state = 3},
  [3272] = {.lex_state = 77, .external_lex_state = 3},
  [3273] = {.lex_state = 77, .external_lex_state = 3},
  [3274] = {.lex_state = 77, .external_lex_state = 3},
  [3275] = {.lex_state = 77, .external_lex_state = 3},
  [3276] = {.lex_state = 77, .external_lex_state = 3},
  [3277] = {.lex_state = 77, .external_lex_state = 3},
  [3278] = {.lex_state = 77, .external_lex_state = 3},
  [3279] = {.lex_state = 77, .external_lex_state = 3},
  [3280] = {.lex_state = 77, .external_lex_state = 3},
  [3281] = {.lex_state = 77, .external_lex_state = 3},
  [3282] = {.lex_state = 77, .external_lex_state = 3},
  [3283] = {.lex_state = 77, .external_lex_state = 3},
  [3284] = {.lex_state = 77, .external_lex_state = 3},
  [3285] = {.lex_state = 77, .external_lex_state = 3},
  [3286] = {.lex_state = 75, .external_lex_state = 3},
  [3287] = {.lex_state = 77, .external_lex_state = 3},
  [3288] = {.lex_state = 77, .external_lex_state = 3},
  [3289] = {.lex_state = 77, .external_lex_state = 3},
  [3290] = {.lex_state = 77, .external_lex_state = 3},
  [3291] = {.lex_state = 77, .external_lex_state = 3},
  [3292] = {.lex_state = 77, .external_lex_state = 3},
  [3293] = {.lex_state = 77, .external_lex_state = 3},
  [3294] = {.lex_state = 77, .external_lex_state = 3},
  [3295] = {.lex_state = 81, .external_lex_state = 3},
  [3296] = {.lex_state = 77, .external_lex_state = 3},
  [3297] = {.lex_state = 77, .external_lex_state = 3},
  [3298] = {.lex_state = 77, .external_lex_state = 3},
  [3299] = {.lex_state = 77, .external_lex_state = 3},
  [3300] = {.lex_state = 77, .external_lex_state = 3},
  [3301] = {.lex_state = 77, .external_lex_state = 3},
  [3302] = {.lex_state = 77, .external_lex_state = 3},
  [3303] = {.lex_state = 77, .external_lex_state = 3},
  [3304] = {.lex_state = 77, .external_lex_state = 3},
  [3305] = {.lex_state = 77, .external_lex_state = 3},
  [3306] = {.lex_state = 77, .external_lex_state = 3},
  [3307] = {.lex_state = 77, .external_lex_state = 3},
  [3308] = {.lex_state = 77, .external_lex_state = 3},
  [3309] = {.lex_state = 77, .external_lex_state = 3},
  [3310] = {.lex_state = 77, .external_lex_state = 3},
  [3311] = {.lex_state = 77, .external_lex_state = 3},
  [3312] = {.lex_state = 81, .external_lex_state = 3},
  [3313] = {.lex_state = 81, .external_lex_state = 3},
  [3314] = {.lex_state = 81, .external_lex_state = 3},
  [3315] = {.lex_state = 24, .external_lex_state = 4},
  [3316] = {.lex_state = 81, .external_lex_state = 3},
  [3317] = {.lex_state = 81, .external_lex_state = 3},
  [3318] = {.lex_state = 81, .external_lex_state = 3},
  [3319] = {.lex_state = 24, .external_lex_state = 3},
  [3320] = {.lex_state = 81, .external_lex_state = 3},
  [3321] = {.lex_state = 81, .external_lex_state = 3},
  [3322] = {.lex_state = 81, .external_lex_state = 3},
  [3323] = {.lex_state = 81, .external_lex_state = 3},
  [3324] = {.lex_state = 81, .external_lex_state = 3},
  [3325] = {.lex_state = 81, .external_lex_state = 3},
  [3326] = {.lex_state = 81, .external_lex_state = 3},
  [3327] = {.lex_state = 81, .external_lex_state = 3},
  [3328] = {.lex_state = 81, .external_lex_state = 3},
  [3329] = {.lex_state = 81, .external_lex_state = 3},
  [3330] = {.lex_state = 81, .external_lex_state = 3},
  [3331] = {.lex_state = 81, .external_lex_state = 3},
  [3332] = {.lex_state = 81, .external_lex_state = 3},
  [3333] = {.lex_state = 24, .external_lex_state = 4},
  [3334] = {.lex_state = 81, .external_lex_state = 3},
  [3335] = {.lex_state = 81, .external_lex_state = 3},
  [3336] = {.lex_state = 81, .external_lex_state = 3},
  [3337] = {.lex_state = 81, .external_lex_state = 3},
  [3338] = {.lex_state = 81, .external_lex_state = 3},
  [3339] = {.lex_state = 81, .external_lex_state = 3},
  [3340] = {.lex_state = 81, .external_lex_state = 3},
  [3341] = {.lex_state = 81, .external_lex_state = 3},
  [3342] = {.lex_state = 81, .external_lex_state = 3},
  [3343] = {.lex_state = 81, .external_lex_state = 3},
  [3344] = {.lex_state = 24, .external_lex_state = 4},
  [3345] = {.lex_state = 81, .external_lex_state = 3},
  [3346] = {.lex_state = 81, .external_lex_state = 3},
  [3347] = {.lex_state = 83, .external_lex_state = 3},
  [3348] = {.lex_state = 81, .external_lex_state = 3},
  [3349] = {.lex_state = 83, .external_lex_state = 3},
  [3350] = {.lex_state = 81, .external_lex_state = 3},
  [3351] = {.lex_state = 81, .external_lex_state = 3},
  [3352] = {.lex_state = 81, .external_lex_state = 3},
  [3353] = {.lex_state = 81, .external_lex_state = 3},
  [3354] = {.lex_state = 81, .external_lex_state = 3},
  [3355] = {.lex_state = 24, .external_lex_state = 4},
  [3356] = {.lex_state = 81, .external_lex_state = 3},
  [3357] = {.lex_state = 81, .external_lex_state = 3},
  [3358] = {.lex_state = 81, .external_lex_state = 3},
  [3359] = {.lex_state = 81, .external_lex_state = 3},
  [3360] = {.lex_state = 77, .external_lex_state = 3},
  [3361] = {.lex_state = 24, .external_lex_state = 4},
  [3362] = {.lex_state = 77, .external_lex_state = 3},
  [3363] = {.lex_state = 81, .external_lex_state = 3},
  [3364] = {.lex_state = 81, .external_lex_state = 3},
  [3365] = {.lex_state = 24, .external_lex_state = 4},
  [3366] = {.lex_state = 75, .external_lex_state = 3},
  [3367] = {.lex_state = 81, .external_lex_state = 3},
  [3368] = {.lex_state = 24, .external_lex_state = 4},
  [3369] = {.lex_state = 78, .external_lex_state = 3},
  [3370] = {.lex_state = 24, .external_lex_state = 4},
  [3371] = {.lex_state = 81, .external_lex_state = 3},
  [3372] = {.lex_state = 24, .external_lex_state = 4},
  [3373] = {.lex_state = 81, .external_lex_state = 3},
  [3374] = {.lex_state = 77, .external_lex_state = 3},
  [3375] = {.lex_state = 24, .external_lex_state = 4},
  [3376] = {.lex_state = 75, .external_lex_state = 3},
  [3377] = {.lex_state = 77, .external_lex_state = 3},
  [3378] = {.lex_state = 24, .external_lex_state = 4},
  [3379] = {.lex_state = 24, .external_lex_state = 4},
  [3380] = {.lex_state = 75, .external_lex_state = 3},
  [3381] = {.lex_state = 24, .external_lex_state = 4},
  [3382] = {.lex_state = 24, .external_lex_state = 4},
  [3383] = {.lex_state = 78, .external_lex_state = 3},
  [3384] = {.lex_state = 78, .external_lex_state = 3},
  [3385] = {.lex_state = 78, .external_lex_state = 3},
  [3386] = {.lex_state = 24, .external_lex_state = 4},
  [3387] = {.lex_state = 81, .external_lex_state = 3},
  [3388] = {.lex_state = 81, .external_lex_state = 3},
  [3389] = {.lex_state = 81, .external_lex_state = 3},
  [3390] = {.lex_state = 78, .external_lex_state = 3},
  [3391] = {.lex_state = 78, .external_lex_state = 3},
  [3392] = {.lex_state = 77, .external_lex_state = 3},
  [3393] = {.lex_state = 24, .external_lex_state = 4},
  [3394] = {.lex_state = 78, .external_lex_state = 3},
  [3395] = {.lex_state = 81, .external_lex_state = 3},
  [3396] = {.lex_state = 81, .external_lex_state = 3},
  [3397] = {.lex_state = 24, .external_lex_state = 4},
  [3398] = {.lex_state = 81, .external_lex_state = 3},
  [3399] = {.lex_state = 81, .external_lex_state = 3},
  [3400] = {.lex_state = 24, .external_lex_state = 4},
  [3401] = {.lex_state = 24, .external_lex_state = 4},
  [3402] = {.lex_state = 81, .external_lex_state = 3},
  [3403] = {.lex_state = 24, .external_lex_state = 4},
  [3404] = {.lex_state = 82, .external_lex_state = 3},
  [3405] = {.lex_state = 24, .external_lex_state = 4},
  [3406] = {.lex_state = 24, .external_lex_state = 4},
  [3407] = {.lex_state = 24, .external_lex_state = 4},
  [3408] = {.lex_state = 24, .external_lex_state = 4},
  [3409] = {.lex_state = 24, .external_lex_state = 4},
  [3410] = {.lex_state = 81, .external_lex_state = 3},
  [3411] = {.lex_state = 24, .external_lex_state = 4},
  [3412] = {.lex_state = 81, .external_lex_state = 3},
  [3413] = {.lex_state = 82, .external_lex_state = 3},
  [3414] = {.lex_state = 82, .external_lex_state = 3},
  [3415] = {.lex_state = 82, .external_lex_state = 3},
  [3416] = {.lex_state = 24, .external_lex_state = 4},
  [3417] = {.lex_state = 82, .external_lex_state = 3},
  [3418] = {.lex_state = 82, .external_lex_state = 3},
  [3419] = {.lex_state = 24, .external_lex_state = 4},
  [3420] = {.lex_state = 83, .external_lex_state = 3},
  [3421] = {.lex_state = 82, .external_lex_state = 3},
  [3422] = {.lex_state = 24, .external_lex_state = 4},
  [3423] = {.lex_state = 24, .external_lex_state = 4},
  [3424] = {.lex_state = 24, .external_lex_state = 4},
  [3425] = {.lex_state = 78, .external_lex_state = 3},
  [3426] = {.lex_state = 24, .external_lex_state = 4},
  [3427] = {.lex_state = 83, .external_lex_state = 3},
  [3428] = {.lex_state = 83, .external_lex_state = 3},
  [3429] = {.lex_state = 83, .external_lex_state = 3},
  [3430] = {.lex_state = 24, .external_lex_state = 4},
  [3431] = {.lex_state = 83, .external_lex_state = 3},
  [3432] = {.lex_state = 83, .external_lex_state = 3},
  [3433] = {.lex_state = 83, .external_lex_state = 3},
  [3434] = {.lex_state = 24, .external_lex_state = 4},
  [3435] = {.lex_state = 24, .external_lex_state = 4},
  [3436] = {.lex_state = 78, .external_lex_state = 3},
  [3437] = {.lex_state = 24, .external_lex_state = 4},
  [3438] = {.lex_state = 24, .external_lex_state = 4},
  [3439] = {.lex_state = 81, .external_lex_state = 3},
  [3440] = {.lex_state = 81, .external_lex_state = 3},
  [3441] = {.lex_state = 24, .external_lex_state = 4},
  [3442] = {.lex_state = 82, .external_lex_state = 3},
  [3443] = {.lex_state = 24, .external_lex_state = 4},
  [3444] = {.lex_state = 24, .external_lex_state = 4},
  [3445] = {.lex_state = 24, .external_lex_state = 4},
  [3446] = {.lex_state = 81, .external_lex_state = 3},
  [3447] = {.lex_state = 81, .external_lex_state = 3},
  [3448] = {.lex_state = 82, .external_lex_state = 3},
  [3449] = {.lex_state = 24, .external_lex_state = 4},
  [3450] = {.lex_state = 77, .external_lex_state = 3},
  [3451] = {.lex_state = 77, .external_lex_state = 3},
  [3452] = {.lex_state = 77, .external_lex_state = 3},
  [3453] = {.lex_state = 77, .external_lex_state = 3},
  [3454] = {.lex_state = 77, .external_lex_state = 3},
  [3455] = {.lex_state = 77, .external_lex_state = 3},
  [3456] = {.lex_state = 77, .external_lex_state = 3},
  [3457] = {.lex_state = 83, .external_lex_state = 3},
  [3458] = {.lex_state = 81, .external_lex_state = 3},
  [3459] = {.lex_state = 77, .external_lex_state = 3},
  [3460] = {.lex_state = 81, .external_lex_state = 3},
  [3461] = {.lex_state = 77, .external_lex_state = 3},
  [3462] = {.lex_state = 77, .external_lex_state = 3},
  [3463] = {.lex_state = 77, .external_lex_state = 3},
  [3464] = {.lex_state = 77, .external_lex_state = 3},
  [3465] = {.lex_state = 24, .external_lex_state = 3},
  [3466] = {.lex_state = 81, .external_lex_state = 3},
  [3467] = {.lex_state = 83, .external_lex_state = 3},
  [3468] = {.lex_state = 77, .external_lex_state = 3},
  [3469] = {.lex_state = 81, .external_lex_state = 3},
  [3470] = {.lex_state = 81, .external_lex_state = 3},
  [3471] = {.lex_state = 81, .external_lex_state = 3},
  [3472] = {.lex_state = 81, .external_lex_state = 3},
  [3473] = {.lex_state = 77, .external_lex_state = 3},
  [3474] = {.lex_state = 77, .external_lex_state = 3},
  [3475] = {.lex_state = 77, .external_lex_state = 3},
  [3476] = {.lex_state = 81, .external_lex_state = 3},
  [3477] = {.lex_state = 81, .external_lex_state = 3},
  [3478] = {.lex_state = 81, .external_lex_state = 3},
  [3479] = {.lex_state = 81, .external_lex_state = 3},
  [3480] = {.lex_state = 77, .external_lex_state = 3},
  [3481] = {.lex_state = 77, .external_lex_state = 3},
  [3482] = {.lex_state = 81, .external_lex_state = 3},
  [3483] = {.lex_state = 77, .external_lex_state = 3},
  [3484] = {.lex_state = 75, .external_lex_state = 3},
  [3485] = {.lex_state = 78, .external_lex_state = 3},
  [3486] = {.lex_state = 78, .external_lex_state = 3},
  [3487] = {.lex_state = 75, .external_lex_state = 3},
  [3488] = {.lex_state = 82, .external_lex_state = 3},
  [3489] = {.lex_state = 82, .external_lex_state = 3},
  [3490] = {.lex_state = 81, .external_lex_state = 3},
  [3491] = {.lex_state = 81, .external_lex_state = 3},
  [3492] = {.lex_state = 81, .external_lex_state = 3},
  [3493] = {.lex_state = 82, .external_lex_state = 3},
  [3494] = {.lex_state = 75, .external_lex_state = 3},
  [3495] = {.lex_state = 75, .external_lex_state = 3},
  [3496] = {.lex_state = 78, .external_lex_state = 3},
  [3497] = {.lex_state = 78, .external_lex_state = 3},
  [3498] = {.lex_state = 75, .external_lex_state = 3},
  [3499] = {.lex_state = 78, .external_lex_state = 3},
  [3500] = {.lex_state = 83, .external_lex_state = 3},
  [3501] = {.lex_state = 84, .external_lex_state = 3},
  [3502] = {.lex_state = 75, .external_lex_state = 3},
  [3503] = {.lex_state = 78, .external_lex_state = 3},
  [3504] = {.lex_state = 75, .external_lex_state = 3},
  [3505] = {.lex_state = 78, .external_lex_state = 3},
  [3506] = {.lex_state = 78, .external_lex_state = 3},
  [3507] = {.lex_state = 78, .external_lex_state = 3},
  [3508] = {.lex_state = 75, .external_lex_state = 3},
  [3509] = {.lex_state = 75, .external_lex_state = 3},
  [3510] = {.lex_state = 78, .external_lex_state = 3},
  [3511] = {.lex_state = 78, .external_lex_state = 3},
  [3512] = {.lex_state = 75, .external_lex_state = 3},
  [3513] = {.lex_state = 75, .external_lex_state = 3},
  [3514] = {.lex_state = 75, .external_lex_state = 3},
  [3515] = {.lex_state = 75, .external_lex_state = 3},
  [3516] = {.lex_state = 78, .external_lex_state = 3},
  [3517] = {.lex_state = 83, .external_lex_state = 3},
  [3518] = {.lex_state = 84, .external_lex_state = 3},
  [3519] = {.lex_state = 83, .external_lex_state = 3},
  [3520] = {.lex_state = 78, .external_lex_state = 3},
  [3521] = {.lex_state = 82, .external_lex_state = 3},
  [3522] = {.lex_state = 82, .external_lex_state = 3},
  [3523] = {.lex_state = 78, .external_lex_state = 3},
  [3524] = {.lex_state = 78, .external_lex_state = 3},
  [3525] = {.lex_state = 82, .external_lex_state = 3},
  [3526] = {.lex_state = 82, .external_lex_state = 3},
  [3527] = {.lex_state = 82, .external_lex_state = 3},
  [3528] = {.lex_state = 82, .external_lex_state = 3},
  [3529] = {.lex_state = 82, .external_lex_state = 3},
  [3530] = {.lex_state = 75, .external_lex_state = 3},
  [3531] = {.lex_state = 82, .external_lex_state = 3},
  [3532] = {.lex_state = 75, .external_lex_state = 3},
  [3533] = {.lex_state = 82, .external_lex_state = 3},
  [3534] = {.lex_state = 82, .external_lex_state = 3},
  [3535] = {.lex_state = 82, .external_lex_state = 3},
  [3536] = {.lex_state = 82, .external_lex_state = 3},
  [3537] = {.lex_state = 82, .external_lex_state = 3},
  [3538] = {.lex_state = 82, .external_lex_state = 3},
  [3539] = {.lex_state = 78, .external_lex_state = 3},
  [3540] = {.lex_state = 75, .external_lex_state = 3},
  [3541] = {.lex_state = 82, .external_lex_state = 3},
  [3542] = {.lex_state = 82, .external_lex_state = 3},
  [3543] = {.lex_state = 75, .external_lex_state = 3},
  [3544] = {.lex_state = 75, .external_lex_state = 3},
  [3545] = {.lex_state = 82, .external_lex_state = 3},
  [3546] = {.lex_state = 78, .external_lex_state = 3},
  [3547] = {.lex_state = 82, .external_lex_state = 3},
  [3548] = {.lex_state = 82, .external_lex_state = 3},
  [3549] = {.lex_state = 82, .external_lex_state = 3},
  [3550] = {.lex_state = 75, .external_lex_state = 3},
  [3551] = {.lex_state = 82, .external_lex_state = 3},
  [3552] = {.lex_state = 82, .external_lex_state = 3},
  [3553] = {.lex_state = 75, .external_lex_state = 3},
  [3554] = {.lex_state = 75, .external_lex_state = 3},
  [3555] = {.lex_state = 82, .external_lex_state = 3},
  [3556] = {.lex_state = 82, .external_lex_state = 3},
  [3557] = {.lex_state = 83, .external_lex_state = 3},
  [3558] = {.lex_state = 82, .external_lex_state = 3},
  [3559] = {.lex_state = 82, .external_lex_state = 3},
  [3560] = {.lex_state = 83, .external_lex_state = 3},
  [3561] = {.lex_state = 83, .external_lex_state = 3},
  [3562] = {.lex_state = 75, .external_lex_state = 3},
  [3563] = {.lex_state = 82, .external_lex_state = 3},
  [3564] = {.lex_state = 78, .external_lex_state = 3},
  [3565] = {.lex_state = 83, .external_lex_state = 3},
  [3566] = {.lex_state = 83, .external_lex_state = 3},
  [3567] = {.lex_state = 83, .external_lex_state = 3},
  [3568] = {.lex_state = 82, .external_lex_state = 3},
  [3569] = {.lex_state = 82, .external_lex_state = 3},
  [3570] = {.lex_state = 82, .external_lex_state = 3},
  [3571] = {.lex_state = 82, .external_lex_state = 3},
  [3572] = {.lex_state = 82, .external_lex_state = 3},
  [3573] = {.lex_state = 82, .external_lex_state = 3},
  [3574] = {.lex_state = 75, .external_lex_state = 3},
  [3575] = {.lex_state = 82, .external_lex_state = 3},
  [3576] = {.lex_state = 75, .external_lex_state = 3},
  [3577] = {.lex_state = 82, .external_lex_state = 3},
  [3578] = {.lex_state = 75, .external_lex_state = 3},
  [3579] = {.lex_state = 82, .external_lex_state = 3},
  [3580] = {.lex_state = 75, .external_lex_state = 3},
  [3581] = {.lex_state = 82, .external_lex_state = 3},
  [3582] = {.lex_state = 82, .external_lex_state = 3},
  [3583] = {.lex_state = 82, .external_lex_state = 3},
  [3584] = {.lex_state = 75, .external_lex_state = 3},
  [3585] = {.lex_state = 82, .external_lex_state = 3},
  [3586] = {.lex_state = 82, .external_lex_state = 3},
  [3587] = {.lex_state = 83, .external_lex_state = 3},
  [3588] = {.lex_state = 83, .external_lex_state = 3},
  [3589] = {.lex_state = 82, .external_lex_state = 3},
  [3590] = {.lex_state = 78, .external_lex_state = 3},
  [3591] = {.lex_state = 83, .external_lex_state = 3},
  [3592] = {.lex_state = 83, .external_lex_state = 3},
  [3593] = {.lex_state = 83, .external_lex_state = 3},
  [3594] = {.lex_state = 83, .external_lex_state = 3},
  [3595] = {.lex_state = 78, .external_lex_state = 3},
  [3596] = {.lex_state = 83, .external_lex_state = 3},
  [3597] = {.lex_state = 83, .external_lex_state = 3},
  [3598] = {.lex_state = 76, .external_lex_state = 3},
  [3599] = {.lex_state = 75, .external_lex_state = 3},
  [3600] = {.lex_state = 82, .external_lex_state = 3},
  [3601] = {.lex_state = 83, .external_lex_state = 3},
  [3602] = {.lex_state = 83, .external_lex_state = 3},
  [3603] = {.lex_state = 83, .external_lex_state = 3},
  [3604] = {.lex_state = 83, .external_lex_state = 3},
  [3605] = {.lex_state = 83, .external_lex_state = 3},
  [3606] = {.lex_state = 82, .external_lex_state = 3},
  [3607] = {.lex_state = 75, .external_lex_state = 3},
  [3608] = {.lex_state = 83, .external_lex_state = 3},
  [3609] = {.lex_state = 78, .external_lex_state = 3},
  [3610] = {.lex_state = 75, .external_lex_state = 3},
  [3611] = {.lex_state = 83, .external_lex_state = 3},
  [3612] = {.lex_state = 83, .external_lex_state = 3},
  [3613] = {.lex_state = 83, .external_lex_state = 3},
  [3614] = {.lex_state = 78, .external_lex_state = 3},
  [3615] = {.lex_state = 78, .external_lex_state = 3},
  [3616] = {.lex_state = 83, .external_lex_state = 3},
  [3617] = {.lex_state = 83, .external_lex_state = 3},
  [3618] = {.lex_state = 83, .external_lex_state = 3},
  [3619] = {.lex_state = 83, .external_lex_state = 3},
  [3620] = {.lex_state = 83, .external_lex_state = 3},
  [3621] = {.lex_state = 83, .external_lex_state = 3},
  [3622] = {.lex_state = 82, .external_lex_state = 3},
  [3623] = {.lex_state = 82, .external_lex_state = 3},
  [3624] = {.lex_state = 83, .external_lex_state = 3},
  [3625] = {.lex_state = 83, .external_lex_state = 3},
  [3626] = {.lex_state = 78, .external_lex_state = 3},
  [3627] = {.lex_state = 75, .external_lex_state = 3},
  [3628] = {.lex_state = 82, .external_lex_state = 3},
  [3629] = {.lex_state = 83, .external_lex_state = 3},
  [3630] = {.lex_state = 83, .external_lex_state = 3},
  [3631] = {.lex_state = 78, .external_lex_state = 3},
  [3632] = {.lex_state = 78, .external_lex_state = 3},
  [3633] = {.lex_state = 83, .external_lex_state = 3},
  [3634] = {.lex_state = 83, .external_lex_state = 3},
  [3635] = {.lex_state = 78, .external_lex_state = 3},
  [3636] = {.lex_state = 75, .external_lex_state = 3},
  [3637] = {.lex_state = 78, .external_lex_state = 3},
  [3638] = {.lex_state = 83, .external_lex_state = 3},
  [3639] = {.lex_state = 75, .external_lex_state = 3},
  [3640] = {.lex_state = 75, .external_lex_state = 3},
  [3641] = {.lex_state = 82, .external_lex_state = 3},
  [3642] = {.lex_state = 78, .external_lex_state = 3},
  [3643] = {.lex_state = 83, .external_lex_state = 3},
  [3644] = {.lex_state = 78, .external_lex_state = 3},
  [3645] = {.lex_state = 78, .external_lex_state = 3},
  [3646] = {.lex_state = 78, .external_lex_state = 3},
  [3647] = {.lex_state = 78, .external_lex_state = 3},
  [3648] = {.lex_state = 83, .external_lex_state = 3},
  [3649] = {.lex_state = 78, .external_lex_state = 3},
  [3650] = {.lex_state = 78, .external_lex_state = 3},
  [3651] = {.lex_state = 78, .external_lex_state = 3},
  [3652] = {.lex_state = 78, .external_lex_state = 3},
  [3653] = {.lex_state = 82, .external_lex_state = 3},
  [3654] = {.lex_state = 78, .external_lex_state = 3},
  [3655] = {.lex_state = 78, .external_lex_state = 3},
  [3656] = {.lex_state = 78, .external_lex_state = 3},
  [3657] = {.lex_state = 78, .external_lex_state = 3},
  [3658] = {.lex_state = 78, .external_lex_state = 3},
  [3659] = {.lex_state = 82, .external_lex_state = 3},
  [3660] = {.lex_state = 82, .external_lex_state = 3},
  [3661] = {.lex_state = 82, .external_lex_state = 3},
  [3662] = {.lex_state = 78, .external_lex_state = 3},
  [3663] = {.lex_state = 83, .external_lex_state = 3},
  [3664] = {.lex_state = 83, .external_lex_state = 3},
  [3665] = {.lex_state = 82, .external_lex_state = 3},
  [3666] = {.lex_state = 75, .external_lex_state = 3},
  [3667] = {.lex_state = 82, .external_lex_state = 3},
  [3668] = {.lex_state = 78, .external_lex_state = 3},
  [3669] = {.lex_state = 83, .external_lex_state = 3},
  [3670] = {.lex_state = 83, .external_lex_state = 3},
  [3671] = {.lex_state = 83, .external_lex_state = 3},
  [3672] = {.lex_state = 78, .external_lex_state = 3},
  [3673] = {.lex_state = 82, .external_lex_state = 3},
  [3674] = {.lex_state = 75, .external_lex_state = 3},
  [3675] = {.lex_state = 82, .external_lex_state = 3},
  [3676] = {.lex_state = 78, .external_lex_state = 3},
  [3677] = {.lex_state = 75, .external_lex_state = 3},
  [3678] = {.lex_state = 75, .external_lex_state = 3},
  [3679] = {.lex_state = 78, .external_lex_state = 3},
  [3680] = {.lex_state = 82, .external_lex_state = 3},
  [3681] = {.lex_state = 78, .external_lex_state = 3},
  [3682] = {.lex_state = 78, .external_lex_state = 3},
  [3683] = {.lex_state = 82, .external_lex_state = 3},
  [3684] = {.lex_state = 78, .external_lex_state = 3},
  [3685] = {.lex_state = 82, .external_lex_state = 3},
  [3686] = {.lex_state = 83, .external_lex_state = 3},
  [3687] = {.lex_state = 78, .external_lex_state = 3},
  [3688] = {.lex_state = 82, .external_lex_state = 3},
  [3689] = {.lex_state = 82, .external_lex_state = 3},
  [3690] = {.lex_state = 82, .external_lex_state = 3},
  [3691] = {.lex_state = 82, .external_lex_state = 3},
  [3692] = {.lex_state = 82, .external_lex_state = 3},
  [3693] = {.lex_state = 82, .external_lex_state = 3},
  [3694] = {.lex_state = 75, .external_lex_state = 3},
  [3695] = {.lex_state = 75, .external_lex_state = 3},
  [3696] = {.lex_state = 82, .external_lex_state = 3},
  [3697] = {.lex_state = 76, .external_lex_state = 3},
  [3698] = {.lex_state = 82, .external_lex_state = 3},
  [3699] = {.lex_state = 75, .external_lex_state = 3},
  [3700] = {.lex_state = 83, .external_lex_state = 3},
  [3701] = {.lex_state = 76, .external_lex_state = 3},
  [3702] = {.lex_state = 76, .external_lex_state = 3},
  [3703] = {.lex_state = 82, .external_lex_state = 3},
  [3704] = {.lex_state = 78, .external_lex_state = 3},
  [3705] = {.lex_state = 76, .external_lex_state = 3},
  [3706] = {.lex_state = 78, .external_lex_state = 3},
  [3707] = {.lex_state = 82, .external_lex_state = 3},
  [3708] = {.lex_state = 76, .external_lex_state = 3},
  [3709] = {.lex_state = 82, .external_lex_state = 3},
  [3710] = {.lex_state = 78, .external_lex_state = 3},
  [3711] = {.lex_state = 75, .external_lex_state = 3},
  [3712] = {.lex_state = 75, .external_lex_state = 3},
  [3713] = {.lex_state = 76, .external_lex_state = 3},
  [3714] = {.lex_state = 78, .external_lex_state = 3},
  [3715] = {.lex_state = 83, .external_lex_state = 3},
  [3716] = {.lex_state = 76, .external_lex_state = 3},
  [3717] = {.lex_state = 78, .external_lex_state = 3},
  [3718] = {.lex_state = 78, .external_lex_state = 3},
  [3719] = {.lex_state = 76, .external_lex_state = 3},
  [3720] = {.lex_state = 75, .external_lex_state = 3},
  [3721] = {.lex_state = 75, .external_lex_state = 3},
  [3722] = {.lex_state = 78, .external_lex_state = 3},
  [3723] = {.lex_state = 83, .external_lex_state = 3},
  [3724] = {.lex_state = 78, .external_lex_state = 3},
  [3725] = {.lex_state = 78, .external_lex_state = 3},
  [3726] = {.lex_state = 75, .external_lex_state = 3},
  [3727] = {.lex_state = 78, .external_lex_state = 3},
  [3728] = {.lex_state = 83, .external_lex_state = 3},
  [3729] = {.lex_state = 75, .external_lex_state = 3},
  [3730] = {.lex_state = 83, .external_lex_state = 3},
  [3731] = {.lex_state = 78, .external_lex_state = 3},
  [3732] = {.lex_state = 75, .external_lex_state = 3},
  [3733] = {.lex_state = 75, .external_lex_state = 3},
  [3734] = {.lex_state = 75, .external_lex_state = 3},
  [3735] = {.lex_state = 78, .external_lex_state = 3},
  [3736] = {.lex_state = 83, .external_lex_state = 3},
  [3737] = {.lex_state = 83, .external_lex_state = 3},
  [3738] = {.lex_state = 75, .external_lex_state = 3},
  [3739] = {.lex_state = 83, .external_lex_state = 3},
  [3740] = {.lex_state = 83, .external_lex_state = 3},
  [3741] = {.lex_state = 83, .external_lex_state = 3},
  [3742] = {.lex_state = 82, .external_lex_state = 3},
  [3743] = {.lex_state = 83, .external_lex_state = 3},
  [3744] = {.lex_state = 83, .external_lex_state = 3},
  [3745] = {.lex_state = 78, .external_lex_state = 3},
  [3746] = {.lex_state = 83, .external_lex_state = 3},
  [3747] = {.lex_state = 83, .external_lex_state = 3},
  [3748] = {.lex_state = 78, .external_lex_state = 3},
  [3749] = {.lex_state = 83, .external_lex_state = 3},
  [3750] = {.lex_state = 78, .external_lex_state = 3},
  [3751] = {.lex_state = 83, .external_lex_state = 3},
  [3752] = {.lex_state = 78, .external_lex_state = 3},
  [3753] = {.lex_state = 82, .external_lex_state = 3},
  [3754] = {.lex_state = 83, .external_lex_state = 3},
  [3755] = {.lex_state = 83, .external_lex_state = 3},
  [3756] = {.lex_state = 83, .external_lex_state = 3},
  [3757] = {.lex_state = 75, .external_lex_state = 3},
  [3758] = {.lex_state = 78, .external_lex_state = 3},
  [3759] = {.lex_state = 75, .external_lex_state = 3},
  [3760] = {.lex_state = 78, .external_lex_state = 3},
  [3761] = {.lex_state = 84, .external_lex_state = 3},
  [3762] = {.lex_state = 78, .external_lex_state = 3},
  [3763] = {.lex_state = 75, .external_lex_state = 3},
  [3764] = {.lex_state = 78, .external_lex_state = 3},
  [3765] = {.lex_state = 76, .external_lex_state = 3},
  [3766] = {.lex_state = 78, .external_lex_state = 3},
  [3767] = {.lex_state = 78, .external_lex_state = 3},
  [3768] = {.lex_state = 84, .external_lex_state = 3},
  [3769] = {.lex_state = 83, .external_lex_state = 3},
  [3770] = {.lex_state = 75, .external_lex_state = 3},
  [3771] = {.lex_state = 78, .external_lex_state = 3},
  [3772] = {.lex_state = 75, .external_lex_state = 3},
  [3773] = {.lex_state = 82, .external_lex_state = 3},
  [3774] = {.lex_state = 78, .external_lex_state = 3},
  [3775] = {.lex_state = 76, .external_lex_state = 3},
  [3776] = {.lex_state = 78, .external_lex_state = 3},
  [3777] = {.lex_state = 78, .external_lex_state = 3},
  [3778] = {.lex_state = 75, .external_lex_state = 3},
  [3779] = {.lex_state = 75, .external_lex_state = 3},
  [3780] = {.lex_state = 75, .external_lex_state = 3},
  [3781] = {.lex_state = 75, .external_lex_state = 3},
  [3782] = {.lex_state = 75, .external_lex_state = 3},
  [3783] = {.lex_state = 84, .external_lex_state = 3},
  [3784] = {.lex_state = 84, .external_lex_state = 3},
  [3785] = {.lex_state = 84, .external_lex_state = 3},
  [3786] = {.lex_state = 78, .external_lex_state = 3},
  [3787] = {.lex_state = 84, .external_lex_state = 3},
  [3788] = {.lex_state = 82, .external_lex_state = 3},
  [3789] = {.lex_state = 84, .external_lex_state = 3},
  [3790] = {.lex_state = 78, .external_lex_state = 3},
  [3791] = {.lex_state = 84, .external_lex_state = 3},
  [3792] = {.lex_state = 78, .external_lex_state = 3},
  [3793] = {.lex_state = 75, .external_lex_state = 3},
  [3794] = {.lex_state = 75, .external_lex_state = 3},
  [3795] = {.lex_state = 83, .external_lex_state = 3},
  [3796] = {.lex_state = 75, .external_lex_state = 3},
  [3797] = {.lex_state = 75, .external_lex_state = 3},
  [3798] = {.lex_state = 75, .external_lex_state = 3},
  [3799] = {.lex_state = 75, .external_lex_state = 3},
  [3800] = {.lex_state = 75, .external_lex_state = 3},
  [3801] = {.lex_state = 75, .external_lex_state = 3},
  [3802] = {.lex_state = 83, .external_lex_state = 3},
  [3803] = {.lex_state = 75, .external_lex_state = 3},
  [3804] = {.lex_state = 83, .external_lex_state = 3},
  [3805] = {.lex_state = 75, .external_lex_state = 3},
  [3806] = {.lex_state = 83, .external_lex_state = 3},
  [3807] = {.lex_state = 83, .external_lex_state = 3},
  [3808] = {.lex_state = 82, .external_lex_state = 3},
  [3809] = {.lex_state = 83, .external_lex_state = 3},
  [3810] = {.lex_state = 82, .external_lex_state = 3},
  [3811] = {.lex_state = 83, .external_lex_state = 3},
  [3812] = {.lex_state = 83, .external_lex_state = 3},
  [3813] = {.lex_state = 82, .external_lex_state = 3},
  [3814] = {.lex_state = 84, .external_lex_state = 3},
  [3815] = {.lex_state = 75, .external_lex_state = 3},
  [3816] = {.lex_state = 75, .external_lex_state = 3},
  [3817] = {.lex_state = 75, .external_lex_state = 3},
  [3818] = {.lex_state = 75, .external_lex_state = 3},
  [3819] = {.lex_state = 83, .external_lex_state = 3},
  [3820] = {.lex_state = 75, .external_lex_state = 3},
  [3821] = {.lex_state = 83, .external_lex_state = 3},
  [3822] = {.lex_state = 75, .external_lex_state = 3},
  [3823] = {.lex_state = 75, .external_lex_state = 3},
  [3824] = {.lex_state = 75, .external_lex_state = 3},
  [3825] = {.lex_state = 75, .external_lex_state = 3},
  [3826] = {.lex_state = 83, .external_lex_state = 3},
  [3827] = {.lex_state = 84, .external_lex_state = 3},
  [3828] = {.lex_state = 84, .external_lex_state = 3},
  [3829] = {.lex_state = 24, .external_lex_state = 3},
  [3830] = {.lex_state = 24, .external_lex_state = 3},
  [3831] = {.lex_state = 84, .external_lex_state = 3},
  [3832] = {.lex_state = 84, .external_lex_state = 3},
  [3833] = {.lex_state = 24, .external_lex_state = 3},
  [3834] = {.lex_state = 76, .external_lex_state = 3},
  [3835] = {.lex_state = 24, .external_lex_state = 3},
  [3836] = {.lex_state = 76, .external_lex_state = 3},
  [3837] = {.lex_state = 76, .external_lex_state = 3},
  [3838] = {.lex_state = 76, .external_lex_state = 3},
  [3839] = {.lex_state = 76, .external_lex_state = 3},
  [3840] = {.lex_state = 76, .external_lex_state = 3},
  [3841] = {.lex_state = 76, .external_lex_state = 3},
  [3842] = {.lex_state = 76, .external_lex_state = 3},
  [3843] = {.lex_state = 76, .external_lex_state = 3},
  [3844] = {.lex_state = 24, .external_lex_state = 3},
  [3845] = {.lex_state = 24, .external_lex_state = 3},
  [3846] = {.lex_state = 76, .external_lex_state = 3},
  [3847] = {.lex_state = 24, .external_lex_state = 3},
  [3848] = {.lex_state = 24, .external_lex_state = 3},
  [3849] = {.lex_state = 24, .external_lex_state = 3},
  [3850] = {.lex_state = 24, .external_lex_state = 3},
  [3851] = {.lex_state = 76, .external_lex_state = 3},
  [3852] = {.lex_state = 84, .external_lex_state = 3},
  [3853] = {.lex_state = 76, .external_lex_state = 3},
  [3854] = {.lex_state = 84, .external_lex_state = 3},
  [3855] = {.lex_state = 84, .external_lex_state = 3},
  [3856] = {.lex_state = 84, .external_lex_state = 3},
  [3857] = {.lex_state = 84, .external_lex_state = 3},
  [3858] = {.lex_state = 24, .external_lex_state = 3},
  [3859] = {.lex_state = 84, .external_lex_state = 3},
  [3860] = {.lex_state = 84, .external_lex_state = 3},
  [3861] = {.lex_state = 24, .external_lex_state = 3},
  [3862] = {.lex_state = 76, .external_lex_state = 3},
  [3863] = {.lex_state = 84, .external_lex_state = 3},
  [3864] = {.lex_state = 84, .external_lex_state = 3},
  [3865] = {.lex_state = 84, .external_lex_state = 3},
  [3866] = {.lex_state = 84, .external_lex_state = 3},
  [3867] = {.lex_state = 76, .external_lex_state = 3},
  [3868] = {.lex_state = 84, .external_lex_state = 3},
  [3869] = {.lex_state = 84, .external_lex_state = 3},
  [3870] = {.lex_state = 24, .external_lex_state = 3},
  [3871] = {.lex_state = 84, .external_lex_state = 3},
  [3872] = {.lex_state = 24, .external_lex_state = 3},
  [3873] = {.lex_state = 84, .external_lex_state = 3},
  [3874] = {.lex_state = 84, .external_lex_state = 3},
  [3875] = {.lex_state = 24, .external_lex_state = 3},
  [3876] = {.lex_state = 24, .external_lex_state = 3},
  [3877] = {.lex_state = 84, .external_lex_state = 3},
  [3878] = {.lex_state = 24, .external_lex_state = 3},
  [3879] = {.lex_state = 24, .external_lex_state = 3},
  [3880] = {.lex_state = 84, .external_lex_state = 3},
  [3881] = {.lex_state = 84, .external_lex_state = 3},
  [3882] = {.lex_state = 76, .external_lex_state = 3},
  [3883] = {.lex_state = 76, .external_lex_state = 3},
  [3884] = {.lex_state = 76, .external_lex_state = 3},
  [3885] = {.lex_state = 84, .external_lex_state = 3},
  [3886] = {.lex_state = 24, .external_lex_state = 3},
  [3887] = {.lex_state = 76, .external_lex_state = 3},
  [3888] = {.lex_state = 76, .external_lex_state = 3},
  [3889] = {.lex_state = 76, .external_lex_state = 3},
  [3890] = {.lex_state = 24, .external_lex_state = 3},
  [3891] = {.lex_state = 24, .external_lex_state = 3},
  [3892] = {.lex_state = 76, .external_lex_state = 3},
  [3893] = {.lex_state = 76, .external_lex_state = 3},
  [3894] = {.lex_state = 24, .external_lex_state = 3},
  [3895] = {.lex_state = 84, .external_lex_state = 3},
  [3896] = {.lex_state = 24, .external_lex_state = 3},
  [3897] = {.lex_state = 84, .external_lex_state = 3},
  [3898] = {.lex_state = 84, .external_lex_state = 3},
  [3899] = {.lex_state = 76, .external_lex_state = 3},
  [3900] = {.lex_state = 24, .external_lex_state = 3},
  [3901] = {.lex_state = 76, .external_lex_state = 3},
  [3902] = {.lex_state = 24, .external_lex_state = 3},
  [3903] = {.lex_state = 24, .external_lex_state = 3},
  [3904] = {.lex_state = 24, .external_lex_state = 3},
  [3905] = {.lex_state = 24, .external_lex_state = 3},
  [3906] = {.lex_state = 24, .external_lex_state = 3},
  [3907] = {.lex_state = 76, .external_lex_state = 3},
  [3908] = {.lex_state = 76, .external_lex_state = 3},
  [3909] = {.lex_state = 24, .external_lex_state = 3},
  [3910] = {.lex_state = 76, .external_lex_state = 3},
  [3911] = {.lex_state = 76, .external_lex_state = 3},
  [3912] = {.lex_state = 24, .external_lex_state = 3},
  [3913] = {.lex_state = 84, .external_lex_state = 3},
  [3914] = {.lex_state = 84, .external_lex_state = 3},
  [3915] = {.lex_state = 84, .external_lex_state = 3},
  [3916] = {.lex_state = 24, .external_lex_state = 3},
  [3917] = {.lex_state = 84, .external_lex_state = 3},
  [3918] = {.lex_state = 24, .external_lex_state = 3},
  [3919] = {.lex_state = 76, .external_lex_state = 3},
  [3920] = {.lex_state = 76, .external_lex_state = 3},
  [3921] = {.lex_state = 84, .external_lex_state = 3},
  [3922] = {.lex_state = 24, .external_lex_state = 3},
  [3923] = {.lex_state = 84, .external_lex_state = 3},
  [3924] = {.lex_state = 84, .external_lex_state = 3},
  [3925] = {.lex_state = 24, .external_lex_state = 3},
  [3926] = {.lex_state = 84, .external_lex_state = 3},
  [3927] = {.lex_state = 24, .external_lex_state = 3},
  [3928] = {.lex_state = 24, .external_lex_state = 3},
  [3929] = {.lex_state = 76, .external_lex_state = 3},
  [3930] = {.lex_state = 24, .external_lex_state = 3},
  [3931] = {.lex_state = 24, .external_lex_state = 3},
  [3932] = {.lex_state = 76, .external_lex_state = 3},
  [3933] = {.lex_state = 24, .external_lex_state = 3},
  [3934] = {.lex_state = 24, .external_lex_state = 3},
  [3935] = {.lex_state = 24, .external_lex_state = 3},
  [3936] = {.lex_state = 24, .external_lex_state = 3},
  [3937] = {.lex_state = 76, .external_lex_state = 3},
  [3938] = {.lex_state = 24, .external_lex_state = 3},
  [3939] = {.lex_state = 24, .external_lex_state = 3},
  [3940] = {.lex_state = 24, .external_lex_state = 3},
  [3941] = {.lex_state = 24, .external_lex_state = 3},
  [3942] = {.lex_state = 24, .external_lex_state = 3},
  [3943] = {.lex_state = 24, .external_lex_state = 3},
  [3944] = {.lex_state = 24, .external_lex_state = 3},
  [3945] = {.lex_state = 24, .external_lex_state = 3},
  [3946] = {.lex_state = 24, .external_lex_state = 3},
  [3947] = {.lex_state = 24, .external_lex_state = 3},
  [3948] = {.lex_state = 76, .external_lex_state = 3},
  [3949] = {.lex_state = 84, .external_lex_state = 3},
  [3950] = {.lex_state = 24, .external_lex_state = 3},
  [3951] = {.lex_state = 24, .external_lex_state = 3},
  [3952] = {.lex_state = 24, .external_lex_state = 3},
  [3953] = {.lex_state = 76, .external_lex_state = 3},
  [3954] = {.lex_state = 24, .external_lex_state = 3},
  [3955] = {.lex_state = 24, .external_lex_state = 3},
  [3956] = {.lex_state = 24, .external_lex_state = 3},
  [3957] = {.lex_state = 24, .external_lex_state = 3},
  [3958] = {.lex_state = 76, .external_lex_state = 3},
  [3959] = {.lex_state = 24, .external_lex_state = 3},
  [3960] = {.lex_state = 24, .external_lex_state = 3},
  [3961] = {.lex_state = 76, .external_lex_state = 3},
  [3962] = {.lex_state = 24, .external_lex_state = 3},
  [3963] = {.lex_state = 24, .external_lex_state = 3},
  [3964] = {.lex_state = 24, .external_lex_state = 3},
  [3965] = {.lex_state = 126, .external_lex_state = 3},
  [3966] = {.lex_state = 24, .external_lex_state = 3},
  [3967] = {.lex_state = 24, .external_lex_state = 3},
  [3968] = {.lex_state = 76, .external_lex_state = 3},
  [3969] = {.lex_state = 24, .external_lex_state = 3},
  [3970] = {.lex_state = 24, .external_lex_state = 3},
  [3971] = {.lex_state = 24, .external_lex_state = 3},
  [3972] = {.lex_state = 76, .external_lex_state = 3},
  [3973] = {.lex_state = 76, .external_lex_state = 3},
  [3974] = {.lex_state = 76, .external_lex_state = 3},
  [3975] = {.lex_state = 24, .external_lex_state = 3},
  [3976] = {.lex_state = 76, .external_lex_state = 3},
  [3977] = {.lex_state = 24, .external_lex_state = 3},
  [3978] = {.lex_state = 76, .external_lex_state = 3},
  [3979] = {.lex_state = 76, .external_lex_state = 3},
  [3980] = {.lex_state = 24, .external_lex_state = 3},
  [3981] = {.lex_state = 24, .external_lex_state = 3},
  [3982] = {.lex_state = 24, .external_lex_state = 3},
  [3983] = {.lex_state = 76, .external_lex_state = 3},
  [3984] = {.lex_state = 24, .external_lex_state = 3},
  [3985] = {.lex_state = 76, .external_lex_state = 3},
  [3986] = {.lex_state = 76, .external_lex_state = 3},
  [3987] = {.lex_state = 24, .external_lex_state = 3},
  [3988] = {.lex_state = 76, .external_lex_state = 3},
  [3989] = {.lex_state = 84, .external_lex_state = 3},
  [3990] = {.lex_state = 24, .external_lex_state = 3},
  [3991] = {.lex_state = 76, .external_lex_state = 3},
  [3992] = {.lex_state = 80, .external_lex_state = 3},
  [3993] = {.lex_state = 24, .external_lex_state = 3},
  [3994] = {.lex_state = 80, .external_lex_state = 3},
  [3995] = {.lex_state = 76, .external_lex_state = 3},
  [3996] = {.lex_state = 24, .external_lex_state = 3},
  [3997] = {.lex_state = 24, .external_lex_state = 3},
  [3998] = {.lex_state = 24, .external_lex_state = 3},
  [3999] = {.lex_state = 76, .external_lex_state = 3},
  [4000] = {.lex_state = 76, .external_lex_state = 3},
  [4001] = {.lex_state = 24, .external_lex_state = 3},
  [4002] = {.lex_state = 76, .external_lex_state = 3},
  [4003] = {.lex_state = 76, .external_lex_state = 3},
  [4004] = {.lex_state = 24, .external_lex_state = 3},
  [4005] = {.lex_state = 24, .external_lex_state = 3},
  [4006] = {.lex_state = 76, .external_lex_state = 3},
  [4007] = {.lex_state = 24, .external_lex_state = 3},
  [4008] = {.lex_state = 24, .external_lex_state = 3},
  [4009] = {.lex_state = 24, .external_lex_state = 3},
  [4010] = {.lex_state = 76, .external_lex_state = 3},
  [4011] = {.lex_state = 24, .external_lex_state = 3},
  [4012] = {.lex_state = 24, .external_lex_state = 3},
  [4013] = {.lex_state = 76, .external_lex_state = 3},
  [4014] = {.lex_state = 84, .external_lex_state = 3},
  [4015] = {.lex_state = 84, .external_lex_state = 3},
  [4016] = {.lex_state = 24, .external_lex_state = 3},
  [4017] = {.lex_state = 84, .external_lex_state = 3},
  [4018] = {.lex_state = 84, .external_lex_state = 3},
  [4019] = {.lex_state = 84, .external_lex_state = 3},
  [4020] = {.lex_state = 24, .external_lex_state = 3},
  [4021] = {.lex_state = 24, .external_lex_state = 3},
  [4022] = {.lex_state = 24, .external_lex_state = 3},
  [4023] = {.lex_state = 24, .external_lex_state = 3},
  [4024] = {.lex_state = 84, .external_lex_state = 3},
  [4025] = {.lex_state = 76, .external_lex_state = 3},
  [4026] = {.lex_state = 24, .external_lex_state = 3},
  [4027] = {.lex_state = 84, .external_lex_state = 3},
  [4028] = {.lex_state = 84, .external_lex_state = 3},
  [4029] = {.lex_state = 84, .external_lex_state = 3},
  [4030] = {.lex_state = 84, .external_lex_state = 3},
  [4031] = {.lex_state = 24, .external_lex_state = 3},
  [4032] = {.lex_state = 24, .external_lex_state = 3},
  [4033] = {.lex_state = 84, .external_lex_state = 3},
  [4034] = {.lex_state = 84, .external_lex_state = 3},
  [4035] = {.lex_state = 24, .external_lex_state = 3},
  [4036] = {.lex_state = 24, .external_lex_state = 3},
  [4037] = {.lex_state = 84, .external_lex_state = 3},
  [4038] = {.lex_state = 84, .external_lex_state = 3},
  [4039] = {.lex_state = 84, .external_lex_state = 3},
  [4040] = {.lex_state = 84, .external_lex_state = 3},
  [4041] = {.lex_state = 84, .external_lex_state = 3},
  [4042] = {.lex_state = 84, .external_lex_state = 3},
  [4043] = {.lex_state = 84, .external_lex_state = 3},
  [4044] = {.lex_state = 84, .external_lex_state = 3},
  [4045] = {.lex_state = 84, .external_lex_state = 3},
  [4046] = {.lex_state = 84, .external_lex_state = 3},
  [4047] = {.lex_state = 84, .external_lex_state = 3},
  [4048] = {.lex_state = 84, .external_lex_state = 3},
  [4049] = {.lex_state = 84, .external_lex_state = 3},
  [4050] = {.lex_state = 84, .external_lex_state = 3},
  [4051] = {.lex_state = 80, .external_lex_state = 3},
  [4052] = {.lex_state = 84, .external_lex_state = 3},
  [4053] = {.lex_state = 84, .external_lex_state = 3},
  [4054] = {.lex_state = 84, .external_lex_state = 3},
  [4055] = {.lex_state = 84, .external_lex_state = 3},
  [4056] = {.lex_state = 84, .external_lex_state = 3},
  [4057] = {.lex_state = 76, .external_lex_state = 3},
  [4058] = {.lex_state = 84, .external_lex_state = 3},
  [4059] = {.lex_state = 24, .external_lex_state = 3},
  [4060] = {.lex_state = 84, .external_lex_state = 3},
  [4061] = {.lex_state = 84, .external_lex_state = 3},
  [4062] = {.lex_state = 80, .external_lex_state = 3},
  [4063] = {.lex_state = 80, .external_lex_state = 3},
  [4064] = {.lex_state = 80, .external_lex_state = 3},
  [4065] = {.lex_state = 84, .external_lex_state = 3},
  [4066] = {.lex_state = 80, .external_lex_state = 3},
  [4067] = {.lex_state = 80, .external_lex_state = 3},
  [4068] = {.lex_state = 80, .external_lex_state = 3},
  [4069] = {.lex_state = 24, .external_lex_state = 3},
  [4070] = {.lex_state = 85, .external_lex_state = 3},
  [4071] = {.lex_state = 24, .external_lex_state = 3},
  [4072] = {.lex_state = 85, .external_lex_state = 3},
  [4073] = {.lex_state = 24, .external_lex_state = 3},
  [4074] = {.lex_state = 84, .external_lex_state = 3},
  [4075] = {.lex_state = 76, .external_lex_state = 3},
  [4076] = {.lex_state = 76, .external_lex_state = 3},
  [4077] = {.lex_state = 24, .external_lex_state = 3},
  [4078] = {.lex_state = 84, .external_lex_state = 3},
  [4079] = {.lex_state = 24, .external_lex_state = 3},
  [4080] = {.lex_state = 80, .external_lex_state = 3},
  [4081] = {.lex_state = 76, .external_lex_state = 3},
  [4082] = {.lex_state = 80, .external_lex_state = 3},
  [4083] = {.lex_state = 84, .external_lex_state = 3},
  [4084] = {.lex_state = 76, .external_lex_state = 3},
  [4085] = {.lex_state = 76, .external_lex_state = 3},
  [4086] = {.lex_state = 76, .external_lex_state = 3},
  [4087] = {.lex_state = 76, .external_lex_state = 3},
  [4088] = {.lex_state = 84, .external_lex_state = 3},
  [4089] = {.lex_state = 76, .external_lex_state = 3},
  [4090] = {.lex_state = 76, .external_lex_state = 3},
  [4091] = {.lex_state = 76, .external_lex_state = 3},
  [4092] = {.lex_state = 76, .external_lex_state = 3},
  [4093] = {.lex_state = 76, .external_lex_state = 3},
  [4094] = {.lex_state = 76, .external_lex_state = 3},
  [4095] = {.lex_state = 76, .external_lex_state = 3},
  [4096] = {.lex_state = 24, .external_lex_state = 3},
  [4097] = {.lex_state = 24, .external_lex_state = 3},
  [4098] = {.lex_state = 24, .external_lex_state = 3},
  [4099] = {.lex_state = 24, .external_lex_state = 3},
  [4100] = {.lex_state = 76, .external_lex_state = 3},
  [4101] = {.lex_state = 24, .external_lex_state = 3},
  [4102] = {.lex_state = 24, .external_lex_state = 3},
  [4103] = {.lex_state = 85, .external_lex_state = 3},
  [4104] = {.lex_state = 76, .external_lex_state = 3},
  [4105] = {.lex_state = 24, .external_lex_state = 3},
  [4106] = {.lex_state = 24, .external_lex_state = 3},
  [4107] = {.lex_state = 76, .external_lex_state = 3},
  [4108] = {.lex_state = 76, .external_lex_state = 3},
  [4109] = {.lex_state = 85, .external_lex_state = 3},
  [4110] = {.lex_state = 85, .external_lex_state = 3},
  [4111] = {.lex_state = 85, .external_lex_state = 3},
  [4112] = {.lex_state = 85, .external_lex_state = 3},
  [4113] = {.lex_state = 85, .external_lex_state = 3},
  [4114] = {.lex_state = 85, .external_lex_state = 3},
  [4115] = {.lex_state = 122, .external_lex_state = 3},
  [4116] = {.lex_state = 24, .external_lex_state = 3},
  [4117] = {.lex_state = 24, .external_lex_state = 3},
  [4118] = {.lex_state = 24, .external_lex_state = 3},
  [4119] = {.lex_state = 24, .external_lex_state = 3},
  [4120] = {.lex_state = 85, .external_lex_state = 3},
  [4121] = {.lex_state = 85, .external_lex_state = 3},
  [4122] = {.lex_state = 76, .external_lex_state = 3},
  [4123] = {.lex_state = 84, .external_lex_state = 3},
  [4124] = {.lex_state = 84, .external_lex_state = 3},
  [4125] = {.lex_state = 80, .external_lex_state = 3},
  [4126] = {.lex_state = 24, .external_lex_state = 3},
  [4127] = {.lex_state = 24, .external_lex_state = 3},
  [4128] = {.lex_state = 79, .external_lex_state = 3},
  [4129] = {.lex_state = 24, .external_lex_state = 3},
  [4130] = {.lex_state = 123, .external_lex_state = 3},
  [4131] = {.lex_state = 79, .external_lex_state = 3},
  [4132] = {.lex_state = 80, .external_lex_state = 3},
  [4133] = {.lex_state = 86, .external_lex_state = 3},
  [4134] = {.lex_state = 85, .external_lex_state = 3},
  [4135] = {.lex_state = 24, .external_lex_state = 3},
  [4136] = {.lex_state = 79, .external_lex_state = 3},
  [4137] = {.lex_state = 24, .external_lex_state = 3},
  [4138] = {.lex_state = 24, .external_lex_state = 3},
  [4139] = {.lex_state = 6, .external_lex_state = 3},
  [4140] = {.lex_state = 85, .external_lex_state = 3},
  [4141] = {.lex_state = 24, .external_lex_state = 3},
  [4142] = {.lex_state = 85, .external_lex_state = 3},
  [4143] = {.lex_state = 24, .external_lex_state = 3},
  [4144] = {.lex_state = 24, .external_lex_state = 3},
  [4145] = {.lex_state = 79, .external_lex_state = 3},
  [4146] = {.lex_state = 24, .external_lex_state = 3},
  [4147] = {.lex_state = 24, .external_lex_state = 3},
  [4148] = {.lex_state = 85, .external_lex_state = 3},
  [4149] = {.lex_state = 24, .external_lex_state = 3},
  [4150] = {.lex_state = 24, .external_lex_state = 3},
  [4151] = {.lex_state = 6, .external_lex_state = 3},
  [4152] = {.lex_state = 24, .external_lex_state = 3},
  [4153] = {.lex_state = 85, .external_lex_state = 3},
  [4154] = {.lex_state = 120, .external_lex_state = 3},
  [4155] = {.lex_state = 80, .external_lex_state = 3},
  [4156] = {.lex_state = 24, .external_lex_state = 3},
  [4157] = {.lex_state = 6, .external_lex_state = 3},
  [4158] = {.lex_state = 24, .external_lex_state = 3},
  [4159] = {.lex_state = 24, .external_lex_state = 3},
  [4160] = {.lex_state = 24, .external_lex_state = 3},
  [4161] = {.lex_state = 122, .external_lex_state = 3},
  [4162] = {.lex_state = 80, .external_lex_state = 3},
  [4163] = {.lex_state = 80, .external_lex_state = 3},
  [4164] = {.lex_state = 24, .external_lex_state = 3},
  [4165] = {.lex_state = 6, .external_lex_state = 3},
  [4166] = {.lex_state = 126, .external_lex_state = 3},
  [4167] = {.lex_state = 24, .external_lex_state = 3},
  [4168] = {.lex_state = 80, .external_lex_state = 3},
  [4169] = {.lex_state = 85, .external_lex_state = 3},
  [4170] = {.lex_state = 80, .external_lex_state = 3},
  [4171] = {.lex_state = 80, .external_lex_state = 3},
  [4172] = {.lex_state = 80, .external_lex_state = 3},
  [4173] = {.lex_state = 80, .external_lex_state = 3},
  [4174] = {.lex_state = 79, .external_lex_state = 3},
  [4175] = {.lex_state = 127, .external_lex_state = 3},
  [4176] = {.lex_state = 24, .external_lex_state = 3},
  [4177] = {.lex_state = 24, .external_lex_state = 3},
  [4178] = {.lex_state = 24, .external_lex_state = 3},
  [4179] = {.lex_state = 6, .external_lex_state = 3},
  [4180] = {.lex_state = 86, .external_lex_state = 3},
  [4181] = {.lex_state = 80, .external_lex_state = 3},
  [4182] = {.lex_state = 80, .external_lex_state = 3},
  [4183] = {.lex_state = 80, .external_lex_state = 3},
  [4184] = {.lex_state = 85, .external_lex_state = 3},
  [4185] = {.lex_state = 24, .external_lex_state = 3},
  [4186] = {.lex_state = 24, .external_lex_state = 3},
  [4187] = {.lex_state = 24, .external_lex_state = 3},
  [4188] = {.lex_state = 6, .external_lex_state = 3},
  [4189] = {.lex_state = 80, .external_lex_state = 3},
  [4190] = {.lex_state = 80, .external_lex_state = 3},
  [4191] = {.lex_state = 80, .external_lex_state = 3},
  [4192] = {.lex_state = 85, .external_lex_state = 3},
  [4193] = {.lex_state = 85, .external_lex_state = 3},
  [4194] = {.lex_state = 24, .external_lex_state = 3},
  [4195] = {.lex_state = 80, .external_lex_state = 3},
  [4196] = {.lex_state = 80, .external_lex_state = 3},
  [4197] = {.lex_state = 80, .external_lex_state = 3},
  [4198] = {.lex_state = 80, .external_lex_state = 3},
  [4199] = {.lex_state = 80, .external_lex_state = 3},
  [4200] = {.lex_state = 80, .external_lex_state = 3},
  [4201] = {.lex_state = 80, .external_lex_state = 3},
  [4202] = {.lex_state = 80, .external_lex_state = 3},
  [4203] = {.lex_state = 80, .external_lex_state = 3},
  [4204] = {.lex_state = 24, .external_lex_state = 3},
  [4205] = {.lex_state = 85, .external_lex_state = 3},
  [4206] = {.lex_state = 80, .external_lex_state = 3},
  [4207] = {.lex_state = 80, .external_lex_state = 3},
  [4208] = {.lex_state = 80, .external_lex_state = 3},
  [4209] = {.lex_state = 80, .external_lex_state = 3},
  [4210] = {.lex_state = 80, .external_lex_state = 3},
  [4211] = {.lex_state = 86, .external_lex_state = 3},
  [4212] = {.lex_state = 80, .external_lex_state = 3},
  [4213] = {.lex_state = 85, .external_lex_state = 3},
  [4214] = {.lex_state = 85, .external_lex_state = 3},
  [4215] = {.lex_state = 24, .external_lex_state = 3},
  [4216] = {.lex_state = 85, .external_lex_state = 3},
  [4217] = {.lex_state = 85, .external_lex_state = 3},
  [4218] = {.lex_state = 80, .external_lex_state = 3},
  [4219] = {.lex_state = 24, .external_lex_state = 3},
  [4220] = {.lex_state = 80, .external_lex_state = 3},
  [4221] = {.lex_state = 80, .external_lex_state = 3},
  [4222] = {.lex_state = 80, .external_lex_state = 3},
  [4223] = {.lex_state = 79, .external_lex_state = 3},
  [4224] = {.lex_state = 80, .external_lex_state = 3},
  [4225] = {.lex_state = 80, .external_lex_state = 3},
  [4226] = {.lex_state = 80, .external_lex_state = 3},
  [4227] = {.lex_state = 80, .external_lex_state = 3},
  [4228] = {.lex_state = 80, .external_lex_state = 3},
  [4229] = {.lex_state = 80, .external_lex_state = 3},
  [4230] = {.lex_state = 80, .external_lex_state = 3},
  [4231] = {.lex_state = 80, .external_lex_state = 3},
  [4232] = {.lex_state = 24, .external_lex_state = 3},
  [4233] = {.lex_state = 24, .external_lex_state = 3},
  [4234] = {.lex_state = 85, .external_lex_state = 3},
  [4235] = {.lex_state = 80, .external_lex_state = 3},
  [4236] = {.lex_state = 80, .external_lex_state = 3},
  [4237] = {.lex_state = 80, .external_lex_state = 3},
  [4238] = {.lex_state = 24, .external_lex_state = 3},
  [4239] = {.lex_state = 80, .external_lex_state = 3},
  [4240] = {.lex_state = 85, .external_lex_state = 3},
  [4241] = {.lex_state = 6, .external_lex_state = 3},
  [4242] = {.lex_state = 24, .external_lex_state = 3},
  [4243] = {.lex_state = 126, .external_lex_state = 3},
  [4244] = {.lex_state = 24, .external_lex_state = 3},
  [4245] = {.lex_state = 80, .external_lex_state = 3},
  [4246] = {.lex_state = 85, .external_lex_state = 3},
  [4247] = {.lex_state = 24, .external_lex_state = 3},
  [4248] = {.lex_state = 85, .external_lex_state = 3},
  [4249] = {.lex_state = 24, .external_lex_state = 3},
  [4250] = {.lex_state = 6, .external_lex_state = 3},
  [4251] = {.lex_state = 85, .external_lex_state = 3},
  [4252] = {.lex_state = 86, .external_lex_state = 3},
  [4253] = {.lex_state = 24, .external_lex_state = 3},
  [4254] = {.lex_state = 24, .external_lex_state = 3},
  [4255] = {.lex_state = 24, .external_lex_state = 3},
  [4256] = {.lex_state = 85, .external_lex_state = 3},
  [4257] = {.lex_state = 80, .external_lex_state = 3},
  [4258] = {.lex_state = 80, .external_lex_state = 3},
  [4259] = {.lex_state = 24, .external_lex_state = 3},
  [4260] = {.lex_state = 24, .external_lex_state = 3},
  [4261] = {.lex_state = 85, .external_lex_state = 3},
  [4262] = {.lex_state = 85, .external_lex_state = 3},
  [4263] = {.lex_state = 24, .external_lex_state = 3},
  [4264] = {.lex_state = 80, .external_lex_state = 3},
  [4265] = {.lex_state = 85, .external_lex_state = 3},
  [4266] = {.lex_state = 80, .external_lex_state = 3},
  [4267] = {.lex_state = 24, .external_lex_state = 3},
  [4268] = {.lex_state = 24, .external_lex_state = 3},
  [4269] = {.lex_state = 80, .external_lex_state = 3},
  [4270] = {.lex_state = 24, .external_lex_state = 3},
  [4271] = {.lex_state = 6, .external_lex_state = 3},
  [4272] = {.lex_state = 86, .external_lex_state = 3},
  [4273] = {.lex_state = 86, .external_lex_state = 3},
  [4274] = {.lex_state = 6, .external_lex_state = 3},
  [4275] = {.lex_state = 86, .external_lex_state = 3},
  [4276] = {.lex_state = 80, .external_lex_state = 3},
  [4277] = {.lex_state = 24, .external_lex_state = 3},
  [4278] = {.lex_state = 6, .external_lex_state = 3},
  [4279] = {.lex_state = 85, .external_lex_state = 3},
  [4280] = {.lex_state = 79, .external_lex_state = 3},
  [4281] = {.lex_state = 80, .external_lex_state = 3},
  [4282] = {.lex_state = 80, .external_lex_state = 3},
  [4283] = {.lex_state = 24, .external_lex_state = 3},
  [4284] = {.lex_state = 24, .external_lex_state = 3},
  [4285] = {.lex_state = 85, .external_lex_state = 3},
  [4286] = {.lex_state = 80, .external_lex_state = 3},
  [4287] = {.lex_state = 80, .external_lex_state = 3},
  [4288] = {.lex_state = 80, .external_lex_state = 3},
  [4289] = {.lex_state = 80, .external_lex_state = 3},
  [4290] = {.lex_state = 80, .external_lex_state = 3},
  [4291] = {.lex_state = 80, .external_lex_state = 3},
  [4292] = {.lex_state = 24, .external_lex_state = 3},
  [4293] = {.lex_state = 24, .external_lex_state = 3},
  [4294] = {.lex_state = 24, .external_lex_state = 3},
  [4295] = {.lex_state = 85, .external_lex_state = 3},
  [4296] = {.lex_state = 24, .external_lex_state = 3},
  [4297] = {.lex_state = 24, .external_lex_state = 3},
  [4298] = {.lex_state = 85, .external_lex_state = 3},
  [4299] = {.lex_state = 24, .external_lex_state = 3},
  [4300] = {.lex_state = 24, .external_lex_state = 3},
  [4301] = {.lex_state = 86, .external_lex_state = 3},
  [4302] = {.lex_state = 86, .external_lex_state = 3},
  [4303] = {.lex_state = 85, .external_lex_state = 3},
  [4304] = {.lex_state = 86, .external_lex_state = 3},
  [4305] = {.lex_state = 24, .external_lex_state = 3},
  [4306] = {.lex_state = 24, .external_lex_state = 3},
  [4307] = {.lex_state = 24, .external_lex_state = 3},
  [4308] = {.lex_state = 24, .external_lex_state = 3},
  [4309] = {.lex_state = 6, .external_lex_state = 3},
  [4310] = {.lex_state = 85, .external_lex_state = 3},
  [4311] = {.lex_state = 24, .external_lex_state = 3},
  [4312] = {.lex_state = 24, .external_lex_state = 3},
  [4313] = {.lex_state = 24, .external_lex_state = 3},
  [4314] = {.lex_state = 24, .external_lex_state = 3},
  [4315] = {.lex_state = 6, .external_lex_state = 3},
  [4316] = {.lex_state = 79, .external_lex_state = 3},
  [4317] = {.lex_state = 6, .external_lex_state = 3},
  [4318] = {.lex_state = 24, .external_lex_state = 3},
  [4319] = {.lex_state = 24, .external_lex_state = 3},
  [4320] = {.lex_state = 24, .external_lex_state = 3},
  [4321] = {.lex_state = 24, .external_lex_state = 3},
  [4322] = {.lex_state = 85, .external_lex_state = 3},
  [4323] = {.lex_state = 85, .external_lex_state = 3},
  [4324] = {.lex_state = 24, .external_lex_state = 3},
  [4325] = {.lex_state = 122, .external_lex_state = 3},
  [4326] = {.lex_state = 85, .external_lex_state = 3},
  [4327] = {.lex_state = 85, .external_lex_state = 3},
  [4328] = {.lex_state = 80, .external_lex_state = 3},
  [4329] = {.lex_state = 85, .external_lex_state = 3},
  [4330] = {.lex_state = 85, .external_lex_state = 3},
  [4331] = {.lex_state = 85, .external_lex_state = 3},
  [4332] = {.lex_state = 80, .external_lex_state = 3},
  [4333] = {.lex_state = 24, .external_lex_state = 3},
  [4334] = {.lex_state = 6, .external_lex_state = 3},
  [4335] = {.lex_state = 6, .external_lex_state = 3},
  [4336] = {.lex_state = 6, .external_lex_state = 3},
  [4337] = {.lex_state = 24, .external_lex_state = 3},
  [4338] = {.lex_state = 6, .external_lex_state = 3},
  [4339] = {.lex_state = 24, .external_lex_state = 3},
  [4340] = {.lex_state = 85, .external_lex_state = 3},
  [4341] = {.lex_state = 85, .external_lex_state = 3},
  [4342] = {.lex_state = 85, .external_lex_state = 3},
  [4343] = {.lex_state = 85, .external_lex_state = 3},
  [4344] = {.lex_state = 85, .external_lex_state = 3},
  [4345] = {.lex_state = 85, .external_lex_state = 3},
  [4346] = {.lex_state = 128, .external_lex_state = 3},
  [4347] = {.lex_state = 85, .external_lex_state = 3},
  [4348] = {.lex_state = 85, .external_lex_state = 3},
  [4349] = {.lex_state = 85, .external_lex_state = 3},
  [4350] = {.lex_state = 85, .external_lex_state = 3},
  [4351] = {.lex_state = 24, .external_lex_state = 3},
  [4352] = {.lex_state = 85, .external_lex_state = 3},
  [4353] = {.lex_state = 85, .external_lex_state = 3},
  [4354] = {.lex_state = 85, .external_lex_state = 3},
  [4355] = {.lex_state = 85, .external_lex_state = 3},
  [4356] = {.lex_state = 24, .external_lex_state = 3},
  [4357] = {.lex_state = 80, .external_lex_state = 3},
  [4358] = {.lex_state = 80, .external_lex_state = 3},
  [4359] = {.lex_state = 85, .external_lex_state = 3},
  [4360] = {.lex_state = 80, .external_lex_state = 3},
  [4361] = {.lex_state = 85, .external_lex_state = 3},
  [4362] = {.lex_state = 24, .external_lex_state = 3},
  [4363] = {.lex_state = 85, .external_lex_state = 3},
  [4364] = {.lex_state = 85, .external_lex_state = 3},
  [4365] = {.lex_state = 85, .external_lex_state = 3},
  [4366] = {.lex_state = 85, .external_lex_state = 3},
  [4367] = {.lex_state = 85, .external_lex_state = 3},
  [4368] = {.lex_state = 85, .external_lex_state = 3},
  [4369] = {.lex_state = 85, .external_lex_state = 3},
  [4370] = {.lex_state = 85, .external_lex_state = 3},
  [4371] = {.lex_state = 85, .external_lex_state = 3},
  [4372] = {.lex_state = 85, .external_lex_state = 3},
  [4373] = {.lex_state = 80, .external_lex_state = 3},
  [4374] = {.lex_state = 24, .external_lex_state = 3},
  [4375] = {.lex_state = 24, .external_lex_state = 3},
  [4376] = {.lex_state = 85, .external_lex_state = 3},
  [4377] = {.lex_state = 85, .external_lex_state = 3},
  [4378] = {.lex_state = 85, .external_lex_state = 3},
  [4379] = {.lex_state = 85, .external_lex_state = 3},
  [4380] = {.lex_state = 80, .external_lex_state = 3},
  [4381] = {.lex_state = 85, .external_lex_state = 3},
  [4382] = {.lex_state = 80, .external_lex_state = 3},
  [4383] = {.lex_state = 85, .external_lex_state = 3},
  [4384] = {.lex_state = 80, .external_lex_state = 3},
  [4385] = {.lex_state = 85, .external_lex_state = 3},
  [4386] = {.lex_state = 24, .external_lex_state = 3},
  [4387] = {.lex_state = 24, .external_lex_state = 3},
  [4388] = {.lex_state = 6, .external_lex_state = 3},
  [4389] = {.lex_state = 80, .external_lex_state = 3},
  [4390] = {.lex_state = 24, .external_lex_state = 3},
  [4391] = {.lex_state = 85, .external_lex_state = 3},
  [4392] = {.lex_state = 24, .external_lex_state = 3},
  [4393] = {.lex_state = 85, .external_lex_state = 3},
  [4394] = {.lex_state = 24, .external_lex_state = 3},
  [4395] = {.lex_state = 6, .external_lex_state = 3},
  [4396] = {.lex_state = 80, .external_lex_state = 3},
  [4397] = {.lex_state = 85, .external_lex_state = 3},
  [4398] = {.lex_state = 24, .external_lex_state = 3},
  [4399] = {.lex_state = 6, .external_lex_state = 3},
  [4400] = {.lex_state = 86, .external_lex_state = 3},
  [4401] = {.lex_state = 80, .external_lex_state = 3},
  [4402] = {.lex_state = 79, .external_lex_state = 3},
  [4403] = {.lex_state = 79, .external_lex_state = 3},
  [4404] = {.lex_state = 80, .external_lex_state = 3},
  [4405] = {.lex_state = 79, .external_lex_state = 3},
  [4406] = {.lex_state = 85, .external_lex_state = 3},
  [4407] = {.lex_state = 24, .external_lex_state = 3},
  [4408] = {.lex_state = 80, .external_lex_state = 3},
  [4409] = {.lex_state = 80, .external_lex_state = 3},
  [4410] = {.lex_state = 85, .external_lex_state = 3},
  [4411] = {.lex_state = 85, .external_lex_state = 3},
  [4412] = {.lex_state = 85, .external_lex_state = 3},
  [4413] = {.lex_state = 85, .external_lex_state = 3},
  [4414] = {.lex_state = 85, .external_lex_state = 3},
  [4415] = {.lex_state = 80, .external_lex_state = 3},
  [4416] = {.lex_state = 86, .external_lex_state = 3},
  [4417] = {.lex_state = 24, .external_lex_state = 3},
  [4418] = {.lex_state = 79, .external_lex_state = 3},
  [4419] = {.lex_state = 86, .external_lex_state = 3},
  [4420] = {.lex_state = 24, .external_lex_state = 3},
  [4421] = {.lex_state = 79, .external_lex_state = 3},
  [4422] = {.lex_state = 79, .external_lex_state = 3},
  [4423] = {.lex_state = 24, .external_lex_state = 3},
  [4424] = {.lex_state = 24, .external_lex_state = 3},
  [4425] = {.lex_state = 24, .external_lex_state = 3},
  [4426] = {.lex_state = 24, .external_lex_state = 3},
  [4427] = {.lex_state = 24, .external_lex_state = 3},
  [4428] = {.lex_state = 24, .external_lex_state = 3},
  [4429] = {.lex_state = 24, .external_lex_state = 3},
  [4430] = {.lex_state = 24, .external_lex_state = 3},
  [4431] = {.lex_state = 24, .external_lex_state = 3},
  [4432] = {.lex_state = 24, .external_lex_state = 3},
  [4433] = {.lex_state = 24, .external_lex_state = 3},
  [4434] = {.lex_state = 24, .external_lex_state = 3},
  [4435] = {.lex_state = 24, .external_lex_state = 3},
  [4436] = {.lex_state = 86, .external_lex_state = 3},
  [4437] = {.lex_state = 86, .external_lex_state = 3},
  [4438] = {.lex_state = 86, .external_lex_state = 3},
  [4439] = {.lex_state = 86, .external_lex_state = 3},
  [4440] = {.lex_state = 24, .external_lex_state = 3},
  [4441] = {.lex_state = 24, .external_lex_state = 3},
  [4442] = {.lex_state = 86, .external_lex_state = 3},
  [4443] = {.lex_state = 86, .external_lex_state = 3},
  [4444] = {.lex_state = 86, .external_lex_state = 3},
  [4445] = {.lex_state = 79, .external_lex_state = 3},
  [4446] = {.lex_state = 79, .external_lex_state = 3},
  [4447] = {.lex_state = 24, .external_lex_state = 3},
  [4448] = {.lex_state = 79, .external_lex_state = 3},
  [4449] = {.lex_state = 86, .external_lex_state = 3},
  [4450] = {.lex_state = 86, .external_lex_state = 3},
  [4451] = {.lex_state = 86, .external_lex_state = 3},
  [4452] = {.lex_state = 86, .external_lex_state = 3},
  [4453] = {.lex_state = 86, .external_lex_state = 3},
  [4454] = {.lex_state = 79, .external_lex_state = 3},
  [4455] = {.lex_state = 79, .external_lex_state = 3},
  [4456] = {.lex_state = 24, .external_lex_state = 3},
  [4457] = {.lex_state = 24, .external_lex_state = 3},
  [4458] = {.lex_state = 86, .external_lex_state = 3},
  [4459] = {.lex_state = 24, .external_lex_state = 3},
  [4460] = {.lex_state = 121, .external_lex_state = 3},
  [4461] = {.lex_state = 24, .external_lex_state = 3},
  [4462] = {.lex_state = 24, .external_lex_state = 3},
  [4463] = {.lex_state = 79, .external_lex_state = 3},
  [4464] = {.lex_state = 24, .external_lex_state = 3},
  [4465] = {.lex_state = 24, .external_lex_state = 3},
  [4466] = {.lex_state = 24, .external_lex_state = 3},
  [4467] = {.lex_state = 79, .external_lex_state = 3},
  [4468] = {.lex_state = 79, .external_lex_state = 3},
  [4469] = {.lex_state = 79, .external_lex_state = 3},
  [4470] = {.lex_state = 123, .external_lex_state = 3},
  [4471] = {.lex_state = 79, .external_lex_state = 3},
  [4472] = {.lex_state = 79, .external_lex_state = 3},
  [4473] = {.lex_state = 24, .external_lex_state = 3},
  [4474] = {.lex_state = 24, .external_lex_state = 3},
  [4475] = {.lex_state = 24, .external_lex_state = 3},
  [4476] = {.lex_state = 24, .external_lex_state = 3},
  [4477] = {.lex_state = 86, .external_lex_state = 3},
  [4478] = {.lex_state = 86, .external_lex_state = 3},
  [4479] = {.lex_state = 86, .external_lex_state = 3},
  [4480] = {.lex_state = 86, .external_lex_state = 3},
  [4481] = {.lex_state = 86, .external_lex_state = 3},
  [4482] = {.lex_state = 79, .external_lex_state = 3},
  [4483] = {.lex_state = 86, .external_lex_state = 3},
  [4484] = {.lex_state = 86, .external_lex_state = 3},
  [4485] = {.lex_state = 86, .external_lex_state = 3},
  [4486] = {.lex_state = 86, .external_lex_state = 3},
  [4487] = {.lex_state = 86, .external_lex_state = 3},
  [4488] = {.lex_state = 86, .external_lex_state = 3},
  [4489] = {.lex_state = 86, .external_lex_state = 3},
  [4490] = {.lex_state = 86, .external_lex_state = 3},
  [4491] = {.lex_state = 86, .external_lex_state = 3},
  [4492] = {.lex_state = 86, .external_lex_state = 3},
  [4493] = {.lex_state = 24, .external_lex_state = 3},
  [4494] = {.lex_state = 123, .external_lex_state = 3},
  [4495] = {.lex_state = 79, .external_lex_state = 3},
  [4496] = {.lex_state = 24, .external_lex_state = 3},
  [4497] = {.lex_state = 79, .external_lex_state = 3},
  [4498] = {.lex_state = 24, .external_lex_state = 3},
  [4499] = {.lex_state = 24, .external_lex_state = 3},
  [4500] = {.lex_state = 24, .external_lex_state = 3},
  [4501] = {.lex_state = 86, .external_lex_state = 3},
  [4502] = {.lex_state = 24, .external_lex_state = 3},
  [4503] = {.lex_state = 24, .external_lex_state = 3},
  [4504] = {.lex_state = 79, .external_lex_state = 3},
  [4505] = {.lex_state = 120, .external_lex_state = 3},
  [4506] = {.lex_state = 24, .external_lex_state = 3},
  [4507] = {.lex_state = 24, .external_lex_state = 3},
  [4508] = {.lex_state = 24, .external_lex_state = 3},
  [4509] = {.lex_state = 24, .external_lex_state = 3},
  [4510] = {.lex_state = 24, .external_lex_state = 3},
  [4511] = {.lex_state = 79, .external_lex_state = 3},
  [4512] = {.lex_state = 24, .external_lex_state = 3},
  [4513] = {.lex_state = 127, .external_lex_state = 3},
  [4514] = {.lex_state = 24, .external_lex_state = 3},
  [4515] = {.lex_state = 79, .external_lex_state = 3},
  [4516] = {.lex_state = 79, .external_lex_state = 3},
  [4517] = {.lex_state = 79, .external_lex_state = 3},
  [4518] = {.lex_state = 79, .external_lex_state = 3},
  [4519] = {.lex_state = 24, .external_lex_state = 3},
  [4520] = {.lex_state = 79, .external_lex_state = 3},
  [4521] = {.lex_state = 24, .external_lex_state = 3},
  [4522] = {.lex_state = 24, .external_lex_state = 3},
  [4523] = {.lex_state = 120, .external_lex_state = 3},
  [4524] = {.lex_state = 24, .external_lex_state = 3},
  [4525] = {.lex_state = 24, .external_lex_state = 3},
  [4526] = {.lex_state = 79, .external_lex_state = 3},
  [4527] = {.lex_state = 129, .external_lex_state = 3},
  [4528] = {.lex_state = 79, .external_lex_state = 3},
  [4529] = {.lex_state = 24, .external_lex_state = 3},
  [4530] = {.lex_state = 79, .external_lex_state = 3},
  [4531] = {.lex_state = 24, .external_lex_state = 3},
  [4532] = {.lex_state = 79, .external_lex_state = 3},
  [4533] = {.lex_state = 24, .external_lex_state = 3},
  [4534] = {.lex_state = 24, .external_lex_state = 3},
  [4535] = {.lex_state = 79, .external_lex_state = 3},
  [4536] = {.lex_state = 79, .external_lex_state = 3},
  [4537] = {.lex_state = 24, .external_lex_state = 3},
  [4538] = {.lex_state = 86, .external_lex_state = 3},
  [4539] = {.lex_state = 24, .external_lex_state = 3},
  [4540] = {.lex_state = 86, .external_lex_state = 3},
  [4541] = {.lex_state = 86, .external_lex_state = 3},
  [4542] = {.lex_state = 86, .external_lex_state = 3},
  [4543] = {.lex_state = 86, .external_lex_state = 3},
  [4544] = {.lex_state = 24, .external_lex_state = 3},
  [4545] = {.lex_state = 86, .external_lex_state = 3},
  [4546] = {.lex_state = 24, .external_lex_state = 3},
  [4547] = {.lex_state = 24, .external_lex_state = 3},
  [4548] = {.lex_state = 24, .external_lex_state = 3},
  [4549] = {.lex_state = 24, .external_lex_state = 3},
  [4550] = {.lex_state = 86, .external_lex_state = 3},
  [4551] = {.lex_state = 24, .external_lex_state = 3},
  [4552] = {.lex_state = 86, .external_lex_state = 3},
  [4553] = {.lex_state = 79, .external_lex_state = 3},
  [4554] = {.lex_state = 79, .external_lex_state = 3},
  [4555] = {.lex_state = 24, .external_lex_state = 3},
  [4556] = {.lex_state = 24, .external_lex_state = 3},
  [4557] = {.lex_state = 24, .external_lex_state = 3},
  [4558] = {.lex_state = 79, .external_lex_state = 3},
  [4559] = {.lex_state = 79, .external_lex_state = 3},
  [4560] = {.lex_state = 79, .external_lex_state = 3},
  [4561] = {.lex_state = 86, .external_lex_state = 3},
  [4562] = {.lex_state = 86, .external_lex_state = 3},
  [4563] = {.lex_state = 24, .external_lex_state = 3},
  [4564] = {.lex_state = 86, .external_lex_state = 3},
  [4565] = {.lex_state = 79, .external_lex_state = 3},
  [4566] = {.lex_state = 24, .external_lex_state = 3},
  [4567] = {.lex_state = 24, .external_lex_state = 3},
  [4568] = {.lex_state = 24, .external_lex_state = 3},
  [4569] = {.lex_state = 79, .external_lex_state = 3},
  [4570] = {.lex_state = 24, .external_lex_state = 3},
  [4571] = {.lex_state = 24, .external_lex_state = 3},
  [4572] = {.lex_state = 24, .external_lex_state = 3},
  [4573] = {.lex_state = 24, .external_lex_state = 3},
  [4574] = {.lex_state = 24, .external_lex_state = 3},
  [4575] = {.lex_state = 24, .external_lex_state = 3},
  [4576] = {.lex_state = 24, .external_lex_state = 3},
  [4577] = {.lex_state = 24, .external_lex_state = 3},
  [4578] = {.lex_state = 24, .external_lex_state = 3},
  [4579] = {.lex_state = 86, .external_lex_state = 3},
  [4580] = {.lex_state = 24, .external_lex_state = 3},
  [4581] = {.lex_state = 24, .external_lex_state = 3},
  [4582] = {.lex_state = 24, .external_lex_state = 3},
  [4583] = {.lex_state = 24, .external_lex_state = 3},
  [4584] = {.lex_state = 86, .external_lex_state = 3},
  [4585] = {.lex_state = 24, .external_lex_state = 3},
  [4586] = {.lex_state = 86, .external_lex_state = 3},
  [4587] = {.lex_state = 24, .external_lex_state = 3},
  [4588] = {.lex_state = 24, .external_lex_state = 3},
  [4589] = {.lex_state = 24, .external_lex_state = 3},
  [4590] = {.lex_state = 24, .external_lex_state = 3},
  [4591] = {.lex_state = 24, .external_lex_state = 3},
  [4592] = {.lex_state = 24, .external_lex_state = 3},
  [4593] = {.lex_state = 24, .external_lex_state = 3},
  [4594] = {.lex_state = 24, .external_lex_state = 3},
  [4595] = {.lex_state = 24, .external_lex_state = 3},
  [4596] = {.lex_state = 24, .external_lex_state = 3},
  [4597] = {.lex_state = 79, .external_lex_state = 3},
  [4598] = {.lex_state = 79, .external_lex_state = 3},
  [4599] = {.lex_state = 79, .external_lex_state = 3},
  [4600] = {.lex_state = 86, .external_lex_state = 3},
  [4601] = {.lex_state = 24, .external_lex_state = 3},
  [4602] = {.lex_state = 24, .external_lex_state = 3},
  [4603] = {.lex_state = 86, .external_lex_state = 3},
  [4604] = {.lex_state = 127, .external_lex_state = 3},
  [4605] = {.lex_state = 86, .external_lex_state = 3},
  [4606] = {.lex_state = 24, .external_lex_state = 3},
  [4607] = {.lex_state = 24, .external_lex_state = 3},
  [4608] = {.lex_state = 24, .external_lex_state = 3},
  [4609] = {.lex_state = 24, .external_lex_state = 3},
  [4610] = {.lex_state = 24, .external_lex_state = 3},
  [4611] = {.lex_state = 24, .external_lex_state = 3},
  [4612] = {.lex_state = 86, .external_lex_state = 3},
  [4613] = {.lex_state = 24, .external_lex_state = 3},
  [4614] = {.lex_state = 79, .external_lex_state = 3},
  [4615] = {.lex_state = 79, .external_lex_state = 3},
  [4616] = {.lex_state = 79, .external_lex_state = 3},
  [4617] = {.lex_state = 86, .external_lex_state = 3},
  [4618] = {.lex_state = 24, .external_lex_state = 3},
  [4619] = {.lex_state = 79, .external_lex_state = 3},
  [4620] = {.lex_state = 24, .external_lex_state = 3},
  [4621] = {.lex_state = 24, .external_lex_state = 3},
  [4622] = {.lex_state = 86, .external_lex_state = 3},
  [4623] = {.lex_state = 24, .external_lex_state = 3},
  [4624] = {.lex_state = 24, .external_lex_state = 3},
  [4625] = {.lex_state = 24, .external_lex_state = 3},
  [4626] = {.lex_state = 24, .external_lex_state = 3},
  [4627] = {.lex_state = 24, .external_lex_state = 3},
  [4628] = {.lex_state = 79, .external_lex_state = 3},
  [4629] = {.lex_state = 24, .external_lex_state = 3},
  [4630] = {.lex_state = 24, .external_lex_state = 3},
  [4631] = {.lex_state = 79, .external_lex_state = 3},
  [4632] = {.lex_state = 86, .external_lex_state = 3},
  [4633] = {.lex_state = 79, .external_lex_state = 3},
  [4634] = {.lex_state = 24, .external_lex_state = 3},
  [4635] = {.lex_state = 79, .external_lex_state = 3},
  [4636] = {.lex_state = 79, .external_lex_state = 3},
  [4637] = {.lex_state = 24, .external_lex_state = 3},
  [4638] = {.lex_state = 79, .external_lex_state = 3},
  [4639] = {.lex_state = 79, .external_lex_state = 3},
  [4640] = {.lex_state = 79, .external_lex_state = 3},
  [4641] = {.lex_state = 79, .external_lex_state = 3},
  [4642] = {.lex_state = 79, .external_lex_state = 3},
  [4643] = {.lex_state = 79, .external_lex_state = 3},
  [4644] = {.lex_state = 24, .external_lex_state = 3},
  [4645] = {.lex_state = 24, .external_lex_state = 3},
  [4646] = {.lex_state = 79, .external_lex_state = 3},
  [4647] = {.lex_state = 24, .external_lex_state = 3},
  [4648] = {.lex_state = 24, .external_lex_state = 3},
  [4649] = {.lex_state = 24, .external_lex_state = 3},
  [4650] = {.lex_state = 24, .external_lex_state = 3},
  [4651] = {.lex_state = 24, .external_lex_state = 3},
  [4652] = {.lex_state = 24, .external_lex_state = 3},
  [4653] = {.lex_state = 86, .external_lex_state = 3},
  [4654] = {.lex_state = 86, .external_lex_state = 3},
  [4655] = {.lex_state = 86, .external_lex_state = 3},
  [4656] = {.lex_state = 79, .external_lex_state = 3},
  [4657] = {.lex_state = 79, .external_lex_state = 3},
  [4658] = {.lex_state = 24, .external_lex_state = 3},
  [4659] = {.lex_state = 86, .external_lex_state = 3},
  [4660] = {.lex_state = 86, .external_lex_state = 3},
  [4661] = {.lex_state = 86, .external_lex_state = 3},
  [4662] = {.lex_state = 79, .external_lex_state = 3},
  [4663] = {.lex_state = 79, .external_lex_state = 3},
  [4664] = {.lex_state = 24, .external_lex_state = 3},
  [4665] = {.lex_state = 79, .external_lex_state = 3},
  [4666] = {.lex_state = 24, .external_lex_state = 3},
  [4667] = {.lex_state = 86, .external_lex_state = 3},
  [4668] = {.lex_state = 86, .external_lex_state = 3},
  [4669] = {.lex_state = 79, .external_lex_state = 3},
  [4670] = {.lex_state = 86, .external_lex_state = 3},
  [4671] = {.lex_state = 86, .external_lex_state = 3},
  [4672] = {.lex_state = 79, .external_lex_state = 3},
  [4673] = {.lex_state = 24, .external_lex_state = 3},
  [4674] = {.lex_state = 86, .external_lex_state = 3},
  [4675] = {.lex_state = 24, .external_lex_state = 3},
  [4676] = {.lex_state = 79, .external_lex_state = 3},
  [4677] = {.lex_state = 24, .external_lex_state = 3},
  [4678] = {.lex_state = 24, .external_lex_state = 3},
  [4679] = {.lex_state = 24, .external_lex_state = 3},
  [4680] = {.lex_state = 86, .external_lex_state = 3},
  [4681] = {.lex_state = 24, .external_lex_state = 3},
  [4682] = {.lex_state = 24, .external_lex_state = 3},
  [4683] = {.lex_state = 79, .external_lex_state = 3},
  [4684] = {.lex_state = 24, .external_lex_state = 3},
  [4685] = {.lex_state = 24, .external_lex_state = 3},
  [4686] = {.lex_state = 24, .external_lex_state = 3},
  [4687] = {.lex_state = 24, .external_lex_state = 3},
  [4688] = {.lex_state = 24, .external_lex_state = 3},
  [4689] = {.lex_state = 24, .external_lex_state = 3},
  [4690] = {.lex_state = 24, .external_lex_state = 3},
  [4691] = {.lex_state = 86, .external_lex_state = 3},
  [4692] = {.lex_state = 24, .external_lex_state = 3},
  [4693] = {.lex_state = 24, .external_lex_state = 3},
  [4694] = {.lex_state = 24, .external_lex_state = 3},
  [4695] = {.lex_state = 86, .external_lex_state = 3},
  [4696] = {.lex_state = 86, .external_lex_state = 3},
  [4697] = {.lex_state = 24, .external_lex_state = 3},
  [4698] = {.lex_state = 24, .external_lex_state = 3},
  [4699] = {.lex_state = 128, .external_lex_state = 3},
  [4700] = {.lex_state = 24, .external_lex_state = 3},
  [4701] = {.lex_state = 24, .external_lex_state = 3},
  [4702] = {.lex_state = 79, .external_lex_state = 3},
  [4703] = {.lex_state = 24, .external_lex_state = 3},
  [4704] = {.lex_state = 24, .external_lex_state = 3},
  [4705] = {.lex_state = 24, .external_lex_state = 3},
  [4706] = {.lex_state = 24, .external_lex_state = 3},
  [4707] = {.lex_state = 79, .external_lex_state = 3},
  [4708] = {.lex_state = 24, .external_lex_state = 3},
  [4709] = {.lex_state = 79, .external_lex_state = 3},
  [4710] = {.lex_state = 24, .external_lex_state = 3},
  [4711] = {.lex_state = 24, .external_lex_state = 3},
  [4712] = {.lex_state = 24, .external_lex_state = 3},
  [4713] = {.lex_state = 24, .external_lex_state = 3},
  [4714] = {.lex_state = 24, .external_lex_state = 3},
  [4715] = {.lex_state = 24, .external_lex_state = 3},
  [4716] = {.lex_state = 24, .external_lex_state = 3},
  [4717] = {.lex_state = 24, .external_lex_state = 3},
  [4718] = {.lex_state = 24, .external_lex_state = 3},
  [4719] = {.lex_state = 79, .external_lex_state = 3},
  [4720] = {.lex_state = 79, .external_lex_state = 3},
  [4721] = {.lex_state = 24, .external_lex_state = 3},
  [4722] = {.lex_state = 24, .external_lex_state = 3},
  [4723] = {.lex_state = 24, .external_lex_state = 3},
  [4724] = {.lex_state = 24, .external_lex_state = 3},
  [4725] = {.lex_state = 24, .external_lex_state = 3},
  [4726] = {.lex_state = 24, .external_lex_state = 3},
  [4727] = {.lex_state = 24, .external_lex_state = 3},
  [4728] = {.lex_state = 24, .external_lex_state = 3},
  [4729] = {.lex_state = 24, .external_lex_state = 3},
  [4730] = {.lex_state = 24, .external_lex_state = 3},
  [4731] = {.lex_state = 86, .external_lex_state = 3},
  [4732] = {.lex_state = 24, .external_lex_state = 3},
  [4733] = {.lex_state = 128, .external_lex_state = 3},
  [4734] = {.lex_state = 24, .external_lex_state = 3},
  [4735] = {.lex_state = 86, .external_lex_state = 3},
  [4736] = {.lex_state = 79, .external_lex_state = 3},
  [4737] = {.lex_state = 86, .external_lex_state = 3},
  [4738] = {.lex_state = 79, .external_lex_state = 3},
  [4739] = {.lex_state = 79, .external_lex_state = 3},
  [4740] = {.lex_state = 24, .external_lex_state = 3},
  [4741] = {.lex_state = 79, .external_lex_state = 3},
  [4742] = {.lex_state = 24, .external_lex_state = 3},
  [4743] = {.lex_state = 86, .external_lex_state = 3},
  [4744] = {.lex_state = 24, .external_lex_state = 3},
  [4745] = {.lex_state = 24, .external_lex_state = 3},
  [4746] = {.lex_state = 24, .external_lex_state = 3},
  [4747] = {.lex_state = 24, .external_lex_state = 3},
  [4748] = {.lex_state = 24, .external_lex_state = 3},
  [4749] = {.lex_state = 24, .external_lex_state = 3},
  [4750] = {.lex_state = 86, .external_lex_state = 3},
  [4751] = {.lex_state = 86, .external_lex_state = 3},
  [4752] = {.lex_state = 86, .external_lex_state = 3},
  [4753] = {.lex_state = 86, .external_lex_state = 3},
  [4754] = {.lex_state = 24, .external_lex_state = 3},
  [4755] = {.lex_state = 24, .external_lex_state = 3},
  [4756] = {.lex_state = 24, .external_lex_state = 3},
  [4757] = {.lex_state = 24, .external_lex_state = 3},
  [4758] = {.lex_state = 79, .external_lex_state = 3},
  [4759] = {.lex_state = 79, .external_lex_state = 3},
  [4760] = {.lex_state = 79, .external_lex_state = 3},
  [4761] = {.lex_state = 24, .external_lex_state = 3},
  [4762] = {.lex_state = 24, .external_lex_state = 3},
  [4763] = {.lex_state = 79, .external_lex_state = 3},
  [4764] = {.lex_state = 24, .external_lex_state = 3},
  [4765] = {.lex_state = 86, .external_lex_state = 3},
  [4766] = {.lex_state = 86, .external_lex_state = 3},
  [4767] = {.lex_state = 86, .external_lex_state = 3},
  [4768] = {.lex_state = 121, .external_lex_state = 3},
  [4769] = {.lex_state = 129, .external_lex_state = 3},
  [4770] = {.lex_state = 129, .external_lex_state = 3},
  [4771] = {.lex_state = 130, .external_lex_state = 3},
  [4772] = {.lex_state = 125, .external_lex_state = 3},
  [4773] = {.lex_state = 121, .external_lex_state = 3},
  [4774] = {.lex_state = 130, .external_lex_state = 3},
  [4775] = {.lex_state = 124, .external_lex_state = 3},
  [4776] = {.lex_state = 125, .external_lex_state = 3},
  [4777] = {.lex_state = 125, .external_lex_state = 3},
  [4778] = {.lex_state = 131, .external_lex_state = 3},
  [4779] = {.lex_state = 130, .external_lex_state = 3},
  [4780] = {.lex_state = 124, .external_lex_state = 3},
  [4781] = {.lex_state = 131, .external_lex_state = 3},
  [4782] = {.lex_state = 6, .external_lex_state = 3},
  [4783] = {.lex_state = 124, .external_lex_state = 3},
  [4784] = {.lex_state = 6, .external_lex_state = 3},
  [4785] = {.lex_state = 32, .external_lex_state = 3},
  [4786] = {.lex_state = 131, .external_lex_state = 3},
  [4787] = {.lex_state = 6, .external_lex_state = 3},
  [4788] = {.lex_state = 32, .external_lex_state = 3},
  [4789] = {.lex_state = 32, .external_lex_state = 3},
  [4790] = {.lex_state = 6, .external_lex_state = 3},
  [4791] = {.lex_state = 6, .external_lex_state = 3},
  [4792] = {.lex_state = 6, .external_lex_state = 3},
  [4793] = {.lex_state = 6, .external_lex_state = 3},
  [4794] = {.lex_state = 6, .external_lex_state = 3},
  [4795] = {.lex_state = 6, .external_lex_state = 3},
  [4796] = {.lex_state = 6, .external_lex_state = 3},
  [4797] = {.lex_state = 6, .external_lex_state = 3},
  [4798] = {.lex_state = 6, .external_lex_state = 3},
  [4799] = {.lex_state = 6, .external_lex_state = 3},
  [4800] = {.lex_state = 6, .external_lex_state = 3},
  [4801] = {.lex_state = 6, .external_lex_state = 3},
  [4802] = {.lex_state = 6, .external_lex_state = 3},
  [4803] = {.lex_state = 59, .external_lex_state = 3},
  [4804] = {.lex_state = 6, .external_lex_state = 3},
  [4805] = {.lex_state = 6, .external_lex_state = 3},
  [4806] = {.lex_state = 6, .external_lex_state = 3},
  [4807] = {.lex_state = 6, .external_lex_state = 3},
  [4808] = {.lex_state = 6, .external_lex_state = 3},
  [4809] = {.lex_state = 6, .external_lex_state = 3},
  [4810] = {.lex_state = 59, .external_lex_state = 3},
  [4811] = {.lex_state = 59, .external_lex_state = 3},
  [4812] = {.lex_state = 6, .external_lex_state = 3},
  [4813] = {.lex_state = 6, .external_lex_state = 3},
  [4814] = {.lex_state = 6, .external_lex_state = 3},
  [4815] = {.lex_state = 6, .external_lex_state = 3},
  [4816] = {.lex_state = 6, .external_lex_state = 3},
  [4817] = {.lex_state = 6, .external_lex_state = 3},
  [4818] = {.lex_state = 6, .external_lex_state = 3},
  [4819] = {.lex_state = 6, .external_lex_state = 3},
  [4820] = {.lex_state = 6, .external_lex_state = 3},
  [4821] = {.lex_state = 6, .external_lex_state = 3},
  [4822] = {.lex_state = 6, .external_lex_state = 3},
  [4823] = {.lex_state = 6, .external_lex_state = 3},
  [4824] = {.lex_state = 6, .external_lex_state = 3},
  [4825] = {.lex_state = 6, .external_lex_state = 3},
  [4826] = {.lex_state = 6, .external_lex_state = 3},
  [4827] = {.lex_state = 6, .external_lex_state = 3},
  [4828] = {.lex_state = 6, .external_lex_state = 3},
  [4829] = {.lex_state = 6, .external_lex_state = 3},
  [4830] = {.lex_state = 59, .external_lex_state = 3},
  [4831] = {.lex_state = 6, .external_lex_state = 3},
  [4832] = {.lex_state = 6, .external_lex_state = 3},
  [4833] = {.lex_state = 6, .external_lex_state = 3},
  [4834] = {.lex_state = 59, .external_lex_state = 3},
  [4835] = {.lex_state = 6, .external_lex_state = 3},
  [4836] = {.lex_state = 6, .external_lex_state = 3},
  [4837] = {.lex_state = 6, .external_lex_state = 3},
  [4838] = {.lex_state = 6, .external_lex_state = 3},
  [4839] = {.lex_state = 6, .external_lex_state = 3},
  [4840] = {.lex_state = 6, .external_lex_state = 3},
  [4841] = {.lex_state = 59, .external_lex_state = 3},
  [4842] = {.lex_state = 6, .external_lex_state = 3},
  [4843] = {.lex_state = 6, .external_lex_state = 3},
  [4844] = {.lex_state = 6, .external_lex_state = 3},
  [4845] = {.lex_state = 6, .external_lex_state = 3},
  [4846] = {.lex_state = 6, .external_lex_state = 3},
  [4847] = {.lex_state = 6, .external_lex_state = 3},
  [4848] = {.lex_state = 6, .external_lex_state = 3},
  [4849] = {.lex_state = 6, .external_lex_state = 3},
  [4850] = {.lex_state = 6, .external_lex_state = 3},
  [4851] = {.lex_state = 6, .external_lex_state = 3},
  [4852] = {.lex_state = 6, .external_lex_state = 3},
  [4853] = {.lex_state = 6, .external_lex_state = 3},
  [4854] = {.lex_state = 6, .external_lex_state = 3},
  [4855] = {.lex_state = 6, .external_lex_state = 3},
  [4856] = {.lex_state = 6, .external_lex_state = 3},
  [4857] = {.lex_state = 6, .external_lex_state = 3},
  [4858] = {.lex_state = 6, .external_lex_state = 3},
  [4859] = {.lex_state = 6, .external_lex_state = 3},
  [4860] = {.lex_state = 32, .external_lex_state = 3},
  [4861] = {.lex_state = 6, .external_lex_state = 3},
  [4862] = {.lex_state = 6, .external_lex_state = 3},
  [4863] = {.lex_state = 6, .external_lex_state = 3},
  [4864] = {.lex_state = 6, .external_lex_state = 3},
  [4865] = {.lex_state = 6, .external_lex_state = 3},
  [4866] = {.lex_state = 6, .external_lex_state = 3},
  [4867] = {.lex_state = 6, .external_lex_state = 3},
  [4868] = {.lex_state = 6, .external_lex_state = 3},
  [4869] = {.lex_state = 6, .external_lex_state = 3},
  [4870] = {.lex_state = 6, .external_lex_state = 3},
  [4871] = {.lex_state = 6, .external_lex_state = 3},
  [4872] = {.lex_state = 59, .external_lex_state = 3},
  [4873] = {.lex_state = 6, .external_lex_state = 3},
  [4874] = {.lex_state = 6, .external_lex_state = 3},
  [4875] = {.lex_state = 6, .external_lex_state = 3},
  [4876] = {.lex_state = 6, .external_lex_state = 3},
  [4877] = {.lex_state = 6, .external_lex_state = 3},
  [4878] = {.lex_state = 6, .external_lex_state = 3},
  [4879] = {.lex_state = 6, .external_lex_state = 3},
  [4880] = {.lex_state = 6, .external_lex_state = 3},
  [4881] = {.lex_state = 6, .external_lex_state = 3},
  [4882] = {.lex_state = 6, .external_lex_state = 3},
  [4883] = {.lex_state = 6, .external_lex_state = 3},
  [4884] = {.lex_state = 6, .external_lex_state = 3},
  [4885] = {.lex_state = 6, .external_lex_state = 3},
  [4886] = {.lex_state = 6, .external_lex_state = 3},
  [4887] = {.lex_state = 6, .external_lex_state = 3},
  [4888] = {.lex_state = 6, .external_lex_state = 3},
  [4889] = {.lex_state = 6, .external_lex_state = 3},
  [4890] = {.lex_state = 59, .external_lex_state = 3},
  [4891] = {.lex_state = 6, .external_lex_state = 3},
  [4892] = {.lex_state = 59, .external_lex_state = 3},
  [4893] = {.lex_state = 59, .external_lex_state = 3},
  [4894] = {.lex_state = 59, .external_lex_state = 3},
  [4895] = {.lex_state = 6, .external_lex_state = 3},
  [4896] = {.lex_state = 6, .external_lex_state = 3},
  [4897] = {.lex_state = 59, .external_lex_state = 3},
  [4898] = {.lex_state = 6, .external_lex_state = 3},
  [4899] = {.lex_state = 59, .external_lex_state = 3},
  [4900] = {.lex_state = 59, .external_lex_state = 3},
  [4901] = {.lex_state = 59, .external_lex_state = 3},
  [4902] = {.lex_state = 6, .external_lex_state = 3},
  [4903] = {.lex_state = 59, .external_lex_state = 3},
  [4904] = {.lex_state = 59, .external_lex_state = 3},
  [4905] = {.lex_state = 6, .external_lex_state = 3},
  [4906] = {.lex_state = 6, .external_lex_state = 3},
  [4907] = {.lex_state = 6, .external_lex_state = 3},
  [4908] = {.lex_state = 59, .external_lex_state = 3},
  [4909] = {.lex_state = 59, .external_lex_state = 3},
  [4910] = {.lex_state = 59, .external_lex_state = 3},
  [4911] = {.lex_state = 59, .external_lex_state = 3},
  [4912] = {.lex_state = 59, .external_lex_state = 3},
  [4913] = {.lex_state = 59, .external_lex_state = 3},
  [4914] = {.lex_state = 6, .external_lex_state = 3},
  [4915] = {.lex_state = 59, .external_lex_state = 3},
  [4916] = {.lex_state = 6, .external_lex_state = 3},
  [4917] = {.lex_state = 6, .external_lex_state = 3},
  [4918] = {.lex_state = 59, .external_lex_state = 3},
  [4919] = {.lex_state = 6, .external_lex_state = 3},
  [4920] = {.lex_state = 6, .external_lex_state = 3},
  [4921] = {.lex_state = 59, .external_lex_state = 3},
  [4922] = {.lex_state = 6, .external_lex_state = 3},
  [4923] = {.lex_state = 59, .external_lex_state = 3},
  [4924] = {.lex_state = 6, .external_lex_state = 3},
  [4925] = {.lex_state = 59, .external_lex_state = 3},
  [4926] = {.lex_state = 59, .external_lex_state = 3},
  [4927] = {.lex_state = 59, .external_lex_state = 3},
  [4928] = {.lex_state = 60, .external_lex_state = 3},
  [4929] = {.lex_state = 59, .external_lex_state = 3},
  [4930] = {.lex_state = 6, .external_lex_state = 3},
  [4931] = {.lex_state = 59, .external_lex_state = 3},
  [4932] = {.lex_state = 59, .external_lex_state = 3},
  [4933] = {.lex_state = 59, .external_lex_state = 3},
  [4934] = {.lex_state = 6, .external_lex_state = 3},
  [4935] = {.lex_state = 6, .external_lex_state = 3},
  [4936] = {.lex_state = 6, .external_lex_state = 3},
  [4937] = {.lex_state = 6, .external_lex_state = 3},
  [4938] = {.lex_state = 6, .external_lex_state = 3},
  [4939] = {.lex_state = 59, .external_lex_state = 3},
  [4940] = {.lex_state = 59, .external_lex_state = 3},
  [4941] = {.lex_state = 6, .external_lex_state = 3},
  [4942] = {.lex_state = 59, .external_lex_state = 3},
  [4943] = {.lex_state = 6, .external_lex_state = 3},
  [4944] = {.lex_state = 6, .external_lex_state = 3},
  [4945] = {.lex_state = 59, .external_lex_state = 3},
  [4946] = {.lex_state = 60, .external_lex_state = 3},
  [4947] = {.lex_state = 6, .external_lex_state = 3},
  [4948] = {.lex_state = 60, .external_lex_state = 3},
  [4949] = {.lex_state = 6, .external_lex_state = 3},
  [4950] = {.lex_state = 60, .external_lex_state = 3},
  [4951] = {.lex_state = 59, .external_lex_state = 3},
  [4952] = {.lex_state = 6, .external_lex_state = 3},
  [4953] = {.lex_state = 59, .external_lex_state = 3},
  [4954] = {.lex_state = 59, .external_lex_state = 3},
  [4955] = {.lex_state = 59, .external_lex_state = 3},
  [4956] = {.lex_state = 59, .external_lex_state = 3},
  [4957] = {.lex_state = 59, .external_lex_state = 3},
  [4958] = {.lex_state = 59, .external_lex_state = 3},
  [4959] = {.lex_state = 6, .external_lex_state = 3},
  [4960] = {.lex_state = 6, .external_lex_state = 3},
  [4961] = {.lex_state = 59, .external_lex_state = 3},
  [4962] = {.lex_state = 59, .external_lex_state = 3},
  [4963] = {.lex_state = 59, .external_lex_state = 3},
  [4964] = {.lex_state = 59, .external_lex_state = 3},
  [4965] = {.lex_state = 6, .external_lex_state = 3},
  [4966] = {.lex_state = 59, .external_lex_state = 3},
  [4967] = {.lex_state = 59, .external_lex_state = 3},
  [4968] = {.lex_state = 6, .external_lex_state = 3},
  [4969] = {.lex_state = 59, .external_lex_state = 3},
  [4970] = {.lex_state = 59, .external_lex_state = 3},
  [4971] = {.lex_state = 6, .external_lex_state = 3},
  [4972] = {.lex_state = 59, .external_lex_state = 3},
  [4973] = {.lex_state = 59, .external_lex_state = 3},
  [4974] = {.lex_state = 59, .external_lex_state = 3},
  [4975] = {.lex_state = 59, .external_lex_state = 3},
  [4976] = {.lex_state = 59, .external_lex_state = 3},
  [4977] = {.lex_state = 6, .external_lex_state = 3},
  [4978] = {.lex_state = 6, .external_lex_state = 3},
  [4979] = {.lex_state = 59, .external_lex_state = 3},
  [4980] = {.lex_state = 6, .external_lex_state = 3},
  [4981] = {.lex_state = 6, .external_lex_state = 3},
  [4982] = {.lex_state = 59, .external_lex_state = 3},
  [4983] = {.lex_state = 59, .external_lex_state = 3},
  [4984] = {.lex_state = 6, .external_lex_state = 3},
  [4985] = {.lex_state = 6, .external_lex_state = 3},
  [4986] = {.lex_state = 59, .external_lex_state = 3},
  [4987] = {.lex_state = 6, .external_lex_state = 3},
  [4988] = {.lex_state = 60, .external_lex_state = 3},
  [4989] = {.lex_state = 6, .external_lex_state = 3},
  [4990] = {.lex_state = 6, .external_lex_state = 3},
  [4991] = {.lex_state = 60, .external_lex_state = 3},
  [4992] = {.lex_state = 60, .external_lex_state = 3},
  [4993] = {.lex_state = 59, .external_lex_state = 3},
  [4994] = {.lex_state = 59, .external_lex_state = 3},
  [4995] = {.lex_state = 59, .external_lex_state = 3},
  [4996] = {.lex_state = 59, .external_lex_state = 3},
  [4997] = {.lex_state = 59, .external_lex_state = 3},
  [4998] = {.lex_state = 59, .external_lex_state = 3},
  [4999] = {.lex_state = 6, .external_lex_state = 3},
  [5000] = {.lex_state = 6, .external_lex_state = 3},
  [5001] = {.lex_state = 6, .external_lex_state = 3},
  [5002] = {.lex_state = 59, .external_lex_state = 3},
  [5003] = {.lex_state = 59, .external_lex_state = 3},
  [5004] = {.lex_state = 59, .external_lex_state = 3},
  [5005] = {.lex_state = 59, .external_lex_state = 3},
  [5006] = {.lex_state = 59, .external_lex_state = 3},
  [5007] = {.lex_state = 59, .external_lex_state = 3},
  [5008] = {.lex_state = 59, .external_lex_state = 3},
  [5009] = {.lex_state = 6, .external_lex_state = 3},
  [5010] = {.lex_state = 60, .external_lex_state = 3},
  [5011] = {.lex_state = 59, .external_lex_state = 3},
  [5012] = {.lex_state = 59, .external_lex_state = 3},
  [5013] = {.lex_state = 60, .external_lex_state = 3},
  [5014] = {.lex_state = 59, .external_lex_state = 3},
  [5015] = {.lex_state = 60, .external_lex_state = 3},
  [5016] = {.lex_state = 59, .external_lex_state = 3},
  [5017] = {.lex_state = 59, .external_lex_state = 3},
  [5018] = {.lex_state = 59, .external_lex_state = 3},
  [5019] = {.lex_state = 59, .external_lex_state = 3},
  [5020] = {.lex_state = 59, .external_lex_state = 3},
  [5021] = {.lex_state = 59, .external_lex_state = 3},
  [5022] = {.lex_state = 59, .external_lex_state = 3},
  [5023] = {.lex_state = 59, .external_lex_state = 3},
  [5024] = {.lex_state = 59, .external_lex_state = 3},
  [5025] = {.lex_state = 6, .external_lex_state = 3},
  [5026] = {.lex_state = 60, .external_lex_state = 3},
  [5027] = {.lex_state = 6, .external_lex_state = 3},
  [5028] = {.lex_state = 6, .external_lex_state = 3},
  [5029] = {.lex_state = 59, .external_lex_state = 3},
  [5030] = {.lex_state = 6, .external_lex_state = 3},
  [5031] = {.lex_state = 59, .external_lex_state = 3},
  [5032] = {.lex_state = 59, .external_lex_state = 3},
  [5033] = {.lex_state = 60, .external_lex_state = 3},
  [5034] = {.lex_state = 60, .external_lex_state = 3},
  [5035] = {.lex_state = 60, .external_lex_state = 3},
  [5036] = {.lex_state = 60, .external_lex_state = 3},
  [5037] = {.lex_state = 60, .external_lex_state = 3},
  [5038] = {.lex_state = 60, .external_lex_state = 3},
  [5039] = {.lex_state = 60, .external_lex_state = 3},
  [5040] = {.lex_state = 6, .external_lex_state = 3},
  [5041] = {.lex_state = 60, .external_lex_state = 3},
  [5042] = {.lex_state = 60, .external_lex_state = 3},
  [5043] = {.lex_state = 60, .external_lex_state = 3},
  [5044] = {.lex_state = 60, .external_lex_state = 3},
  [5045] = {.lex_state = 56, .external_lex_state = 3},
  [5046] = {.lex_state = 60, .external_lex_state = 3},
  [5047] = {.lex_state = 60, .external_lex_state = 3},
  [5048] = {.lex_state = 60, .external_lex_state = 3},
  [5049] = {.lex_state = 60, .external_lex_state = 3},
  [5050] = {.lex_state = 60, .external_lex_state = 3},
  [5051] = {.lex_state = 60, .external_lex_state = 3},
  [5052] = {.lex_state = 60, .external_lex_state = 3},
  [5053] = {.lex_state = 60, .external_lex_state = 3},
  [5054] = {.lex_state = 60, .external_lex_state = 3},
  [5055] = {.lex_state = 60, .external_lex_state = 3},
  [5056] = {.lex_state = 60, .external_lex_state = 3},
  [5057] = {.lex_state = 60, .external_lex_state = 3},
  [5058] = {.lex_state = 60, .external_lex_state = 3},
  [5059] = {.lex_state = 60, .external_lex_state = 3},
  [5060] = {.lex_state = 60, .external_lex_state = 3},
  [5061] = {.lex_state = 60, .external_lex_state = 3},
  [5062] = {.lex_state = 33, .external_lex_state = 3},
  [5063] = {.lex_state = 60, .external_lex_state = 3},
  [5064] = {.lex_state = 60, .external_lex_state = 3},
  [5065] = {.lex_state = 60, .external_lex_state = 3},
  [5066] = {.lex_state = 60, .external_lex_state = 3},
  [5067] = {.lex_state = 60, .external_lex_state = 3},
  [5068] = {.lex_state = 60, .external_lex_state = 3},
  [5069] = {.lex_state = 60, .external_lex_state = 3},
  [5070] = {.lex_state = 60, .external_lex_state = 3},
  [5071] = {.lex_state = 60, .external_lex_state = 3},
  [5072] = {.lex_state = 60, .external_lex_state = 3},
  [5073] = {.lex_state = 6, .external_lex_state = 3},
  [5074] = {.lex_state = 60, .external_lex_state = 3},
  [5075] = {.lex_state = 60, .external_lex_state = 3},
  [5076] = {.lex_state = 6, .external_lex_state = 3},
  [5077] = {.lex_state = 60, .external_lex_state = 3},
  [5078] = {.lex_state = 60, .external_lex_state = 3},
  [5079] = {.lex_state = 60, .external_lex_state = 3},
  [5080] = {.lex_state = 56, .external_lex_state = 3},
  [5081] = {.lex_state = 60, .external_lex_state = 3},
  [5082] = {.lex_state = 60, .external_lex_state = 3},
  [5083] = {.lex_state = 60, .external_lex_state = 3},
  [5084] = {.lex_state = 60, .external_lex_state = 3},
  [5085] = {.lex_state = 60, .external_lex_state = 3},
  [5086] = {.lex_state = 60, .external_lex_state = 3},
  [5087] = {.lex_state = 32, .external_lex_state = 3},
  [5088] = {.lex_state = 60, .external_lex_state = 3},
  [5089] = {.lex_state = 60, .external_lex_state = 3},
  [5090] = {.lex_state = 60, .external_lex_state = 3},
  [5091] = {.lex_state = 60, .external_lex_state = 3},
  [5092] = {.lex_state = 60, .external_lex_state = 3},
  [5093] = {.lex_state = 60, .external_lex_state = 3},
  [5094] = {.lex_state = 60, .external_lex_state = 3},
  [5095] = {.lex_state = 60, .external_lex_state = 3},
  [5096] = {.lex_state = 60, .external_lex_state = 3},
  [5097] = {.lex_state = 60, .external_lex_state = 3},
  [5098] = {.lex_state = 60, .external_lex_state = 3},
  [5099] = {.lex_state = 60, .external_lex_state = 3},
  [5100] = {.lex_state = 6, .external_lex_state = 3},
  [5101] = {.lex_state = 60, .external_lex_state = 3},
  [5102] = {.lex_state = 60, .external_lex_state = 3},
  [5103] = {.lex_state = 60, .external_lex_state = 3},
  [5104] = {.lex_state = 60, .external_lex_state = 3},
  [5105] = {.lex_state = 60, .external_lex_state = 3},
  [5106] = {.lex_state = 60, .external_lex_state = 3},
  [5107] = {.lex_state = 60, .external_lex_state = 3},
  [5108] = {.lex_state = 60, .external_lex_state = 3},
  [5109] = {.lex_state = 60, .external_lex_state = 3},
  [5110] = {.lex_state = 56, .external_lex_state = 3},
  [5111] = {.lex_state = 60, .external_lex_state = 3},
  [5112] = {.lex_state = 60, .external_lex_state = 3},
  [5113] = {.lex_state = 6, .external_lex_state = 3},
  [5114] = {.lex_state = 60, .external_lex_state = 3},
  [5115] = {.lex_state = 56, .external_lex_state = 3},
  [5116] = {.lex_state = 56, .external_lex_state = 3},
  [5117] = {.lex_state = 60, .external_lex_state = 3},
  [5118] = {.lex_state = 60, .external_lex_state = 3},
  [5119] = {.lex_state = 56, .external_lex_state = 3},
  [5120] = {.lex_state = 60, .external_lex_state = 3},
  [5121] = {.lex_state = 60, .external_lex_state = 3},
  [5122] = {.lex_state = 56, .external_lex_state = 3},
  [5123] = {.lex_state = 60, .external_lex_state = 3},
  [5124] = {.lex_state = 60, .external_lex_state = 3},
  [5125] = {.lex_state = 6, .external_lex_state = 3},
  [5126] = {.lex_state = 56, .external_lex_state = 3},
  [5127] = {.lex_state = 56, .external_lex_state = 3},
  [5128] = {.lex_state = 56, .external_lex_state = 3},
  [5129] = {.lex_state = 60, .external_lex_state = 3},
  [5130] = {.lex_state = 56, .external_lex_state = 3},
  [5131] = {.lex_state = 6, .external_lex_state = 3},
  [5132] = {.lex_state = 56, .external_lex_state = 3},
  [5133] = {.lex_state = 6, .external_lex_state = 3},
  [5134] = {.lex_state = 56, .external_lex_state = 3},
  [5135] = {.lex_state = 6, .external_lex_state = 3},
  [5136] = {.lex_state = 6, .external_lex_state = 3},
  [5137] = {.lex_state = 6, .external_lex_state = 3},
  [5138] = {.lex_state = 55, .external_lex_state = 3},
  [5139] = {.lex_state = 6, .external_lex_state = 3},
  [5140] = {.lex_state = 56, .external_lex_state = 3},
  [5141] = {.lex_state = 56, .external_lex_state = 3},
  [5142] = {.lex_state = 6, .external_lex_state = 3},
  [5143] = {.lex_state = 56, .external_lex_state = 3},
  [5144] = {.lex_state = 56, .external_lex_state = 3},
  [5145] = {.lex_state = 32, .external_lex_state = 3},
  [5146] = {.lex_state = 6, .external_lex_state = 3},
  [5147] = {.lex_state = 56, .external_lex_state = 3},
  [5148] = {.lex_state = 56, .external_lex_state = 3},
  [5149] = {.lex_state = 55, .external_lex_state = 3},
  [5150] = {.lex_state = 56, .external_lex_state = 3},
  [5151] = {.lex_state = 6, .external_lex_state = 3},
  [5152] = {.lex_state = 6, .external_lex_state = 3},
  [5153] = {.lex_state = 6, .external_lex_state = 3},
  [5154] = {.lex_state = 56, .external_lex_state = 3},
  [5155] = {.lex_state = 56, .external_lex_state = 3},
  [5156] = {.lex_state = 58, .external_lex_state = 3},
  [5157] = {.lex_state = 6, .external_lex_state = 3},
  [5158] = {.lex_state = 6, .external_lex_state = 3},
  [5159] = {.lex_state = 58, .external_lex_state = 3},
  [5160] = {.lex_state = 58, .external_lex_state = 3},
  [5161] = {.lex_state = 58, .external_lex_state = 3},
  [5162] = {.lex_state = 6, .external_lex_state = 3},
  [5163] = {.lex_state = 6, .external_lex_state = 3},
  [5164] = {.lex_state = 56, .external_lex_state = 3},
  [5165] = {.lex_state = 6, .external_lex_state = 3},
  [5166] = {.lex_state = 6, .external_lex_state = 3},
  [5167] = {.lex_state = 6, .external_lex_state = 3},
  [5168] = {.lex_state = 6, .external_lex_state = 3},
  [5169] = {.lex_state = 55, .external_lex_state = 3},
  [5170] = {.lex_state = 55, .external_lex_state = 3},
  [5171] = {.lex_state = 6, .external_lex_state = 3},
  [5172] = {.lex_state = 55, .external_lex_state = 3},
  [5173] = {.lex_state = 6, .external_lex_state = 3},
  [5174] = {.lex_state = 59, .external_lex_state = 3},
  [5175] = {.lex_state = 6, .external_lex_state = 3},
  [5176] = {.lex_state = 6, .external_lex_state = 3},
  [5177] = {.lex_state = 6, .external_lex_state = 3},
  [5178] = {.lex_state = 56, .external_lex_state = 3},
  [5179] = {.lex_state = 58, .external_lex_state = 3},
  [5180] = {.lex_state = 6, .external_lex_state = 3},
  [5181] = {.lex_state = 58, .external_lex_state = 3},
  [5182] = {.lex_state = 56, .external_lex_state = 3},
  [5183] = {.lex_state = 58, .external_lex_state = 3},
  [5184] = {.lex_state = 56, .external_lex_state = 3},
  [5185] = {.lex_state = 6, .external_lex_state = 3},
  [5186] = {.lex_state = 56, .external_lex_state = 3},
  [5187] = {.lex_state = 56, .external_lex_state = 3},
  [5188] = {.lex_state = 56, .external_lex_state = 3},
  [5189] = {.lex_state = 6, .external_lex_state = 3},
  [5190] = {.lex_state = 56, .external_lex_state = 3},
  [5191] = {.lex_state = 6, .external_lex_state = 3},
  [5192] = {.lex_state = 6, .external_lex_state = 3},
  [5193] = {.lex_state = 56, .external_lex_state = 3},
  [5194] = {.lex_state = 6, .external_lex_state = 3},
  [5195] = {.lex_state = 56, .external_lex_state = 3},
  [5196] = {.lex_state = 6, .external_lex_state = 3},
  [5197] = {.lex_state = 56, .external_lex_state = 3},
  [5198] = {.lex_state = 58, .external_lex_state = 3},
  [5199] = {.lex_state = 56, .external_lex_state = 3},
  [5200] = {.lex_state = 6, .external_lex_state = 3},
  [5201] = {.lex_state = 56, .external_lex_state = 3},
  [5202] = {.lex_state = 56, .external_lex_state = 3},
  [5203] = {.lex_state = 33, .external_lex_state = 3},
  [5204] = {.lex_state = 6, .external_lex_state = 3},
  [5205] = {.lex_state = 56, .external_lex_state = 3},
  [5206] = {.lex_state = 6, .external_lex_state = 3},
  [5207] = {.lex_state = 55, .external_lex_state = 3},
  [5208] = {.lex_state = 6, .external_lex_state = 3},
  [5209] = {.lex_state = 56, .external_lex_state = 3},
  [5210] = {.lex_state = 55, .external_lex_state = 3},
  [5211] = {.lex_state = 56, .external_lex_state = 3},
  [5212] = {.lex_state = 6, .external_lex_state = 3},
  [5213] = {.lex_state = 56, .external_lex_state = 3},
  [5214] = {.lex_state = 56, .external_lex_state = 3},
  [5215] = {.lex_state = 56, .external_lex_state = 3},
  [5216] = {.lex_state = 6, .external_lex_state = 3},
  [5217] = {.lex_state = 55, .external_lex_state = 3},
  [5218] = {.lex_state = 56, .external_lex_state = 3},
  [5219] = {.lex_state = 55, .external_lex_state = 3},
  [5220] = {.lex_state = 6, .external_lex_state = 3},
  [5221] = {.lex_state = 56, .external_lex_state = 3},
  [5222] = {.lex_state = 58, .external_lex_state = 3},
  [5223] = {.lex_state = 6, .external_lex_state = 3},
  [5224] = {.lex_state = 6, .external_lex_state = 3},
  [5225] = {.lex_state = 55, .external_lex_state = 3},
  [5226] = {.lex_state = 6, .external_lex_state = 3},
  [5227] = {.lex_state = 56, .external_lex_state = 3},
  [5228] = {.lex_state = 6, .external_lex_state = 3},
  [5229] = {.lex_state = 56, .external_lex_state = 3},
  [5230] = {.lex_state = 6, .external_lex_state = 3},
  [5231] = {.lex_state = 56, .external_lex_state = 3},
  [5232] = {.lex_state = 6, .external_lex_state = 3},
  [5233] = {.lex_state = 6, .external_lex_state = 3},
  [5234] = {.lex_state = 24, .external_lex_state = 3},
  [5235] = {.lex_state = 6, .external_lex_state = 3},
  [5236] = {.lex_state = 56, .external_lex_state = 3},
  [5237] = {.lex_state = 24, .external_lex_state = 3},
  [5238] = {.lex_state = 6, .external_lex_state = 3},
  [5239] = {.lex_state = 6, .external_lex_state = 3},
  [5240] = {.lex_state = 56, .external_lex_state = 3},
  [5241] = {.lex_state = 6, .external_lex_state = 3},
  [5242] = {.lex_state = 56, .external_lex_state = 3},
  [5243] = {.lex_state = 6, .external_lex_state = 3},
  [5244] = {.lex_state = 56, .external_lex_state = 3},
  [5245] = {.lex_state = 6, .external_lex_state = 3},
  [5246] = {.lex_state = 56, .external_lex_state = 3},
  [5247] = {.lex_state = 6, .external_lex_state = 3},
  [5248] = {.lex_state = 56, .external_lex_state = 3},
  [5249] = {.lex_state = 56, .external_lex_state = 3},
  [5250] = {.lex_state = 56, .external_lex_state = 3},
  [5251] = {.lex_state = 56, .external_lex_state = 3},
  [5252] = {.lex_state = 55, .external_lex_state = 3},
  [5253] = {.lex_state = 56, .external_lex_state = 3},
  [5254] = {.lex_state = 24, .external_lex_state = 3},
  [5255] = {.lex_state = 56, .external_lex_state = 3},
  [5256] = {.lex_state = 56, .external_lex_state = 3},
  [5257] = {.lex_state = 56, .external_lex_state = 3},
  [5258] = {.lex_state = 56, .external_lex_state = 3},
  [5259] = {.lex_state = 56, .external_lex_state = 3},
  [5260] = {.lex_state = 56, .external_lex_state = 3},
  [5261] = {.lex_state = 56, .external_lex_state = 3},
  [5262] = {.lex_state = 56, .external_lex_state = 3},
  [5263] = {.lex_state = 56, .external_lex_state = 3},
  [5264] = {.lex_state = 56, .external_lex_state = 3},
  [5265] = {.lex_state = 56, .external_lex_state = 3},
  [5266] = {.lex_state = 56, .external_lex_state = 3},
  [5267] = {.lex_state = 58, .external_lex_state = 3},
  [5268] = {.lex_state = 56, .external_lex_state = 3},
  [5269] = {.lex_state = 56, .external_lex_state = 3},
  [5270] = {.lex_state = 56, .external_lex_state = 3},
  [5271] = {.lex_state = 56, .external_lex_state = 3},
  [5272] = {.lex_state = 56, .external_lex_state = 3},
  [5273] = {.lex_state = 56, .external_lex_state = 3},
  [5274] = {.lex_state = 56, .external_lex_state = 3},
  [5275] = {.lex_state = 56, .external_lex_state = 3},
  [5276] = {.lex_state = 56, .external_lex_state = 3},
  [5277] = {.lex_state = 56, .external_lex_state = 3},
  [5278] = {.lex_state = 56, .external_lex_state = 3},
  [5279] = {.lex_state = 56, .external_lex_state = 3},
  [5280] = {.lex_state = 56, .external_lex_state = 3},
  [5281] = {.lex_state = 56, .external_lex_state = 3},
  [5282] = {.lex_state = 56, .external_lex_state = 3},
  [5283] = {.lex_state = 56, .external_lex_state = 3},
  [5284] = {.lex_state = 56, .external_lex_state = 3},
  [5285] = {.lex_state = 56, .external_lex_state = 3},
  [5286] = {.lex_state = 56, .external_lex_state = 3},
  [5287] = {.lex_state = 58, .external_lex_state = 3},
  [5288] = {.lex_state = 55, .external_lex_state = 3},
  [5289] = {.lex_state = 55, .external_lex_state = 3},
  [5290] = {.lex_state = 58, .external_lex_state = 3},
  [5291] = {.lex_state = 55, .external_lex_state = 3},
  [5292] = {.lex_state = 55, .external_lex_state = 3},
  [5293] = {.lex_state = 58, .external_lex_state = 3},
  [5294] = {.lex_state = 58, .external_lex_state = 3},
  [5295] = {.lex_state = 58, .external_lex_state = 3},
  [5296] = {.lex_state = 55, .external_lex_state = 3},
  [5297] = {.lex_state = 58, .external_lex_state = 3},
  [5298] = {.lex_state = 55, .external_lex_state = 3},
  [5299] = {.lex_state = 55, .external_lex_state = 3},
  [5300] = {.lex_state = 55, .external_lex_state = 3},
  [5301] = {.lex_state = 55, .external_lex_state = 3},
  [5302] = {.lex_state = 55, .external_lex_state = 3},
  [5303] = {.lex_state = 59, .external_lex_state = 3},
  [5304] = {.lex_state = 55, .external_lex_state = 3},
  [5305] = {.lex_state = 58, .external_lex_state = 3},
  [5306] = {.lex_state = 55, .external_lex_state = 3},
  [5307] = {.lex_state = 185, .external_lex_state = 3},
  [5308] = {.lex_state = 55, .external_lex_state = 3},
  [5309] = {.lex_state = 58, .external_lex_state = 3},
  [5310] = {.lex_state = 58, .external_lex_state = 3},
  [5311] = {.lex_state = 55, .external_lex_state = 3},
  [5312] = {.lex_state = 58, .external_lex_state = 3},
  [5313] = {.lex_state = 58, .external_lex_state = 3},
  [5314] = {.lex_state = 58, .external_lex_state = 3},
  [5315] = {.lex_state = 58, .external_lex_state = 3},
  [5316] = {.lex_state = 55, .external_lex_state = 3},
  [5317] = {.lex_state = 58, .external_lex_state = 3},
  [5318] = {.lex_state = 55, .external_lex_state = 3},
  [5319] = {.lex_state = 58, .external_lex_state = 3},
  [5320] = {.lex_state = 57, .external_lex_state = 3},
  [5321] = {.lex_state = 58, .external_lex_state = 3},
  [5322] = {.lex_state = 58, .external_lex_state = 3},
  [5323] = {.lex_state = 57, .external_lex_state = 3},
  [5324] = {.lex_state = 55, .external_lex_state = 3},
  [5325] = {.lex_state = 56, .external_lex_state = 3},
  [5326] = {.lex_state = 58, .external_lex_state = 3},
  [5327] = {.lex_state = 55, .external_lex_state = 3},
  [5328] = {.lex_state = 58, .external_lex_state = 3},
  [5329] = {.lex_state = 58, .external_lex_state = 3},
  [5330] = {.lex_state = 55, .external_lex_state = 3},
  [5331] = {.lex_state = 58, .external_lex_state = 3},
  [5332] = {.lex_state = 58, .external_lex_state = 3},
  [5333] = {.lex_state = 55, .external_lex_state = 3},
  [5334] = {.lex_state = 57, .external_lex_state = 3},
  [5335] = {.lex_state = 58, .external_lex_state = 3},
  [5336] = {.lex_state = 55, .external_lex_state = 3},
  [5337] = {.lex_state = 58, .external_lex_state = 3},
  [5338] = {.lex_state = 59, .external_lex_state = 3},
  [5339] = {.lex_state = 58, .external_lex_state = 3},
  [5340] = {.lex_state = 58, .external_lex_state = 3},
  [5341] = {.lex_state = 58, .external_lex_state = 3},
  [5342] = {.lex_state = 58, .external_lex_state = 3},
  [5343] = {.lex_state = 58, .external_lex_state = 3},
  [5344] = {.lex_state = 55, .external_lex_state = 3},
  [5345] = {.lex_state = 58, .external_lex_state = 3},
  [5346] = {.lex_state = 58, .external_lex_state = 3},
  [5347] = {.lex_state = 55, .external_lex_state = 3},
  [5348] = {.lex_state = 58, .external_lex_state = 3},
  [5349] = {.lex_state = 55, .external_lex_state = 3},
  [5350] = {.lex_state = 58, .external_lex_state = 3},
  [5351] = {.lex_state = 60, .external_lex_state = 3},
  [5352] = {.lex_state = 58, .external_lex_state = 3},
  [5353] = {.lex_state = 58, .external_lex_state = 3},
  [5354] = {.lex_state = 185, .external_lex_state = 3},
  [5355] = {.lex_state = 58, .external_lex_state = 3},
  [5356] = {.lex_state = 58, .external_lex_state = 3},
  [5357] = {.lex_state = 58, .external_lex_state = 3},
  [5358] = {.lex_state = 58, .external_lex_state = 3},
  [5359] = {.lex_state = 58, .external_lex_state = 3},
  [5360] = {.lex_state = 187, .external_lex_state = 3},
  [5361] = {.lex_state = 58, .external_lex_state = 3},
  [5362] = {.lex_state = 55, .external_lex_state = 3},
  [5363] = {.lex_state = 58, .external_lex_state = 3},
  [5364] = {.lex_state = 58, .external_lex_state = 3},
  [5365] = {.lex_state = 55, .external_lex_state = 3},
  [5366] = {.lex_state = 55, .external_lex_state = 3},
  [5367] = {.lex_state = 55, .external_lex_state = 3},
  [5368] = {.lex_state = 55, .external_lex_state = 3},
  [5369] = {.lex_state = 55, .external_lex_state = 3},
  [5370] = {.lex_state = 55, .external_lex_state = 3},
  [5371] = {.lex_state = 58, .external_lex_state = 3},
  [5372] = {.lex_state = 55, .external_lex_state = 3},
  [5373] = {.lex_state = 55, .external_lex_state = 3},
  [5374] = {.lex_state = 55, .external_lex_state = 3},
  [5375] = {.lex_state = 58, .external_lex_state = 3},
  [5376] = {.lex_state = 55, .external_lex_state = 3},
  [5377] = {.lex_state = 58, .external_lex_state = 3},
  [5378] = {.lex_state = 55, .external_lex_state = 3},
  [5379] = {.lex_state = 55, .external_lex_state = 3},
  [5380] = {.lex_state = 55, .external_lex_state = 3},
  [5381] = {.lex_state = 58, .external_lex_state = 3},
  [5382] = {.lex_state = 55, .external_lex_state = 3},
  [5383] = {.lex_state = 55, .external_lex_state = 3},
  [5384] = {.lex_state = 55, .external_lex_state = 3},
  [5385] = {.lex_state = 55, .external_lex_state = 3},
  [5386] = {.lex_state = 55, .external_lex_state = 3},
  [5387] = {.lex_state = 55, .external_lex_state = 3},
  [5388] = {.lex_state = 55, .external_lex_state = 3},
  [5389] = {.lex_state = 55, .external_lex_state = 3},
  [5390] = {.lex_state = 58, .external_lex_state = 3},
  [5391] = {.lex_state = 58, .external_lex_state = 3},
  [5392] = {.lex_state = 58, .external_lex_state = 3},
  [5393] = {.lex_state = 55, .external_lex_state = 3},
  [5394] = {.lex_state = 58, .external_lex_state = 3},
  [5395] = {.lex_state = 58, .external_lex_state = 3},
  [5396] = {.lex_state = 58, .external_lex_state = 3},
  [5397] = {.lex_state = 58, .external_lex_state = 3},
  [5398] = {.lex_state = 55, .external_lex_state = 3},
  [5399] = {.lex_state = 58, .external_lex_state = 3},
  [5400] = {.lex_state = 55, .external_lex_state = 3},
  [5401] = {.lex_state = 55, .external_lex_state = 3},
  [5402] = {.lex_state = 58, .external_lex_state = 3},
  [5403] = {.lex_state = 57, .external_lex_state = 3},
  [5404] = {.lex_state = 55, .external_lex_state = 3},
  [5405] = {.lex_state = 58, .external_lex_state = 3},
  [5406] = {.lex_state = 58, .external_lex_state = 3},
  [5407] = {.lex_state = 55, .external_lex_state = 3},
  [5408] = {.lex_state = 58, .external_lex_state = 3},
  [5409] = {.lex_state = 55, .external_lex_state = 3},
  [5410] = {.lex_state = 55, .external_lex_state = 3},
  [5411] = {.lex_state = 58, .external_lex_state = 3},
  [5412] = {.lex_state = 57, .external_lex_state = 3},
  [5413] = {.lex_state = 57, .external_lex_state = 3},
  [5414] = {.lex_state = 57, .external_lex_state = 3},
  [5415] = {.lex_state = 58, .external_lex_state = 3},
  [5416] = {.lex_state = 55, .external_lex_state = 3},
  [5417] = {.lex_state = 55, .external_lex_state = 3},
  [5418] = {.lex_state = 58, .external_lex_state = 3},
  [5419] = {.lex_state = 57, .external_lex_state = 3},
  [5420] = {.lex_state = 55, .external_lex_state = 3},
  [5421] = {.lex_state = 58, .external_lex_state = 3},
  [5422] = {.lex_state = 57, .external_lex_state = 3},
  [5423] = {.lex_state = 57, .external_lex_state = 3},
  [5424] = {.lex_state = 55, .external_lex_state = 3},
  [5425] = {.lex_state = 58, .external_lex_state = 3},
  [5426] = {.lex_state = 58, .external_lex_state = 3},
  [5427] = {.lex_state = 58, .external_lex_state = 3},
  [5428] = {.lex_state = 58, .external_lex_state = 3},
  [5429] = {.lex_state = 58, .external_lex_state = 3},
  [5430] = {.lex_state = 55, .external_lex_state = 3},
  [5431] = {.lex_state = 55, .external_lex_state = 3},
  [5432] = {.lex_state = 55, .external_lex_state = 3},
  [5433] = {.lex_state = 55, .external_lex_state = 3},
  [5434] = {.lex_state = 55, .external_lex_state = 3},
  [5435] = {.lex_state = 58, .external_lex_state = 3},
  [5436] = {.lex_state = 55, .external_lex_state = 3},
  [5437] = {.lex_state = 58, .external_lex_state = 3},
  [5438] = {.lex_state = 187, .external_lex_state = 3},
  [5439] = {.lex_state = 55, .external_lex_state = 3},
  [5440] = {.lex_state = 58, .external_lex_state = 3},
  [5441] = {.lex_state = 55, .external_lex_state = 3},
  [5442] = {.lex_state = 55, .external_lex_state = 3},
  [5443] = {.lex_state = 58, .external_lex_state = 3},
  [5444] = {.lex_state = 57, .external_lex_state = 3},
  [5445] = {.lex_state = 55, .external_lex_state = 3},
  [5446] = {.lex_state = 58, .external_lex_state = 3},
  [5447] = {.lex_state = 58, .external_lex_state = 3},
  [5448] = {.lex_state = 55, .external_lex_state = 3},
  [5449] = {.lex_state = 55, .external_lex_state = 3},
  [5450] = {.lex_state = 58, .external_lex_state = 3},
  [5451] = {.lex_state = 55, .external_lex_state = 3},
  [5452] = {.lex_state = 58, .external_lex_state = 3},
  [5453] = {.lex_state = 58, .external_lex_state = 3},
  [5454] = {.lex_state = 55, .external_lex_state = 3},
  [5455] = {.lex_state = 55, .external_lex_state = 3},
  [5456] = {.lex_state = 55, .external_lex_state = 3},
  [5457] = {.lex_state = 55, .external_lex_state = 3},
  [5458] = {.lex_state = 58, .external_lex_state = 3},
  [5459] = {.lex_state = 55, .external_lex_state = 3},
  [5460] = {.lex_state = 55, .external_lex_state = 3},
  [5461] = {.lex_state = 55, .external_lex_state = 3},
  [5462] = {.lex_state = 57, .external_lex_state = 3},
  [5463] = {.lex_state = 57, .external_lex_state = 3},
  [5464] = {.lex_state = 193, .external_lex_state = 3},
  [5465] = {.lex_state = 57, .external_lex_state = 3},
  [5466] = {.lex_state = 57, .external_lex_state = 3},
  [5467] = {.lex_state = 57, .external_lex_state = 3},
  [5468] = {.lex_state = 437, .external_lex_state = 2},
  [5469] = {.lex_state = 191, .external_lex_state = 3},
  [5470] = {.lex_state = 186, .external_lex_state = 3},
  [5471] = {.lex_state = 437, .external_lex_state = 2},
  [5472] = {.lex_state = 57, .external_lex_state = 3},
  [5473] = {.lex_state = 57, .external_lex_state = 3},
  [5474] = {.lex_state = 57, .external_lex_state = 3},
  [5475] = {.lex_state = 57, .external_lex_state = 3},
  [5476] = {.lex_state = 57, .external_lex_state = 3},
  [5477] = {.lex_state = 57, .external_lex_state = 3},
  [5478] = {.lex_state = 57, .external_lex_state = 3},
  [5479] = {.lex_state = 191, .external_lex_state = 3},
  [5480] = {.lex_state = 57, .external_lex_state = 3},
  [5481] = {.lex_state = 57, .external_lex_state = 3},
  [5482] = {.lex_state = 57, .external_lex_state = 3},
  [5483] = {.lex_state = 57, .external_lex_state = 3},
  [5484] = {.lex_state = 57, .external_lex_state = 3},
  [5485] = {.lex_state = 57, .external_lex_state = 3},
  [5486] = {.lex_state = 57, .external_lex_state = 3},
  [5487] = {.lex_state = 57, .external_lex_state = 3},
  [5488] = {.lex_state = 191, .external_lex_state = 3},
  [5489] = {.lex_state = 191, .external_lex_state = 3},
  [5490] = {.lex_state = 57, .external_lex_state = 3},
  [5491] = {.lex_state = 57, .external_lex_state = 3},
  [5492] = {.lex_state = 193, .external_lex_state = 3},
  [5493] = {.lex_state = 57, .external_lex_state = 3},
  [5494] = {.lex_state = 201, .external_lex_state = 3},
  [5495] = {.lex_state = 186, .external_lex_state = 3},
  [5496] = {.lex_state = 193, .external_lex_state = 3},
  [5497] = {.lex_state = 57, .external_lex_state = 3},
  [5498] = {.lex_state = 57, .external_lex_state = 3},
  [5499] = {.lex_state = 57, .external_lex_state = 3},
  [5500] = {.lex_state = 193, .external_lex_state = 3},
  [5501] = {.lex_state = 57, .external_lex_state = 3},
  [5502] = {.lex_state = 57, .external_lex_state = 3},
  [5503] = {.lex_state = 57, .external_lex_state = 3},
  [5504] = {.lex_state = 57, .external_lex_state = 3},
  [5505] = {.lex_state = 57, .external_lex_state = 3},
  [5506] = {.lex_state = 57, .external_lex_state = 3},
  [5507] = {.lex_state = 57, .external_lex_state = 3},
  [5508] = {.lex_state = 57, .external_lex_state = 3},
  [5509] = {.lex_state = 57, .external_lex_state = 3},
  [5510] = {.lex_state = 57, .external_lex_state = 3},
  [5511] = {.lex_state = 58, .external_lex_state = 3},
  [5512] = {.lex_state = 57, .external_lex_state = 3},
  [5513] = {.lex_state = 193, .external_lex_state = 3},
  [5514] = {.lex_state = 57, .external_lex_state = 3},
  [5515] = {.lex_state = 57, .external_lex_state = 3},
  [5516] = {.lex_state = 57, .external_lex_state = 3},
  [5517] = {.lex_state = 57, .external_lex_state = 3},
  [5518] = {.lex_state = 57, .external_lex_state = 3},
  [5519] = {.lex_state = 57, .external_lex_state = 3},
  [5520] = {.lex_state = 57, .external_lex_state = 3},
  [5521] = {.lex_state = 57, .external_lex_state = 3},
  [5522] = {.lex_state = 57, .external_lex_state = 3},
  [5523] = {.lex_state = 57, .external_lex_state = 3},
  [5524] = {.lex_state = 203, .external_lex_state = 3},
  [5525] = {.lex_state = 185, .external_lex_state = 3},
  [5526] = {.lex_state = 57, .external_lex_state = 3},
  [5527] = {.lex_state = 57, .external_lex_state = 3},
  [5528] = {.lex_state = 57, .external_lex_state = 3},
  [5529] = {.lex_state = 57, .external_lex_state = 3},
  [5530] = {.lex_state = 57, .external_lex_state = 3},
  [5531] = {.lex_state = 57, .external_lex_state = 3},
  [5532] = {.lex_state = 57, .external_lex_state = 3},
  [5533] = {.lex_state = 437, .external_lex_state = 2},
  [5534] = {.lex_state = 187, .external_lex_state = 3},
  [5535] = {.lex_state = 57, .external_lex_state = 3},
  [5536] = {.lex_state = 191, .external_lex_state = 3},
  [5537] = {.lex_state = 60, .external_lex_state = 3},
  [5538] = {.lex_state = 57, .external_lex_state = 3},
  [5539] = {.lex_state = 193, .external_lex_state = 3},
  [5540] = {.lex_state = 188, .external_lex_state = 3},
  [5541] = {.lex_state = 191, .external_lex_state = 3},
  [5542] = {.lex_state = 57, .external_lex_state = 3},
  [5543] = {.lex_state = 57, .external_lex_state = 3},
  [5544] = {.lex_state = 185, .external_lex_state = 3},
  [5545] = {.lex_state = 57, .external_lex_state = 3},
  [5546] = {.lex_state = 185, .external_lex_state = 3},
  [5547] = {.lex_state = 57, .external_lex_state = 3},
  [5548] = {.lex_state = 57, .external_lex_state = 3},
  [5549] = {.lex_state = 57, .external_lex_state = 3},
  [5550] = {.lex_state = 57, .external_lex_state = 3},
  [5551] = {.lex_state = 60, .external_lex_state = 3},
  [5552] = {.lex_state = 57, .external_lex_state = 3},
  [5553] = {.lex_state = 57, .external_lex_state = 3},
  [5554] = {.lex_state = 57, .external_lex_state = 3},
  [5555] = {.lex_state = 57, .external_lex_state = 3},
  [5556] = {.lex_state = 191, .external_lex_state = 3},
  [5557] = {.lex_state = 57, .external_lex_state = 3},
  [5558] = {.lex_state = 193, .external_lex_state = 3},
  [5559] = {.lex_state = 191, .external_lex_state = 3},
  [5560] = {.lex_state = 57, .external_lex_state = 3},
  [5561] = {.lex_state = 193, .external_lex_state = 3},
  [5562] = {.lex_state = 188, .external_lex_state = 3},
  [5563] = {.lex_state = 191, .external_lex_state = 3},
  [5564] = {.lex_state = 57, .external_lex_state = 3},
  [5565] = {.lex_state = 187, .external_lex_state = 3},
  [5566] = {.lex_state = 191, .external_lex_state = 3},
  [5567] = {.lex_state = 57, .external_lex_state = 3},
  [5568] = {.lex_state = 193, .external_lex_state = 3},
  [5569] = {.lex_state = 57, .external_lex_state = 3},
  [5570] = {.lex_state = 191, .external_lex_state = 3},
  [5571] = {.lex_state = 193, .external_lex_state = 3},
  [5572] = {.lex_state = 193, .external_lex_state = 3},
  [5573] = {.lex_state = 185, .external_lex_state = 3},
  [5574] = {.lex_state = 187, .external_lex_state = 3},
  [5575] = {.lex_state = 57, .external_lex_state = 3},
  [5576] = {.lex_state = 57, .external_lex_state = 3},
  [5577] = {.lex_state = 57, .external_lex_state = 3},
  [5578] = {.lex_state = 57, .external_lex_state = 3},
  [5579] = {.lex_state = 57, .external_lex_state = 3},
  [5580] = {.lex_state = 165, .external_lex_state = 3},
  [5581] = {.lex_state = 187, .external_lex_state = 3},
  [5582] = {.lex_state = 57, .external_lex_state = 3},
  [5583] = {.lex_state = 187, .external_lex_state = 3},
  [5584] = {.lex_state = 194, .external_lex_state = 3},
  [5585] = {.lex_state = 187, .external_lex_state = 3},
  [5586] = {.lex_state = 187, .external_lex_state = 3},
  [5587] = {.lex_state = 187, .external_lex_state = 3},
  [5588] = {.lex_state = 187, .external_lex_state = 3},
  [5589] = {.lex_state = 185, .external_lex_state = 3},
  [5590] = {.lex_state = 73, .external_lex_state = 3},
  [5591] = {.lex_state = 187, .external_lex_state = 3},
  [5592] = {.lex_state = 194, .external_lex_state = 3},
  [5593] = {.lex_state = 185, .external_lex_state = 3},
  [5594] = {.lex_state = 185, .external_lex_state = 3},
  [5595] = {.lex_state = 187, .external_lex_state = 3},
  [5596] = {.lex_state = 194, .external_lex_state = 3},
  [5597] = {.lex_state = 187, .external_lex_state = 3},
  [5598] = {.lex_state = 185, .external_lex_state = 3},
  [5599] = {.lex_state = 187, .external_lex_state = 3},
  [5600] = {.lex_state = 187, .external_lex_state = 3},
  [5601] = {.lex_state = 185, .external_lex_state = 3},
  [5602] = {.lex_state = 194, .external_lex_state = 3},
  [5603] = {.lex_state = 185, .external_lex_state = 3},
  [5604] = {.lex_state = 192, .external_lex_state = 3},
  [5605] = {.lex_state = 185, .external_lex_state = 3},
  [5606] = {.lex_state = 185, .external_lex_state = 3},
  [5607] = {.lex_state = 185, .external_lex_state = 3},
  [5608] = {.lex_state = 185, .external_lex_state = 3},
  [5609] = {.lex_state = 187, .external_lex_state = 3},
  [5610] = {.lex_state = 187, .external_lex_state = 3},
  [5611] = {.lex_state = 185, .external_lex_state = 3},
  [5612] = {.lex_state = 194, .external_lex_state = 3},
  [5613] = {.lex_state = 187, .external_lex_state = 3},
  [5614] = {.lex_state = 204, .external_lex_state = 3},
  [5615] = {.lex_state = 185, .external_lex_state = 3},
  [5616] = {.lex_state = 185, .external_lex_state = 3},
  [5617] = {.lex_state = 185, .external_lex_state = 3},
  [5618] = {.lex_state = 185, .external_lex_state = 3},
  [5619] = {.lex_state = 187, .external_lex_state = 3},
  [5620] = {.lex_state = 185, .external_lex_state = 3},
  [5621] = {.lex_state = 187, .external_lex_state = 3},
  [5622] = {.lex_state = 185, .external_lex_state = 3},
  [5623] = {.lex_state = 185, .external_lex_state = 3},
  [5624] = {.lex_state = 194, .external_lex_state = 3},
  [5625] = {.lex_state = 187, .external_lex_state = 3},
  [5626] = {.lex_state = 194, .external_lex_state = 3},
  [5627] = {.lex_state = 185, .external_lex_state = 3},
  [5628] = {.lex_state = 187, .external_lex_state = 3},
  [5629] = {.lex_state = 194, .external_lex_state = 3},
  [5630] = {.lex_state = 187, .external_lex_state = 3},
  [5631] = {.lex_state = 187, .external_lex_state = 3},
  [5632] = {.lex_state = 194, .external_lex_state = 3},
  [5633] = {.lex_state = 185, .external_lex_state = 3},
  [5634] = {.lex_state = 185, .external_lex_state = 3},
  [5635] = {.lex_state = 185, .external_lex_state = 3},
  [5636] = {.lex_state = 73, .external_lex_state = 3},
  [5637] = {.lex_state = 185, .external_lex_state = 3},
  [5638] = {.lex_state = 73, .external_lex_state = 3},
  [5639] = {.lex_state = 56, .external_lex_state = 3},
  [5640] = {.lex_state = 187, .external_lex_state = 3},
  [5641] = {.lex_state = 185, .external_lex_state = 3},
  [5642] = {.lex_state = 202, .external_lex_state = 3},
  [5643] = {.lex_state = 187, .external_lex_state = 3},
  [5644] = {.lex_state = 185, .external_lex_state = 3},
  [5645] = {.lex_state = 185, .external_lex_state = 3},
  [5646] = {.lex_state = 185, .external_lex_state = 3},
  [5647] = {.lex_state = 185, .external_lex_state = 3},
  [5648] = {.lex_state = 73, .external_lex_state = 3},
  [5649] = {.lex_state = 185, .external_lex_state = 3},
  [5650] = {.lex_state = 187, .external_lex_state = 3},
  [5651] = {.lex_state = 185, .external_lex_state = 3},
  [5652] = {.lex_state = 185, .external_lex_state = 3},
  [5653] = {.lex_state = 187, .external_lex_state = 3},
  [5654] = {.lex_state = 187, .external_lex_state = 3},
  [5655] = {.lex_state = 187, .external_lex_state = 3},
  [5656] = {.lex_state = 185, .external_lex_state = 3},
  [5657] = {.lex_state = 186, .external_lex_state = 3},
  [5658] = {.lex_state = 188, .external_lex_state = 3},
  [5659] = {.lex_state = 186, .external_lex_state = 3},
  [5660] = {.lex_state = 164, .external_lex_state = 3},
  [5661] = {.lex_state = 192, .external_lex_state = 3},
  [5662] = {.lex_state = 187, .external_lex_state = 3},
  [5663] = {.lex_state = 192, .external_lex_state = 3},
  [5664] = {.lex_state = 187, .external_lex_state = 3},
  [5665] = {.lex_state = 187, .external_lex_state = 3},
  [5666] = {.lex_state = 185, .external_lex_state = 3},
  [5667] = {.lex_state = 185, .external_lex_state = 3},
  [5668] = {.lex_state = 185, .external_lex_state = 3},
  [5669] = {.lex_state = 185, .external_lex_state = 3},
  [5670] = {.lex_state = 185, .external_lex_state = 3},
  [5671] = {.lex_state = 187, .external_lex_state = 3},
  [5672] = {.lex_state = 187, .external_lex_state = 3},
  [5673] = {.lex_state = 187, .external_lex_state = 3},
  [5674] = {.lex_state = 185, .external_lex_state = 3},
  [5675] = {.lex_state = 186, .external_lex_state = 3},
  [5676] = {.lex_state = 185, .external_lex_state = 3},
  [5677] = {.lex_state = 187, .external_lex_state = 3},
  [5678] = {.lex_state = 73, .external_lex_state = 3},
  [5679] = {.lex_state = 187, .external_lex_state = 3},
  [5680] = {.lex_state = 73, .external_lex_state = 3},
  [5681] = {.lex_state = 187, .external_lex_state = 3},
  [5682] = {.lex_state = 187, .external_lex_state = 3},
  [5683] = {.lex_state = 192, .external_lex_state = 3},
  [5684] = {.lex_state = 192, .external_lex_state = 3},
  [5685] = {.lex_state = 192, .external_lex_state = 3},
  [5686] = {.lex_state = 192, .external_lex_state = 3},
  [5687] = {.lex_state = 185, .external_lex_state = 3},
  [5688] = {.lex_state = 192, .external_lex_state = 3},
  [5689] = {.lex_state = 187, .external_lex_state = 3},
  [5690] = {.lex_state = 187, .external_lex_state = 3},
  [5691] = {.lex_state = 185, .external_lex_state = 3},
  [5692] = {.lex_state = 185, .external_lex_state = 3},
  [5693] = {.lex_state = 187, .external_lex_state = 3},
  [5694] = {.lex_state = 185, .external_lex_state = 3},
  [5695] = {.lex_state = 185, .external_lex_state = 3},
  [5696] = {.lex_state = 185, .external_lex_state = 3},
  [5697] = {.lex_state = 187, .external_lex_state = 3},
  [5698] = {.lex_state = 73, .external_lex_state = 3},
  [5699] = {.lex_state = 185, .external_lex_state = 3},
  [5700] = {.lex_state = 187, .external_lex_state = 3},
  [5701] = {.lex_state = 192, .external_lex_state = 3},
  [5702] = {.lex_state = 194, .external_lex_state = 3},
  [5703] = {.lex_state = 187, .external_lex_state = 3},
  [5704] = {.lex_state = 192, .external_lex_state = 3},
  [5705] = {.lex_state = 185, .external_lex_state = 3},
  [5706] = {.lex_state = 192, .external_lex_state = 3},
  [5707] = {.lex_state = 185, .external_lex_state = 3},
  [5708] = {.lex_state = 187, .external_lex_state = 3},
  [5709] = {.lex_state = 185, .external_lex_state = 3},
  [5710] = {.lex_state = 73, .external_lex_state = 3},
  [5711] = {.lex_state = 185, .external_lex_state = 3},
  [5712] = {.lex_state = 73, .external_lex_state = 3},
  [5713] = {.lex_state = 187, .external_lex_state = 3},
  [5714] = {.lex_state = 73, .external_lex_state = 3},
  [5715] = {.lex_state = 73, .external_lex_state = 3},
  [5716] = {.lex_state = 188, .external_lex_state = 3},
  [5717] = {.lex_state = 188, .external_lex_state = 3},
  [5718] = {.lex_state = 185, .external_lex_state = 3},
  [5719] = {.lex_state = 186, .external_lex_state = 3},
  [5720] = {.lex_state = 185, .external_lex_state = 3},
  [5721] = {.lex_state = 185, .external_lex_state = 3},
  [5722] = {.lex_state = 167, .external_lex_state = 3},
  [5723] = {.lex_state = 187, .external_lex_state = 3},
  [5724] = {.lex_state = 187, .external_lex_state = 3},
  [5725] = {.lex_state = 187, .external_lex_state = 3},
  [5726] = {.lex_state = 56, .external_lex_state = 3},
  [5727] = {.lex_state = 187, .external_lex_state = 3},
  [5728] = {.lex_state = 187, .external_lex_state = 3},
  [5729] = {.lex_state = 187, .external_lex_state = 3},
  [5730] = {.lex_state = 188, .external_lex_state = 3},
  [5731] = {.lex_state = 187, .external_lex_state = 3},
  [5732] = {.lex_state = 185, .external_lex_state = 3},
  [5733] = {.lex_state = 185, .external_lex_state = 3},
  [5734] = {.lex_state = 194, .external_lex_state = 3},
  [5735] = {.lex_state = 185, .external_lex_state = 3},
  [5736] = {.lex_state = 187, .external_lex_state = 3},
  [5737] = {.lex_state = 187, .external_lex_state = 3},
  [5738] = {.lex_state = 187, .external_lex_state = 3},
  [5739] = {.lex_state = 187, .external_lex_state = 3},
  [5740] = {.lex_state = 187, .external_lex_state = 3},
  [5741] = {.lex_state = 187, .external_lex_state = 3},
  [5742] = {.lex_state = 185, .external_lex_state = 3},
  [5743] = {.lex_state = 187, .external_lex_state = 3},
  [5744] = {.lex_state = 185, .external_lex_state = 3},
  [5745] = {.lex_state = 187, .external_lex_state = 3},
  [5746] = {.lex_state = 186, .external_lex_state = 3},
  [5747] = {.lex_state = 188, .external_lex_state = 3},
  [5748] = {.lex_state = 74, .external_lex_state = 3},
  [5749] = {.lex_state = 186, .external_lex_state = 3},
  [5750] = {.lex_state = 188, .external_lex_state = 3},
  [5751] = {.lex_state = 73, .external_lex_state = 3},
  [5752] = {.lex_state = 186, .external_lex_state = 3},
  [5753] = {.lex_state = 186, .external_lex_state = 3},
  [5754] = {.lex_state = 188, .external_lex_state = 3},
  [5755] = {.lex_state = 73, .external_lex_state = 3},
  [5756] = {.lex_state = 186, .external_lex_state = 3},
  [5757] = {.lex_state = 188, .external_lex_state = 3},
  [5758] = {.lex_state = 186, .external_lex_state = 3},
  [5759] = {.lex_state = 186, .external_lex_state = 3},
  [5760] = {.lex_state = 186, .external_lex_state = 3},
  [5761] = {.lex_state = 186, .external_lex_state = 3},
  [5762] = {.lex_state = 73, .external_lex_state = 3},
  [5763] = {.lex_state = 186, .external_lex_state = 3},
  [5764] = {.lex_state = 73, .external_lex_state = 3},
  [5765] = {.lex_state = 73, .external_lex_state = 3},
  [5766] = {.lex_state = 186, .external_lex_state = 3},
  [5767] = {.lex_state = 73, .external_lex_state = 3},
  [5768] = {.lex_state = 74, .external_lex_state = 3},
  [5769] = {.lex_state = 73, .external_lex_state = 3},
  [5770] = {.lex_state = 186, .external_lex_state = 3},
  [5771] = {.lex_state = 188, .external_lex_state = 3},
  [5772] = {.lex_state = 186, .external_lex_state = 3},
  [5773] = {.lex_state = 188, .external_lex_state = 3},
  [5774] = {.lex_state = 186, .external_lex_state = 3},
  [5775] = {.lex_state = 73, .external_lex_state = 3},
  [5776] = {.lex_state = 186, .external_lex_state = 3},
  [5777] = {.lex_state = 73, .external_lex_state = 3},
  [5778] = {.lex_state = 73, .external_lex_state = 3},
  [5779] = {.lex_state = 186, .external_lex_state = 3},
  [5780] = {.lex_state = 73, .external_lex_state = 3},
  [5781] = {.lex_state = 186, .external_lex_state = 3},
  [5782] = {.lex_state = 55, .external_lex_state = 3},
  [5783] = {.lex_state = 188, .external_lex_state = 3},
  [5784] = {.lex_state = 186, .external_lex_state = 3},
  [5785] = {.lex_state = 186, .external_lex_state = 3},
  [5786] = {.lex_state = 73, .external_lex_state = 3},
  [5787] = {.lex_state = 73, .external_lex_state = 3},
  [5788] = {.lex_state = 73, .external_lex_state = 3},
  [5789] = {.lex_state = 73, .external_lex_state = 3},
  [5790] = {.lex_state = 73, .external_lex_state = 3},
  [5791] = {.lex_state = 73, .external_lex_state = 3},
  [5792] = {.lex_state = 186, .external_lex_state = 3},
  [5793] = {.lex_state = 73, .external_lex_state = 3},
  [5794] = {.lex_state = 73, .external_lex_state = 3},
  [5795] = {.lex_state = 73, .external_lex_state = 3},
  [5796] = {.lex_state = 186, .external_lex_state = 3},
  [5797] = {.lex_state = 58, .external_lex_state = 3},
  [5798] = {.lex_state = 73, .external_lex_state = 3},
  [5799] = {.lex_state = 188, .external_lex_state = 3},
  [5800] = {.lex_state = 73, .external_lex_state = 3},
  [5801] = {.lex_state = 188, .external_lex_state = 3},
  [5802] = {.lex_state = 73, .external_lex_state = 3},
  [5803] = {.lex_state = 188, .external_lex_state = 3},
  [5804] = {.lex_state = 186, .external_lex_state = 3},
  [5805] = {.lex_state = 188, .external_lex_state = 3},
  [5806] = {.lex_state = 188, .external_lex_state = 3},
  [5807] = {.lex_state = 73, .external_lex_state = 3},
  [5808] = {.lex_state = 186, .external_lex_state = 3},
  [5809] = {.lex_state = 186, .external_lex_state = 3},
  [5810] = {.lex_state = 186, .external_lex_state = 3},
  [5811] = {.lex_state = 186, .external_lex_state = 3},
  [5812] = {.lex_state = 188, .external_lex_state = 3},
  [5813] = {.lex_state = 186, .external_lex_state = 3},
  [5814] = {.lex_state = 186, .external_lex_state = 3},
  [5815] = {.lex_state = 186, .external_lex_state = 3},
  [5816] = {.lex_state = 188, .external_lex_state = 3},
  [5817] = {.lex_state = 188, .external_lex_state = 3},
  [5818] = {.lex_state = 74, .external_lex_state = 3},
  [5819] = {.lex_state = 186, .external_lex_state = 3},
  [5820] = {.lex_state = 188, .external_lex_state = 3},
  [5821] = {.lex_state = 73, .external_lex_state = 3},
  [5822] = {.lex_state = 188, .external_lex_state = 3},
  [5823] = {.lex_state = 188, .external_lex_state = 3},
  [5824] = {.lex_state = 73, .external_lex_state = 3},
  [5825] = {.lex_state = 188, .external_lex_state = 3},
  [5826] = {.lex_state = 73, .external_lex_state = 3},
  [5827] = {.lex_state = 73, .external_lex_state = 3},
  [5828] = {.lex_state = 186, .external_lex_state = 3},
  [5829] = {.lex_state = 188, .external_lex_state = 3},
  [5830] = {.lex_state = 188, .external_lex_state = 3},
  [5831] = {.lex_state = 73, .external_lex_state = 3},
  [5832] = {.lex_state = 186, .external_lex_state = 3},
  [5833] = {.lex_state = 73, .external_lex_state = 3},
  [5834] = {.lex_state = 188, .external_lex_state = 3},
  [5835] = {.lex_state = 186, .external_lex_state = 3},
  [5836] = {.lex_state = 188, .external_lex_state = 3},
  [5837] = {.lex_state = 188, .external_lex_state = 3},
  [5838] = {.lex_state = 188, .external_lex_state = 3},
  [5839] = {.lex_state = 73, .external_lex_state = 3},
  [5840] = {.lex_state = 186, .external_lex_state = 3},
  [5841] = {.lex_state = 73, .external_lex_state = 3},
  [5842] = {.lex_state = 73, .external_lex_state = 3},
  [5843] = {.lex_state = 186, .external_lex_state = 3},
  [5844] = {.lex_state = 73, .external_lex_state = 3},
  [5845] = {.lex_state = 73, .external_lex_state = 3},
  [5846] = {.lex_state = 186, .external_lex_state = 3},
  [5847] = {.lex_state = 73, .external_lex_state = 3},
  [5848] = {.lex_state = 188, .external_lex_state = 3},
  [5849] = {.lex_state = 188, .external_lex_state = 3},
  [5850] = {.lex_state = 73, .external_lex_state = 3},
  [5851] = {.lex_state = 186, .external_lex_state = 3},
  [5852] = {.lex_state = 188, .external_lex_state = 3},
  [5853] = {.lex_state = 188, .external_lex_state = 3},
  [5854] = {.lex_state = 58, .external_lex_state = 3},
  [5855] = {.lex_state = 186, .external_lex_state = 3},
  [5856] = {.lex_state = 186, .external_lex_state = 3},
  [5857] = {.lex_state = 188, .external_lex_state = 3},
  [5858] = {.lex_state = 73, .external_lex_state = 3},
  [5859] = {.lex_state = 73, .external_lex_state = 3},
  [5860] = {.lex_state = 188, .external_lex_state = 3},
  [5861] = {.lex_state = 73, .external_lex_state = 3},
  [5862] = {.lex_state = 73, .external_lex_state = 3},
  [5863] = {.lex_state = 73, .external_lex_state = 3},
  [5864] = {.lex_state = 186, .external_lex_state = 3},
  [5865] = {.lex_state = 188, .external_lex_state = 3},
  [5866] = {.lex_state = 186, .external_lex_state = 3},
  [5867] = {.lex_state = 73, .external_lex_state = 3},
  [5868] = {.lex_state = 186, .external_lex_state = 3},
  [5869] = {.lex_state = 73, .external_lex_state = 3},
  [5870] = {.lex_state = 186, .external_lex_state = 3},
  [5871] = {.lex_state = 73, .external_lex_state = 3},
  [5872] = {.lex_state = 188, .external_lex_state = 3},
  [5873] = {.lex_state = 188, .external_lex_state = 3},
  [5874] = {.lex_state = 73, .external_lex_state = 3},
  [5875] = {.lex_state = 74, .external_lex_state = 3},
  [5876] = {.lex_state = 73, .external_lex_state = 3},
  [5877] = {.lex_state = 73, .external_lex_state = 3},
  [5878] = {.lex_state = 73, .external_lex_state = 3},
  [5879] = {.lex_state = 73, .external_lex_state = 3},
  [5880] = {.lex_state = 188, .external_lex_state = 3},
  [5881] = {.lex_state = 73, .external_lex_state = 3},
  [5882] = {.lex_state = 73, .external_lex_state = 3},
  [5883] = {.lex_state = 73, .external_lex_state = 3},
  [5884] = {.lex_state = 73, .external_lex_state = 3},
  [5885] = {.lex_state = 73, .external_lex_state = 3},
  [5886] = {.lex_state = 73, .external_lex_state = 3},
  [5887] = {.lex_state = 188, .external_lex_state = 3},
  [5888] = {.lex_state = 186, .external_lex_state = 3},
  [5889] = {.lex_state = 73, .external_lex_state = 3},
  [5890] = {.lex_state = 73, .external_lex_state = 3},
  [5891] = {.lex_state = 186, .external_lex_state = 3},
  [5892] = {.lex_state = 74, .external_lex_state = 3},
  [5893] = {.lex_state = 74, .external_lex_state = 3},
  [5894] = {.lex_state = 74, .external_lex_state = 3},
  [5895] = {.lex_state = 188, .external_lex_state = 3},
  [5896] = {.lex_state = 188, .external_lex_state = 3},
  [5897] = {.lex_state = 74, .external_lex_state = 3},
  [5898] = {.lex_state = 74, .external_lex_state = 3},
  [5899] = {.lex_state = 74, .external_lex_state = 3},
  [5900] = {.lex_state = 188, .external_lex_state = 3},
  [5901] = {.lex_state = 73, .external_lex_state = 3},
  [5902] = {.lex_state = 188, .external_lex_state = 3},
  [5903] = {.lex_state = 188, .external_lex_state = 3},
  [5904] = {.lex_state = 188, .external_lex_state = 3},
  [5905] = {.lex_state = 73, .external_lex_state = 3},
  [5906] = {.lex_state = 73, .external_lex_state = 3},
  [5907] = {.lex_state = 73, .external_lex_state = 3},
  [5908] = {.lex_state = 188, .external_lex_state = 3},
  [5909] = {.lex_state = 188, .external_lex_state = 3},
  [5910] = {.lex_state = 186, .external_lex_state = 3},
  [5911] = {.lex_state = 186, .external_lex_state = 3},
  [5912] = {.lex_state = 166, .external_lex_state = 3},
  [5913] = {.lex_state = 188, .external_lex_state = 3},
  [5914] = {.lex_state = 73, .external_lex_state = 3},
  [5915] = {.lex_state = 73, .external_lex_state = 3},
  [5916] = {.lex_state = 73, .external_lex_state = 3},
  [5917] = {.lex_state = 188, .external_lex_state = 3},
  [5918] = {.lex_state = 186, .external_lex_state = 3},
  [5919] = {.lex_state = 186, .external_lex_state = 3},
  [5920] = {.lex_state = 74, .external_lex_state = 3},
  [5921] = {.lex_state = 186, .external_lex_state = 3},
  [5922] = {.lex_state = 186, .external_lex_state = 3},
  [5923] = {.lex_state = 188, .external_lex_state = 3},
  [5924] = {.lex_state = 73, .external_lex_state = 3},
  [5925] = {.lex_state = 186, .external_lex_state = 3},
  [5926] = {.lex_state = 73, .external_lex_state = 3},
  [5927] = {.lex_state = 188, .external_lex_state = 3},
  [5928] = {.lex_state = 186, .external_lex_state = 3},
  [5929] = {.lex_state = 73, .external_lex_state = 3},
  [5930] = {.lex_state = 186, .external_lex_state = 3},
  [5931] = {.lex_state = 186, .external_lex_state = 3},
  [5932] = {.lex_state = 188, .external_lex_state = 3},
  [5933] = {.lex_state = 186, .external_lex_state = 3},
  [5934] = {.lex_state = 188, .external_lex_state = 3},
  [5935] = {.lex_state = 188, .external_lex_state = 3},
  [5936] = {.lex_state = 188, .external_lex_state = 3},
  [5937] = {.lex_state = 188, .external_lex_state = 3},
  [5938] = {.lex_state = 188, .external_lex_state = 3},
  [5939] = {.lex_state = 73, .external_lex_state = 3},
  [5940] = {.lex_state = 73, .external_lex_state = 3},
  [5941] = {.lex_state = 73, .external_lex_state = 3},
  [5942] = {.lex_state = 186, .external_lex_state = 3},
  [5943] = {.lex_state = 73, .external_lex_state = 3},
  [5944] = {.lex_state = 73, .external_lex_state = 3},
  [5945] = {.lex_state = 186, .external_lex_state = 3},
  [5946] = {.lex_state = 188, .external_lex_state = 3},
  [5947] = {.lex_state = 73, .external_lex_state = 3},
  [5948] = {.lex_state = 188, .external_lex_state = 3},
  [5949] = {.lex_state = 73, .external_lex_state = 3},
  [5950] = {.lex_state = 73, .external_lex_state = 3},
  [5951] = {.lex_state = 73, .external_lex_state = 3},
  [5952] = {.lex_state = 73, .external_lex_state = 3},
  [5953] = {.lex_state = 73, .external_lex_state = 3},
  [5954] = {.lex_state = 188, .external_lex_state = 3},
  [5955] = {.lex_state = 188, .external_lex_state = 3},
  [5956] = {.lex_state = 55, .external_lex_state = 3},
  [5957] = {.lex_state = 74, .external_lex_state = 3},
  [5958] = {.lex_state = 74, .external_lex_state = 3},
  [5959] = {.lex_state = 57, .external_lex_state = 3},
  [5960] = {.lex_state = 74, .external_lex_state = 3},
  [5961] = {.lex_state = 74, .external_lex_state = 3},
  [5962] = {.lex_state = 74, .external_lex_state = 3},
  [5963] = {.lex_state = 24, .external_lex_state = 3},
  [5964] = {.lex_state = 74, .external_lex_state = 3},
  [5965] = {.lex_state = 74, .external_lex_state = 3},
  [5966] = {.lex_state = 74, .external_lex_state = 3},
  [5967] = {.lex_state = 74, .external_lex_state = 3},
  [5968] = {.lex_state = 74, .external_lex_state = 3},
  [5969] = {.lex_state = 74, .external_lex_state = 3},
  [5970] = {.lex_state = 74, .external_lex_state = 3},
  [5971] = {.lex_state = 74, .external_lex_state = 3},
  [5972] = {.lex_state = 74, .external_lex_state = 3},
  [5973] = {.lex_state = 24, .external_lex_state = 3},
  [5974] = {.lex_state = 74, .external_lex_state = 3},
  [5975] = {.lex_state = 74, .external_lex_state = 3},
  [5976] = {.lex_state = 74, .external_lex_state = 3},
  [5977] = {.lex_state = 74, .external_lex_state = 3},
  [5978] = {.lex_state = 74, .external_lex_state = 3},
  [5979] = {.lex_state = 24, .external_lex_state = 3},
  [5980] = {.lex_state = 74, .external_lex_state = 3},
  [5981] = {.lex_state = 74, .external_lex_state = 3},
  [5982] = {.lex_state = 74, .external_lex_state = 3},
  [5983] = {.lex_state = 74, .external_lex_state = 3},
  [5984] = {.lex_state = 74, .external_lex_state = 3},
  [5985] = {.lex_state = 74, .external_lex_state = 3},
  [5986] = {.lex_state = 74, .external_lex_state = 3},
  [5987] = {.lex_state = 74, .external_lex_state = 3},
  [5988] = {.lex_state = 74, .external_lex_state = 3},
  [5989] = {.lex_state = 74, .external_lex_state = 3},
  [5990] = {.lex_state = 57, .external_lex_state = 3},
  [5991] = {.lex_state = 63, .external_lex_state = 3},
  [5992] = {.lex_state = 74, .external_lex_state = 3},
  [5993] = {.lex_state = 24, .external_lex_state = 3},
  [5994] = {.lex_state = 74, .external_lex_state = 3},
  [5995] = {.lex_state = 74, .external_lex_state = 3},
  [5996] = {.lex_state = 63, .external_lex_state = 3},
  [5997] = {.lex_state = 63, .external_lex_state = 3},
  [5998] = {.lex_state = 63, .external_lex_state = 3},
  [5999] = {.lex_state = 74, .external_lex_state = 3},
  [6000] = {.lex_state = 63, .external_lex_state = 3},
  [6001] = {.lex_state = 74, .external_lex_state = 3},
  [6002] = {.lex_state = 74, .external_lex_state = 3},
  [6003] = {.lex_state = 24, .external_lex_state = 3},
  [6004] = {.lex_state = 24, .external_lex_state = 3},
  [6005] = {.lex_state = 74, .external_lex_state = 3},
  [6006] = {.lex_state = 74, .external_lex_state = 3},
  [6007] = {.lex_state = 24, .external_lex_state = 3},
  [6008] = {.lex_state = 24, .external_lex_state = 3},
  [6009] = {.lex_state = 74, .external_lex_state = 3},
  [6010] = {.lex_state = 74, .external_lex_state = 3},
  [6011] = {.lex_state = 74, .external_lex_state = 3},
  [6012] = {.lex_state = 74, .external_lex_state = 3},
  [6013] = {.lex_state = 24, .external_lex_state = 3},
  [6014] = {.lex_state = 74, .external_lex_state = 3},
  [6015] = {.lex_state = 74, .external_lex_state = 3},
  [6016] = {.lex_state = 74, .external_lex_state = 3},
  [6017] = {.lex_state = 74, .external_lex_state = 3},
  [6018] = {.lex_state = 74, .external_lex_state = 3},
  [6019] = {.lex_state = 74, .external_lex_state = 3},
  [6020] = {.lex_state = 74, .external_lex_state = 3},
  [6021] = {.lex_state = 24, .external_lex_state = 3},
  [6022] = {.lex_state = 74, .external_lex_state = 3},
  [6023] = {.lex_state = 74, .external_lex_state = 3},
  [6024] = {.lex_state = 74, .external_lex_state = 3},
  [6025] = {.lex_state = 24, .external_lex_state = 3},
  [6026] = {.lex_state = 24, .external_lex_state = 3},
  [6027] = {.lex_state = 24, .external_lex_state = 3},
  [6028] = {.lex_state = 74, .external_lex_state = 3},
  [6029] = {.lex_state = 74, .external_lex_state = 3},
  [6030] = {.lex_state = 24, .external_lex_state = 3},
  [6031] = {.lex_state = 74, .external_lex_state = 3},
  [6032] = {.lex_state = 74, .external_lex_state = 3},
  [6033] = {.lex_state = 74, .external_lex_state = 3},
  [6034] = {.lex_state = 24, .external_lex_state = 3},
  [6035] = {.lex_state = 24, .external_lex_state = 3},
  [6036] = {.lex_state = 74, .external_lex_state = 3},
  [6037] = {.lex_state = 74, .external_lex_state = 3},
  [6038] = {.lex_state = 74, .external_lex_state = 3},
  [6039] = {.lex_state = 24, .external_lex_state = 3},
  [6040] = {.lex_state = 74, .external_lex_state = 3},
  [6041] = {.lex_state = 74, .external_lex_state = 3},
  [6042] = {.lex_state = 63, .external_lex_state = 3},
  [6043] = {.lex_state = 63, .external_lex_state = 3},
  [6044] = {.lex_state = 63, .external_lex_state = 3},
  [6045] = {.lex_state = 24, .external_lex_state = 3},
  [6046] = {.lex_state = 63, .external_lex_state = 3},
  [6047] = {.lex_state = 74, .external_lex_state = 3},
  [6048] = {.lex_state = 74, .external_lex_state = 3},
  [6049] = {.lex_state = 74, .external_lex_state = 3},
  [6050] = {.lex_state = 74, .external_lex_state = 3},
  [6051] = {.lex_state = 74, .external_lex_state = 3},
  [6052] = {.lex_state = 63, .external_lex_state = 3},
  [6053] = {.lex_state = 74, .external_lex_state = 3},
  [6054] = {.lex_state = 74, .external_lex_state = 3},
  [6055] = {.lex_state = 74, .external_lex_state = 3},
  [6056] = {.lex_state = 74, .external_lex_state = 3},
  [6057] = {.lex_state = 74, .external_lex_state = 3},
  [6058] = {.lex_state = 74, .external_lex_state = 3},
  [6059] = {.lex_state = 74, .external_lex_state = 3},
  [6060] = {.lex_state = 24, .external_lex_state = 3},
  [6061] = {.lex_state = 74, .external_lex_state = 3},
  [6062] = {.lex_state = 74, .external_lex_state = 3},
  [6063] = {.lex_state = 24, .external_lex_state = 3},
  [6064] = {.lex_state = 74, .external_lex_state = 3},
  [6065] = {.lex_state = 74, .external_lex_state = 3},
  [6066] = {.lex_state = 24, .external_lex_state = 3},
  [6067] = {.lex_state = 63, .external_lex_state = 3},
  [6068] = {.lex_state = 74, .external_lex_state = 3},
  [6069] = {.lex_state = 74, .external_lex_state = 3},
  [6070] = {.lex_state = 24, .external_lex_state = 3},
  [6071] = {.lex_state = 31, .external_lex_state = 3},
  [6072] = {.lex_state = 30, .external_lex_state = 3},
  [6073] = {.lex_state = 30, .external_lex_state = 3},
  [6074] = {.lex_state = 30, .external_lex_state = 3},
  [6075] = {.lex_state = 30, .external_lex_state = 3},
  [6076] = {.lex_state = 30, .external_lex_state = 3},
  [6077] = {.lex_state = 30, .external_lex_state = 3},
  [6078] = {.lex_state = 63, .external_lex_state = 3},
  [6079] = {.lex_state = 63, .external_lex_state = 3},
  [6080] = {.lex_state = 30, .external_lex_state = 3},
  [6081] = {.lex_state = 63, .external_lex_state = 3},
  [6082] = {.lex_state = 30, .external_lex_state = 3},
  [6083] = {.lex_state = 30, .external_lex_state = 3},
  [6084] = {.lex_state = 30, .external_lex_state = 3},
  [6085] = {.lex_state = 63, .external_lex_state = 3},
  [6086] = {.lex_state = 63, .external_lex_state = 3},
  [6087] = {.lex_state = 63, .external_lex_state = 3},
  [6088] = {.lex_state = 63, .external_lex_state = 3},
  [6089] = {.lex_state = 63, .external_lex_state = 3},
  [6090] = {.lex_state = 63, .external_lex_state = 3},
  [6091] = {.lex_state = 63, .external_lex_state = 3},
  [6092] = {.lex_state = 63, .external_lex_state = 3},
  [6093] = {.lex_state = 63, .external_lex_state = 3},
  [6094] = {.lex_state = 63, .external_lex_state = 3},
  [6095] = {.lex_state = 30, .external_lex_state = 3},
  [6096] = {.lex_state = 30, .external_lex_state = 3},
  [6097] = {.lex_state = 30, .external_lex_state = 3},
  [6098] = {.lex_state = 63, .external_lex_state = 3},
  [6099] = {.lex_state = 63, .external_lex_state = 3},
  [6100] = {.lex_state = 31, .external_lex_state = 3},
  [6101] = {.lex_state = 31, .external_lex_state = 3},
  [6102] = {.lex_state = 31, .external_lex_state = 3},
  [6103] = {.lex_state = 31, .external_lex_state = 3},
  [6104] = {.lex_state = 31, .external_lex_state = 3},
  [6105] = {.lex_state = 31, .external_lex_state = 3},
  [6106] = {.lex_state = 31, .external_lex_state = 3},
  [6107] = {.lex_state = 31, .external_lex_state = 3},
  [6108] = {.lex_state = 31, .external_lex_state = 3},
  [6109] = {.lex_state = 31, .external_lex_state = 3},
  [6110] = {.lex_state = 31, .external_lex_state = 3},
  [6111] = {.lex_state = 31, .external_lex_state = 3},
  [6112] = {.lex_state = 31, .external_lex_state = 3},
  [6113] = {.lex_state = 31, .external_lex_state = 3},
  [6114] = {.lex_state = 31, .external_lex_state = 3},
  [6115] = {.lex_state = 31, .external_lex_state = 3},
  [6116] = {.lex_state = 31, .external_lex_state = 3},
  [6117] = {.lex_state = 31, .external_lex_state = 3},
  [6118] = {.lex_state = 31, .external_lex_state = 3},
  [6119] = {.lex_state = 63, .external_lex_state = 3},
  [6120] = {.lex_state = 63, .external_lex_state = 3},
  [6121] = {.lex_state = 63, .external_lex_state = 3},
  [6122] = {.lex_state = 63, .external_lex_state = 3},
  [6123] = {.lex_state = 63, .external_lex_state = 3},
  [6124] = {.lex_state = 63, .external_lex_state = 3},
  [6125] = {.lex_state = 63, .external_lex_state = 3},
  [6126] = {.lex_state = 63, .external_lex_state = 3},
  [6127] = {.lex_state = 63, .external_lex_state = 3},
  [6128] = {.lex_state = 63, .external_lex_state = 3},
  [6129] = {.lex_state = 63, .external_lex_state = 3},
  [6130] = {.lex_state = 63, .external_lex_state = 3},
  [6131] = {.lex_state = 63, .external_lex_state = 3},
  [6132] = {.lex_state = 63, .external_lex_state = 3},
  [6133] = {.lex_state = 63, .external_lex_state = 3},
  [6134] = {.lex_state = 63, .external_lex_state = 3},
  [6135] = {.lex_state = 63, .external_lex_state = 3},
  [6136] = {.lex_state = 63, .external_lex_state = 3},
  [6137] = {.lex_state = 63, .external_lex_state = 3},
  [6138] = {.lex_state = 30, .external_lex_state = 3},
  [6139] = {.lex_state = 30, .external_lex_state = 3},
  [6140] = {.lex_state = 30, .external_lex_state = 3},
  [6141] = {.lex_state = 30, .external_lex_state = 3},
  [6142] = {.lex_state = 31, .external_lex_state = 3},
  [6143] = {.lex_state = 31, .external_lex_state = 3},
  [6144] = {.lex_state = 31, .external_lex_state = 3},
  [6145] = {.lex_state = 63, .external_lex_state = 3},
  [6146] = {.lex_state = 63, .external_lex_state = 3},
  [6147] = {.lex_state = 63, .external_lex_state = 3},
  [6148] = {.lex_state = 63, .external_lex_state = 3},
  [6149] = {.lex_state = 7, .external_lex_state = 2},
  [6150] = {.lex_state = 7, .external_lex_state = 2},
  [6151] = {.lex_state = 7, .external_lex_state = 2},
  [6152] = {.lex_state = 64, .external_lex_state = 3},
  [6153] = {.lex_state = 64, .external_lex_state = 3},
  [6154] = {.lex_state = 7, .external_lex_state = 2},
  [6155] = {.lex_state = 7, .external_lex_state = 2},
  [6156] = {.lex_state = 7, .external_lex_state = 2},
  [6157] = {.lex_state = 7, .external_lex_state = 2},
  [6158] = {.lex_state = 30, .external_lex_state = 3},
  [6159] = {.lex_state = 30, .external_lex_state = 3},
  [6160] = {.lex_state = 64, .external_lex_state = 3},
  [6161] = {.lex_state = 64, .external_lex_state = 3},
  [6162] = {.lex_state = 64, .external_lex_state = 3},
  [6163] = {.lex_state = 64, .external_lex_state = 3},
  [6164] = {.lex_state = 64, .external_lex_state = 3},
  [6165] = {.lex_state = 64, .external_lex_state = 3},
  [6166] = {.lex_state = 64, .external_lex_state = 3},
  [6167] = {.lex_state = 68, .external_lex_state = 3},
  [6168] = {.lex_state = 64, .external_lex_state = 3},
  [6169] = {.lex_state = 64, .external_lex_state = 3},
  [6170] = {.lex_state = 61, .external_lex_state = 3},
  [6171] = {.lex_state = 31, .external_lex_state = 3},
  [6172] = {.lex_state = 31, .external_lex_state = 3},
  [6173] = {.lex_state = 30, .external_lex_state = 3},
  [6174] = {.lex_state = 69, .external_lex_state = 3},
  [6175] = {.lex_state = 67, .external_lex_state = 3},
  [6176] = {.lex_state = 30, .external_lex_state = 3},
  [6177] = {.lex_state = 30, .external_lex_state = 3},
  [6178] = {.lex_state = 30, .external_lex_state = 3},
  [6179] = {.lex_state = 30, .external_lex_state = 3},
  [6180] = {.lex_state = 30, .external_lex_state = 3},
  [6181] = {.lex_state = 30, .external_lex_state = 3},
  [6182] = {.lex_state = 30, .external_lex_state = 3},
  [6183] = {.lex_state = 30, .external_lex_state = 3},
  [6184] = {.lex_state = 30, .external_lex_state = 3},
  [6185] = {.lex_state = 30, .external_lex_state = 3},
  [6186] = {.lex_state = 30, .external_lex_state = 3},
  [6187] = {.lex_state = 30, .external_lex_state = 3},
  [6188] = {.lex_state = 30, .external_lex_state = 3},
  [6189] = {.lex_state = 30, .external_lex_state = 3},
  [6190] = {.lex_state = 30, .external_lex_state = 3},
  [6191] = {.lex_state = 30, .external_lex_state = 3},
  [6192] = {.lex_state = 30, .external_lex_state = 3},
  [6193] = {.lex_state = 30, .external_lex_state = 3},
  [6194] = {.lex_state = 30, .external_lex_state = 3},
  [6195] = {.lex_state = 30, .external_lex_state = 3},
  [6196] = {.lex_state = 30, .external_lex_state = 3},
  [6197] = {.lex_state = 30, .external_lex_state = 3},
  [6198] = {.lex_state = 30, .external_lex_state = 3},
  [6199] = {.lex_state = 30, .external_lex_state = 3},
  [6200] = {.lex_state = 30, .external_lex_state = 3},
  [6201] = {.lex_state = 30, .external_lex_state = 3},
  [6202] = {.lex_state = 30, .external_lex_state = 3},
  [6203] = {.lex_state = 30, .external_lex_state = 3},
  [6204] = {.lex_state = 30, .external_lex_state = 3},
  [6205] = {.lex_state = 30, .external_lex_state = 3},
  [6206] = {.lex_state = 30, .external_lex_state = 3},
  [6207] = {.lex_state = 30, .external_lex_state = 3},
  [6208] = {.lex_state = 30, .external_lex_state = 3},
  [6209] = {.lex_state = 30, .external_lex_state = 3},
  [6210] = {.lex_state = 30, .external_lex_state = 3},
  [6211] = {.lex_state = 30, .external_lex_state = 3},
  [6212] = {.lex_state = 30, .external_lex_state = 3},
  [6213] = {.lex_state = 30, .external_lex_state = 3},
  [6214] = {.lex_state = 30, .external_lex_state = 3},
  [6215] = {.lex_state = 30, .external_lex_state = 3},
  [6216] = {.lex_state = 30, .external_lex_state = 3},
  [6217] = {.lex_state = 30, .external_lex_state = 3},
  [6218] = {.lex_state = 30, .external_lex_state = 3},
  [6219] = {.lex_state = 30, .external_lex_state = 3},
  [6220] = {.lex_state = 68, .external_lex_state = 3},
  [6221] = {.lex_state = 30, .external_lex_state = 3},
  [6222] = {.lex_state = 68, .external_lex_state = 3},
  [6223] = {.lex_state = 68, .external_lex_state = 3},
  [6224] = {.lex_state = 68, .external_lex_state = 3},
  [6225] = {.lex_state = 68, .external_lex_state = 3},
  [6226] = {.lex_state = 68, .external_lex_state = 3},
  [6227] = {.lex_state = 68, .external_lex_state = 3},
  [6228] = {.lex_state = 30, .external_lex_state = 3},
  [6229] = {.lex_state = 61, .external_lex_state = 3},
  [6230] = {.lex_state = 30, .external_lex_state = 3},
  [6231] = {.lex_state = 61, .external_lex_state = 3},
  [6232] = {.lex_state = 61, .external_lex_state = 3},
  [6233] = {.lex_state = 61, .external_lex_state = 3},
  [6234] = {.lex_state = 61, .external_lex_state = 3},
  [6235] = {.lex_state = 61, .external_lex_state = 3},
  [6236] = {.lex_state = 61, .external_lex_state = 3},
  [6237] = {.lex_state = 31, .external_lex_state = 3},
  [6238] = {.lex_state = 30, .external_lex_state = 3},
  [6239] = {.lex_state = 30, .external_lex_state = 3},
  [6240] = {.lex_state = 68, .external_lex_state = 3},
  [6241] = {.lex_state = 30, .external_lex_state = 3},
  [6242] = {.lex_state = 69, .external_lex_state = 3},
  [6243] = {.lex_state = 30, .external_lex_state = 3},
  [6244] = {.lex_state = 30, .external_lex_state = 3},
  [6245] = {.lex_state = 68, .external_lex_state = 3},
  [6246] = {.lex_state = 30, .external_lex_state = 3},
  [6247] = {.lex_state = 69, .external_lex_state = 3},
  [6248] = {.lex_state = 69, .external_lex_state = 3},
  [6249] = {.lex_state = 69, .external_lex_state = 3},
  [6250] = {.lex_state = 30, .external_lex_state = 3},
  [6251] = {.lex_state = 65, .external_lex_state = 3},
  [6252] = {.lex_state = 30, .external_lex_state = 3},
  [6253] = {.lex_state = 69, .external_lex_state = 3},
  [6254] = {.lex_state = 69, .external_lex_state = 3},
  [6255] = {.lex_state = 69, .external_lex_state = 3},
  [6256] = {.lex_state = 68, .external_lex_state = 3},
  [6257] = {.lex_state = 61, .external_lex_state = 3},
  [6258] = {.lex_state = 69, .external_lex_state = 3},
  [6259] = {.lex_state = 67, .external_lex_state = 3},
  [6260] = {.lex_state = 30, .external_lex_state = 3},
  [6261] = {.lex_state = 30, .external_lex_state = 3},
  [6262] = {.lex_state = 30, .external_lex_state = 3},
  [6263] = {.lex_state = 30, .external_lex_state = 3},
  [6264] = {.lex_state = 65, .external_lex_state = 3},
  [6265] = {.lex_state = 65, .external_lex_state = 3},
  [6266] = {.lex_state = 61, .external_lex_state = 3},
  [6267] = {.lex_state = 67, .external_lex_state = 3},
  [6268] = {.lex_state = 61, .external_lex_state = 3},
  [6269] = {.lex_state = 67, .external_lex_state = 3},
  [6270] = {.lex_state = 67, .external_lex_state = 3},
  [6271] = {.lex_state = 67, .external_lex_state = 3},
  [6272] = {.lex_state = 67, .external_lex_state = 3},
  [6273] = {.lex_state = 67, .external_lex_state = 3},
  [6274] = {.lex_state = 67, .external_lex_state = 3},
  [6275] = {.lex_state = 30, .external_lex_state = 3},
  [6276] = {.lex_state = 69, .external_lex_state = 3},
  [6277] = {.lex_state = 69, .external_lex_state = 3},
  [6278] = {.lex_state = 31, .external_lex_state = 3},
  [6279] = {.lex_state = 31, .external_lex_state = 3},
  [6280] = {.lex_state = 31, .external_lex_state = 3},
  [6281] = {.lex_state = 31, .external_lex_state = 3},
  [6282] = {.lex_state = 31, .external_lex_state = 3},
  [6283] = {.lex_state = 31, .external_lex_state = 3},
  [6284] = {.lex_state = 67, .external_lex_state = 3},
  [6285] = {.lex_state = 31, .external_lex_state = 3},
  [6286] = {.lex_state = 31, .external_lex_state = 3},
  [6287] = {.lex_state = 31, .external_lex_state = 3},
  [6288] = {.lex_state = 31, .external_lex_state = 3},
  [6289] = {.lex_state = 31, .external_lex_state = 3},
  [6290] = {.lex_state = 31, .external_lex_state = 3},
  [6291] = {.lex_state = 31, .external_lex_state = 3},
  [6292] = {.lex_state = 31, .external_lex_state = 3},
  [6293] = {.lex_state = 31, .external_lex_state = 3},
  [6294] = {.lex_state = 31, .external_lex_state = 3},
  [6295] = {.lex_state = 31, .external_lex_state = 3},
  [6296] = {.lex_state = 31, .external_lex_state = 3},
  [6297] = {.lex_state = 31, .external_lex_state = 3},
  [6298] = {.lex_state = 31, .external_lex_state = 3},
  [6299] = {.lex_state = 31, .external_lex_state = 3},
  [6300] = {.lex_state = 31, .external_lex_state = 3},
  [6301] = {.lex_state = 31, .external_lex_state = 3},
  [6302] = {.lex_state = 31, .external_lex_state = 3},
  [6303] = {.lex_state = 67, .external_lex_state = 3},
  [6304] = {.lex_state = 31, .external_lex_state = 3},
  [6305] = {.lex_state = 31, .external_lex_state = 3},
  [6306] = {.lex_state = 31, .external_lex_state = 3},
  [6307] = {.lex_state = 31, .external_lex_state = 3},
  [6308] = {.lex_state = 31, .external_lex_state = 3},
  [6309] = {.lex_state = 31, .external_lex_state = 3},
  [6310] = {.lex_state = 31, .external_lex_state = 3},
  [6311] = {.lex_state = 31, .external_lex_state = 3},
  [6312] = {.lex_state = 31, .external_lex_state = 3},
  [6313] = {.lex_state = 31, .external_lex_state = 3},
  [6314] = {.lex_state = 31, .external_lex_state = 3},
  [6315] = {.lex_state = 31, .external_lex_state = 3},
  [6316] = {.lex_state = 31, .external_lex_state = 3},
  [6317] = {.lex_state = 31, .external_lex_state = 3},
  [6318] = {.lex_state = 31, .external_lex_state = 3},
  [6319] = {.lex_state = 31, .external_lex_state = 3},
  [6320] = {.lex_state = 31, .external_lex_state = 3},
  [6321] = {.lex_state = 31, .external_lex_state = 3},
  [6322] = {.lex_state = 31, .external_lex_state = 3},
  [6323] = {.lex_state = 31, .external_lex_state = 3},
  [6324] = {.lex_state = 31, .external_lex_state = 3},
  [6325] = {.lex_state = 7, .external_lex_state = 2},
  [6326] = {.lex_state = 31, .external_lex_state = 3},
  [6327] = {.lex_state = 31, .external_lex_state = 3},
  [6328] = {.lex_state = 31, .external_lex_state = 3},
  [6329] = {.lex_state = 31, .external_lex_state = 3},
  [6330] = {.lex_state = 31, .external_lex_state = 3},
  [6331] = {.lex_state = 31, .external_lex_state = 3},
  [6332] = {.lex_state = 31, .external_lex_state = 3},
  [6333] = {.lex_state = 31, .external_lex_state = 3},
  [6334] = {.lex_state = 31, .external_lex_state = 3},
  [6335] = {.lex_state = 31, .external_lex_state = 3},
  [6336] = {.lex_state = 31, .external_lex_state = 3},
  [6337] = {.lex_state = 31, .external_lex_state = 3},
  [6338] = {.lex_state = 31, .external_lex_state = 3},
  [6339] = {.lex_state = 31, .external_lex_state = 3},
  [6340] = {.lex_state = 31, .external_lex_state = 3},
  [6341] = {.lex_state = 56, .external_lex_state = 3},
  [6342] = {.lex_state = 31, .external_lex_state = 3},
  [6343] = {.lex_state = 30, .external_lex_state = 3},
  [6344] = {.lex_state = 65, .external_lex_state = 3},
  [6345] = {.lex_state = 65, .external_lex_state = 3},
  [6346] = {.lex_state = 65, .external_lex_state = 3},
  [6347] = {.lex_state = 65, .external_lex_state = 3},
  [6348] = {.lex_state = 30, .external_lex_state = 3},
  [6349] = {.lex_state = 65, .external_lex_state = 3},
  [6350] = {.lex_state = 65, .external_lex_state = 3},
  [6351] = {.lex_state = 65, .external_lex_state = 3},
  [6352] = {.lex_state = 30, .external_lex_state = 3},
  [6353] = {.lex_state = 30, .external_lex_state = 3},
  [6354] = {.lex_state = 30, .external_lex_state = 3},
  [6355] = {.lex_state = 63, .external_lex_state = 3},
  [6356] = {.lex_state = 63, .external_lex_state = 3},
  [6357] = {.lex_state = 63, .external_lex_state = 3},
  [6358] = {.lex_state = 63, .external_lex_state = 3},
  [6359] = {.lex_state = 63, .external_lex_state = 3},
  [6360] = {.lex_state = 63, .external_lex_state = 3},
  [6361] = {.lex_state = 63, .external_lex_state = 3},
  [6362] = {.lex_state = 63, .external_lex_state = 3},
  [6363] = {.lex_state = 63, .external_lex_state = 3},
  [6364] = {.lex_state = 63, .external_lex_state = 3},
  [6365] = {.lex_state = 63, .external_lex_state = 3},
  [6366] = {.lex_state = 63, .external_lex_state = 3},
  [6367] = {.lex_state = 63, .external_lex_state = 3},
  [6368] = {.lex_state = 63, .external_lex_state = 3},
  [6369] = {.lex_state = 63, .external_lex_state = 3},
  [6370] = {.lex_state = 63, .external_lex_state = 3},
  [6371] = {.lex_state = 63, .external_lex_state = 3},
  [6372] = {.lex_state = 63, .external_lex_state = 3},
  [6373] = {.lex_state = 63, .external_lex_state = 3},
  [6374] = {.lex_state = 63, .external_lex_state = 3},
  [6375] = {.lex_state = 63, .external_lex_state = 3},
  [6376] = {.lex_state = 63, .external_lex_state = 3},
  [6377] = {.lex_state = 63, .external_lex_state = 3},
  [6378] = {.lex_state = 63, .external_lex_state = 3},
  [6379] = {.lex_state = 63, .external_lex_state = 3},
  [6380] = {.lex_state = 63, .external_lex_state = 3},
  [6381] = {.lex_state = 63, .external_lex_state = 3},
  [6382] = {.lex_state = 63, .external_lex_state = 3},
  [6383] = {.lex_state = 63, .external_lex_state = 3},
  [6384] = {.lex_state = 63, .external_lex_state = 3},
  [6385] = {.lex_state = 63, .external_lex_state = 3},
  [6386] = {.lex_state = 63, .external_lex_state = 3},
  [6387] = {.lex_state = 63, .external_lex_state = 3},
  [6388] = {.lex_state = 63, .external_lex_state = 3},
  [6389] = {.lex_state = 63, .external_lex_state = 3},
  [6390] = {.lex_state = 63, .external_lex_state = 3},
  [6391] = {.lex_state = 63, .external_lex_state = 3},
  [6392] = {.lex_state = 63, .external_lex_state = 3},
  [6393] = {.lex_state = 63, .external_lex_state = 3},
  [6394] = {.lex_state = 30, .external_lex_state = 3},
  [6395] = {.lex_state = 65, .external_lex_state = 3},
  [6396] = {.lex_state = 73, .external_lex_state = 3},
  [6397] = {.lex_state = 63, .external_lex_state = 3},
  [6398] = {.lex_state = 30, .external_lex_state = 3},
  [6399] = {.lex_state = 65, .external_lex_state = 3},
  [6400] = {.lex_state = 67, .external_lex_state = 3},
  [6401] = {.lex_state = 67, .external_lex_state = 3},
  [6402] = {.lex_state = 67, .external_lex_state = 3},
  [6403] = {.lex_state = 69, .external_lex_state = 3},
  [6404] = {.lex_state = 67, .external_lex_state = 3},
  [6405] = {.lex_state = 438, .external_lex_state = 3},
  [6406] = {.lex_state = 70, .external_lex_state = 3},
  [6407] = {.lex_state = 70, .external_lex_state = 3},
  [6408] = {.lex_state = 70, .external_lex_state = 3},
  [6409] = {.lex_state = 69, .external_lex_state = 3},
  [6410] = {.lex_state = 73, .external_lex_state = 3},
  [6411] = {.lex_state = 61, .external_lex_state = 3},
  [6412] = {.lex_state = 67, .external_lex_state = 3},
  [6413] = {.lex_state = 65, .external_lex_state = 3},
  [6414] = {.lex_state = 70, .external_lex_state = 3},
  [6415] = {.lex_state = 70, .external_lex_state = 3},
  [6416] = {.lex_state = 70, .external_lex_state = 3},
  [6417] = {.lex_state = 65, .external_lex_state = 3},
  [6418] = {.lex_state = 65, .external_lex_state = 3},
  [6419] = {.lex_state = 65, .external_lex_state = 3},
  [6420] = {.lex_state = 65, .external_lex_state = 3},
  [6421] = {.lex_state = 65, .external_lex_state = 3},
  [6422] = {.lex_state = 65, .external_lex_state = 3},
  [6423] = {.lex_state = 65, .external_lex_state = 3},
  [6424] = {.lex_state = 438, .external_lex_state = 3},
  [6425] = {.lex_state = 65, .external_lex_state = 3},
  [6426] = {.lex_state = 7, .external_lex_state = 2},
  [6427] = {.lex_state = 65, .external_lex_state = 3},
  [6428] = {.lex_state = 65, .external_lex_state = 3},
  [6429] = {.lex_state = 65, .external_lex_state = 3},
  [6430] = {.lex_state = 65, .external_lex_state = 3},
  [6431] = {.lex_state = 65, .external_lex_state = 3},
  [6432] = {.lex_state = 65, .external_lex_state = 3},
  [6433] = {.lex_state = 61, .external_lex_state = 3},
  [6434] = {.lex_state = 65, .external_lex_state = 3},
  [6435] = {.lex_state = 65, .external_lex_state = 3},
  [6436] = {.lex_state = 65, .external_lex_state = 3},
  [6437] = {.lex_state = 65, .external_lex_state = 3},
  [6438] = {.lex_state = 70, .external_lex_state = 3},
  [6439] = {.lex_state = 65, .external_lex_state = 3},
  [6440] = {.lex_state = 72, .external_lex_state = 3},
  [6441] = {.lex_state = 65, .external_lex_state = 3},
  [6442] = {.lex_state = 65, .external_lex_state = 3},
  [6443] = {.lex_state = 438, .external_lex_state = 3},
  [6444] = {.lex_state = 65, .external_lex_state = 3},
  [6445] = {.lex_state = 61, .external_lex_state = 3},
  [6446] = {.lex_state = 438, .external_lex_state = 3},
  [6447] = {.lex_state = 70, .external_lex_state = 3},
  [6448] = {.lex_state = 438, .external_lex_state = 3},
  [6449] = {.lex_state = 68, .external_lex_state = 3},
  [6450] = {.lex_state = 68, .external_lex_state = 3},
  [6451] = {.lex_state = 68, .external_lex_state = 3},
  [6452] = {.lex_state = 68, .external_lex_state = 3},
  [6453] = {.lex_state = 61, .external_lex_state = 3},
  [6454] = {.lex_state = 61, .external_lex_state = 3},
  [6455] = {.lex_state = 61, .external_lex_state = 3},
  [6456] = {.lex_state = 61, .external_lex_state = 3},
  [6457] = {.lex_state = 69, .external_lex_state = 3},
  [6458] = {.lex_state = 438, .external_lex_state = 3},
  [6459] = {.lex_state = 438, .external_lex_state = 3},
  [6460] = {.lex_state = 438, .external_lex_state = 3},
  [6461] = {.lex_state = 69, .external_lex_state = 3},
  [6462] = {.lex_state = 69, .external_lex_state = 3},
  [6463] = {.lex_state = 69, .external_lex_state = 3},
  [6464] = {.lex_state = 67, .external_lex_state = 3},
  [6465] = {.lex_state = 67, .external_lex_state = 3},
  [6466] = {.lex_state = 67, .external_lex_state = 3},
  [6467] = {.lex_state = 67, .external_lex_state = 3},
  [6468] = {.lex_state = 69, .external_lex_state = 3},
  [6469] = {.lex_state = 438, .external_lex_state = 3},
  [6470] = {.lex_state = 438, .external_lex_state = 3},
  [6471] = {.lex_state = 438, .external_lex_state = 3},
  [6472] = {.lex_state = 65, .external_lex_state = 3},
  [6473] = {.lex_state = 65, .external_lex_state = 3},
  [6474] = {.lex_state = 65, .external_lex_state = 3},
  [6475] = {.lex_state = 65, .external_lex_state = 3},
  [6476] = {.lex_state = 438, .external_lex_state = 3},
  [6477] = {.lex_state = 438, .external_lex_state = 3},
  [6478] = {.lex_state = 438, .external_lex_state = 3},
  [6479] = {.lex_state = 438, .external_lex_state = 3},
  [6480] = {.lex_state = 438, .external_lex_state = 3},
  [6481] = {.lex_state = 438, .external_lex_state = 3},
  [6482] = {.lex_state = 438, .external_lex_state = 3},
  [6483] = {.lex_state = 69, .external_lex_state = 3},
  [6484] = {.lex_state = 7, .external_lex_state = 2},
  [6485] = {.lex_state = 438, .external_lex_state = 3},
  [6486] = {.lex_state = 438, .external_lex_state = 3},
  [6487] = {.lex_state = 438, .external_lex_state = 3},
  [6488] = {.lex_state = 438, .external_lex_state = 3},
  [6489] = {.lex_state = 438, .external_lex_state = 3},
  [6490] = {.lex_state = 438, .external_lex_state = 3},
  [6491] = {.lex_state = 438, .external_lex_state = 3},
  [6492] = {.lex_state = 438, .external_lex_state = 3},
  [6493] = {.lex_state = 438, .external_lex_state = 3},
  [6494] = {.lex_state = 7, .external_lex_state = 2},
  [6495] = {.lex_state = 438, .external_lex_state = 3},
  [6496] = {.lex_state = 438, .external_lex_state = 3},
  [6497] = {.lex_state = 438, .external_lex_state = 3},
  [6498] = {.lex_state = 438, .external_lex_state = 3},
  [6499] = {.lex_state = 438, .external_lex_state = 3},
  [6500] = {.lex_state = 438, .external_lex_state = 3},
  [6501] = {.lex_state = 438, .external_lex_state = 3},
  [6502] = {.lex_state = 438, .external_lex_state = 3},
  [6503] = {.lex_state = 438, .external_lex_state = 3},
  [6504] = {.lex_state = 438, .external_lex_state = 3},
  [6505] = {.lex_state = 438, .external_lex_state = 3},
  [6506] = {.lex_state = 438, .external_lex_state = 3},
  [6507] = {.lex_state = 438, .external_lex_state = 3},
  [6508] = {.lex_state = 438, .external_lex_state = 3},
  [6509] = {.lex_state = 438, .external_lex_state = 3},
  [6510] = {.lex_state = 438, .external_lex_state = 3},
  [6511] = {.lex_state = 438, .external_lex_state = 3},
  [6512] = {.lex_state = 438, .external_lex_state = 3},
  [6513] = {.lex_state = 438, .external_lex_state = 3},
  [6514] = {.lex_state = 438, .external_lex_state = 3},
  [6515] = {.lex_state = 438, .external_lex_state = 3},
  [6516] = {.lex_state = 438, .external_lex_state = 3},
  [6517] = {.lex_state = 438, .external_lex_state = 3},
  [6518] = {.lex_state = 438, .external_lex_state = 3},
  [6519] = {.lex_state = 438, .external_lex_state = 3},
  [6520] = {.lex_state = 438, .external_lex_state = 3},
  [6521] = {.lex_state = 438, .external_lex_state = 3},
  [6522] = {.lex_state = 438, .external_lex_state = 3},
  [6523] = {.lex_state = 66, .external_lex_state = 3},
  [6524] = {.lex_state = 66, .external_lex_state = 3},
  [6525] = {.lex_state = 438, .external_lex_state = 3},
  [6526] = {.lex_state = 438, .external_lex_state = 3},
  [6527] = {.lex_state = 7, .external_lex_state = 2},
  [6528] = {.lex_state = 61, .external_lex_state = 3},
  [6529] = {.lex_state = 69, .external_lex_state = 3},
  [6530] = {.lex_state = 7, .external_lex_state = 2},
  [6531] = {.lex_state = 65, .external_lex_state = 3},
  [6532] = {.lex_state = 69, .external_lex_state = 3},
  [6533] = {.lex_state = 7, .external_lex_state = 2},
  [6534] = {.lex_state = 438, .external_lex_state = 3},
  [6535] = {.lex_state = 438, .external_lex_state = 3},
  [6536] = {.lex_state = 7, .external_lex_state = 2},
  [6537] = {.lex_state = 7, .external_lex_state = 2},
  [6538] = {.lex_state = 68, .external_lex_state = 3},
  [6539] = {.lex_state = 438, .external_lex_state = 3},
  [6540] = {.lex_state = 438, .external_lex_state = 3},
  [6541] = {.lex_state = 66, .external_lex_state = 3},
  [6542] = {.lex_state = 66, .external_lex_state = 3},
  [6543] = {.lex_state = 66, .external_lex_state = 3},
  [6544] = {.lex_state = 66, .external_lex_state = 3},
  [6545] = {.lex_state = 66, .external_lex_state = 3},
  [6546] = {.lex_state = 66, .external_lex_state = 3},
  [6547] = {.lex_state = 66, .external_lex_state = 3},
  [6548] = {.lex_state = 438, .external_lex_state = 3},
  [6549] = {.lex_state = 64, .external_lex_state = 3},
  [6550] = {.lex_state = 64, .external_lex_state = 3},
  [6551] = {.lex_state = 64, .external_lex_state = 3},
  [6552] = {.lex_state = 64, .external_lex_state = 3},
  [6553] = {.lex_state = 64, .external_lex_state = 3},
  [6554] = {.lex_state = 64, .external_lex_state = 3},
  [6555] = {.lex_state = 64, .external_lex_state = 3},
  [6556] = {.lex_state = 64, .external_lex_state = 3},
  [6557] = {.lex_state = 64, .external_lex_state = 3},
  [6558] = {.lex_state = 64, .external_lex_state = 3},
  [6559] = {.lex_state = 64, .external_lex_state = 3},
  [6560] = {.lex_state = 64, .external_lex_state = 3},
  [6561] = {.lex_state = 68, .external_lex_state = 3},
  [6562] = {.lex_state = 64, .external_lex_state = 3},
  [6563] = {.lex_state = 64, .external_lex_state = 3},
  [6564] = {.lex_state = 64, .external_lex_state = 3},
  [6565] = {.lex_state = 64, .external_lex_state = 3},
  [6566] = {.lex_state = 64, .external_lex_state = 3},
  [6567] = {.lex_state = 64, .external_lex_state = 3},
  [6568] = {.lex_state = 64, .external_lex_state = 3},
  [6569] = {.lex_state = 64, .external_lex_state = 3},
  [6570] = {.lex_state = 64, .external_lex_state = 3},
  [6571] = {.lex_state = 64, .external_lex_state = 3},
  [6572] = {.lex_state = 64, .external_lex_state = 3},
  [6573] = {.lex_state = 64, .external_lex_state = 3},
  [6574] = {.lex_state = 64, .external_lex_state = 3},
  [6575] = {.lex_state = 64, .external_lex_state = 3},
  [6576] = {.lex_state = 64, .external_lex_state = 3},
  [6577] = {.lex_state = 64, .external_lex_state = 3},
  [6578] = {.lex_state = 64, .external_lex_state = 3},
  [6579] = {.lex_state = 64, .external_lex_state = 3},
  [6580] = {.lex_state = 64, .external_lex_state = 3},
  [6581] = {.lex_state = 68, .external_lex_state = 3},
  [6582] = {.lex_state = 68, .external_lex_state = 3},
  [6583] = {.lex_state = 64, .external_lex_state = 3},
  [6584] = {.lex_state = 64, .external_lex_state = 3},
  [6585] = {.lex_state = 64, .external_lex_state = 3},
  [6586] = {.lex_state = 64, .external_lex_state = 3},
  [6587] = {.lex_state = 68, .external_lex_state = 3},
  [6588] = {.lex_state = 68, .external_lex_state = 3},
  [6589] = {.lex_state = 64, .external_lex_state = 3},
  [6590] = {.lex_state = 64, .external_lex_state = 3},
  [6591] = {.lex_state = 64, .external_lex_state = 3},
  [6592] = {.lex_state = 66, .external_lex_state = 3},
  [6593] = {.lex_state = 438, .external_lex_state = 3},
  [6594] = {.lex_state = 64, .external_lex_state = 3},
  [6595] = {.lex_state = 66, .external_lex_state = 3},
  [6596] = {.lex_state = 64, .external_lex_state = 3},
  [6597] = {.lex_state = 72, .external_lex_state = 3},
  [6598] = {.lex_state = 68, .external_lex_state = 3},
  [6599] = {.lex_state = 64, .external_lex_state = 3},
  [6600] = {.lex_state = 438, .external_lex_state = 3},
  [6601] = {.lex_state = 64, .external_lex_state = 3},
  [6602] = {.lex_state = 438, .external_lex_state = 3},
  [6603] = {.lex_state = 438, .external_lex_state = 3},
  [6604] = {.lex_state = 64, .external_lex_state = 3},
  [6605] = {.lex_state = 438, .external_lex_state = 3},
  [6606] = {.lex_state = 64, .external_lex_state = 3},
  [6607] = {.lex_state = 71, .external_lex_state = 3},
  [6608] = {.lex_state = 64, .external_lex_state = 3},
  [6609] = {.lex_state = 64, .external_lex_state = 3},
  [6610] = {.lex_state = 64, .external_lex_state = 3},
  [6611] = {.lex_state = 64, .external_lex_state = 3},
  [6612] = {.lex_state = 64, .external_lex_state = 3},
  [6613] = {.lex_state = 64, .external_lex_state = 3},
  [6614] = {.lex_state = 64, .external_lex_state = 3},
  [6615] = {.lex_state = 61, .external_lex_state = 3},
  [6616] = {.lex_state = 61, .external_lex_state = 3},
  [6617] = {.lex_state = 67, .external_lex_state = 3},
  [6618] = {.lex_state = 69, .external_lex_state = 3},
  [6619] = {.lex_state = 64, .external_lex_state = 3},
  [6620] = {.lex_state = 64, .external_lex_state = 3},
  [6621] = {.lex_state = 64, .external_lex_state = 3},
  [6622] = {.lex_state = 67, .external_lex_state = 3},
  [6623] = {.lex_state = 438, .external_lex_state = 3},
  [6624] = {.lex_state = 438, .external_lex_state = 3},
  [6625] = {.lex_state = 438, .external_lex_state = 3},
  [6626] = {.lex_state = 438, .external_lex_state = 3},
  [6627] = {.lex_state = 438, .external_lex_state = 3},
  [6628] = {.lex_state = 68, .external_lex_state = 3},
  [6629] = {.lex_state = 68, .external_lex_state = 3},
  [6630] = {.lex_state = 65, .external_lex_state = 3},
  [6631] = {.lex_state = 68, .external_lex_state = 3},
  [6632] = {.lex_state = 74, .external_lex_state = 3},
  [6633] = {.lex_state = 68, .external_lex_state = 3},
  [6634] = {.lex_state = 67, .external_lex_state = 3},
  [6635] = {.lex_state = 72, .external_lex_state = 3},
  [6636] = {.lex_state = 67, .external_lex_state = 3},
  [6637] = {.lex_state = 64, .external_lex_state = 3},
  [6638] = {.lex_state = 68, .external_lex_state = 3},
  [6639] = {.lex_state = 438, .external_lex_state = 3},
  [6640] = {.lex_state = 438, .external_lex_state = 3},
  [6641] = {.lex_state = 68, .external_lex_state = 3},
  [6642] = {.lex_state = 68, .external_lex_state = 3},
  [6643] = {.lex_state = 68, .external_lex_state = 3},
  [6644] = {.lex_state = 68, .external_lex_state = 3},
  [6645] = {.lex_state = 68, .external_lex_state = 3},
  [6646] = {.lex_state = 438, .external_lex_state = 3},
  [6647] = {.lex_state = 62, .external_lex_state = 3},
  [6648] = {.lex_state = 68, .external_lex_state = 3},
  [6649] = {.lex_state = 68, .external_lex_state = 3},
  [6650] = {.lex_state = 68, .external_lex_state = 3},
  [6651] = {.lex_state = 68, .external_lex_state = 3},
  [6652] = {.lex_state = 68, .external_lex_state = 3},
  [6653] = {.lex_state = 68, .external_lex_state = 3},
  [6654] = {.lex_state = 68, .external_lex_state = 3},
  [6655] = {.lex_state = 68, .external_lex_state = 3},
  [6656] = {.lex_state = 438, .external_lex_state = 3},
  [6657] = {.lex_state = 68, .external_lex_state = 3},
  [6658] = {.lex_state = 438, .external_lex_state = 3},
  [6659] = {.lex_state = 68, .external_lex_state = 3},
  [6660] = {.lex_state = 68, .external_lex_state = 3},
  [6661] = {.lex_state = 68, .external_lex_state = 3},
  [6662] = {.lex_state = 68, .external_lex_state = 3},
  [6663] = {.lex_state = 68, .external_lex_state = 3},
  [6664] = {.lex_state = 68, .external_lex_state = 3},
  [6665] = {.lex_state = 68, .external_lex_state = 3},
  [6666] = {.lex_state = 68, .external_lex_state = 3},
  [6667] = {.lex_state = 68, .external_lex_state = 3},
  [6668] = {.lex_state = 68, .external_lex_state = 3},
  [6669] = {.lex_state = 68, .external_lex_state = 3},
  [6670] = {.lex_state = 68, .external_lex_state = 3},
  [6671] = {.lex_state = 68, .external_lex_state = 3},
  [6672] = {.lex_state = 68, .external_lex_state = 3},
  [6673] = {.lex_state = 68, .external_lex_state = 3},
  [6674] = {.lex_state = 68, .external_lex_state = 3},
  [6675] = {.lex_state = 67, .external_lex_state = 3},
  [6676] = {.lex_state = 67, .external_lex_state = 3},
  [6677] = {.lex_state = 68, .external_lex_state = 3},
  [6678] = {.lex_state = 68, .external_lex_state = 3},
  [6679] = {.lex_state = 68, .external_lex_state = 3},
  [6680] = {.lex_state = 68, .external_lex_state = 3},
  [6681] = {.lex_state = 65, .external_lex_state = 3},
  [6682] = {.lex_state = 65, .external_lex_state = 3},
  [6683] = {.lex_state = 61, .external_lex_state = 3},
  [6684] = {.lex_state = 68, .external_lex_state = 3},
  [6685] = {.lex_state = 438, .external_lex_state = 3},
  [6686] = {.lex_state = 61, .external_lex_state = 3},
  [6687] = {.lex_state = 438, .external_lex_state = 3},
  [6688] = {.lex_state = 438, .external_lex_state = 3},
  [6689] = {.lex_state = 68, .external_lex_state = 3},
  [6690] = {.lex_state = 438, .external_lex_state = 3},
  [6691] = {.lex_state = 61, .external_lex_state = 3},
  [6692] = {.lex_state = 61, .external_lex_state = 3},
  [6693] = {.lex_state = 61, .external_lex_state = 3},
  [6694] = {.lex_state = 61, .external_lex_state = 3},
  [6695] = {.lex_state = 61, .external_lex_state = 3},
  [6696] = {.lex_state = 61, .external_lex_state = 3},
  [6697] = {.lex_state = 61, .external_lex_state = 3},
  [6698] = {.lex_state = 61, .external_lex_state = 3},
  [6699] = {.lex_state = 438, .external_lex_state = 3},
  [6700] = {.lex_state = 61, .external_lex_state = 3},
  [6701] = {.lex_state = 61, .external_lex_state = 3},
  [6702] = {.lex_state = 61, .external_lex_state = 3},
  [6703] = {.lex_state = 438, .external_lex_state = 3},
  [6704] = {.lex_state = 61, .external_lex_state = 3},
  [6705] = {.lex_state = 61, .external_lex_state = 3},
  [6706] = {.lex_state = 61, .external_lex_state = 3},
  [6707] = {.lex_state = 61, .external_lex_state = 3},
  [6708] = {.lex_state = 68, .external_lex_state = 3},
  [6709] = {.lex_state = 61, .external_lex_state = 3},
  [6710] = {.lex_state = 61, .external_lex_state = 3},
  [6711] = {.lex_state = 61, .external_lex_state = 3},
  [6712] = {.lex_state = 61, .external_lex_state = 3},
  [6713] = {.lex_state = 61, .external_lex_state = 3},
  [6714] = {.lex_state = 61, .external_lex_state = 3},
  [6715] = {.lex_state = 61, .external_lex_state = 3},
  [6716] = {.lex_state = 61, .external_lex_state = 3},
  [6717] = {.lex_state = 61, .external_lex_state = 3},
  [6718] = {.lex_state = 61, .external_lex_state = 3},
  [6719] = {.lex_state = 61, .external_lex_state = 3},
  [6720] = {.lex_state = 61, .external_lex_state = 3},
  [6721] = {.lex_state = 61, .external_lex_state = 3},
  [6722] = {.lex_state = 61, .external_lex_state = 3},
  [6723] = {.lex_state = 61, .external_lex_state = 3},
  [6724] = {.lex_state = 61, .external_lex_state = 3},
  [6725] = {.lex_state = 61, .external_lex_state = 3},
  [6726] = {.lex_state = 61, .external_lex_state = 3},
  [6727] = {.lex_state = 61, .external_lex_state = 3},
  [6728] = {.lex_state = 61, .external_lex_state = 3},
  [6729] = {.lex_state = 61, .external_lex_state = 3},
  [6730] = {.lex_state = 61, .external_lex_state = 3},
  [6731] = {.lex_state = 61, .external_lex_state = 3},
  [6732] = {.lex_state = 61, .external_lex_state = 3},
  [6733] = {.lex_state = 68, .external_lex_state = 3},
  [6734] = {.lex_state = 61, .external_lex_state = 3},
  [6735] = {.lex_state = 69, .external_lex_state = 3},
  [6736] = {.lex_state = 69, .external_lex_state = 3},
  [6737] = {.lex_state = 61, .external_lex_state = 3},
  [6738] = {.lex_state = 69, .external_lex_state = 3},
  [6739] = {.lex_state = 69, .external_lex_state = 3},
  [6740] = {.lex_state = 69, .external_lex_state = 3},
  [6741] = {.lex_state = 69, .external_lex_state = 3},
  [6742] = {.lex_state = 438, .external_lex_state = 3},
  [6743] = {.lex_state = 69, .external_lex_state = 3},
  [6744] = {.lex_state = 68, .external_lex_state = 3},
  [6745] = {.lex_state = 69, .external_lex_state = 3},
  [6746] = {.lex_state = 69, .external_lex_state = 3},
  [6747] = {.lex_state = 69, .external_lex_state = 3},
  [6748] = {.lex_state = 69, .external_lex_state = 3},
  [6749] = {.lex_state = 69, .external_lex_state = 3},
  [6750] = {.lex_state = 69, .external_lex_state = 3},
  [6751] = {.lex_state = 69, .external_lex_state = 3},
  [6752] = {.lex_state = 69, .external_lex_state = 3},
  [6753] = {.lex_state = 69, .external_lex_state = 3},
  [6754] = {.lex_state = 69, .external_lex_state = 3},
  [6755] = {.lex_state = 61, .external_lex_state = 3},
  [6756] = {.lex_state = 71, .external_lex_state = 3},
  [6757] = {.lex_state = 69, .external_lex_state = 3},
  [6758] = {.lex_state = 69, .external_lex_state = 3},
  [6759] = {.lex_state = 69, .external_lex_state = 3},
  [6760] = {.lex_state = 71, .external_lex_state = 3},
  [6761] = {.lex_state = 62, .external_lex_state = 3},
  [6762] = {.lex_state = 72, .external_lex_state = 3},
  [6763] = {.lex_state = 70, .external_lex_state = 3},
  [6764] = {.lex_state = 69, .external_lex_state = 3},
  [6765] = {.lex_state = 69, .external_lex_state = 3},
  [6766] = {.lex_state = 69, .external_lex_state = 3},
  [6767] = {.lex_state = 69, .external_lex_state = 3},
  [6768] = {.lex_state = 69, .external_lex_state = 3},
  [6769] = {.lex_state = 72, .external_lex_state = 3},
  [6770] = {.lex_state = 69, .external_lex_state = 3},
  [6771] = {.lex_state = 69, .external_lex_state = 3},
  [6772] = {.lex_state = 69, .external_lex_state = 3},
  [6773] = {.lex_state = 69, .external_lex_state = 3},
  [6774] = {.lex_state = 69, .external_lex_state = 3},
  [6775] = {.lex_state = 69, .external_lex_state = 3},
  [6776] = {.lex_state = 72, .external_lex_state = 3},
  [6777] = {.lex_state = 69, .external_lex_state = 3},
  [6778] = {.lex_state = 69, .external_lex_state = 3},
  [6779] = {.lex_state = 68, .external_lex_state = 3},
  [6780] = {.lex_state = 72, .external_lex_state = 3},
  [6781] = {.lex_state = 61, .external_lex_state = 3},
  [6782] = {.lex_state = 69, .external_lex_state = 3},
  [6783] = {.lex_state = 69, .external_lex_state = 3},
  [6784] = {.lex_state = 69, .external_lex_state = 3},
  [6785] = {.lex_state = 69, .external_lex_state = 3},
  [6786] = {.lex_state = 61, .external_lex_state = 3},
  [6787] = {.lex_state = 68, .external_lex_state = 3},
  [6788] = {.lex_state = 61, .external_lex_state = 3},
  [6789] = {.lex_state = 69, .external_lex_state = 3},
  [6790] = {.lex_state = 61, .external_lex_state = 3},
  [6791] = {.lex_state = 67, .external_lex_state = 3},
  [6792] = {.lex_state = 69, .external_lex_state = 3},
  [6793] = {.lex_state = 67, .external_lex_state = 3},
  [6794] = {.lex_state = 68, .external_lex_state = 3},
  [6795] = {.lex_state = 67, .external_lex_state = 3},
  [6796] = {.lex_state = 68, .external_lex_state = 3},
  [6797] = {.lex_state = 67, .external_lex_state = 3},
  [6798] = {.lex_state = 67, .external_lex_state = 3},
  [6799] = {.lex_state = 67, .external_lex_state = 3},
  [6800] = {.lex_state = 61, .external_lex_state = 3},
  [6801] = {.lex_state = 438, .external_lex_state = 3},
  [6802] = {.lex_state = 67, .external_lex_state = 3},
  [6803] = {.lex_state = 67, .external_lex_state = 3},
  [6804] = {.lex_state = 67, .external_lex_state = 3},
  [6805] = {.lex_state = 68, .external_lex_state = 3},
  [6806] = {.lex_state = 67, .external_lex_state = 3},
  [6807] = {.lex_state = 67, .external_lex_state = 3},
  [6808] = {.lex_state = 67, .external_lex_state = 3},
  [6809] = {.lex_state = 67, .external_lex_state = 3},
  [6810] = {.lex_state = 67, .external_lex_state = 3},
  [6811] = {.lex_state = 67, .external_lex_state = 3},
  [6812] = {.lex_state = 69, .external_lex_state = 3},
  [6813] = {.lex_state = 67, .external_lex_state = 3},
  [6814] = {.lex_state = 67, .external_lex_state = 3},
  [6815] = {.lex_state = 67, .external_lex_state = 3},
  [6816] = {.lex_state = 67, .external_lex_state = 3},
  [6817] = {.lex_state = 68, .external_lex_state = 3},
  [6818] = {.lex_state = 67, .external_lex_state = 3},
  [6819] = {.lex_state = 68, .external_lex_state = 3},
  [6820] = {.lex_state = 67, .external_lex_state = 3},
  [6821] = {.lex_state = 67, .external_lex_state = 3},
  [6822] = {.lex_state = 67, .external_lex_state = 3},
  [6823] = {.lex_state = 67, .external_lex_state = 3},
  [6824] = {.lex_state = 67, .external_lex_state = 3},
  [6825] = {.lex_state = 67, .external_lex_state = 3},
  [6826] = {.lex_state = 67, .external_lex_state = 3},
  [6827] = {.lex_state = 67, .external_lex_state = 3},
  [6828] = {.lex_state = 67, .external_lex_state = 3},
  [6829] = {.lex_state = 68, .external_lex_state = 3},
  [6830] = {.lex_state = 67, .external_lex_state = 3},
  [6831] = {.lex_state = 67, .external_lex_state = 3},
  [6832] = {.lex_state = 61, .external_lex_state = 3},
  [6833] = {.lex_state = 67, .external_lex_state = 3},
  [6834] = {.lex_state = 67, .external_lex_state = 3},
  [6835] = {.lex_state = 67, .external_lex_state = 3},
  [6836] = {.lex_state = 67, .external_lex_state = 3},
  [6837] = {.lex_state = 68, .external_lex_state = 3},
  [6838] = {.lex_state = 68, .external_lex_state = 3},
  [6839] = {.lex_state = 68, .external_lex_state = 3},
  [6840] = {.lex_state = 72, .external_lex_state = 3},
  [6841] = {.lex_state = 72, .external_lex_state = 3},
  [6842] = {.lex_state = 67, .external_lex_state = 3},
  [6843] = {.lex_state = 68, .external_lex_state = 3},
  [6844] = {.lex_state = 68, .external_lex_state = 3},
  [6845] = {.lex_state = 68, .external_lex_state = 3},
  [6846] = {.lex_state = 68, .external_lex_state = 3},
  [6847] = {.lex_state = 72, .external_lex_state = 3},
  [6848] = {.lex_state = 67, .external_lex_state = 3},
  [6849] = {.lex_state = 61, .external_lex_state = 3},
  [6850] = {.lex_state = 61, .external_lex_state = 3},
  [6851] = {.lex_state = 69, .external_lex_state = 3},
  [6852] = {.lex_state = 64, .external_lex_state = 3},
  [6853] = {.lex_state = 71, .external_lex_state = 3},
  [6854] = {.lex_state = 61, .external_lex_state = 3},
  [6855] = {.lex_state = 67, .external_lex_state = 3},
  [6856] = {.lex_state = 61, .external_lex_state = 3},
  [6857] = {.lex_state = 61, .external_lex_state = 3},
  [6858] = {.lex_state = 61, .external_lex_state = 3},
  [6859] = {.lex_state = 69, .external_lex_state = 3},
  [6860] = {.lex_state = 64, .external_lex_state = 3},
  [6861] = {.lex_state = 61, .external_lex_state = 3},
  [6862] = {.lex_state = 61, .external_lex_state = 3},
  [6863] = {.lex_state = 61, .external_lex_state = 3},
  [6864] = {.lex_state = 64, .external_lex_state = 3},
  [6865] = {.lex_state = 61, .external_lex_state = 3},
  [6866] = {.lex_state = 61, .external_lex_state = 3},
  [6867] = {.lex_state = 61, .external_lex_state = 3},
  [6868] = {.lex_state = 64, .external_lex_state = 3},
  [6869] = {.lex_state = 61, .external_lex_state = 3},
  [6870] = {.lex_state = 64, .external_lex_state = 3},
  [6871] = {.lex_state = 68, .external_lex_state = 3},
  [6872] = {.lex_state = 69, .external_lex_state = 3},
  [6873] = {.lex_state = 69, .external_lex_state = 3},
  [6874] = {.lex_state = 67, .external_lex_state = 3},
  [6875] = {.lex_state = 69, .external_lex_state = 3},
  [6876] = {.lex_state = 65, .external_lex_state = 3},
  [6877] = {.lex_state = 69, .external_lex_state = 3},
  [6878] = {.lex_state = 69, .external_lex_state = 3},
  [6879] = {.lex_state = 69, .external_lex_state = 3},
  [6880] = {.lex_state = 69, .external_lex_state = 3},
  [6881] = {.lex_state = 69, .external_lex_state = 3},
  [6882] = {.lex_state = 69, .external_lex_state = 3},
  [6883] = {.lex_state = 69, .external_lex_state = 3},
  [6884] = {.lex_state = 69, .external_lex_state = 3},
  [6885] = {.lex_state = 61, .external_lex_state = 3},
  [6886] = {.lex_state = 67, .external_lex_state = 3},
  [6887] = {.lex_state = 69, .external_lex_state = 3},
  [6888] = {.lex_state = 67, .external_lex_state = 3},
  [6889] = {.lex_state = 68, .external_lex_state = 3},
  [6890] = {.lex_state = 64, .external_lex_state = 3},
  [6891] = {.lex_state = 69, .external_lex_state = 3},
  [6892] = {.lex_state = 69, .external_lex_state = 3},
  [6893] = {.lex_state = 69, .external_lex_state = 3},
  [6894] = {.lex_state = 69, .external_lex_state = 3},
  [6895] = {.lex_state = 69, .external_lex_state = 3},
  [6896] = {.lex_state = 61, .external_lex_state = 3},
  [6897] = {.lex_state = 69, .external_lex_state = 3},
  [6898] = {.lex_state = 69, .external_lex_state = 3},
  [6899] = {.lex_state = 69, .external_lex_state = 3},
  [6900] = {.lex_state = 69, .external_lex_state = 3},
  [6901] = {.lex_state = 61, .external_lex_state = 3},
  [6902] = {.lex_state = 71, .external_lex_state = 3},
  [6903] = {.lex_state = 67, .external_lex_state = 3},
  [6904] = {.lex_state = 67, .external_lex_state = 3},
  [6905] = {.lex_state = 64, .external_lex_state = 3},
  [6906] = {.lex_state = 67, .external_lex_state = 3},
  [6907] = {.lex_state = 71, .external_lex_state = 3},
  [6908] = {.lex_state = 71, .external_lex_state = 3},
  [6909] = {.lex_state = 71, .external_lex_state = 3},
  [6910] = {.lex_state = 67, .external_lex_state = 3},
  [6911] = {.lex_state = 67, .external_lex_state = 3},
  [6912] = {.lex_state = 67, .external_lex_state = 3},
  [6913] = {.lex_state = 67, .external_lex_state = 3},
  [6914] = {.lex_state = 67, .external_lex_state = 3},
  [6915] = {.lex_state = 67, .external_lex_state = 3},
  [6916] = {.lex_state = 67, .external_lex_state = 3},
  [6917] = {.lex_state = 67, .external_lex_state = 3},
  [6918] = {.lex_state = 67, .external_lex_state = 3},
  [6919] = {.lex_state = 67, .external_lex_state = 3},
  [6920] = {.lex_state = 71, .external_lex_state = 3},
  [6921] = {.lex_state = 68, .external_lex_state = 3},
  [6922] = {.lex_state = 69, .external_lex_state = 3},
  [6923] = {.lex_state = 64, .external_lex_state = 3},
  [6924] = {.lex_state = 64, .external_lex_state = 3},
  [6925] = {.lex_state = 71, .external_lex_state = 3},
  [6926] = {.lex_state = 64, .external_lex_state = 3},
  [6927] = {.lex_state = 71, .external_lex_state = 3},
  [6928] = {.lex_state = 64, .external_lex_state = 3},
  [6929] = {.lex_state = 64, .external_lex_state = 3},
  [6930] = {.lex_state = 64, .external_lex_state = 3},
  [6931] = {.lex_state = 64, .external_lex_state = 3},
  [6932] = {.lex_state = 64, .external_lex_state = 3},
  [6933] = {.lex_state = 64, .external_lex_state = 3},
  [6934] = {.lex_state = 64, .external_lex_state = 3},
  [6935] = {.lex_state = 61, .external_lex_state = 3},
  [6936] = {.lex_state = 67, .external_lex_state = 3},
  [6937] = {.lex_state = 72, .external_lex_state = 3},
  [6938] = {.lex_state = 69, .external_lex_state = 3},
  [6939] = {.lex_state = 64, .external_lex_state = 3},
  [6940] = {.lex_state = 64, .external_lex_state = 3},
  [6941] = {.lex_state = 69, .external_lex_state = 3},
  [6942] = {.lex_state = 64, .external_lex_state = 3},
  [6943] = {.lex_state = 64, .external_lex_state = 3},
  [6944] = {.lex_state = 438, .external_lex_state = 3},
  [6945] = {.lex_state = 62, .external_lex_state = 3},
  [6946] = {.lex_state = 69, .external_lex_state = 3},
  [6947] = {.lex_state = 64, .external_lex_state = 3},
  [6948] = {.lex_state = 58, .external_lex_state = 3},
  [6949] = {.lex_state = 62, .external_lex_state = 3},
  [6950] = {.lex_state = 67, .external_lex_state = 3},
  [6951] = {.lex_state = 65, .external_lex_state = 3},
  [6952] = {.lex_state = 65, .external_lex_state = 3},
  [6953] = {.lex_state = 65, .external_lex_state = 3},
  [6954] = {.lex_state = 65, .external_lex_state = 3},
  [6955] = {.lex_state = 65, .external_lex_state = 3},
  [6956] = {.lex_state = 65, .external_lex_state = 3},
  [6957] = {.lex_state = 65, .external_lex_state = 3},
  [6958] = {.lex_state = 65, .external_lex_state = 3},
  [6959] = {.lex_state = 65, .external_lex_state = 3},
  [6960] = {.lex_state = 65, .external_lex_state = 3},
  [6961] = {.lex_state = 62, .external_lex_state = 3},
  [6962] = {.lex_state = 65, .external_lex_state = 3},
  [6963] = {.lex_state = 65, .external_lex_state = 3},
  [6964] = {.lex_state = 65, .external_lex_state = 3},
  [6965] = {.lex_state = 65, .external_lex_state = 3},
  [6966] = {.lex_state = 65, .external_lex_state = 3},
  [6967] = {.lex_state = 65, .external_lex_state = 3},
  [6968] = {.lex_state = 65, .external_lex_state = 3},
  [6969] = {.lex_state = 65, .external_lex_state = 3},
  [6970] = {.lex_state = 65, .external_lex_state = 3},
  [6971] = {.lex_state = 65, .external_lex_state = 3},
  [6972] = {.lex_state = 65, .external_lex_state = 3},
  [6973] = {.lex_state = 65, .external_lex_state = 3},
  [6974] = {.lex_state = 65, .external_lex_state = 3},
  [6975] = {.lex_state = 65, .external_lex_state = 3},
  [6976] = {.lex_state = 65, .external_lex_state = 3},
  [6977] = {.lex_state = 65, .external_lex_state = 3},
  [6978] = {.lex_state = 65, .external_lex_state = 3},
  [6979] = {.lex_state = 65, .external_lex_state = 3},
  [6980] = {.lex_state = 65, .external_lex_state = 3},
  [6981] = {.lex_state = 65, .external_lex_state = 3},
  [6982] = {.lex_state = 65, .external_lex_state = 3},
  [6983] = {.lex_state = 65, .external_lex_state = 3},
  [6984] = {.lex_state = 65, .external_lex_state = 3},
  [6985] = {.lex_state = 64, .external_lex_state = 3},
  [6986] = {.lex_state = 65, .external_lex_state = 3},
  [6987] = {.lex_state = 65, .external_lex_state = 3},
  [6988] = {.lex_state = 65, .external_lex_state = 3},
  [6989] = {.lex_state = 65, .external_lex_state = 3},
  [6990] = {.lex_state = 65, .external_lex_state = 3},
  [6991] = {.lex_state = 65, .external_lex_state = 3},
  [6992] = {.lex_state = 68, .external_lex_state = 3},
  [6993] = {.lex_state = 62, .external_lex_state = 3},
  [6994] = {.lex_state = 62, .external_lex_state = 3},
  [6995] = {.lex_state = 68, .external_lex_state = 3},
  [6996] = {.lex_state = 62, .external_lex_state = 3},
  [6997] = {.lex_state = 67, .external_lex_state = 3},
  [6998] = {.lex_state = 67, .external_lex_state = 3},
  [6999] = {.lex_state = 65, .external_lex_state = 3},
  [7000] = {.lex_state = 67, .external_lex_state = 3},
  [7001] = {.lex_state = 67, .external_lex_state = 3},
  [7002] = {.lex_state = 67, .external_lex_state = 3},
  [7003] = {.lex_state = 67, .external_lex_state = 3},
  [7004] = {.lex_state = 69, .external_lex_state = 3},
  [7005] = {.lex_state = 61, .external_lex_state = 3},
  [7006] = {.lex_state = 70, .external_lex_state = 3},
  [7007] = {.lex_state = 68, .external_lex_state = 3},
  [7008] = {.lex_state = 68, .external_lex_state = 3},
  [7009] = {.lex_state = 67, .external_lex_state = 3},
  [7010] = {.lex_state = 68, .external_lex_state = 3},
  [7011] = {.lex_state = 68, .external_lex_state = 3},
  [7012] = {.lex_state = 62, .external_lex_state = 3},
  [7013] = {.lex_state = 62, .external_lex_state = 3},
  [7014] = {.lex_state = 62, .external_lex_state = 3},
  [7015] = {.lex_state = 65, .external_lex_state = 3},
  [7016] = {.lex_state = 65, .external_lex_state = 3},
  [7017] = {.lex_state = 73, .external_lex_state = 3},
  [7018] = {.lex_state = 61, .external_lex_state = 3},
  [7019] = {.lex_state = 65, .external_lex_state = 3},
  [7020] = {.lex_state = 67, .external_lex_state = 3},
  [7021] = {.lex_state = 70, .external_lex_state = 3},
  [7022] = {.lex_state = 65, .external_lex_state = 3},
  [7023] = {.lex_state = 65, .external_lex_state = 3},
  [7024] = {.lex_state = 438, .external_lex_state = 3},
  [7025] = {.lex_state = 72, .external_lex_state = 3},
  [7026] = {.lex_state = 72, .external_lex_state = 3},
  [7027] = {.lex_state = 72, .external_lex_state = 3},
  [7028] = {.lex_state = 72, .external_lex_state = 3},
  [7029] = {.lex_state = 72, .external_lex_state = 3},
  [7030] = {.lex_state = 72, .external_lex_state = 3},
  [7031] = {.lex_state = 72, .external_lex_state = 3},
  [7032] = {.lex_state = 70, .external_lex_state = 3},
  [7033] = {.lex_state = 70, .external_lex_state = 3},
  [7034] = {.lex_state = 70, .external_lex_state = 3},
  [7035] = {.lex_state = 70, .external_lex_state = 3},
  [7036] = {.lex_state = 70, .external_lex_state = 3},
  [7037] = {.lex_state = 70, .external_lex_state = 3},
  [7038] = {.lex_state = 70, .external_lex_state = 3},
  [7039] = {.lex_state = 70, .external_lex_state = 3},
  [7040] = {.lex_state = 70, .external_lex_state = 3},
  [7041] = {.lex_state = 70, .external_lex_state = 3},
  [7042] = {.lex_state = 70, .external_lex_state = 3},
  [7043] = {.lex_state = 70, .external_lex_state = 3},
  [7044] = {.lex_state = 70, .external_lex_state = 3},
  [7045] = {.lex_state = 70, .external_lex_state = 3},
  [7046] = {.lex_state = 70, .external_lex_state = 3},
  [7047] = {.lex_state = 70, .external_lex_state = 3},
  [7048] = {.lex_state = 70, .external_lex_state = 3},
  [7049] = {.lex_state = 72, .external_lex_state = 3},
  [7050] = {.lex_state = 70, .external_lex_state = 3},
  [7051] = {.lex_state = 70, .external_lex_state = 3},
  [7052] = {.lex_state = 40, .external_lex_state = 3},
  [7053] = {.lex_state = 70, .external_lex_state = 3},
  [7054] = {.lex_state = 70, .external_lex_state = 3},
  [7055] = {.lex_state = 70, .external_lex_state = 3},
  [7056] = {.lex_state = 72, .external_lex_state = 3},
  [7057] = {.lex_state = 66, .external_lex_state = 3},
  [7058] = {.lex_state = 66, .external_lex_state = 3},
  [7059] = {.lex_state = 66, .external_lex_state = 3},
  [7060] = {.lex_state = 66, .external_lex_state = 3},
  [7061] = {.lex_state = 66, .external_lex_state = 3},
  [7062] = {.lex_state = 66, .external_lex_state = 3},
  [7063] = {.lex_state = 66, .external_lex_state = 3},
  [7064] = {.lex_state = 66, .external_lex_state = 3},
  [7065] = {.lex_state = 66, .external_lex_state = 3},
  [7066] = {.lex_state = 66, .external_lex_state = 3},
  [7067] = {.lex_state = 66, .external_lex_state = 3},
  [7068] = {.lex_state = 66, .external_lex_state = 3},
  [7069] = {.lex_state = 66, .external_lex_state = 3},
  [7070] = {.lex_state = 66, .external_lex_state = 3},
  [7071] = {.lex_state = 66, .external_lex_state = 3},
  [7072] = {.lex_state = 66, .external_lex_state = 3},
  [7073] = {.lex_state = 66, .external_lex_state = 3},
  [7074] = {.lex_state = 66, .external_lex_state = 3},
  [7075] = {.lex_state = 66, .external_lex_state = 3},
  [7076] = {.lex_state = 66, .external_lex_state = 3},
  [7077] = {.lex_state = 66, .external_lex_state = 3},
  [7078] = {.lex_state = 66, .external_lex_state = 3},
  [7079] = {.lex_state = 66, .external_lex_state = 3},
  [7080] = {.lex_state = 66, .external_lex_state = 3},
  [7081] = {.lex_state = 66, .external_lex_state = 3},
  [7082] = {.lex_state = 66, .external_lex_state = 3},
  [7083] = {.lex_state = 66, .external_lex_state = 3},
  [7084] = {.lex_state = 66, .external_lex_state = 3},
  [7085] = {.lex_state = 66, .external_lex_state = 3},
  [7086] = {.lex_state = 66, .external_lex_state = 3},
  [7087] = {.lex_state = 66, .external_lex_state = 3},
  [7088] = {.lex_state = 66, .external_lex_state = 3},
  [7089] = {.lex_state = 66, .external_lex_state = 3},
  [7090] = {.lex_state = 66, .external_lex_state = 3},
  [7091] = {.lex_state = 66, .external_lex_state = 3},
  [7092] = {.lex_state = 66, .external_lex_state = 3},
  [7093] = {.lex_state = 66, .external_lex_state = 3},
  [7094] = {.lex_state = 26, .external_lex_state = 3},
  [7095] = {.lex_state = 66, .external_lex_state = 3},
  [7096] = {.lex_state = 70, .external_lex_state = 3},
  [7097] = {.lex_state = 66, .external_lex_state = 3},
  [7098] = {.lex_state = 70, .external_lex_state = 3},
  [7099] = {.lex_state = 70, .external_lex_state = 3},
  [7100] = {.lex_state = 70, .external_lex_state = 3},
  [7101] = {.lex_state = 26, .external_lex_state = 3},
  [7102] = {.lex_state = 71, .external_lex_state = 3},
  [7103] = {.lex_state = 26, .external_lex_state = 3},
  [7104] = {.lex_state = 70, .external_lex_state = 3},
  [7105] = {.lex_state = 66, .external_lex_state = 3},
  [7106] = {.lex_state = 70, .external_lex_state = 3},
  [7107] = {.lex_state = 70, .external_lex_state = 3},
  [7108] = {.lex_state = 72, .external_lex_state = 3},
  [7109] = {.lex_state = 70, .external_lex_state = 3},
  [7110] = {.lex_state = 71, .external_lex_state = 3},
  [7111] = {.lex_state = 66, .external_lex_state = 3},
  [7112] = {.lex_state = 70, .external_lex_state = 3},
  [7113] = {.lex_state = 71, .external_lex_state = 3},
  [7114] = {.lex_state = 66, .external_lex_state = 3},
  [7115] = {.lex_state = 62, .external_lex_state = 3},
  [7116] = {.lex_state = 70, .external_lex_state = 3},
  [7117] = {.lex_state = 66, .external_lex_state = 3},
  [7118] = {.lex_state = 62, .external_lex_state = 3},
  [7119] = {.lex_state = 66, .external_lex_state = 3},
  [7120] = {.lex_state = 66, .external_lex_state = 3},
  [7121] = {.lex_state = 66, .external_lex_state = 3},
  [7122] = {.lex_state = 66, .external_lex_state = 3},
  [7123] = {.lex_state = 66, .external_lex_state = 3},
  [7124] = {.lex_state = 66, .external_lex_state = 3},
  [7125] = {.lex_state = 66, .external_lex_state = 3},
  [7126] = {.lex_state = 66, .external_lex_state = 3},
  [7127] = {.lex_state = 62, .external_lex_state = 3},
  [7128] = {.lex_state = 71, .external_lex_state = 3},
  [7129] = {.lex_state = 26, .external_lex_state = 3},
  [7130] = {.lex_state = 26, .external_lex_state = 3},
  [7131] = {.lex_state = 72, .external_lex_state = 3},
  [7132] = {.lex_state = 26, .external_lex_state = 3},
  [7133] = {.lex_state = 26, .external_lex_state = 3},
  [7134] = {.lex_state = 26, .external_lex_state = 3},
  [7135] = {.lex_state = 26, .external_lex_state = 3},
  [7136] = {.lex_state = 72, .external_lex_state = 3},
  [7137] = {.lex_state = 71, .external_lex_state = 3},
  [7138] = {.lex_state = 62, .external_lex_state = 3},
  [7139] = {.lex_state = 26, .external_lex_state = 3},
  [7140] = {.lex_state = 26, .external_lex_state = 3},
  [7141] = {.lex_state = 72, .external_lex_state = 3},
  [7142] = {.lex_state = 26, .external_lex_state = 3},
  [7143] = {.lex_state = 66, .external_lex_state = 3},
  [7144] = {.lex_state = 26, .external_lex_state = 3},
  [7145] = {.lex_state = 71, .external_lex_state = 3},
  [7146] = {.lex_state = 38, .external_lex_state = 3},
  [7147] = {.lex_state = 66, .external_lex_state = 3},
  [7148] = {.lex_state = 10, .external_lex_state = 2},
  [7149] = {.lex_state = 72, .external_lex_state = 3},
  [7150] = {.lex_state = 66, .external_lex_state = 3},
  [7151] = {.lex_state = 72, .external_lex_state = 3},
  [7152] = {.lex_state = 26, .external_lex_state = 3},
  [7153] = {.lex_state = 71, .external_lex_state = 3},
  [7154] = {.lex_state = 26, .external_lex_state = 3},
  [7155] = {.lex_state = 66, .external_lex_state = 3},
  [7156] = {.lex_state = 10, .external_lex_state = 2},
  [7157] = {.lex_state = 26, .external_lex_state = 3},
  [7158] = {.lex_state = 74, .external_lex_state = 3},
  [7159] = {.lex_state = 26, .external_lex_state = 3},
  [7160] = {.lex_state = 71, .external_lex_state = 3},
  [7161] = {.lex_state = 62, .external_lex_state = 3},
  [7162] = {.lex_state = 26, .external_lex_state = 3},
  [7163] = {.lex_state = 72, .external_lex_state = 3},
  [7164] = {.lex_state = 72, .external_lex_state = 3},
  [7165] = {.lex_state = 26, .external_lex_state = 3},
  [7166] = {.lex_state = 72, .external_lex_state = 3},
  [7167] = {.lex_state = 72, .external_lex_state = 3},
  [7168] = {.lex_state = 72, .external_lex_state = 3},
  [7169] = {.lex_state = 72, .external_lex_state = 3},
  [7170] = {.lex_state = 71, .external_lex_state = 3},
  [7171] = {.lex_state = 72, .external_lex_state = 3},
  [7172] = {.lex_state = 72, .external_lex_state = 3},
  [7173] = {.lex_state = 72, .external_lex_state = 3},
  [7174] = {.lex_state = 26, .external_lex_state = 3},
  [7175] = {.lex_state = 26, .external_lex_state = 3},
  [7176] = {.lex_state = 26, .external_lex_state = 3},
  [7177] = {.lex_state = 26, .external_lex_state = 3},
  [7178] = {.lex_state = 74, .external_lex_state = 3},
  [7179] = {.lex_state = 26, .external_lex_state = 3},
  [7180] = {.lex_state = 26, .external_lex_state = 3},
  [7181] = {.lex_state = 26, .external_lex_state = 3},
  [7182] = {.lex_state = 26, .external_lex_state = 3},
  [7183] = {.lex_state = 26, .external_lex_state = 3},
  [7184] = {.lex_state = 72, .external_lex_state = 3},
  [7185] = {.lex_state = 62, .external_lex_state = 3},
  [7186] = {.lex_state = 71, .external_lex_state = 3},
  [7187] = {.lex_state = 71, .external_lex_state = 3},
  [7188] = {.lex_state = 62, .external_lex_state = 3},
  [7189] = {.lex_state = 71, .external_lex_state = 3},
  [7190] = {.lex_state = 26, .external_lex_state = 3},
  [7191] = {.lex_state = 72, .external_lex_state = 3},
  [7192] = {.lex_state = 72, .external_lex_state = 3},
  [7193] = {.lex_state = 62, .external_lex_state = 3},
  [7194] = {.lex_state = 71, .external_lex_state = 3},
  [7195] = {.lex_state = 70, .external_lex_state = 3},
  [7196] = {.lex_state = 70, .external_lex_state = 3},
  [7197] = {.lex_state = 71, .external_lex_state = 3},
  [7198] = {.lex_state = 72, .external_lex_state = 3},
  [7199] = {.lex_state = 26, .external_lex_state = 3},
  [7200] = {.lex_state = 26, .external_lex_state = 3},
  [7201] = {.lex_state = 26, .external_lex_state = 3},
  [7202] = {.lex_state = 71, .external_lex_state = 3},
  [7203] = {.lex_state = 26, .external_lex_state = 3},
  [7204] = {.lex_state = 62, .external_lex_state = 3},
  [7205] = {.lex_state = 70, .external_lex_state = 3},
  [7206] = {.lex_state = 71, .external_lex_state = 3},
  [7207] = {.lex_state = 71, .external_lex_state = 3},
  [7208] = {.lex_state = 71, .external_lex_state = 3},
  [7209] = {.lex_state = 71, .external_lex_state = 3},
  [7210] = {.lex_state = 72, .external_lex_state = 3},
  [7211] = {.lex_state = 70, .external_lex_state = 3},
  [7212] = {.lex_state = 62, .external_lex_state = 3},
  [7213] = {.lex_state = 62, .external_lex_state = 3},
  [7214] = {.lex_state = 71, .external_lex_state = 3},
  [7215] = {.lex_state = 70, .external_lex_state = 3},
  [7216] = {.lex_state = 62, .external_lex_state = 3},
  [7217] = {.lex_state = 71, .external_lex_state = 3},
  [7218] = {.lex_state = 71, .external_lex_state = 3},
  [7219] = {.lex_state = 71, .external_lex_state = 3},
  [7220] = {.lex_state = 71, .external_lex_state = 3},
  [7221] = {.lex_state = 72, .external_lex_state = 3},
  [7222] = {.lex_state = 72, .external_lex_state = 3},
  [7223] = {.lex_state = 10, .external_lex_state = 2},
  [7224] = {.lex_state = 72, .external_lex_state = 3},
  [7225] = {.lex_state = 71, .external_lex_state = 3},
  [7226] = {.lex_state = 72, .external_lex_state = 3},
  [7227] = {.lex_state = 72, .external_lex_state = 3},
  [7228] = {.lex_state = 72, .external_lex_state = 3},
  [7229] = {.lex_state = 72, .external_lex_state = 3},
  [7230] = {.lex_state = 72, .external_lex_state = 3},
  [7231] = {.lex_state = 26, .external_lex_state = 3},
  [7232] = {.lex_state = 66, .external_lex_state = 3},
  [7233] = {.lex_state = 70, .external_lex_state = 3},
  [7234] = {.lex_state = 70, .external_lex_state = 3},
  [7235] = {.lex_state = 70, .external_lex_state = 3},
  [7236] = {.lex_state = 62, .external_lex_state = 3},
  [7237] = {.lex_state = 10, .external_lex_state = 2},
  [7238] = {.lex_state = 70, .external_lex_state = 3},
  [7239] = {.lex_state = 62, .external_lex_state = 3},
  [7240] = {.lex_state = 70, .external_lex_state = 3},
  [7241] = {.lex_state = 70, .external_lex_state = 3},
  [7242] = {.lex_state = 66, .external_lex_state = 3},
  [7243] = {.lex_state = 66, .external_lex_state = 3},
  [7244] = {.lex_state = 72, .external_lex_state = 3},
  [7245] = {.lex_state = 72, .external_lex_state = 3},
  [7246] = {.lex_state = 70, .external_lex_state = 3},
  [7247] = {.lex_state = 70, .external_lex_state = 3},
  [7248] = {.lex_state = 10, .external_lex_state = 2},
  [7249] = {.lex_state = 66, .external_lex_state = 3},
  [7250] = {.lex_state = 66, .external_lex_state = 3},
  [7251] = {.lex_state = 71, .external_lex_state = 3},
  [7252] = {.lex_state = 70, .external_lex_state = 3},
  [7253] = {.lex_state = 62, .external_lex_state = 3},
  [7254] = {.lex_state = 70, .external_lex_state = 3},
  [7255] = {.lex_state = 72, .external_lex_state = 3},
  [7256] = {.lex_state = 72, .external_lex_state = 3},
  [7257] = {.lex_state = 70, .external_lex_state = 3},
  [7258] = {.lex_state = 70, .external_lex_state = 3},
  [7259] = {.lex_state = 70, .external_lex_state = 3},
  [7260] = {.lex_state = 62, .external_lex_state = 3},
  [7261] = {.lex_state = 70, .external_lex_state = 3},
  [7262] = {.lex_state = 70, .external_lex_state = 3},
  [7263] = {.lex_state = 70, .external_lex_state = 3},
  [7264] = {.lex_state = 26, .external_lex_state = 3},
  [7265] = {.lex_state = 72, .external_lex_state = 3},
  [7266] = {.lex_state = 72, .external_lex_state = 3},
  [7267] = {.lex_state = 72, .external_lex_state = 3},
  [7268] = {.lex_state = 72, .external_lex_state = 3},
  [7269] = {.lex_state = 66, .external_lex_state = 3},
  [7270] = {.lex_state = 72, .external_lex_state = 3},
  [7271] = {.lex_state = 70, .external_lex_state = 3},
  [7272] = {.lex_state = 62, .external_lex_state = 3},
  [7273] = {.lex_state = 72, .external_lex_state = 3},
  [7274] = {.lex_state = 72, .external_lex_state = 3},
  [7275] = {.lex_state = 72, .external_lex_state = 3},
  [7276] = {.lex_state = 66, .external_lex_state = 3},
  [7277] = {.lex_state = 62, .external_lex_state = 3},
  [7278] = {.lex_state = 66, .external_lex_state = 3},
  [7279] = {.lex_state = 72, .external_lex_state = 3},
  [7280] = {.lex_state = 66, .external_lex_state = 3},
  [7281] = {.lex_state = 26, .external_lex_state = 3},
  [7282] = {.lex_state = 62, .external_lex_state = 3},
  [7283] = {.lex_state = 71, .external_lex_state = 3},
  [7284] = {.lex_state = 72, .external_lex_state = 3},
  [7285] = {.lex_state = 71, .external_lex_state = 3},
  [7286] = {.lex_state = 71, .external_lex_state = 3},
  [7287] = {.lex_state = 71, .external_lex_state = 3},
  [7288] = {.lex_state = 71, .external_lex_state = 3},
  [7289] = {.lex_state = 71, .external_lex_state = 3},
  [7290] = {.lex_state = 70, .external_lex_state = 3},
  [7291] = {.lex_state = 71, .external_lex_state = 3},
  [7292] = {.lex_state = 71, .external_lex_state = 3},
  [7293] = {.lex_state = 71, .external_lex_state = 3},
  [7294] = {.lex_state = 71, .external_lex_state = 3},
  [7295] = {.lex_state = 70, .external_lex_state = 3},
  [7296] = {.lex_state = 71, .external_lex_state = 3},
  [7297] = {.lex_state = 72, .external_lex_state = 3},
  [7298] = {.lex_state = 71, .external_lex_state = 3},
  [7299] = {.lex_state = 62, .external_lex_state = 3},
  [7300] = {.lex_state = 71, .external_lex_state = 3},
  [7301] = {.lex_state = 71, .external_lex_state = 3},
  [7302] = {.lex_state = 26, .external_lex_state = 3},
  [7303] = {.lex_state = 71, .external_lex_state = 3},
  [7304] = {.lex_state = 71, .external_lex_state = 3},
  [7305] = {.lex_state = 71, .external_lex_state = 3},
  [7306] = {.lex_state = 72, .external_lex_state = 3},
  [7307] = {.lex_state = 72, .external_lex_state = 3},
  [7308] = {.lex_state = 72, .external_lex_state = 3},
  [7309] = {.lex_state = 72, .external_lex_state = 3},
  [7310] = {.lex_state = 66, .external_lex_state = 3},
  [7311] = {.lex_state = 71, .external_lex_state = 3},
  [7312] = {.lex_state = 71, .external_lex_state = 3},
  [7313] = {.lex_state = 72, .external_lex_state = 3},
  [7314] = {.lex_state = 71, .external_lex_state = 3},
  [7315] = {.lex_state = 72, .external_lex_state = 3},
  [7316] = {.lex_state = 71, .external_lex_state = 3},
  [7317] = {.lex_state = 72, .external_lex_state = 3},
  [7318] = {.lex_state = 71, .external_lex_state = 3},
  [7319] = {.lex_state = 70, .external_lex_state = 3},
  [7320] = {.lex_state = 71, .external_lex_state = 3},
  [7321] = {.lex_state = 62, .external_lex_state = 3},
  [7322] = {.lex_state = 71, .external_lex_state = 3},
  [7323] = {.lex_state = 62, .external_lex_state = 3},
  [7324] = {.lex_state = 71, .external_lex_state = 3},
  [7325] = {.lex_state = 70, .external_lex_state = 3},
  [7326] = {.lex_state = 72, .external_lex_state = 3},
  [7327] = {.lex_state = 71, .external_lex_state = 3},
  [7328] = {.lex_state = 70, .external_lex_state = 3},
  [7329] = {.lex_state = 70, .external_lex_state = 3},
  [7330] = {.lex_state = 70, .external_lex_state = 3},
  [7331] = {.lex_state = 62, .external_lex_state = 3},
  [7332] = {.lex_state = 26, .external_lex_state = 3},
  [7333] = {.lex_state = 72, .external_lex_state = 3},
  [7334] = {.lex_state = 26, .external_lex_state = 3},
  [7335] = {.lex_state = 66, .external_lex_state = 3},
  [7336] = {.lex_state = 66, .external_lex_state = 3},
  [7337] = {.lex_state = 66, .external_lex_state = 3},
  [7338] = {.lex_state = 66, .external_lex_state = 3},
  [7339] = {.lex_state = 70, .external_lex_state = 3},
  [7340] = {.lex_state = 66, .external_lex_state = 3},
  [7341] = {.lex_state = 66, .external_lex_state = 3},
  [7342] = {.lex_state = 72, .external_lex_state = 3},
  [7343] = {.lex_state = 71, .external_lex_state = 3},
  [7344] = {.lex_state = 71, .external_lex_state = 3},
  [7345] = {.lex_state = 71, .external_lex_state = 3},
  [7346] = {.lex_state = 71, .external_lex_state = 3},
  [7347] = {.lex_state = 66, .external_lex_state = 3},
  [7348] = {.lex_state = 72, .external_lex_state = 3},
  [7349] = {.lex_state = 71, .external_lex_state = 3},
  [7350] = {.lex_state = 71, .external_lex_state = 3},
  [7351] = {.lex_state = 66, .external_lex_state = 3},
  [7352] = {.lex_state = 71, .external_lex_state = 3},
  [7353] = {.lex_state = 71, .external_lex_state = 3},
  [7354] = {.lex_state = 71, .external_lex_state = 3},
  [7355] = {.lex_state = 62, .external_lex_state = 3},
  [7356] = {.lex_state = 66, .external_lex_state = 3},
  [7357] = {.lex_state = 70, .external_lex_state = 3},
  [7358] = {.lex_state = 66, .external_lex_state = 3},
  [7359] = {.lex_state = 71, .external_lex_state = 3},
  [7360] = {.lex_state = 71, .external_lex_state = 3},
  [7361] = {.lex_state = 71, .external_lex_state = 3},
  [7362] = {.lex_state = 71, .external_lex_state = 3},
  [7363] = {.lex_state = 71, .external_lex_state = 3},
  [7364] = {.lex_state = 71, .external_lex_state = 3},
  [7365] = {.lex_state = 71, .external_lex_state = 3},
  [7366] = {.lex_state = 71, .external_lex_state = 3},
  [7367] = {.lex_state = 26, .external_lex_state = 3},
  [7368] = {.lex_state = 26, .external_lex_state = 3},
  [7369] = {.lex_state = 26, .external_lex_state = 3},
  [7370] = {.lex_state = 26, .external_lex_state = 3},
  [7371] = {.lex_state = 26, .external_lex_state = 3},
  [7372] = {.lex_state = 66, .external_lex_state = 3},
  [7373] = {.lex_state = 26, .external_lex_state = 3},
  [7374] = {.lex_state = 70, .external_lex_state = 3},
  [7375] = {.lex_state = 26, .external_lex_state = 3},
  [7376] = {.lex_state = 26, .external_lex_state = 3},
  [7377] = {.lex_state = 26, .external_lex_state = 3},
  [7378] = {.lex_state = 71, .external_lex_state = 3},
  [7379] = {.lex_state = 26, .external_lex_state = 3},
  [7380] = {.lex_state = 26, .external_lex_state = 3},
  [7381] = {.lex_state = 26, .external_lex_state = 3},
  [7382] = {.lex_state = 66, .external_lex_state = 3},
  [7383] = {.lex_state = 71, .external_lex_state = 3},
  [7384] = {.lex_state = 26, .external_lex_state = 3},
  [7385] = {.lex_state = 26, .external_lex_state = 3},
  [7386] = {.lex_state = 26, .external_lex_state = 3},
  [7387] = {.lex_state = 71, .external_lex_state = 3},
  [7388] = {.lex_state = 26, .external_lex_state = 3},
  [7389] = {.lex_state = 71, .external_lex_state = 3},
  [7390] = {.lex_state = 26, .external_lex_state = 3},
  [7391] = {.lex_state = 26, .external_lex_state = 3},
  [7392] = {.lex_state = 26, .external_lex_state = 3},
  [7393] = {.lex_state = 26, .external_lex_state = 3},
  [7394] = {.lex_state = 26, .external_lex_state = 3},
  [7395] = {.lex_state = 26, .external_lex_state = 3},
  [7396] = {.lex_state = 26, .external_lex_state = 3},
  [7397] = {.lex_state = 26, .external_lex_state = 3},
  [7398] = {.lex_state = 26, .external_lex_state = 3},
  [7399] = {.lex_state = 26, .external_lex_state = 3},
  [7400] = {.lex_state = 26, .external_lex_state = 3},
  [7401] = {.lex_state = 26, .external_lex_state = 3},
  [7402] = {.lex_state = 26, .external_lex_state = 3},
  [7403] = {.lex_state = 26, .external_lex_state = 3},
  [7404] = {.lex_state = 26, .external_lex_state = 3},
  [7405] = {.lex_state = 26, .external_lex_state = 3},
  [7406] = {.lex_state = 71, .external_lex_state = 3},
  [7407] = {.lex_state = 26, .external_lex_state = 3},
  [7408] = {.lex_state = 26, .external_lex_state = 3},
  [7409] = {.lex_state = 26, .external_lex_state = 3},
  [7410] = {.lex_state = 26, .external_lex_state = 3},
  [7411] = {.lex_state = 26, .external_lex_state = 3},
  [7412] = {.lex_state = 26, .external_lex_state = 3},
  [7413] = {.lex_state = 26, .external_lex_state = 3},
  [7414] = {.lex_state = 26, .external_lex_state = 3},
  [7415] = {.lex_state = 26, .external_lex_state = 3},
  [7416] = {.lex_state = 26, .external_lex_state = 3},
  [7417] = {.lex_state = 26, .external_lex_state = 3},
  [7418] = {.lex_state = 71, .external_lex_state = 3},
  [7419] = {.lex_state = 62, .external_lex_state = 3},
  [7420] = {.lex_state = 62, .external_lex_state = 3},
  [7421] = {.lex_state = 72, .external_lex_state = 3},
  [7422] = {.lex_state = 26, .external_lex_state = 3},
  [7423] = {.lex_state = 62, .external_lex_state = 3},
  [7424] = {.lex_state = 70, .external_lex_state = 3},
  [7425] = {.lex_state = 66, .external_lex_state = 3},
  [7426] = {.lex_state = 62, .external_lex_state = 3},
  [7427] = {.lex_state = 62, .external_lex_state = 3},
  [7428] = {.lex_state = 62, .external_lex_state = 3},
  [7429] = {.lex_state = 62, .external_lex_state = 3},
  [7430] = {.lex_state = 62, .external_lex_state = 3},
  [7431] = {.lex_state = 26, .external_lex_state = 3},
  [7432] = {.lex_state = 62, .external_lex_state = 3},
  [7433] = {.lex_state = 72, .external_lex_state = 3},
  [7434] = {.lex_state = 62, .external_lex_state = 3},
  [7435] = {.lex_state = 62, .external_lex_state = 3},
  [7436] = {.lex_state = 62, .external_lex_state = 3},
  [7437] = {.lex_state = 70, .external_lex_state = 3},
  [7438] = {.lex_state = 62, .external_lex_state = 3},
  [7439] = {.lex_state = 62, .external_lex_state = 3},
  [7440] = {.lex_state = 62, .external_lex_state = 3},
  [7441] = {.lex_state = 62, .external_lex_state = 3},
  [7442] = {.lex_state = 62, .external_lex_state = 3},
  [7443] = {.lex_state = 26, .external_lex_state = 3},
  [7444] = {.lex_state = 62, .external_lex_state = 3},
  [7445] = {.lex_state = 62, .external_lex_state = 3},
  [7446] = {.lex_state = 62, .external_lex_state = 3},
  [7447] = {.lex_state = 62, .external_lex_state = 3},
  [7448] = {.lex_state = 62, .external_lex_state = 3},
  [7449] = {.lex_state = 62, .external_lex_state = 3},
  [7450] = {.lex_state = 26, .external_lex_state = 3},
  [7451] = {.lex_state = 62, .external_lex_state = 3},
  [7452] = {.lex_state = 62, .external_lex_state = 3},
  [7453] = {.lex_state = 62, .external_lex_state = 3},
  [7454] = {.lex_state = 62, .external_lex_state = 3},
  [7455] = {.lex_state = 62, .external_lex_state = 3},
  [7456] = {.lex_state = 62, .external_lex_state = 3},
  [7457] = {.lex_state = 62, .external_lex_state = 3},
  [7458] = {.lex_state = 62, .external_lex_state = 3},
  [7459] = {.lex_state = 62, .external_lex_state = 3},
  [7460] = {.lex_state = 70, .external_lex_state = 3},
  [7461] = {.lex_state = 62, .external_lex_state = 3},
  [7462] = {.lex_state = 63, .external_lex_state = 3},
  [7463] = {.lex_state = 70, .external_lex_state = 3},
  [7464] = {.lex_state = 72, .external_lex_state = 3},
  [7465] = {.lex_state = 71, .external_lex_state = 3},
  [7466] = {.lex_state = 62, .external_lex_state = 3},
  [7467] = {.lex_state = 62, .external_lex_state = 3},
  [7468] = {.lex_state = 72, .external_lex_state = 3},
  [7469] = {.lex_state = 62, .external_lex_state = 3},
  [7470] = {.lex_state = 62, .external_lex_state = 3},
  [7471] = {.lex_state = 62, .external_lex_state = 3},
  [7472] = {.lex_state = 62, .external_lex_state = 3},
  [7473] = {.lex_state = 62, .external_lex_state = 3},
  [7474] = {.lex_state = 62, .external_lex_state = 3},
  [7475] = {.lex_state = 62, .external_lex_state = 3},
  [7476] = {.lex_state = 70, .external_lex_state = 3},
  [7477] = {.lex_state = 70, .external_lex_state = 3},
  [7478] = {.lex_state = 72, .external_lex_state = 3},
  [7479] = {.lex_state = 72, .external_lex_state = 3},
  [7480] = {.lex_state = 62, .external_lex_state = 3},
  [7481] = {.lex_state = 72, .external_lex_state = 3},
  [7482] = {.lex_state = 70, .external_lex_state = 3},
  [7483] = {.lex_state = 10, .external_lex_state = 2},
  [7484] = {.lex_state = 71, .external_lex_state = 3},
  [7485] = {.lex_state = 70, .external_lex_state = 3},
  [7486] = {.lex_state = 72, .external_lex_state = 3},
  [7487] = {.lex_state = 72, .external_lex_state = 3},
  [7488] = {.lex_state = 70, .external_lex_state = 3},
  [7489] = {.lex_state = 70, .external_lex_state = 3},
  [7490] = {.lex_state = 70, .external_lex_state = 3},
  [7491] = {.lex_state = 70, .external_lex_state = 3},
  [7492] = {.lex_state = 71, .external_lex_state = 3},
  [7493] = {.lex_state = 71, .external_lex_state = 3},
  [7494] = {.lex_state = 62, .external_lex_state = 3},
  [7495] = {.lex_state = 72, .external_lex_state = 3},
  [7496] = {.lex_state = 62, .external_lex_state = 3},
  [7497] = {.lex_state = 62, .external_lex_state = 3},
  [7498] = {.lex_state = 62, .external_lex_state = 3},
  [7499] = {.lex_state = 62, .external_lex_state = 3},
  [7500] = {.lex_state = 62, .external_lex_state = 3},
  [7501] = {.lex_state = 26, .external_lex_state = 3},
  [7502] = {.lex_state = 72, .external_lex_state = 3},
  [7503] = {.lex_state = 70, .external_lex_state = 3},
  [7504] = {.lex_state = 62, .external_lex_state = 3},
  [7505] = {.lex_state = 62, .external_lex_state = 3},
  [7506] = {.lex_state = 62, .external_lex_state = 3},
  [7507] = {.lex_state = 72, .external_lex_state = 3},
  [7508] = {.lex_state = 62, .external_lex_state = 3},
  [7509] = {.lex_state = 62, .external_lex_state = 3},
  [7510] = {.lex_state = 62, .external_lex_state = 3},
  [7511] = {.lex_state = 72, .external_lex_state = 3},
  [7512] = {.lex_state = 10, .external_lex_state = 2},
  [7513] = {.lex_state = 70, .external_lex_state = 3},
  [7514] = {.lex_state = 70, .external_lex_state = 3},
  [7515] = {.lex_state = 72, .external_lex_state = 3},
  [7516] = {.lex_state = 72, .external_lex_state = 3},
  [7517] = {.lex_state = 72, .external_lex_state = 3},
  [7518] = {.lex_state = 10, .external_lex_state = 2},
  [7519] = {.lex_state = 40, .external_lex_state = 3},
  [7520] = {.lex_state = 14, .external_lex_state = 2},
  [7521] = {.lex_state = 10, .external_lex_state = 2},
  [7522] = {.lex_state = 40, .external_lex_state = 3},
  [7523] = {.lex_state = 40, .external_lex_state = 3},
  [7524] = {.lex_state = 14, .external_lex_state = 2},
  [7525] = {.lex_state = 14, .external_lex_state = 2},
  [7526] = {.lex_state = 14, .external_lex_state = 2},
  [7527] = {.lex_state = 14, .external_lex_state = 2},
  [7528] = {.lex_state = 14, .external_lex_state = 2},
  [7529] = {.lex_state = 14, .external_lex_state = 2},
  [7530] = {.lex_state = 14, .external_lex_state = 2},
  [7531] = {.lex_state = 14, .external_lex_state = 2},
  [7532] = {.lex_state = 14, .external_lex_state = 2},
  [7533] = {.lex_state = 14, .external_lex_state = 2},
  [7534] = {.lex_state = 14, .external_lex_state = 2},
  [7535] = {.lex_state = 14, .external_lex_state = 2},
  [7536] = {.lex_state = 14, .external_lex_state = 2},
  [7537] = {.lex_state = 14, .external_lex_state = 2},
  [7538] = {.lex_state = 14, .external_lex_state = 2},
  [7539] = {.lex_state = 40, .external_lex_state = 3},
  [7540] = {.lex_state = 14, .external_lex_state = 2},
  [7541] = {.lex_state = 14, .external_lex_state = 2},
  [7542] = {.lex_state = 10, .external_lex_state = 2},
  [7543] = {.lex_state = 14, .external_lex_state = 2},
  [7544] = {.lex_state = 14, .external_lex_state = 2},
  [7545] = {.lex_state = 68, .external_lex_state = 3},
  [7546] = {.lex_state = 14, .external_lex_state = 2},
  [7547] = {.lex_state = 14, .external_lex_state = 2},
  [7548] = {.lex_state = 14, .external_lex_state = 2},
  [7549] = {.lex_state = 14, .external_lex_state = 2},
  [7550] = {.lex_state = 14, .external_lex_state = 2},
  [7551] = {.lex_state = 14, .external_lex_state = 2},
  [7552] = {.lex_state = 14, .external_lex_state = 2},
  [7553] = {.lex_state = 14, .external_lex_state = 2},
  [7554] = {.lex_state = 38, .external_lex_state = 3},
  [7555] = {.lex_state = 38, .external_lex_state = 3},
  [7556] = {.lex_state = 14, .external_lex_state = 2},
  [7557] = {.lex_state = 14, .external_lex_state = 2},
  [7558] = {.lex_state = 14, .external_lex_state = 2},
  [7559] = {.lex_state = 61, .external_lex_state = 3},
  [7560] = {.lex_state = 14, .external_lex_state = 2},
  [7561] = {.lex_state = 14, .external_lex_state = 2},
  [7562] = {.lex_state = 14, .external_lex_state = 2},
  [7563] = {.lex_state = 14, .external_lex_state = 2},
  [7564] = {.lex_state = 14, .external_lex_state = 2},
  [7565] = {.lex_state = 40, .external_lex_state = 3},
  [7566] = {.lex_state = 14, .external_lex_state = 2},
  [7567] = {.lex_state = 38, .external_lex_state = 3},
  [7568] = {.lex_state = 38, .external_lex_state = 3},
  [7569] = {.lex_state = 14, .external_lex_state = 2},
  [7570] = {.lex_state = 14, .external_lex_state = 2},
  [7571] = {.lex_state = 180, .external_lex_state = 3},
  [7572] = {.lex_state = 14, .external_lex_state = 2},
  [7573] = {.lex_state = 38, .external_lex_state = 3},
  [7574] = {.lex_state = 14, .external_lex_state = 2},
  [7575] = {.lex_state = 69, .external_lex_state = 3},
  [7576] = {.lex_state = 14, .external_lex_state = 2},
  [7577] = {.lex_state = 14, .external_lex_state = 2},
  [7578] = {.lex_state = 40, .external_lex_state = 3},
  [7579] = {.lex_state = 40, .external_lex_state = 3},
  [7580] = {.lex_state = 14, .external_lex_state = 2},
  [7581] = {.lex_state = 38, .external_lex_state = 3},
  [7582] = {.lex_state = 14, .external_lex_state = 2},
  [7583] = {.lex_state = 14, .external_lex_state = 2},
  [7584] = {.lex_state = 64, .external_lex_state = 3},
  [7585] = {.lex_state = 180, .external_lex_state = 3},
  [7586] = {.lex_state = 14, .external_lex_state = 2},
  [7587] = {.lex_state = 14, .external_lex_state = 2},
  [7588] = {.lex_state = 14, .external_lex_state = 2},
  [7589] = {.lex_state = 211, .external_lex_state = 3},
  [7590] = {.lex_state = 14, .external_lex_state = 2},
  [7591] = {.lex_state = 67, .external_lex_state = 3},
  [7592] = {.lex_state = 14, .external_lex_state = 2},
  [7593] = {.lex_state = 40, .external_lex_state = 3},
  [7594] = {.lex_state = 10, .external_lex_state = 2},
  [7595] = {.lex_state = 14, .external_lex_state = 2},
  [7596] = {.lex_state = 38, .external_lex_state = 3},
  [7597] = {.lex_state = 10, .external_lex_state = 2},
  [7598] = {.lex_state = 14, .external_lex_state = 2},
  [7599] = {.lex_state = 10, .external_lex_state = 2},
  [7600] = {.lex_state = 40, .external_lex_state = 3},
  [7601] = {.lex_state = 40, .external_lex_state = 3},
  [7602] = {.lex_state = 14, .external_lex_state = 2},
  [7603] = {.lex_state = 10, .external_lex_state = 2},
  [7604] = {.lex_state = 38, .external_lex_state = 3},
  [7605] = {.lex_state = 38, .external_lex_state = 3},
  [7606] = {.lex_state = 14, .external_lex_state = 2},
  [7607] = {.lex_state = 38, .external_lex_state = 3},
  [7608] = {.lex_state = 38, .external_lex_state = 3},
  [7609] = {.lex_state = 10, .external_lex_state = 2},
  [7610] = {.lex_state = 10, .external_lex_state = 2},
  [7611] = {.lex_state = 10, .external_lex_state = 2},
  [7612] = {.lex_state = 10, .external_lex_state = 2},
  [7613] = {.lex_state = 10, .external_lex_state = 2},
  [7614] = {.lex_state = 14, .external_lex_state = 2},
  [7615] = {.lex_state = 38, .external_lex_state = 3},
  [7616] = {.lex_state = 38, .external_lex_state = 3},
  [7617] = {.lex_state = 40, .external_lex_state = 3},
  [7618] = {.lex_state = 212, .external_lex_state = 3},
  [7619] = {.lex_state = 181, .external_lex_state = 3},
  [7620] = {.lex_state = 10, .external_lex_state = 2},
  [7621] = {.lex_state = 10, .external_lex_state = 2},
  [7622] = {.lex_state = 38, .external_lex_state = 3},
  [7623] = {.lex_state = 10, .external_lex_state = 2},
  [7624] = {.lex_state = 10, .external_lex_state = 2},
  [7625] = {.lex_state = 10, .external_lex_state = 2},
  [7626] = {.lex_state = 10, .external_lex_state = 2},
  [7627] = {.lex_state = 10, .external_lex_state = 2},
  [7628] = {.lex_state = 10, .external_lex_state = 2},
  [7629] = {.lex_state = 40, .external_lex_state = 3},
  [7630] = {.lex_state = 40, .external_lex_state = 3},
  [7631] = {.lex_state = 10, .external_lex_state = 2},
  [7632] = {.lex_state = 10, .external_lex_state = 2},
  [7633] = {.lex_state = 181, .external_lex_state = 3},
  [7634] = {.lex_state = 10, .external_lex_state = 2},
  [7635] = {.lex_state = 10, .external_lex_state = 2},
  [7636] = {.lex_state = 38, .external_lex_state = 3},
  [7637] = {.lex_state = 10, .external_lex_state = 2},
  [7638] = {.lex_state = 14, .external_lex_state = 2},
  [7639] = {.lex_state = 10, .external_lex_state = 2},
  [7640] = {.lex_state = 10, .external_lex_state = 2},
  [7641] = {.lex_state = 10, .external_lex_state = 2},
  [7642] = {.lex_state = 38, .external_lex_state = 3},
  [7643] = {.lex_state = 38, .external_lex_state = 3},
  [7644] = {.lex_state = 38, .external_lex_state = 3},
  [7645] = {.lex_state = 38, .external_lex_state = 3},
  [7646] = {.lex_state = 10, .external_lex_state = 2},
  [7647] = {.lex_state = 10, .external_lex_state = 2},
  [7648] = {.lex_state = 10, .external_lex_state = 2},
  [7649] = {.lex_state = 38, .external_lex_state = 3},
  [7650] = {.lex_state = 38, .external_lex_state = 3},
  [7651] = {.lex_state = 38, .external_lex_state = 3},
  [7652] = {.lex_state = 38, .external_lex_state = 3},
  [7653] = {.lex_state = 14, .external_lex_state = 2},
  [7654] = {.lex_state = 40, .external_lex_state = 3},
  [7655] = {.lex_state = 14, .external_lex_state = 2},
  [7656] = {.lex_state = 40, .external_lex_state = 3},
  [7657] = {.lex_state = 65, .external_lex_state = 3},
  [7658] = {.lex_state = 10, .external_lex_state = 2},
  [7659] = {.lex_state = 10, .external_lex_state = 2},
  [7660] = {.lex_state = 10, .external_lex_state = 2},
  [7661] = {.lex_state = 10, .external_lex_state = 2},
  [7662] = {.lex_state = 10, .external_lex_state = 2},
  [7663] = {.lex_state = 10, .external_lex_state = 2},
  [7664] = {.lex_state = 10, .external_lex_state = 2},
  [7665] = {.lex_state = 14, .external_lex_state = 2},
  [7666] = {.lex_state = 63, .external_lex_state = 3},
  [7667] = {.lex_state = 40, .external_lex_state = 3},
  [7668] = {.lex_state = 14, .external_lex_state = 2},
  [7669] = {.lex_state = 10, .external_lex_state = 2},
  [7670] = {.lex_state = 14, .external_lex_state = 2},
  [7671] = {.lex_state = 10, .external_lex_state = 2},
  [7672] = {.lex_state = 40, .external_lex_state = 3},
  [7673] = {.lex_state = 40, .external_lex_state = 3},
  [7674] = {.lex_state = 40, .external_lex_state = 3},
  [7675] = {.lex_state = 14, .external_lex_state = 2},
  [7676] = {.lex_state = 40, .external_lex_state = 3},
  [7677] = {.lex_state = 14, .external_lex_state = 2},
  [7678] = {.lex_state = 10, .external_lex_state = 2},
  [7679] = {.lex_state = 14, .external_lex_state = 2},
  [7680] = {.lex_state = 10, .external_lex_state = 2},
  [7681] = {.lex_state = 10, .external_lex_state = 2},
  [7682] = {.lex_state = 10, .external_lex_state = 2},
  [7683] = {.lex_state = 63, .external_lex_state = 3},
  [7684] = {.lex_state = 40, .external_lex_state = 3},
  [7685] = {.lex_state = 40, .external_lex_state = 3},
  [7686] = {.lex_state = 14, .external_lex_state = 2},
  [7687] = {.lex_state = 10, .external_lex_state = 2},
  [7688] = {.lex_state = 10, .external_lex_state = 2},
  [7689] = {.lex_state = 10, .external_lex_state = 2},
  [7690] = {.lex_state = 10, .external_lex_state = 2},
  [7691] = {.lex_state = 10, .external_lex_state = 2},
  [7692] = {.lex_state = 10, .external_lex_state = 2},
  [7693] = {.lex_state = 14, .external_lex_state = 2},
  [7694] = {.lex_state = 10, .external_lex_state = 2},
  [7695] = {.lex_state = 10, .external_lex_state = 2},
  [7696] = {.lex_state = 14, .external_lex_state = 2},
  [7697] = {.lex_state = 10, .external_lex_state = 2},
  [7698] = {.lex_state = 14, .external_lex_state = 2},
  [7699] = {.lex_state = 14, .external_lex_state = 2},
  [7700] = {.lex_state = 14, .external_lex_state = 2},
  [7701] = {.lex_state = 14, .external_lex_state = 2},
  [7702] = {.lex_state = 40, .external_lex_state = 3},
  [7703] = {.lex_state = 438, .external_lex_state = 3},
  [7704] = {.lex_state = 14, .external_lex_state = 2},
  [7705] = {.lex_state = 14, .external_lex_state = 2},
  [7706] = {.lex_state = 14, .external_lex_state = 2},
  [7707] = {.lex_state = 14, .external_lex_state = 2},
  [7708] = {.lex_state = 14, .external_lex_state = 2},
  [7709] = {.lex_state = 10, .external_lex_state = 2},
  [7710] = {.lex_state = 10, .external_lex_state = 2},
  [7711] = {.lex_state = 10, .external_lex_state = 2},
  [7712] = {.lex_state = 14, .external_lex_state = 2},
  [7713] = {.lex_state = 14, .external_lex_state = 2},
  [7714] = {.lex_state = 10, .external_lex_state = 2},
  [7715] = {.lex_state = 14, .external_lex_state = 2},
  [7716] = {.lex_state = 14, .external_lex_state = 2},
  [7717] = {.lex_state = 40, .external_lex_state = 3},
  [7718] = {.lex_state = 38, .external_lex_state = 3},
  [7719] = {.lex_state = 66, .external_lex_state = 3},
  [7720] = {.lex_state = 438, .external_lex_state = 3},
  [7721] = {.lex_state = 7, .external_lex_state = 2},
  [7722] = {.lex_state = 438, .external_lex_state = 3},
  [7723] = {.lex_state = 7, .external_lex_state = 2},
  [7724] = {.lex_state = 438, .external_lex_state = 3},
  [7725] = {.lex_state = 10, .external_lex_state = 2},
  [7726] = {.lex_state = 13, .external_lex_state = 2},
  [7727] = {.lex_state = 7, .external_lex_state = 2},
  [7728] = {.lex_state = 13, .external_lex_state = 2},
  [7729] = {.lex_state = 13, .external_lex_state = 2},
  [7730] = {.lex_state = 17, .external_lex_state = 2},
  [7731] = {.lex_state = 13, .external_lex_state = 2},
  [7732] = {.lex_state = 10, .external_lex_state = 2},
  [7733] = {.lex_state = 69, .external_lex_state = 3},
  [7734] = {.lex_state = 180, .external_lex_state = 3},
  [7735] = {.lex_state = 7, .external_lex_state = 2},
  [7736] = {.lex_state = 180, .external_lex_state = 3},
  [7737] = {.lex_state = 180, .external_lex_state = 3},
  [7738] = {.lex_state = 181, .external_lex_state = 3},
  [7739] = {.lex_state = 68, .external_lex_state = 3},
  [7740] = {.lex_state = 181, .external_lex_state = 3},
  [7741] = {.lex_state = 67, .external_lex_state = 3},
  [7742] = {.lex_state = 180, .external_lex_state = 3},
  [7743] = {.lex_state = 180, .external_lex_state = 3},
  [7744] = {.lex_state = 64, .external_lex_state = 3},
  [7745] = {.lex_state = 62, .external_lex_state = 3},
  [7746] = {.lex_state = 7, .external_lex_state = 2},
  [7747] = {.lex_state = 181, .external_lex_state = 3},
  [7748] = {.lex_state = 13, .external_lex_state = 2},
  [7749] = {.lex_state = 10, .external_lex_state = 2},
  [7750] = {.lex_state = 180, .external_lex_state = 3},
  [7751] = {.lex_state = 181, .external_lex_state = 3},
  [7752] = {.lex_state = 180, .external_lex_state = 3},
  [7753] = {.lex_state = 180, .external_lex_state = 3},
  [7754] = {.lex_state = 181, .external_lex_state = 3},
  [7755] = {.lex_state = 180, .external_lex_state = 3},
  [7756] = {.lex_state = 180, .external_lex_state = 3},
  [7757] = {.lex_state = 180, .external_lex_state = 3},
  [7758] = {.lex_state = 180, .external_lex_state = 3},
  [7759] = {.lex_state = 7, .external_lex_state = 2},
  [7760] = {.lex_state = 10, .external_lex_state = 2},
  [7761] = {.lex_state = 180, .external_lex_state = 3},
  [7762] = {.lex_state = 67, .external_lex_state = 3},
  [7763] = {.lex_state = 180, .external_lex_state = 3},
  [7764] = {.lex_state = 180, .external_lex_state = 3},
  [7765] = {.lex_state = 180, .external_lex_state = 3},
  [7766] = {.lex_state = 181, .external_lex_state = 3},
  [7767] = {.lex_state = 13, .external_lex_state = 2},
  [7768] = {.lex_state = 438, .external_lex_state = 3},
  [7769] = {.lex_state = 180, .external_lex_state = 3},
  [7770] = {.lex_state = 180, .external_lex_state = 3},
  [7771] = {.lex_state = 7, .external_lex_state = 2},
  [7772] = {.lex_state = 180, .external_lex_state = 3},
  [7773] = {.lex_state = 180, .external_lex_state = 3},
  [7774] = {.lex_state = 442, .external_lex_state = 3},
  [7775] = {.lex_state = 180, .external_lex_state = 3},
  [7776] = {.lex_state = 13, .external_lex_state = 2},
  [7777] = {.lex_state = 13, .external_lex_state = 2},
  [7778] = {.lex_state = 13, .external_lex_state = 2},
  [7779] = {.lex_state = 7, .external_lex_state = 2},
  [7780] = {.lex_state = 180, .external_lex_state = 3},
  [7781] = {.lex_state = 180, .external_lex_state = 3},
  [7782] = {.lex_state = 180, .external_lex_state = 3},
  [7783] = {.lex_state = 13, .external_lex_state = 2},
  [7784] = {.lex_state = 7, .external_lex_state = 2},
  [7785] = {.lex_state = 13, .external_lex_state = 2},
  [7786] = {.lex_state = 180, .external_lex_state = 3},
  [7787] = {.lex_state = 10, .external_lex_state = 2},
  [7788] = {.lex_state = 181, .external_lex_state = 3},
  [7789] = {.lex_state = 181, .external_lex_state = 3},
  [7790] = {.lex_state = 180, .external_lex_state = 3},
  [7791] = {.lex_state = 180, .external_lex_state = 3},
  [7792] = {.lex_state = 180, .external_lex_state = 3},
  [7793] = {.lex_state = 180, .external_lex_state = 3},
  [7794] = {.lex_state = 13, .external_lex_state = 2},
  [7795] = {.lex_state = 180, .external_lex_state = 3},
  [7796] = {.lex_state = 180, .external_lex_state = 3},
  [7797] = {.lex_state = 180, .external_lex_state = 3},
  [7798] = {.lex_state = 181, .external_lex_state = 3},
  [7799] = {.lex_state = 10, .external_lex_state = 2},
  [7800] = {.lex_state = 180, .external_lex_state = 3},
  [7801] = {.lex_state = 180, .external_lex_state = 3},
  [7802] = {.lex_state = 10, .external_lex_state = 2},
  [7803] = {.lex_state = 7, .external_lex_state = 2},
  [7804] = {.lex_state = 7, .external_lex_state = 2},
  [7805] = {.lex_state = 13, .external_lex_state = 2},
  [7806] = {.lex_state = 181, .external_lex_state = 3},
  [7807] = {.lex_state = 13, .external_lex_state = 2},
  [7808] = {.lex_state = 13, .external_lex_state = 2},
  [7809] = {.lex_state = 10, .external_lex_state = 2},
  [7810] = {.lex_state = 181, .external_lex_state = 3},
  [7811] = {.lex_state = 181, .external_lex_state = 3},
  [7812] = {.lex_state = 181, .external_lex_state = 3},
  [7813] = {.lex_state = 181, .external_lex_state = 3},
  [7814] = {.lex_state = 13, .external_lex_state = 2},
  [7815] = {.lex_state = 438, .external_lex_state = 3},
  [7816] = {.lex_state = 7, .external_lex_state = 2},
  [7817] = {.lex_state = 10, .external_lex_state = 2},
  [7818] = {.lex_state = 10, .external_lex_state = 2},
  [7819] = {.lex_state = 180, .external_lex_state = 3},
  [7820] = {.lex_state = 180, .external_lex_state = 3},
  [7821] = {.lex_state = 180, .external_lex_state = 3},
  [7822] = {.lex_state = 180, .external_lex_state = 3},
  [7823] = {.lex_state = 10, .external_lex_state = 2},
  [7824] = {.lex_state = 13, .external_lex_state = 2},
  [7825] = {.lex_state = 10, .external_lex_state = 2},
  [7826] = {.lex_state = 10, .external_lex_state = 2},
  [7827] = {.lex_state = 10, .external_lex_state = 2},
  [7828] = {.lex_state = 7, .external_lex_state = 2},
  [7829] = {.lex_state = 13, .external_lex_state = 2},
  [7830] = {.lex_state = 7, .external_lex_state = 2},
  [7831] = {.lex_state = 13, .external_lex_state = 2},
  [7832] = {.lex_state = 7, .external_lex_state = 2},
  [7833] = {.lex_state = 7, .external_lex_state = 2},
  [7834] = {.lex_state = 180, .external_lex_state = 3},
  [7835] = {.lex_state = 13, .external_lex_state = 2},
  [7836] = {.lex_state = 7, .external_lex_state = 2},
  [7837] = {.lex_state = 13, .external_lex_state = 2},
  [7838] = {.lex_state = 13, .external_lex_state = 2},
  [7839] = {.lex_state = 180, .external_lex_state = 3},
  [7840] = {.lex_state = 181, .external_lex_state = 3},
  [7841] = {.lex_state = 13, .external_lex_state = 2},
  [7842] = {.lex_state = 7, .external_lex_state = 2},
  [7843] = {.lex_state = 13, .external_lex_state = 2},
  [7844] = {.lex_state = 13, .external_lex_state = 2},
  [7845] = {.lex_state = 13, .external_lex_state = 2},
  [7846] = {.lex_state = 181, .external_lex_state = 3},
  [7847] = {.lex_state = 68, .external_lex_state = 3},
  [7848] = {.lex_state = 13, .external_lex_state = 2},
  [7849] = {.lex_state = 180, .external_lex_state = 3},
  [7850] = {.lex_state = 13, .external_lex_state = 2},
  [7851] = {.lex_state = 181, .external_lex_state = 3},
  [7852] = {.lex_state = 7, .external_lex_state = 2},
  [7853] = {.lex_state = 180, .external_lex_state = 3},
  [7854] = {.lex_state = 180, .external_lex_state = 3},
  [7855] = {.lex_state = 71, .external_lex_state = 3},
  [7856] = {.lex_state = 7, .external_lex_state = 2},
  [7857] = {.lex_state = 7, .external_lex_state = 2},
  [7858] = {.lex_state = 13, .external_lex_state = 2},
  [7859] = {.lex_state = 13, .external_lex_state = 2},
  [7860] = {.lex_state = 13, .external_lex_state = 2},
  [7861] = {.lex_state = 180, .external_lex_state = 3},
  [7862] = {.lex_state = 181, .external_lex_state = 3},
  [7863] = {.lex_state = 181, .external_lex_state = 3},
  [7864] = {.lex_state = 180, .external_lex_state = 3},
  [7865] = {.lex_state = 61, .external_lex_state = 3},
  [7866] = {.lex_state = 10, .external_lex_state = 2},
  [7867] = {.lex_state = 7, .external_lex_state = 2},
  [7868] = {.lex_state = 181, .external_lex_state = 3},
  [7869] = {.lex_state = 7, .external_lex_state = 2},
  [7870] = {.lex_state = 181, .external_lex_state = 3},
  [7871] = {.lex_state = 13, .external_lex_state = 2},
  [7872] = {.lex_state = 13, .external_lex_state = 2},
  [7873] = {.lex_state = 10, .external_lex_state = 2},
  [7874] = {.lex_state = 180, .external_lex_state = 3},
  [7875] = {.lex_state = 13, .external_lex_state = 2},
  [7876] = {.lex_state = 181, .external_lex_state = 3},
  [7877] = {.lex_state = 180, .external_lex_state = 3},
  [7878] = {.lex_state = 438, .external_lex_state = 3},
  [7879] = {.lex_state = 13, .external_lex_state = 2},
  [7880] = {.lex_state = 438, .external_lex_state = 3},
  [7881] = {.lex_state = 181, .external_lex_state = 3},
  [7882] = {.lex_state = 13, .external_lex_state = 2},
  [7883] = {.lex_state = 64, .external_lex_state = 3},
  [7884] = {.lex_state = 443, .external_lex_state = 2},
  [7885] = {.lex_state = 181, .external_lex_state = 3},
  [7886] = {.lex_state = 181, .external_lex_state = 3},
  [7887] = {.lex_state = 13, .external_lex_state = 2},
  [7888] = {.lex_state = 65, .external_lex_state = 3},
  [7889] = {.lex_state = 181, .external_lex_state = 3},
  [7890] = {.lex_state = 443, .external_lex_state = 2},
  [7891] = {.lex_state = 181, .external_lex_state = 3},
  [7892] = {.lex_state = 10, .external_lex_state = 2},
  [7893] = {.lex_state = 72, .external_lex_state = 3},
  [7894] = {.lex_state = 181, .external_lex_state = 3},
  [7895] = {.lex_state = 181, .external_lex_state = 3},
  [7896] = {.lex_state = 10, .external_lex_state = 2},
  [7897] = {.lex_state = 181, .external_lex_state = 3},
  [7898] = {.lex_state = 181, .external_lex_state = 3},
  [7899] = {.lex_state = 181, .external_lex_state = 3},
  [7900] = {.lex_state = 181, .external_lex_state = 3},
  [7901] = {.lex_state = 181, .external_lex_state = 3},
  [7902] = {.lex_state = 13, .external_lex_state = 2},
  [7903] = {.lex_state = 180, .external_lex_state = 3},
  [7904] = {.lex_state = 13, .external_lex_state = 2},
  [7905] = {.lex_state = 13, .external_lex_state = 2},
  [7906] = {.lex_state = 65, .external_lex_state = 3},
  [7907] = {.lex_state = 13, .external_lex_state = 2},
  [7908] = {.lex_state = 181, .external_lex_state = 3},
  [7909] = {.lex_state = 181, .external_lex_state = 3},
  [7910] = {.lex_state = 26, .external_lex_state = 3},
  [7911] = {.lex_state = 13, .external_lex_state = 2},
  [7912] = {.lex_state = 13, .external_lex_state = 2},
  [7913] = {.lex_state = 13, .external_lex_state = 2},
  [7914] = {.lex_state = 180, .external_lex_state = 3},
  [7915] = {.lex_state = 13, .external_lex_state = 2},
  [7916] = {.lex_state = 13, .external_lex_state = 2},
  [7917] = {.lex_state = 181, .external_lex_state = 3},
  [7918] = {.lex_state = 181, .external_lex_state = 3},
  [7919] = {.lex_state = 13, .external_lex_state = 2},
  [7920] = {.lex_state = 181, .external_lex_state = 3},
  [7921] = {.lex_state = 13, .external_lex_state = 2},
  [7922] = {.lex_state = 13, .external_lex_state = 2},
  [7923] = {.lex_state = 7, .external_lex_state = 2},
  [7924] = {.lex_state = 181, .external_lex_state = 3},
  [7925] = {.lex_state = 13, .external_lex_state = 2},
  [7926] = {.lex_state = 13, .external_lex_state = 2},
  [7927] = {.lex_state = 181, .external_lex_state = 3},
  [7928] = {.lex_state = 440, .external_lex_state = 3},
  [7929] = {.lex_state = 13, .external_lex_state = 2},
  [7930] = {.lex_state = 181, .external_lex_state = 3},
  [7931] = {.lex_state = 13, .external_lex_state = 2},
  [7932] = {.lex_state = 7, .external_lex_state = 2},
  [7933] = {.lex_state = 13, .external_lex_state = 2},
  [7934] = {.lex_state = 13, .external_lex_state = 2},
  [7935] = {.lex_state = 13, .external_lex_state = 2},
  [7936] = {.lex_state = 13, .external_lex_state = 2},
  [7937] = {.lex_state = 13, .external_lex_state = 2},
  [7938] = {.lex_state = 13, .external_lex_state = 2},
  [7939] = {.lex_state = 13, .external_lex_state = 2},
  [7940] = {.lex_state = 61, .external_lex_state = 3},
  [7941] = {.lex_state = 13, .external_lex_state = 2},
  [7942] = {.lex_state = 13, .external_lex_state = 2},
  [7943] = {.lex_state = 181, .external_lex_state = 3},
  [7944] = {.lex_state = 181, .external_lex_state = 3},
  [7945] = {.lex_state = 13, .external_lex_state = 2},
  [7946] = {.lex_state = 13, .external_lex_state = 2},
  [7947] = {.lex_state = 180, .external_lex_state = 3},
  [7948] = {.lex_state = 70, .external_lex_state = 3},
  [7949] = {.lex_state = 13, .external_lex_state = 2},
  [7950] = {.lex_state = 13, .external_lex_state = 2},
  [7951] = {.lex_state = 443, .external_lex_state = 2},
  [7952] = {.lex_state = 10, .external_lex_state = 2},
  [7953] = {.lex_state = 13, .external_lex_state = 2},
  [7954] = {.lex_state = 13, .external_lex_state = 2},
  [7955] = {.lex_state = 181, .external_lex_state = 3},
  [7956] = {.lex_state = 180, .external_lex_state = 3},
  [7957] = {.lex_state = 180, .external_lex_state = 3},
  [7958] = {.lex_state = 13, .external_lex_state = 2},
  [7959] = {.lex_state = 181, .external_lex_state = 3},
  [7960] = {.lex_state = 13, .external_lex_state = 2},
  [7961] = {.lex_state = 13, .external_lex_state = 2},
  [7962] = {.lex_state = 13, .external_lex_state = 2},
  [7963] = {.lex_state = 13, .external_lex_state = 2},
  [7964] = {.lex_state = 13, .external_lex_state = 2},
  [7965] = {.lex_state = 181, .external_lex_state = 3},
  [7966] = {.lex_state = 443, .external_lex_state = 2},
  [7967] = {.lex_state = 17, .external_lex_state = 2},
  [7968] = {.lex_state = 13, .external_lex_state = 2},
  [7969] = {.lex_state = 13, .external_lex_state = 2},
  [7970] = {.lex_state = 180, .external_lex_state = 3},
  [7971] = {.lex_state = 181, .external_lex_state = 3},
  [7972] = {.lex_state = 181, .external_lex_state = 3},
  [7973] = {.lex_state = 180, .external_lex_state = 3},
  [7974] = {.lex_state = 181, .external_lex_state = 3},
  [7975] = {.lex_state = 13, .external_lex_state = 2},
  [7976] = {.lex_state = 69, .external_lex_state = 3},
  [7977] = {.lex_state = 10, .external_lex_state = 2},
  [7978] = {.lex_state = 181, .external_lex_state = 3},
  [7979] = {.lex_state = 180, .external_lex_state = 3},
  [7980] = {.lex_state = 181, .external_lex_state = 3},
  [7981] = {.lex_state = 13, .external_lex_state = 2},
  [7982] = {.lex_state = 13, .external_lex_state = 2},
  [7983] = {.lex_state = 13, .external_lex_state = 2},
  [7984] = {.lex_state = 13, .external_lex_state = 2},
  [7985] = {.lex_state = 10, .external_lex_state = 2},
  [7986] = {.lex_state = 10, .external_lex_state = 2},
  [7987] = {.lex_state = 181, .external_lex_state = 3},
  [7988] = {.lex_state = 181, .external_lex_state = 3},
  [7989] = {.lex_state = 13, .external_lex_state = 2},
  [7990] = {.lex_state = 7, .external_lex_state = 2},
  [7991] = {.lex_state = 180, .external_lex_state = 3},
  [7992] = {.lex_state = 13, .external_lex_state = 2},
  [7993] = {.lex_state = 13, .external_lex_state = 2},
  [7994] = {.lex_state = 13, .external_lex_state = 2},
  [7995] = {.lex_state = 13, .external_lex_state = 2},
  [7996] = {.lex_state = 10, .external_lex_state = 2},
  [7997] = {.lex_state = 180, .external_lex_state = 3},
  [7998] = {.lex_state = 13, .external_lex_state = 2},
  [7999] = {.lex_state = 13, .external_lex_state = 2},
  [8000] = {.lex_state = 181, .external_lex_state = 3},
  [8001] = {.lex_state = 10, .external_lex_state = 2},
  [8002] = {.lex_state = 181, .external_lex_state = 3},
  [8003] = {.lex_state = 181, .external_lex_state = 3},
  [8004] = {.lex_state = 13, .external_lex_state = 2},
  [8005] = {.lex_state = 180, .external_lex_state = 3},
  [8006] = {.lex_state = 10, .external_lex_state = 2},
  [8007] = {.lex_state = 180, .external_lex_state = 3},
  [8008] = {.lex_state = 181, .external_lex_state = 3},
  [8009] = {.lex_state = 13, .external_lex_state = 2},
  [8010] = {.lex_state = 440, .external_lex_state = 3},
  [8011] = {.lex_state = 181, .external_lex_state = 3},
  [8012] = {.lex_state = 181, .external_lex_state = 3},
  [8013] = {.lex_state = 180, .external_lex_state = 3},
  [8014] = {.lex_state = 180, .external_lex_state = 3},
  [8015] = {.lex_state = 10, .external_lex_state = 2},
  [8016] = {.lex_state = 17, .external_lex_state = 2},
  [8017] = {.lex_state = 181, .external_lex_state = 3},
  [8018] = {.lex_state = 70, .external_lex_state = 3},
  [8019] = {.lex_state = 440, .external_lex_state = 3},
  [8020] = {.lex_state = 440, .external_lex_state = 3},
  [8021] = {.lex_state = 26, .external_lex_state = 3},
  [8022] = {.lex_state = 7, .external_lex_state = 2},
  [8023] = {.lex_state = 7, .external_lex_state = 2},
  [8024] = {.lex_state = 7, .external_lex_state = 2},
  [8025] = {.lex_state = 440, .external_lex_state = 3},
  [8026] = {.lex_state = 440, .external_lex_state = 3},
  [8027] = {.lex_state = 227, .external_lex_state = 2},
  [8028] = {.lex_state = 440, .external_lex_state = 3},
  [8029] = {.lex_state = 440, .external_lex_state = 3},
  [8030] = {.lex_state = 440, .external_lex_state = 3},
  [8031] = {.lex_state = 7, .external_lex_state = 2},
  [8032] = {.lex_state = 7, .external_lex_state = 2},
  [8033] = {.lex_state = 7, .external_lex_state = 2},
  [8034] = {.lex_state = 227, .external_lex_state = 2},
  [8035] = {.lex_state = 440, .external_lex_state = 3},
  [8036] = {.lex_state = 7, .external_lex_state = 2},
  [8037] = {.lex_state = 440, .external_lex_state = 3},
  [8038] = {.lex_state = 440, .external_lex_state = 3},
  [8039] = {.lex_state = 7, .external_lex_state = 2},
  [8040] = {.lex_state = 440, .external_lex_state = 3},
  [8041] = {.lex_state = 26, .external_lex_state = 3},
  [8042] = {.lex_state = 62, .external_lex_state = 3},
  [8043] = {.lex_state = 7, .external_lex_state = 2},
  [8044] = {.lex_state = 7, .external_lex_state = 2},
  [8045] = {.lex_state = 71, .external_lex_state = 3},
  [8046] = {.lex_state = 7, .external_lex_state = 2},
  [8047] = {.lex_state = 440, .external_lex_state = 3},
  [8048] = {.lex_state = 7, .external_lex_state = 2},
  [8049] = {.lex_state = 7, .external_lex_state = 2},
  [8050] = {.lex_state = 7, .external_lex_state = 2},
  [8051] = {.lex_state = 440, .external_lex_state = 3},
  [8052] = {.lex_state = 440, .external_lex_state = 3},
  [8053] = {.lex_state = 7, .external_lex_state = 2},
  [8054] = {.lex_state = 440, .external_lex_state = 3},
  [8055] = {.lex_state = 7, .external_lex_state = 2},
  [8056] = {.lex_state = 7, .external_lex_state = 2},
  [8057] = {.lex_state = 7, .external_lex_state = 2},
  [8058] = {.lex_state = 7, .external_lex_state = 2},
  [8059] = {.lex_state = 440, .external_lex_state = 3},
  [8060] = {.lex_state = 7, .external_lex_state = 2},
  [8061] = {.lex_state = 7, .external_lex_state = 2},
  [8062] = {.lex_state = 7, .external_lex_state = 2},
  [8063] = {.lex_state = 7, .external_lex_state = 2},
  [8064] = {.lex_state = 66, .external_lex_state = 3},
  [8065] = {.lex_state = 70, .external_lex_state = 3},
  [8066] = {.lex_state = 440, .external_lex_state = 3},
  [8067] = {.lex_state = 440, .external_lex_state = 3},
  [8068] = {.lex_state = 7, .external_lex_state = 2},
  [8069] = {.lex_state = 7, .external_lex_state = 2},
  [8070] = {.lex_state = 440, .external_lex_state = 3},
  [8071] = {.lex_state = 7, .external_lex_state = 2},
  [8072] = {.lex_state = 440, .external_lex_state = 3},
  [8073] = {.lex_state = 7, .external_lex_state = 2},
  [8074] = {.lex_state = 440, .external_lex_state = 3},
  [8075] = {.lex_state = 7, .external_lex_state = 2},
  [8076] = {.lex_state = 7, .external_lex_state = 2},
  [8077] = {.lex_state = 440, .external_lex_state = 3},
  [8078] = {.lex_state = 7, .external_lex_state = 2},
  [8079] = {.lex_state = 440, .external_lex_state = 3},
  [8080] = {.lex_state = 440, .external_lex_state = 3},
  [8081] = {.lex_state = 440, .external_lex_state = 3},
  [8082] = {.lex_state = 440, .external_lex_state = 3},
  [8083] = {.lex_state = 7, .external_lex_state = 2},
  [8084] = {.lex_state = 440, .external_lex_state = 3},
  [8085] = {.lex_state = 440, .external_lex_state = 3},
  [8086] = {.lex_state = 440, .external_lex_state = 3},
  [8087] = {.lex_state = 440, .external_lex_state = 3},
  [8088] = {.lex_state = 7, .external_lex_state = 2},
  [8089] = {.lex_state = 7, .external_lex_state = 2},
  [8090] = {.lex_state = 7, .external_lex_state = 2},
  [8091] = {.lex_state = 7, .external_lex_state = 2},
  [8092] = {.lex_state = 7, .external_lex_state = 2},
  [8093] = {.lex_state = 7, .external_lex_state = 2},
  [8094] = {.lex_state = 7, .external_lex_state = 2},
  [8095] = {.lex_state = 227, .external_lex_state = 2},
  [8096] = {.lex_state = 440, .external_lex_state = 3},
  [8097] = {.lex_state = 440, .external_lex_state = 3},
  [8098] = {.lex_state = 440, .external_lex_state = 3},
  [8099] = {.lex_state = 26, .external_lex_state = 3},
  [8100] = {.lex_state = 7, .external_lex_state = 2},
  [8101] = {.lex_state = 227, .external_lex_state = 2},
  [8102] = {.lex_state = 7, .external_lex_state = 2},
  [8103] = {.lex_state = 440, .external_lex_state = 3},
  [8104] = {.lex_state = 440, .external_lex_state = 3},
  [8105] = {.lex_state = 440, .external_lex_state = 3},
  [8106] = {.lex_state = 440, .external_lex_state = 3},
  [8107] = {.lex_state = 7, .external_lex_state = 2},
  [8108] = {.lex_state = 440, .external_lex_state = 3},
  [8109] = {.lex_state = 71, .external_lex_state = 3},
  [8110] = {.lex_state = 26, .external_lex_state = 3},
  [8111] = {.lex_state = 26, .external_lex_state = 3},
  [8112] = {.lex_state = 440, .external_lex_state = 3},
  [8113] = {.lex_state = 440, .external_lex_state = 3},
  [8114] = {.lex_state = 7, .external_lex_state = 2},
  [8115] = {.lex_state = 7, .external_lex_state = 2},
  [8116] = {.lex_state = 440, .external_lex_state = 3},
  [8117] = {.lex_state = 7, .external_lex_state = 2},
  [8118] = {.lex_state = 7, .external_lex_state = 2},
  [8119] = {.lex_state = 7, .external_lex_state = 2},
  [8120] = {.lex_state = 440, .external_lex_state = 3},
  [8121] = {.lex_state = 66, .external_lex_state = 3},
  [8122] = {.lex_state = 213, .external_lex_state = 3},
  [8123] = {.lex_state = 440, .external_lex_state = 3},
  [8124] = {.lex_state = 182, .external_lex_state = 3},
  [8125] = {.lex_state = 7, .external_lex_state = 2},
  [8126] = {.lex_state = 7, .external_lex_state = 2},
  [8127] = {.lex_state = 7, .external_lex_state = 2},
  [8128] = {.lex_state = 440, .external_lex_state = 3},
  [8129] = {.lex_state = 53, .external_lex_state = 3},
  [8130] = {.lex_state = 7, .external_lex_state = 2},
  [8131] = {.lex_state = 7, .external_lex_state = 2},
  [8132] = {.lex_state = 7, .external_lex_state = 2},
  [8133] = {.lex_state = 227, .external_lex_state = 2},
  [8134] = {.lex_state = 7, .external_lex_state = 2},
  [8135] = {.lex_state = 72, .external_lex_state = 3},
  [8136] = {.lex_state = 440, .external_lex_state = 3},
  [8137] = {.lex_state = 7, .external_lex_state = 2},
  [8138] = {.lex_state = 440, .external_lex_state = 3},
  [8139] = {.lex_state = 440, .external_lex_state = 3},
  [8140] = {.lex_state = 7, .external_lex_state = 2},
  [8141] = {.lex_state = 7, .external_lex_state = 2},
  [8142] = {.lex_state = 7, .external_lex_state = 2},
  [8143] = {.lex_state = 440, .external_lex_state = 3},
  [8144] = {.lex_state = 440, .external_lex_state = 3},
  [8145] = {.lex_state = 26, .external_lex_state = 3},
  [8146] = {.lex_state = 7, .external_lex_state = 2},
  [8147] = {.lex_state = 72, .external_lex_state = 3},
  [8148] = {.lex_state = 440, .external_lex_state = 3},
  [8149] = {.lex_state = 7, .external_lex_state = 2},
  [8150] = {.lex_state = 440, .external_lex_state = 3},
  [8151] = {.lex_state = 26, .external_lex_state = 3},
  [8152] = {.lex_state = 7, .external_lex_state = 2},
  [8153] = {.lex_state = 440, .external_lex_state = 3},
  [8154] = {.lex_state = 440, .external_lex_state = 3},
  [8155] = {.lex_state = 440, .external_lex_state = 3},
  [8156] = {.lex_state = 7, .external_lex_state = 2},
  [8157] = {.lex_state = 440, .external_lex_state = 3},
  [8158] = {.lex_state = 7, .external_lex_state = 2},
  [8159] = {.lex_state = 7, .external_lex_state = 2},
  [8160] = {.lex_state = 62, .external_lex_state = 3},
  [8161] = {.lex_state = 7, .external_lex_state = 2},
  [8162] = {.lex_state = 440, .external_lex_state = 3},
  [8163] = {.lex_state = 440, .external_lex_state = 3},
  [8164] = {.lex_state = 7, .external_lex_state = 2},
  [8165] = {.lex_state = 53, .external_lex_state = 3},
  [8166] = {.lex_state = 182, .external_lex_state = 3},
  [8167] = {.lex_state = 53, .external_lex_state = 3},
  [8168] = {.lex_state = 440, .external_lex_state = 3},
  [8169] = {.lex_state = 440, .external_lex_state = 3},
  [8170] = {.lex_state = 7, .external_lex_state = 2},
  [8171] = {.lex_state = 7, .external_lex_state = 2},
  [8172] = {.lex_state = 440, .external_lex_state = 3},
  [8173] = {.lex_state = 227, .external_lex_state = 2},
  [8174] = {.lex_state = 7, .external_lex_state = 2},
  [8175] = {.lex_state = 440, .external_lex_state = 3},
  [8176] = {.lex_state = 27, .external_lex_state = 3},
  [8177] = {.lex_state = 231, .external_lex_state = 2},
  [8178] = {.lex_state = 14, .external_lex_state = 2},
  [8179] = {.lex_state = 14, .external_lex_state = 2},
  [8180] = {.lex_state = 14, .external_lex_state = 2},
  [8181] = {.lex_state = 17, .external_lex_state = 2},
  [8182] = {.lex_state = 14, .external_lex_state = 2},
  [8183] = {.lex_state = 14, .external_lex_state = 2},
  [8184] = {.lex_state = 7, .external_lex_state = 2},
  [8185] = {.lex_state = 7, .external_lex_state = 2},
  [8186] = {.lex_state = 27, .external_lex_state = 3},
  [8187] = {.lex_state = 7, .external_lex_state = 2},
  [8188] = {.lex_state = 182, .external_lex_state = 3},
  [8189] = {.lex_state = 14, .external_lex_state = 2},
  [8190] = {.lex_state = 182, .external_lex_state = 3},
  [8191] = {.lex_state = 173, .external_lex_state = 3},
  [8192] = {.lex_state = 14, .external_lex_state = 2},
  [8193] = {.lex_state = 14, .external_lex_state = 2},
  [8194] = {.lex_state = 27, .external_lex_state = 3},
  [8195] = {.lex_state = 14, .external_lex_state = 2},
  [8196] = {.lex_state = 182, .external_lex_state = 3},
  [8197] = {.lex_state = 182, .external_lex_state = 3},
  [8198] = {.lex_state = 182, .external_lex_state = 3},
  [8199] = {.lex_state = 182, .external_lex_state = 3},
  [8200] = {.lex_state = 14, .external_lex_state = 2},
  [8201] = {.lex_state = 27, .external_lex_state = 3},
  [8202] = {.lex_state = 27, .external_lex_state = 3},
  [8203] = {.lex_state = 27, .external_lex_state = 3},
  [8204] = {.lex_state = 27, .external_lex_state = 3},
  [8205] = {.lex_state = 27, .external_lex_state = 3},
  [8206] = {.lex_state = 27, .external_lex_state = 3},
  [8207] = {.lex_state = 27, .external_lex_state = 3},
  [8208] = {.lex_state = 27, .external_lex_state = 3},
  [8209] = {.lex_state = 14, .external_lex_state = 2},
  [8210] = {.lex_state = 27, .external_lex_state = 3},
  [8211] = {.lex_state = 27, .external_lex_state = 3},
  [8212] = {.lex_state = 7, .external_lex_state = 2},
  [8213] = {.lex_state = 7, .external_lex_state = 2},
  [8214] = {.lex_state = 7, .external_lex_state = 2},
  [8215] = {.lex_state = 27, .external_lex_state = 3},
  [8216] = {.lex_state = 27, .external_lex_state = 3},
  [8217] = {.lex_state = 182, .external_lex_state = 3},
  [8218] = {.lex_state = 14, .external_lex_state = 2},
  [8219] = {.lex_state = 7, .external_lex_state = 2},
  [8220] = {.lex_state = 7, .external_lex_state = 2},
  [8221] = {.lex_state = 53, .external_lex_state = 3},
  [8222] = {.lex_state = 231, .external_lex_state = 2},
  [8223] = {.lex_state = 7, .external_lex_state = 2},
  [8224] = {.lex_state = 14, .external_lex_state = 2},
  [8225] = {.lex_state = 231, .external_lex_state = 2},
  [8226] = {.lex_state = 19, .external_lex_state = 2},
  [8227] = {.lex_state = 27, .external_lex_state = 3},
  [8228] = {.lex_state = 14, .external_lex_state = 2},
  [8229] = {.lex_state = 7, .external_lex_state = 2},
  [8230] = {.lex_state = 7, .external_lex_state = 2},
  [8231] = {.lex_state = 7, .external_lex_state = 2},
  [8232] = {.lex_state = 27, .external_lex_state = 3},
  [8233] = {.lex_state = 14, .external_lex_state = 2},
  [8234] = {.lex_state = 27, .external_lex_state = 3},
  [8235] = {.lex_state = 7, .external_lex_state = 2},
  [8236] = {.lex_state = 7, .external_lex_state = 2},
  [8237] = {.lex_state = 7, .external_lex_state = 2},
  [8238] = {.lex_state = 27, .external_lex_state = 3},
  [8239] = {.lex_state = 7, .external_lex_state = 2},
  [8240] = {.lex_state = 7, .external_lex_state = 2},
  [8241] = {.lex_state = 7, .external_lex_state = 2},
  [8242] = {.lex_state = 182, .external_lex_state = 3},
  [8243] = {.lex_state = 231, .external_lex_state = 2},
  [8244] = {.lex_state = 182, .external_lex_state = 3},
  [8245] = {.lex_state = 7, .external_lex_state = 2},
  [8246] = {.lex_state = 7, .external_lex_state = 2},
  [8247] = {.lex_state = 7, .external_lex_state = 2},
  [8248] = {.lex_state = 7, .external_lex_state = 2},
  [8249] = {.lex_state = 7, .external_lex_state = 2},
  [8250] = {.lex_state = 27, .external_lex_state = 3},
  [8251] = {.lex_state = 7, .external_lex_state = 2},
  [8252] = {.lex_state = 7, .external_lex_state = 2},
  [8253] = {.lex_state = 7, .external_lex_state = 2},
  [8254] = {.lex_state = 7, .external_lex_state = 2},
  [8255] = {.lex_state = 27, .external_lex_state = 3},
  [8256] = {.lex_state = 231, .external_lex_state = 2},
  [8257] = {.lex_state = 7, .external_lex_state = 2},
  [8258] = {.lex_state = 7, .external_lex_state = 2},
  [8259] = {.lex_state = 182, .external_lex_state = 3},
  [8260] = {.lex_state = 7, .external_lex_state = 2},
  [8261] = {.lex_state = 231, .external_lex_state = 2},
  [8262] = {.lex_state = 27, .external_lex_state = 3},
  [8263] = {.lex_state = 182, .external_lex_state = 3},
  [8264] = {.lex_state = 14, .external_lex_state = 2},
  [8265] = {.lex_state = 27, .external_lex_state = 3},
  [8266] = {.lex_state = 7, .external_lex_state = 2},
  [8267] = {.lex_state = 7, .external_lex_state = 2},
  [8268] = {.lex_state = 7, .external_lex_state = 2},
  [8269] = {.lex_state = 27, .external_lex_state = 3},
  [8270] = {.lex_state = 27, .external_lex_state = 3},
  [8271] = {.lex_state = 14, .external_lex_state = 2},
  [8272] = {.lex_state = 7, .external_lex_state = 2},
  [8273] = {.lex_state = 7, .external_lex_state = 2},
  [8274] = {.lex_state = 182, .external_lex_state = 3},
  [8275] = {.lex_state = 182, .external_lex_state = 3},
  [8276] = {.lex_state = 7, .external_lex_state = 2},
  [8277] = {.lex_state = 27, .external_lex_state = 3},
  [8278] = {.lex_state = 7, .external_lex_state = 2},
  [8279] = {.lex_state = 7, .external_lex_state = 2},
  [8280] = {.lex_state = 182, .external_lex_state = 3},
  [8281] = {.lex_state = 7, .external_lex_state = 2},
  [8282] = {.lex_state = 7, .external_lex_state = 2},
  [8283] = {.lex_state = 7, .external_lex_state = 2},
  [8284] = {.lex_state = 7, .external_lex_state = 2},
  [8285] = {.lex_state = 7, .external_lex_state = 2},
  [8286] = {.lex_state = 182, .external_lex_state = 3},
  [8287] = {.lex_state = 11, .external_lex_state = 2},
  [8288] = {.lex_state = 7, .external_lex_state = 2},
  [8289] = {.lex_state = 7, .external_lex_state = 2},
  [8290] = {.lex_state = 7, .external_lex_state = 2},
  [8291] = {.lex_state = 182, .external_lex_state = 3},
  [8292] = {.lex_state = 7, .external_lex_state = 2},
  [8293] = {.lex_state = 182, .external_lex_state = 3},
  [8294] = {.lex_state = 27, .external_lex_state = 3},
  [8295] = {.lex_state = 231, .external_lex_state = 2},
  [8296] = {.lex_state = 7, .external_lex_state = 2},
  [8297] = {.lex_state = 7, .external_lex_state = 2},
  [8298] = {.lex_state = 7, .external_lex_state = 2},
  [8299] = {.lex_state = 7, .external_lex_state = 2},
  [8300] = {.lex_state = 7, .external_lex_state = 2},
  [8301] = {.lex_state = 11, .external_lex_state = 2},
  [8302] = {.lex_state = 7, .external_lex_state = 2},
  [8303] = {.lex_state = 11, .external_lex_state = 2},
  [8304] = {.lex_state = 7, .external_lex_state = 2},
  [8305] = {.lex_state = 7, .external_lex_state = 2},
  [8306] = {.lex_state = 7, .external_lex_state = 2},
  [8307] = {.lex_state = 11, .external_lex_state = 2},
  [8308] = {.lex_state = 182, .external_lex_state = 3},
  [8309] = {.lex_state = 7, .external_lex_state = 2},
  [8310] = {.lex_state = 7, .external_lex_state = 2},
  [8311] = {.lex_state = 174, .external_lex_state = 3},
  [8312] = {.lex_state = 182, .external_lex_state = 3},
  [8313] = {.lex_state = 14, .external_lex_state = 2},
  [8314] = {.lex_state = 7, .external_lex_state = 2},
  [8315] = {.lex_state = 7, .external_lex_state = 2},
  [8316] = {.lex_state = 7, .external_lex_state = 2},
  [8317] = {.lex_state = 182, .external_lex_state = 3},
  [8318] = {.lex_state = 182, .external_lex_state = 3},
  [8319] = {.lex_state = 182, .external_lex_state = 3},
  [8320] = {.lex_state = 7, .external_lex_state = 2},
  [8321] = {.lex_state = 7, .external_lex_state = 2},
  [8322] = {.lex_state = 182, .external_lex_state = 3},
  [8323] = {.lex_state = 7, .external_lex_state = 2},
  [8324] = {.lex_state = 182, .external_lex_state = 3},
  [8325] = {.lex_state = 27, .external_lex_state = 3},
  [8326] = {.lex_state = 182, .external_lex_state = 3},
  [8327] = {.lex_state = 27, .external_lex_state = 3},
  [8328] = {.lex_state = 27, .external_lex_state = 3},
  [8329] = {.lex_state = 27, .external_lex_state = 3},
  [8330] = {.lex_state = 14, .external_lex_state = 2},
  [8331] = {.lex_state = 27, .external_lex_state = 3},
  [8332] = {.lex_state = 27, .external_lex_state = 3},
  [8333] = {.lex_state = 14, .external_lex_state = 2},
  [8334] = {.lex_state = 42, .external_lex_state = 3},
  [8335] = {.lex_state = 182, .external_lex_state = 3},
  [8336] = {.lex_state = 27, .external_lex_state = 3},
  [8337] = {.lex_state = 27, .external_lex_state = 3},
  [8338] = {.lex_state = 182, .external_lex_state = 3},
  [8339] = {.lex_state = 27, .external_lex_state = 3},
  [8340] = {.lex_state = 27, .external_lex_state = 3},
  [8341] = {.lex_state = 27, .external_lex_state = 3},
  [8342] = {.lex_state = 27, .external_lex_state = 3},
  [8343] = {.lex_state = 27, .external_lex_state = 3},
  [8344] = {.lex_state = 27, .external_lex_state = 3},
  [8345] = {.lex_state = 27, .external_lex_state = 3},
  [8346] = {.lex_state = 27, .external_lex_state = 3},
  [8347] = {.lex_state = 182, .external_lex_state = 3},
  [8348] = {.lex_state = 182, .external_lex_state = 3},
  [8349] = {.lex_state = 182, .external_lex_state = 3},
  [8350] = {.lex_state = 27, .external_lex_state = 3},
  [8351] = {.lex_state = 182, .external_lex_state = 3},
  [8352] = {.lex_state = 27, .external_lex_state = 3},
  [8353] = {.lex_state = 182, .external_lex_state = 3},
  [8354] = {.lex_state = 182, .external_lex_state = 3},
  [8355] = {.lex_state = 27, .external_lex_state = 3},
  [8356] = {.lex_state = 27, .external_lex_state = 3},
  [8357] = {.lex_state = 182, .external_lex_state = 3},
  [8358] = {.lex_state = 182, .external_lex_state = 3},
  [8359] = {.lex_state = 182, .external_lex_state = 3},
  [8360] = {.lex_state = 27, .external_lex_state = 3},
  [8361] = {.lex_state = 182, .external_lex_state = 3},
  [8362] = {.lex_state = 27, .external_lex_state = 3},
  [8363] = {.lex_state = 27, .external_lex_state = 3},
  [8364] = {.lex_state = 27, .external_lex_state = 3},
  [8365] = {.lex_state = 182, .external_lex_state = 3},
  [8366] = {.lex_state = 27, .external_lex_state = 3},
  [8367] = {.lex_state = 27, .external_lex_state = 3},
  [8368] = {.lex_state = 27, .external_lex_state = 3},
  [8369] = {.lex_state = 27, .external_lex_state = 3},
  [8370] = {.lex_state = 7, .external_lex_state = 2},
  [8371] = {.lex_state = 27, .external_lex_state = 3},
  [8372] = {.lex_state = 27, .external_lex_state = 3},
  [8373] = {.lex_state = 27, .external_lex_state = 3},
  [8374] = {.lex_state = 7, .external_lex_state = 2},
  [8375] = {.lex_state = 27, .external_lex_state = 3},
  [8376] = {.lex_state = 27, .external_lex_state = 3},
  [8377] = {.lex_state = 182, .external_lex_state = 3},
  [8378] = {.lex_state = 182, .external_lex_state = 3},
  [8379] = {.lex_state = 182, .external_lex_state = 3},
  [8380] = {.lex_state = 182, .external_lex_state = 3},
  [8381] = {.lex_state = 182, .external_lex_state = 3},
  [8382] = {.lex_state = 182, .external_lex_state = 3},
  [8383] = {.lex_state = 27, .external_lex_state = 3},
  [8384] = {.lex_state = 182, .external_lex_state = 3},
  [8385] = {.lex_state = 182, .external_lex_state = 3},
  [8386] = {.lex_state = 182, .external_lex_state = 3},
  [8387] = {.lex_state = 182, .external_lex_state = 3},
  [8388] = {.lex_state = 182, .external_lex_state = 3},
  [8389] = {.lex_state = 182, .external_lex_state = 3},
  [8390] = {.lex_state = 27, .external_lex_state = 3},
  [8391] = {.lex_state = 27, .external_lex_state = 3},
  [8392] = {.lex_state = 27, .external_lex_state = 3},
  [8393] = {.lex_state = 231, .external_lex_state = 2},
  [8394] = {.lex_state = 27, .external_lex_state = 3},
  [8395] = {.lex_state = 182, .external_lex_state = 3},
  [8396] = {.lex_state = 27, .external_lex_state = 3},
  [8397] = {.lex_state = 182, .external_lex_state = 3},
  [8398] = {.lex_state = 27, .external_lex_state = 3},
  [8399] = {.lex_state = 27, .external_lex_state = 3},
  [8400] = {.lex_state = 27, .external_lex_state = 3},
  [8401] = {.lex_state = 27, .external_lex_state = 3},
  [8402] = {.lex_state = 27, .external_lex_state = 3},
  [8403] = {.lex_state = 27, .external_lex_state = 3},
  [8404] = {.lex_state = 27, .external_lex_state = 3},
  [8405] = {.lex_state = 27, .external_lex_state = 3},
  [8406] = {.lex_state = 27, .external_lex_state = 3},
  [8407] = {.lex_state = 182, .external_lex_state = 3},
  [8408] = {.lex_state = 27, .external_lex_state = 3},
  [8409] = {.lex_state = 231, .external_lex_state = 2},
  [8410] = {.lex_state = 182, .external_lex_state = 3},
  [8411] = {.lex_state = 27, .external_lex_state = 3},
  [8412] = {.lex_state = 182, .external_lex_state = 3},
  [8413] = {.lex_state = 27, .external_lex_state = 3},
  [8414] = {.lex_state = 27, .external_lex_state = 3},
  [8415] = {.lex_state = 27, .external_lex_state = 3},
  [8416] = {.lex_state = 14, .external_lex_state = 2},
  [8417] = {.lex_state = 27, .external_lex_state = 3},
  [8418] = {.lex_state = 182, .external_lex_state = 3},
  [8419] = {.lex_state = 27, .external_lex_state = 3},
  [8420] = {.lex_state = 27, .external_lex_state = 3},
  [8421] = {.lex_state = 182, .external_lex_state = 3},
  [8422] = {.lex_state = 27, .external_lex_state = 3},
  [8423] = {.lex_state = 27, .external_lex_state = 3},
  [8424] = {.lex_state = 27, .external_lex_state = 3},
  [8425] = {.lex_state = 14, .external_lex_state = 2},
  [8426] = {.lex_state = 14, .external_lex_state = 2},
  [8427] = {.lex_state = 231, .external_lex_state = 2},
  [8428] = {.lex_state = 182, .external_lex_state = 3},
  [8429] = {.lex_state = 27, .external_lex_state = 3},
  [8430] = {.lex_state = 14, .external_lex_state = 2},
  [8431] = {.lex_state = 14, .external_lex_state = 2},
  [8432] = {.lex_state = 182, .external_lex_state = 3},
  [8433] = {.lex_state = 14, .external_lex_state = 2},
  [8434] = {.lex_state = 182, .external_lex_state = 3},
  [8435] = {.lex_state = 182, .external_lex_state = 3},
  [8436] = {.lex_state = 7, .external_lex_state = 2},
  [8437] = {.lex_state = 25, .external_lex_state = 3},
  [8438] = {.lex_state = 17, .external_lex_state = 2},
  [8439] = {.lex_state = 17, .external_lex_state = 2},
  [8440] = {.lex_state = 13, .external_lex_state = 2},
  [8441] = {.lex_state = 17, .external_lex_state = 2},
  [8442] = {.lex_state = 17, .external_lex_state = 2},
  [8443] = {.lex_state = 13, .external_lex_state = 2},
  [8444] = {.lex_state = 13, .external_lex_state = 2},
  [8445] = {.lex_state = 17, .external_lex_state = 2},
  [8446] = {.lex_state = 17, .external_lex_state = 2},
  [8447] = {.lex_state = 226, .external_lex_state = 2},
  [8448] = {.lex_state = 13, .external_lex_state = 2},
  [8449] = {.lex_state = 13, .external_lex_state = 2},
  [8450] = {.lex_state = 13, .external_lex_state = 2},
  [8451] = {.lex_state = 13, .external_lex_state = 2},
  [8452] = {.lex_state = 13, .external_lex_state = 2},
  [8453] = {.lex_state = 13, .external_lex_state = 2},
  [8454] = {.lex_state = 17, .external_lex_state = 2},
  [8455] = {.lex_state = 17, .external_lex_state = 2},
  [8456] = {.lex_state = 13, .external_lex_state = 2},
  [8457] = {.lex_state = 17, .external_lex_state = 2},
  [8458] = {.lex_state = 17, .external_lex_state = 2},
  [8459] = {.lex_state = 17, .external_lex_state = 2},
  [8460] = {.lex_state = 226, .external_lex_state = 2},
  [8461] = {.lex_state = 17, .external_lex_state = 2},
  [8462] = {.lex_state = 17, .external_lex_state = 2},
  [8463] = {.lex_state = 13, .external_lex_state = 2},
  [8464] = {.lex_state = 17, .external_lex_state = 2},
  [8465] = {.lex_state = 13, .external_lex_state = 2},
  [8466] = {.lex_state = 17, .external_lex_state = 2},
  [8467] = {.lex_state = 25, .external_lex_state = 3},
  [8468] = {.lex_state = 13, .external_lex_state = 2},
  [8469] = {.lex_state = 13, .external_lex_state = 2},
  [8470] = {.lex_state = 226, .external_lex_state = 2},
  [8471] = {.lex_state = 17, .external_lex_state = 2},
  [8472] = {.lex_state = 13, .external_lex_state = 2},
  [8473] = {.lex_state = 17, .external_lex_state = 2},
  [8474] = {.lex_state = 13, .external_lex_state = 2},
  [8475] = {.lex_state = 17, .external_lex_state = 2},
  [8476] = {.lex_state = 13, .external_lex_state = 2},
  [8477] = {.lex_state = 17, .external_lex_state = 2},
  [8478] = {.lex_state = 13, .external_lex_state = 2},
  [8479] = {.lex_state = 17, .external_lex_state = 2},
  [8480] = {.lex_state = 13, .external_lex_state = 2},
  [8481] = {.lex_state = 17, .external_lex_state = 2},
  [8482] = {.lex_state = 17, .external_lex_state = 2},
  [8483] = {.lex_state = 13, .external_lex_state = 2},
  [8484] = {.lex_state = 13, .external_lex_state = 2},
  [8485] = {.lex_state = 13, .external_lex_state = 2},
  [8486] = {.lex_state = 17, .external_lex_state = 2},
  [8487] = {.lex_state = 17, .external_lex_state = 2},
  [8488] = {.lex_state = 17, .external_lex_state = 2},
  [8489] = {.lex_state = 17, .external_lex_state = 2},
  [8490] = {.lex_state = 17, .external_lex_state = 2},
  [8491] = {.lex_state = 25, .external_lex_state = 3},
  [8492] = {.lex_state = 25, .external_lex_state = 3},
  [8493] = {.lex_state = 17, .external_lex_state = 2},
  [8494] = {.lex_state = 17, .external_lex_state = 2},
  [8495] = {.lex_state = 17, .external_lex_state = 2},
  [8496] = {.lex_state = 17, .external_lex_state = 2},
  [8497] = {.lex_state = 17, .external_lex_state = 2},
  [8498] = {.lex_state = 17, .external_lex_state = 2},
  [8499] = {.lex_state = 17, .external_lex_state = 2},
  [8500] = {.lex_state = 17, .external_lex_state = 2},
  [8501] = {.lex_state = 446, .external_lex_state = 2},
  [8502] = {.lex_state = 13, .external_lex_state = 2},
  [8503] = {.lex_state = 17, .external_lex_state = 2},
  [8504] = {.lex_state = 17, .external_lex_state = 2},
  [8505] = {.lex_state = 17, .external_lex_state = 2},
  [8506] = {.lex_state = 25, .external_lex_state = 3},
  [8507] = {.lex_state = 17, .external_lex_state = 2},
  [8508] = {.lex_state = 17, .external_lex_state = 2},
  [8509] = {.lex_state = 17, .external_lex_state = 2},
  [8510] = {.lex_state = 17, .external_lex_state = 2},
  [8511] = {.lex_state = 17, .external_lex_state = 2},
  [8512] = {.lex_state = 17, .external_lex_state = 2},
  [8513] = {.lex_state = 13, .external_lex_state = 2},
  [8514] = {.lex_state = 17, .external_lex_state = 2},
  [8515] = {.lex_state = 13, .external_lex_state = 2},
  [8516] = {.lex_state = 42, .external_lex_state = 3},
  [8517] = {.lex_state = 17, .external_lex_state = 2},
  [8518] = {.lex_state = 13, .external_lex_state = 2},
  [8519] = {.lex_state = 17, .external_lex_state = 2},
  [8520] = {.lex_state = 42, .external_lex_state = 3},
  [8521] = {.lex_state = 13, .external_lex_state = 2},
  [8522] = {.lex_state = 17, .external_lex_state = 2},
  [8523] = {.lex_state = 17, .external_lex_state = 2},
  [8524] = {.lex_state = 17, .external_lex_state = 2},
  [8525] = {.lex_state = 17, .external_lex_state = 2},
  [8526] = {.lex_state = 17, .external_lex_state = 2},
  [8527] = {.lex_state = 17, .external_lex_state = 2},
  [8528] = {.lex_state = 17, .external_lex_state = 2},
  [8529] = {.lex_state = 17, .external_lex_state = 2},
  [8530] = {.lex_state = 13, .external_lex_state = 2},
  [8531] = {.lex_state = 13, .external_lex_state = 2},
  [8532] = {.lex_state = 17, .external_lex_state = 2},
  [8533] = {.lex_state = 17, .external_lex_state = 2},
  [8534] = {.lex_state = 446, .external_lex_state = 2},
  [8535] = {.lex_state = 13, .external_lex_state = 2},
  [8536] = {.lex_state = 17, .external_lex_state = 2},
  [8537] = {.lex_state = 17, .external_lex_state = 2},
  [8538] = {.lex_state = 446, .external_lex_state = 2},
  [8539] = {.lex_state = 17, .external_lex_state = 2},
  [8540] = {.lex_state = 17, .external_lex_state = 2},
  [8541] = {.lex_state = 17, .external_lex_state = 2},
  [8542] = {.lex_state = 17, .external_lex_state = 2},
  [8543] = {.lex_state = 17, .external_lex_state = 2},
  [8544] = {.lex_state = 17, .external_lex_state = 2},
  [8545] = {.lex_state = 446, .external_lex_state = 2},
  [8546] = {.lex_state = 17, .external_lex_state = 2},
  [8547] = {.lex_state = 17, .external_lex_state = 2},
  [8548] = {.lex_state = 17, .external_lex_state = 2},
  [8549] = {.lex_state = 17, .external_lex_state = 2},
  [8550] = {.lex_state = 446, .external_lex_state = 2},
  [8551] = {.lex_state = 446, .external_lex_state = 2},
  [8552] = {.lex_state = 17, .external_lex_state = 2},
  [8553] = {.lex_state = 17, .external_lex_state = 2},
  [8554] = {.lex_state = 42, .external_lex_state = 3},
  [8555] = {.lex_state = 13, .external_lex_state = 2},
  [8556] = {.lex_state = 17, .external_lex_state = 2},
  [8557] = {.lex_state = 17, .external_lex_state = 2},
  [8558] = {.lex_state = 17, .external_lex_state = 2},
  [8559] = {.lex_state = 17, .external_lex_state = 2},
  [8560] = {.lex_state = 17, .external_lex_state = 2},
  [8561] = {.lex_state = 17, .external_lex_state = 2},
  [8562] = {.lex_state = 17, .external_lex_state = 2},
  [8563] = {.lex_state = 13, .external_lex_state = 2},
  [8564] = {.lex_state = 25, .external_lex_state = 3},
  [8565] = {.lex_state = 17, .external_lex_state = 2},
  [8566] = {.lex_state = 17, .external_lex_state = 2},
  [8567] = {.lex_state = 17, .external_lex_state = 2},
  [8568] = {.lex_state = 226, .external_lex_state = 2},
  [8569] = {.lex_state = 17, .external_lex_state = 2},
  [8570] = {.lex_state = 13, .external_lex_state = 2},
  [8571] = {.lex_state = 17, .external_lex_state = 2},
  [8572] = {.lex_state = 17, .external_lex_state = 2},
  [8573] = {.lex_state = 17, .external_lex_state = 2},
  [8574] = {.lex_state = 17, .external_lex_state = 2},
  [8575] = {.lex_state = 17, .external_lex_state = 2},
  [8576] = {.lex_state = 17, .external_lex_state = 2},
  [8577] = {.lex_state = 17, .external_lex_state = 2},
  [8578] = {.lex_state = 17, .external_lex_state = 2},
  [8579] = {.lex_state = 17, .external_lex_state = 2},
  [8580] = {.lex_state = 17, .external_lex_state = 2},
  [8581] = {.lex_state = 437, .external_lex_state = 2},
  [8582] = {.lex_state = 437, .external_lex_state = 2},
  [8583] = {.lex_state = 437, .external_lex_state = 2},
  [8584] = {.lex_state = 437, .external_lex_state = 2},
  [8585] = {.lex_state = 17, .external_lex_state = 2},
  [8586] = {.lex_state = 17, .external_lex_state = 2},
  [8587] = {.lex_state = 437, .external_lex_state = 2},
  [8588] = {.lex_state = 437, .external_lex_state = 2},
  [8589] = {.lex_state = 437, .external_lex_state = 2},
  [8590] = {.lex_state = 437, .external_lex_state = 2},
  [8591] = {.lex_state = 437, .external_lex_state = 2},
  [8592] = {.lex_state = 437, .external_lex_state = 2},
  [8593] = {.lex_state = 437, .external_lex_state = 2},
  [8594] = {.lex_state = 17, .external_lex_state = 2},
  [8595] = {.lex_state = 437, .external_lex_state = 2},
  [8596] = {.lex_state = 437, .external_lex_state = 2},
  [8597] = {.lex_state = 17, .external_lex_state = 2},
  [8598] = {.lex_state = 17, .external_lex_state = 2},
  [8599] = {.lex_state = 437, .external_lex_state = 2},
  [8600] = {.lex_state = 437, .external_lex_state = 2},
  [8601] = {.lex_state = 437, .external_lex_state = 2},
  [8602] = {.lex_state = 437, .external_lex_state = 2},
  [8603] = {.lex_state = 437, .external_lex_state = 2},
  [8604] = {.lex_state = 437, .external_lex_state = 2},
  [8605] = {.lex_state = 437, .external_lex_state = 2},
  [8606] = {.lex_state = 437, .external_lex_state = 2},
  [8607] = {.lex_state = 437, .external_lex_state = 2},
  [8608] = {.lex_state = 437, .external_lex_state = 2},
  [8609] = {.lex_state = 437, .external_lex_state = 2},
  [8610] = {.lex_state = 17, .external_lex_state = 2},
  [8611] = {.lex_state = 437, .external_lex_state = 2},
  [8612] = {.lex_state = 17, .external_lex_state = 2},
  [8613] = {.lex_state = 17, .external_lex_state = 2},
  [8614] = {.lex_state = 17, .external_lex_state = 2},
  [8615] = {.lex_state = 437, .external_lex_state = 2},
  [8616] = {.lex_state = 437, .external_lex_state = 2},
  [8617] = {.lex_state = 437, .external_lex_state = 2},
  [8618] = {.lex_state = 17, .external_lex_state = 2},
  [8619] = {.lex_state = 17, .external_lex_state = 2},
  [8620] = {.lex_state = 17, .external_lex_state = 2},
  [8621] = {.lex_state = 17, .external_lex_state = 2},
  [8622] = {.lex_state = 17, .external_lex_state = 2},
  [8623] = {.lex_state = 437, .external_lex_state = 2},
  [8624] = {.lex_state = 437, .external_lex_state = 2},
  [8625] = {.lex_state = 17, .external_lex_state = 2},
  [8626] = {.lex_state = 17, .external_lex_state = 2},
  [8627] = {.lex_state = 437, .external_lex_state = 2},
  [8628] = {.lex_state = 437, .external_lex_state = 2},
  [8629] = {.lex_state = 17, .external_lex_state = 2},
  [8630] = {.lex_state = 437, .external_lex_state = 2},
  [8631] = {.lex_state = 437, .external_lex_state = 2},
  [8632] = {.lex_state = 437, .external_lex_state = 2},
  [8633] = {.lex_state = 437, .external_lex_state = 2},
  [8634] = {.lex_state = 437, .external_lex_state = 2},
  [8635] = {.lex_state = 437, .external_lex_state = 2},
  [8636] = {.lex_state = 437, .external_lex_state = 2},
  [8637] = {.lex_state = 437, .external_lex_state = 2},
  [8638] = {.lex_state = 437, .external_lex_state = 2},
  [8639] = {.lex_state = 437, .external_lex_state = 2},
  [8640] = {.lex_state = 437, .external_lex_state = 2},
  [8641] = {.lex_state = 17, .external_lex_state = 2},
  [8642] = {.lex_state = 17, .external_lex_state = 2},
  [8643] = {.lex_state = 437, .external_lex_state = 2},
  [8644] = {.lex_state = 17, .external_lex_state = 2},
  [8645] = {.lex_state = 437, .external_lex_state = 2},
  [8646] = {.lex_state = 17, .external_lex_state = 2},
  [8647] = {.lex_state = 17, .external_lex_state = 2},
  [8648] = {.lex_state = 17, .external_lex_state = 2},
  [8649] = {.lex_state = 17, .external_lex_state = 2},
  [8650] = {.lex_state = 17, .external_lex_state = 2},
  [8651] = {.lex_state = 175, .external_lex_state = 3},
  [8652] = {.lex_state = 437, .external_lex_state = 2},
  [8653] = {.lex_state = 17, .external_lex_state = 2},
  [8654] = {.lex_state = 437, .external_lex_state = 2},
  [8655] = {.lex_state = 17, .external_lex_state = 2},
  [8656] = {.lex_state = 17, .external_lex_state = 2},
  [8657] = {.lex_state = 437, .external_lex_state = 2},
  [8658] = {.lex_state = 437, .external_lex_state = 2},
  [8659] = {.lex_state = 175, .external_lex_state = 3},
  [8660] = {.lex_state = 437, .external_lex_state = 2},
  [8661] = {.lex_state = 17, .external_lex_state = 2},
  [8662] = {.lex_state = 17, .external_lex_state = 2},
  [8663] = {.lex_state = 437, .external_lex_state = 2},
  [8664] = {.lex_state = 27, .external_lex_state = 3},
  [8665] = {.lex_state = 437, .external_lex_state = 2},
  [8666] = {.lex_state = 17, .external_lex_state = 2},
  [8667] = {.lex_state = 17, .external_lex_state = 2},
  [8668] = {.lex_state = 17, .external_lex_state = 2},
  [8669] = {.lex_state = 17, .external_lex_state = 2},
  [8670] = {.lex_state = 7, .external_lex_state = 2},
  [8671] = {.lex_state = 226, .external_lex_state = 2},
  [8672] = {.lex_state = 226, .external_lex_state = 2},
  [8673] = {.lex_state = 226, .external_lex_state = 2},
  [8674] = {.lex_state = 437, .external_lex_state = 2},
  [8675] = {.lex_state = 226, .external_lex_state = 2},
  [8676] = {.lex_state = 226, .external_lex_state = 2},
  [8677] = {.lex_state = 226, .external_lex_state = 2},
  [8678] = {.lex_state = 17, .external_lex_state = 2},
  [8679] = {.lex_state = 226, .external_lex_state = 2},
  [8680] = {.lex_state = 437, .external_lex_state = 2},
  [8681] = {.lex_state = 226, .external_lex_state = 2},
  [8682] = {.lex_state = 226, .external_lex_state = 2},
  [8683] = {.lex_state = 437, .external_lex_state = 2},
  [8684] = {.lex_state = 226, .external_lex_state = 2},
  [8685] = {.lex_state = 226, .external_lex_state = 2},
  [8686] = {.lex_state = 226, .external_lex_state = 2},
  [8687] = {.lex_state = 226, .external_lex_state = 2},
  [8688] = {.lex_state = 226, .external_lex_state = 2},
  [8689] = {.lex_state = 437, .external_lex_state = 2},
  [8690] = {.lex_state = 226, .external_lex_state = 2},
  [8691] = {.lex_state = 27, .external_lex_state = 3},
  [8692] = {.lex_state = 226, .external_lex_state = 2},
  [8693] = {.lex_state = 17, .external_lex_state = 2},
  [8694] = {.lex_state = 437, .external_lex_state = 2},
  [8695] = {.lex_state = 437, .external_lex_state = 2},
  [8696] = {.lex_state = 226, .external_lex_state = 2},
  [8697] = {.lex_state = 437, .external_lex_state = 2},
  [8698] = {.lex_state = 437, .external_lex_state = 2},
  [8699] = {.lex_state = 437, .external_lex_state = 2},
  [8700] = {.lex_state = 17, .external_lex_state = 2},
  [8701] = {.lex_state = 437, .external_lex_state = 2},
  [8702] = {.lex_state = 226, .external_lex_state = 2},
  [8703] = {.lex_state = 437, .external_lex_state = 2},
  [8704] = {.lex_state = 7, .external_lex_state = 2},
  [8705] = {.lex_state = 226, .external_lex_state = 2},
  [8706] = {.lex_state = 7, .external_lex_state = 2},
  [8707] = {.lex_state = 226, .external_lex_state = 2},
  [8708] = {.lex_state = 437, .external_lex_state = 2},
  [8709] = {.lex_state = 226, .external_lex_state = 2},
  [8710] = {.lex_state = 179, .external_lex_state = 3},
  [8711] = {.lex_state = 437, .external_lex_state = 2},
  [8712] = {.lex_state = 226, .external_lex_state = 2},
  [8713] = {.lex_state = 437, .external_lex_state = 2},
  [8714] = {.lex_state = 437, .external_lex_state = 2},
  [8715] = {.lex_state = 437, .external_lex_state = 2},
  [8716] = {.lex_state = 226, .external_lex_state = 2},
  [8717] = {.lex_state = 226, .external_lex_state = 2},
  [8718] = {.lex_state = 226, .external_lex_state = 2},
  [8719] = {.lex_state = 437, .external_lex_state = 2},
  [8720] = {.lex_state = 7, .external_lex_state = 2},
  [8721] = {.lex_state = 226, .external_lex_state = 2},
  [8722] = {.lex_state = 226, .external_lex_state = 2},
  [8723] = {.lex_state = 437, .external_lex_state = 2},
  [8724] = {.lex_state = 437, .external_lex_state = 2},
  [8725] = {.lex_state = 437, .external_lex_state = 2},
  [8726] = {.lex_state = 437, .external_lex_state = 2},
  [8727] = {.lex_state = 437, .external_lex_state = 2},
  [8728] = {.lex_state = 437, .external_lex_state = 2},
  [8729] = {.lex_state = 17, .external_lex_state = 2},
  [8730] = {.lex_state = 17, .external_lex_state = 2},
  [8731] = {.lex_state = 437, .external_lex_state = 2},
  [8732] = {.lex_state = 7, .external_lex_state = 2},
  [8733] = {.lex_state = 437, .external_lex_state = 2},
  [8734] = {.lex_state = 226, .external_lex_state = 2},
  [8735] = {.lex_state = 7, .external_lex_state = 2},
  [8736] = {.lex_state = 437, .external_lex_state = 2},
  [8737] = {.lex_state = 175, .external_lex_state = 3},
  [8738] = {.lex_state = 437, .external_lex_state = 2},
  [8739] = {.lex_state = 17, .external_lex_state = 2},
  [8740] = {.lex_state = 226, .external_lex_state = 2},
  [8741] = {.lex_state = 7, .external_lex_state = 2},
  [8742] = {.lex_state = 226, .external_lex_state = 2},
  [8743] = {.lex_state = 445, .external_lex_state = 2},
  [8744] = {.lex_state = 226, .external_lex_state = 2},
  [8745] = {.lex_state = 226, .external_lex_state = 2},
  [8746] = {.lex_state = 27, .external_lex_state = 3},
  [8747] = {.lex_state = 226, .external_lex_state = 2},
  [8748] = {.lex_state = 27, .external_lex_state = 3},
  [8749] = {.lex_state = 7, .external_lex_state = 2},
  [8750] = {.lex_state = 226, .external_lex_state = 2},
  [8751] = {.lex_state = 7, .external_lex_state = 2},
  [8752] = {.lex_state = 226, .external_lex_state = 2},
  [8753] = {.lex_state = 437, .external_lex_state = 2},
  [8754] = {.lex_state = 437, .external_lex_state = 2},
  [8755] = {.lex_state = 437, .external_lex_state = 2},
  [8756] = {.lex_state = 437, .external_lex_state = 2},
  [8757] = {.lex_state = 437, .external_lex_state = 2},
  [8758] = {.lex_state = 27, .external_lex_state = 3},
  [8759] = {.lex_state = 226, .external_lex_state = 2},
  [8760] = {.lex_state = 226, .external_lex_state = 2},
  [8761] = {.lex_state = 437, .external_lex_state = 2},
  [8762] = {.lex_state = 27, .external_lex_state = 3},
  [8763] = {.lex_state = 175, .external_lex_state = 3},
  [8764] = {.lex_state = 226, .external_lex_state = 2},
  [8765] = {.lex_state = 437, .external_lex_state = 2},
  [8766] = {.lex_state = 437, .external_lex_state = 2},
  [8767] = {.lex_state = 437, .external_lex_state = 2},
  [8768] = {.lex_state = 226, .external_lex_state = 2},
  [8769] = {.lex_state = 226, .external_lex_state = 2},
  [8770] = {.lex_state = 7, .external_lex_state = 2},
  [8771] = {.lex_state = 179, .external_lex_state = 3},
  [8772] = {.lex_state = 17, .external_lex_state = 2},
  [8773] = {.lex_state = 437, .external_lex_state = 2},
  [8774] = {.lex_state = 437, .external_lex_state = 2},
  [8775] = {.lex_state = 437, .external_lex_state = 2},
  [8776] = {.lex_state = 437, .external_lex_state = 2},
  [8777] = {.lex_state = 226, .external_lex_state = 2},
  [8778] = {.lex_state = 437, .external_lex_state = 2},
  [8779] = {.lex_state = 437, .external_lex_state = 2},
  [8780] = {.lex_state = 7, .external_lex_state = 2},
  [8781] = {.lex_state = 437, .external_lex_state = 2},
  [8782] = {.lex_state = 27, .external_lex_state = 3},
  [8783] = {.lex_state = 226, .external_lex_state = 2},
  [8784] = {.lex_state = 437, .external_lex_state = 2},
  [8785] = {.lex_state = 175, .external_lex_state = 3},
  [8786] = {.lex_state = 437, .external_lex_state = 2},
  [8787] = {.lex_state = 437, .external_lex_state = 2},
  [8788] = {.lex_state = 437, .external_lex_state = 2},
  [8789] = {.lex_state = 437, .external_lex_state = 2},
  [8790] = {.lex_state = 437, .external_lex_state = 2},
  [8791] = {.lex_state = 226, .external_lex_state = 2},
  [8792] = {.lex_state = 27, .external_lex_state = 3},
  [8793] = {.lex_state = 437, .external_lex_state = 2},
  [8794] = {.lex_state = 437, .external_lex_state = 2},
  [8795] = {.lex_state = 226, .external_lex_state = 2},
  [8796] = {.lex_state = 437, .external_lex_state = 2},
  [8797] = {.lex_state = 17, .external_lex_state = 2},
  [8798] = {.lex_state = 175, .external_lex_state = 3},
  [8799] = {.lex_state = 437, .external_lex_state = 2},
  [8800] = {.lex_state = 437, .external_lex_state = 2},
  [8801] = {.lex_state = 7, .external_lex_state = 2},
  [8802] = {.lex_state = 7, .external_lex_state = 2},
  [8803] = {.lex_state = 7, .external_lex_state = 2},
  [8804] = {.lex_state = 437, .external_lex_state = 2},
  [8805] = {.lex_state = 437, .external_lex_state = 2},
  [8806] = {.lex_state = 7, .external_lex_state = 2},
  [8807] = {.lex_state = 7, .external_lex_state = 2},
  [8808] = {.lex_state = 7, .external_lex_state = 2},
  [8809] = {.lex_state = 7, .external_lex_state = 2},
  [8810] = {.lex_state = 7, .external_lex_state = 2},
  [8811] = {.lex_state = 437, .external_lex_state = 2},
  [8812] = {.lex_state = 437, .external_lex_state = 2},
  [8813] = {.lex_state = 437, .external_lex_state = 2},
  [8814] = {.lex_state = 7, .external_lex_state = 2},
  [8815] = {.lex_state = 7, .external_lex_state = 2},
  [8816] = {.lex_state = 7, .external_lex_state = 2},
  [8817] = {.lex_state = 7, .external_lex_state = 2},
  [8818] = {.lex_state = 7, .external_lex_state = 2},
  [8819] = {.lex_state = 7, .external_lex_state = 2},
  [8820] = {.lex_state = 7, .external_lex_state = 2},
  [8821] = {.lex_state = 7, .external_lex_state = 2},
  [8822] = {.lex_state = 7, .external_lex_state = 2},
  [8823] = {.lex_state = 7, .external_lex_state = 2},
  [8824] = {.lex_state = 437, .external_lex_state = 2},
  [8825] = {.lex_state = 7, .external_lex_state = 2},
  [8826] = {.lex_state = 7, .external_lex_state = 2},
  [8827] = {.lex_state = 7, .external_lex_state = 2},
  [8828] = {.lex_state = 437, .external_lex_state = 2},
  [8829] = {.lex_state = 7, .external_lex_state = 2},
  [8830] = {.lex_state = 7, .external_lex_state = 2},
  [8831] = {.lex_state = 7, .external_lex_state = 2},
  [8832] = {.lex_state = 7, .external_lex_state = 2},
  [8833] = {.lex_state = 7, .external_lex_state = 2},
  [8834] = {.lex_state = 7, .external_lex_state = 2},
  [8835] = {.lex_state = 7, .external_lex_state = 2},
  [8836] = {.lex_state = 7, .external_lex_state = 2},
  [8837] = {.lex_state = 7, .external_lex_state = 2},
  [8838] = {.lex_state = 7, .external_lex_state = 2},
  [8839] = {.lex_state = 7, .external_lex_state = 2},
  [8840] = {.lex_state = 7, .external_lex_state = 2},
  [8841] = {.lex_state = 7, .external_lex_state = 2},
  [8842] = {.lex_state = 437, .external_lex_state = 2},
  [8843] = {.lex_state = 7, .external_lex_state = 2},
  [8844] = {.lex_state = 7, .external_lex_state = 2},
  [8845] = {.lex_state = 437, .external_lex_state = 2},
  [8846] = {.lex_state = 7, .external_lex_state = 2},
  [8847] = {.lex_state = 7, .external_lex_state = 2},
  [8848] = {.lex_state = 437, .external_lex_state = 2},
  [8849] = {.lex_state = 7, .external_lex_state = 2},
  [8850] = {.lex_state = 7, .external_lex_state = 2},
  [8851] = {.lex_state = 7, .external_lex_state = 2},
  [8852] = {.lex_state = 7, .external_lex_state = 2},
  [8853] = {.lex_state = 7, .external_lex_state = 2},
  [8854] = {.lex_state = 7, .external_lex_state = 2},
  [8855] = {.lex_state = 437, .external_lex_state = 2},
  [8856] = {.lex_state = 437, .external_lex_state = 2},
  [8857] = {.lex_state = 437, .external_lex_state = 2},
  [8858] = {.lex_state = 437, .external_lex_state = 2},
  [8859] = {.lex_state = 437, .external_lex_state = 2},
  [8860] = {.lex_state = 7, .external_lex_state = 2},
  [8861] = {.lex_state = 437, .external_lex_state = 2},
  [8862] = {.lex_state = 437, .external_lex_state = 2},
  [8863] = {.lex_state = 7, .external_lex_state = 2},
  [8864] = {.lex_state = 7, .external_lex_state = 2},
  [8865] = {.lex_state = 7, .external_lex_state = 2},
  [8866] = {.lex_state = 7, .external_lex_state = 2},
  [8867] = {.lex_state = 7, .external_lex_state = 2},
  [8868] = {.lex_state = 7, .external_lex_state = 2},
  [8869] = {.lex_state = 437, .external_lex_state = 2},
  [8870] = {.lex_state = 437, .external_lex_state = 2},
  [8871] = {.lex_state = 7, .external_lex_state = 2},
  [8872] = {.lex_state = 7, .external_lex_state = 2},
  [8873] = {.lex_state = 7, .external_lex_state = 2},
  [8874] = {.lex_state = 437, .external_lex_state = 2},
  [8875] = {.lex_state = 7, .external_lex_state = 2},
  [8876] = {.lex_state = 7, .external_lex_state = 2},
  [8877] = {.lex_state = 437, .external_lex_state = 2},
  [8878] = {.lex_state = 7, .external_lex_state = 2},
  [8879] = {.lex_state = 437, .external_lex_state = 2},
  [8880] = {.lex_state = 7, .external_lex_state = 2},
  [8881] = {.lex_state = 7, .external_lex_state = 2},
  [8882] = {.lex_state = 7, .external_lex_state = 2},
  [8883] = {.lex_state = 437, .external_lex_state = 2},
  [8884] = {.lex_state = 7, .external_lex_state = 2},
  [8885] = {.lex_state = 7, .external_lex_state = 2},
  [8886] = {.lex_state = 7, .external_lex_state = 2},
  [8887] = {.lex_state = 437, .external_lex_state = 2},
  [8888] = {.lex_state = 7, .external_lex_state = 2},
  [8889] = {.lex_state = 7, .external_lex_state = 2},
  [8890] = {.lex_state = 7, .external_lex_state = 2},
  [8891] = {.lex_state = 179, .external_lex_state = 3},
  [8892] = {.lex_state = 7, .external_lex_state = 2},
  [8893] = {.lex_state = 7, .external_lex_state = 2},
  [8894] = {.lex_state = 437, .external_lex_state = 2},
  [8895] = {.lex_state = 437, .external_lex_state = 2},
  [8896] = {.lex_state = 7, .external_lex_state = 2},
  [8897] = {.lex_state = 7, .external_lex_state = 2},
  [8898] = {.lex_state = 7, .external_lex_state = 2},
  [8899] = {.lex_state = 437, .external_lex_state = 2},
  [8900] = {.lex_state = 7, .external_lex_state = 2},
  [8901] = {.lex_state = 7, .external_lex_state = 2},
  [8902] = {.lex_state = 7, .external_lex_state = 2},
  [8903] = {.lex_state = 7, .external_lex_state = 2},
  [8904] = {.lex_state = 7, .external_lex_state = 2},
  [8905] = {.lex_state = 437, .external_lex_state = 2},
  [8906] = {.lex_state = 7, .external_lex_state = 2},
  [8907] = {.lex_state = 7, .external_lex_state = 2},
  [8908] = {.lex_state = 7, .external_lex_state = 2},
  [8909] = {.lex_state = 437, .external_lex_state = 2},
  [8910] = {.lex_state = 437, .external_lex_state = 2},
  [8911] = {.lex_state = 7, .external_lex_state = 2},
  [8912] = {.lex_state = 437, .external_lex_state = 2},
  [8913] = {.lex_state = 7, .external_lex_state = 2},
  [8914] = {.lex_state = 7, .external_lex_state = 2},
  [8915] = {.lex_state = 7, .external_lex_state = 2},
  [8916] = {.lex_state = 7, .external_lex_state = 2},
  [8917] = {.lex_state = 7, .external_lex_state = 2},
  [8918] = {.lex_state = 7, .external_lex_state = 2},
  [8919] = {.lex_state = 7, .external_lex_state = 2},
  [8920] = {.lex_state = 7, .external_lex_state = 2},
  [8921] = {.lex_state = 7, .external_lex_state = 2},
  [8922] = {.lex_state = 7, .external_lex_state = 2},
  [8923] = {.lex_state = 7, .external_lex_state = 2},
  [8924] = {.lex_state = 7, .external_lex_state = 2},
  [8925] = {.lex_state = 189, .external_lex_state = 3},
  [8926] = {.lex_state = 437, .external_lex_state = 2},
  [8927] = {.lex_state = 7, .external_lex_state = 2},
  [8928] = {.lex_state = 7, .external_lex_state = 2},
  [8929] = {.lex_state = 437, .external_lex_state = 2},
  [8930] = {.lex_state = 7, .external_lex_state = 2},
  [8931] = {.lex_state = 7, .external_lex_state = 2},
  [8932] = {.lex_state = 7, .external_lex_state = 2},
  [8933] = {.lex_state = 7, .external_lex_state = 2},
  [8934] = {.lex_state = 7, .external_lex_state = 2},
  [8935] = {.lex_state = 7, .external_lex_state = 2},
  [8936] = {.lex_state = 7, .external_lex_state = 2},
  [8937] = {.lex_state = 7, .external_lex_state = 2},
  [8938] = {.lex_state = 7, .external_lex_state = 2},
  [8939] = {.lex_state = 7, .external_lex_state = 2},
  [8940] = {.lex_state = 214, .external_lex_state = 3},
  [8941] = {.lex_state = 7, .external_lex_state = 2},
  [8942] = {.lex_state = 7, .external_lex_state = 2},
  [8943] = {.lex_state = 7, .external_lex_state = 2},
  [8944] = {.lex_state = 7, .external_lex_state = 2},
  [8945] = {.lex_state = 437, .external_lex_state = 2},
  [8946] = {.lex_state = 7, .external_lex_state = 2},
  [8947] = {.lex_state = 7, .external_lex_state = 2},
  [8948] = {.lex_state = 437, .external_lex_state = 2},
  [8949] = {.lex_state = 7, .external_lex_state = 2},
  [8950] = {.lex_state = 437, .external_lex_state = 2},
  [8951] = {.lex_state = 7, .external_lex_state = 2},
  [8952] = {.lex_state = 437, .external_lex_state = 2},
  [8953] = {.lex_state = 7, .external_lex_state = 2},
  [8954] = {.lex_state = 7, .external_lex_state = 2},
  [8955] = {.lex_state = 7, .external_lex_state = 2},
  [8956] = {.lex_state = 7, .external_lex_state = 2},
  [8957] = {.lex_state = 7, .external_lex_state = 2},
  [8958] = {.lex_state = 437, .external_lex_state = 2},
  [8959] = {.lex_state = 7, .external_lex_state = 2},
  [8960] = {.lex_state = 7, .external_lex_state = 2},
  [8961] = {.lex_state = 7, .external_lex_state = 2},
  [8962] = {.lex_state = 7, .external_lex_state = 2},
  [8963] = {.lex_state = 179, .external_lex_state = 3},
  [8964] = {.lex_state = 7, .external_lex_state = 2},
  [8965] = {.lex_state = 7, .external_lex_state = 2},
  [8966] = {.lex_state = 7, .external_lex_state = 2},
  [8967] = {.lex_state = 7, .external_lex_state = 2},
  [8968] = {.lex_state = 7, .external_lex_state = 2},
  [8969] = {.lex_state = 7, .external_lex_state = 2},
  [8970] = {.lex_state = 7, .external_lex_state = 2},
  [8971] = {.lex_state = 7, .external_lex_state = 2},
  [8972] = {.lex_state = 7, .external_lex_state = 2},
  [8973] = {.lex_state = 7, .external_lex_state = 2},
  [8974] = {.lex_state = 7, .external_lex_state = 2},
  [8975] = {.lex_state = 7, .external_lex_state = 2},
  [8976] = {.lex_state = 7, .external_lex_state = 2},
  [8977] = {.lex_state = 7, .external_lex_state = 2},
  [8978] = {.lex_state = 7, .external_lex_state = 2},
  [8979] = {.lex_state = 7, .external_lex_state = 2},
  [8980] = {.lex_state = 7, .external_lex_state = 2},
  [8981] = {.lex_state = 7, .external_lex_state = 2},
  [8982] = {.lex_state = 7, .external_lex_state = 2},
  [8983] = {.lex_state = 437, .external_lex_state = 2},
  [8984] = {.lex_state = 7, .external_lex_state = 2},
  [8985] = {.lex_state = 7, .external_lex_state = 2},
  [8986] = {.lex_state = 7, .external_lex_state = 2},
  [8987] = {.lex_state = 7, .external_lex_state = 2},
  [8988] = {.lex_state = 7, .external_lex_state = 2},
  [8989] = {.lex_state = 7, .external_lex_state = 2},
  [8990] = {.lex_state = 7, .external_lex_state = 2},
  [8991] = {.lex_state = 7, .external_lex_state = 2},
  [8992] = {.lex_state = 7, .external_lex_state = 2},
  [8993] = {.lex_state = 437, .external_lex_state = 2},
  [8994] = {.lex_state = 7, .external_lex_state = 2},
  [8995] = {.lex_state = 437, .external_lex_state = 2},
  [8996] = {.lex_state = 7, .external_lex_state = 2},
  [8997] = {.lex_state = 7, .external_lex_state = 2},
  [8998] = {.lex_state = 178, .external_lex_state = 3},
  [8999] = {.lex_state = 7, .external_lex_state = 2},
  [9000] = {.lex_state = 7, .external_lex_state = 2},
  [9001] = {.lex_state = 437, .external_lex_state = 2},
  [9002] = {.lex_state = 7, .external_lex_state = 2},
  [9003] = {.lex_state = 7, .external_lex_state = 2},
  [9004] = {.lex_state = 437, .external_lex_state = 2},
  [9005] = {.lex_state = 437, .external_lex_state = 2},
  [9006] = {.lex_state = 7, .external_lex_state = 2},
  [9007] = {.lex_state = 7, .external_lex_state = 2},
  [9008] = {.lex_state = 189, .external_lex_state = 3},
  [9009] = {.lex_state = 7, .external_lex_state = 2},
  [9010] = {.lex_state = 437, .external_lex_state = 2},
  [9011] = {.lex_state = 7, .external_lex_state = 2},
  [9012] = {.lex_state = 7, .external_lex_state = 2},
  [9013] = {.lex_state = 437, .external_lex_state = 2},
  [9014] = {.lex_state = 179, .external_lex_state = 3},
  [9015] = {.lex_state = 7, .external_lex_state = 2},
  [9016] = {.lex_state = 7, .external_lex_state = 2},
  [9017] = {.lex_state = 7, .external_lex_state = 2},
  [9018] = {.lex_state = 7, .external_lex_state = 2},
  [9019] = {.lex_state = 7, .external_lex_state = 2},
  [9020] = {.lex_state = 437, .external_lex_state = 2},
  [9021] = {.lex_state = 7, .external_lex_state = 2},
  [9022] = {.lex_state = 7, .external_lex_state = 2},
  [9023] = {.lex_state = 7, .external_lex_state = 2},
  [9024] = {.lex_state = 7, .external_lex_state = 2},
  [9025] = {.lex_state = 445, .external_lex_state = 2},
  [9026] = {.lex_state = 437, .external_lex_state = 2},
  [9027] = {.lex_state = 179, .external_lex_state = 3},
  [9028] = {.lex_state = 7, .external_lex_state = 2},
  [9029] = {.lex_state = 7, .external_lex_state = 2},
  [9030] = {.lex_state = 7, .external_lex_state = 2},
  [9031] = {.lex_state = 7, .external_lex_state = 2},
  [9032] = {.lex_state = 437, .external_lex_state = 2},
  [9033] = {.lex_state = 7, .external_lex_state = 2},
  [9034] = {.lex_state = 7, .external_lex_state = 2},
  [9035] = {.lex_state = 437, .external_lex_state = 2},
  [9036] = {.lex_state = 7, .external_lex_state = 2},
  [9037] = {.lex_state = 437, .external_lex_state = 2},
  [9038] = {.lex_state = 437, .external_lex_state = 2},
  [9039] = {.lex_state = 178, .external_lex_state = 3},
  [9040] = {.lex_state = 437, .external_lex_state = 2},
  [9041] = {.lex_state = 7, .external_lex_state = 2},
  [9042] = {.lex_state = 437, .external_lex_state = 2},
  [9043] = {.lex_state = 437, .external_lex_state = 2},
  [9044] = {.lex_state = 7, .external_lex_state = 2},
  [9045] = {.lex_state = 7, .external_lex_state = 2},
  [9046] = {.lex_state = 444, .external_lex_state = 2},
  [9047] = {.lex_state = 437, .external_lex_state = 2},
  [9048] = {.lex_state = 7, .external_lex_state = 2},
  [9049] = {.lex_state = 7, .external_lex_state = 2},
  [9050] = {.lex_state = 437, .external_lex_state = 2},
  [9051] = {.lex_state = 7, .external_lex_state = 2},
  [9052] = {.lex_state = 437, .external_lex_state = 2},
  [9053] = {.lex_state = 7, .external_lex_state = 2},
  [9054] = {.lex_state = 7, .external_lex_state = 2},
  [9055] = {.lex_state = 7, .external_lex_state = 2},
  [9056] = {.lex_state = 437, .external_lex_state = 2},
  [9057] = {.lex_state = 7, .external_lex_state = 2},
  [9058] = {.lex_state = 437, .external_lex_state = 2},
  [9059] = {.lex_state = 7, .external_lex_state = 2},
  [9060] = {.lex_state = 22, .external_lex_state = 2},
  [9061] = {.lex_state = 437, .external_lex_state = 2},
  [9062] = {.lex_state = 195, .external_lex_state = 3},
  [9063] = {.lex_state = 437, .external_lex_state = 2},
  [9064] = {.lex_state = 189, .external_lex_state = 3},
  [9065] = {.lex_state = 195, .external_lex_state = 3},
  [9066] = {.lex_state = 437, .external_lex_state = 2},
  [9067] = {.lex_state = 437, .external_lex_state = 2},
  [9068] = {.lex_state = 437, .external_lex_state = 2},
  [9069] = {.lex_state = 437, .external_lex_state = 2},
  [9070] = {.lex_state = 437, .external_lex_state = 2},
  [9071] = {.lex_state = 195, .external_lex_state = 3},
  [9072] = {.lex_state = 178, .external_lex_state = 3},
  [9073] = {.lex_state = 437, .external_lex_state = 2},
  [9074] = {.lex_state = 437, .external_lex_state = 2},
  [9075] = {.lex_state = 437, .external_lex_state = 2},
  [9076] = {.lex_state = 437, .external_lex_state = 2},
  [9077] = {.lex_state = 195, .external_lex_state = 3},
  [9078] = {.lex_state = 437, .external_lex_state = 2},
  [9079] = {.lex_state = 437, .external_lex_state = 2},
  [9080] = {.lex_state = 189, .external_lex_state = 3},
  [9081] = {.lex_state = 178, .external_lex_state = 3},
  [9082] = {.lex_state = 437, .external_lex_state = 2},
  [9083] = {.lex_state = 178, .external_lex_state = 3},
  [9084] = {.lex_state = 437, .external_lex_state = 2},
  [9085] = {.lex_state = 437, .external_lex_state = 2},
  [9086] = {.lex_state = 437, .external_lex_state = 2},
  [9087] = {.lex_state = 437, .external_lex_state = 2},
  [9088] = {.lex_state = 437, .external_lex_state = 2},
  [9089] = {.lex_state = 205, .external_lex_state = 3},
  [9090] = {.lex_state = 178, .external_lex_state = 3},
  [9091] = {.lex_state = 445, .external_lex_state = 2},
  [9092] = {.lex_state = 437, .external_lex_state = 2},
  [9093] = {.lex_state = 178, .external_lex_state = 3},
  [9094] = {.lex_state = 178, .external_lex_state = 3},
  [9095] = {.lex_state = 445, .external_lex_state = 2},
  [9096] = {.lex_state = 178, .external_lex_state = 3},
  [9097] = {.lex_state = 178, .external_lex_state = 3},
  [9098] = {.lex_state = 445, .external_lex_state = 2},
  [9099] = {.lex_state = 178, .external_lex_state = 3},
  [9100] = {.lex_state = 178, .external_lex_state = 3},
  [9101] = {.lex_state = 178, .external_lex_state = 3},
  [9102] = {.lex_state = 437, .external_lex_state = 2},
  [9103] = {.lex_state = 437, .external_lex_state = 2},
  [9104] = {.lex_state = 178, .external_lex_state = 3},
  [9105] = {.lex_state = 437, .external_lex_state = 2},
  [9106] = {.lex_state = 195, .external_lex_state = 3},
  [9107] = {.lex_state = 178, .external_lex_state = 3},
  [9108] = {.lex_state = 178, .external_lex_state = 3},
  [9109] = {.lex_state = 178, .external_lex_state = 3},
  [9110] = {.lex_state = 178, .external_lex_state = 3},
  [9111] = {.lex_state = 178, .external_lex_state = 3},
  [9112] = {.lex_state = 437, .external_lex_state = 2},
  [9113] = {.lex_state = 178, .external_lex_state = 3},
  [9114] = {.lex_state = 178, .external_lex_state = 3},
  [9115] = {.lex_state = 195, .external_lex_state = 3},
  [9116] = {.lex_state = 178, .external_lex_state = 3},
  [9117] = {.lex_state = 437, .external_lex_state = 2},
  [9118] = {.lex_state = 195, .external_lex_state = 3},
  [9119] = {.lex_state = 178, .external_lex_state = 3},
  [9120] = {.lex_state = 437, .external_lex_state = 2},
  [9121] = {.lex_state = 447, .external_lex_state = 2},
  [9122] = {.lex_state = 189, .external_lex_state = 3},
  [9123] = {.lex_state = 437, .external_lex_state = 2},
  [9124] = {.lex_state = 437, .external_lex_state = 2},
  [9125] = {.lex_state = 178, .external_lex_state = 3},
  [9126] = {.lex_state = 437, .external_lex_state = 2},
  [9127] = {.lex_state = 437, .external_lex_state = 2},
  [9128] = {.lex_state = 178, .external_lex_state = 3},
  [9129] = {.lex_state = 178, .external_lex_state = 3},
  [9130] = {.lex_state = 447, .external_lex_state = 2},
  [9131] = {.lex_state = 178, .external_lex_state = 3},
  [9132] = {.lex_state = 437, .external_lex_state = 2},
  [9133] = {.lex_state = 437, .external_lex_state = 2},
  [9134] = {.lex_state = 437, .external_lex_state = 2},
  [9135] = {.lex_state = 437, .external_lex_state = 2},
  [9136] = {.lex_state = 178, .external_lex_state = 3},
  [9137] = {.lex_state = 437, .external_lex_state = 2},
  [9138] = {.lex_state = 178, .external_lex_state = 3},
  [9139] = {.lex_state = 445, .external_lex_state = 2},
  [9140] = {.lex_state = 178, .external_lex_state = 3},
  [9141] = {.lex_state = 178, .external_lex_state = 3},
  [9142] = {.lex_state = 178, .external_lex_state = 3},
  [9143] = {.lex_state = 178, .external_lex_state = 3},
  [9144] = {.lex_state = 178, .external_lex_state = 3},
  [9145] = {.lex_state = 178, .external_lex_state = 3},
  [9146] = {.lex_state = 178, .external_lex_state = 3},
  [9147] = {.lex_state = 178, .external_lex_state = 3},
  [9148] = {.lex_state = 178, .external_lex_state = 3},
  [9149] = {.lex_state = 178, .external_lex_state = 3},
  [9150] = {.lex_state = 437, .external_lex_state = 2},
  [9151] = {.lex_state = 178, .external_lex_state = 3},
  [9152] = {.lex_state = 437, .external_lex_state = 2},
  [9153] = {.lex_state = 178, .external_lex_state = 3},
  [9154] = {.lex_state = 195, .external_lex_state = 3},
  [9155] = {.lex_state = 178, .external_lex_state = 3},
  [9156] = {.lex_state = 445, .external_lex_state = 2},
  [9157] = {.lex_state = 178, .external_lex_state = 3},
  [9158] = {.lex_state = 178, .external_lex_state = 3},
  [9159] = {.lex_state = 437, .external_lex_state = 2},
  [9160] = {.lex_state = 22, .external_lex_state = 2},
  [9161] = {.lex_state = 195, .external_lex_state = 3},
  [9162] = {.lex_state = 437, .external_lex_state = 2},
  [9163] = {.lex_state = 446, .external_lex_state = 2},
  [9164] = {.lex_state = 437, .external_lex_state = 2},
  [9165] = {.lex_state = 178, .external_lex_state = 3},
  [9166] = {.lex_state = 178, .external_lex_state = 3},
  [9167] = {.lex_state = 178, .external_lex_state = 3},
  [9168] = {.lex_state = 178, .external_lex_state = 3},
  [9169] = {.lex_state = 195, .external_lex_state = 3},
  [9170] = {.lex_state = 178, .external_lex_state = 3},
  [9171] = {.lex_state = 178, .external_lex_state = 3},
  [9172] = {.lex_state = 178, .external_lex_state = 3},
  [9173] = {.lex_state = 178, .external_lex_state = 3},
  [9174] = {.lex_state = 178, .external_lex_state = 3},
  [9175] = {.lex_state = 178, .external_lex_state = 3},
  [9176] = {.lex_state = 178, .external_lex_state = 3},
  [9177] = {.lex_state = 178, .external_lex_state = 3},
  [9178] = {.lex_state = 437, .external_lex_state = 2},
  [9179] = {.lex_state = 178, .external_lex_state = 3},
  [9180] = {.lex_state = 178, .external_lex_state = 3},
  [9181] = {.lex_state = 195, .external_lex_state = 3},
  [9182] = {.lex_state = 178, .external_lex_state = 3},
  [9183] = {.lex_state = 178, .external_lex_state = 3},
  [9184] = {.lex_state = 437, .external_lex_state = 2},
  [9185] = {.lex_state = 178, .external_lex_state = 3},
  [9186] = {.lex_state = 178, .external_lex_state = 3},
  [9187] = {.lex_state = 22, .external_lex_state = 2},
  [9188] = {.lex_state = 437, .external_lex_state = 2},
  [9189] = {.lex_state = 437, .external_lex_state = 2},
  [9190] = {.lex_state = 178, .external_lex_state = 3},
  [9191] = {.lex_state = 189, .external_lex_state = 3},
  [9192] = {.lex_state = 189, .external_lex_state = 3},
  [9193] = {.lex_state = 189, .external_lex_state = 3},
  [9194] = {.lex_state = 189, .external_lex_state = 3},
  [9195] = {.lex_state = 445, .external_lex_state = 2},
  [9196] = {.lex_state = 189, .external_lex_state = 3},
  [9197] = {.lex_state = 189, .external_lex_state = 3},
  [9198] = {.lex_state = 437, .external_lex_state = 2},
  [9199] = {.lex_state = 445, .external_lex_state = 2},
  [9200] = {.lex_state = 445, .external_lex_state = 2},
  [9201] = {.lex_state = 189, .external_lex_state = 3},
  [9202] = {.lex_state = 437, .external_lex_state = 2},
  [9203] = {.lex_state = 189, .external_lex_state = 3},
  [9204] = {.lex_state = 189, .external_lex_state = 3},
  [9205] = {.lex_state = 189, .external_lex_state = 3},
  [9206] = {.lex_state = 189, .external_lex_state = 3},
  [9207] = {.lex_state = 189, .external_lex_state = 3},
  [9208] = {.lex_state = 189, .external_lex_state = 3},
  [9209] = {.lex_state = 189, .external_lex_state = 3},
  [9210] = {.lex_state = 189, .external_lex_state = 3},
  [9211] = {.lex_state = 445, .external_lex_state = 2},
  [9212] = {.lex_state = 189, .external_lex_state = 3},
  [9213] = {.lex_state = 437, .external_lex_state = 2},
  [9214] = {.lex_state = 189, .external_lex_state = 3},
  [9215] = {.lex_state = 445, .external_lex_state = 2},
  [9216] = {.lex_state = 437, .external_lex_state = 2},
  [9217] = {.lex_state = 189, .external_lex_state = 3},
  [9218] = {.lex_state = 445, .external_lex_state = 2},
  [9219] = {.lex_state = 189, .external_lex_state = 3},
  [9220] = {.lex_state = 189, .external_lex_state = 3},
  [9221] = {.lex_state = 189, .external_lex_state = 3},
  [9222] = {.lex_state = 189, .external_lex_state = 3},
  [9223] = {.lex_state = 189, .external_lex_state = 3},
  [9224] = {.lex_state = 189, .external_lex_state = 3},
  [9225] = {.lex_state = 445, .external_lex_state = 2},
  [9226] = {.lex_state = 189, .external_lex_state = 3},
  [9227] = {.lex_state = 189, .external_lex_state = 3},
  [9228] = {.lex_state = 189, .external_lex_state = 3},
  [9229] = {.lex_state = 14, .external_lex_state = 2},
  [9230] = {.lex_state = 189, .external_lex_state = 3},
  [9231] = {.lex_state = 189, .external_lex_state = 3},
  [9232] = {.lex_state = 189, .external_lex_state = 3},
  [9233] = {.lex_state = 189, .external_lex_state = 3},
  [9234] = {.lex_state = 189, .external_lex_state = 3},
  [9235] = {.lex_state = 189, .external_lex_state = 3},
  [9236] = {.lex_state = 189, .external_lex_state = 3},
  [9237] = {.lex_state = 437, .external_lex_state = 2},
  [9238] = {.lex_state = 189, .external_lex_state = 3},
  [9239] = {.lex_state = 189, .external_lex_state = 3},
  [9240] = {.lex_state = 447, .external_lex_state = 2},
  [9241] = {.lex_state = 189, .external_lex_state = 3},
  [9242] = {.lex_state = 189, .external_lex_state = 3},
  [9243] = {.lex_state = 189, .external_lex_state = 3},
  [9244] = {.lex_state = 437, .external_lex_state = 2},
  [9245] = {.lex_state = 14, .external_lex_state = 2},
  [9246] = {.lex_state = 189, .external_lex_state = 3},
  [9247] = {.lex_state = 189, .external_lex_state = 3},
  [9248] = {.lex_state = 14, .external_lex_state = 2},
  [9249] = {.lex_state = 189, .external_lex_state = 3},
  [9250] = {.lex_state = 445, .external_lex_state = 2},
  [9251] = {.lex_state = 189, .external_lex_state = 3},
  [9252] = {.lex_state = 14, .external_lex_state = 2},
  [9253] = {.lex_state = 447, .external_lex_state = 2},
  [9254] = {.lex_state = 189, .external_lex_state = 3},
  [9255] = {.lex_state = 189, .external_lex_state = 3},
  [9256] = {.lex_state = 445, .external_lex_state = 2},
  [9257] = {.lex_state = 189, .external_lex_state = 3},
  [9258] = {.lex_state = 189, .external_lex_state = 3},
  [9259] = {.lex_state = 437, .external_lex_state = 2},
  [9260] = {.lex_state = 437, .external_lex_state = 2},
  [9261] = {.lex_state = 437, .external_lex_state = 2},
  [9262] = {.lex_state = 189, .external_lex_state = 3},
  [9263] = {.lex_state = 189, .external_lex_state = 3},
  [9264] = {.lex_state = 189, .external_lex_state = 3},
  [9265] = {.lex_state = 189, .external_lex_state = 3},
  [9266] = {.lex_state = 189, .external_lex_state = 3},
  [9267] = {.lex_state = 189, .external_lex_state = 3},
  [9268] = {.lex_state = 189, .external_lex_state = 3},
  [9269] = {.lex_state = 14, .external_lex_state = 2},
  [9270] = {.lex_state = 189, .external_lex_state = 3},
  [9271] = {.lex_state = 445, .external_lex_state = 2},
  [9272] = {.lex_state = 189, .external_lex_state = 3},
  [9273] = {.lex_state = 189, .external_lex_state = 3},
  [9274] = {.lex_state = 189, .external_lex_state = 3},
  [9275] = {.lex_state = 445, .external_lex_state = 2},
  [9276] = {.lex_state = 445, .external_lex_state = 2},
  [9277] = {.lex_state = 437, .external_lex_state = 2},
  [9278] = {.lex_state = 189, .external_lex_state = 3},
  [9279] = {.lex_state = 445, .external_lex_state = 2},
  [9280] = {.lex_state = 445, .external_lex_state = 2},
  [9281] = {.lex_state = 437, .external_lex_state = 2},
  [9282] = {.lex_state = 244, .external_lex_state = 2},
  [9283] = {.lex_state = 437, .external_lex_state = 2},
  [9284] = {.lex_state = 437, .external_lex_state = 2},
  [9285] = {.lex_state = 445, .external_lex_state = 2},
  [9286] = {.lex_state = 243, .external_lex_state = 2},
  [9287] = {.lex_state = 437, .external_lex_state = 2},
  [9288] = {.lex_state = 445, .external_lex_state = 2},
  [9289] = {.lex_state = 243, .external_lex_state = 2},
  [9290] = {.lex_state = 437, .external_lex_state = 2},
  [9291] = {.lex_state = 244, .external_lex_state = 2},
  [9292] = {.lex_state = 445, .external_lex_state = 2},
  [9293] = {.lex_state = 437, .external_lex_state = 2},
  [9294] = {.lex_state = 450, .external_lex_state = 2},
  [9295] = {.lex_state = 445, .external_lex_state = 2},
  [9296] = {.lex_state = 244, .external_lex_state = 2},
  [9297] = {.lex_state = 244, .external_lex_state = 2},
  [9298] = {.lex_state = 243, .external_lex_state = 2},
  [9299] = {.lex_state = 243, .external_lex_state = 2},
  [9300] = {.lex_state = 7, .external_lex_state = 2},
  [9301] = {.lex_state = 445, .external_lex_state = 2},
  [9302] = {.lex_state = 7, .external_lex_state = 2},
  [9303] = {.lex_state = 190, .external_lex_state = 3},
  [9304] = {.lex_state = 7, .external_lex_state = 2},
  [9305] = {.lex_state = 7, .external_lex_state = 2},
  [9306] = {.lex_state = 7, .external_lex_state = 2},
  [9307] = {.lex_state = 21, .external_lex_state = 2},
  [9308] = {.lex_state = 453, .external_lex_state = 2},
  [9309] = {.lex_state = 437, .external_lex_state = 2},
  [9310] = {.lex_state = 437, .external_lex_state = 2},
  [9311] = {.lex_state = 448, .external_lex_state = 2},
  [9312] = {.lex_state = 244, .external_lex_state = 2},
  [9313] = {.lex_state = 448, .external_lex_state = 2},
  [9314] = {.lex_state = 7, .external_lex_state = 2},
  [9315] = {.lex_state = 7, .external_lex_state = 2},
  [9316] = {.lex_state = 453, .external_lex_state = 2},
  [9317] = {.lex_state = 233, .external_lex_state = 2},
  [9318] = {.lex_state = 445, .external_lex_state = 2},
  [9319] = {.lex_state = 437, .external_lex_state = 2},
  [9320] = {.lex_state = 445, .external_lex_state = 2},
  [9321] = {.lex_state = 445, .external_lex_state = 2},
  [9322] = {.lex_state = 445, .external_lex_state = 2},
  [9323] = {.lex_state = 7, .external_lex_state = 2},
  [9324] = {.lex_state = 7, .external_lex_state = 2},
  [9325] = {.lex_state = 7, .external_lex_state = 2},
  [9326] = {.lex_state = 453, .external_lex_state = 2},
  [9327] = {.lex_state = 437, .external_lex_state = 2},
  [9328] = {.lex_state = 7, .external_lex_state = 2},
  [9329] = {.lex_state = 7, .external_lex_state = 2},
  [9330] = {.lex_state = 7, .external_lex_state = 2},
  [9331] = {.lex_state = 437, .external_lex_state = 2},
  [9332] = {.lex_state = 7, .external_lex_state = 2},
  [9333] = {.lex_state = 7, .external_lex_state = 2},
  [9334] = {.lex_state = 7, .external_lex_state = 2},
  [9335] = {.lex_state = 7, .external_lex_state = 2},
  [9336] = {.lex_state = 7, .external_lex_state = 2},
  [9337] = {.lex_state = 7, .external_lex_state = 2},
  [9338] = {.lex_state = 234, .external_lex_state = 2},
  [9339] = {.lex_state = 437, .external_lex_state = 2},
  [9340] = {.lex_state = 7, .external_lex_state = 2},
  [9341] = {.lex_state = 7, .external_lex_state = 2},
  [9342] = {.lex_state = 7, .external_lex_state = 2},
  [9343] = {.lex_state = 7, .external_lex_state = 2},
  [9344] = {.lex_state = 437, .external_lex_state = 2},
  [9345] = {.lex_state = 7, .external_lex_state = 2},
  [9346] = {.lex_state = 437, .external_lex_state = 2},
  [9347] = {.lex_state = 445, .external_lex_state = 2},
  [9348] = {.lex_state = 7, .external_lex_state = 2},
  [9349] = {.lex_state = 234, .external_lex_state = 2},
  [9350] = {.lex_state = 7, .external_lex_state = 2},
  [9351] = {.lex_state = 7, .external_lex_state = 2},
  [9352] = {.lex_state = 7, .external_lex_state = 2},
  [9353] = {.lex_state = 7, .external_lex_state = 2},
  [9354] = {.lex_state = 7, .external_lex_state = 2},
  [9355] = {.lex_state = 243, .external_lex_state = 2},
  [9356] = {.lex_state = 437, .external_lex_state = 2},
  [9357] = {.lex_state = 445, .external_lex_state = 2},
  [9358] = {.lex_state = 7, .external_lex_state = 2},
  [9359] = {.lex_state = 7, .external_lex_state = 2},
  [9360] = {.lex_state = 7, .external_lex_state = 2},
  [9361] = {.lex_state = 445, .external_lex_state = 2},
  [9362] = {.lex_state = 445, .external_lex_state = 2},
  [9363] = {.lex_state = 7, .external_lex_state = 2},
  [9364] = {.lex_state = 7, .external_lex_state = 2},
  [9365] = {.lex_state = 7, .external_lex_state = 2},
  [9366] = {.lex_state = 190, .external_lex_state = 3},
  [9367] = {.lex_state = 437, .external_lex_state = 2},
  [9368] = {.lex_state = 448, .external_lex_state = 2},
  [9369] = {.lex_state = 7, .external_lex_state = 2},
  [9370] = {.lex_state = 7, .external_lex_state = 2},
  [9371] = {.lex_state = 233, .external_lex_state = 2},
  [9372] = {.lex_state = 445, .external_lex_state = 2},
  [9373] = {.lex_state = 453, .external_lex_state = 2},
  [9374] = {.lex_state = 445, .external_lex_state = 2},
  [9375] = {.lex_state = 244, .external_lex_state = 2},
  [9376] = {.lex_state = 243, .external_lex_state = 2},
  [9377] = {.lex_state = 7, .external_lex_state = 2},
  [9378] = {.lex_state = 445, .external_lex_state = 2},
  [9379] = {.lex_state = 437, .external_lex_state = 2},
  [9380] = {.lex_state = 24, .external_lex_state = 3},
  [9381] = {.lex_state = 7, .external_lex_state = 2},
  [9382] = {.lex_state = 7, .external_lex_state = 2},
  [9383] = {.lex_state = 7, .external_lex_state = 2},
  [9384] = {.lex_state = 233, .external_lex_state = 2},
  [9385] = {.lex_state = 444, .external_lex_state = 2},
  [9386] = {.lex_state = 24, .external_lex_state = 3},
  [9387] = {.lex_state = 7, .external_lex_state = 2},
  [9388] = {.lex_state = 7, .external_lex_state = 2},
  [9389] = {.lex_state = 24, .external_lex_state = 3},
  [9390] = {.lex_state = 444, .external_lex_state = 2},
  [9391] = {.lex_state = 24, .external_lex_state = 3},
  [9392] = {.lex_state = 233, .external_lex_state = 2},
  [9393] = {.lex_state = 233, .external_lex_state = 2},
  [9394] = {.lex_state = 444, .external_lex_state = 2},
  [9395] = {.lex_state = 243, .external_lex_state = 2},
  [9396] = {.lex_state = 24, .external_lex_state = 3},
  [9397] = {.lex_state = 24, .external_lex_state = 3},
  [9398] = {.lex_state = 24, .external_lex_state = 3},
  [9399] = {.lex_state = 7, .external_lex_state = 2},
  [9400] = {.lex_state = 24, .external_lex_state = 3},
  [9401] = {.lex_state = 7, .external_lex_state = 2},
  [9402] = {.lex_state = 243, .external_lex_state = 2},
  [9403] = {.lex_state = 243, .external_lex_state = 2},
  [9404] = {.lex_state = 243, .external_lex_state = 2},
  [9405] = {.lex_state = 243, .external_lex_state = 2},
  [9406] = {.lex_state = 243, .external_lex_state = 2},
  [9407] = {.lex_state = 243, .external_lex_state = 2},
  [9408] = {.lex_state = 243, .external_lex_state = 2},
  [9409] = {.lex_state = 243, .external_lex_state = 2},
  [9410] = {.lex_state = 24, .external_lex_state = 3},
  [9411] = {.lex_state = 24, .external_lex_state = 3},
  [9412] = {.lex_state = 24, .external_lex_state = 3},
  [9413] = {.lex_state = 24, .external_lex_state = 3},
  [9414] = {.lex_state = 243, .external_lex_state = 2},
  [9415] = {.lex_state = 7, .external_lex_state = 2},
  [9416] = {.lex_state = 243, .external_lex_state = 2},
  [9417] = {.lex_state = 243, .external_lex_state = 2},
  [9418] = {.lex_state = 243, .external_lex_state = 2},
  [9419] = {.lex_state = 243, .external_lex_state = 2},
  [9420] = {.lex_state = 24, .external_lex_state = 3},
  [9421] = {.lex_state = 243, .external_lex_state = 2},
  [9422] = {.lex_state = 7, .external_lex_state = 2},
  [9423] = {.lex_state = 243, .external_lex_state = 2},
  [9424] = {.lex_state = 243, .external_lex_state = 2},
  [9425] = {.lex_state = 244, .external_lex_state = 2},
  [9426] = {.lex_state = 243, .external_lex_state = 2},
  [9427] = {.lex_state = 243, .external_lex_state = 2},
  [9428] = {.lex_state = 243, .external_lex_state = 2},
  [9429] = {.lex_state = 243, .external_lex_state = 2},
  [9430] = {.lex_state = 243, .external_lex_state = 2},
  [9431] = {.lex_state = 243, .external_lex_state = 2},
  [9432] = {.lex_state = 244, .external_lex_state = 2},
  [9433] = {.lex_state = 233, .external_lex_state = 2},
  [9434] = {.lex_state = 244, .external_lex_state = 2},
  [9435] = {.lex_state = 243, .external_lex_state = 2},
  [9436] = {.lex_state = 243, .external_lex_state = 2},
  [9437] = {.lex_state = 243, .external_lex_state = 2},
  [9438] = {.lex_state = 7, .external_lex_state = 2},
  [9439] = {.lex_state = 244, .external_lex_state = 2},
  [9440] = {.lex_state = 243, .external_lex_state = 2},
  [9441] = {.lex_state = 243, .external_lex_state = 2},
  [9442] = {.lex_state = 244, .external_lex_state = 2},
  [9443] = {.lex_state = 244, .external_lex_state = 2},
  [9444] = {.lex_state = 244, .external_lex_state = 2},
  [9445] = {.lex_state = 243, .external_lex_state = 2},
  [9446] = {.lex_state = 244, .external_lex_state = 2},
  [9447] = {.lex_state = 244, .external_lex_state = 2},
  [9448] = {.lex_state = 7, .external_lex_state = 2},
  [9449] = {.lex_state = 244, .external_lex_state = 2},
  [9450] = {.lex_state = 244, .external_lex_state = 2},
  [9451] = {.lex_state = 244, .external_lex_state = 2},
  [9452] = {.lex_state = 244, .external_lex_state = 2},
  [9453] = {.lex_state = 7, .external_lex_state = 2},
  [9454] = {.lex_state = 244, .external_lex_state = 2},
  [9455] = {.lex_state = 244, .external_lex_state = 2},
  [9456] = {.lex_state = 244, .external_lex_state = 2},
  [9457] = {.lex_state = 244, .external_lex_state = 2},
  [9458] = {.lex_state = 243, .external_lex_state = 2},
  [9459] = {.lex_state = 244, .external_lex_state = 2},
  [9460] = {.lex_state = 244, .external_lex_state = 2},
  [9461] = {.lex_state = 244, .external_lex_state = 2},
  [9462] = {.lex_state = 244, .external_lex_state = 2},
  [9463] = {.lex_state = 244, .external_lex_state = 2},
  [9464] = {.lex_state = 244, .external_lex_state = 2},
  [9465] = {.lex_state = 7, .external_lex_state = 2},
  [9466] = {.lex_state = 7, .external_lex_state = 2},
  [9467] = {.lex_state = 244, .external_lex_state = 2},
  [9468] = {.lex_state = 244, .external_lex_state = 2},
  [9469] = {.lex_state = 244, .external_lex_state = 2},
  [9470] = {.lex_state = 7, .external_lex_state = 2},
  [9471] = {.lex_state = 244, .external_lex_state = 2},
  [9472] = {.lex_state = 244, .external_lex_state = 2},
  [9473] = {.lex_state = 7, .external_lex_state = 2},
  [9474] = {.lex_state = 244, .external_lex_state = 2},
  [9475] = {.lex_state = 7, .external_lex_state = 2},
  [9476] = {.lex_state = 453, .external_lex_state = 2},
  [9477] = {.lex_state = 7, .external_lex_state = 2},
  [9478] = {.lex_state = 437, .external_lex_state = 2},
  [9479] = {.lex_state = 7, .external_lex_state = 2},
  [9480] = {.lex_state = 445, .external_lex_state = 2},
  [9481] = {.lex_state = 437, .external_lex_state = 2},
  [9482] = {.lex_state = 7, .external_lex_state = 2},
  [9483] = {.lex_state = 244, .external_lex_state = 2},
  [9484] = {.lex_state = 234, .external_lex_state = 2},
  [9485] = {.lex_state = 234, .external_lex_state = 2},
  [9486] = {.lex_state = 233, .external_lex_state = 2},
  [9487] = {.lex_state = 449, .external_lex_state = 2},
  [9488] = {.lex_state = 7, .external_lex_state = 2},
  [9489] = {.lex_state = 7, .external_lex_state = 2},
  [9490] = {.lex_state = 7, .external_lex_state = 2},
  [9491] = {.lex_state = 24, .external_lex_state = 3},
  [9492] = {.lex_state = 437, .external_lex_state = 2},
  [9493] = {.lex_state = 234, .external_lex_state = 2},
  [9494] = {.lex_state = 7, .external_lex_state = 2},
  [9495] = {.lex_state = 7, .external_lex_state = 2},
  [9496] = {.lex_state = 449, .external_lex_state = 2},
  [9497] = {.lex_state = 7, .external_lex_state = 2},
  [9498] = {.lex_state = 7, .external_lex_state = 2},
  [9499] = {.lex_state = 7, .external_lex_state = 2},
  [9500] = {.lex_state = 7, .external_lex_state = 2},
  [9501] = {.lex_state = 7, .external_lex_state = 2},
  [9502] = {.lex_state = 7, .external_lex_state = 2},
  [9503] = {.lex_state = 190, .external_lex_state = 3},
  [9504] = {.lex_state = 190, .external_lex_state = 3},
  [9505] = {.lex_state = 7, .external_lex_state = 2},
  [9506] = {.lex_state = 7, .external_lex_state = 2},
  [9507] = {.lex_state = 7, .external_lex_state = 2},
  [9508] = {.lex_state = 7, .external_lex_state = 2},
  [9509] = {.lex_state = 7, .external_lex_state = 2},
  [9510] = {.lex_state = 234, .external_lex_state = 2},
  [9511] = {.lex_state = 7, .external_lex_state = 2},
  [9512] = {.lex_state = 7, .external_lex_state = 2},
  [9513] = {.lex_state = 7, .external_lex_state = 2},
  [9514] = {.lex_state = 7, .external_lex_state = 2},
  [9515] = {.lex_state = 7, .external_lex_state = 2},
  [9516] = {.lex_state = 7, .external_lex_state = 2},
  [9517] = {.lex_state = 7, .external_lex_state = 2},
  [9518] = {.lex_state = 190, .external_lex_state = 3},
  [9519] = {.lex_state = 437, .external_lex_state = 2},
  [9520] = {.lex_state = 7, .external_lex_state = 2},
  [9521] = {.lex_state = 7, .external_lex_state = 2},
  [9522] = {.lex_state = 7, .external_lex_state = 2},
  [9523] = {.lex_state = 234, .external_lex_state = 2},
  [9524] = {.lex_state = 234, .external_lex_state = 2},
  [9525] = {.lex_state = 7, .external_lex_state = 2},
  [9526] = {.lex_state = 7, .external_lex_state = 2},
  [9527] = {.lex_state = 7, .external_lex_state = 2},
  [9528] = {.lex_state = 7, .external_lex_state = 2},
  [9529] = {.lex_state = 234, .external_lex_state = 2},
  [9530] = {.lex_state = 7, .external_lex_state = 2},
  [9531] = {.lex_state = 7, .external_lex_state = 2},
  [9532] = {.lex_state = 451, .external_lex_state = 2},
  [9533] = {.lex_state = 7, .external_lex_state = 2},
  [9534] = {.lex_state = 7, .external_lex_state = 2},
  [9535] = {.lex_state = 7, .external_lex_state = 2},
  [9536] = {.lex_state = 7, .external_lex_state = 2},
  [9537] = {.lex_state = 7, .external_lex_state = 2},
  [9538] = {.lex_state = 190, .external_lex_state = 3},
  [9539] = {.lex_state = 24, .external_lex_state = 3},
  [9540] = {.lex_state = 451, .external_lex_state = 2},
  [9541] = {.lex_state = 7, .external_lex_state = 2},
  [9542] = {.lex_state = 7, .external_lex_state = 2},
  [9543] = {.lex_state = 24, .external_lex_state = 3},
  [9544] = {.lex_state = 7, .external_lex_state = 2},
  [9545] = {.lex_state = 7, .external_lex_state = 2},
  [9546] = {.lex_state = 7, .external_lex_state = 2},
  [9547] = {.lex_state = 7, .external_lex_state = 2},
  [9548] = {.lex_state = 7, .external_lex_state = 2},
  [9549] = {.lex_state = 7, .external_lex_state = 2},
  [9550] = {.lex_state = 234, .external_lex_state = 2},
  [9551] = {.lex_state = 7, .external_lex_state = 2},
  [9552] = {.lex_state = 233, .external_lex_state = 2},
  [9553] = {.lex_state = 7, .external_lex_state = 2},
  [9554] = {.lex_state = 7, .external_lex_state = 2},
  [9555] = {.lex_state = 7, .external_lex_state = 2},
  [9556] = {.lex_state = 7, .external_lex_state = 2},
  [9557] = {.lex_state = 453, .external_lex_state = 2},
  [9558] = {.lex_state = 7, .external_lex_state = 2},
  [9559] = {.lex_state = 7, .external_lex_state = 2},
  [9560] = {.lex_state = 7, .external_lex_state = 2},
  [9561] = {.lex_state = 7, .external_lex_state = 2},
  [9562] = {.lex_state = 7, .external_lex_state = 2},
  [9563] = {.lex_state = 7, .external_lex_state = 2},
  [9564] = {.lex_state = 7, .external_lex_state = 2},
  [9565] = {.lex_state = 233, .external_lex_state = 2},
  [9566] = {.lex_state = 24, .external_lex_state = 3},
  [9567] = {.lex_state = 7, .external_lex_state = 2},
  [9568] = {.lex_state = 7, .external_lex_state = 2},
  [9569] = {.lex_state = 7, .external_lex_state = 2},
  [9570] = {.lex_state = 449, .external_lex_state = 2},
  [9571] = {.lex_state = 7, .external_lex_state = 2},
  [9572] = {.lex_state = 233, .external_lex_state = 2},
  [9573] = {.lex_state = 7, .external_lex_state = 2},
  [9574] = {.lex_state = 7, .external_lex_state = 2},
  [9575] = {.lex_state = 7, .external_lex_state = 2},
  [9576] = {.lex_state = 7, .external_lex_state = 2},
  [9577] = {.lex_state = 7, .external_lex_state = 2},
  [9578] = {.lex_state = 24, .external_lex_state = 3},
  [9579] = {.lex_state = 447, .external_lex_state = 2},
  [9580] = {.lex_state = 24, .external_lex_state = 3},
  [9581] = {.lex_state = 7, .external_lex_state = 2},
  [9582] = {.lex_state = 7, .external_lex_state = 2},
  [9583] = {.lex_state = 24, .external_lex_state = 3},
  [9584] = {.lex_state = 7, .external_lex_state = 2},
  [9585] = {.lex_state = 24, .external_lex_state = 3},
  [9586] = {.lex_state = 7, .external_lex_state = 2},
  [9587] = {.lex_state = 24, .external_lex_state = 3},
  [9588] = {.lex_state = 7, .external_lex_state = 2},
  [9589] = {.lex_state = 7, .external_lex_state = 2},
  [9590] = {.lex_state = 7, .external_lex_state = 2},
  [9591] = {.lex_state = 7, .external_lex_state = 2},
  [9592] = {.lex_state = 7, .external_lex_state = 2},
  [9593] = {.lex_state = 234, .external_lex_state = 2},
  [9594] = {.lex_state = 24, .external_lex_state = 3},
  [9595] = {.lex_state = 7, .external_lex_state = 2},
  [9596] = {.lex_state = 7, .external_lex_state = 2},
  [9597] = {.lex_state = 24, .external_lex_state = 3},
  [9598] = {.lex_state = 7, .external_lex_state = 2},
  [9599] = {.lex_state = 7, .external_lex_state = 2},
  [9600] = {.lex_state = 7, .external_lex_state = 2},
  [9601] = {.lex_state = 7, .external_lex_state = 2},
  [9602] = {.lex_state = 437, .external_lex_state = 2},
  [9603] = {.lex_state = 7, .external_lex_state = 2},
  [9604] = {.lex_state = 7, .external_lex_state = 2},
  [9605] = {.lex_state = 7, .external_lex_state = 2},
  [9606] = {.lex_state = 7, .external_lex_state = 2},
  [9607] = {.lex_state = 7, .external_lex_state = 2},
  [9608] = {.lex_state = 24, .external_lex_state = 3},
  [9609] = {.lex_state = 24, .external_lex_state = 3},
  [9610] = {.lex_state = 24, .external_lex_state = 3},
  [9611] = {.lex_state = 24, .external_lex_state = 3},
  [9612] = {.lex_state = 7, .external_lex_state = 2},
  [9613] = {.lex_state = 7, .external_lex_state = 2},
  [9614] = {.lex_state = 7, .external_lex_state = 2},
  [9615] = {.lex_state = 7, .external_lex_state = 2},
  [9616] = {.lex_state = 449, .external_lex_state = 2},
  [9617] = {.lex_state = 7, .external_lex_state = 2},
  [9618] = {.lex_state = 7, .external_lex_state = 2},
  [9619] = {.lex_state = 444, .external_lex_state = 2},
  [9620] = {.lex_state = 7, .external_lex_state = 2},
  [9621] = {.lex_state = 7, .external_lex_state = 2},
  [9622] = {.lex_state = 7, .external_lex_state = 2},
  [9623] = {.lex_state = 24, .external_lex_state = 3},
  [9624] = {.lex_state = 445, .external_lex_state = 2},
  [9625] = {.lex_state = 437, .external_lex_state = 2},
  [9626] = {.lex_state = 7, .external_lex_state = 2},
  [9627] = {.lex_state = 7, .external_lex_state = 2},
  [9628] = {.lex_state = 243, .external_lex_state = 2},
  [9629] = {.lex_state = 243, .external_lex_state = 2},
  [9630] = {.lex_state = 7, .external_lex_state = 2},
  [9631] = {.lex_state = 7, .external_lex_state = 2},
  [9632] = {.lex_state = 7, .external_lex_state = 2},
  [9633] = {.lex_state = 7, .external_lex_state = 2},
  [9634] = {.lex_state = 7, .external_lex_state = 2},
  [9635] = {.lex_state = 7, .external_lex_state = 2},
  [9636] = {.lex_state = 24, .external_lex_state = 3},
  [9637] = {.lex_state = 24, .external_lex_state = 3},
  [9638] = {.lex_state = 7, .external_lex_state = 2},
  [9639] = {.lex_state = 24, .external_lex_state = 3},
  [9640] = {.lex_state = 24, .external_lex_state = 3},
  [9641] = {.lex_state = 7, .external_lex_state = 2},
  [9642] = {.lex_state = 24, .external_lex_state = 3},
  [9643] = {.lex_state = 244, .external_lex_state = 2},
  [9644] = {.lex_state = 244, .external_lex_state = 2},
  [9645] = {.lex_state = 7, .external_lex_state = 2},
  [9646] = {.lex_state = 24, .external_lex_state = 3},
  [9647] = {.lex_state = 24, .external_lex_state = 3},
  [9648] = {.lex_state = 24, .external_lex_state = 3},
  [9649] = {.lex_state = 24, .external_lex_state = 3},
  [9650] = {.lex_state = 24, .external_lex_state = 3},
  [9651] = {.lex_state = 24, .external_lex_state = 3},
  [9652] = {.lex_state = 24, .external_lex_state = 3},
  [9653] = {.lex_state = 233, .external_lex_state = 2},
  [9654] = {.lex_state = 7, .external_lex_state = 2},
  [9655] = {.lex_state = 7, .external_lex_state = 2},
  [9656] = {.lex_state = 7, .external_lex_state = 2},
  [9657] = {.lex_state = 7, .external_lex_state = 2},
  [9658] = {.lex_state = 24, .external_lex_state = 3},
  [9659] = {.lex_state = 24, .external_lex_state = 3},
  [9660] = {.lex_state = 24, .external_lex_state = 3},
  [9661] = {.lex_state = 7, .external_lex_state = 2},
  [9662] = {.lex_state = 24, .external_lex_state = 3},
  [9663] = {.lex_state = 7, .external_lex_state = 2},
  [9664] = {.lex_state = 24, .external_lex_state = 3},
  [9665] = {.lex_state = 24, .external_lex_state = 3},
  [9666] = {.lex_state = 24, .external_lex_state = 3},
  [9667] = {.lex_state = 24, .external_lex_state = 3},
  [9668] = {.lex_state = 24, .external_lex_state = 3},
  [9669] = {.lex_state = 24, .external_lex_state = 3},
  [9670] = {.lex_state = 24, .external_lex_state = 3},
  [9671] = {.lex_state = 7, .external_lex_state = 2},
  [9672] = {.lex_state = 24, .external_lex_state = 3},
  [9673] = {.lex_state = 24, .external_lex_state = 3},
  [9674] = {.lex_state = 24, .external_lex_state = 3},
  [9675] = {.lex_state = 24, .external_lex_state = 3},
  [9676] = {.lex_state = 24, .external_lex_state = 3},
  [9677] = {.lex_state = 24, .external_lex_state = 3},
  [9678] = {.lex_state = 24, .external_lex_state = 3},
  [9679] = {.lex_state = 7, .external_lex_state = 2},
  [9680] = {.lex_state = 24, .external_lex_state = 3},
  [9681] = {.lex_state = 7, .external_lex_state = 2},
  [9682] = {.lex_state = 24, .external_lex_state = 3},
  [9683] = {.lex_state = 24, .external_lex_state = 3},
  [9684] = {.lex_state = 24, .external_lex_state = 3},
  [9685] = {.lex_state = 24, .external_lex_state = 3},
  [9686] = {.lex_state = 24, .external_lex_state = 3},
  [9687] = {.lex_state = 24, .external_lex_state = 3},
  [9688] = {.lex_state = 24, .external_lex_state = 3},
  [9689] = {.lex_state = 7, .external_lex_state = 2},
  [9690] = {.lex_state = 7, .external_lex_state = 2},
  [9691] = {.lex_state = 24, .external_lex_state = 3},
  [9692] = {.lex_state = 24, .external_lex_state = 3},
  [9693] = {.lex_state = 24, .external_lex_state = 3},
  [9694] = {.lex_state = 24, .external_lex_state = 3},
  [9695] = {.lex_state = 24, .external_lex_state = 3},
  [9696] = {.lex_state = 24, .external_lex_state = 3},
  [9697] = {.lex_state = 24, .external_lex_state = 3},
  [9698] = {.lex_state = 24, .external_lex_state = 3},
  [9699] = {.lex_state = 24, .external_lex_state = 3},
  [9700] = {.lex_state = 7, .external_lex_state = 2},
  [9701] = {.lex_state = 7, .external_lex_state = 2},
  [9702] = {.lex_state = 24, .external_lex_state = 3},
  [9703] = {.lex_state = 24, .external_lex_state = 3},
  [9704] = {.lex_state = 24, .external_lex_state = 3},
  [9705] = {.lex_state = 24, .external_lex_state = 3},
  [9706] = {.lex_state = 7, .external_lex_state = 2},
  [9707] = {.lex_state = 7, .external_lex_state = 2},
  [9708] = {.lex_state = 7, .external_lex_state = 2},
  [9709] = {.lex_state = 24, .external_lex_state = 3},
  [9710] = {.lex_state = 7, .external_lex_state = 2},
  [9711] = {.lex_state = 7, .external_lex_state = 2},
  [9712] = {.lex_state = 7, .external_lex_state = 2},
  [9713] = {.lex_state = 14, .external_lex_state = 2},
  [9714] = {.lex_state = 14, .external_lex_state = 2},
  [9715] = {.lex_state = 14, .external_lex_state = 2},
  [9716] = {.lex_state = 14, .external_lex_state = 2},
  [9717] = {.lex_state = 14, .external_lex_state = 2},
  [9718] = {.lex_state = 7, .external_lex_state = 2},
  [9719] = {.lex_state = 7, .external_lex_state = 2},
  [9720] = {.lex_state = 7, .external_lex_state = 2},
  [9721] = {.lex_state = 7, .external_lex_state = 2},
  [9722] = {.lex_state = 7, .external_lex_state = 2},
  [9723] = {.lex_state = 233, .external_lex_state = 2},
  [9724] = {.lex_state = 181, .external_lex_state = 2},
  [9725] = {.lex_state = 234, .external_lex_state = 2},
  [9726] = {.lex_state = 181, .external_lex_state = 2},
  [9727] = {.lex_state = 453, .external_lex_state = 2},
  [9728] = {.lex_state = 233, .external_lex_state = 2},
  [9729] = {.lex_state = 453, .external_lex_state = 2},
  [9730] = {.lex_state = 233, .external_lex_state = 2},
  [9731] = {.lex_state = 218, .external_lex_state = 2},
  [9732] = {.lex_state = 7, .external_lex_state = 2},
  [9733] = {.lex_state = 7, .external_lex_state = 2},
  [9734] = {.lex_state = 445, .external_lex_state = 2},
  [9735] = {.lex_state = 7, .external_lex_state = 2},
  [9736] = {.lex_state = 234, .external_lex_state = 2},
  [9737] = {.lex_state = 180, .external_lex_state = 2},
  [9738] = {.lex_state = 453, .external_lex_state = 2},
  [9739] = {.lex_state = 233, .external_lex_state = 2},
  [9740] = {.lex_state = 453, .external_lex_state = 2},
  [9741] = {.lex_state = 453, .external_lex_state = 2},
  [9742] = {.lex_state = 234, .external_lex_state = 2},
  [9743] = {.lex_state = 180, .external_lex_state = 2},
  [9744] = {.lex_state = 453, .external_lex_state = 2},
  [9745] = {.lex_state = 181, .external_lex_state = 2},
  [9746] = {.lex_state = 445, .external_lex_state = 2},
  [9747] = {.lex_state = 445, .external_lex_state = 2},
  [9748] = {.lex_state = 233, .external_lex_state = 2},
  [9749] = {.lex_state = 7, .external_lex_state = 2},
  [9750] = {.lex_state = 451, .external_lex_state = 2},
  [9751] = {.lex_state = 451, .external_lex_state = 2},
  [9752] = {.lex_state = 445, .external_lex_state = 2},
  [9753] = {.lex_state = 453, .external_lex_state = 2},
  [9754] = {.lex_state = 453, .external_lex_state = 2},
  [9755] = {.lex_state = 453, .external_lex_state = 2},
  [9756] = {.lex_state = 453, .external_lex_state = 2},
  [9757] = {.lex_state = 234, .external_lex_state = 2},
  [9758] = {.lex_state = 7, .external_lex_state = 2},
  [9759] = {.lex_state = 7, .external_lex_state = 2},
  [9760] = {.lex_state = 453, .external_lex_state = 2},
  [9761] = {.lex_state = 7, .external_lex_state = 2},
  [9762] = {.lex_state = 453, .external_lex_state = 2},
  [9763] = {.lex_state = 234, .external_lex_state = 2},
  [9764] = {.lex_state = 233, .external_lex_state = 2},
  [9765] = {.lex_state = 234, .external_lex_state = 2},
  [9766] = {.lex_state = 234, .external_lex_state = 2},
  [9767] = {.lex_state = 234, .external_lex_state = 2},
  [9768] = {.lex_state = 7, .external_lex_state = 2},
  [9769] = {.lex_state = 445, .external_lex_state = 2},
  [9770] = {.lex_state = 13, .external_lex_state = 2},
  [9771] = {.lex_state = 13, .external_lex_state = 2},
  [9772] = {.lex_state = 451, .external_lex_state = 2},
  [9773] = {.lex_state = 445, .external_lex_state = 2},
  [9774] = {.lex_state = 451, .external_lex_state = 2},
  [9775] = {.lex_state = 234, .external_lex_state = 2},
  [9776] = {.lex_state = 233, .external_lex_state = 2},
  [9777] = {.lex_state = 7, .external_lex_state = 2},
  [9778] = {.lex_state = 234, .external_lex_state = 2},
  [9779] = {.lex_state = 453, .external_lex_state = 2},
  [9780] = {.lex_state = 445, .external_lex_state = 2},
  [9781] = {.lex_state = 7, .external_lex_state = 2},
  [9782] = {.lex_state = 453, .external_lex_state = 2},
  [9783] = {.lex_state = 233, .external_lex_state = 2},
  [9784] = {.lex_state = 7, .external_lex_state = 2},
  [9785] = {.lex_state = 7, .external_lex_state = 2},
  [9786] = {.lex_state = 7, .external_lex_state = 2},
  [9787] = {.lex_state = 7, .external_lex_state = 2},
  [9788] = {.lex_state = 451, .external_lex_state = 2},
  [9789] = {.lex_state = 234, .external_lex_state = 2},
  [9790] = {.lex_state = 453, .external_lex_state = 2},
  [9791] = {.lex_state = 233, .external_lex_state = 2},
  [9792] = {.lex_state = 7, .external_lex_state = 2},
  [9793] = {.lex_state = 451, .external_lex_state = 2},
  [9794] = {.lex_state = 234, .external_lex_state = 2},
  [9795] = {.lex_state = 229, .external_lex_state = 2},
  [9796] = {.lex_state = 218, .external_lex_state = 2},
  [9797] = {.lex_state = 13, .external_lex_state = 2},
  [9798] = {.lex_state = 234, .external_lex_state = 2},
  [9799] = {.lex_state = 9, .external_lex_state = 2},
  [9800] = {.lex_state = 234, .external_lex_state = 2},
  [9801] = {.lex_state = 445, .external_lex_state = 2},
  [9802] = {.lex_state = 445, .external_lex_state = 2},
  [9803] = {.lex_state = 13, .external_lex_state = 2},
  [9804] = {.lex_state = 180, .external_lex_state = 2},
  [9805] = {.lex_state = 180, .external_lex_state = 2},
  [9806] = {.lex_state = 233, .external_lex_state = 2},
  [9807] = {.lex_state = 453, .external_lex_state = 2},
  [9808] = {.lex_state = 444, .external_lex_state = 2},
  [9809] = {.lex_state = 453, .external_lex_state = 2},
  [9810] = {.lex_state = 453, .external_lex_state = 2},
  [9811] = {.lex_state = 7, .external_lex_state = 2},
  [9812] = {.lex_state = 7, .external_lex_state = 2},
  [9813] = {.lex_state = 180, .external_lex_state = 2},
  [9814] = {.lex_state = 234, .external_lex_state = 2},
  [9815] = {.lex_state = 7, .external_lex_state = 2},
  [9816] = {.lex_state = 445, .external_lex_state = 2},
  [9817] = {.lex_state = 233, .external_lex_state = 2},
  [9818] = {.lex_state = 233, .external_lex_state = 2},
  [9819] = {.lex_state = 453, .external_lex_state = 2},
  [9820] = {.lex_state = 233, .external_lex_state = 2},
  [9821] = {.lex_state = 453, .external_lex_state = 2},
  [9822] = {.lex_state = 7, .external_lex_state = 2},
  [9823] = {.lex_state = 234, .external_lex_state = 2},
  [9824] = {.lex_state = 445, .external_lex_state = 2},
  [9825] = {.lex_state = 445, .external_lex_state = 2},
  [9826] = {.lex_state = 7, .external_lex_state = 2},
  [9827] = {.lex_state = 234, .external_lex_state = 2},
  [9828] = {.lex_state = 453, .external_lex_state = 2},
  [9829] = {.lex_state = 7, .external_lex_state = 2},
  [9830] = {.lex_state = 7, .external_lex_state = 2},
  [9831] = {.lex_state = 7, .external_lex_state = 2},
  [9832] = {.lex_state = 451, .external_lex_state = 2},
  [9833] = {.lex_state = 7, .external_lex_state = 2},
  [9834] = {.lex_state = 7, .external_lex_state = 2},
  [9835] = {.lex_state = 7, .external_lex_state = 2},
  [9836] = {.lex_state = 453, .external_lex_state = 2},
  [9837] = {.lex_state = 233, .external_lex_state = 2},
  [9838] = {.lex_state = 7, .external_lex_state = 2},
  [9839] = {.lex_state = 7, .external_lex_state = 2},
  [9840] = {.lex_state = 233, .external_lex_state = 2},
  [9841] = {.lex_state = 233, .external_lex_state = 2},
  [9842] = {.lex_state = 7, .external_lex_state = 2},
  [9843] = {.lex_state = 233, .external_lex_state = 2},
  [9844] = {.lex_state = 233, .external_lex_state = 2},
  [9845] = {.lex_state = 234, .external_lex_state = 2},
  [9846] = {.lex_state = 233, .external_lex_state = 2},
  [9847] = {.lex_state = 234, .external_lex_state = 2},
  [9848] = {.lex_state = 13, .external_lex_state = 2},
  [9849] = {.lex_state = 7, .external_lex_state = 2},
  [9850] = {.lex_state = 234, .external_lex_state = 2},
  [9851] = {.lex_state = 13, .external_lex_state = 2},
  [9852] = {.lex_state = 13, .external_lex_state = 2},
  [9853] = {.lex_state = 13, .external_lex_state = 2},
  [9854] = {.lex_state = 13, .external_lex_state = 2},
  [9855] = {.lex_state = 13, .external_lex_state = 2},
  [9856] = {.lex_state = 13, .external_lex_state = 2},
  [9857] = {.lex_state = 13, .external_lex_state = 2},
  [9858] = {.lex_state = 13, .external_lex_state = 2},
  [9859] = {.lex_state = 13, .external_lex_state = 2},
  [9860] = {.lex_state = 7, .external_lex_state = 2},
  [9861] = {.lex_state = 13, .external_lex_state = 2},
  [9862] = {.lex_state = 7, .external_lex_state = 2},
  [9863] = {.lex_state = 13, .external_lex_state = 2},
  [9864] = {.lex_state = 13, .external_lex_state = 2},
  [9865] = {.lex_state = 233, .external_lex_state = 2},
  [9866] = {.lex_state = 13, .external_lex_state = 2},
  [9867] = {.lex_state = 7, .external_lex_state = 2},
  [9868] = {.lex_state = 233, .external_lex_state = 2},
  [9869] = {.lex_state = 7, .external_lex_state = 2},
  [9870] = {.lex_state = 233, .external_lex_state = 2},
  [9871] = {.lex_state = 445, .external_lex_state = 2},
  [9872] = {.lex_state = 234, .external_lex_state = 2},
  [9873] = {.lex_state = 218, .external_lex_state = 2},
  [9874] = {.lex_state = 234, .external_lex_state = 2},
  [9875] = {.lex_state = 234, .external_lex_state = 2},
  [9876] = {.lex_state = 234, .external_lex_state = 2},
  [9877] = {.lex_state = 234, .external_lex_state = 2},
  [9878] = {.lex_state = 234, .external_lex_state = 2},
  [9879] = {.lex_state = 234, .external_lex_state = 2},
  [9880] = {.lex_state = 13, .external_lex_state = 2},
  [9881] = {.lex_state = 13, .external_lex_state = 2},
  [9882] = {.lex_state = 445, .external_lex_state = 2},
  [9883] = {.lex_state = 233, .external_lex_state = 2},
  [9884] = {.lex_state = 7, .external_lex_state = 2},
  [9885] = {.lex_state = 234, .external_lex_state = 2},
  [9886] = {.lex_state = 233, .external_lex_state = 2},
  [9887] = {.lex_state = 234, .external_lex_state = 2},
  [9888] = {.lex_state = 445, .external_lex_state = 2},
  [9889] = {.lex_state = 233, .external_lex_state = 2},
  [9890] = {.lex_state = 234, .external_lex_state = 2},
  [9891] = {.lex_state = 233, .external_lex_state = 2},
  [9892] = {.lex_state = 453, .external_lex_state = 2},
  [9893] = {.lex_state = 234, .external_lex_state = 2},
  [9894] = {.lex_state = 453, .external_lex_state = 2},
  [9895] = {.lex_state = 453, .external_lex_state = 2},
  [9896] = {.lex_state = 7, .external_lex_state = 2},
  [9897] = {.lex_state = 453, .external_lex_state = 2},
  [9898] = {.lex_state = 451, .external_lex_state = 2},
  [9899] = {.lex_state = 453, .external_lex_state = 2},
  [9900] = {.lex_state = 7, .external_lex_state = 2},
  [9901] = {.lex_state = 7, .external_lex_state = 2},
  [9902] = {.lex_state = 181, .external_lex_state = 2},
  [9903] = {.lex_state = 234, .external_lex_state = 2},
  [9904] = {.lex_state = 233, .external_lex_state = 2},
  [9905] = {.lex_state = 234, .external_lex_state = 2},
  [9906] = {.lex_state = 233, .external_lex_state = 2},
  [9907] = {.lex_state = 233, .external_lex_state = 2},
  [9908] = {.lex_state = 233, .external_lex_state = 2},
  [9909] = {.lex_state = 234, .external_lex_state = 2},
  [9910] = {.lex_state = 181, .external_lex_state = 2},
  [9911] = {.lex_state = 7, .external_lex_state = 2},
  [9912] = {.lex_state = 233, .external_lex_state = 2},
  [9913] = {.lex_state = 13, .external_lex_state = 2},
  [9914] = {.lex_state = 218, .external_lex_state = 2},
  [9915] = {.lex_state = 453, .external_lex_state = 2},
  [9916] = {.lex_state = 180, .external_lex_state = 2},
  [9917] = {.lex_state = 7, .external_lex_state = 2},
  [9918] = {.lex_state = 234, .external_lex_state = 2},
  [9919] = {.lex_state = 445, .external_lex_state = 2},
  [9920] = {.lex_state = 453, .external_lex_state = 2},
  [9921] = {.lex_state = 13, .external_lex_state = 2},
  [9922] = {.lex_state = 13, .external_lex_state = 2},
  [9923] = {.lex_state = 13, .external_lex_state = 2},
  [9924] = {.lex_state = 13, .external_lex_state = 2},
  [9925] = {.lex_state = 13, .external_lex_state = 2},
  [9926] = {.lex_state = 229, .external_lex_state = 2},
  [9927] = {.lex_state = 453, .external_lex_state = 2},
  [9928] = {.lex_state = 7, .external_lex_state = 2},
  [9929] = {.lex_state = 7, .external_lex_state = 2},
  [9930] = {.lex_state = 7, .external_lex_state = 2},
  [9931] = {.lex_state = 7, .external_lex_state = 2},
  [9932] = {.lex_state = 453, .external_lex_state = 2},
  [9933] = {.lex_state = 233, .external_lex_state = 2},
  [9934] = {.lex_state = 233, .external_lex_state = 2},
  [9935] = {.lex_state = 233, .external_lex_state = 2},
  [9936] = {.lex_state = 233, .external_lex_state = 2},
  [9937] = {.lex_state = 451, .external_lex_state = 2},
  [9938] = {.lex_state = 453, .external_lex_state = 2},
  [9939] = {.lex_state = 7, .external_lex_state = 2},
  [9940] = {.lex_state = 444, .external_lex_state = 2},
  [9941] = {.lex_state = 445, .external_lex_state = 2},
  [9942] = {.lex_state = 181, .external_lex_state = 2},
  [9943] = {.lex_state = 218, .external_lex_state = 2},
  [9944] = {.lex_state = 15, .external_lex_state = 2},
  [9945] = {.lex_state = 444, .external_lex_state = 2},
  [9946] = {.lex_state = 437, .external_lex_state = 2},
  [9947] = {.lex_state = 444, .external_lex_state = 2},
  [9948] = {.lex_state = 444, .external_lex_state = 2},
  [9949] = {.lex_state = 451, .external_lex_state = 2},
  [9950] = {.lex_state = 438, .external_lex_state = 2},
  [9951] = {.lex_state = 7, .external_lex_state = 2},
  [9952] = {.lex_state = 451, .external_lex_state = 2},
  [9953] = {.lex_state = 451, .external_lex_state = 2},
  [9954] = {.lex_state = 9, .external_lex_state = 2},
  [9955] = {.lex_state = 9, .external_lex_state = 2},
  [9956] = {.lex_state = 444, .external_lex_state = 2},
  [9957] = {.lex_state = 15, .external_lex_state = 2},
  [9958] = {.lex_state = 238, .external_lex_state = 2},
  [9959] = {.lex_state = 451, .external_lex_state = 2},
  [9960] = {.lex_state = 13, .external_lex_state = 2},
  [9961] = {.lex_state = 13, .external_lex_state = 2},
  [9962] = {.lex_state = 13, .external_lex_state = 2},
  [9963] = {.lex_state = 13, .external_lex_state = 2},
  [9964] = {.lex_state = 13, .external_lex_state = 2},
  [9965] = {.lex_state = 229, .external_lex_state = 2},
  [9966] = {.lex_state = 15, .external_lex_state = 2},
  [9967] = {.lex_state = 451, .external_lex_state = 2},
  [9968] = {.lex_state = 9, .external_lex_state = 2},
  [9969] = {.lex_state = 451, .external_lex_state = 2},
  [9970] = {.lex_state = 173, .external_lex_state = 3},
  [9971] = {.lex_state = 444, .external_lex_state = 2},
  [9972] = {.lex_state = 444, .external_lex_state = 2},
  [9973] = {.lex_state = 444, .external_lex_state = 2},
  [9974] = {.lex_state = 9, .external_lex_state = 2},
  [9975] = {.lex_state = 9, .external_lex_state = 2},
  [9976] = {.lex_state = 451, .external_lex_state = 2},
  [9977] = {.lex_state = 444, .external_lex_state = 2},
  [9978] = {.lex_state = 451, .external_lex_state = 2},
  [9979] = {.lex_state = 451, .external_lex_state = 2},
  [9980] = {.lex_state = 444, .external_lex_state = 2},
  [9981] = {.lex_state = 9, .external_lex_state = 2},
  [9982] = {.lex_state = 451, .external_lex_state = 2},
  [9983] = {.lex_state = 451, .external_lex_state = 2},
  [9984] = {.lex_state = 9, .external_lex_state = 2},
  [9985] = {.lex_state = 437, .external_lex_state = 2},
  [9986] = {.lex_state = 437, .external_lex_state = 2},
  [9987] = {.lex_state = 437, .external_lex_state = 2},
  [9988] = {.lex_state = 444, .external_lex_state = 2},
  [9989] = {.lex_state = 238, .external_lex_state = 2},
  [9990] = {.lex_state = 174, .external_lex_state = 3},
  [9991] = {.lex_state = 445, .external_lex_state = 2},
  [9992] = {.lex_state = 181, .external_lex_state = 2},
  [9993] = {.lex_state = 13, .external_lex_state = 2},
  [9994] = {.lex_state = 13, .external_lex_state = 2},
  [9995] = {.lex_state = 181, .external_lex_state = 2},
  [9996] = {.lex_state = 13, .external_lex_state = 2},
  [9997] = {.lex_state = 15, .external_lex_state = 2},
  [9998] = {.lex_state = 451, .external_lex_state = 2},
  [9999] = {.lex_state = 444, .external_lex_state = 2},
  [10000] = {.lex_state = 444, .external_lex_state = 2},
  [10001] = {.lex_state = 445, .external_lex_state = 2},
  [10002] = {.lex_state = 13, .external_lex_state = 2},
  [10003] = {.lex_state = 13, .external_lex_state = 2},
  [10004] = {.lex_state = 13, .external_lex_state = 2},
  [10005] = {.lex_state = 13, .external_lex_state = 2},
  [10006] = {.lex_state = 13, .external_lex_state = 2},
  [10007] = {.lex_state = 13, .external_lex_state = 2},
  [10008] = {.lex_state = 13, .external_lex_state = 2},
  [10009] = {.lex_state = 13, .external_lex_state = 2},
  [10010] = {.lex_state = 444, .external_lex_state = 2},
  [10011] = {.lex_state = 15, .external_lex_state = 2},
  [10012] = {.lex_state = 15, .external_lex_state = 2},
  [10013] = {.lex_state = 14, .external_lex_state = 2},
  [10014] = {.lex_state = 447, .external_lex_state = 2},
  [10015] = {.lex_state = 15, .external_lex_state = 2},
  [10016] = {.lex_state = 13, .external_lex_state = 2},
  [10017] = {.lex_state = 444, .external_lex_state = 2},
  [10018] = {.lex_state = 15, .external_lex_state = 2},
  [10019] = {.lex_state = 15, .external_lex_state = 2},
  [10020] = {.lex_state = 229, .external_lex_state = 2},
  [10021] = {.lex_state = 15, .external_lex_state = 2},
  [10022] = {.lex_state = 451, .external_lex_state = 2},
  [10023] = {.lex_state = 9, .external_lex_state = 2},
  [10024] = {.lex_state = 444, .external_lex_state = 2},
  [10025] = {.lex_state = 9, .external_lex_state = 2},
  [10026] = {.lex_state = 9, .external_lex_state = 2},
  [10027] = {.lex_state = 9, .external_lex_state = 2},
  [10028] = {.lex_state = 9, .external_lex_state = 2},
  [10029] = {.lex_state = 15, .external_lex_state = 2},
  [10030] = {.lex_state = 9, .external_lex_state = 2},
  [10031] = {.lex_state = 15, .external_lex_state = 2},
  [10032] = {.lex_state = 52, .external_lex_state = 3},
  [10033] = {.lex_state = 9, .external_lex_state = 2},
  [10034] = {.lex_state = 15, .external_lex_state = 2},
  [10035] = {.lex_state = 15, .external_lex_state = 2},
  [10036] = {.lex_state = 9, .external_lex_state = 2},
  [10037] = {.lex_state = 444, .external_lex_state = 2},
  [10038] = {.lex_state = 445, .external_lex_state = 2},
  [10039] = {.lex_state = 240, .external_lex_state = 2},
  [10040] = {.lex_state = 445, .external_lex_state = 2},
  [10041] = {.lex_state = 15, .external_lex_state = 2},
  [10042] = {.lex_state = 9, .external_lex_state = 2},
  [10043] = {.lex_state = 15, .external_lex_state = 2},
  [10044] = {.lex_state = 9, .external_lex_state = 2},
  [10045] = {.lex_state = 234, .external_lex_state = 2},
  [10046] = {.lex_state = 445, .external_lex_state = 2},
  [10047] = {.lex_state = 445, .external_lex_state = 2},
  [10048] = {.lex_state = 15, .external_lex_state = 2},
  [10049] = {.lex_state = 445, .external_lex_state = 2},
  [10050] = {.lex_state = 438, .external_lex_state = 2},
  [10051] = {.lex_state = 9, .external_lex_state = 2},
  [10052] = {.lex_state = 9, .external_lex_state = 2},
  [10053] = {.lex_state = 444, .external_lex_state = 2},
  [10054] = {.lex_state = 15, .external_lex_state = 2},
  [10055] = {.lex_state = 15, .external_lex_state = 2},
  [10056] = {.lex_state = 15, .external_lex_state = 2},
  [10057] = {.lex_state = 438, .external_lex_state = 2},
  [10058] = {.lex_state = 445, .external_lex_state = 2},
  [10059] = {.lex_state = 233, .external_lex_state = 2},
  [10060] = {.lex_state = 9, .external_lex_state = 2},
  [10061] = {.lex_state = 444, .external_lex_state = 2},
  [10062] = {.lex_state = 15, .external_lex_state = 2},
  [10063] = {.lex_state = 15, .external_lex_state = 2},
  [10064] = {.lex_state = 15, .external_lex_state = 2},
  [10065] = {.lex_state = 15, .external_lex_state = 2},
  [10066] = {.lex_state = 9, .external_lex_state = 2},
  [10067] = {.lex_state = 9, .external_lex_state = 2},
  [10068] = {.lex_state = 451, .external_lex_state = 2},
  [10069] = {.lex_state = 451, .external_lex_state = 2},
  [10070] = {.lex_state = 444, .external_lex_state = 2},
  [10071] = {.lex_state = 451, .external_lex_state = 2},
  [10072] = {.lex_state = 445, .external_lex_state = 2},
  [10073] = {.lex_state = 15, .external_lex_state = 2},
  [10074] = {.lex_state = 15, .external_lex_state = 2},
  [10075] = {.lex_state = 229, .external_lex_state = 2},
  [10076] = {.lex_state = 15, .external_lex_state = 2},
  [10077] = {.lex_state = 15, .external_lex_state = 2},
  [10078] = {.lex_state = 15, .external_lex_state = 2},
  [10079] = {.lex_state = 15, .external_lex_state = 2},
  [10080] = {.lex_state = 229, .external_lex_state = 2},
  [10081] = {.lex_state = 445, .external_lex_state = 2},
  [10082] = {.lex_state = 445, .external_lex_state = 2},
  [10083] = {.lex_state = 451, .external_lex_state = 2},
  [10084] = {.lex_state = 451, .external_lex_state = 2},
  [10085] = {.lex_state = 9, .external_lex_state = 2},
  [10086] = {.lex_state = 9, .external_lex_state = 2},
  [10087] = {.lex_state = 15, .external_lex_state = 2},
  [10088] = {.lex_state = 444, .external_lex_state = 2},
  [10089] = {.lex_state = 13, .external_lex_state = 2},
  [10090] = {.lex_state = 13, .external_lex_state = 2},
  [10091] = {.lex_state = 437, .external_lex_state = 2},
  [10092] = {.lex_state = 437, .external_lex_state = 2},
  [10093] = {.lex_state = 15, .external_lex_state = 2},
  [10094] = {.lex_state = 9, .external_lex_state = 2},
  [10095] = {.lex_state = 9, .external_lex_state = 2},
  [10096] = {.lex_state = 220, .external_lex_state = 2},
  [10097] = {.lex_state = 9, .external_lex_state = 2},
  [10098] = {.lex_state = 15, .external_lex_state = 2},
  [10099] = {.lex_state = 15, .external_lex_state = 2},
  [10100] = {.lex_state = 15, .external_lex_state = 2},
  [10101] = {.lex_state = 451, .external_lex_state = 2},
  [10102] = {.lex_state = 14, .external_lex_state = 2},
  [10103] = {.lex_state = 445, .external_lex_state = 2},
  [10104] = {.lex_state = 14, .external_lex_state = 2},
  [10105] = {.lex_state = 14, .external_lex_state = 2},
  [10106] = {.lex_state = 9, .external_lex_state = 2},
  [10107] = {.lex_state = 14, .external_lex_state = 2},
  [10108] = {.lex_state = 14, .external_lex_state = 2},
  [10109] = {.lex_state = 14, .external_lex_state = 2},
  [10110] = {.lex_state = 15, .external_lex_state = 2},
  [10111] = {.lex_state = 9, .external_lex_state = 2},
  [10112] = {.lex_state = 15, .external_lex_state = 2},
  [10113] = {.lex_state = 15, .external_lex_state = 2},
  [10114] = {.lex_state = 14, .external_lex_state = 2},
  [10115] = {.lex_state = 14, .external_lex_state = 2},
  [10116] = {.lex_state = 14, .external_lex_state = 2},
  [10117] = {.lex_state = 14, .external_lex_state = 2},
  [10118] = {.lex_state = 14, .external_lex_state = 2},
  [10119] = {.lex_state = 14, .external_lex_state = 2},
  [10120] = {.lex_state = 14, .external_lex_state = 2},
  [10121] = {.lex_state = 14, .external_lex_state = 2},
  [10122] = {.lex_state = 14, .external_lex_state = 2},
  [10123] = {.lex_state = 451, .external_lex_state = 2},
  [10124] = {.lex_state = 9, .external_lex_state = 2},
  [10125] = {.lex_state = 9, .external_lex_state = 2},
  [10126] = {.lex_state = 15, .external_lex_state = 2},
  [10127] = {.lex_state = 15, .external_lex_state = 2},
  [10128] = {.lex_state = 15, .external_lex_state = 2},
  [10129] = {.lex_state = 15, .external_lex_state = 2},
  [10130] = {.lex_state = 451, .external_lex_state = 2},
  [10131] = {.lex_state = 9, .external_lex_state = 2},
  [10132] = {.lex_state = 14, .external_lex_state = 2},
  [10133] = {.lex_state = 9, .external_lex_state = 2},
  [10134] = {.lex_state = 9, .external_lex_state = 2},
  [10135] = {.lex_state = 15, .external_lex_state = 2},
  [10136] = {.lex_state = 15, .external_lex_state = 2},
  [10137] = {.lex_state = 15, .external_lex_state = 2},
  [10138] = {.lex_state = 444, .external_lex_state = 2},
  [10139] = {.lex_state = 15, .external_lex_state = 2},
  [10140] = {.lex_state = 444, .external_lex_state = 2},
  [10141] = {.lex_state = 9, .external_lex_state = 2},
  [10142] = {.lex_state = 9, .external_lex_state = 2},
  [10143] = {.lex_state = 229, .external_lex_state = 2},
  [10144] = {.lex_state = 15, .external_lex_state = 2},
  [10145] = {.lex_state = 15, .external_lex_state = 2},
  [10146] = {.lex_state = 445, .external_lex_state = 2},
  [10147] = {.lex_state = 451, .external_lex_state = 2},
  [10148] = {.lex_state = 9, .external_lex_state = 2},
  [10149] = {.lex_state = 9, .external_lex_state = 2},
  [10150] = {.lex_state = 444, .external_lex_state = 2},
  [10151] = {.lex_state = 444, .external_lex_state = 2},
  [10152] = {.lex_state = 9, .external_lex_state = 2},
  [10153] = {.lex_state = 9, .external_lex_state = 2},
  [10154] = {.lex_state = 9, .external_lex_state = 2},
  [10155] = {.lex_state = 9, .external_lex_state = 2},
  [10156] = {.lex_state = 9, .external_lex_state = 2},
  [10157] = {.lex_state = 451, .external_lex_state = 2},
  [10158] = {.lex_state = 9, .external_lex_state = 2},
  [10159] = {.lex_state = 15, .external_lex_state = 2},
  [10160] = {.lex_state = 9, .external_lex_state = 2},
  [10161] = {.lex_state = 9, .external_lex_state = 2},
  [10162] = {.lex_state = 9, .external_lex_state = 2},
  [10163] = {.lex_state = 444, .external_lex_state = 2},
  [10164] = {.lex_state = 445, .external_lex_state = 2},
  [10165] = {.lex_state = 445, .external_lex_state = 2},
  [10166] = {.lex_state = 9, .external_lex_state = 2},
  [10167] = {.lex_state = 15, .external_lex_state = 2},
  [10168] = {.lex_state = 451, .external_lex_state = 2},
  [10169] = {.lex_state = 15, .external_lex_state = 2},
  [10170] = {.lex_state = 9, .external_lex_state = 2},
  [10171] = {.lex_state = 15, .external_lex_state = 2},
  [10172] = {.lex_state = 180, .external_lex_state = 2},
  [10173] = {.lex_state = 444, .external_lex_state = 2},
  [10174] = {.lex_state = 451, .external_lex_state = 2},
  [10175] = {.lex_state = 9, .external_lex_state = 2},
  [10176] = {.lex_state = 444, .external_lex_state = 2},
  [10177] = {.lex_state = 445, .external_lex_state = 2},
  [10178] = {.lex_state = 9, .external_lex_state = 2},
  [10179] = {.lex_state = 9, .external_lex_state = 2},
  [10180] = {.lex_state = 9, .external_lex_state = 2},
  [10181] = {.lex_state = 221, .external_lex_state = 2},
  [10182] = {.lex_state = 9, .external_lex_state = 2},
  [10183] = {.lex_state = 9, .external_lex_state = 2},
  [10184] = {.lex_state = 15, .external_lex_state = 2},
  [10185] = {.lex_state = 15, .external_lex_state = 2},
  [10186] = {.lex_state = 15, .external_lex_state = 2},
  [10187] = {.lex_state = 15, .external_lex_state = 2},
  [10188] = {.lex_state = 15, .external_lex_state = 2},
  [10189] = {.lex_state = 9, .external_lex_state = 2},
  [10190] = {.lex_state = 9, .external_lex_state = 2},
  [10191] = {.lex_state = 9, .external_lex_state = 2},
  [10192] = {.lex_state = 9, .external_lex_state = 2},
  [10193] = {.lex_state = 9, .external_lex_state = 2},
  [10194] = {.lex_state = 15, .external_lex_state = 2},
  [10195] = {.lex_state = 15, .external_lex_state = 2},
  [10196] = {.lex_state = 9, .external_lex_state = 2},
  [10197] = {.lex_state = 229, .external_lex_state = 2},
  [10198] = {.lex_state = 9, .external_lex_state = 2},
  [10199] = {.lex_state = 444, .external_lex_state = 2},
  [10200] = {.lex_state = 9, .external_lex_state = 2},
  [10201] = {.lex_state = 9, .external_lex_state = 2},
  [10202] = {.lex_state = 9, .external_lex_state = 2},
  [10203] = {.lex_state = 9, .external_lex_state = 2},
  [10204] = {.lex_state = 15, .external_lex_state = 2},
  [10205] = {.lex_state = 9, .external_lex_state = 2},
  [10206] = {.lex_state = 9, .external_lex_state = 2},
  [10207] = {.lex_state = 9, .external_lex_state = 2},
  [10208] = {.lex_state = 229, .external_lex_state = 2},
  [10209] = {.lex_state = 229, .external_lex_state = 2},
  [10210] = {.lex_state = 9, .external_lex_state = 2},
  [10211] = {.lex_state = 9, .external_lex_state = 2},
  [10212] = {.lex_state = 9, .external_lex_state = 2},
  [10213] = {.lex_state = 9, .external_lex_state = 2},
  [10214] = {.lex_state = 9, .external_lex_state = 2},
  [10215] = {.lex_state = 15, .external_lex_state = 2},
  [10216] = {.lex_state = 15, .external_lex_state = 2},
  [10217] = {.lex_state = 15, .external_lex_state = 2},
  [10218] = {.lex_state = 15, .external_lex_state = 2},
  [10219] = {.lex_state = 15, .external_lex_state = 2},
  [10220] = {.lex_state = 9, .external_lex_state = 2},
  [10221] = {.lex_state = 9, .external_lex_state = 2},
  [10222] = {.lex_state = 9, .external_lex_state = 2},
  [10223] = {.lex_state = 9, .external_lex_state = 2},
  [10224] = {.lex_state = 14, .external_lex_state = 2},
  [10225] = {.lex_state = 9, .external_lex_state = 2},
  [10226] = {.lex_state = 9, .external_lex_state = 2},
  [10227] = {.lex_state = 15, .external_lex_state = 2},
  [10228] = {.lex_state = 14, .external_lex_state = 2},
  [10229] = {.lex_state = 444, .external_lex_state = 2},
  [10230] = {.lex_state = 9, .external_lex_state = 2},
  [10231] = {.lex_state = 15, .external_lex_state = 2},
  [10232] = {.lex_state = 15, .external_lex_state = 2},
  [10233] = {.lex_state = 15, .external_lex_state = 2},
  [10234] = {.lex_state = 15, .external_lex_state = 2},
  [10235] = {.lex_state = 445, .external_lex_state = 2},
  [10236] = {.lex_state = 13, .external_lex_state = 2},
  [10237] = {.lex_state = 15, .external_lex_state = 2},
  [10238] = {.lex_state = 15, .external_lex_state = 2},
  [10239] = {.lex_state = 445, .external_lex_state = 2},
  [10240] = {.lex_state = 9, .external_lex_state = 2},
  [10241] = {.lex_state = 437, .external_lex_state = 2},
  [10242] = {.lex_state = 9, .external_lex_state = 2},
  [10243] = {.lex_state = 9, .external_lex_state = 2},
  [10244] = {.lex_state = 9, .external_lex_state = 2},
  [10245] = {.lex_state = 444, .external_lex_state = 2},
  [10246] = {.lex_state = 9, .external_lex_state = 2},
  [10247] = {.lex_state = 15, .external_lex_state = 2},
  [10248] = {.lex_state = 15, .external_lex_state = 2},
  [10249] = {.lex_state = 9, .external_lex_state = 2},
  [10250] = {.lex_state = 451, .external_lex_state = 2},
  [10251] = {.lex_state = 451, .external_lex_state = 2},
  [10252] = {.lex_state = 9, .external_lex_state = 2},
  [10253] = {.lex_state = 445, .external_lex_state = 2},
  [10254] = {.lex_state = 180, .external_lex_state = 2},
  [10255] = {.lex_state = 9, .external_lex_state = 2},
  [10256] = {.lex_state = 9, .external_lex_state = 2},
  [10257] = {.lex_state = 9, .external_lex_state = 2},
  [10258] = {.lex_state = 9, .external_lex_state = 2},
  [10259] = {.lex_state = 9, .external_lex_state = 2},
  [10260] = {.lex_state = 9, .external_lex_state = 2},
  [10261] = {.lex_state = 451, .external_lex_state = 2},
  [10262] = {.lex_state = 9, .external_lex_state = 2},
  [10263] = {.lex_state = 451, .external_lex_state = 2},
  [10264] = {.lex_state = 451, .external_lex_state = 2},
  [10265] = {.lex_state = 9, .external_lex_state = 2},
  [10266] = {.lex_state = 240, .external_lex_state = 2},
  [10267] = {.lex_state = 9, .external_lex_state = 2},
  [10268] = {.lex_state = 9, .external_lex_state = 2},
  [10269] = {.lex_state = 9, .external_lex_state = 2},
  [10270] = {.lex_state = 14, .external_lex_state = 2},
  [10271] = {.lex_state = 9, .external_lex_state = 2},
  [10272] = {.lex_state = 15, .external_lex_state = 2},
  [10273] = {.lex_state = 9, .external_lex_state = 2},
  [10274] = {.lex_state = 451, .external_lex_state = 2},
  [10275] = {.lex_state = 438, .external_lex_state = 2},
  [10276] = {.lex_state = 9, .external_lex_state = 2},
  [10277] = {.lex_state = 15, .external_lex_state = 2},
  [10278] = {.lex_state = 9, .external_lex_state = 2},
  [10279] = {.lex_state = 15, .external_lex_state = 2},
  [10280] = {.lex_state = 451, .external_lex_state = 2},
  [10281] = {.lex_state = 15, .external_lex_state = 2},
  [10282] = {.lex_state = 438, .external_lex_state = 2},
  [10283] = {.lex_state = 15, .external_lex_state = 2},
  [10284] = {.lex_state = 229, .external_lex_state = 2},
  [10285] = {.lex_state = 9, .external_lex_state = 2},
  [10286] = {.lex_state = 15, .external_lex_state = 2},
  [10287] = {.lex_state = 15, .external_lex_state = 2},
  [10288] = {.lex_state = 15, .external_lex_state = 2},
  [10289] = {.lex_state = 451, .external_lex_state = 2},
  [10290] = {.lex_state = 15, .external_lex_state = 2},
  [10291] = {.lex_state = 15, .external_lex_state = 2},
  [10292] = {.lex_state = 15, .external_lex_state = 2},
  [10293] = {.lex_state = 13, .external_lex_state = 2},
  [10294] = {.lex_state = 451, .external_lex_state = 2},
  [10295] = {.lex_state = 438, .external_lex_state = 2},
  [10296] = {.lex_state = 15, .external_lex_state = 2},
  [10297] = {.lex_state = 444, .external_lex_state = 2},
  [10298] = {.lex_state = 13, .external_lex_state = 2},
  [10299] = {.lex_state = 15, .external_lex_state = 2},
  [10300] = {.lex_state = 14, .external_lex_state = 2},
  [10301] = {.lex_state = 15, .external_lex_state = 2},
  [10302] = {.lex_state = 19, .external_lex_state = 2},
  [10303] = {.lex_state = 437, .external_lex_state = 2},
  [10304] = {.lex_state = 451, .external_lex_state = 2},
  [10305] = {.lex_state = 15, .external_lex_state = 2},
  [10306] = {.lex_state = 444, .external_lex_state = 2},
  [10307] = {.lex_state = 15, .external_lex_state = 2},
  [10308] = {.lex_state = 9, .external_lex_state = 2},
  [10309] = {.lex_state = 7, .external_lex_state = 2},
  [10310] = {.lex_state = 233, .external_lex_state = 2},
  [10311] = {.lex_state = 7, .external_lex_state = 2},
  [10312] = {.lex_state = 181, .external_lex_state = 2},
  [10313] = {.lex_state = 14, .external_lex_state = 2},
  [10314] = {.lex_state = 233, .external_lex_state = 2},
  [10315] = {.lex_state = 234, .external_lex_state = 2},
  [10316] = {.lex_state = 7, .external_lex_state = 2},
  [10317] = {.lex_state = 7, .external_lex_state = 2},
  [10318] = {.lex_state = 229, .external_lex_state = 2},
  [10319] = {.lex_state = 7, .external_lex_state = 2},
  [10320] = {.lex_state = 13, .external_lex_state = 2},
  [10321] = {.lex_state = 229, .external_lex_state = 2},
  [10322] = {.lex_state = 7, .external_lex_state = 2},
  [10323] = {.lex_state = 229, .external_lex_state = 2},
  [10324] = {.lex_state = 241, .external_lex_state = 2},
  [10325] = {.lex_state = 229, .external_lex_state = 2},
  [10326] = {.lex_state = 24, .external_lex_state = 3},
  [10327] = {.lex_state = 229, .external_lex_state = 2},
  [10328] = {.lex_state = 229, .external_lex_state = 2},
  [10329] = {.lex_state = 229, .external_lex_state = 2},
  [10330] = {.lex_state = 14, .external_lex_state = 2},
  [10331] = {.lex_state = 14, .external_lex_state = 2},
  [10332] = {.lex_state = 229, .external_lex_state = 2},
  [10333] = {.lex_state = 437, .external_lex_state = 3},
  [10334] = {.lex_state = 241, .external_lex_state = 2},
  [10335] = {.lex_state = 229, .external_lex_state = 2},
  [10336] = {.lex_state = 7, .external_lex_state = 2},
  [10337] = {.lex_state = 241, .external_lex_state = 2},
  [10338] = {.lex_state = 222, .external_lex_state = 2},
  [10339] = {.lex_state = 225, .external_lex_state = 2},
  [10340] = {.lex_state = 229, .external_lex_state = 2},
  [10341] = {.lex_state = 7, .external_lex_state = 2},
  [10342] = {.lex_state = 7, .external_lex_state = 2},
  [10343] = {.lex_state = 7, .external_lex_state = 2},
  [10344] = {.lex_state = 14, .external_lex_state = 2},
  [10345] = {.lex_state = 239, .external_lex_state = 2},
  [10346] = {.lex_state = 7, .external_lex_state = 2},
  [10347] = {.lex_state = 7, .external_lex_state = 2},
  [10348] = {.lex_state = 7, .external_lex_state = 2},
  [10349] = {.lex_state = 14, .external_lex_state = 2},
  [10350] = {.lex_state = 7, .external_lex_state = 2},
  [10351] = {.lex_state = 7, .external_lex_state = 2},
  [10352] = {.lex_state = 229, .external_lex_state = 2},
  [10353] = {.lex_state = 7, .external_lex_state = 2},
  [10354] = {.lex_state = 223, .external_lex_state = 2},
  [10355] = {.lex_state = 7, .external_lex_state = 2},
  [10356] = {.lex_state = 233, .external_lex_state = 2},
  [10357] = {.lex_state = 7, .external_lex_state = 2},
  [10358] = {.lex_state = 7, .external_lex_state = 2},
  [10359] = {.lex_state = 7, .external_lex_state = 2},
  [10360] = {.lex_state = 229, .external_lex_state = 2},
  [10361] = {.lex_state = 7, .external_lex_state = 2},
  [10362] = {.lex_state = 206, .external_lex_state = 3},
  [10363] = {.lex_state = 7, .external_lex_state = 2},
  [10364] = {.lex_state = 438, .external_lex_state = 2},
  [10365] = {.lex_state = 229, .external_lex_state = 2},
  [10366] = {.lex_state = 229, .external_lex_state = 2},
  [10367] = {.lex_state = 7, .external_lex_state = 2},
  [10368] = {.lex_state = 7, .external_lex_state = 2},
  [10369] = {.lex_state = 7, .external_lex_state = 2},
  [10370] = {.lex_state = 229, .external_lex_state = 2},
  [10371] = {.lex_state = 445, .external_lex_state = 2},
  [10372] = {.lex_state = 7, .external_lex_state = 2},
  [10373] = {.lex_state = 7, .external_lex_state = 2},
  [10374] = {.lex_state = 180, .external_lex_state = 2},
  [10375] = {.lex_state = 7, .external_lex_state = 2},
  [10376] = {.lex_state = 24, .external_lex_state = 3},
  [10377] = {.lex_state = 445, .external_lex_state = 2},
  [10378] = {.lex_state = 14, .external_lex_state = 2},
  [10379] = {.lex_state = 229, .external_lex_state = 2},
  [10380] = {.lex_state = 229, .external_lex_state = 2},
  [10381] = {.lex_state = 445, .external_lex_state = 2},
  [10382] = {.lex_state = 7, .external_lex_state = 2},
  [10383] = {.lex_state = 452, .external_lex_state = 2},
  [10384] = {.lex_state = 229, .external_lex_state = 2},
  [10385] = {.lex_state = 7, .external_lex_state = 2},
  [10386] = {.lex_state = 7, .external_lex_state = 2},
  [10387] = {.lex_state = 445, .external_lex_state = 2},
  [10388] = {.lex_state = 181, .external_lex_state = 2},
  [10389] = {.lex_state = 241, .external_lex_state = 2},
  [10390] = {.lex_state = 229, .external_lex_state = 2},
  [10391] = {.lex_state = 229, .external_lex_state = 2},
  [10392] = {.lex_state = 7, .external_lex_state = 2},
  [10393] = {.lex_state = 7, .external_lex_state = 2},
  [10394] = {.lex_state = 7, .external_lex_state = 2},
  [10395] = {.lex_state = 26, .external_lex_state = 2},
  [10396] = {.lex_state = 7, .external_lex_state = 2},
  [10397] = {.lex_state = 14, .external_lex_state = 2},
  [10398] = {.lex_state = 7, .external_lex_state = 2},
  [10399] = {.lex_state = 14, .external_lex_state = 2},
  [10400] = {.lex_state = 7, .external_lex_state = 2},
  [10401] = {.lex_state = 14, .external_lex_state = 2},
  [10402] = {.lex_state = 7, .external_lex_state = 2},
  [10403] = {.lex_state = 26, .external_lex_state = 2},
  [10404] = {.lex_state = 7, .external_lex_state = 2},
  [10405] = {.lex_state = 7, .external_lex_state = 2},
  [10406] = {.lex_state = 7, .external_lex_state = 2},
  [10407] = {.lex_state = 181, .external_lex_state = 2},
  [10408] = {.lex_state = 7, .external_lex_state = 2},
  [10409] = {.lex_state = 229, .external_lex_state = 2},
  [10410] = {.lex_state = 229, .external_lex_state = 2},
  [10411] = {.lex_state = 239, .external_lex_state = 2},
  [10412] = {.lex_state = 7, .external_lex_state = 2},
  [10413] = {.lex_state = 239, .external_lex_state = 2},
  [10414] = {.lex_state = 7, .external_lex_state = 2},
  [10415] = {.lex_state = 239, .external_lex_state = 2},
  [10416] = {.lex_state = 7, .external_lex_state = 2},
  [10417] = {.lex_state = 7, .external_lex_state = 2},
  [10418] = {.lex_state = 7, .external_lex_state = 2},
  [10419] = {.lex_state = 7, .external_lex_state = 2},
  [10420] = {.lex_state = 7, .external_lex_state = 2},
  [10421] = {.lex_state = 7, .external_lex_state = 2},
  [10422] = {.lex_state = 437, .external_lex_state = 3},
  [10423] = {.lex_state = 7, .external_lex_state = 2},
  [10424] = {.lex_state = 7, .external_lex_state = 2},
  [10425] = {.lex_state = 7, .external_lex_state = 2},
  [10426] = {.lex_state = 14, .external_lex_state = 2},
  [10427] = {.lex_state = 7, .external_lex_state = 2},
  [10428] = {.lex_state = 14, .external_lex_state = 2},
  [10429] = {.lex_state = 7, .external_lex_state = 2},
  [10430] = {.lex_state = 239, .external_lex_state = 2},
  [10431] = {.lex_state = 14, .external_lex_state = 2},
  [10432] = {.lex_state = 7, .external_lex_state = 2},
  [10433] = {.lex_state = 7, .external_lex_state = 2},
  [10434] = {.lex_state = 7, .external_lex_state = 2},
  [10435] = {.lex_state = 6, .external_lex_state = 3},
  [10436] = {.lex_state = 7, .external_lex_state = 2},
  [10437] = {.lex_state = 7, .external_lex_state = 2},
  [10438] = {.lex_state = 7, .external_lex_state = 2},
  [10439] = {.lex_state = 24, .external_lex_state = 3},
  [10440] = {.lex_state = 7, .external_lex_state = 2},
  [10441] = {.lex_state = 7, .external_lex_state = 2},
  [10442] = {.lex_state = 233, .external_lex_state = 2},
  [10443] = {.lex_state = 7, .external_lex_state = 2},
  [10444] = {.lex_state = 24, .external_lex_state = 3},
  [10445] = {.lex_state = 14, .external_lex_state = 2},
  [10446] = {.lex_state = 7, .external_lex_state = 2},
  [10447] = {.lex_state = 7, .external_lex_state = 2},
  [10448] = {.lex_state = 239, .external_lex_state = 2},
  [10449] = {.lex_state = 7, .external_lex_state = 2},
  [10450] = {.lex_state = 7, .external_lex_state = 2},
  [10451] = {.lex_state = 7, .external_lex_state = 2},
  [10452] = {.lex_state = 181, .external_lex_state = 2},
  [10453] = {.lex_state = 7, .external_lex_state = 2},
  [10454] = {.lex_state = 7, .external_lex_state = 2},
  [10455] = {.lex_state = 229, .external_lex_state = 2},
  [10456] = {.lex_state = 445, .external_lex_state = 2},
  [10457] = {.lex_state = 180, .external_lex_state = 2},
  [10458] = {.lex_state = 7, .external_lex_state = 2},
  [10459] = {.lex_state = 241, .external_lex_state = 2},
  [10460] = {.lex_state = 7, .external_lex_state = 2},
  [10461] = {.lex_state = 7, .external_lex_state = 2},
  [10462] = {.lex_state = 7, .external_lex_state = 2},
  [10463] = {.lex_state = 445, .external_lex_state = 2},
  [10464] = {.lex_state = 229, .external_lex_state = 2},
  [10465] = {.lex_state = 229, .external_lex_state = 2},
  [10466] = {.lex_state = 7, .external_lex_state = 2},
  [10467] = {.lex_state = 229, .external_lex_state = 2},
  [10468] = {.lex_state = 241, .external_lex_state = 2},
  [10469] = {.lex_state = 14, .external_lex_state = 2},
  [10470] = {.lex_state = 14, .external_lex_state = 2},
  [10471] = {.lex_state = 234, .external_lex_state = 2},
  [10472] = {.lex_state = 180, .external_lex_state = 2},
  [10473] = {.lex_state = 180, .external_lex_state = 2},
  [10474] = {.lex_state = 180, .external_lex_state = 2},
  [10475] = {.lex_state = 206, .external_lex_state = 3},
  [10476] = {.lex_state = 234, .external_lex_state = 2},
  [10477] = {.lex_state = 445, .external_lex_state = 2},
  [10478] = {.lex_state = 234, .external_lex_state = 2},
  [10479] = {.lex_state = 451, .external_lex_state = 2},
  [10480] = {.lex_state = 14, .external_lex_state = 2},
  [10481] = {.lex_state = 7, .external_lex_state = 2},
  [10482] = {.lex_state = 7, .external_lex_state = 2},
  [10483] = {.lex_state = 180, .external_lex_state = 2},
  [10484] = {.lex_state = 7, .external_lex_state = 2},
  [10485] = {.lex_state = 438, .external_lex_state = 2},
  [10486] = {.lex_state = 7, .external_lex_state = 2},
  [10487] = {.lex_state = 7, .external_lex_state = 2},
  [10488] = {.lex_state = 7, .external_lex_state = 2},
  [10489] = {.lex_state = 181, .external_lex_state = 2},
  [10490] = {.lex_state = 229, .external_lex_state = 2},
  [10491] = {.lex_state = 7, .external_lex_state = 2},
  [10492] = {.lex_state = 7, .external_lex_state = 2},
  [10493] = {.lex_state = 7, .external_lex_state = 2},
  [10494] = {.lex_state = 229, .external_lex_state = 2},
  [10495] = {.lex_state = 7, .external_lex_state = 2},
  [10496] = {.lex_state = 14, .external_lex_state = 2},
  [10497] = {.lex_state = 14, .external_lex_state = 2},
  [10498] = {.lex_state = 206, .external_lex_state = 3},
  [10499] = {.lex_state = 7, .external_lex_state = 2},
  [10500] = {.lex_state = 7, .external_lex_state = 2},
  [10501] = {.lex_state = 229, .external_lex_state = 2},
  [10502] = {.lex_state = 229, .external_lex_state = 2},
  [10503] = {.lex_state = 7, .external_lex_state = 2},
  [10504] = {.lex_state = 14, .external_lex_state = 2},
  [10505] = {.lex_state = 7, .external_lex_state = 2},
  [10506] = {.lex_state = 229, .external_lex_state = 2},
  [10507] = {.lex_state = 234, .external_lex_state = 2},
  [10508] = {.lex_state = 7, .external_lex_state = 2},
  [10509] = {.lex_state = 229, .external_lex_state = 2},
  [10510] = {.lex_state = 7, .external_lex_state = 2},
  [10511] = {.lex_state = 7, .external_lex_state = 2},
  [10512] = {.lex_state = 26, .external_lex_state = 2},
  [10513] = {.lex_state = 26, .external_lex_state = 2},
  [10514] = {.lex_state = 7, .external_lex_state = 2},
  [10515] = {.lex_state = 229, .external_lex_state = 2},
  [10516] = {.lex_state = 7, .external_lex_state = 2},
  [10517] = {.lex_state = 7, .external_lex_state = 2},
  [10518] = {.lex_state = 7, .external_lex_state = 2},
  [10519] = {.lex_state = 233, .external_lex_state = 2},
  [10520] = {.lex_state = 24, .external_lex_state = 3},
  [10521] = {.lex_state = 181, .external_lex_state = 2},
  [10522] = {.lex_state = 7, .external_lex_state = 2},
  [10523] = {.lex_state = 7, .external_lex_state = 2},
  [10524] = {.lex_state = 233, .external_lex_state = 2},
  [10525] = {.lex_state = 24, .external_lex_state = 3},
  [10526] = {.lex_state = 7, .external_lex_state = 2},
  [10527] = {.lex_state = 7, .external_lex_state = 2},
  [10528] = {.lex_state = 7, .external_lex_state = 2},
  [10529] = {.lex_state = 7, .external_lex_state = 2},
  [10530] = {.lex_state = 445, .external_lex_state = 2},
  [10531] = {.lex_state = 7, .external_lex_state = 2},
  [10532] = {.lex_state = 7, .external_lex_state = 2},
  [10533] = {.lex_state = 7, .external_lex_state = 2},
  [10534] = {.lex_state = 224, .external_lex_state = 2},
  [10535] = {.lex_state = 184, .external_lex_state = 3},
  [10536] = {.lex_state = 445, .external_lex_state = 2},
  [10537] = {.lex_state = 234, .external_lex_state = 2},
  [10538] = {.lex_state = 26, .external_lex_state = 2},
  [10539] = {.lex_state = 229, .external_lex_state = 2},
  [10540] = {.lex_state = 26, .external_lex_state = 2},
  [10541] = {.lex_state = 229, .external_lex_state = 2},
  [10542] = {.lex_state = 451, .external_lex_state = 2},
  [10543] = {.lex_state = 452, .external_lex_state = 2},
  [10544] = {.lex_state = 14, .external_lex_state = 2},
  [10545] = {.lex_state = 7, .external_lex_state = 2},
  [10546] = {.lex_state = 445, .external_lex_state = 2},
  [10547] = {.lex_state = 445, .external_lex_state = 2},
  [10548] = {.lex_state = 445, .external_lex_state = 2},
  [10549] = {.lex_state = 445, .external_lex_state = 2},
  [10550] = {.lex_state = 445, .external_lex_state = 2},
  [10551] = {.lex_state = 445, .external_lex_state = 2},
  [10552] = {.lex_state = 445, .external_lex_state = 2},
  [10553] = {.lex_state = 445, .external_lex_state = 2},
  [10554] = {.lex_state = 445, .external_lex_state = 2},
  [10555] = {.lex_state = 445, .external_lex_state = 2},
  [10556] = {.lex_state = 7, .external_lex_state = 2},
  [10557] = {.lex_state = 24, .external_lex_state = 3},
  [10558] = {.lex_state = 6, .external_lex_state = 3},
  [10559] = {.lex_state = 226, .external_lex_state = 2},
  [10560] = {.lex_state = 226, .external_lex_state = 2},
  [10561] = {.lex_state = 180, .external_lex_state = 2},
  [10562] = {.lex_state = 6, .external_lex_state = 3},
  [10563] = {.lex_state = 226, .external_lex_state = 2},
  [10564] = {.lex_state = 239, .external_lex_state = 2},
  [10565] = {.lex_state = 181, .external_lex_state = 2},
  [10566] = {.lex_state = 181, .external_lex_state = 2},
  [10567] = {.lex_state = 181, .external_lex_state = 2},
  [10568] = {.lex_state = 181, .external_lex_state = 2},
  [10569] = {.lex_state = 226, .external_lex_state = 2},
  [10570] = {.lex_state = 6, .external_lex_state = 3},
  [10571] = {.lex_state = 241, .external_lex_state = 2},
  [10572] = {.lex_state = 6, .external_lex_state = 3},
  [10573] = {.lex_state = 6, .external_lex_state = 3},
  [10574] = {.lex_state = 226, .external_lex_state = 2},
  [10575] = {.lex_state = 181, .external_lex_state = 2},
  [10576] = {.lex_state = 181, .external_lex_state = 2},
  [10577] = {.lex_state = 181, .external_lex_state = 2},
  [10578] = {.lex_state = 181, .external_lex_state = 2},
  [10579] = {.lex_state = 180, .external_lex_state = 2},
  [10580] = {.lex_state = 241, .external_lex_state = 2},
  [10581] = {.lex_state = 6, .external_lex_state = 3},
  [10582] = {.lex_state = 450, .external_lex_state = 2},
  [10583] = {.lex_state = 181, .external_lex_state = 2},
  [10584] = {.lex_state = 6, .external_lex_state = 3},
  [10585] = {.lex_state = 226, .external_lex_state = 2},
  [10586] = {.lex_state = 6, .external_lex_state = 3},
  [10587] = {.lex_state = 181, .external_lex_state = 2},
  [10588] = {.lex_state = 181, .external_lex_state = 2},
  [10589] = {.lex_state = 181, .external_lex_state = 2},
  [10590] = {.lex_state = 181, .external_lex_state = 2},
  [10591] = {.lex_state = 226, .external_lex_state = 2},
  [10592] = {.lex_state = 438, .external_lex_state = 2},
  [10593] = {.lex_state = 181, .external_lex_state = 2},
  [10594] = {.lex_state = 226, .external_lex_state = 2},
  [10595] = {.lex_state = 181, .external_lex_state = 2},
  [10596] = {.lex_state = 181, .external_lex_state = 2},
  [10597] = {.lex_state = 181, .external_lex_state = 2},
  [10598] = {.lex_state = 453, .external_lex_state = 2},
  [10599] = {.lex_state = 239, .external_lex_state = 2},
  [10600] = {.lex_state = 226, .external_lex_state = 2},
  [10601] = {.lex_state = 6, .external_lex_state = 3},
  [10602] = {.lex_state = 239, .external_lex_state = 2},
  [10603] = {.lex_state = 26, .external_lex_state = 2},
  [10604] = {.lex_state = 180, .external_lex_state = 2},
  [10605] = {.lex_state = 181, .external_lex_state = 2},
  [10606] = {.lex_state = 6, .external_lex_state = 3},
  [10607] = {.lex_state = 6, .external_lex_state = 3},
  [10608] = {.lex_state = 6, .external_lex_state = 3},
  [10609] = {.lex_state = 226, .external_lex_state = 2},
  [10610] = {.lex_state = 6, .external_lex_state = 3},
  [10611] = {.lex_state = 450, .external_lex_state = 2},
  [10612] = {.lex_state = 241, .external_lex_state = 2},
  [10613] = {.lex_state = 6, .external_lex_state = 3},
  [10614] = {.lex_state = 226, .external_lex_state = 2},
  [10615] = {.lex_state = 6, .external_lex_state = 3},
  [10616] = {.lex_state = 450, .external_lex_state = 2},
  [10617] = {.lex_state = 181, .external_lex_state = 2},
  [10618] = {.lex_state = 6, .external_lex_state = 3},
  [10619] = {.lex_state = 181, .external_lex_state = 2},
  [10620] = {.lex_state = 450, .external_lex_state = 2},
  [10621] = {.lex_state = 206, .external_lex_state = 3},
  [10622] = {.lex_state = 6, .external_lex_state = 3},
  [10623] = {.lex_state = 226, .external_lex_state = 2},
  [10624] = {.lex_state = 180, .external_lex_state = 2},
  [10625] = {.lex_state = 6, .external_lex_state = 3},
  [10626] = {.lex_state = 6, .external_lex_state = 3},
  [10627] = {.lex_state = 13, .external_lex_state = 2},
  [10628] = {.lex_state = 13, .external_lex_state = 2},
  [10629] = {.lex_state = 180, .external_lex_state = 2},
  [10630] = {.lex_state = 226, .external_lex_state = 2},
  [10631] = {.lex_state = 13, .external_lex_state = 2},
  [10632] = {.lex_state = 181, .external_lex_state = 2},
  [10633] = {.lex_state = 13, .external_lex_state = 2},
  [10634] = {.lex_state = 180, .external_lex_state = 2},
  [10635] = {.lex_state = 6, .external_lex_state = 3},
  [10636] = {.lex_state = 226, .external_lex_state = 2},
  [10637] = {.lex_state = 181, .external_lex_state = 2},
  [10638] = {.lex_state = 6, .external_lex_state = 3},
  [10639] = {.lex_state = 181, .external_lex_state = 2},
  [10640] = {.lex_state = 226, .external_lex_state = 2},
  [10641] = {.lex_state = 6, .external_lex_state = 3},
  [10642] = {.lex_state = 451, .external_lex_state = 2},
  [10643] = {.lex_state = 451, .external_lex_state = 2},
  [10644] = {.lex_state = 6, .external_lex_state = 3},
  [10645] = {.lex_state = 6, .external_lex_state = 3},
  [10646] = {.lex_state = 226, .external_lex_state = 2},
  [10647] = {.lex_state = 450, .external_lex_state = 2},
  [10648] = {.lex_state = 6, .external_lex_state = 3},
  [10649] = {.lex_state = 180, .external_lex_state = 2},
  [10650] = {.lex_state = 226, .external_lex_state = 2},
  [10651] = {.lex_state = 180, .external_lex_state = 2},
  [10652] = {.lex_state = 6, .external_lex_state = 3},
  [10653] = {.lex_state = 181, .external_lex_state = 2},
  [10654] = {.lex_state = 6, .external_lex_state = 3},
  [10655] = {.lex_state = 6, .external_lex_state = 3},
  [10656] = {.lex_state = 6, .external_lex_state = 3},
  [10657] = {.lex_state = 6, .external_lex_state = 3},
  [10658] = {.lex_state = 181, .external_lex_state = 2},
  [10659] = {.lex_state = 180, .external_lex_state = 2},
  [10660] = {.lex_state = 180, .external_lex_state = 2},
  [10661] = {.lex_state = 180, .external_lex_state = 2},
  [10662] = {.lex_state = 450, .external_lex_state = 2},
  [10663] = {.lex_state = 450, .external_lex_state = 2},
  [10664] = {.lex_state = 181, .external_lex_state = 2},
  [10665] = {.lex_state = 181, .external_lex_state = 2},
  [10666] = {.lex_state = 6, .external_lex_state = 3},
  [10667] = {.lex_state = 239, .external_lex_state = 2},
  [10668] = {.lex_state = 181, .external_lex_state = 2},
  [10669] = {.lex_state = 445, .external_lex_state = 2},
  [10670] = {.lex_state = 445, .external_lex_state = 2},
  [10671] = {.lex_state = 180, .external_lex_state = 2},
  [10672] = {.lex_state = 181, .external_lex_state = 2},
  [10673] = {.lex_state = 451, .external_lex_state = 2},
  [10674] = {.lex_state = 6, .external_lex_state = 3},
  [10675] = {.lex_state = 6, .external_lex_state = 3},
  [10676] = {.lex_state = 445, .external_lex_state = 2},
  [10677] = {.lex_state = 6, .external_lex_state = 3},
  [10678] = {.lex_state = 6, .external_lex_state = 3},
  [10679] = {.lex_state = 6, .external_lex_state = 3},
  [10680] = {.lex_state = 6, .external_lex_state = 3},
  [10681] = {.lex_state = 450, .external_lex_state = 2},
  [10682] = {.lex_state = 226, .external_lex_state = 2},
  [10683] = {.lex_state = 180, .external_lex_state = 2},
  [10684] = {.lex_state = 180, .external_lex_state = 2},
  [10685] = {.lex_state = 445, .external_lex_state = 2},
  [10686] = {.lex_state = 181, .external_lex_state = 2},
  [10687] = {.lex_state = 180, .external_lex_state = 2},
  [10688] = {.lex_state = 180, .external_lex_state = 2},
  [10689] = {.lex_state = 450, .external_lex_state = 2},
  [10690] = {.lex_state = 224, .external_lex_state = 2},
  [10691] = {.lex_state = 445, .external_lex_state = 2},
  [10692] = {.lex_state = 13, .external_lex_state = 2},
  [10693] = {.lex_state = 180, .external_lex_state = 2},
  [10694] = {.lex_state = 13, .external_lex_state = 2},
  [10695] = {.lex_state = 13, .external_lex_state = 2},
  [10696] = {.lex_state = 13, .external_lex_state = 2},
  [10697] = {.lex_state = 13, .external_lex_state = 2},
  [10698] = {.lex_state = 13, .external_lex_state = 2},
  [10699] = {.lex_state = 451, .external_lex_state = 2},
  [10700] = {.lex_state = 451, .external_lex_state = 2},
  [10701] = {.lex_state = 13, .external_lex_state = 2},
  [10702] = {.lex_state = 13, .external_lex_state = 2},
  [10703] = {.lex_state = 13, .external_lex_state = 2},
  [10704] = {.lex_state = 13, .external_lex_state = 2},
  [10705] = {.lex_state = 13, .external_lex_state = 2},
  [10706] = {.lex_state = 6, .external_lex_state = 3},
  [10707] = {.lex_state = 241, .external_lex_state = 2},
  [10708] = {.lex_state = 13, .external_lex_state = 2},
  [10709] = {.lex_state = 6, .external_lex_state = 3},
  [10710] = {.lex_state = 13, .external_lex_state = 2},
  [10711] = {.lex_state = 26, .external_lex_state = 2},
  [10712] = {.lex_state = 180, .external_lex_state = 2},
  [10713] = {.lex_state = 14, .external_lex_state = 2},
  [10714] = {.lex_state = 180, .external_lex_state = 2},
  [10715] = {.lex_state = 180, .external_lex_state = 2},
  [10716] = {.lex_state = 180, .external_lex_state = 2},
  [10717] = {.lex_state = 451, .external_lex_state = 2},
  [10718] = {.lex_state = 13, .external_lex_state = 2},
  [10719] = {.lex_state = 180, .external_lex_state = 2},
  [10720] = {.lex_state = 6, .external_lex_state = 3},
  [10721] = {.lex_state = 6, .external_lex_state = 3},
  [10722] = {.lex_state = 440, .external_lex_state = 2},
  [10723] = {.lex_state = 445, .external_lex_state = 2},
  [10724] = {.lex_state = 226, .external_lex_state = 2},
  [10725] = {.lex_state = 226, .external_lex_state = 2},
  [10726] = {.lex_state = 225, .external_lex_state = 2},
  [10727] = {.lex_state = 452, .external_lex_state = 2},
  [10728] = {.lex_state = 445, .external_lex_state = 2},
  [10729] = {.lex_state = 450, .external_lex_state = 2},
  [10730] = {.lex_state = 445, .external_lex_state = 2},
  [10731] = {.lex_state = 13, .external_lex_state = 2},
  [10732] = {.lex_state = 229, .external_lex_state = 2},
  [10733] = {.lex_state = 445, .external_lex_state = 2},
  [10734] = {.lex_state = 445, .external_lex_state = 2},
  [10735] = {.lex_state = 6, .external_lex_state = 3},
  [10736] = {.lex_state = 6, .external_lex_state = 3},
  [10737] = {.lex_state = 180, .external_lex_state = 2},
  [10738] = {.lex_state = 180, .external_lex_state = 2},
  [10739] = {.lex_state = 180, .external_lex_state = 2},
  [10740] = {.lex_state = 180, .external_lex_state = 2},
  [10741] = {.lex_state = 180, .external_lex_state = 2},
  [10742] = {.lex_state = 180, .external_lex_state = 2},
  [10743] = {.lex_state = 226, .external_lex_state = 2},
  [10744] = {.lex_state = 6, .external_lex_state = 3},
  [10745] = {.lex_state = 6, .external_lex_state = 3},
  [10746] = {.lex_state = 229, .external_lex_state = 2},
  [10747] = {.lex_state = 15, .external_lex_state = 2},
  [10748] = {.lex_state = 230, .external_lex_state = 2},
  [10749] = {.lex_state = 180, .external_lex_state = 2},
  [10750] = {.lex_state = 180, .external_lex_state = 2},
  [10751] = {.lex_state = 180, .external_lex_state = 2},
  [10752] = {.lex_state = 13, .external_lex_state = 2},
  [10753] = {.lex_state = 180, .external_lex_state = 2},
  [10754] = {.lex_state = 450, .external_lex_state = 2},
  [10755] = {.lex_state = 450, .external_lex_state = 2},
  [10756] = {.lex_state = 180, .external_lex_state = 2},
  [10757] = {.lex_state = 438, .external_lex_state = 2},
  [10758] = {.lex_state = 445, .external_lex_state = 2},
  [10759] = {.lex_state = 226, .external_lex_state = 2},
  [10760] = {.lex_state = 181, .external_lex_state = 2},
  [10761] = {.lex_state = 438, .external_lex_state = 2},
  [10762] = {.lex_state = 438, .external_lex_state = 2},
  [10763] = {.lex_state = 180, .external_lex_state = 2},
  [10764] = {.lex_state = 6, .external_lex_state = 3},
  [10765] = {.lex_state = 6, .external_lex_state = 3},
  [10766] = {.lex_state = 438, .external_lex_state = 2},
  [10767] = {.lex_state = 181, .external_lex_state = 2},
  [10768] = {.lex_state = 6, .external_lex_state = 3},
  [10769] = {.lex_state = 226, .external_lex_state = 2},
  [10770] = {.lex_state = 6, .external_lex_state = 3},
  [10771] = {.lex_state = 13, .external_lex_state = 2},
  [10772] = {.lex_state = 6, .external_lex_state = 3},
  [10773] = {.lex_state = 445, .external_lex_state = 2},
  [10774] = {.lex_state = 13, .external_lex_state = 2},
  [10775] = {.lex_state = 13, .external_lex_state = 2},
  [10776] = {.lex_state = 6, .external_lex_state = 3},
  [10777] = {.lex_state = 13, .external_lex_state = 2},
  [10778] = {.lex_state = 13, .external_lex_state = 2},
  [10779] = {.lex_state = 13, .external_lex_state = 2},
  [10780] = {.lex_state = 6, .external_lex_state = 3},
  [10781] = {.lex_state = 6, .external_lex_state = 3},
  [10782] = {.lex_state = 6, .external_lex_state = 3},
  [10783] = {.lex_state = 445, .external_lex_state = 2},
  [10784] = {.lex_state = 6, .external_lex_state = 3},
  [10785] = {.lex_state = 6, .external_lex_state = 3},
  [10786] = {.lex_state = 230, .external_lex_state = 2},
  [10787] = {.lex_state = 6, .external_lex_state = 3},
  [10788] = {.lex_state = 226, .external_lex_state = 2},
  [10789] = {.lex_state = 226, .external_lex_state = 2},
  [10790] = {.lex_state = 6, .external_lex_state = 3},
  [10791] = {.lex_state = 181, .external_lex_state = 2},
  [10792] = {.lex_state = 181, .external_lex_state = 2},
  [10793] = {.lex_state = 180, .external_lex_state = 2},
  [10794] = {.lex_state = 181, .external_lex_state = 2},
  [10795] = {.lex_state = 6, .external_lex_state = 3},
  [10796] = {.lex_state = 226, .external_lex_state = 2},
  [10797] = {.lex_state = 221, .external_lex_state = 2},
  [10798] = {.lex_state = 445, .external_lex_state = 2},
  [10799] = {.lex_state = 445, .external_lex_state = 2},
  [10800] = {.lex_state = 17, .external_lex_state = 2},
  [10801] = {.lex_state = 445, .external_lex_state = 2},
  [10802] = {.lex_state = 445, .external_lex_state = 2},
  [10803] = {.lex_state = 445, .external_lex_state = 2},
  [10804] = {.lex_state = 454, .external_lex_state = 2},
  [10805] = {.lex_state = 445, .external_lex_state = 2},
  [10806] = {.lex_state = 14, .external_lex_state = 2},
  [10807] = {.lex_state = 445, .external_lex_state = 2},
  [10808] = {.lex_state = 52, .external_lex_state = 3},
  [10809] = {.lex_state = 445, .external_lex_state = 2},
  [10810] = {.lex_state = 15, .external_lex_state = 2},
  [10811] = {.lex_state = 445, .external_lex_state = 2},
  [10812] = {.lex_state = 445, .external_lex_state = 2},
  [10813] = {.lex_state = 445, .external_lex_state = 2},
  [10814] = {.lex_state = 445, .external_lex_state = 2},
  [10815] = {.lex_state = 445, .external_lex_state = 2},
  [10816] = {.lex_state = 445, .external_lex_state = 2},
  [10817] = {.lex_state = 445, .external_lex_state = 2},
  [10818] = {.lex_state = 445, .external_lex_state = 2},
  [10819] = {.lex_state = 445, .external_lex_state = 2},
  [10820] = {.lex_state = 454, .external_lex_state = 2},
  [10821] = {.lex_state = 454, .external_lex_state = 2},
  [10822] = {.lex_state = 445, .external_lex_state = 2},
  [10823] = {.lex_state = 15, .external_lex_state = 2},
  [10824] = {.lex_state = 14, .external_lex_state = 2},
  [10825] = {.lex_state = 14, .external_lex_state = 2},
  [10826] = {.lex_state = 14, .external_lex_state = 2},
  [10827] = {.lex_state = 14, .external_lex_state = 2},
  [10828] = {.lex_state = 14, .external_lex_state = 2},
  [10829] = {.lex_state = 14, .external_lex_state = 2},
  [10830] = {.lex_state = 14, .external_lex_state = 2},
  [10831] = {.lex_state = 52, .external_lex_state = 3},
  [10832] = {.lex_state = 14, .external_lex_state = 2},
  [10833] = {.lex_state = 14, .external_lex_state = 2},
  [10834] = {.lex_state = 14, .external_lex_state = 2},
  [10835] = {.lex_state = 14, .external_lex_state = 2},
  [10836] = {.lex_state = 229, .external_lex_state = 2},
  [10837] = {.lex_state = 239, .external_lex_state = 2},
  [10838] = {.lex_state = 445, .external_lex_state = 2},
  [10839] = {.lex_state = 445, .external_lex_state = 2},
  [10840] = {.lex_state = 438, .external_lex_state = 2},
  [10841] = {.lex_state = 445, .external_lex_state = 2},
  [10842] = {.lex_state = 445, .external_lex_state = 2},
  [10843] = {.lex_state = 17, .external_lex_state = 2},
  [10844] = {.lex_state = 445, .external_lex_state = 2},
  [10845] = {.lex_state = 14, .external_lex_state = 2},
  [10846] = {.lex_state = 15, .external_lex_state = 2},
  [10847] = {.lex_state = 445, .external_lex_state = 2},
  [10848] = {.lex_state = 14, .external_lex_state = 2},
  [10849] = {.lex_state = 445, .external_lex_state = 2},
  [10850] = {.lex_state = 445, .external_lex_state = 2},
  [10851] = {.lex_state = 17, .external_lex_state = 2},
  [10852] = {.lex_state = 445, .external_lex_state = 2},
  [10853] = {.lex_state = 445, .external_lex_state = 2},
  [10854] = {.lex_state = 235, .external_lex_state = 2},
  [10855] = {.lex_state = 445, .external_lex_state = 2},
  [10856] = {.lex_state = 445, .external_lex_state = 2},
  [10857] = {.lex_state = 445, .external_lex_state = 2},
  [10858] = {.lex_state = 15, .external_lex_state = 2},
  [10859] = {.lex_state = 15, .external_lex_state = 2},
  [10860] = {.lex_state = 235, .external_lex_state = 2},
  [10861] = {.lex_state = 445, .external_lex_state = 2},
  [10862] = {.lex_state = 14, .external_lex_state = 2},
  [10863] = {.lex_state = 445, .external_lex_state = 2},
  [10864] = {.lex_state = 445, .external_lex_state = 2},
  [10865] = {.lex_state = 445, .external_lex_state = 2},
  [10866] = {.lex_state = 438, .external_lex_state = 2},
  [10867] = {.lex_state = 13, .external_lex_state = 2},
  [10868] = {.lex_state = 445, .external_lex_state = 2},
  [10869] = {.lex_state = 438, .external_lex_state = 2},
  [10870] = {.lex_state = 445, .external_lex_state = 2},
  [10871] = {.lex_state = 445, .external_lex_state = 2},
  [10872] = {.lex_state = 13, .external_lex_state = 2},
  [10873] = {.lex_state = 438, .external_lex_state = 2},
  [10874] = {.lex_state = 445, .external_lex_state = 2},
  [10875] = {.lex_state = 445, .external_lex_state = 2},
  [10876] = {.lex_state = 15, .external_lex_state = 2},
  [10877] = {.lex_state = 15, .external_lex_state = 2},
  [10878] = {.lex_state = 445, .external_lex_state = 2},
  [10879] = {.lex_state = 445, .external_lex_state = 2},
  [10880] = {.lex_state = 445, .external_lex_state = 2},
  [10881] = {.lex_state = 15, .external_lex_state = 2},
  [10882] = {.lex_state = 17, .external_lex_state = 2},
  [10883] = {.lex_state = 17, .external_lex_state = 2},
  [10884] = {.lex_state = 444, .external_lex_state = 2},
  [10885] = {.lex_state = 445, .external_lex_state = 2},
  [10886] = {.lex_state = 15, .external_lex_state = 2},
  [10887] = {.lex_state = 445, .external_lex_state = 2},
  [10888] = {.lex_state = 15, .external_lex_state = 2},
  [10889] = {.lex_state = 17, .external_lex_state = 2},
  [10890] = {.lex_state = 15, .external_lex_state = 2},
  [10891] = {.lex_state = 15, .external_lex_state = 2},
  [10892] = {.lex_state = 445, .external_lex_state = 2},
  [10893] = {.lex_state = 13, .external_lex_state = 2},
  [10894] = {.lex_state = 173, .external_lex_state = 2},
  [10895] = {.lex_state = 445, .external_lex_state = 2},
  [10896] = {.lex_state = 445, .external_lex_state = 2},
  [10897] = {.lex_state = 438, .external_lex_state = 2},
  [10898] = {.lex_state = 445, .external_lex_state = 2},
  [10899] = {.lex_state = 445, .external_lex_state = 2},
  [10900] = {.lex_state = 17, .external_lex_state = 2},
  [10901] = {.lex_state = 438, .external_lex_state = 2},
  [10902] = {.lex_state = 445, .external_lex_state = 2},
  [10903] = {.lex_state = 445, .external_lex_state = 2},
  [10904] = {.lex_state = 438, .external_lex_state = 2},
  [10905] = {.lex_state = 445, .external_lex_state = 2},
  [10906] = {.lex_state = 445, .external_lex_state = 2},
  [10907] = {.lex_state = 445, .external_lex_state = 2},
  [10908] = {.lex_state = 445, .external_lex_state = 2},
  [10909] = {.lex_state = 445, .external_lex_state = 2},
  [10910] = {.lex_state = 445, .external_lex_state = 2},
  [10911] = {.lex_state = 445, .external_lex_state = 2},
  [10912] = {.lex_state = 445, .external_lex_state = 2},
  [10913] = {.lex_state = 15, .external_lex_state = 2},
  [10914] = {.lex_state = 445, .external_lex_state = 2},
  [10915] = {.lex_state = 445, .external_lex_state = 2},
  [10916] = {.lex_state = 445, .external_lex_state = 2},
  [10917] = {.lex_state = 175, .external_lex_state = 3},
  [10918] = {.lex_state = 445, .external_lex_state = 2},
  [10919] = {.lex_state = 445, .external_lex_state = 2},
  [10920] = {.lex_state = 445, .external_lex_state = 2},
  [10921] = {.lex_state = 445, .external_lex_state = 2},
  [10922] = {.lex_state = 445, .external_lex_state = 2},
  [10923] = {.lex_state = 445, .external_lex_state = 2},
  [10924] = {.lex_state = 453, .external_lex_state = 2},
  [10925] = {.lex_state = 445, .external_lex_state = 2},
  [10926] = {.lex_state = 445, .external_lex_state = 2},
  [10927] = {.lex_state = 445, .external_lex_state = 2},
  [10928] = {.lex_state = 438, .external_lex_state = 2},
  [10929] = {.lex_state = 13, .external_lex_state = 2},
  [10930] = {.lex_state = 15, .external_lex_state = 2},
  [10931] = {.lex_state = 445, .external_lex_state = 2},
  [10932] = {.lex_state = 445, .external_lex_state = 2},
  [10933] = {.lex_state = 445, .external_lex_state = 2},
  [10934] = {.lex_state = 445, .external_lex_state = 2},
  [10935] = {.lex_state = 13, .external_lex_state = 2},
  [10936] = {.lex_state = 445, .external_lex_state = 2},
  [10937] = {.lex_state = 445, .external_lex_state = 2},
  [10938] = {.lex_state = 13, .external_lex_state = 2},
  [10939] = {.lex_state = 445, .external_lex_state = 2},
  [10940] = {.lex_state = 13, .external_lex_state = 2},
  [10941] = {.lex_state = 445, .external_lex_state = 2},
  [10942] = {.lex_state = 445, .external_lex_state = 2},
  [10943] = {.lex_state = 445, .external_lex_state = 2},
  [10944] = {.lex_state = 445, .external_lex_state = 2},
  [10945] = {.lex_state = 445, .external_lex_state = 2},
  [10946] = {.lex_state = 14, .external_lex_state = 2},
  [10947] = {.lex_state = 445, .external_lex_state = 2},
  [10948] = {.lex_state = 13, .external_lex_state = 2},
  [10949] = {.lex_state = 26, .external_lex_state = 2},
  [10950] = {.lex_state = 13, .external_lex_state = 2},
  [10951] = {.lex_state = 445, .external_lex_state = 2},
  [10952] = {.lex_state = 13, .external_lex_state = 2},
  [10953] = {.lex_state = 13, .external_lex_state = 2},
  [10954] = {.lex_state = 13, .external_lex_state = 2},
  [10955] = {.lex_state = 235, .external_lex_state = 2},
  [10956] = {.lex_state = 235, .external_lex_state = 2},
  [10957] = {.lex_state = 13, .external_lex_state = 2},
  [10958] = {.lex_state = 13, .external_lex_state = 2},
  [10959] = {.lex_state = 13, .external_lex_state = 2},
  [10960] = {.lex_state = 445, .external_lex_state = 2},
  [10961] = {.lex_state = 438, .external_lex_state = 2},
  [10962] = {.lex_state = 221, .external_lex_state = 2},
  [10963] = {.lex_state = 15, .external_lex_state = 2},
  [10964] = {.lex_state = 6, .external_lex_state = 3},
  [10965] = {.lex_state = 235, .external_lex_state = 2},
  [10966] = {.lex_state = 445, .external_lex_state = 2},
  [10967] = {.lex_state = 17, .external_lex_state = 2},
  [10968] = {.lex_state = 17, .external_lex_state = 2},
  [10969] = {.lex_state = 17, .external_lex_state = 2},
  [10970] = {.lex_state = 445, .external_lex_state = 2},
  [10971] = {.lex_state = 17, .external_lex_state = 2},
  [10972] = {.lex_state = 445, .external_lex_state = 2},
  [10973] = {.lex_state = 438, .external_lex_state = 2},
  [10974] = {.lex_state = 438, .external_lex_state = 2},
  [10975] = {.lex_state = 437, .external_lex_state = 2},
  [10976] = {.lex_state = 445, .external_lex_state = 2},
  [10977] = {.lex_state = 438, .external_lex_state = 2},
  [10978] = {.lex_state = 438, .external_lex_state = 2},
  [10979] = {.lex_state = 221, .external_lex_state = 2},
  [10980] = {.lex_state = 14, .external_lex_state = 2},
  [10981] = {.lex_state = 445, .external_lex_state = 2},
  [10982] = {.lex_state = 445, .external_lex_state = 2},
  [10983] = {.lex_state = 450, .external_lex_state = 2},
  [10984] = {.lex_state = 13, .external_lex_state = 2},
  [10985] = {.lex_state = 445, .external_lex_state = 2},
  [10986] = {.lex_state = 445, .external_lex_state = 2},
  [10987] = {.lex_state = 445, .external_lex_state = 2},
  [10988] = {.lex_state = 445, .external_lex_state = 2},
  [10989] = {.lex_state = 445, .external_lex_state = 2},
  [10990] = {.lex_state = 445, .external_lex_state = 2},
  [10991] = {.lex_state = 445, .external_lex_state = 2},
  [10992] = {.lex_state = 445, .external_lex_state = 2},
  [10993] = {.lex_state = 445, .external_lex_state = 2},
  [10994] = {.lex_state = 445, .external_lex_state = 2},
  [10995] = {.lex_state = 445, .external_lex_state = 2},
  [10996] = {.lex_state = 445, .external_lex_state = 2},
  [10997] = {.lex_state = 445, .external_lex_state = 2},
  [10998] = {.lex_state = 445, .external_lex_state = 2},
  [10999] = {.lex_state = 445, .external_lex_state = 2},
  [11000] = {.lex_state = 445, .external_lex_state = 2},
  [11001] = {.lex_state = 445, .external_lex_state = 2},
  [11002] = {.lex_state = 445, .external_lex_state = 2},
  [11003] = {.lex_state = 445, .external_lex_state = 2},
  [11004] = {.lex_state = 445, .external_lex_state = 2},
  [11005] = {.lex_state = 445, .external_lex_state = 2},
  [11006] = {.lex_state = 445, .external_lex_state = 2},
  [11007] = {.lex_state = 445, .external_lex_state = 2},
  [11008] = {.lex_state = 445, .external_lex_state = 2},
  [11009] = {.lex_state = 15, .external_lex_state = 2},
  [11010] = {.lex_state = 445, .external_lex_state = 2},
  [11011] = {.lex_state = 445, .external_lex_state = 2},
  [11012] = {.lex_state = 445, .external_lex_state = 2},
  [11013] = {.lex_state = 445, .external_lex_state = 2},
  [11014] = {.lex_state = 445, .external_lex_state = 2},
  [11015] = {.lex_state = 445, .external_lex_state = 2},
  [11016] = {.lex_state = 445, .external_lex_state = 2},
  [11017] = {.lex_state = 445, .external_lex_state = 2},
  [11018] = {.lex_state = 445, .external_lex_state = 2},
  [11019] = {.lex_state = 445, .external_lex_state = 2},
  [11020] = {.lex_state = 445, .external_lex_state = 2},
  [11021] = {.lex_state = 445, .external_lex_state = 2},
  [11022] = {.lex_state = 445, .external_lex_state = 2},
  [11023] = {.lex_state = 445, .external_lex_state = 2},
  [11024] = {.lex_state = 445, .external_lex_state = 2},
  [11025] = {.lex_state = 445, .external_lex_state = 2},
  [11026] = {.lex_state = 438, .external_lex_state = 2},
  [11027] = {.lex_state = 445, .external_lex_state = 2},
  [11028] = {.lex_state = 13, .external_lex_state = 2},
  [11029] = {.lex_state = 445, .external_lex_state = 2},
  [11030] = {.lex_state = 445, .external_lex_state = 2},
  [11031] = {.lex_state = 445, .external_lex_state = 2},
  [11032] = {.lex_state = 15, .external_lex_state = 2},
  [11033] = {.lex_state = 445, .external_lex_state = 2},
  [11034] = {.lex_state = 445, .external_lex_state = 2},
  [11035] = {.lex_state = 221, .external_lex_state = 2},
  [11036] = {.lex_state = 445, .external_lex_state = 2},
  [11037] = {.lex_state = 445, .external_lex_state = 2},
  [11038] = {.lex_state = 445, .external_lex_state = 2},
  [11039] = {.lex_state = 445, .external_lex_state = 2},
  [11040] = {.lex_state = 445, .external_lex_state = 2},
  [11041] = {.lex_state = 445, .external_lex_state = 2},
  [11042] = {.lex_state = 445, .external_lex_state = 2},
  [11043] = {.lex_state = 445, .external_lex_state = 2},
  [11044] = {.lex_state = 445, .external_lex_state = 2},
  [11045] = {.lex_state = 445, .external_lex_state = 2},
  [11046] = {.lex_state = 445, .external_lex_state = 2},
  [11047] = {.lex_state = 445, .external_lex_state = 2},
  [11048] = {.lex_state = 445, .external_lex_state = 2},
  [11049] = {.lex_state = 445, .external_lex_state = 2},
  [11050] = {.lex_state = 445, .external_lex_state = 2},
  [11051] = {.lex_state = 445, .external_lex_state = 2},
  [11052] = {.lex_state = 445, .external_lex_state = 2},
  [11053] = {.lex_state = 445, .external_lex_state = 2},
  [11054] = {.lex_state = 445, .external_lex_state = 2},
  [11055] = {.lex_state = 445, .external_lex_state = 2},
  [11056] = {.lex_state = 15, .external_lex_state = 2},
  [11057] = {.lex_state = 445, .external_lex_state = 2},
  [11058] = {.lex_state = 445, .external_lex_state = 2},
  [11059] = {.lex_state = 445, .external_lex_state = 2},
  [11060] = {.lex_state = 445, .external_lex_state = 2},
  [11061] = {.lex_state = 445, .external_lex_state = 2},
  [11062] = {.lex_state = 445, .external_lex_state = 2},
  [11063] = {.lex_state = 445, .external_lex_state = 2},
  [11064] = {.lex_state = 445, .external_lex_state = 2},
  [11065] = {.lex_state = 445, .external_lex_state = 2},
  [11066] = {.lex_state = 445, .external_lex_state = 2},
  [11067] = {.lex_state = 445, .external_lex_state = 2},
  [11068] = {.lex_state = 445, .external_lex_state = 2},
  [11069] = {.lex_state = 445, .external_lex_state = 2},
  [11070] = {.lex_state = 235, .external_lex_state = 2},
  [11071] = {.lex_state = 15, .external_lex_state = 2},
  [11072] = {.lex_state = 230, .external_lex_state = 2},
  [11073] = {.lex_state = 445, .external_lex_state = 2},
  [11074] = {.lex_state = 445, .external_lex_state = 2},
  [11075] = {.lex_state = 445, .external_lex_state = 2},
  [11076] = {.lex_state = 445, .external_lex_state = 2},
  [11077] = {.lex_state = 445, .external_lex_state = 2},
  [11078] = {.lex_state = 445, .external_lex_state = 2},
  [11079] = {.lex_state = 445, .external_lex_state = 2},
  [11080] = {.lex_state = 445, .external_lex_state = 2},
  [11081] = {.lex_state = 445, .external_lex_state = 2},
  [11082] = {.lex_state = 445, .external_lex_state = 2},
  [11083] = {.lex_state = 445, .external_lex_state = 2},
  [11084] = {.lex_state = 445, .external_lex_state = 2},
  [11085] = {.lex_state = 445, .external_lex_state = 2},
  [11086] = {.lex_state = 445, .external_lex_state = 2},
  [11087] = {.lex_state = 445, .external_lex_state = 2},
  [11088] = {.lex_state = 445, .external_lex_state = 2},
  [11089] = {.lex_state = 445, .external_lex_state = 2},
  [11090] = {.lex_state = 445, .external_lex_state = 2},
  [11091] = {.lex_state = 438, .external_lex_state = 2},
  [11092] = {.lex_state = 438, .external_lex_state = 2},
  [11093] = {.lex_state = 445, .external_lex_state = 2},
  [11094] = {.lex_state = 445, .external_lex_state = 2},
  [11095] = {.lex_state = 438, .external_lex_state = 2},
  [11096] = {.lex_state = 438, .external_lex_state = 2},
  [11097] = {.lex_state = 445, .external_lex_state = 2},
  [11098] = {.lex_state = 445, .external_lex_state = 2},
  [11099] = {.lex_state = 445, .external_lex_state = 2},
  [11100] = {.lex_state = 445, .external_lex_state = 2},
  [11101] = {.lex_state = 445, .external_lex_state = 2},
  [11102] = {.lex_state = 438, .external_lex_state = 2},
  [11103] = {.lex_state = 445, .external_lex_state = 2},
  [11104] = {.lex_state = 17, .external_lex_state = 2},
  [11105] = {.lex_state = 15, .external_lex_state = 2},
  [11106] = {.lex_state = 445, .external_lex_state = 2},
  [11107] = {.lex_state = 241, .external_lex_state = 2},
  [11108] = {.lex_state = 235, .external_lex_state = 2},
  [11109] = {.lex_state = 15, .external_lex_state = 2},
  [11110] = {.lex_state = 235, .external_lex_state = 2},
  [11111] = {.lex_state = 445, .external_lex_state = 2},
  [11112] = {.lex_state = 445, .external_lex_state = 2},
  [11113] = {.lex_state = 445, .external_lex_state = 2},
  [11114] = {.lex_state = 438, .external_lex_state = 2},
  [11115] = {.lex_state = 445, .external_lex_state = 2},
  [11116] = {.lex_state = 445, .external_lex_state = 2},
  [11117] = {.lex_state = 445, .external_lex_state = 2},
  [11118] = {.lex_state = 15, .external_lex_state = 2},
  [11119] = {.lex_state = 15, .external_lex_state = 2},
  [11120] = {.lex_state = 229, .external_lex_state = 2},
  [11121] = {.lex_state = 14, .external_lex_state = 2},
  [11122] = {.lex_state = 445, .external_lex_state = 2},
  [11123] = {.lex_state = 15, .external_lex_state = 2},
  [11124] = {.lex_state = 13, .external_lex_state = 2},
  [11125] = {.lex_state = 15, .external_lex_state = 2},
  [11126] = {.lex_state = 445, .external_lex_state = 2},
  [11127] = {.lex_state = 13, .external_lex_state = 2},
  [11128] = {.lex_state = 445, .external_lex_state = 2},
  [11129] = {.lex_state = 14, .external_lex_state = 2},
  [11130] = {.lex_state = 445, .external_lex_state = 2},
  [11131] = {.lex_state = 17, .external_lex_state = 2},
  [11132] = {.lex_state = 13, .external_lex_state = 2},
  [11133] = {.lex_state = 437, .external_lex_state = 2},
  [11134] = {.lex_state = 450, .external_lex_state = 2},
  [11135] = {.lex_state = 17, .external_lex_state = 2},
  [11136] = {.lex_state = 229, .external_lex_state = 2},
  [11137] = {.lex_state = 220, .external_lex_state = 2},
  [11138] = {.lex_state = 445, .external_lex_state = 2},
  [11139] = {.lex_state = 445, .external_lex_state = 2},
  [11140] = {.lex_state = 445, .external_lex_state = 2},
  [11141] = {.lex_state = 17, .external_lex_state = 2},
  [11142] = {.lex_state = 445, .external_lex_state = 2},
  [11143] = {.lex_state = 445, .external_lex_state = 2},
  [11144] = {.lex_state = 445, .external_lex_state = 2},
  [11145] = {.lex_state = 15, .external_lex_state = 2},
  [11146] = {.lex_state = 438, .external_lex_state = 2},
  [11147] = {.lex_state = 26, .external_lex_state = 2},
  [11148] = {.lex_state = 438, .external_lex_state = 2},
  [11149] = {.lex_state = 438, .external_lex_state = 2},
  [11150] = {.lex_state = 438, .external_lex_state = 2},
  [11151] = {.lex_state = 445, .external_lex_state = 2},
  [11152] = {.lex_state = 445, .external_lex_state = 2},
  [11153] = {.lex_state = 445, .external_lex_state = 2},
  [11154] = {.lex_state = 17, .external_lex_state = 2},
  [11155] = {.lex_state = 445, .external_lex_state = 2},
  [11156] = {.lex_state = 445, .external_lex_state = 2},
  [11157] = {.lex_state = 15, .external_lex_state = 2},
  [11158] = {.lex_state = 445, .external_lex_state = 2},
  [11159] = {.lex_state = 445, .external_lex_state = 2},
  [11160] = {.lex_state = 445, .external_lex_state = 2},
  [11161] = {.lex_state = 445, .external_lex_state = 2},
  [11162] = {.lex_state = 445, .external_lex_state = 2},
  [11163] = {.lex_state = 229, .external_lex_state = 2},
  [11164] = {.lex_state = 235, .external_lex_state = 2},
  [11165] = {.lex_state = 445, .external_lex_state = 2},
  [11166] = {.lex_state = 445, .external_lex_state = 2},
  [11167] = {.lex_state = 445, .external_lex_state = 2},
  [11168] = {.lex_state = 173, .external_lex_state = 2},
  [11169] = {.lex_state = 437, .external_lex_state = 3},
  [11170] = {.lex_state = 14, .external_lex_state = 2},
  [11171] = {.lex_state = 445, .external_lex_state = 2},
  [11172] = {.lex_state = 14, .external_lex_state = 2},
  [11173] = {.lex_state = 15, .external_lex_state = 2},
  [11174] = {.lex_state = 445, .external_lex_state = 2},
  [11175] = {.lex_state = 438, .external_lex_state = 2},
  [11176] = {.lex_state = 445, .external_lex_state = 2},
  [11177] = {.lex_state = 221, .external_lex_state = 2},
  [11178] = {.lex_state = 15, .external_lex_state = 2},
  [11179] = {.lex_state = 13, .external_lex_state = 2},
  [11180] = {.lex_state = 26, .external_lex_state = 2},
  [11181] = {.lex_state = 26, .external_lex_state = 2},
  [11182] = {.lex_state = 26, .external_lex_state = 2},
  [11183] = {.lex_state = 235, .external_lex_state = 2},
  [11184] = {.lex_state = 445, .external_lex_state = 2},
  [11185] = {.lex_state = 438, .external_lex_state = 2},
  [11186] = {.lex_state = 438, .external_lex_state = 2},
  [11187] = {.lex_state = 438, .external_lex_state = 2},
  [11188] = {.lex_state = 438, .external_lex_state = 2},
  [11189] = {.lex_state = 438, .external_lex_state = 2},
  [11190] = {.lex_state = 17, .external_lex_state = 2},
  [11191] = {.lex_state = 438, .external_lex_state = 2},
  [11192] = {.lex_state = 445, .external_lex_state = 2},
  [11193] = {.lex_state = 445, .external_lex_state = 2},
  [11194] = {.lex_state = 445, .external_lex_state = 2},
  [11195] = {.lex_state = 445, .external_lex_state = 2},
  [11196] = {.lex_state = 445, .external_lex_state = 2},
  [11197] = {.lex_state = 445, .external_lex_state = 2},
  [11198] = {.lex_state = 52, .external_lex_state = 3},
  [11199] = {.lex_state = 445, .external_lex_state = 2},
  [11200] = {.lex_state = 182, .external_lex_state = 2},
  [11201] = {.lex_state = 445, .external_lex_state = 2},
  [11202] = {.lex_state = 438, .external_lex_state = 2},
  [11203] = {.lex_state = 438, .external_lex_state = 2},
  [11204] = {.lex_state = 438, .external_lex_state = 2},
  [11205] = {.lex_state = 17, .external_lex_state = 2},
  [11206] = {.lex_state = 15, .external_lex_state = 2},
  [11207] = {.lex_state = 15, .external_lex_state = 2},
  [11208] = {.lex_state = 15, .external_lex_state = 2},
  [11209] = {.lex_state = 445, .external_lex_state = 2},
  [11210] = {.lex_state = 445, .external_lex_state = 2},
  [11211] = {.lex_state = 235, .external_lex_state = 2},
  [11212] = {.lex_state = 445, .external_lex_state = 2},
  [11213] = {.lex_state = 445, .external_lex_state = 2},
  [11214] = {.lex_state = 438, .external_lex_state = 2},
  [11215] = {.lex_state = 445, .external_lex_state = 2},
  [11216] = {.lex_state = 445, .external_lex_state = 2},
  [11217] = {.lex_state = 445, .external_lex_state = 2},
  [11218] = {.lex_state = 220, .external_lex_state = 2},
  [11219] = {.lex_state = 220, .external_lex_state = 2},
  [11220] = {.lex_state = 235, .external_lex_state = 2},
  [11221] = {.lex_state = 445, .external_lex_state = 2},
  [11222] = {.lex_state = 445, .external_lex_state = 2},
  [11223] = {.lex_state = 220, .external_lex_state = 2},
  [11224] = {.lex_state = 445, .external_lex_state = 2},
  [11225] = {.lex_state = 178, .external_lex_state = 2},
  [11226] = {.lex_state = 445, .external_lex_state = 2},
  [11227] = {.lex_state = 445, .external_lex_state = 2},
  [11228] = {.lex_state = 15, .external_lex_state = 2},
  [11229] = {.lex_state = 445, .external_lex_state = 2},
  [11230] = {.lex_state = 445, .external_lex_state = 2},
  [11231] = {.lex_state = 445, .external_lex_state = 2},
  [11232] = {.lex_state = 445, .external_lex_state = 2},
  [11233] = {.lex_state = 229, .external_lex_state = 2},
  [11234] = {.lex_state = 445, .external_lex_state = 2},
  [11235] = {.lex_state = 229, .external_lex_state = 2},
  [11236] = {.lex_state = 445, .external_lex_state = 2},
  [11237] = {.lex_state = 445, .external_lex_state = 2},
  [11238] = {.lex_state = 445, .external_lex_state = 2},
  [11239] = {.lex_state = 445, .external_lex_state = 2},
  [11240] = {.lex_state = 445, .external_lex_state = 2},
  [11241] = {.lex_state = 445, .external_lex_state = 2},
  [11242] = {.lex_state = 445, .external_lex_state = 2},
  [11243] = {.lex_state = 445, .external_lex_state = 2},
  [11244] = {.lex_state = 450, .external_lex_state = 2},
  [11245] = {.lex_state = 445, .external_lex_state = 2},
  [11246] = {.lex_state = 445, .external_lex_state = 2},
  [11247] = {.lex_state = 13, .external_lex_state = 2},
  [11248] = {.lex_state = 445, .external_lex_state = 2},
  [11249] = {.lex_state = 226, .external_lex_state = 2},
  [11250] = {.lex_state = 226, .external_lex_state = 2},
  [11251] = {.lex_state = 239, .external_lex_state = 2},
  [11252] = {.lex_state = 241, .external_lex_state = 2},
  [11253] = {.lex_state = 445, .external_lex_state = 2},
  [11254] = {.lex_state = 450, .external_lex_state = 2},
  [11255] = {.lex_state = 450, .external_lex_state = 2},
  [11256] = {.lex_state = 239, .external_lex_state = 2},
  [11257] = {.lex_state = 239, .external_lex_state = 2},
  [11258] = {.lex_state = 226, .external_lex_state = 2},
  [11259] = {.lex_state = 445, .external_lex_state = 2},
  [11260] = {.lex_state = 241, .external_lex_state = 2},
  [11261] = {.lex_state = 444, .external_lex_state = 2},
  [11262] = {.lex_state = 241, .external_lex_state = 2},
  [11263] = {.lex_state = 14, .external_lex_state = 2},
  [11264] = {.lex_state = 226, .external_lex_state = 2},
  [11265] = {.lex_state = 241, .external_lex_state = 2},
  [11266] = {.lex_state = 445, .external_lex_state = 2},
  [11267] = {.lex_state = 445, .external_lex_state = 2},
  [11268] = {.lex_state = 226, .external_lex_state = 2},
  [11269] = {.lex_state = 226, .external_lex_state = 2},
  [11270] = {.lex_state = 241, .external_lex_state = 2},
  [11271] = {.lex_state = 445, .external_lex_state = 2},
  [11272] = {.lex_state = 6, .external_lex_state = 3},
  [11273] = {.lex_state = 241, .external_lex_state = 2},
  [11274] = {.lex_state = 26, .external_lex_state = 2},
  [11275] = {.lex_state = 437, .external_lex_state = 2},
  [11276] = {.lex_state = 26, .external_lex_state = 2},
  [11277] = {.lex_state = 445, .external_lex_state = 2},
  [11278] = {.lex_state = 239, .external_lex_state = 2},
  [11279] = {.lex_state = 26, .external_lex_state = 2},
  [11280] = {.lex_state = 26, .external_lex_state = 2},
  [11281] = {.lex_state = 26, .external_lex_state = 2},
  [11282] = {.lex_state = 226, .external_lex_state = 2},
  [11283] = {.lex_state = 222, .external_lex_state = 2},
  [11284] = {.lex_state = 450, .external_lex_state = 2},
  [11285] = {.lex_state = 14, .external_lex_state = 2},
  [11286] = {.lex_state = 241, .external_lex_state = 2},
  [11287] = {.lex_state = 241, .external_lex_state = 2},
  [11288] = {.lex_state = 26, .external_lex_state = 2},
  [11289] = {.lex_state = 451, .external_lex_state = 2},
  [11290] = {.lex_state = 451, .external_lex_state = 2},
  [11291] = {.lex_state = 239, .external_lex_state = 2},
  [11292] = {.lex_state = 226, .external_lex_state = 2},
  [11293] = {.lex_state = 445, .external_lex_state = 2},
  [11294] = {.lex_state = 226, .external_lex_state = 2},
  [11295] = {.lex_state = 239, .external_lex_state = 2},
  [11296] = {.lex_state = 226, .external_lex_state = 2},
  [11297] = {.lex_state = 445, .external_lex_state = 2},
  [11298] = {.lex_state = 451, .external_lex_state = 2},
  [11299] = {.lex_state = 226, .external_lex_state = 2},
  [11300] = {.lex_state = 241, .external_lex_state = 2},
  [11301] = {.lex_state = 437, .external_lex_state = 2},
  [11302] = {.lex_state = 239, .external_lex_state = 2},
  [11303] = {.lex_state = 222, .external_lex_state = 2},
  [11304] = {.lex_state = 26, .external_lex_state = 2},
  [11305] = {.lex_state = 14, .external_lex_state = 2},
  [11306] = {.lex_state = 241, .external_lex_state = 2},
  [11307] = {.lex_state = 437, .external_lex_state = 2},
  [11308] = {.lex_state = 241, .external_lex_state = 2},
  [11309] = {.lex_state = 445, .external_lex_state = 2},
  [11310] = {.lex_state = 226, .external_lex_state = 2},
  [11311] = {.lex_state = 450, .external_lex_state = 2},
  [11312] = {.lex_state = 450, .external_lex_state = 2},
  [11313] = {.lex_state = 450, .external_lex_state = 2},
  [11314] = {.lex_state = 450, .external_lex_state = 2},
  [11315] = {.lex_state = 450, .external_lex_state = 2},
  [11316] = {.lex_state = 241, .external_lex_state = 2},
  [11317] = {.lex_state = 226, .external_lex_state = 2},
  [11318] = {.lex_state = 226, .external_lex_state = 2},
  [11319] = {.lex_state = 26, .external_lex_state = 2},
  [11320] = {.lex_state = 26, .external_lex_state = 2},
  [11321] = {.lex_state = 445, .external_lex_state = 2},
  [11322] = {.lex_state = 239, .external_lex_state = 2},
  [11323] = {.lex_state = 239, .external_lex_state = 2},
  [11324] = {.lex_state = 241, .external_lex_state = 2},
  [11325] = {.lex_state = 445, .external_lex_state = 2},
  [11326] = {.lex_state = 26, .external_lex_state = 2},
  [11327] = {.lex_state = 26, .external_lex_state = 2},
  [11328] = {.lex_state = 26, .external_lex_state = 2},
  [11329] = {.lex_state = 26, .external_lex_state = 2},
  [11330] = {.lex_state = 222, .external_lex_state = 2},
  [11331] = {.lex_state = 14, .external_lex_state = 2},
  [11332] = {.lex_state = 239, .external_lex_state = 2},
  [11333] = {.lex_state = 235, .external_lex_state = 2},
  [11334] = {.lex_state = 239, .external_lex_state = 2},
  [11335] = {.lex_state = 226, .external_lex_state = 2},
  [11336] = {.lex_state = 450, .external_lex_state = 2},
  [11337] = {.lex_state = 450, .external_lex_state = 2},
  [11338] = {.lex_state = 445, .external_lex_state = 2},
  [11339] = {.lex_state = 241, .external_lex_state = 2},
  [11340] = {.lex_state = 450, .external_lex_state = 2},
  [11341] = {.lex_state = 241, .external_lex_state = 2},
  [11342] = {.lex_state = 226, .external_lex_state = 2},
  [11343] = {.lex_state = 226, .external_lex_state = 2},
  [11344] = {.lex_state = 26, .external_lex_state = 2},
  [11345] = {.lex_state = 445, .external_lex_state = 2},
  [11346] = {.lex_state = 26, .external_lex_state = 2},
  [11347] = {.lex_state = 241, .external_lex_state = 2},
  [11348] = {.lex_state = 445, .external_lex_state = 2},
  [11349] = {.lex_state = 241, .external_lex_state = 2},
  [11350] = {.lex_state = 26, .external_lex_state = 2},
  [11351] = {.lex_state = 26, .external_lex_state = 2},
  [11352] = {.lex_state = 223, .external_lex_state = 2},
  [11353] = {.lex_state = 241, .external_lex_state = 2},
  [11354] = {.lex_state = 226, .external_lex_state = 2},
  [11355] = {.lex_state = 241, .external_lex_state = 2},
  [11356] = {.lex_state = 26, .external_lex_state = 2},
  [11357] = {.lex_state = 26, .external_lex_state = 2},
  [11358] = {.lex_state = 445, .external_lex_state = 2},
  [11359] = {.lex_state = 241, .external_lex_state = 2},
  [11360] = {.lex_state = 226, .external_lex_state = 2},
  [11361] = {.lex_state = 26, .external_lex_state = 2},
  [11362] = {.lex_state = 26, .external_lex_state = 2},
  [11363] = {.lex_state = 241, .external_lex_state = 2},
  [11364] = {.lex_state = 450, .external_lex_state = 2},
  [11365] = {.lex_state = 450, .external_lex_state = 2},
  [11366] = {.lex_state = 226, .external_lex_state = 2},
  [11367] = {.lex_state = 445, .external_lex_state = 2},
  [11368] = {.lex_state = 14, .external_lex_state = 2},
  [11369] = {.lex_state = 226, .external_lex_state = 2},
  [11370] = {.lex_state = 445, .external_lex_state = 2},
  [11371] = {.lex_state = 437, .external_lex_state = 2},
  [11372] = {.lex_state = 226, .external_lex_state = 2},
  [11373] = {.lex_state = 226, .external_lex_state = 2},
  [11374] = {.lex_state = 241, .external_lex_state = 2},
  [11375] = {.lex_state = 14, .external_lex_state = 2},
  [11376] = {.lex_state = 450, .external_lex_state = 2},
  [11377] = {.lex_state = 450, .external_lex_state = 2},
  [11378] = {.lex_state = 226, .external_lex_state = 2},
  [11379] = {.lex_state = 226, .external_lex_state = 2},
  [11380] = {.lex_state = 239, .external_lex_state = 2},
  [11381] = {.lex_state = 239, .external_lex_state = 2},
  [11382] = {.lex_state = 26, .external_lex_state = 2},
  [11383] = {.lex_state = 451, .external_lex_state = 2},
  [11384] = {.lex_state = 175, .external_lex_state = 3},
  [11385] = {.lex_state = 239, .external_lex_state = 2},
  [11386] = {.lex_state = 235, .external_lex_state = 2},
  [11387] = {.lex_state = 221, .external_lex_state = 2},
  [11388] = {.lex_state = 239, .external_lex_state = 2},
  [11389] = {.lex_state = 14, .external_lex_state = 2},
  [11390] = {.lex_state = 26, .external_lex_state = 2},
  [11391] = {.lex_state = 445, .external_lex_state = 2},
  [11392] = {.lex_state = 445, .external_lex_state = 2},
  [11393] = {.lex_state = 450, .external_lex_state = 2},
  [11394] = {.lex_state = 226, .external_lex_state = 2},
  [11395] = {.lex_state = 14, .external_lex_state = 2},
  [11396] = {.lex_state = 437, .external_lex_state = 2},
  [11397] = {.lex_state = 14, .external_lex_state = 2},
  [11398] = {.lex_state = 239, .external_lex_state = 2},
  [11399] = {.lex_state = 239, .external_lex_state = 2},
  [11400] = {.lex_state = 226, .external_lex_state = 2},
  [11401] = {.lex_state = 450, .external_lex_state = 2},
  [11402] = {.lex_state = 14, .external_lex_state = 2},
  [11403] = {.lex_state = 226, .external_lex_state = 2},
  [11404] = {.lex_state = 14, .external_lex_state = 2},
  [11405] = {.lex_state = 437, .external_lex_state = 2},
  [11406] = {.lex_state = 241, .external_lex_state = 2},
  [11407] = {.lex_state = 445, .external_lex_state = 2},
  [11408] = {.lex_state = 26, .external_lex_state = 2},
  [11409] = {.lex_state = 239, .external_lex_state = 2},
  [11410] = {.lex_state = 226, .external_lex_state = 2},
  [11411] = {.lex_state = 241, .external_lex_state = 2},
  [11412] = {.lex_state = 445, .external_lex_state = 2},
  [11413] = {.lex_state = 226, .external_lex_state = 2},
  [11414] = {.lex_state = 445, .external_lex_state = 2},
  [11415] = {.lex_state = 239, .external_lex_state = 2},
  [11416] = {.lex_state = 239, .external_lex_state = 2},
  [11417] = {.lex_state = 445, .external_lex_state = 2},
  [11418] = {.lex_state = 13, .external_lex_state = 2},
  [11419] = {.lex_state = 445, .external_lex_state = 2},
  [11420] = {.lex_state = 445, .external_lex_state = 2},
  [11421] = {.lex_state = 445, .external_lex_state = 2},
  [11422] = {.lex_state = 226, .external_lex_state = 2},
  [11423] = {.lex_state = 445, .external_lex_state = 2},
  [11424] = {.lex_state = 14, .external_lex_state = 2},
  [11425] = {.lex_state = 226, .external_lex_state = 2},
  [11426] = {.lex_state = 445, .external_lex_state = 2},
  [11427] = {.lex_state = 445, .external_lex_state = 2},
  [11428] = {.lex_state = 241, .external_lex_state = 2},
  [11429] = {.lex_state = 26, .external_lex_state = 2},
  [11430] = {.lex_state = 445, .external_lex_state = 2},
  [11431] = {.lex_state = 445, .external_lex_state = 2},
  [11432] = {.lex_state = 239, .external_lex_state = 2},
  [11433] = {.lex_state = 241, .external_lex_state = 2},
  [11434] = {.lex_state = 437, .external_lex_state = 2},
  [11435] = {.lex_state = 226, .external_lex_state = 2},
  [11436] = {.lex_state = 226, .external_lex_state = 2},
  [11437] = {.lex_state = 239, .external_lex_state = 2},
  [11438] = {.lex_state = 239, .external_lex_state = 2},
  [11439] = {.lex_state = 241, .external_lex_state = 2},
  [11440] = {.lex_state = 437, .external_lex_state = 2},
  [11441] = {.lex_state = 226, .external_lex_state = 2},
  [11442] = {.lex_state = 239, .external_lex_state = 2},
  [11443] = {.lex_state = 445, .external_lex_state = 2},
  [11444] = {.lex_state = 239, .external_lex_state = 2},
  [11445] = {.lex_state = 239, .external_lex_state = 2},
  [11446] = {.lex_state = 437, .external_lex_state = 2},
  [11447] = {.lex_state = 26, .external_lex_state = 2},
  [11448] = {.lex_state = 14, .external_lex_state = 2},
  [11449] = {.lex_state = 445, .external_lex_state = 2},
  [11450] = {.lex_state = 239, .external_lex_state = 2},
  [11451] = {.lex_state = 26, .external_lex_state = 2},
  [11452] = {.lex_state = 445, .external_lex_state = 2},
  [11453] = {.lex_state = 239, .external_lex_state = 2},
  [11454] = {.lex_state = 445, .external_lex_state = 2},
  [11455] = {.lex_state = 437, .external_lex_state = 2},
  [11456] = {.lex_state = 26, .external_lex_state = 2},
  [11457] = {.lex_state = 235, .external_lex_state = 2},
  [11458] = {.lex_state = 445, .external_lex_state = 2},
  [11459] = {.lex_state = 241, .external_lex_state = 2},
  [11460] = {.lex_state = 26, .external_lex_state = 2},
  [11461] = {.lex_state = 445, .external_lex_state = 2},
  [11462] = {.lex_state = 239, .external_lex_state = 2},
  [11463] = {.lex_state = 239, .external_lex_state = 2},
  [11464] = {.lex_state = 226, .external_lex_state = 2},
  [11465] = {.lex_state = 450, .external_lex_state = 2},
  [11466] = {.lex_state = 226, .external_lex_state = 2},
  [11467] = {.lex_state = 226, .external_lex_state = 2},
  [11468] = {.lex_state = 450, .external_lex_state = 2},
  [11469] = {.lex_state = 450, .external_lex_state = 2},
  [11470] = {.lex_state = 450, .external_lex_state = 2},
  [11471] = {.lex_state = 450, .external_lex_state = 2},
  [11472] = {.lex_state = 450, .external_lex_state = 2},
  [11473] = {.lex_state = 445, .external_lex_state = 2},
  [11474] = {.lex_state = 450, .external_lex_state = 2},
  [11475] = {.lex_state = 226, .external_lex_state = 2},
  [11476] = {.lex_state = 445, .external_lex_state = 2},
  [11477] = {.lex_state = 26, .external_lex_state = 2},
  [11478] = {.lex_state = 26, .external_lex_state = 2},
  [11479] = {.lex_state = 437, .external_lex_state = 2},
  [11480] = {.lex_state = 26, .external_lex_state = 2},
  [11481] = {.lex_state = 14, .external_lex_state = 2},
  [11482] = {.lex_state = 26, .external_lex_state = 2},
  [11483] = {.lex_state = 445, .external_lex_state = 2},
  [11484] = {.lex_state = 445, .external_lex_state = 2},
  [11485] = {.lex_state = 450, .external_lex_state = 2},
  [11486] = {.lex_state = 26, .external_lex_state = 2},
  [11487] = {.lex_state = 445, .external_lex_state = 2},
  [11488] = {.lex_state = 26, .external_lex_state = 2},
  [11489] = {.lex_state = 437, .external_lex_state = 2},
  [11490] = {.lex_state = 241, .external_lex_state = 2},
  [11491] = {.lex_state = 239, .external_lex_state = 2},
  [11492] = {.lex_state = 239, .external_lex_state = 2},
  [11493] = {.lex_state = 445, .external_lex_state = 2},
  [11494] = {.lex_state = 226, .external_lex_state = 2},
  [11495] = {.lex_state = 226, .external_lex_state = 2},
  [11496] = {.lex_state = 445, .external_lex_state = 2},
  [11497] = {.lex_state = 226, .external_lex_state = 2},
  [11498] = {.lex_state = 241, .external_lex_state = 2},
  [11499] = {.lex_state = 239, .external_lex_state = 2},
  [11500] = {.lex_state = 445, .external_lex_state = 2},
  [11501] = {.lex_state = 445, .external_lex_state = 2},
  [11502] = {.lex_state = 226, .external_lex_state = 2},
  [11503] = {.lex_state = 239, .external_lex_state = 2},
  [11504] = {.lex_state = 445, .external_lex_state = 2},
  [11505] = {.lex_state = 239, .external_lex_state = 2},
  [11506] = {.lex_state = 241, .external_lex_state = 2},
  [11507] = {.lex_state = 450, .external_lex_state = 2},
  [11508] = {.lex_state = 450, .external_lex_state = 2},
  [11509] = {.lex_state = 450, .external_lex_state = 2},
  [11510] = {.lex_state = 226, .external_lex_state = 2},
  [11511] = {.lex_state = 14, .external_lex_state = 2},
  [11512] = {.lex_state = 445, .external_lex_state = 2},
  [11513] = {.lex_state = 226, .external_lex_state = 2},
  [11514] = {.lex_state = 14, .external_lex_state = 2},
  [11515] = {.lex_state = 223, .external_lex_state = 2},
  [11516] = {.lex_state = 445, .external_lex_state = 2},
  [11517] = {.lex_state = 241, .external_lex_state = 2},
  [11518] = {.lex_state = 450, .external_lex_state = 2},
  [11519] = {.lex_state = 14, .external_lex_state = 2},
  [11520] = {.lex_state = 239, .external_lex_state = 2},
  [11521] = {.lex_state = 241, .external_lex_state = 2},
  [11522] = {.lex_state = 445, .external_lex_state = 2},
  [11523] = {.lex_state = 7, .external_lex_state = 2},
  [11524] = {.lex_state = 445, .external_lex_state = 2},
  [11525] = {.lex_state = 226, .external_lex_state = 2},
  [11526] = {.lex_state = 226, .external_lex_state = 2},
  [11527] = {.lex_state = 445, .external_lex_state = 2},
  [11528] = {.lex_state = 223, .external_lex_state = 2},
  [11529] = {.lex_state = 241, .external_lex_state = 2},
  [11530] = {.lex_state = 226, .external_lex_state = 2},
  [11531] = {.lex_state = 226, .external_lex_state = 2},
  [11532] = {.lex_state = 437, .external_lex_state = 2},
  [11533] = {.lex_state = 241, .external_lex_state = 2},
  [11534] = {.lex_state = 241, .external_lex_state = 2},
  [11535] = {.lex_state = 450, .external_lex_state = 2},
  [11536] = {.lex_state = 226, .external_lex_state = 2},
  [11537] = {.lex_state = 226, .external_lex_state = 2},
  [11538] = {.lex_state = 239, .external_lex_state = 2},
  [11539] = {.lex_state = 226, .external_lex_state = 2},
  [11540] = {.lex_state = 226, .external_lex_state = 2},
  [11541] = {.lex_state = 226, .external_lex_state = 2},
  [11542] = {.lex_state = 226, .external_lex_state = 2},
  [11543] = {.lex_state = 226, .external_lex_state = 2},
  [11544] = {.lex_state = 445, .external_lex_state = 2},
  [11545] = {.lex_state = 445, .external_lex_state = 2},
  [11546] = {.lex_state = 445, .external_lex_state = 2},
  [11547] = {.lex_state = 445, .external_lex_state = 2},
  [11548] = {.lex_state = 445, .external_lex_state = 2},
  [11549] = {.lex_state = 226, .external_lex_state = 2},
  [11550] = {.lex_state = 226, .external_lex_state = 2},
  [11551] = {.lex_state = 226, .external_lex_state = 2},
  [11552] = {.lex_state = 226, .external_lex_state = 2},
  [11553] = {.lex_state = 450, .external_lex_state = 2},
  [11554] = {.lex_state = 52, .external_lex_state = 3},
  [11555] = {.lex_state = 226, .external_lex_state = 2},
  [11556] = {.lex_state = 226, .external_lex_state = 2},
  [11557] = {.lex_state = 226, .external_lex_state = 2},
  [11558] = {.lex_state = 226, .external_lex_state = 2},
  [11559] = {.lex_state = 226, .external_lex_state = 2},
  [11560] = {.lex_state = 226, .external_lex_state = 2},
  [11561] = {.lex_state = 226, .external_lex_state = 2},
  [11562] = {.lex_state = 226, .external_lex_state = 2},
  [11563] = {.lex_state = 226, .external_lex_state = 2},
  [11564] = {.lex_state = 226, .external_lex_state = 2},
  [11565] = {.lex_state = 220, .external_lex_state = 2},
  [11566] = {.lex_state = 226, .external_lex_state = 2},
  [11567] = {.lex_state = 226, .external_lex_state = 2},
  [11568] = {.lex_state = 241, .external_lex_state = 2},
  [11569] = {.lex_state = 445, .external_lex_state = 2},
  [11570] = {.lex_state = 445, .external_lex_state = 2},
  [11571] = {.lex_state = 445, .external_lex_state = 2},
  [11572] = {.lex_state = 445, .external_lex_state = 2},
  [11573] = {.lex_state = 437, .external_lex_state = 2},
  [11574] = {.lex_state = 445, .external_lex_state = 2},
  [11575] = {.lex_state = 15, .external_lex_state = 2},
  [11576] = {.lex_state = 235, .external_lex_state = 2},
  [11577] = {.lex_state = 235, .external_lex_state = 2},
  [11578] = {.lex_state = 15, .external_lex_state = 2},
  [11579] = {.lex_state = 445, .external_lex_state = 2},
  [11580] = {.lex_state = 445, .external_lex_state = 2},
  [11581] = {.lex_state = 445, .external_lex_state = 2},
  [11582] = {.lex_state = 235, .external_lex_state = 2},
  [11583] = {.lex_state = 445, .external_lex_state = 2},
  [11584] = {.lex_state = 445, .external_lex_state = 2},
  [11585] = {.lex_state = 235, .external_lex_state = 2},
  [11586] = {.lex_state = 445, .external_lex_state = 2},
  [11587] = {.lex_state = 445, .external_lex_state = 2},
  [11588] = {.lex_state = 445, .external_lex_state = 2},
  [11589] = {.lex_state = 437, .external_lex_state = 2},
  [11590] = {.lex_state = 15, .external_lex_state = 2},
  [11591] = {.lex_state = 15, .external_lex_state = 2},
  [11592] = {.lex_state = 15, .external_lex_state = 2},
  [11593] = {.lex_state = 15, .external_lex_state = 2},
  [11594] = {.lex_state = 437, .external_lex_state = 2},
  [11595] = {.lex_state = 15, .external_lex_state = 2},
  [11596] = {.lex_state = 445, .external_lex_state = 2},
  [11597] = {.lex_state = 235, .external_lex_state = 2},
  [11598] = {.lex_state = 437, .external_lex_state = 2},
  [11599] = {.lex_state = 437, .external_lex_state = 2},
  [11600] = {.lex_state = 445, .external_lex_state = 2},
  [11601] = {.lex_state = 437, .external_lex_state = 2},
  [11602] = {.lex_state = 15, .external_lex_state = 2},
  [11603] = {.lex_state = 15, .external_lex_state = 2},
  [11604] = {.lex_state = 450, .external_lex_state = 2},
  [11605] = {.lex_state = 437, .external_lex_state = 2},
  [11606] = {.lex_state = 437, .external_lex_state = 3},
  [11607] = {.lex_state = 437, .external_lex_state = 2},
  [11608] = {.lex_state = 440, .external_lex_state = 2},
  [11609] = {.lex_state = 445, .external_lex_state = 2},
  [11610] = {.lex_state = 437, .external_lex_state = 2},
  [11611] = {.lex_state = 27, .external_lex_state = 2},
  [11612] = {.lex_state = 440, .external_lex_state = 2},
  [11613] = {.lex_state = 235, .external_lex_state = 2},
  [11614] = {.lex_state = 437, .external_lex_state = 2},
  [11615] = {.lex_state = 437, .external_lex_state = 2},
  [11616] = {.lex_state = 15, .external_lex_state = 2},
  [11617] = {.lex_state = 450, .external_lex_state = 2},
  [11618] = {.lex_state = 6, .external_lex_state = 2},
  [11619] = {.lex_state = 15, .external_lex_state = 2},
  [11620] = {.lex_state = 15, .external_lex_state = 2},
  [11621] = {.lex_state = 15, .external_lex_state = 2},
  [11622] = {.lex_state = 437, .external_lex_state = 2},
  [11623] = {.lex_state = 15, .external_lex_state = 2},
  [11624] = {.lex_state = 15, .external_lex_state = 2},
  [11625] = {.lex_state = 17, .external_lex_state = 2},
  [11626] = {.lex_state = 235, .external_lex_state = 2},
  [11627] = {.lex_state = 445, .external_lex_state = 2},
  [11628] = {.lex_state = 445, .external_lex_state = 2},
  [11629] = {.lex_state = 445, .external_lex_state = 2},
  [11630] = {.lex_state = 437, .external_lex_state = 2},
  [11631] = {.lex_state = 235, .external_lex_state = 2},
  [11632] = {.lex_state = 437, .external_lex_state = 2},
  [11633] = {.lex_state = 450, .external_lex_state = 2},
  [11634] = {.lex_state = 229, .external_lex_state = 2},
  [11635] = {.lex_state = 445, .external_lex_state = 2},
  [11636] = {.lex_state = 15, .external_lex_state = 2},
  [11637] = {.lex_state = 437, .external_lex_state = 2},
  [11638] = {.lex_state = 235, .external_lex_state = 2},
  [11639] = {.lex_state = 445, .external_lex_state = 2},
  [11640] = {.lex_state = 437, .external_lex_state = 2},
  [11641] = {.lex_state = 437, .external_lex_state = 2},
  [11642] = {.lex_state = 437, .external_lex_state = 2},
  [11643] = {.lex_state = 437, .external_lex_state = 2},
  [11644] = {.lex_state = 235, .external_lex_state = 2},
  [11645] = {.lex_state = 437, .external_lex_state = 2},
  [11646] = {.lex_state = 235, .external_lex_state = 2},
  [11647] = {.lex_state = 437, .external_lex_state = 2},
  [11648] = {.lex_state = 437, .external_lex_state = 3},
  [11649] = {.lex_state = 445, .external_lex_state = 2},
  [11650] = {.lex_state = 437, .external_lex_state = 2},
  [11651] = {.lex_state = 17, .external_lex_state = 2},
  [11652] = {.lex_state = 445, .external_lex_state = 2},
  [11653] = {.lex_state = 445, .external_lex_state = 2},
  [11654] = {.lex_state = 445, .external_lex_state = 2},
  [11655] = {.lex_state = 235, .external_lex_state = 2},
  [11656] = {.lex_state = 445, .external_lex_state = 2},
  [11657] = {.lex_state = 437, .external_lex_state = 2},
  [11658] = {.lex_state = 15, .external_lex_state = 2},
  [11659] = {.lex_state = 437, .external_lex_state = 2},
  [11660] = {.lex_state = 445, .external_lex_state = 2},
  [11661] = {.lex_state = 235, .external_lex_state = 2},
  [11662] = {.lex_state = 445, .external_lex_state = 2},
  [11663] = {.lex_state = 437, .external_lex_state = 2},
  [11664] = {.lex_state = 440, .external_lex_state = 2},
  [11665] = {.lex_state = 445, .external_lex_state = 2},
  [11666] = {.lex_state = 445, .external_lex_state = 2},
  [11667] = {.lex_state = 445, .external_lex_state = 2},
  [11668] = {.lex_state = 15, .external_lex_state = 2},
  [11669] = {.lex_state = 17, .external_lex_state = 2},
  [11670] = {.lex_state = 437, .external_lex_state = 2},
  [11671] = {.lex_state = 8, .external_lex_state = 2},
  [11672] = {.lex_state = 15, .external_lex_state = 2},
  [11673] = {.lex_state = 235, .external_lex_state = 2},
  [11674] = {.lex_state = 235, .external_lex_state = 2},
  [11675] = {.lex_state = 437, .external_lex_state = 3},
  [11676] = {.lex_state = 445, .external_lex_state = 2},
  [11677] = {.lex_state = 235, .external_lex_state = 2},
  [11678] = {.lex_state = 450, .external_lex_state = 2},
  [11679] = {.lex_state = 445, .external_lex_state = 2},
  [11680] = {.lex_state = 445, .external_lex_state = 2},
  [11681] = {.lex_state = 445, .external_lex_state = 2},
  [11682] = {.lex_state = 237, .external_lex_state = 2},
  [11683] = {.lex_state = 235, .external_lex_state = 2},
  [11684] = {.lex_state = 235, .external_lex_state = 2},
  [11685] = {.lex_state = 445, .external_lex_state = 2},
  [11686] = {.lex_state = 229, .external_lex_state = 2},
  [11687] = {.lex_state = 445, .external_lex_state = 2},
  [11688] = {.lex_state = 437, .external_lex_state = 2},
  [11689] = {.lex_state = 15, .external_lex_state = 2},
  [11690] = {.lex_state = 229, .external_lex_state = 2},
  [11691] = {.lex_state = 437, .external_lex_state = 2},
  [11692] = {.lex_state = 445, .external_lex_state = 2},
  [11693] = {.lex_state = 445, .external_lex_state = 2},
  [11694] = {.lex_state = 445, .external_lex_state = 2},
  [11695] = {.lex_state = 235, .external_lex_state = 2},
  [11696] = {.lex_state = 445, .external_lex_state = 2},
  [11697] = {.lex_state = 445, .external_lex_state = 2},
  [11698] = {.lex_state = 445, .external_lex_state = 2},
  [11699] = {.lex_state = 437, .external_lex_state = 2},
  [11700] = {.lex_state = 445, .external_lex_state = 2},
  [11701] = {.lex_state = 437, .external_lex_state = 2},
  [11702] = {.lex_state = 6, .external_lex_state = 2},
  [11703] = {.lex_state = 445, .external_lex_state = 2},
  [11704] = {.lex_state = 445, .external_lex_state = 2},
  [11705] = {.lex_state = 229, .external_lex_state = 2},
  [11706] = {.lex_state = 445, .external_lex_state = 2},
  [11707] = {.lex_state = 27, .external_lex_state = 2},
  [11708] = {.lex_state = 235, .external_lex_state = 2},
  [11709] = {.lex_state = 437, .external_lex_state = 2},
  [11710] = {.lex_state = 6, .external_lex_state = 2},
  [11711] = {.lex_state = 235, .external_lex_state = 2},
  [11712] = {.lex_state = 235, .external_lex_state = 2},
  [11713] = {.lex_state = 445, .external_lex_state = 2},
  [11714] = {.lex_state = 437, .external_lex_state = 2},
  [11715] = {.lex_state = 235, .external_lex_state = 2},
  [11716] = {.lex_state = 235, .external_lex_state = 2},
  [11717] = {.lex_state = 445, .external_lex_state = 2},
  [11718] = {.lex_state = 437, .external_lex_state = 2},
  [11719] = {.lex_state = 451, .external_lex_state = 2},
  [11720] = {.lex_state = 445, .external_lex_state = 2},
  [11721] = {.lex_state = 445, .external_lex_state = 2},
  [11722] = {.lex_state = 445, .external_lex_state = 2},
  [11723] = {.lex_state = 15, .external_lex_state = 2},
  [11724] = {.lex_state = 235, .external_lex_state = 2},
  [11725] = {.lex_state = 235, .external_lex_state = 2},
  [11726] = {.lex_state = 235, .external_lex_state = 2},
  [11727] = {.lex_state = 235, .external_lex_state = 2},
  [11728] = {.lex_state = 445, .external_lex_state = 2},
  [11729] = {.lex_state = 445, .external_lex_state = 2},
  [11730] = {.lex_state = 14, .external_lex_state = 2},
  [11731] = {.lex_state = 450, .external_lex_state = 2},
  [11732] = {.lex_state = 445, .external_lex_state = 2},
  [11733] = {.lex_state = 445, .external_lex_state = 2},
  [11734] = {.lex_state = 235, .external_lex_state = 2},
  [11735] = {.lex_state = 15, .external_lex_state = 2},
  [11736] = {.lex_state = 450, .external_lex_state = 2},
  [11737] = {.lex_state = 445, .external_lex_state = 2},
  [11738] = {.lex_state = 24, .external_lex_state = 3},
  [11739] = {.lex_state = 437, .external_lex_state = 2},
  [11740] = {.lex_state = 437, .external_lex_state = 2},
  [11741] = {.lex_state = 445, .external_lex_state = 2},
  [11742] = {.lex_state = 445, .external_lex_state = 2},
  [11743] = {.lex_state = 445, .external_lex_state = 2},
  [11744] = {.lex_state = 445, .external_lex_state = 2},
  [11745] = {.lex_state = 437, .external_lex_state = 2},
  [11746] = {.lex_state = 445, .external_lex_state = 2},
  [11747] = {.lex_state = 445, .external_lex_state = 2},
  [11748] = {.lex_state = 445, .external_lex_state = 2},
  [11749] = {.lex_state = 445, .external_lex_state = 2},
  [11750] = {.lex_state = 27, .external_lex_state = 2},
  [11751] = {.lex_state = 445, .external_lex_state = 2},
  [11752] = {.lex_state = 437, .external_lex_state = 2},
  [11753] = {.lex_state = 445, .external_lex_state = 2},
  [11754] = {.lex_state = 437, .external_lex_state = 2},
  [11755] = {.lex_state = 445, .external_lex_state = 2},
  [11756] = {.lex_state = 235, .external_lex_state = 2},
  [11757] = {.lex_state = 15, .external_lex_state = 2},
  [11758] = {.lex_state = 445, .external_lex_state = 2},
  [11759] = {.lex_state = 445, .external_lex_state = 2},
  [11760] = {.lex_state = 15, .external_lex_state = 2},
  [11761] = {.lex_state = 445, .external_lex_state = 2},
  [11762] = {.lex_state = 235, .external_lex_state = 2},
  [11763] = {.lex_state = 445, .external_lex_state = 2},
  [11764] = {.lex_state = 445, .external_lex_state = 2},
  [11765] = {.lex_state = 235, .external_lex_state = 2},
  [11766] = {.lex_state = 445, .external_lex_state = 2},
  [11767] = {.lex_state = 445, .external_lex_state = 2},
  [11768] = {.lex_state = 437, .external_lex_state = 2},
  [11769] = {.lex_state = 445, .external_lex_state = 2},
  [11770] = {.lex_state = 445, .external_lex_state = 2},
  [11771] = {.lex_state = 15, .external_lex_state = 2},
  [11772] = {.lex_state = 445, .external_lex_state = 2},
  [11773] = {.lex_state = 445, .external_lex_state = 2},
  [11774] = {.lex_state = 445, .external_lex_state = 2},
  [11775] = {.lex_state = 445, .external_lex_state = 2},
  [11776] = {.lex_state = 437, .external_lex_state = 2},
  [11777] = {.lex_state = 437, .external_lex_state = 2},
  [11778] = {.lex_state = 437, .external_lex_state = 2},
  [11779] = {.lex_state = 8, .external_lex_state = 2},
  [11780] = {.lex_state = 445, .external_lex_state = 2},
  [11781] = {.lex_state = 27, .external_lex_state = 2},
  [11782] = {.lex_state = 445, .external_lex_state = 2},
  [11783] = {.lex_state = 445, .external_lex_state = 2},
  [11784] = {.lex_state = 445, .external_lex_state = 2},
  [11785] = {.lex_state = 445, .external_lex_state = 2},
  [11786] = {.lex_state = 445, .external_lex_state = 2},
  [11787] = {.lex_state = 437, .external_lex_state = 2},
  [11788] = {.lex_state = 437, .external_lex_state = 2},
  [11789] = {.lex_state = 445, .external_lex_state = 2},
  [11790] = {.lex_state = 445, .external_lex_state = 2},
  [11791] = {.lex_state = 15, .external_lex_state = 2},
  [11792] = {.lex_state = 445, .external_lex_state = 2},
  [11793] = {.lex_state = 8, .external_lex_state = 2},
  [11794] = {.lex_state = 17, .external_lex_state = 2},
  [11795] = {.lex_state = 437, .external_lex_state = 2},
  [11796] = {.lex_state = 437, .external_lex_state = 2},
  [11797] = {.lex_state = 437, .external_lex_state = 2},
  [11798] = {.lex_state = 437, .external_lex_state = 2},
  [11799] = {.lex_state = 437, .external_lex_state = 2},
  [11800] = {.lex_state = 437, .external_lex_state = 2},
  [11801] = {.lex_state = 437, .external_lex_state = 2},
  [11802] = {.lex_state = 437, .external_lex_state = 2},
  [11803] = {.lex_state = 437, .external_lex_state = 2},
  [11804] = {.lex_state = 437, .external_lex_state = 2},
  [11805] = {.lex_state = 437, .external_lex_state = 2},
  [11806] = {.lex_state = 437, .external_lex_state = 2},
  [11807] = {.lex_state = 437, .external_lex_state = 2},
  [11808] = {.lex_state = 437, .external_lex_state = 2},
  [11809] = {.lex_state = 437, .external_lex_state = 2},
  [11810] = {.lex_state = 437, .external_lex_state = 2},
  [11811] = {.lex_state = 437, .external_lex_state = 2},
  [11812] = {.lex_state = 437, .external_lex_state = 2},
  [11813] = {.lex_state = 437, .external_lex_state = 2},
  [11814] = {.lex_state = 437, .external_lex_state = 2},
  [11815] = {.lex_state = 437, .external_lex_state = 2},
  [11816] = {.lex_state = 437, .external_lex_state = 2},
  [11817] = {.lex_state = 15, .external_lex_state = 2},
  [11818] = {.lex_state = 437, .external_lex_state = 2},
  [11819] = {.lex_state = 22, .external_lex_state = 2},
  [11820] = {.lex_state = 437, .external_lex_state = 2},
  [11821] = {.lex_state = 14, .external_lex_state = 2},
  [11822] = {.lex_state = 437, .external_lex_state = 2},
  [11823] = {.lex_state = 437, .external_lex_state = 2},
  [11824] = {.lex_state = 437, .external_lex_state = 2},
  [11825] = {.lex_state = 437, .external_lex_state = 2},
  [11826] = {.lex_state = 437, .external_lex_state = 2},
  [11827] = {.lex_state = 437, .external_lex_state = 2},
  [11828] = {.lex_state = 437, .external_lex_state = 2},
  [11829] = {.lex_state = 437, .external_lex_state = 2},
  [11830] = {.lex_state = 437, .external_lex_state = 2},
  [11831] = {.lex_state = 22, .external_lex_state = 2},
  [11832] = {.lex_state = 437, .external_lex_state = 2},
  [11833] = {.lex_state = 437, .external_lex_state = 2},
  [11834] = {.lex_state = 437, .external_lex_state = 2},
  [11835] = {.lex_state = 178, .external_lex_state = 2},
  [11836] = {.lex_state = 437, .external_lex_state = 2},
  [11837] = {.lex_state = 445, .external_lex_state = 2},
  [11838] = {.lex_state = 445, .external_lex_state = 2},
  [11839] = {.lex_state = 437, .external_lex_state = 2},
  [11840] = {.lex_state = 437, .external_lex_state = 2},
  [11841] = {.lex_state = 437, .external_lex_state = 2},
  [11842] = {.lex_state = 437, .external_lex_state = 2},
  [11843] = {.lex_state = 437, .external_lex_state = 2},
  [11844] = {.lex_state = 437, .external_lex_state = 2},
  [11845] = {.lex_state = 437, .external_lex_state = 2},
  [11846] = {.lex_state = 437, .external_lex_state = 2},
  [11847] = {.lex_state = 437, .external_lex_state = 2},
  [11848] = {.lex_state = 14, .external_lex_state = 2},
  [11849] = {.lex_state = 445, .external_lex_state = 2},
  [11850] = {.lex_state = 437, .external_lex_state = 2},
  [11851] = {.lex_state = 437, .external_lex_state = 2},
  [11852] = {.lex_state = 24, .external_lex_state = 2},
  [11853] = {.lex_state = 437, .external_lex_state = 2},
  [11854] = {.lex_state = 437, .external_lex_state = 2},
  [11855] = {.lex_state = 437, .external_lex_state = 2},
  [11856] = {.lex_state = 437, .external_lex_state = 2},
  [11857] = {.lex_state = 437, .external_lex_state = 2},
  [11858] = {.lex_state = 437, .external_lex_state = 2},
  [11859] = {.lex_state = 437, .external_lex_state = 2},
  [11860] = {.lex_state = 437, .external_lex_state = 2},
  [11861] = {.lex_state = 257, .external_lex_state = 2},
  [11862] = {.lex_state = 437, .external_lex_state = 2},
  [11863] = {.lex_state = 437, .external_lex_state = 2},
  [11864] = {.lex_state = 437, .external_lex_state = 2},
  [11865] = {.lex_state = 178, .external_lex_state = 2},
  [11866] = {.lex_state = 437, .external_lex_state = 2},
  [11867] = {.lex_state = 437, .external_lex_state = 2},
  [11868] = {.lex_state = 437, .external_lex_state = 2},
  [11869] = {.lex_state = 437, .external_lex_state = 2},
  [11870] = {.lex_state = 437, .external_lex_state = 2},
  [11871] = {.lex_state = 437, .external_lex_state = 2},
  [11872] = {.lex_state = 437, .external_lex_state = 2},
  [11873] = {.lex_state = 437, .external_lex_state = 2},
  [11874] = {.lex_state = 437, .external_lex_state = 2},
  [11875] = {.lex_state = 437, .external_lex_state = 2},
  [11876] = {.lex_state = 437, .external_lex_state = 2},
  [11877] = {.lex_state = 437, .external_lex_state = 2},
  [11878] = {.lex_state = 437, .external_lex_state = 2},
  [11879] = {.lex_state = 437, .external_lex_state = 2},
  [11880] = {.lex_state = 437, .external_lex_state = 2},
  [11881] = {.lex_state = 437, .external_lex_state = 2},
  [11882] = {.lex_state = 437, .external_lex_state = 2},
  [11883] = {.lex_state = 437, .external_lex_state = 2},
  [11884] = {.lex_state = 437, .external_lex_state = 2},
  [11885] = {.lex_state = 17, .external_lex_state = 2},
  [11886] = {.lex_state = 437, .external_lex_state = 2},
  [11887] = {.lex_state = 437, .external_lex_state = 2},
  [11888] = {.lex_state = 437, .external_lex_state = 2},
  [11889] = {.lex_state = 437, .external_lex_state = 2},
  [11890] = {.lex_state = 437, .external_lex_state = 2},
  [11891] = {.lex_state = 437, .external_lex_state = 2},
  [11892] = {.lex_state = 437, .external_lex_state = 2},
  [11893] = {.lex_state = 437, .external_lex_state = 2},
  [11894] = {.lex_state = 437, .external_lex_state = 2},
  [11895] = {.lex_state = 437, .external_lex_state = 2},
  [11896] = {.lex_state = 437, .external_lex_state = 2},
  [11897] = {.lex_state = 437, .external_lex_state = 2},
  [11898] = {.lex_state = 437, .external_lex_state = 2},
  [11899] = {.lex_state = 437, .external_lex_state = 2},
  [11900] = {.lex_state = 437, .external_lex_state = 2},
  [11901] = {.lex_state = 437, .external_lex_state = 2},
  [11902] = {.lex_state = 437, .external_lex_state = 2},
  [11903] = {.lex_state = 437, .external_lex_state = 2},
  [11904] = {.lex_state = 437, .external_lex_state = 2},
  [11905] = {.lex_state = 437, .external_lex_state = 2},
  [11906] = {.lex_state = 437, .external_lex_state = 2},
  [11907] = {.lex_state = 437, .external_lex_state = 2},
  [11908] = {.lex_state = 437, .external_lex_state = 2},
  [11909] = {.lex_state = 437, .external_lex_state = 2},
  [11910] = {.lex_state = 17, .external_lex_state = 2},
  [11911] = {.lex_state = 437, .external_lex_state = 2},
  [11912] = {.lex_state = 17, .external_lex_state = 2},
  [11913] = {.lex_state = 437, .external_lex_state = 2},
  [11914] = {.lex_state = 17, .external_lex_state = 2},
  [11915] = {.lex_state = 437, .external_lex_state = 2},
  [11916] = {.lex_state = 437, .external_lex_state = 2},
  [11917] = {.lex_state = 437, .external_lex_state = 2},
  [11918] = {.lex_state = 437, .external_lex_state = 2},
  [11919] = {.lex_state = 437, .external_lex_state = 2},
  [11920] = {.lex_state = 437, .external_lex_state = 2},
  [11921] = {.lex_state = 437, .external_lex_state = 2},
  [11922] = {.lex_state = 437, .external_lex_state = 2},
  [11923] = {.lex_state = 437, .external_lex_state = 2},
  [11924] = {.lex_state = 437, .external_lex_state = 2},
  [11925] = {.lex_state = 437, .external_lex_state = 2},
  [11926] = {.lex_state = 437, .external_lex_state = 2},
  [11927] = {.lex_state = 437, .external_lex_state = 2},
  [11928] = {.lex_state = 437, .external_lex_state = 2},
  [11929] = {.lex_state = 437, .external_lex_state = 2},
  [11930] = {.lex_state = 437, .external_lex_state = 2},
  [11931] = {.lex_state = 437, .external_lex_state = 2},
  [11932] = {.lex_state = 437, .external_lex_state = 2},
  [11933] = {.lex_state = 437, .external_lex_state = 2},
  [11934] = {.lex_state = 437, .external_lex_state = 2},
  [11935] = {.lex_state = 437, .external_lex_state = 2},
  [11936] = {.lex_state = 437, .external_lex_state = 2},
  [11937] = {.lex_state = 437, .external_lex_state = 2},
  [11938] = {.lex_state = 437, .external_lex_state = 2},
  [11939] = {.lex_state = 437, .external_lex_state = 2},
  [11940] = {.lex_state = 437, .external_lex_state = 2},
  [11941] = {.lex_state = 437, .external_lex_state = 2},
  [11942] = {.lex_state = 437, .external_lex_state = 2},
  [11943] = {.lex_state = 17, .external_lex_state = 2},
  [11944] = {.lex_state = 437, .external_lex_state = 2},
  [11945] = {.lex_state = 437, .external_lex_state = 2},
  [11946] = {.lex_state = 437, .external_lex_state = 2},
  [11947] = {.lex_state = 437, .external_lex_state = 2},
  [11948] = {.lex_state = 437, .external_lex_state = 2},
  [11949] = {.lex_state = 437, .external_lex_state = 2},
  [11950] = {.lex_state = 437, .external_lex_state = 2},
  [11951] = {.lex_state = 437, .external_lex_state = 2},
  [11952] = {.lex_state = 437, .external_lex_state = 2},
  [11953] = {.lex_state = 437, .external_lex_state = 2},
  [11954] = {.lex_state = 437, .external_lex_state = 2},
  [11955] = {.lex_state = 437, .external_lex_state = 2},
  [11956] = {.lex_state = 437, .external_lex_state = 2},
  [11957] = {.lex_state = 437, .external_lex_state = 2},
  [11958] = {.lex_state = 437, .external_lex_state = 2},
  [11959] = {.lex_state = 437, .external_lex_state = 2},
  [11960] = {.lex_state = 437, .external_lex_state = 2},
  [11961] = {.lex_state = 437, .external_lex_state = 2},
  [11962] = {.lex_state = 437, .external_lex_state = 2},
  [11963] = {.lex_state = 437, .external_lex_state = 2},
  [11964] = {.lex_state = 437, .external_lex_state = 2},
  [11965] = {.lex_state = 437, .external_lex_state = 2},
  [11966] = {.lex_state = 437, .external_lex_state = 2},
  [11967] = {.lex_state = 437, .external_lex_state = 2},
  [11968] = {.lex_state = 437, .external_lex_state = 2},
  [11969] = {.lex_state = 437, .external_lex_state = 2},
  [11970] = {.lex_state = 437, .external_lex_state = 2},
  [11971] = {.lex_state = 445, .external_lex_state = 2},
  [11972] = {.lex_state = 445, .external_lex_state = 2},
  [11973] = {.lex_state = 437, .external_lex_state = 2},
  [11974] = {.lex_state = 437, .external_lex_state = 2},
  [11975] = {.lex_state = 445, .external_lex_state = 2},
  [11976] = {.lex_state = 437, .external_lex_state = 2},
  [11977] = {.lex_state = 437, .external_lex_state = 2},
  [11978] = {.lex_state = 437, .external_lex_state = 2},
  [11979] = {.lex_state = 437, .external_lex_state = 2},
  [11980] = {.lex_state = 437, .external_lex_state = 2},
  [11981] = {.lex_state = 437, .external_lex_state = 2},
  [11982] = {.lex_state = 437, .external_lex_state = 2},
  [11983] = {.lex_state = 437, .external_lex_state = 2},
  [11984] = {.lex_state = 445, .external_lex_state = 2},
  [11985] = {.lex_state = 445, .external_lex_state = 2},
  [11986] = {.lex_state = 437, .external_lex_state = 2},
  [11987] = {.lex_state = 437, .external_lex_state = 2},
  [11988] = {.lex_state = 437, .external_lex_state = 2},
  [11989] = {.lex_state = 437, .external_lex_state = 2},
  [11990] = {.lex_state = 437, .external_lex_state = 2},
  [11991] = {.lex_state = 437, .external_lex_state = 2},
  [11992] = {.lex_state = 437, .external_lex_state = 2},
  [11993] = {.lex_state = 437, .external_lex_state = 2},
  [11994] = {.lex_state = 437, .external_lex_state = 2},
  [11995] = {.lex_state = 437, .external_lex_state = 2},
  [11996] = {.lex_state = 237, .external_lex_state = 2},
  [11997] = {.lex_state = 437, .external_lex_state = 2},
  [11998] = {.lex_state = 437, .external_lex_state = 2},
  [11999] = {.lex_state = 437, .external_lex_state = 2},
  [12000] = {.lex_state = 437, .external_lex_state = 2},
  [12001] = {.lex_state = 437, .external_lex_state = 2},
  [12002] = {.lex_state = 437, .external_lex_state = 2},
  [12003] = {.lex_state = 437, .external_lex_state = 2},
  [12004] = {.lex_state = 437, .external_lex_state = 2},
  [12005] = {.lex_state = 437, .external_lex_state = 2},
  [12006] = {.lex_state = 437, .external_lex_state = 2},
  [12007] = {.lex_state = 437, .external_lex_state = 2},
  [12008] = {.lex_state = 437, .external_lex_state = 2},
  [12009] = {.lex_state = 437, .external_lex_state = 2},
  [12010] = {.lex_state = 437, .external_lex_state = 2},
  [12011] = {.lex_state = 437, .external_lex_state = 2},
  [12012] = {.lex_state = 437, .external_lex_state = 2},
  [12013] = {.lex_state = 437, .external_lex_state = 2},
  [12014] = {.lex_state = 437, .external_lex_state = 2},
  [12015] = {.lex_state = 437, .external_lex_state = 2},
  [12016] = {.lex_state = 437, .external_lex_state = 2},
  [12017] = {.lex_state = 437, .external_lex_state = 2},
  [12018] = {.lex_state = 437, .external_lex_state = 2},
  [12019] = {.lex_state = 437, .external_lex_state = 2},
  [12020] = {.lex_state = 437, .external_lex_state = 2},
  [12021] = {.lex_state = 437, .external_lex_state = 2},
  [12022] = {.lex_state = 437, .external_lex_state = 2},
  [12023] = {.lex_state = 437, .external_lex_state = 2},
  [12024] = {.lex_state = 437, .external_lex_state = 2},
  [12025] = {.lex_state = 437, .external_lex_state = 2},
  [12026] = {.lex_state = 437, .external_lex_state = 2},
  [12027] = {.lex_state = 437, .external_lex_state = 2},
  [12028] = {.lex_state = 437, .external_lex_state = 2},
  [12029] = {.lex_state = 437, .external_lex_state = 2},
  [12030] = {.lex_state = 445, .external_lex_state = 2},
  [12031] = {.lex_state = 437, .external_lex_state = 2},
  [12032] = {.lex_state = 437, .external_lex_state = 2},
  [12033] = {.lex_state = 437, .external_lex_state = 2},
  [12034] = {.lex_state = 437, .external_lex_state = 2},
  [12035] = {.lex_state = 437, .external_lex_state = 2},
  [12036] = {.lex_state = 437, .external_lex_state = 2},
  [12037] = {.lex_state = 437, .external_lex_state = 2},
  [12038] = {.lex_state = 437, .external_lex_state = 2},
  [12039] = {.lex_state = 437, .external_lex_state = 2},
  [12040] = {.lex_state = 172, .external_lex_state = 2},
  [12041] = {.lex_state = 437, .external_lex_state = 2},
  [12042] = {.lex_state = 437, .external_lex_state = 2},
  [12043] = {.lex_state = 437, .external_lex_state = 2},
  [12044] = {.lex_state = 437, .external_lex_state = 2},
  [12045] = {.lex_state = 437, .external_lex_state = 2},
  [12046] = {.lex_state = 437, .external_lex_state = 2},
  [12047] = {.lex_state = 437, .external_lex_state = 2},
  [12048] = {.lex_state = 437, .external_lex_state = 2},
  [12049] = {.lex_state = 437, .external_lex_state = 2},
  [12050] = {.lex_state = 437, .external_lex_state = 2},
  [12051] = {.lex_state = 437, .external_lex_state = 2},
  [12052] = {.lex_state = 437, .external_lex_state = 2},
  [12053] = {.lex_state = 437, .external_lex_state = 2},
  [12054] = {.lex_state = 437, .external_lex_state = 2},
  [12055] = {.lex_state = 437, .external_lex_state = 2},
  [12056] = {.lex_state = 437, .external_lex_state = 2},
  [12057] = {.lex_state = 437, .external_lex_state = 2},
  [12058] = {.lex_state = 437, .external_lex_state = 2},
  [12059] = {.lex_state = 437, .external_lex_state = 2},
  [12060] = {.lex_state = 437, .external_lex_state = 2},
  [12061] = {.lex_state = 437, .external_lex_state = 2},
  [12062] = {.lex_state = 437, .external_lex_state = 2},
  [12063] = {.lex_state = 437, .external_lex_state = 2},
  [12064] = {.lex_state = 437, .external_lex_state = 2},
  [12065] = {.lex_state = 437, .external_lex_state = 2},
  [12066] = {.lex_state = 437, .external_lex_state = 2},
  [12067] = {.lex_state = 437, .external_lex_state = 2},
  [12068] = {.lex_state = 437, .external_lex_state = 2},
  [12069] = {.lex_state = 437, .external_lex_state = 2},
  [12070] = {.lex_state = 437, .external_lex_state = 2},
  [12071] = {.lex_state = 437, .external_lex_state = 2},
  [12072] = {.lex_state = 437, .external_lex_state = 2},
  [12073] = {.lex_state = 437, .external_lex_state = 2},
  [12074] = {.lex_state = 437, .external_lex_state = 2},
  [12075] = {.lex_state = 437, .external_lex_state = 2},
  [12076] = {.lex_state = 437, .external_lex_state = 2},
  [12077] = {.lex_state = 437, .external_lex_state = 2},
  [12078] = {.lex_state = 437, .external_lex_state = 2},
  [12079] = {.lex_state = 437, .external_lex_state = 2},
  [12080] = {.lex_state = 437, .external_lex_state = 2},
  [12081] = {.lex_state = 445, .external_lex_state = 2},
  [12082] = {.lex_state = 437, .external_lex_state = 2},
  [12083] = {.lex_state = 437, .external_lex_state = 2},
  [12084] = {.lex_state = 437, .external_lex_state = 2},
  [12085] = {.lex_state = 437, .external_lex_state = 2},
  [12086] = {.lex_state = 437, .external_lex_state = 2},
  [12087] = {.lex_state = 437, .external_lex_state = 2},
  [12088] = {.lex_state = 437, .external_lex_state = 2},
  [12089] = {.lex_state = 437, .external_lex_state = 2},
  [12090] = {.lex_state = 437, .external_lex_state = 2},
  [12091] = {.lex_state = 437, .external_lex_state = 2},
  [12092] = {.lex_state = 437, .external_lex_state = 2},
  [12093] = {.lex_state = 437, .external_lex_state = 2},
  [12094] = {.lex_state = 437, .external_lex_state = 2},
  [12095] = {.lex_state = 437, .external_lex_state = 2},
  [12096] = {.lex_state = 437, .external_lex_state = 2},
  [12097] = {.lex_state = 437, .external_lex_state = 2},
  [12098] = {.lex_state = 437, .external_lex_state = 2},
  [12099] = {.lex_state = 437, .external_lex_state = 2},
  [12100] = {.lex_state = 437, .external_lex_state = 2},
  [12101] = {.lex_state = 437, .external_lex_state = 2},
  [12102] = {.lex_state = 437, .external_lex_state = 2},
  [12103] = {.lex_state = 437, .external_lex_state = 2},
  [12104] = {.lex_state = 437, .external_lex_state = 2},
  [12105] = {.lex_state = 437, .external_lex_state = 2},
  [12106] = {.lex_state = 437, .external_lex_state = 2},
  [12107] = {.lex_state = 437, .external_lex_state = 2},
  [12108] = {.lex_state = 437, .external_lex_state = 2},
  [12109] = {.lex_state = 437, .external_lex_state = 2},
  [12110] = {.lex_state = 437, .external_lex_state = 2},
  [12111] = {.lex_state = 437, .external_lex_state = 2},
  [12112] = {.lex_state = 445, .external_lex_state = 2},
  [12113] = {.lex_state = 437, .external_lex_state = 2},
  [12114] = {.lex_state = 15, .external_lex_state = 2},
  [12115] = {.lex_state = 15, .external_lex_state = 2},
  [12116] = {.lex_state = 437, .external_lex_state = 2},
  [12117] = {.lex_state = 437, .external_lex_state = 2},
  [12118] = {.lex_state = 437, .external_lex_state = 2},
  [12119] = {.lex_state = 437, .external_lex_state = 2},
  [12120] = {.lex_state = 437, .external_lex_state = 2},
  [12121] = {.lex_state = 437, .external_lex_state = 2},
  [12122] = {.lex_state = 437, .external_lex_state = 2},
  [12123] = {.lex_state = 437, .external_lex_state = 2},
  [12124] = {.lex_state = 437, .external_lex_state = 2},
  [12125] = {.lex_state = 437, .external_lex_state = 2},
  [12126] = {.lex_state = 437, .external_lex_state = 2},
  [12127] = {.lex_state = 445, .external_lex_state = 2},
  [12128] = {.lex_state = 437, .external_lex_state = 2},
  [12129] = {.lex_state = 437, .external_lex_state = 2},
  [12130] = {.lex_state = 437, .external_lex_state = 2},
  [12131] = {.lex_state = 437, .external_lex_state = 2},
  [12132] = {.lex_state = 437, .external_lex_state = 2},
  [12133] = {.lex_state = 437, .external_lex_state = 2},
  [12134] = {.lex_state = 437, .external_lex_state = 2},
  [12135] = {.lex_state = 437, .external_lex_state = 2},
  [12136] = {.lex_state = 437, .external_lex_state = 2},
  [12137] = {.lex_state = 437, .external_lex_state = 2},
  [12138] = {.lex_state = 257, .external_lex_state = 2},
  [12139] = {.lex_state = 437, .external_lex_state = 2},
  [12140] = {.lex_state = 437, .external_lex_state = 2},
  [12141] = {.lex_state = 437, .external_lex_state = 2},
  [12142] = {.lex_state = 437, .external_lex_state = 2},
  [12143] = {.lex_state = 437, .external_lex_state = 2},
  [12144] = {.lex_state = 437, .external_lex_state = 2},
  [12145] = {.lex_state = 437, .external_lex_state = 2},
  [12146] = {.lex_state = 437, .external_lex_state = 2},
  [12147] = {.lex_state = 437, .external_lex_state = 2},
  [12148] = {.lex_state = 437, .external_lex_state = 2},
  [12149] = {.lex_state = 437, .external_lex_state = 2},
  [12150] = {.lex_state = 437, .external_lex_state = 2},
  [12151] = {.lex_state = 437, .external_lex_state = 2},
  [12152] = {.lex_state = 437, .external_lex_state = 2},
  [12153] = {.lex_state = 437, .external_lex_state = 2},
  [12154] = {.lex_state = 437, .external_lex_state = 2},
  [12155] = {.lex_state = 437, .external_lex_state = 2},
  [12156] = {.lex_state = 437, .external_lex_state = 2},
  [12157] = {.lex_state = 437, .external_lex_state = 2},
  [12158] = {.lex_state = 437, .external_lex_state = 2},
  [12159] = {.lex_state = 437, .external_lex_state = 2},
  [12160] = {.lex_state = 445, .external_lex_state = 2},
  [12161] = {.lex_state = 437, .external_lex_state = 2},
  [12162] = {.lex_state = 437, .external_lex_state = 2},
  [12163] = {.lex_state = 437, .external_lex_state = 2},
  [12164] = {.lex_state = 437, .external_lex_state = 2},
  [12165] = {.lex_state = 437, .external_lex_state = 2},
  [12166] = {.lex_state = 437, .external_lex_state = 2},
  [12167] = {.lex_state = 437, .external_lex_state = 2},
  [12168] = {.lex_state = 437, .external_lex_state = 2},
  [12169] = {.lex_state = 437, .external_lex_state = 2},
  [12170] = {.lex_state = 437, .external_lex_state = 2},
  [12171] = {.lex_state = 437, .external_lex_state = 2},
  [12172] = {.lex_state = 437, .external_lex_state = 2},
  [12173] = {.lex_state = 437, .external_lex_state = 2},
  [12174] = {.lex_state = 437, .external_lex_state = 2},
  [12175] = {.lex_state = 437, .external_lex_state = 2},
  [12176] = {.lex_state = 437, .external_lex_state = 2},
  [12177] = {.lex_state = 437, .external_lex_state = 2},
  [12178] = {.lex_state = 437, .external_lex_state = 2},
  [12179] = {.lex_state = 437, .external_lex_state = 2},
  [12180] = {.lex_state = 437, .external_lex_state = 2},
  [12181] = {.lex_state = 437, .external_lex_state = 2},
  [12182] = {.lex_state = 437, .external_lex_state = 2},
  [12183] = {.lex_state = 437, .external_lex_state = 2},
  [12184] = {.lex_state = 437, .external_lex_state = 2},
  [12185] = {.lex_state = 437, .external_lex_state = 2},
  [12186] = {.lex_state = 437, .external_lex_state = 2},
  [12187] = {.lex_state = 437, .external_lex_state = 2},
  [12188] = {.lex_state = 437, .external_lex_state = 2},
  [12189] = {.lex_state = 437, .external_lex_state = 2},
  [12190] = {.lex_state = 437, .external_lex_state = 2},
  [12191] = {.lex_state = 437, .external_lex_state = 2},
  [12192] = {.lex_state = 437, .external_lex_state = 2},
  [12193] = {.lex_state = 437, .external_lex_state = 2},
  [12194] = {.lex_state = 437, .external_lex_state = 2},
  [12195] = {.lex_state = 437, .external_lex_state = 2},
  [12196] = {.lex_state = 437, .external_lex_state = 2},
  [12197] = {.lex_state = 437, .external_lex_state = 2},
  [12198] = {.lex_state = 437, .external_lex_state = 2},
  [12199] = {.lex_state = 437, .external_lex_state = 2},
  [12200] = {.lex_state = 437, .external_lex_state = 2},
  [12201] = {.lex_state = 437, .external_lex_state = 2},
  [12202] = {.lex_state = 437, .external_lex_state = 2},
  [12203] = {.lex_state = 437, .external_lex_state = 2},
  [12204] = {.lex_state = 437, .external_lex_state = 2},
  [12205] = {.lex_state = 437, .external_lex_state = 2},
  [12206] = {.lex_state = 437, .external_lex_state = 2},
  [12207] = {.lex_state = 437, .external_lex_state = 2},
  [12208] = {.lex_state = 437, .external_lex_state = 2},
  [12209] = {.lex_state = 437, .external_lex_state = 2},
  [12210] = {.lex_state = 437, .external_lex_state = 2},
  [12211] = {.lex_state = 437, .external_lex_state = 2},
  [12212] = {.lex_state = 437, .external_lex_state = 2},
  [12213] = {.lex_state = 437, .external_lex_state = 2},
  [12214] = {.lex_state = 437, .external_lex_state = 2},
  [12215] = {.lex_state = 437, .external_lex_state = 2},
  [12216] = {.lex_state = 437, .external_lex_state = 2},
  [12217] = {.lex_state = 437, .external_lex_state = 2},
  [12218] = {.lex_state = 437, .external_lex_state = 2},
  [12219] = {.lex_state = 437, .external_lex_state = 2},
  [12220] = {.lex_state = 14, .external_lex_state = 2},
  [12221] = {.lex_state = 174, .external_lex_state = 2},
  [12222] = {.lex_state = 174, .external_lex_state = 2},
  [12223] = {.lex_state = 174, .external_lex_state = 2},
  [12224] = {.lex_state = 17, .external_lex_state = 2},
  [12225] = {.lex_state = 437, .external_lex_state = 2},
  [12226] = {.lex_state = 24, .external_lex_state = 2},
  [12227] = {.lex_state = 445, .external_lex_state = 2},
  [12228] = {.lex_state = 17, .external_lex_state = 2},
  [12229] = {.lex_state = 445, .external_lex_state = 2},
  [12230] = {.lex_state = 437, .external_lex_state = 2},
  [12231] = {.lex_state = 437, .external_lex_state = 2},
  [12232] = {.lex_state = 437, .external_lex_state = 2},
  [12233] = {.lex_state = 437, .external_lex_state = 2},
  [12234] = {.lex_state = 437, .external_lex_state = 2},
  [12235] = {.lex_state = 437, .external_lex_state = 2},
  [12236] = {.lex_state = 437, .external_lex_state = 2},
  [12237] = {.lex_state = 15, .external_lex_state = 2},
  [12238] = {.lex_state = 15, .external_lex_state = 2},
  [12239] = {.lex_state = 15, .external_lex_state = 2},
  [12240] = {.lex_state = 15, .external_lex_state = 2},
  [12241] = {.lex_state = 15, .external_lex_state = 2},
  [12242] = {.lex_state = 15, .external_lex_state = 2},
  [12243] = {.lex_state = 15, .external_lex_state = 2},
  [12244] = {.lex_state = 15, .external_lex_state = 2},
  [12245] = {.lex_state = 15, .external_lex_state = 2},
  [12246] = {.lex_state = 15, .external_lex_state = 2},
  [12247] = {.lex_state = 15, .external_lex_state = 2},
  [12248] = {.lex_state = 15, .external_lex_state = 2},
  [12249] = {.lex_state = 17, .external_lex_state = 2},
  [12250] = {.lex_state = 445, .external_lex_state = 2},
  [12251] = {.lex_state = 17, .external_lex_state = 2},
  [12252] = {.lex_state = 17, .external_lex_state = 2},
  [12253] = {.lex_state = 22, .external_lex_state = 2},
  [12254] = {.lex_state = 24, .external_lex_state = 2},
  [12255] = {.lex_state = 24, .external_lex_state = 2},
  [12256] = {.lex_state = 17, .external_lex_state = 2},
  [12257] = {.lex_state = 445, .external_lex_state = 2},
  [12258] = {.lex_state = 22, .external_lex_state = 2},
  [12259] = {.lex_state = 22, .external_lex_state = 2},
  [12260] = {.lex_state = 22, .external_lex_state = 2},
  [12261] = {.lex_state = 22, .external_lex_state = 2},
  [12262] = {.lex_state = 22, .external_lex_state = 2},
  [12263] = {.lex_state = 22, .external_lex_state = 2},
  [12264] = {.lex_state = 22, .external_lex_state = 2},
  [12265] = {.lex_state = 22, .external_lex_state = 2},
  [12266] = {.lex_state = 22, .external_lex_state = 2},
  [12267] = {.lex_state = 22, .external_lex_state = 2},
  [12268] = {.lex_state = 22, .external_lex_state = 2},
  [12269] = {.lex_state = 22, .external_lex_state = 2},
  [12270] = {.lex_state = 22, .external_lex_state = 2},
  [12271] = {.lex_state = 24, .external_lex_state = 2},
  [12272] = {.lex_state = 437, .external_lex_state = 2},
  [12273] = {.lex_state = 22, .external_lex_state = 2},
  [12274] = {.lex_state = 15, .external_lex_state = 2},
  [12275] = {.lex_state = 22, .external_lex_state = 2},
  [12276] = {.lex_state = 22, .external_lex_state = 2},
  [12277] = {.lex_state = 173, .external_lex_state = 2},
  [12278] = {.lex_state = 173, .external_lex_state = 2},
  [12279] = {.lex_state = 173, .external_lex_state = 2},
  [12280] = {.lex_state = 24, .external_lex_state = 2},
  [12281] = {.lex_state = 15, .external_lex_state = 2},
  [12282] = {.lex_state = 15, .external_lex_state = 2},
  [12283] = {.lex_state = 15, .external_lex_state = 2},
  [12284] = {.lex_state = 15, .external_lex_state = 2},
  [12285] = {.lex_state = 15, .external_lex_state = 2},
  [12286] = {.lex_state = 437, .external_lex_state = 2},
  [12287] = {.lex_state = 445, .external_lex_state = 2},
  [12288] = {.lex_state = 445, .external_lex_state = 2},
  [12289] = {.lex_state = 24, .external_lex_state = 2},
  [12290] = {.lex_state = 437, .external_lex_state = 2},
  [12291] = {.lex_state = 24, .external_lex_state = 2},
  [12292] = {.lex_state = 24, .external_lex_state = 2},
  [12293] = {.lex_state = 437, .external_lex_state = 2},
  [12294] = {.lex_state = 437, .external_lex_state = 2},
  [12295] = {.lex_state = 437, .external_lex_state = 2},
  [12296] = {.lex_state = 437, .external_lex_state = 2},
  [12297] = {.lex_state = 437, .external_lex_state = 2},
  [12298] = {.lex_state = 437, .external_lex_state = 2},
  [12299] = {.lex_state = 24, .external_lex_state = 2},
  [12300] = {.lex_state = 445, .external_lex_state = 2},
  [12301] = {.lex_state = 437, .external_lex_state = 2},
  [12302] = {.lex_state = 445, .external_lex_state = 2},
  [12303] = {.lex_state = 24, .external_lex_state = 2},
  [12304] = {.lex_state = 445, .external_lex_state = 2},
  [12305] = {.lex_state = 15, .external_lex_state = 2},
  [12306] = {.lex_state = 24, .external_lex_state = 2},
  [12307] = {.lex_state = 24, .external_lex_state = 2},
  [12308] = {.lex_state = 445, .external_lex_state = 2},
  [12309] = {.lex_state = 437, .external_lex_state = 2},
  [12310] = {.lex_state = 437, .external_lex_state = 2},
  [12311] = {.lex_state = 182, .external_lex_state = 2},
  [12312] = {.lex_state = 182, .external_lex_state = 2},
  [12313] = {.lex_state = 182, .external_lex_state = 2},
  [12314] = {.lex_state = 24, .external_lex_state = 2},
  [12315] = {.lex_state = 24, .external_lex_state = 2},
  [12316] = {.lex_state = 24, .external_lex_state = 2},
  [12317] = {.lex_state = 437, .external_lex_state = 2},
  [12318] = {.lex_state = 24, .external_lex_state = 2},
  [12319] = {.lex_state = 24, .external_lex_state = 2},
  [12320] = {.lex_state = 24, .external_lex_state = 2},
  [12321] = {.lex_state = 437, .external_lex_state = 2},
  [12322] = {.lex_state = 24, .external_lex_state = 2},
  [12323] = {.lex_state = 24, .external_lex_state = 2},
  [12324] = {.lex_state = 24, .external_lex_state = 2},
  [12325] = {.lex_state = 437, .external_lex_state = 2},
  [12326] = {.lex_state = 24, .external_lex_state = 2},
  [12327] = {.lex_state = 24, .external_lex_state = 2},
  [12328] = {.lex_state = 437, .external_lex_state = 2},
  [12329] = {.lex_state = 437, .external_lex_state = 2},
  [12330] = {.lex_state = 437, .external_lex_state = 2},
  [12331] = {.lex_state = 24, .external_lex_state = 2},
  [12332] = {.lex_state = 437, .external_lex_state = 2},
  [12333] = {.lex_state = 437, .external_lex_state = 2},
  [12334] = {.lex_state = 437, .external_lex_state = 2},
  [12335] = {.lex_state = 24, .external_lex_state = 2},
  [12336] = {.lex_state = 437, .external_lex_state = 2},
  [12337] = {.lex_state = 24, .external_lex_state = 2},
  [12338] = {.lex_state = 24, .external_lex_state = 2},
  [12339] = {.lex_state = 24, .external_lex_state = 2},
  [12340] = {.lex_state = 24, .external_lex_state = 2},
  [12341] = {.lex_state = 445, .external_lex_state = 2},
  [12342] = {.lex_state = 24, .external_lex_state = 2},
  [12343] = {.lex_state = 24, .external_lex_state = 2},
  [12344] = {.lex_state = 24, .external_lex_state = 2},
  [12345] = {.lex_state = 24, .external_lex_state = 2},
  [12346] = {.lex_state = 24, .external_lex_state = 2},
  [12347] = {.lex_state = 24, .external_lex_state = 2},
  [12348] = {.lex_state = 445, .external_lex_state = 2},
  [12349] = {.lex_state = 24, .external_lex_state = 2},
  [12350] = {.lex_state = 445, .external_lex_state = 2},
  [12351] = {.lex_state = 24, .external_lex_state = 2},
  [12352] = {.lex_state = 229, .external_lex_state = 2},
  [12353] = {.lex_state = 24, .external_lex_state = 2},
  [12354] = {.lex_state = 437, .external_lex_state = 2},
  [12355] = {.lex_state = 24, .external_lex_state = 2},
  [12356] = {.lex_state = 24, .external_lex_state = 2},
  [12357] = {.lex_state = 24, .external_lex_state = 2},
  [12358] = {.lex_state = 24, .external_lex_state = 2},
  [12359] = {.lex_state = 24, .external_lex_state = 2},
  [12360] = {.lex_state = 437, .external_lex_state = 2},
  [12361] = {.lex_state = 24, .external_lex_state = 2},
  [12362] = {.lex_state = 437, .external_lex_state = 2},
  [12363] = {.lex_state = 445, .external_lex_state = 2},
  [12364] = {.lex_state = 445, .external_lex_state = 2},
  [12365] = {.lex_state = 445, .external_lex_state = 2},
  [12366] = {.lex_state = 437, .external_lex_state = 2},
  [12367] = {.lex_state = 437, .external_lex_state = 2},
  [12368] = {.lex_state = 437, .external_lex_state = 2},
  [12369] = {.lex_state = 445, .external_lex_state = 2},
  [12370] = {.lex_state = 445, .external_lex_state = 2},
  [12371] = {.lex_state = 437, .external_lex_state = 2},
  [12372] = {.lex_state = 437, .external_lex_state = 2},
  [12373] = {.lex_state = 437, .external_lex_state = 2},
  [12374] = {.lex_state = 437, .external_lex_state = 2},
  [12375] = {.lex_state = 445, .external_lex_state = 2},
  [12376] = {.lex_state = 445, .external_lex_state = 2},
  [12377] = {.lex_state = 445, .external_lex_state = 2},
  [12378] = {.lex_state = 235, .external_lex_state = 2},
  [12379] = {.lex_state = 235, .external_lex_state = 2},
  [12380] = {.lex_state = 17, .external_lex_state = 2},
  [12381] = {.lex_state = 445, .external_lex_state = 2},
  [12382] = {.lex_state = 437, .external_lex_state = 2},
  [12383] = {.lex_state = 17, .external_lex_state = 2},
  [12384] = {.lex_state = 445, .external_lex_state = 2},
  [12385] = {.lex_state = 445, .external_lex_state = 2},
  [12386] = {.lex_state = 445, .external_lex_state = 2},
  [12387] = {.lex_state = 445, .external_lex_state = 2},
  [12388] = {.lex_state = 235, .external_lex_state = 2},
  [12389] = {.lex_state = 445, .external_lex_state = 2},
  [12390] = {.lex_state = 437, .external_lex_state = 2},
  [12391] = {.lex_state = 235, .external_lex_state = 2},
  [12392] = {.lex_state = 235, .external_lex_state = 2},
  [12393] = {.lex_state = 437, .external_lex_state = 2},
  [12394] = {.lex_state = 235, .external_lex_state = 2},
  [12395] = {.lex_state = 437, .external_lex_state = 2},
  [12396] = {.lex_state = 437, .external_lex_state = 2},
  [12397] = {.lex_state = 437, .external_lex_state = 2},
  [12398] = {.lex_state = 437, .external_lex_state = 2},
  [12399] = {.lex_state = 437, .external_lex_state = 2},
  [12400] = {.lex_state = 437, .external_lex_state = 2},
  [12401] = {.lex_state = 437, .external_lex_state = 2},
  [12402] = {.lex_state = 437, .external_lex_state = 2},
  [12403] = {.lex_state = 24, .external_lex_state = 2},
  [12404] = {.lex_state = 17, .external_lex_state = 2},
  [12405] = {.lex_state = 445, .external_lex_state = 2},
  [12406] = {.lex_state = 445, .external_lex_state = 2},
  [12407] = {.lex_state = 445, .external_lex_state = 2},
  [12408] = {.lex_state = 445, .external_lex_state = 2},
  [12409] = {.lex_state = 22, .external_lex_state = 2},
  [12410] = {.lex_state = 22, .external_lex_state = 2},
  [12411] = {.lex_state = 445, .external_lex_state = 2},
  [12412] = {.lex_state = 8, .external_lex_state = 2},
  [12413] = {.lex_state = 437, .external_lex_state = 2},
  [12414] = {.lex_state = 8, .external_lex_state = 2},
  [12415] = {.lex_state = 437, .external_lex_state = 2},
  [12416] = {.lex_state = 257, .external_lex_state = 2},
  [12417] = {.lex_state = 437, .external_lex_state = 2},
  [12418] = {.lex_state = 24, .external_lex_state = 3},
  [12419] = {.lex_state = 22, .external_lex_state = 2},
  [12420] = {.lex_state = 450, .external_lex_state = 2},
  [12421] = {.lex_state = 22, .external_lex_state = 2},
  [12422] = {.lex_state = 27, .external_lex_state = 2},
  [12423] = {.lex_state = 27, .external_lex_state = 2},
  [12424] = {.lex_state = 27, .external_lex_state = 2},
  [12425] = {.lex_state = 22, .external_lex_state = 2},
  [12426] = {.lex_state = 22, .external_lex_state = 2},
  [12427] = {.lex_state = 27, .external_lex_state = 2},
  [12428] = {.lex_state = 27, .external_lex_state = 2},
  [12429] = {.lex_state = 24, .external_lex_state = 3},
  [12430] = {.lex_state = 27, .external_lex_state = 2},
  [12431] = {.lex_state = 27, .external_lex_state = 2},
  [12432] = {.lex_state = 27, .external_lex_state = 2},
  [12433] = {.lex_state = 437, .external_lex_state = 2},
  [12434] = {.lex_state = 22, .external_lex_state = 2},
  [12435] = {.lex_state = 22, .external_lex_state = 2},
  [12436] = {.lex_state = 15, .external_lex_state = 2},
  [12437] = {.lex_state = 22, .external_lex_state = 2},
  [12438] = {.lex_state = 445, .external_lex_state = 2},
  [12439] = {.lex_state = 437, .external_lex_state = 2},
  [12440] = {.lex_state = 172, .external_lex_state = 2},
  [12441] = {.lex_state = 445, .external_lex_state = 2},
  [12442] = {.lex_state = 15, .external_lex_state = 2},
  [12443] = {.lex_state = 445, .external_lex_state = 2},
  [12444] = {.lex_state = 445, .external_lex_state = 2},
  [12445] = {.lex_state = 437, .external_lex_state = 2},
  [12446] = {.lex_state = 27, .external_lex_state = 2},
  [12447] = {.lex_state = 27, .external_lex_state = 2},
  [12448] = {.lex_state = 27, .external_lex_state = 2},
  [12449] = {.lex_state = 27, .external_lex_state = 2},
  [12450] = {.lex_state = 22, .external_lex_state = 2},
  [12451] = {.lex_state = 437, .external_lex_state = 2},
  [12452] = {.lex_state = 445, .external_lex_state = 2},
  [12453] = {.lex_state = 445, .external_lex_state = 2},
  [12454] = {.lex_state = 27, .external_lex_state = 2},
  [12455] = {.lex_state = 27, .external_lex_state = 2},
  [12456] = {.lex_state = 27, .external_lex_state = 2},
  [12457] = {.lex_state = 27, .external_lex_state = 2},
  [12458] = {.lex_state = 27, .external_lex_state = 2},
  [12459] = {.lex_state = 27, .external_lex_state = 2},
  [12460] = {.lex_state = 437, .external_lex_state = 2},
  [12461] = {.lex_state = 27, .external_lex_state = 2},
  [12462] = {.lex_state = 27, .external_lex_state = 2},
  [12463] = {.lex_state = 15, .external_lex_state = 2},
  [12464] = {.lex_state = 27, .external_lex_state = 2},
  [12465] = {.lex_state = 27, .external_lex_state = 2},
  [12466] = {.lex_state = 27, .external_lex_state = 2},
  [12467] = {.lex_state = 445, .external_lex_state = 2},
  [12468] = {.lex_state = 445, .external_lex_state = 2},
  [12469] = {.lex_state = 445, .external_lex_state = 2},
  [12470] = {.lex_state = 445, .external_lex_state = 2},
  [12471] = {.lex_state = 445, .external_lex_state = 2},
  [12472] = {.lex_state = 437, .external_lex_state = 2},
  [12473] = {.lex_state = 445, .external_lex_state = 2},
  [12474] = {.lex_state = 445, .external_lex_state = 2},
  [12475] = {.lex_state = 257, .external_lex_state = 2},
  [12476] = {.lex_state = 15, .external_lex_state = 2},
  [12477] = {.lex_state = 15, .external_lex_state = 2},
  [12478] = {.lex_state = 15, .external_lex_state = 2},
  [12479] = {.lex_state = 437, .external_lex_state = 2},
  [12480] = {.lex_state = 15, .external_lex_state = 2},
  [12481] = {.lex_state = 15, .external_lex_state = 2},
  [12482] = {.lex_state = 24, .external_lex_state = 3},
  [12483] = {.lex_state = 24, .external_lex_state = 3},
  [12484] = {.lex_state = 15, .external_lex_state = 2},
  [12485] = {.lex_state = 24, .external_lex_state = 2},
  [12486] = {.lex_state = 172, .external_lex_state = 2},
  [12487] = {.lex_state = 27, .external_lex_state = 2},
  [12488] = {.lex_state = 445, .external_lex_state = 2},
  [12489] = {.lex_state = 445, .external_lex_state = 2},
  [12490] = {.lex_state = 27, .external_lex_state = 2},
  [12491] = {.lex_state = 445, .external_lex_state = 2},
  [12492] = {.lex_state = 445, .external_lex_state = 2},
  [12493] = {.lex_state = 445, .external_lex_state = 2},
  [12494] = {.lex_state = 445, .external_lex_state = 2},
  [12495] = {.lex_state = 445, .external_lex_state = 2},
  [12496] = {.lex_state = 445, .external_lex_state = 2},
  [12497] = {.lex_state = 437, .external_lex_state = 2},
  [12498] = {.lex_state = 228, .external_lex_state = 2},
  [12499] = {.lex_state = 22, .external_lex_state = 2},
  [12500] = {.lex_state = 24, .external_lex_state = 3},
  [12501] = {.lex_state = 22, .external_lex_state = 2},
  [12502] = {.lex_state = 22, .external_lex_state = 2},
  [12503] = {.lex_state = 22, .external_lex_state = 2},
  [12504] = {.lex_state = 22, .external_lex_state = 2},
  [12505] = {.lex_state = 445, .external_lex_state = 2},
  [12506] = {.lex_state = 22, .external_lex_state = 2},
  [12507] = {.lex_state = 437, .external_lex_state = 2},
  [12508] = {.lex_state = 437, .external_lex_state = 2},
  [12509] = {.lex_state = 445, .external_lex_state = 2},
  [12510] = {.lex_state = 445, .external_lex_state = 2},
  [12511] = {.lex_state = 437, .external_lex_state = 2},
  [12512] = {.lex_state = 172, .external_lex_state = 2},
  [12513] = {.lex_state = 22, .external_lex_state = 2},
  [12514] = {.lex_state = 15, .external_lex_state = 2},
  [12515] = {.lex_state = 437, .external_lex_state = 2},
  [12516] = {.lex_state = 437, .external_lex_state = 2},
  [12517] = {.lex_state = 445, .external_lex_state = 2},
  [12518] = {.lex_state = 445, .external_lex_state = 2},
  [12519] = {.lex_state = 445, .external_lex_state = 2},
  [12520] = {.lex_state = 172, .external_lex_state = 2},
  [12521] = {.lex_state = 15, .external_lex_state = 2},
  [12522] = {.lex_state = 27, .external_lex_state = 2},
  [12523] = {.lex_state = 15, .external_lex_state = 2},
  [12524] = {.lex_state = 172, .external_lex_state = 2},
  [12525] = {.lex_state = 15, .external_lex_state = 2},
  [12526] = {.lex_state = 15, .external_lex_state = 2},
  [12527] = {.lex_state = 15, .external_lex_state = 2},
  [12528] = {.lex_state = 15, .external_lex_state = 2},
  [12529] = {.lex_state = 15, .external_lex_state = 2},
  [12530] = {.lex_state = 15, .external_lex_state = 2},
  [12531] = {.lex_state = 15, .external_lex_state = 2},
  [12532] = {.lex_state = 15, .external_lex_state = 2},
  [12533] = {.lex_state = 15, .external_lex_state = 2},
  [12534] = {.lex_state = 15, .external_lex_state = 2},
  [12535] = {.lex_state = 15, .external_lex_state = 2},
  [12536] = {.lex_state = 24, .external_lex_state = 3},
  [12537] = {.lex_state = 24, .external_lex_state = 3},
  [12538] = {.lex_state = 15, .external_lex_state = 2},
  [12539] = {.lex_state = 437, .external_lex_state = 2},
  [12540] = {.lex_state = 15, .external_lex_state = 2},
  [12541] = {.lex_state = 437, .external_lex_state = 2},
  [12542] = {.lex_state = 24, .external_lex_state = 2},
  [12543] = {.lex_state = 437, .external_lex_state = 2},
  [12544] = {.lex_state = 437, .external_lex_state = 2},
  [12545] = {.lex_state = 27, .external_lex_state = 2},
  [12546] = {.lex_state = 437, .external_lex_state = 2},
  [12547] = {.lex_state = 172, .external_lex_state = 2},
  [12548] = {.lex_state = 437, .external_lex_state = 2},
  [12549] = {.lex_state = 15, .external_lex_state = 2},
  [12550] = {.lex_state = 22, .external_lex_state = 2},
  [12551] = {.lex_state = 172, .external_lex_state = 2},
  [12552] = {.lex_state = 445, .external_lex_state = 2},
  [12553] = {.lex_state = 445, .external_lex_state = 2},
  [12554] = {.lex_state = 445, .external_lex_state = 2},
  [12555] = {.lex_state = 445, .external_lex_state = 2},
  [12556] = {.lex_state = 445, .external_lex_state = 2},
  [12557] = {.lex_state = 445, .external_lex_state = 2},
  [12558] = {.lex_state = 15, .external_lex_state = 2},
  [12559] = {.lex_state = 445, .external_lex_state = 2},
  [12560] = {.lex_state = 22, .external_lex_state = 2},
  [12561] = {.lex_state = 22, .external_lex_state = 2},
  [12562] = {.lex_state = 22, .external_lex_state = 2},
  [12563] = {.lex_state = 445, .external_lex_state = 2},
  [12564] = {.lex_state = 27, .external_lex_state = 2},
  [12565] = {.lex_state = 27, .external_lex_state = 2},
  [12566] = {.lex_state = 172, .external_lex_state = 2},
  [12567] = {.lex_state = 445, .external_lex_state = 2},
  [12568] = {.lex_state = 27, .external_lex_state = 2},
  [12569] = {.lex_state = 445, .external_lex_state = 2},
  [12570] = {.lex_state = 445, .external_lex_state = 2},
  [12571] = {.lex_state = 27, .external_lex_state = 2},
  [12572] = {.lex_state = 22, .external_lex_state = 2},
  [12573] = {.lex_state = 14, .external_lex_state = 2},
  [12574] = {.lex_state = 445, .external_lex_state = 2},
  [12575] = {.lex_state = 13, .external_lex_state = 2},
  [12576] = {.lex_state = 437, .external_lex_state = 2},
  [12577] = {.lex_state = 24, .external_lex_state = 2},
  [12578] = {.lex_state = 24, .external_lex_state = 2},
  [12579] = {.lex_state = 24, .external_lex_state = 2},
  [12580] = {.lex_state = 236, .external_lex_state = 2},
  [12581] = {.lex_state = 24, .external_lex_state = 2},
  [12582] = {.lex_state = 15, .external_lex_state = 2},
  [12583] = {.lex_state = 13, .external_lex_state = 2},
  [12584] = {.lex_state = 13, .external_lex_state = 2},
  [12585] = {.lex_state = 13, .external_lex_state = 2},
  [12586] = {.lex_state = 13, .external_lex_state = 2},
  [12587] = {.lex_state = 13, .external_lex_state = 2},
  [12588] = {.lex_state = 13, .external_lex_state = 2},
  [12589] = {.lex_state = 13, .external_lex_state = 2},
  [12590] = {.lex_state = 13, .external_lex_state = 2},
  [12591] = {.lex_state = 13, .external_lex_state = 2},
  [12592] = {.lex_state = 13, .external_lex_state = 2},
  [12593] = {.lex_state = 13, .external_lex_state = 2},
  [12594] = {.lex_state = 13, .external_lex_state = 2},
  [12595] = {.lex_state = 13, .external_lex_state = 2},
  [12596] = {.lex_state = 22, .external_lex_state = 2},
  [12597] = {.lex_state = 14, .external_lex_state = 2},
  [12598] = {.lex_state = 445, .external_lex_state = 2},
  [12599] = {.lex_state = 445, .external_lex_state = 2},
  [12600] = {.lex_state = 236, .external_lex_state = 2},
  [12601] = {.lex_state = 13, .external_lex_state = 2},
  [12602] = {.lex_state = 13, .external_lex_state = 2},
  [12603] = {.lex_state = 13, .external_lex_state = 2},
  [12604] = {.lex_state = 13, .external_lex_state = 2},
  [12605] = {.lex_state = 13, .external_lex_state = 2},
  [12606] = {.lex_state = 13, .external_lex_state = 2},
  [12607] = {.lex_state = 13, .external_lex_state = 2},
  [12608] = {.lex_state = 13, .external_lex_state = 2},
  [12609] = {.lex_state = 445, .external_lex_state = 2},
  [12610] = {.lex_state = 450, .external_lex_state = 2},
  [12611] = {.lex_state = 24, .external_lex_state = 2},
  [12612] = {.lex_state = 450, .external_lex_state = 2},
  [12613] = {.lex_state = 24, .external_lex_state = 2},
  [12614] = {.lex_state = 24, .external_lex_state = 2},
  [12615] = {.lex_state = 13, .external_lex_state = 2},
  [12616] = {.lex_state = 15, .external_lex_state = 2},
  [12617] = {.lex_state = 437, .external_lex_state = 2},
  [12618] = {.lex_state = 24, .external_lex_state = 2},
  [12619] = {.lex_state = 445, .external_lex_state = 2},
  [12620] = {.lex_state = 13, .external_lex_state = 2},
  [12621] = {.lex_state = 24, .external_lex_state = 2},
  [12622] = {.lex_state = 24, .external_lex_state = 2},
  [12623] = {.lex_state = 445, .external_lex_state = 2},
  [12624] = {.lex_state = 445, .external_lex_state = 2},
  [12625] = {.lex_state = 445, .external_lex_state = 2},
  [12626] = {.lex_state = 24, .external_lex_state = 2},
  [12627] = {.lex_state = 24, .external_lex_state = 2},
  [12628] = {.lex_state = 24, .external_lex_state = 2},
  [12629] = {.lex_state = 24, .external_lex_state = 2},
  [12630] = {.lex_state = 24, .external_lex_state = 2},
  [12631] = {.lex_state = 24, .external_lex_state = 2},
  [12632] = {.lex_state = 445, .external_lex_state = 2},
  [12633] = {.lex_state = 24, .external_lex_state = 2},
  [12634] = {.lex_state = 24, .external_lex_state = 2},
  [12635] = {.lex_state = 217, .external_lex_state = 2},
  [12636] = {.lex_state = 24, .external_lex_state = 2},
  [12637] = {.lex_state = 217, .external_lex_state = 2},
  [12638] = {.lex_state = 217, .external_lex_state = 2},
  [12639] = {.lex_state = 14, .external_lex_state = 2},
  [12640] = {.lex_state = 24, .external_lex_state = 2},
  [12641] = {.lex_state = 14, .external_lex_state = 2},
  [12642] = {.lex_state = 14, .external_lex_state = 2},
  [12643] = {.lex_state = 13, .external_lex_state = 2},
  [12644] = {.lex_state = 14, .external_lex_state = 2},
  [12645] = {.lex_state = 14, .external_lex_state = 2},
  [12646] = {.lex_state = 14, .external_lex_state = 2},
  [12647] = {.lex_state = 15, .external_lex_state = 2},
  [12648] = {.lex_state = 15, .external_lex_state = 2},
  [12649] = {.lex_state = 15, .external_lex_state = 2},
  [12650] = {.lex_state = 15, .external_lex_state = 2},
  [12651] = {.lex_state = 15, .external_lex_state = 2},
  [12652] = {.lex_state = 445, .external_lex_state = 2},
  [12653] = {.lex_state = 445, .external_lex_state = 2},
  [12654] = {.lex_state = 217, .external_lex_state = 2},
  [12655] = {.lex_state = 13, .external_lex_state = 2},
  [12656] = {.lex_state = 15, .external_lex_state = 2},
  [12657] = {.lex_state = 13, .external_lex_state = 2},
  [12658] = {.lex_state = 15, .external_lex_state = 2},
  [12659] = {.lex_state = 15, .external_lex_state = 2},
  [12660] = {.lex_state = 14, .external_lex_state = 2},
  [12661] = {.lex_state = 14, .external_lex_state = 2},
  [12662] = {.lex_state = 14, .external_lex_state = 2},
  [12663] = {.lex_state = 14, .external_lex_state = 2},
  [12664] = {.lex_state = 14, .external_lex_state = 2},
  [12665] = {.lex_state = 14, .external_lex_state = 2},
  [12666] = {.lex_state = 14, .external_lex_state = 2},
  [12667] = {.lex_state = 14, .external_lex_state = 2},
  [12668] = {.lex_state = 14, .external_lex_state = 2},
  [12669] = {.lex_state = 14, .external_lex_state = 2},
  [12670] = {.lex_state = 217, .external_lex_state = 2},
  [12671] = {.lex_state = 14, .external_lex_state = 2},
  [12672] = {.lex_state = 14, .external_lex_state = 2},
  [12673] = {.lex_state = 15, .external_lex_state = 2},
  [12674] = {.lex_state = 24, .external_lex_state = 2},
  [12675] = {.lex_state = 14, .external_lex_state = 2},
  [12676] = {.lex_state = 14, .external_lex_state = 2},
  [12677] = {.lex_state = 13, .external_lex_state = 2},
  [12678] = {.lex_state = 13, .external_lex_state = 2},
  [12679] = {.lex_state = 13, .external_lex_state = 2},
  [12680] = {.lex_state = 13, .external_lex_state = 2},
  [12681] = {.lex_state = 13, .external_lex_state = 2},
  [12682] = {.lex_state = 13, .external_lex_state = 2},
  [12683] = {.lex_state = 13, .external_lex_state = 2},
  [12684] = {.lex_state = 13, .external_lex_state = 2},
  [12685] = {.lex_state = 13, .external_lex_state = 2},
  [12686] = {.lex_state = 13, .external_lex_state = 2},
  [12687] = {.lex_state = 13, .external_lex_state = 2},
  [12688] = {.lex_state = 13, .external_lex_state = 2},
  [12689] = {.lex_state = 13, .external_lex_state = 2},
  [12690] = {.lex_state = 14, .external_lex_state = 2},
  [12691] = {.lex_state = 14, .external_lex_state = 2},
  [12692] = {.lex_state = 236, .external_lex_state = 2},
  [12693] = {.lex_state = 445, .external_lex_state = 2},
  [12694] = {.lex_state = 15, .external_lex_state = 2},
  [12695] = {.lex_state = 14, .external_lex_state = 2},
  [12696] = {.lex_state = 15, .external_lex_state = 2},
  [12697] = {.lex_state = 15, .external_lex_state = 2},
  [12698] = {.lex_state = 15, .external_lex_state = 2},
  [12699] = {.lex_state = 15, .external_lex_state = 2},
  [12700] = {.lex_state = 15, .external_lex_state = 2},
  [12701] = {.lex_state = 15, .external_lex_state = 2},
  [12702] = {.lex_state = 15, .external_lex_state = 2},
  [12703] = {.lex_state = 15, .external_lex_state = 2},
  [12704] = {.lex_state = 445, .external_lex_state = 2},
  [12705] = {.lex_state = 15, .external_lex_state = 2},
  [12706] = {.lex_state = 15, .external_lex_state = 2},
  [12707] = {.lex_state = 445, .external_lex_state = 2},
  [12708] = {.lex_state = 445, .external_lex_state = 2},
  [12709] = {.lex_state = 445, .external_lex_state = 2},
  [12710] = {.lex_state = 24, .external_lex_state = 2},
  [12711] = {.lex_state = 445, .external_lex_state = 2},
  [12712] = {.lex_state = 15, .external_lex_state = 2},
  [12713] = {.lex_state = 24, .external_lex_state = 2},
  [12714] = {.lex_state = 24, .external_lex_state = 2},
  [12715] = {.lex_state = 13, .external_lex_state = 2},
  [12716] = {.lex_state = 13, .external_lex_state = 2},
  [12717] = {.lex_state = 13, .external_lex_state = 2},
  [12718] = {.lex_state = 15, .external_lex_state = 2},
  [12719] = {.lex_state = 15, .external_lex_state = 2},
  [12720] = {.lex_state = 15, .external_lex_state = 2},
  [12721] = {.lex_state = 217, .external_lex_state = 2},
  [12722] = {.lex_state = 15, .external_lex_state = 2},
  [12723] = {.lex_state = 15, .external_lex_state = 2},
  [12724] = {.lex_state = 217, .external_lex_state = 2},
  [12725] = {.lex_state = 217, .external_lex_state = 2},
  [12726] = {.lex_state = 13, .external_lex_state = 2},
  [12727] = {.lex_state = 13, .external_lex_state = 2},
  [12728] = {.lex_state = 13, .external_lex_state = 2},
  [12729] = {.lex_state = 13, .external_lex_state = 2},
  [12730] = {.lex_state = 13, .external_lex_state = 2},
  [12731] = {.lex_state = 13, .external_lex_state = 2},
  [12732] = {.lex_state = 13, .external_lex_state = 2},
  [12733] = {.lex_state = 13, .external_lex_state = 2},
  [12734] = {.lex_state = 13, .external_lex_state = 2},
  [12735] = {.lex_state = 13, .external_lex_state = 2},
  [12736] = {.lex_state = 13, .external_lex_state = 2},
  [12737] = {.lex_state = 13, .external_lex_state = 2},
  [12738] = {.lex_state = 13, .external_lex_state = 2},
  [12739] = {.lex_state = 15, .external_lex_state = 2},
  [12740] = {.lex_state = 24, .external_lex_state = 2},
  [12741] = {.lex_state = 445, .external_lex_state = 2},
  [12742] = {.lex_state = 445, .external_lex_state = 2},
  [12743] = {.lex_state = 13, .external_lex_state = 2},
  [12744] = {.lex_state = 13, .external_lex_state = 2},
  [12745] = {.lex_state = 13, .external_lex_state = 2},
  [12746] = {.lex_state = 13, .external_lex_state = 2},
  [12747] = {.lex_state = 13, .external_lex_state = 2},
  [12748] = {.lex_state = 13, .external_lex_state = 2},
  [12749] = {.lex_state = 13, .external_lex_state = 2},
  [12750] = {.lex_state = 13, .external_lex_state = 2},
  [12751] = {.lex_state = 13, .external_lex_state = 2},
  [12752] = {.lex_state = 13, .external_lex_state = 2},
  [12753] = {.lex_state = 13, .external_lex_state = 2},
  [12754] = {.lex_state = 13, .external_lex_state = 2},
  [12755] = {.lex_state = 13, .external_lex_state = 2},
  [12756] = {.lex_state = 13, .external_lex_state = 2},
  [12757] = {.lex_state = 13, .external_lex_state = 2},
  [12758] = {.lex_state = 13, .external_lex_state = 2},
  [12759] = {.lex_state = 24, .external_lex_state = 2},
  [12760] = {.lex_state = 24, .external_lex_state = 2},
  [12761] = {.lex_state = 13, .external_lex_state = 2},
  [12762] = {.lex_state = 13, .external_lex_state = 2},
  [12763] = {.lex_state = 13, .external_lex_state = 2},
  [12764] = {.lex_state = 236, .external_lex_state = 2},
  [12765] = {.lex_state = 13, .external_lex_state = 2},
  [12766] = {.lex_state = 437, .external_lex_state = 2},
  [12767] = {.lex_state = 235, .external_lex_state = 2},
  [12768] = {.lex_state = 235, .external_lex_state = 2},
  [12769] = {.lex_state = 235, .external_lex_state = 2},
  [12770] = {.lex_state = 24, .external_lex_state = 2},
  [12771] = {.lex_state = 24, .external_lex_state = 2},
  [12772] = {.lex_state = 24, .external_lex_state = 2},
  [12773] = {.lex_state = 24, .external_lex_state = 2},
  [12774] = {.lex_state = 15, .external_lex_state = 2},
  [12775] = {.lex_state = 24, .external_lex_state = 2},
  [12776] = {.lex_state = 450, .external_lex_state = 2},
  [12777] = {.lex_state = 450, .external_lex_state = 2},
  [12778] = {.lex_state = 450, .external_lex_state = 2},
  [12779] = {.lex_state = 24, .external_lex_state = 2},
  [12780] = {.lex_state = 24, .external_lex_state = 2},
  [12781] = {.lex_state = 24, .external_lex_state = 2},
  [12782] = {.lex_state = 24, .external_lex_state = 2},
  [12783] = {.lex_state = 13, .external_lex_state = 2},
  [12784] = {.lex_state = 13, .external_lex_state = 2},
  [12785] = {.lex_state = 13, .external_lex_state = 2},
  [12786] = {.lex_state = 13, .external_lex_state = 2},
  [12787] = {.lex_state = 13, .external_lex_state = 2},
  [12788] = {.lex_state = 236, .external_lex_state = 2},
  [12789] = {.lex_state = 24, .external_lex_state = 2},
  [12790] = {.lex_state = 15, .external_lex_state = 2},
  [12791] = {.lex_state = 13, .external_lex_state = 2},
  [12792] = {.lex_state = 13, .external_lex_state = 2},
  [12793] = {.lex_state = 13, .external_lex_state = 2},
  [12794] = {.lex_state = 13, .external_lex_state = 2},
  [12795] = {.lex_state = 13, .external_lex_state = 2},
  [12796] = {.lex_state = 236, .external_lex_state = 2},
  [12797] = {.lex_state = 445, .external_lex_state = 2},
  [12798] = {.lex_state = 445, .external_lex_state = 2},
  [12799] = {.lex_state = 24, .external_lex_state = 2},
  [12800] = {.lex_state = 15, .external_lex_state = 2},
  [12801] = {.lex_state = 13, .external_lex_state = 2},
  [12802] = {.lex_state = 14, .external_lex_state = 2},
  [12803] = {.lex_state = 24, .external_lex_state = 2},
  [12804] = {.lex_state = 13, .external_lex_state = 2},
  [12805] = {.lex_state = 13, .external_lex_state = 2},
  [12806] = {.lex_state = 13, .external_lex_state = 2},
  [12807] = {.lex_state = 13, .external_lex_state = 2},
  [12808] = {.lex_state = 13, .external_lex_state = 2},
  [12809] = {.lex_state = 450, .external_lex_state = 2},
  [12810] = {.lex_state = 24, .external_lex_state = 2},
  [12811] = {.lex_state = 24, .external_lex_state = 2},
  [12812] = {.lex_state = 13, .external_lex_state = 2},
  [12813] = {.lex_state = 13, .external_lex_state = 2},
  [12814] = {.lex_state = 13, .external_lex_state = 2},
  [12815] = {.lex_state = 13, .external_lex_state = 2},
  [12816] = {.lex_state = 13, .external_lex_state = 2},
  [12817] = {.lex_state = 24, .external_lex_state = 2},
  [12818] = {.lex_state = 24, .external_lex_state = 2},
  [12819] = {.lex_state = 24, .external_lex_state = 2},
  [12820] = {.lex_state = 24, .external_lex_state = 2},
  [12821] = {.lex_state = 450, .external_lex_state = 2},
  [12822] = {.lex_state = 24, .external_lex_state = 2},
  [12823] = {.lex_state = 24, .external_lex_state = 2},
  [12824] = {.lex_state = 15, .external_lex_state = 2},
  [12825] = {.lex_state = 24, .external_lex_state = 2},
  [12826] = {.lex_state = 15, .external_lex_state = 2},
  [12827] = {.lex_state = 24, .external_lex_state = 2},
  [12828] = {.lex_state = 15, .external_lex_state = 2},
  [12829] = {.lex_state = 15, .external_lex_state = 2},
  [12830] = {.lex_state = 15, .external_lex_state = 2},
  [12831] = {.lex_state = 15, .external_lex_state = 2},
  [12832] = {.lex_state = 15, .external_lex_state = 2},
  [12833] = {.lex_state = 24, .external_lex_state = 2},
  [12834] = {.lex_state = 15, .external_lex_state = 2},
  [12835] = {.lex_state = 15, .external_lex_state = 2},
  [12836] = {.lex_state = 15, .external_lex_state = 2},
  [12837] = {.lex_state = 15, .external_lex_state = 2},
  [12838] = {.lex_state = 24, .external_lex_state = 2},
  [12839] = {.lex_state = 24, .external_lex_state = 2},
  [12840] = {.lex_state = 24, .external_lex_state = 2},
  [12841] = {.lex_state = 437, .external_lex_state = 2},
  [12842] = {.lex_state = 24, .external_lex_state = 2},
  [12843] = {.lex_state = 24, .external_lex_state = 2},
  [12844] = {.lex_state = 13, .external_lex_state = 2},
  [12845] = {.lex_state = 24, .external_lex_state = 2},
  [12846] = {.lex_state = 24, .external_lex_state = 2},
  [12847] = {.lex_state = 24, .external_lex_state = 2},
  [12848] = {.lex_state = 24, .external_lex_state = 2},
  [12849] = {.lex_state = 24, .external_lex_state = 2},
  [12850] = {.lex_state = 24, .external_lex_state = 2},
  [12851] = {.lex_state = 15, .external_lex_state = 2},
  [12852] = {.lex_state = 13, .external_lex_state = 2},
  [12853] = {.lex_state = 445, .external_lex_state = 2},
  [12854] = {.lex_state = 24, .external_lex_state = 2},
  [12855] = {.lex_state = 445, .external_lex_state = 2},
  [12856] = {.lex_state = 24, .external_lex_state = 2},
  [12857] = {.lex_state = 15, .external_lex_state = 2},
  [12858] = {.lex_state = 24, .external_lex_state = 2},
  [12859] = {.lex_state = 24, .external_lex_state = 2},
  [12860] = {.lex_state = 24, .external_lex_state = 2},
  [12861] = {.lex_state = 24, .external_lex_state = 2},
  [12862] = {.lex_state = 13, .external_lex_state = 2},
  [12863] = {.lex_state = 24, .external_lex_state = 2},
  [12864] = {.lex_state = 445, .external_lex_state = 2},
  [12865] = {.lex_state = 24, .external_lex_state = 2},
  [12866] = {.lex_state = 24, .external_lex_state = 2},
  [12867] = {.lex_state = 24, .external_lex_state = 2},
  [12868] = {.lex_state = 24, .external_lex_state = 2},
  [12869] = {.lex_state = 24, .external_lex_state = 2},
  [12870] = {.lex_state = 24, .external_lex_state = 2},
  [12871] = {.lex_state = 24, .external_lex_state = 2},
  [12872] = {.lex_state = 24, .external_lex_state = 2},
  [12873] = {.lex_state = 8, .external_lex_state = 2},
  [12874] = {.lex_state = 445, .external_lex_state = 2},
  [12875] = {.lex_state = 445, .external_lex_state = 2},
  [12876] = {.lex_state = 445, .external_lex_state = 2},
  [12877] = {.lex_state = 445, .external_lex_state = 2},
  [12878] = {.lex_state = 445, .external_lex_state = 2},
  [12879] = {.lex_state = 445, .external_lex_state = 2},
  [12880] = {.lex_state = 15, .external_lex_state = 2},
  [12881] = {.lex_state = 445, .external_lex_state = 2},
  [12882] = {.lex_state = 24, .external_lex_state = 2},
  [12883] = {.lex_state = 14, .external_lex_state = 2},
  [12884] = {.lex_state = 14, .external_lex_state = 2},
  [12885] = {.lex_state = 8, .external_lex_state = 2},
  [12886] = {.lex_state = 445, .external_lex_state = 2},
  [12887] = {.lex_state = 445, .external_lex_state = 2},
  [12888] = {.lex_state = 445, .external_lex_state = 2},
  [12889] = {.lex_state = 8, .external_lex_state = 2},
  [12890] = {.lex_state = 445, .external_lex_state = 2},
  [12891] = {.lex_state = 445, .external_lex_state = 2},
  [12892] = {.lex_state = 445, .external_lex_state = 2},
  [12893] = {.lex_state = 15, .external_lex_state = 2},
  [12894] = {.lex_state = 13, .external_lex_state = 2},
  [12895] = {.lex_state = 15, .external_lex_state = 2},
  [12896] = {.lex_state = 24, .external_lex_state = 2},
  [12897] = {.lex_state = 24, .external_lex_state = 2},
  [12898] = {.lex_state = 8, .external_lex_state = 2},
  [12899] = {.lex_state = 437, .external_lex_state = 2},
  [12900] = {.lex_state = 445, .external_lex_state = 2},
  [12901] = {.lex_state = 235, .external_lex_state = 2},
  [12902] = {.lex_state = 13, .external_lex_state = 2},
  [12903] = {.lex_state = 13, .external_lex_state = 2},
  [12904] = {.lex_state = 445, .external_lex_state = 2},
  [12905] = {.lex_state = 445, .external_lex_state = 2},
  [12906] = {.lex_state = 24, .external_lex_state = 2},
  [12907] = {.lex_state = 445, .external_lex_state = 2},
  [12908] = {.lex_state = 445, .external_lex_state = 2},
  [12909] = {.lex_state = 445, .external_lex_state = 2},
  [12910] = {.lex_state = 24, .external_lex_state = 2},
  [12911] = {.lex_state = 445, .external_lex_state = 2},
  [12912] = {.lex_state = 445, .external_lex_state = 2},
  [12913] = {.lex_state = 445, .external_lex_state = 2},
  [12914] = {.lex_state = 445, .external_lex_state = 2},
  [12915] = {.lex_state = 445, .external_lex_state = 2},
  [12916] = {.lex_state = 445, .external_lex_state = 2},
  [12917] = {.lex_state = 445, .external_lex_state = 2},
  [12918] = {.lex_state = 13, .external_lex_state = 2},
  [12919] = {.lex_state = 13, .external_lex_state = 2},
  [12920] = {.lex_state = 14, .external_lex_state = 2},
  [12921] = {.lex_state = 14, .external_lex_state = 2},
  [12922] = {.lex_state = 14, .external_lex_state = 2},
  [12923] = {.lex_state = 14, .external_lex_state = 2},
  [12924] = {.lex_state = 14, .external_lex_state = 2},
  [12925] = {.lex_state = 14, .external_lex_state = 2},
  [12926] = {.lex_state = 14, .external_lex_state = 2},
  [12927] = {.lex_state = 14, .external_lex_state = 2},
  [12928] = {.lex_state = 236, .external_lex_state = 2},
  [12929] = {.lex_state = 14, .external_lex_state = 2},
  [12930] = {.lex_state = 14, .external_lex_state = 2},
  [12931] = {.lex_state = 14, .external_lex_state = 2},
  [12932] = {.lex_state = 14, .external_lex_state = 2},
  [12933] = {.lex_state = 13, .external_lex_state = 2},
  [12934] = {.lex_state = 14, .external_lex_state = 2},
  [12935] = {.lex_state = 15, .external_lex_state = 2},
  [12936] = {.lex_state = 437, .external_lex_state = 2},
  [12937] = {.lex_state = 14, .external_lex_state = 2},
  [12938] = {.lex_state = 14, .external_lex_state = 2},
  [12939] = {.lex_state = 215, .external_lex_state = 5},
  [12940] = {.lex_state = 14, .external_lex_state = 2},
  [12941] = {.lex_state = 14, .external_lex_state = 2},
  [12942] = {.lex_state = 14, .external_lex_state = 2},
  [12943] = {.lex_state = 445, .external_lex_state = 2},
  [12944] = {.lex_state = 14, .external_lex_state = 2},
  [12945] = {.lex_state = 14, .external_lex_state = 2},
  [12946] = {.lex_state = 215, .external_lex_state = 5},
  [12947] = {.lex_state = 14, .external_lex_state = 2},
  [12948] = {.lex_state = 445, .external_lex_state = 2},
  [12949] = {.lex_state = 215, .external_lex_state = 5},
  [12950] = {.lex_state = 14, .external_lex_state = 2},
  [12951] = {.lex_state = 24, .external_lex_state = 2},
  [12952] = {.lex_state = 445, .external_lex_state = 2},
  [12953] = {.lex_state = 14, .external_lex_state = 2},
  [12954] = {.lex_state = 14, .external_lex_state = 2},
  [12955] = {.lex_state = 14, .external_lex_state = 2},
  [12956] = {.lex_state = 437, .external_lex_state = 2},
  [12957] = {.lex_state = 215, .external_lex_state = 5},
  [12958] = {.lex_state = 215, .external_lex_state = 5},
  [12959] = {.lex_state = 14, .external_lex_state = 2},
  [12960] = {.lex_state = 13, .external_lex_state = 2},
  [12961] = {.lex_state = 13, .external_lex_state = 2},
  [12962] = {.lex_state = 13, .external_lex_state = 2},
  [12963] = {.lex_state = 13, .external_lex_state = 2},
  [12964] = {.lex_state = 13, .external_lex_state = 2},
  [12965] = {.lex_state = 215, .external_lex_state = 5},
  [12966] = {.lex_state = 14, .external_lex_state = 2},
  [12967] = {.lex_state = 14, .external_lex_state = 2},
  [12968] = {.lex_state = 14, .external_lex_state = 2},
  [12969] = {.lex_state = 437, .external_lex_state = 2},
  [12970] = {.lex_state = 437, .external_lex_state = 2},
  [12971] = {.lex_state = 24, .external_lex_state = 2},
  [12972] = {.lex_state = 215, .external_lex_state = 5},
  [12973] = {.lex_state = 14, .external_lex_state = 2},
  [12974] = {.lex_state = 215, .external_lex_state = 5},
  [12975] = {.lex_state = 437, .external_lex_state = 2},
  [12976] = {.lex_state = 14, .external_lex_state = 2},
  [12977] = {.lex_state = 14, .external_lex_state = 2},
  [12978] = {.lex_state = 14, .external_lex_state = 2},
  [12979] = {.lex_state = 14, .external_lex_state = 2},
  [12980] = {.lex_state = 24, .external_lex_state = 2},
  [12981] = {.lex_state = 14, .external_lex_state = 2},
  [12982] = {.lex_state = 13, .external_lex_state = 2},
  [12983] = {.lex_state = 14, .external_lex_state = 2},
  [12984] = {.lex_state = 14, .external_lex_state = 2},
  [12985] = {.lex_state = 437, .external_lex_state = 2},
  [12986] = {.lex_state = 14, .external_lex_state = 2},
  [12987] = {.lex_state = 13, .external_lex_state = 2},
  [12988] = {.lex_state = 437, .external_lex_state = 2},
  [12989] = {.lex_state = 13, .external_lex_state = 2},
  [12990] = {.lex_state = 215, .external_lex_state = 5},
  [12991] = {.lex_state = 14, .external_lex_state = 2},
  [12992] = {.lex_state = 215, .external_lex_state = 5},
  [12993] = {.lex_state = 14, .external_lex_state = 2},
  [12994] = {.lex_state = 14, .external_lex_state = 2},
  [12995] = {.lex_state = 14, .external_lex_state = 2},
  [12996] = {.lex_state = 15, .external_lex_state = 2},
  [12997] = {.lex_state = 14, .external_lex_state = 2},
  [12998] = {.lex_state = 15, .external_lex_state = 2},
  [12999] = {.lex_state = 14, .external_lex_state = 2},
  [13000] = {.lex_state = 437, .external_lex_state = 2},
  [13001] = {.lex_state = 14, .external_lex_state = 2},
  [13002] = {.lex_state = 14, .external_lex_state = 2},
  [13003] = {.lex_state = 14, .external_lex_state = 2},
  [13004] = {.lex_state = 215, .external_lex_state = 5},
  [13005] = {.lex_state = 14, .external_lex_state = 2},
  [13006] = {.lex_state = 13, .external_lex_state = 2},
  [13007] = {.lex_state = 13, .external_lex_state = 2},
  [13008] = {.lex_state = 13, .external_lex_state = 2},
  [13009] = {.lex_state = 13, .external_lex_state = 2},
  [13010] = {.lex_state = 13, .external_lex_state = 2},
  [13011] = {.lex_state = 14, .external_lex_state = 2},
  [13012] = {.lex_state = 14, .external_lex_state = 2},
  [13013] = {.lex_state = 24, .external_lex_state = 2},
  [13014] = {.lex_state = 14, .external_lex_state = 2},
  [13015] = {.lex_state = 445, .external_lex_state = 2},
  [13016] = {.lex_state = 15, .external_lex_state = 2},
  [13017] = {.lex_state = 15, .external_lex_state = 2},
  [13018] = {.lex_state = 15, .external_lex_state = 2},
  [13019] = {.lex_state = 215, .external_lex_state = 5},
  [13020] = {.lex_state = 437, .external_lex_state = 2},
  [13021] = {.lex_state = 13, .external_lex_state = 2},
  [13022] = {.lex_state = 14, .external_lex_state = 2},
  [13023] = {.lex_state = 24, .external_lex_state = 2},
  [13024] = {.lex_state = 437, .external_lex_state = 2},
  [13025] = {.lex_state = 215, .external_lex_state = 5},
  [13026] = {.lex_state = 215, .external_lex_state = 5},
  [13027] = {.lex_state = 14, .external_lex_state = 2},
  [13028] = {.lex_state = 13, .external_lex_state = 2},
  [13029] = {.lex_state = 14, .external_lex_state = 2},
  [13030] = {.lex_state = 14, .external_lex_state = 2},
  [13031] = {.lex_state = 437, .external_lex_state = 2},
  [13032] = {.lex_state = 215, .external_lex_state = 5},
  [13033] = {.lex_state = 14, .external_lex_state = 2},
  [13034] = {.lex_state = 13, .external_lex_state = 2},
  [13035] = {.lex_state = 14, .external_lex_state = 2},
  [13036] = {.lex_state = 13, .external_lex_state = 2},
  [13037] = {.lex_state = 15, .external_lex_state = 2},
  [13038] = {.lex_state = 15, .external_lex_state = 2},
  [13039] = {.lex_state = 14, .external_lex_state = 2},
  [13040] = {.lex_state = 15, .external_lex_state = 2},
  [13041] = {.lex_state = 15, .external_lex_state = 2},
  [13042] = {.lex_state = 15, .external_lex_state = 2},
  [13043] = {.lex_state = 15, .external_lex_state = 2},
  [13044] = {.lex_state = 15, .external_lex_state = 2},
  [13045] = {.lex_state = 215, .external_lex_state = 5},
  [13046] = {.lex_state = 15, .external_lex_state = 2},
  [13047] = {.lex_state = 15, .external_lex_state = 2},
  [13048] = {.lex_state = 13, .external_lex_state = 2},
  [13049] = {.lex_state = 13, .external_lex_state = 2},
  [13050] = {.lex_state = 13, .external_lex_state = 2},
  [13051] = {.lex_state = 13, .external_lex_state = 2},
  [13052] = {.lex_state = 13, .external_lex_state = 2},
  [13053] = {.lex_state = 14, .external_lex_state = 2},
  [13054] = {.lex_state = 14, .external_lex_state = 2},
  [13055] = {.lex_state = 14, .external_lex_state = 2},
  [13056] = {.lex_state = 13, .external_lex_state = 2},
  [13057] = {.lex_state = 14, .external_lex_state = 2},
  [13058] = {.lex_state = 236, .external_lex_state = 2},
  [13059] = {.lex_state = 14, .external_lex_state = 2},
  [13060] = {.lex_state = 14, .external_lex_state = 2},
  [13061] = {.lex_state = 445, .external_lex_state = 2},
  [13062] = {.lex_state = 14, .external_lex_state = 2},
  [13063] = {.lex_state = 215, .external_lex_state = 5},
  [13064] = {.lex_state = 14, .external_lex_state = 2},
  [13065] = {.lex_state = 24, .external_lex_state = 2},
  [13066] = {.lex_state = 215, .external_lex_state = 5},
  [13067] = {.lex_state = 14, .external_lex_state = 2},
  [13068] = {.lex_state = 215, .external_lex_state = 5},
  [13069] = {.lex_state = 14, .external_lex_state = 2},
  [13070] = {.lex_state = 13, .external_lex_state = 2},
  [13071] = {.lex_state = 215, .external_lex_state = 5},
  [13072] = {.lex_state = 14, .external_lex_state = 2},
  [13073] = {.lex_state = 215, .external_lex_state = 5},
  [13074] = {.lex_state = 215, .external_lex_state = 5},
  [13075] = {.lex_state = 215, .external_lex_state = 5},
  [13076] = {.lex_state = 215, .external_lex_state = 5},
  [13077] = {.lex_state = 215, .external_lex_state = 5},
  [13078] = {.lex_state = 14, .external_lex_state = 2},
  [13079] = {.lex_state = 215, .external_lex_state = 5},
  [13080] = {.lex_state = 14, .external_lex_state = 2},
  [13081] = {.lex_state = 14, .external_lex_state = 2},
  [13082] = {.lex_state = 215, .external_lex_state = 5},
  [13083] = {.lex_state = 15, .external_lex_state = 2},
  [13084] = {.lex_state = 215, .external_lex_state = 5},
  [13085] = {.lex_state = 215, .external_lex_state = 5},
  [13086] = {.lex_state = 215, .external_lex_state = 5},
  [13087] = {.lex_state = 215, .external_lex_state = 5},
  [13088] = {.lex_state = 215, .external_lex_state = 5},
  [13089] = {.lex_state = 14, .external_lex_state = 2},
  [13090] = {.lex_state = 15, .external_lex_state = 2},
  [13091] = {.lex_state = 215, .external_lex_state = 5},
  [13092] = {.lex_state = 14, .external_lex_state = 2},
  [13093] = {.lex_state = 445, .external_lex_state = 2},
  [13094] = {.lex_state = 14, .external_lex_state = 2},
  [13095] = {.lex_state = 445, .external_lex_state = 2},
  [13096] = {.lex_state = 445, .external_lex_state = 2},
  [13097] = {.lex_state = 14, .external_lex_state = 2},
  [13098] = {.lex_state = 14, .external_lex_state = 2},
  [13099] = {.lex_state = 14, .external_lex_state = 2},
  [13100] = {.lex_state = 14, .external_lex_state = 2},
  [13101] = {.lex_state = 14, .external_lex_state = 2},
  [13102] = {.lex_state = 14, .external_lex_state = 2},
  [13103] = {.lex_state = 14, .external_lex_state = 2},
  [13104] = {.lex_state = 215, .external_lex_state = 5},
  [13105] = {.lex_state = 215, .external_lex_state = 5},
  [13106] = {.lex_state = 437, .external_lex_state = 2},
  [13107] = {.lex_state = 14, .external_lex_state = 2},
  [13108] = {.lex_state = 445, .external_lex_state = 2},
  [13109] = {.lex_state = 14, .external_lex_state = 2},
  [13110] = {.lex_state = 13, .external_lex_state = 2},
  [13111] = {.lex_state = 13, .external_lex_state = 2},
  [13112] = {.lex_state = 14, .external_lex_state = 2},
  [13113] = {.lex_state = 14, .external_lex_state = 2},
  [13114] = {.lex_state = 14, .external_lex_state = 2},
  [13115] = {.lex_state = 14, .external_lex_state = 2},
  [13116] = {.lex_state = 14, .external_lex_state = 2},
  [13117] = {.lex_state = 24, .external_lex_state = 2},
  [13118] = {.lex_state = 14, .external_lex_state = 2},
  [13119] = {.lex_state = 14, .external_lex_state = 2},
  [13120] = {.lex_state = 24, .external_lex_state = 2},
  [13121] = {.lex_state = 14, .external_lex_state = 2},
  [13122] = {.lex_state = 14, .external_lex_state = 2},
  [13123] = {.lex_state = 24, .external_lex_state = 2},
  [13124] = {.lex_state = 24, .external_lex_state = 2},
  [13125] = {.lex_state = 13, .external_lex_state = 2},
  [13126] = {.lex_state = 14, .external_lex_state = 2},
  [13127] = {.lex_state = 14, .external_lex_state = 2},
  [13128] = {.lex_state = 14, .external_lex_state = 2},
  [13129] = {.lex_state = 14, .external_lex_state = 2},
  [13130] = {.lex_state = 14, .external_lex_state = 2},
  [13131] = {.lex_state = 14, .external_lex_state = 2},
  [13132] = {.lex_state = 14, .external_lex_state = 2},
  [13133] = {.lex_state = 14, .external_lex_state = 2},
  [13134] = {.lex_state = 14, .external_lex_state = 2},
  [13135] = {.lex_state = 14, .external_lex_state = 2},
  [13136] = {.lex_state = 13, .external_lex_state = 2},
  [13137] = {.lex_state = 14, .external_lex_state = 2},
  [13138] = {.lex_state = 14, .external_lex_state = 2},
  [13139] = {.lex_state = 15, .external_lex_state = 2},
  [13140] = {.lex_state = 445, .external_lex_state = 2},
  [13141] = {.lex_state = 14, .external_lex_state = 2},
  [13142] = {.lex_state = 14, .external_lex_state = 2},
  [13143] = {.lex_state = 14, .external_lex_state = 2},
  [13144] = {.lex_state = 13, .external_lex_state = 2},
  [13145] = {.lex_state = 14, .external_lex_state = 2},
  [13146] = {.lex_state = 24, .external_lex_state = 2},
  [13147] = {.lex_state = 24, .external_lex_state = 2},
  [13148] = {.lex_state = 13, .external_lex_state = 2},
  [13149] = {.lex_state = 24, .external_lex_state = 2},
  [13150] = {.lex_state = 14, .external_lex_state = 2},
  [13151] = {.lex_state = 13, .external_lex_state = 2},
  [13152] = {.lex_state = 445, .external_lex_state = 2},
  [13153] = {.lex_state = 13, .external_lex_state = 2},
  [13154] = {.lex_state = 14, .external_lex_state = 2},
  [13155] = {.lex_state = 14, .external_lex_state = 2},
  [13156] = {.lex_state = 13, .external_lex_state = 2},
  [13157] = {.lex_state = 215, .external_lex_state = 5},
  [13158] = {.lex_state = 13, .external_lex_state = 2},
  [13159] = {.lex_state = 13, .external_lex_state = 2},
  [13160] = {.lex_state = 13, .external_lex_state = 2},
  [13161] = {.lex_state = 13, .external_lex_state = 2},
  [13162] = {.lex_state = 15, .external_lex_state = 2},
  [13163] = {.lex_state = 14, .external_lex_state = 2},
  [13164] = {.lex_state = 13, .external_lex_state = 2},
  [13165] = {.lex_state = 13, .external_lex_state = 2},
  [13166] = {.lex_state = 14, .external_lex_state = 2},
  [13167] = {.lex_state = 13, .external_lex_state = 2},
  [13168] = {.lex_state = 445, .external_lex_state = 2},
  [13169] = {.lex_state = 13, .external_lex_state = 2},
  [13170] = {.lex_state = 14, .external_lex_state = 2},
  [13171] = {.lex_state = 445, .external_lex_state = 2},
  [13172] = {.lex_state = 14, .external_lex_state = 2},
  [13173] = {.lex_state = 13, .external_lex_state = 2},
  [13174] = {.lex_state = 14, .external_lex_state = 2},
  [13175] = {.lex_state = 15, .external_lex_state = 2},
  [13176] = {.lex_state = 14, .external_lex_state = 2},
  [13177] = {.lex_state = 445, .external_lex_state = 2},
  [13178] = {.lex_state = 215, .external_lex_state = 5},
  [13179] = {.lex_state = 14, .external_lex_state = 2},
  [13180] = {.lex_state = 14, .external_lex_state = 2},
  [13181] = {.lex_state = 445, .external_lex_state = 2},
  [13182] = {.lex_state = 14, .external_lex_state = 2},
  [13183] = {.lex_state = 24, .external_lex_state = 2},
  [13184] = {.lex_state = 14, .external_lex_state = 2},
  [13185] = {.lex_state = 14, .external_lex_state = 2},
  [13186] = {.lex_state = 14, .external_lex_state = 2},
  [13187] = {.lex_state = 14, .external_lex_state = 2},
  [13188] = {.lex_state = 14, .external_lex_state = 2},
  [13189] = {.lex_state = 14, .external_lex_state = 2},
  [13190] = {.lex_state = 14, .external_lex_state = 2},
  [13191] = {.lex_state = 14, .external_lex_state = 2},
  [13192] = {.lex_state = 14, .external_lex_state = 2},
  [13193] = {.lex_state = 13, .external_lex_state = 2},
  [13194] = {.lex_state = 14, .external_lex_state = 2},
  [13195] = {.lex_state = 14, .external_lex_state = 2},
  [13196] = {.lex_state = 14, .external_lex_state = 2},
  [13197] = {.lex_state = 24, .external_lex_state = 2},
  [13198] = {.lex_state = 13, .external_lex_state = 2},
  [13199] = {.lex_state = 216, .external_lex_state = 2},
  [13200] = {.lex_state = 445, .external_lex_state = 2},
  [13201] = {.lex_state = 215, .external_lex_state = 5},
  [13202] = {.lex_state = 14, .external_lex_state = 2},
  [13203] = {.lex_state = 24, .external_lex_state = 2},
  [13204] = {.lex_state = 14, .external_lex_state = 2},
  [13205] = {.lex_state = 14, .external_lex_state = 2},
  [13206] = {.lex_state = 14, .external_lex_state = 2},
  [13207] = {.lex_state = 14, .external_lex_state = 2},
  [13208] = {.lex_state = 14, .external_lex_state = 2},
  [13209] = {.lex_state = 215, .external_lex_state = 5},
  [13210] = {.lex_state = 14, .external_lex_state = 2},
  [13211] = {.lex_state = 14, .external_lex_state = 2},
  [13212] = {.lex_state = 13, .external_lex_state = 2},
  [13213] = {.lex_state = 14, .external_lex_state = 2},
  [13214] = {.lex_state = 14, .external_lex_state = 2},
  [13215] = {.lex_state = 13, .external_lex_state = 2},
  [13216] = {.lex_state = 24, .external_lex_state = 2},
  [13217] = {.lex_state = 14, .external_lex_state = 2},
  [13218] = {.lex_state = 14, .external_lex_state = 2},
  [13219] = {.lex_state = 14, .external_lex_state = 2},
  [13220] = {.lex_state = 13, .external_lex_state = 2},
  [13221] = {.lex_state = 13, .external_lex_state = 2},
  [13222] = {.lex_state = 14, .external_lex_state = 2},
  [13223] = {.lex_state = 215, .external_lex_state = 5},
  [13224] = {.lex_state = 437, .external_lex_state = 2},
  [13225] = {.lex_state = 24, .external_lex_state = 2},
  [13226] = {.lex_state = 15, .external_lex_state = 2},
  [13227] = {.lex_state = 14, .external_lex_state = 2},
  [13228] = {.lex_state = 13, .external_lex_state = 2},
  [13229] = {.lex_state = 13, .external_lex_state = 2},
  [13230] = {.lex_state = 13, .external_lex_state = 2},
  [13231] = {.lex_state = 13, .external_lex_state = 2},
  [13232] = {.lex_state = 24, .external_lex_state = 2},
  [13233] = {.lex_state = 13, .external_lex_state = 2},
  [13234] = {.lex_state = 13, .external_lex_state = 2},
  [13235] = {.lex_state = 13, .external_lex_state = 2},
  [13236] = {.lex_state = 13, .external_lex_state = 2},
  [13237] = {.lex_state = 445, .external_lex_state = 2},
  [13238] = {.lex_state = 445, .external_lex_state = 2},
  [13239] = {.lex_state = 215, .external_lex_state = 5},
  [13240] = {.lex_state = 13, .external_lex_state = 2},
  [13241] = {.lex_state = 437, .external_lex_state = 2},
  [13242] = {.lex_state = 24, .external_lex_state = 2},
  [13243] = {.lex_state = 215, .external_lex_state = 5},
  [13244] = {.lex_state = 215, .external_lex_state = 5},
  [13245] = {.lex_state = 14, .external_lex_state = 2},
  [13246] = {.lex_state = 14, .external_lex_state = 2},
  [13247] = {.lex_state = 14, .external_lex_state = 2},
  [13248] = {.lex_state = 13, .external_lex_state = 2},
  [13249] = {.lex_state = 215, .external_lex_state = 5},
  [13250] = {.lex_state = 13, .external_lex_state = 2},
  [13251] = {.lex_state = 14, .external_lex_state = 2},
  [13252] = {.lex_state = 14, .external_lex_state = 2},
  [13253] = {.lex_state = 14, .external_lex_state = 2},
  [13254] = {.lex_state = 14, .external_lex_state = 2},
  [13255] = {.lex_state = 14, .external_lex_state = 2},
  [13256] = {.lex_state = 15, .external_lex_state = 2},
  [13257] = {.lex_state = 13, .external_lex_state = 2},
  [13258] = {.lex_state = 14, .external_lex_state = 2},
  [13259] = {.lex_state = 445, .external_lex_state = 2},
  [13260] = {.lex_state = 215, .external_lex_state = 5},
  [13261] = {.lex_state = 215, .external_lex_state = 5},
  [13262] = {.lex_state = 24, .external_lex_state = 2},
  [13263] = {.lex_state = 14, .external_lex_state = 2},
  [13264] = {.lex_state = 24, .external_lex_state = 2},
  [13265] = {.lex_state = 14, .external_lex_state = 2},
  [13266] = {.lex_state = 14, .external_lex_state = 2},
  [13267] = {.lex_state = 24, .external_lex_state = 2},
  [13268] = {.lex_state = 215, .external_lex_state = 5},
  [13269] = {.lex_state = 445, .external_lex_state = 2},
  [13270] = {.lex_state = 14, .external_lex_state = 2},
  [13271] = {.lex_state = 14, .external_lex_state = 2},
  [13272] = {.lex_state = 14, .external_lex_state = 2},
  [13273] = {.lex_state = 216, .external_lex_state = 2},
  [13274] = {.lex_state = 14, .external_lex_state = 2},
  [13275] = {.lex_state = 14, .external_lex_state = 2},
  [13276] = {.lex_state = 24, .external_lex_state = 2},
  [13277] = {.lex_state = 14, .external_lex_state = 2},
  [13278] = {.lex_state = 15, .external_lex_state = 2},
  [13279] = {.lex_state = 15, .external_lex_state = 2},
  [13280] = {.lex_state = 13, .external_lex_state = 2},
  [13281] = {.lex_state = 437, .external_lex_state = 2},
  [13282] = {.lex_state = 13, .external_lex_state = 2},
  [13283] = {.lex_state = 215, .external_lex_state = 5},
  [13284] = {.lex_state = 13, .external_lex_state = 2},
  [13285] = {.lex_state = 13, .external_lex_state = 2},
  [13286] = {.lex_state = 13, .external_lex_state = 2},
  [13287] = {.lex_state = 13, .external_lex_state = 2},
  [13288] = {.lex_state = 14, .external_lex_state = 2},
  [13289] = {.lex_state = 445, .external_lex_state = 2},
  [13290] = {.lex_state = 13, .external_lex_state = 2},
  [13291] = {.lex_state = 445, .external_lex_state = 2},
  [13292] = {.lex_state = 24, .external_lex_state = 2},
  [13293] = {.lex_state = 14, .external_lex_state = 2},
  [13294] = {.lex_state = 13, .external_lex_state = 2},
  [13295] = {.lex_state = 445, .external_lex_state = 2},
  [13296] = {.lex_state = 445, .external_lex_state = 2},
  [13297] = {.lex_state = 13, .external_lex_state = 2},
  [13298] = {.lex_state = 14, .external_lex_state = 2},
  [13299] = {.lex_state = 13, .external_lex_state = 2},
  [13300] = {.lex_state = 13, .external_lex_state = 2},
  [13301] = {.lex_state = 14, .external_lex_state = 2},
  [13302] = {.lex_state = 17, .external_lex_state = 2},
  [13303] = {.lex_state = 215, .external_lex_state = 5},
  [13304] = {.lex_state = 13, .external_lex_state = 2},
  [13305] = {.lex_state = 437, .external_lex_state = 2},
  [13306] = {.lex_state = 24, .external_lex_state = 2},
  [13307] = {.lex_state = 14, .external_lex_state = 2},
  [13308] = {.lex_state = 215, .external_lex_state = 5},
  [13309] = {.lex_state = 215, .external_lex_state = 5},
  [13310] = {.lex_state = 13, .external_lex_state = 2},
  [13311] = {.lex_state = 14, .external_lex_state = 2},
  [13312] = {.lex_state = 14, .external_lex_state = 2},
  [13313] = {.lex_state = 14, .external_lex_state = 2},
  [13314] = {.lex_state = 14, .external_lex_state = 2},
  [13315] = {.lex_state = 215, .external_lex_state = 5},
  [13316] = {.lex_state = 14, .external_lex_state = 2},
  [13317] = {.lex_state = 235, .external_lex_state = 2},
  [13318] = {.lex_state = 14, .external_lex_state = 2},
  [13319] = {.lex_state = 14, .external_lex_state = 2},
  [13320] = {.lex_state = 14, .external_lex_state = 2},
  [13321] = {.lex_state = 14, .external_lex_state = 2},
  [13322] = {.lex_state = 215, .external_lex_state = 5},
  [13323] = {.lex_state = 437, .external_lex_state = 2},
  [13324] = {.lex_state = 14, .external_lex_state = 2},
  [13325] = {.lex_state = 14, .external_lex_state = 2},
  [13326] = {.lex_state = 14, .external_lex_state = 2},
  [13327] = {.lex_state = 13, .external_lex_state = 2},
  [13328] = {.lex_state = 14, .external_lex_state = 2},
  [13329] = {.lex_state = 215, .external_lex_state = 5},
  [13330] = {.lex_state = 13, .external_lex_state = 2},
  [13331] = {.lex_state = 14, .external_lex_state = 2},
  [13332] = {.lex_state = 14, .external_lex_state = 2},
  [13333] = {.lex_state = 13, .external_lex_state = 2},
  [13334] = {.lex_state = 17, .external_lex_state = 2},
  [13335] = {.lex_state = 13, .external_lex_state = 2},
  [13336] = {.lex_state = 13, .external_lex_state = 2},
  [13337] = {.lex_state = 13, .external_lex_state = 2},
  [13338] = {.lex_state = 13, .external_lex_state = 2},
  [13339] = {.lex_state = 15, .external_lex_state = 2},
  [13340] = {.lex_state = 13, .external_lex_state = 2},
  [13341] = {.lex_state = 14, .external_lex_state = 2},
  [13342] = {.lex_state = 15, .external_lex_state = 2},
  [13343] = {.lex_state = 215, .external_lex_state = 5},
  [13344] = {.lex_state = 13, .external_lex_state = 2},
  [13345] = {.lex_state = 13, .external_lex_state = 2},
  [13346] = {.lex_state = 24, .external_lex_state = 2},
  [13347] = {.lex_state = 215, .external_lex_state = 5},
  [13348] = {.lex_state = 14, .external_lex_state = 2},
  [13349] = {.lex_state = 13, .external_lex_state = 2},
  [13350] = {.lex_state = 14, .external_lex_state = 2},
  [13351] = {.lex_state = 14, .external_lex_state = 2},
  [13352] = {.lex_state = 13, .external_lex_state = 2},
  [13353] = {.lex_state = 437, .external_lex_state = 2},
  [13354] = {.lex_state = 437, .external_lex_state = 2},
  [13355] = {.lex_state = 437, .external_lex_state = 2},
  [13356] = {.lex_state = 14, .external_lex_state = 2},
  [13357] = {.lex_state = 14, .external_lex_state = 2},
  [13358] = {.lex_state = 14, .external_lex_state = 2},
  [13359] = {.lex_state = 215, .external_lex_state = 5},
  [13360] = {.lex_state = 14, .external_lex_state = 2},
  [13361] = {.lex_state = 13, .external_lex_state = 2},
  [13362] = {.lex_state = 445, .external_lex_state = 2},
  [13363] = {.lex_state = 14, .external_lex_state = 2},
  [13364] = {.lex_state = 14, .external_lex_state = 2},
  [13365] = {.lex_state = 15, .external_lex_state = 2},
  [13366] = {.lex_state = 236, .external_lex_state = 2},
  [13367] = {.lex_state = 14, .external_lex_state = 2},
  [13368] = {.lex_state = 236, .external_lex_state = 2},
  [13369] = {.lex_state = 236, .external_lex_state = 2},
  [13370] = {.lex_state = 14, .external_lex_state = 2},
  [13371] = {.lex_state = 236, .external_lex_state = 2},
  [13372] = {.lex_state = 14, .external_lex_state = 2},
  [13373] = {.lex_state = 24, .external_lex_state = 2},
  [13374] = {.lex_state = 14, .external_lex_state = 2},
  [13375] = {.lex_state = 14, .external_lex_state = 2},
  [13376] = {.lex_state = 15, .external_lex_state = 2},
  [13377] = {.lex_state = 14, .external_lex_state = 2},
  [13378] = {.lex_state = 14, .external_lex_state = 2},
  [13379] = {.lex_state = 282, .external_lex_state = 2},
  [13380] = {.lex_state = 24, .external_lex_state = 2},
  [13381] = {.lex_state = 14, .external_lex_state = 2},
  [13382] = {.lex_state = 14, .external_lex_state = 2},
  [13383] = {.lex_state = 8, .external_lex_state = 2},
  [13384] = {.lex_state = 245, .external_lex_state = 2},
  [13385] = {.lex_state = 14, .external_lex_state = 2},
  [13386] = {.lex_state = 236, .external_lex_state = 2},
  [13387] = {.lex_state = 14, .external_lex_state = 2},
  [13388] = {.lex_state = 14, .external_lex_state = 2},
  [13389] = {.lex_state = 236, .external_lex_state = 2},
  [13390] = {.lex_state = 236, .external_lex_state = 2},
  [13391] = {.lex_state = 236, .external_lex_state = 2},
  [13392] = {.lex_state = 14, .external_lex_state = 2},
  [13393] = {.lex_state = 236, .external_lex_state = 2},
  [13394] = {.lex_state = 236, .external_lex_state = 2},
  [13395] = {.lex_state = 236, .external_lex_state = 2},
  [13396] = {.lex_state = 14, .external_lex_state = 2},
  [13397] = {.lex_state = 24, .external_lex_state = 2},
  [13398] = {.lex_state = 14, .external_lex_state = 2},
  [13399] = {.lex_state = 282, .external_lex_state = 2},
  [13400] = {.lex_state = 24, .external_lex_state = 2},
  [13401] = {.lex_state = 14, .external_lex_state = 2},
  [13402] = {.lex_state = 24, .external_lex_state = 2},
  [13403] = {.lex_state = 14, .external_lex_state = 2},
  [13404] = {.lex_state = 236, .external_lex_state = 2},
  [13405] = {.lex_state = 24, .external_lex_state = 2},
  [13406] = {.lex_state = 282, .external_lex_state = 2},
  [13407] = {.lex_state = 282, .external_lex_state = 2},
  [13408] = {.lex_state = 14, .external_lex_state = 2},
  [13409] = {.lex_state = 282, .external_lex_state = 2},
  [13410] = {.lex_state = 282, .external_lex_state = 2},
  [13411] = {.lex_state = 282, .external_lex_state = 2},
  [13412] = {.lex_state = 14, .external_lex_state = 2},
  [13413] = {.lex_state = 24, .external_lex_state = 2},
  [13414] = {.lex_state = 27, .external_lex_state = 2},
  [13415] = {.lex_state = 14, .external_lex_state = 2},
  [13416] = {.lex_state = 14, .external_lex_state = 2},
  [13417] = {.lex_state = 14, .external_lex_state = 2},
  [13418] = {.lex_state = 14, .external_lex_state = 2},
  [13419] = {.lex_state = 14, .external_lex_state = 2},
  [13420] = {.lex_state = 14, .external_lex_state = 2},
  [13421] = {.lex_state = 437, .external_lex_state = 2},
  [13422] = {.lex_state = 14, .external_lex_state = 2},
  [13423] = {.lex_state = 14, .external_lex_state = 2},
  [13424] = {.lex_state = 14, .external_lex_state = 2},
  [13425] = {.lex_state = 24, .external_lex_state = 2},
  [13426] = {.lex_state = 14, .external_lex_state = 2},
  [13427] = {.lex_state = 24, .external_lex_state = 2},
  [13428] = {.lex_state = 24, .external_lex_state = 2},
  [13429] = {.lex_state = 14, .external_lex_state = 2},
  [13430] = {.lex_state = 236, .external_lex_state = 2},
  [13431] = {.lex_state = 236, .external_lex_state = 2},
  [13432] = {.lex_state = 24, .external_lex_state = 2},
  [13433] = {.lex_state = 14, .external_lex_state = 2},
  [13434] = {.lex_state = 14, .external_lex_state = 2},
  [13435] = {.lex_state = 14, .external_lex_state = 2},
  [13436] = {.lex_state = 13, .external_lex_state = 2},
  [13437] = {.lex_state = 14, .external_lex_state = 2},
  [13438] = {.lex_state = 445, .external_lex_state = 2},
  [13439] = {.lex_state = 24, .external_lex_state = 2},
  [13440] = {.lex_state = 24, .external_lex_state = 2},
  [13441] = {.lex_state = 14, .external_lex_state = 2},
  [13442] = {.lex_state = 14, .external_lex_state = 2},
  [13443] = {.lex_state = 270, .external_lex_state = 2},
  [13444] = {.lex_state = 14, .external_lex_state = 2},
  [13445] = {.lex_state = 236, .external_lex_state = 2},
  [13446] = {.lex_state = 14, .external_lex_state = 2},
  [13447] = {.lex_state = 14, .external_lex_state = 2},
  [13448] = {.lex_state = 14, .external_lex_state = 2},
  [13449] = {.lex_state = 24, .external_lex_state = 2},
  [13450] = {.lex_state = 24, .external_lex_state = 2},
  [13451] = {.lex_state = 445, .external_lex_state = 2},
  [13452] = {.lex_state = 236, .external_lex_state = 2},
  [13453] = {.lex_state = 24, .external_lex_state = 2},
  [13454] = {.lex_state = 24, .external_lex_state = 2},
  [13455] = {.lex_state = 245, .external_lex_state = 2},
  [13456] = {.lex_state = 245, .external_lex_state = 2},
  [13457] = {.lex_state = 236, .external_lex_state = 2},
  [13458] = {.lex_state = 14, .external_lex_state = 2},
  [13459] = {.lex_state = 14, .external_lex_state = 2},
  [13460] = {.lex_state = 445, .external_lex_state = 2},
  [13461] = {.lex_state = 215, .external_lex_state = 5},
  [13462] = {.lex_state = 8, .external_lex_state = 2},
  [13463] = {.lex_state = 282, .external_lex_state = 2},
  [13464] = {.lex_state = 24, .external_lex_state = 2},
  [13465] = {.lex_state = 24, .external_lex_state = 2},
  [13466] = {.lex_state = 24, .external_lex_state = 2},
  [13467] = {.lex_state = 24, .external_lex_state = 2},
  [13468] = {.lex_state = 14, .external_lex_state = 2},
  [13469] = {.lex_state = 445, .external_lex_state = 2},
  [13470] = {.lex_state = 14, .external_lex_state = 2},
  [13471] = {.lex_state = 14, .external_lex_state = 2},
  [13472] = {.lex_state = 445, .external_lex_state = 2},
  [13473] = {.lex_state = 282, .external_lex_state = 2},
  [13474] = {.lex_state = 282, .external_lex_state = 2},
  [13475] = {.lex_state = 14, .external_lex_state = 2},
  [13476] = {.lex_state = 236, .external_lex_state = 2},
  [13477] = {.lex_state = 24, .external_lex_state = 2},
  [13478] = {.lex_state = 13, .external_lex_state = 2},
  [13479] = {.lex_state = 236, .external_lex_state = 2},
  [13480] = {.lex_state = 236, .external_lex_state = 2},
  [13481] = {.lex_state = 14, .external_lex_state = 2},
  [13482] = {.lex_state = 24, .external_lex_state = 2},
  [13483] = {.lex_state = 24, .external_lex_state = 2},
  [13484] = {.lex_state = 14, .external_lex_state = 2},
  [13485] = {.lex_state = 236, .external_lex_state = 2},
  [13486] = {.lex_state = 24, .external_lex_state = 2},
  [13487] = {.lex_state = 236, .external_lex_state = 2},
  [13488] = {.lex_state = 14, .external_lex_state = 2},
  [13489] = {.lex_state = 236, .external_lex_state = 2},
  [13490] = {.lex_state = 8, .external_lex_state = 2},
  [13491] = {.lex_state = 14, .external_lex_state = 2},
  [13492] = {.lex_state = 24, .external_lex_state = 2},
  [13493] = {.lex_state = 24, .external_lex_state = 2},
  [13494] = {.lex_state = 24, .external_lex_state = 2},
  [13495] = {.lex_state = 24, .external_lex_state = 2},
  [13496] = {.lex_state = 24, .external_lex_state = 2},
  [13497] = {.lex_state = 14, .external_lex_state = 2},
  [13498] = {.lex_state = 245, .external_lex_state = 2},
  [13499] = {.lex_state = 14, .external_lex_state = 2},
  [13500] = {.lex_state = 14, .external_lex_state = 2},
  [13501] = {.lex_state = 14, .external_lex_state = 2},
  [13502] = {.lex_state = 14, .external_lex_state = 2},
  [13503] = {.lex_state = 14, .external_lex_state = 2},
  [13504] = {.lex_state = 14, .external_lex_state = 2},
  [13505] = {.lex_state = 14, .external_lex_state = 2},
  [13506] = {.lex_state = 14, .external_lex_state = 2},
  [13507] = {.lex_state = 14, .external_lex_state = 2},
  [13508] = {.lex_state = 14, .external_lex_state = 2},
  [13509] = {.lex_state = 14, .external_lex_state = 2},
  [13510] = {.lex_state = 236, .external_lex_state = 2},
  [13511] = {.lex_state = 236, .external_lex_state = 2},
  [13512] = {.lex_state = 24, .external_lex_state = 2},
  [13513] = {.lex_state = 24, .external_lex_state = 2},
  [13514] = {.lex_state = 14, .external_lex_state = 2},
  [13515] = {.lex_state = 14, .external_lex_state = 2},
  [13516] = {.lex_state = 236, .external_lex_state = 2},
  [13517] = {.lex_state = 445, .external_lex_state = 2},
  [13518] = {.lex_state = 14, .external_lex_state = 2},
  [13519] = {.lex_state = 236, .external_lex_state = 2},
  [13520] = {.lex_state = 13, .external_lex_state = 2},
  [13521] = {.lex_state = 282, .external_lex_state = 2},
  [13522] = {.lex_state = 14, .external_lex_state = 2},
  [13523] = {.lex_state = 24, .external_lex_state = 2},
  [13524] = {.lex_state = 14, .external_lex_state = 2},
  [13525] = {.lex_state = 282, .external_lex_state = 2},
  [13526] = {.lex_state = 14, .external_lex_state = 2},
  [13527] = {.lex_state = 445, .external_lex_state = 2},
  [13528] = {.lex_state = 445, .external_lex_state = 2},
  [13529] = {.lex_state = 282, .external_lex_state = 2},
  [13530] = {.lex_state = 14, .external_lex_state = 2},
  [13531] = {.lex_state = 24, .external_lex_state = 2},
  [13532] = {.lex_state = 236, .external_lex_state = 2},
  [13533] = {.lex_state = 14, .external_lex_state = 2},
  [13534] = {.lex_state = 14, .external_lex_state = 2},
  [13535] = {.lex_state = 14, .external_lex_state = 2},
  [13536] = {.lex_state = 14, .external_lex_state = 2},
  [13537] = {.lex_state = 236, .external_lex_state = 2},
  [13538] = {.lex_state = 24, .external_lex_state = 2},
  [13539] = {.lex_state = 437, .external_lex_state = 2},
  [13540] = {.lex_state = 24, .external_lex_state = 2},
  [13541] = {.lex_state = 14, .external_lex_state = 2},
  [13542] = {.lex_state = 437, .external_lex_state = 2},
  [13543] = {.lex_state = 236, .external_lex_state = 2},
  [13544] = {.lex_state = 282, .external_lex_state = 2},
  [13545] = {.lex_state = 24, .external_lex_state = 2},
  [13546] = {.lex_state = 24, .external_lex_state = 2},
  [13547] = {.lex_state = 445, .external_lex_state = 2},
  [13548] = {.lex_state = 24, .external_lex_state = 2},
  [13549] = {.lex_state = 15, .external_lex_state = 2},
  [13550] = {.lex_state = 24, .external_lex_state = 2},
  [13551] = {.lex_state = 437, .external_lex_state = 2},
  [13552] = {.lex_state = 14, .external_lex_state = 2},
  [13553] = {.lex_state = 14, .external_lex_state = 2},
  [13554] = {.lex_state = 14, .external_lex_state = 2},
  [13555] = {.lex_state = 14, .external_lex_state = 2},
  [13556] = {.lex_state = 14, .external_lex_state = 2},
  [13557] = {.lex_state = 14, .external_lex_state = 2},
  [13558] = {.lex_state = 24, .external_lex_state = 2},
  [13559] = {.lex_state = 8, .external_lex_state = 2},
  [13560] = {.lex_state = 13, .external_lex_state = 2},
  [13561] = {.lex_state = 24, .external_lex_state = 2},
  [13562] = {.lex_state = 15, .external_lex_state = 2},
  [13563] = {.lex_state = 445, .external_lex_state = 2},
  [13564] = {.lex_state = 14, .external_lex_state = 2},
  [13565] = {.lex_state = 445, .external_lex_state = 2},
  [13566] = {.lex_state = 445, .external_lex_state = 2},
  [13567] = {.lex_state = 445, .external_lex_state = 2},
  [13568] = {.lex_state = 14, .external_lex_state = 2},
  [13569] = {.lex_state = 14, .external_lex_state = 2},
  [13570] = {.lex_state = 445, .external_lex_state = 2},
  [13571] = {.lex_state = 445, .external_lex_state = 2},
  [13572] = {.lex_state = 24, .external_lex_state = 2},
  [13573] = {.lex_state = 445, .external_lex_state = 2},
  [13574] = {.lex_state = 445, .external_lex_state = 2},
  [13575] = {.lex_state = 24, .external_lex_state = 2},
  [13576] = {.lex_state = 14, .external_lex_state = 2},
  [13577] = {.lex_state = 445, .external_lex_state = 2},
  [13578] = {.lex_state = 215, .external_lex_state = 5},
  [13579] = {.lex_state = 14, .external_lex_state = 2},
  [13580] = {.lex_state = 14, .external_lex_state = 2},
  [13581] = {.lex_state = 14, .external_lex_state = 2},
  [13582] = {.lex_state = 236, .external_lex_state = 2},
  [13583] = {.lex_state = 8, .external_lex_state = 2},
  [13584] = {.lex_state = 11, .external_lex_state = 2},
  [13585] = {.lex_state = 11, .external_lex_state = 2},
  [13586] = {.lex_state = 11, .external_lex_state = 2},
  [13587] = {.lex_state = 27, .external_lex_state = 2},
  [13588] = {.lex_state = 27, .external_lex_state = 2},
  [13589] = {.lex_state = 8, .external_lex_state = 2},
  [13590] = {.lex_state = 8, .external_lex_state = 2},
  [13591] = {.lex_state = 8, .external_lex_state = 2},
  [13592] = {.lex_state = 24, .external_lex_state = 2},
  [13593] = {.lex_state = 8, .external_lex_state = 2},
  [13594] = {.lex_state = 245, .external_lex_state = 2},
  [13595] = {.lex_state = 8, .external_lex_state = 2},
  [13596] = {.lex_state = 27, .external_lex_state = 2},
  [13597] = {.lex_state = 14, .external_lex_state = 2},
  [13598] = {.lex_state = 8, .external_lex_state = 2},
  [13599] = {.lex_state = 11, .external_lex_state = 2},
  [13600] = {.lex_state = 27, .external_lex_state = 2},
  [13601] = {.lex_state = 11, .external_lex_state = 2},
  [13602] = {.lex_state = 11, .external_lex_state = 2},
  [13603] = {.lex_state = 445, .external_lex_state = 2},
  [13604] = {.lex_state = 8, .external_lex_state = 2},
  [13605] = {.lex_state = 8, .external_lex_state = 2},
  [13606] = {.lex_state = 27, .external_lex_state = 2},
  [13607] = {.lex_state = 14, .external_lex_state = 2},
  [13608] = {.lex_state = 14, .external_lex_state = 2},
  [13609] = {.lex_state = 27, .external_lex_state = 2},
  [13610] = {.lex_state = 245, .external_lex_state = 2},
  [13611] = {.lex_state = 8, .external_lex_state = 2},
  [13612] = {.lex_state = 8, .external_lex_state = 2},
  [13613] = {.lex_state = 445, .external_lex_state = 2},
  [13614] = {.lex_state = 14, .external_lex_state = 2},
  [13615] = {.lex_state = 445, .external_lex_state = 2},
  [13616] = {.lex_state = 27, .external_lex_state = 2},
  [13617] = {.lex_state = 8, .external_lex_state = 2},
  [13618] = {.lex_state = 232, .external_lex_state = 2},
  [13619] = {.lex_state = 445, .external_lex_state = 2},
  [13620] = {.lex_state = 245, .external_lex_state = 2},
  [13621] = {.lex_state = 8, .external_lex_state = 2},
  [13622] = {.lex_state = 27, .external_lex_state = 2},
  [13623] = {.lex_state = 245, .external_lex_state = 2},
  [13624] = {.lex_state = 245, .external_lex_state = 2},
  [13625] = {.lex_state = 245, .external_lex_state = 2},
  [13626] = {.lex_state = 27, .external_lex_state = 2},
  [13627] = {.lex_state = 245, .external_lex_state = 2},
  [13628] = {.lex_state = 258, .external_lex_state = 2},
  [13629] = {.lex_state = 245, .external_lex_state = 2},
  [13630] = {.lex_state = 245, .external_lex_state = 2},
  [13631] = {.lex_state = 232, .external_lex_state = 2},
  [13632] = {.lex_state = 245, .external_lex_state = 2},
  [13633] = {.lex_state = 445, .external_lex_state = 2},
  [13634] = {.lex_state = 245, .external_lex_state = 2},
  [13635] = {.lex_state = 245, .external_lex_state = 2},
  [13636] = {.lex_state = 228, .external_lex_state = 2},
  [13637] = {.lex_state = 11, .external_lex_state = 2},
  [13638] = {.lex_state = 245, .external_lex_state = 2},
  [13639] = {.lex_state = 232, .external_lex_state = 2},
  [13640] = {.lex_state = 11, .external_lex_state = 2},
  [13641] = {.lex_state = 245, .external_lex_state = 2},
  [13642] = {.lex_state = 215, .external_lex_state = 5},
  [13643] = {.lex_state = 258, .external_lex_state = 2},
  [13644] = {.lex_state = 258, .external_lex_state = 2},
  [13645] = {.lex_state = 232, .external_lex_state = 2},
  [13646] = {.lex_state = 8, .external_lex_state = 2},
  [13647] = {.lex_state = 245, .external_lex_state = 2},
  [13648] = {.lex_state = 245, .external_lex_state = 2},
  [13649] = {.lex_state = 245, .external_lex_state = 2},
  [13650] = {.lex_state = 258, .external_lex_state = 2},
  [13651] = {.lex_state = 245, .external_lex_state = 2},
  [13652] = {.lex_state = 245, .external_lex_state = 2},
  [13653] = {.lex_state = 445, .external_lex_state = 2},
  [13654] = {.lex_state = 258, .external_lex_state = 2},
  [13655] = {.lex_state = 258, .external_lex_state = 2},
  [13656] = {.lex_state = 258, .external_lex_state = 2},
  [13657] = {.lex_state = 215, .external_lex_state = 5},
  [13658] = {.lex_state = 232, .external_lex_state = 2},
  [13659] = {.lex_state = 8, .external_lex_state = 2},
  [13660] = {.lex_state = 11, .external_lex_state = 2},
  [13661] = {.lex_state = 445, .external_lex_state = 2},
  [13662] = {.lex_state = 245, .external_lex_state = 2},
  [13663] = {.lex_state = 8, .external_lex_state = 2},
  [13664] = {.lex_state = 245, .external_lex_state = 2},
  [13665] = {.lex_state = 258, .external_lex_state = 2},
  [13666] = {.lex_state = 242, .external_lex_state = 2},
  [13667] = {.lex_state = 445, .external_lex_state = 2},
  [13668] = {.lex_state = 8, .external_lex_state = 2},
  [13669] = {.lex_state = 245, .external_lex_state = 2},
  [13670] = {.lex_state = 242, .external_lex_state = 2},
  [13671] = {.lex_state = 242, .external_lex_state = 2},
  [13672] = {.lex_state = 7, .external_lex_state = 2},
  [13673] = {.lex_state = 242, .external_lex_state = 2},
  [13674] = {.lex_state = 245, .external_lex_state = 2},
  [13675] = {.lex_state = 245, .external_lex_state = 2},
  [13676] = {.lex_state = 27, .external_lex_state = 2},
  [13677] = {.lex_state = 245, .external_lex_state = 2},
  [13678] = {.lex_state = 245, .external_lex_state = 2},
  [13679] = {.lex_state = 245, .external_lex_state = 2},
  [13680] = {.lex_state = 245, .external_lex_state = 2},
  [13681] = {.lex_state = 245, .external_lex_state = 2},
  [13682] = {.lex_state = 7, .external_lex_state = 2},
  [13683] = {.lex_state = 8, .external_lex_state = 2},
  [13684] = {.lex_state = 245, .external_lex_state = 2},
  [13685] = {.lex_state = 245, .external_lex_state = 2},
  [13686] = {.lex_state = 27, .external_lex_state = 2},
  [13687] = {.lex_state = 245, .external_lex_state = 2},
  [13688] = {.lex_state = 232, .external_lex_state = 2},
  [13689] = {.lex_state = 245, .external_lex_state = 2},
  [13690] = {.lex_state = 445, .external_lex_state = 2},
  [13691] = {.lex_state = 7, .external_lex_state = 2},
  [13692] = {.lex_state = 245, .external_lex_state = 2},
  [13693] = {.lex_state = 258, .external_lex_state = 2},
  [13694] = {.lex_state = 437, .external_lex_state = 2},
  [13695] = {.lex_state = 24, .external_lex_state = 2},
  [13696] = {.lex_state = 437, .external_lex_state = 2},
  [13697] = {.lex_state = 437, .external_lex_state = 2},
  [13698] = {.lex_state = 437, .external_lex_state = 2},
  [13699] = {.lex_state = 437, .external_lex_state = 2},
  [13700] = {.lex_state = 24, .external_lex_state = 2},
  [13701] = {.lex_state = 24, .external_lex_state = 2},
  [13702] = {.lex_state = 24, .external_lex_state = 2},
  [13703] = {.lex_state = 437, .external_lex_state = 2},
  [13704] = {.lex_state = 437, .external_lex_state = 2},
  [13705] = {.lex_state = 437, .external_lex_state = 2},
  [13706] = {.lex_state = 24, .external_lex_state = 2},
  [13707] = {.lex_state = 19, .external_lex_state = 2},
  [13708] = {.lex_state = 258, .external_lex_state = 2},
  [13709] = {.lex_state = 437, .external_lex_state = 2},
  [13710] = {.lex_state = 437, .external_lex_state = 2},
  [13711] = {.lex_state = 437, .external_lex_state = 2},
  [13712] = {.lex_state = 437, .external_lex_state = 2},
  [13713] = {.lex_state = 437, .external_lex_state = 2},
  [13714] = {.lex_state = 242, .external_lex_state = 2},
  [13715] = {.lex_state = 437, .external_lex_state = 2},
  [13716] = {.lex_state = 216, .external_lex_state = 2},
  [13717] = {.lex_state = 437, .external_lex_state = 2},
  [13718] = {.lex_state = 437, .external_lex_state = 2},
  [13719] = {.lex_state = 437, .external_lex_state = 2},
  [13720] = {.lex_state = 437, .external_lex_state = 2},
  [13721] = {.lex_state = 24, .external_lex_state = 2},
  [13722] = {.lex_state = 437, .external_lex_state = 2},
  [13723] = {.lex_state = 437, .external_lex_state = 2},
  [13724] = {.lex_state = 437, .external_lex_state = 2},
  [13725] = {.lex_state = 437, .external_lex_state = 2},
  [13726] = {.lex_state = 437, .external_lex_state = 2},
  [13727] = {.lex_state = 437, .external_lex_state = 2},
  [13728] = {.lex_state = 437, .external_lex_state = 2},
  [13729] = {.lex_state = 245, .external_lex_state = 2},
  [13730] = {.lex_state = 437, .external_lex_state = 2},
  [13731] = {.lex_state = 245, .external_lex_state = 2},
  [13732] = {.lex_state = 437, .external_lex_state = 2},
  [13733] = {.lex_state = 245, .external_lex_state = 2},
  [13734] = {.lex_state = 245, .external_lex_state = 2},
  [13735] = {.lex_state = 437, .external_lex_state = 2},
  [13736] = {.lex_state = 437, .external_lex_state = 2},
  [13737] = {.lex_state = 437, .external_lex_state = 2},
  [13738] = {.lex_state = 437, .external_lex_state = 2},
  [13739] = {.lex_state = 437, .external_lex_state = 2},
  [13740] = {.lex_state = 437, .external_lex_state = 2},
  [13741] = {.lex_state = 437, .external_lex_state = 2},
  [13742] = {.lex_state = 437, .external_lex_state = 2},
  [13743] = {.lex_state = 437, .external_lex_state = 2},
  [13744] = {.lex_state = 262, .external_lex_state = 2},
  [13745] = {.lex_state = 437, .external_lex_state = 2},
  [13746] = {.lex_state = 437, .external_lex_state = 2},
  [13747] = {.lex_state = 437, .external_lex_state = 2},
  [13748] = {.lex_state = 437, .external_lex_state = 2},
  [13749] = {.lex_state = 437, .external_lex_state = 2},
  [13750] = {.lex_state = 24, .external_lex_state = 2},
  [13751] = {.lex_state = 437, .external_lex_state = 2},
  [13752] = {.lex_state = 437, .external_lex_state = 2},
  [13753] = {.lex_state = 437, .external_lex_state = 2},
  [13754] = {.lex_state = 437, .external_lex_state = 2},
  [13755] = {.lex_state = 437, .external_lex_state = 2},
  [13756] = {.lex_state = 437, .external_lex_state = 2},
  [13757] = {.lex_state = 437, .external_lex_state = 2},
  [13758] = {.lex_state = 437, .external_lex_state = 2},
  [13759] = {.lex_state = 437, .external_lex_state = 2},
  [13760] = {.lex_state = 437, .external_lex_state = 2},
  [13761] = {.lex_state = 437, .external_lex_state = 2},
  [13762] = {.lex_state = 437, .external_lex_state = 2},
  [13763] = {.lex_state = 24, .external_lex_state = 2},
  [13764] = {.lex_state = 437, .external_lex_state = 2},
  [13765] = {.lex_state = 24, .external_lex_state = 2},
  [13766] = {.lex_state = 437, .external_lex_state = 2},
  [13767] = {.lex_state = 437, .external_lex_state = 2},
  [13768] = {.lex_state = 437, .external_lex_state = 2},
  [13769] = {.lex_state = 437, .external_lex_state = 2},
  [13770] = {.lex_state = 437, .external_lex_state = 2},
  [13771] = {.lex_state = 437, .external_lex_state = 2},
  [13772] = {.lex_state = 437, .external_lex_state = 2},
  [13773] = {.lex_state = 437, .external_lex_state = 2},
  [13774] = {.lex_state = 437, .external_lex_state = 2},
  [13775] = {.lex_state = 437, .external_lex_state = 2},
  [13776] = {.lex_state = 437, .external_lex_state = 2},
  [13777] = {.lex_state = 437, .external_lex_state = 2},
  [13778] = {.lex_state = 24, .external_lex_state = 2},
  [13779] = {.lex_state = 437, .external_lex_state = 2},
  [13780] = {.lex_state = 216, .external_lex_state = 2},
  [13781] = {.lex_state = 437, .external_lex_state = 2},
  [13782] = {.lex_state = 437, .external_lex_state = 2},
  [13783] = {.lex_state = 19, .external_lex_state = 2},
  [13784] = {.lex_state = 437, .external_lex_state = 2},
  [13785] = {.lex_state = 24, .external_lex_state = 2},
  [13786] = {.lex_state = 258, .external_lex_state = 2},
  [13787] = {.lex_state = 24, .external_lex_state = 2},
  [13788] = {.lex_state = 437, .external_lex_state = 2},
  [13789] = {.lex_state = 437, .external_lex_state = 2},
  [13790] = {.lex_state = 437, .external_lex_state = 2},
  [13791] = {.lex_state = 437, .external_lex_state = 2},
  [13792] = {.lex_state = 11, .external_lex_state = 2},
  [13793] = {.lex_state = 258, .external_lex_state = 2},
  [13794] = {.lex_state = 437, .external_lex_state = 2},
  [13795] = {.lex_state = 437, .external_lex_state = 2},
  [13796] = {.lex_state = 437, .external_lex_state = 2},
  [13797] = {.lex_state = 437, .external_lex_state = 2},
  [13798] = {.lex_state = 258, .external_lex_state = 2},
  [13799] = {.lex_state = 245, .external_lex_state = 2},
  [13800] = {.lex_state = 437, .external_lex_state = 2},
  [13801] = {.lex_state = 437, .external_lex_state = 2},
  [13802] = {.lex_state = 258, .external_lex_state = 2},
  [13803] = {.lex_state = 19, .external_lex_state = 2},
  [13804] = {.lex_state = 437, .external_lex_state = 2},
  [13805] = {.lex_state = 437, .external_lex_state = 2},
  [13806] = {.lex_state = 236, .external_lex_state = 2},
  [13807] = {.lex_state = 437, .external_lex_state = 2},
  [13808] = {.lex_state = 437, .external_lex_state = 2},
  [13809] = {.lex_state = 437, .external_lex_state = 2},
  [13810] = {.lex_state = 24, .external_lex_state = 2},
  [13811] = {.lex_state = 437, .external_lex_state = 2},
  [13812] = {.lex_state = 437, .external_lex_state = 2},
  [13813] = {.lex_state = 24, .external_lex_state = 2},
  [13814] = {.lex_state = 24, .external_lex_state = 2},
  [13815] = {.lex_state = 437, .external_lex_state = 2},
  [13816] = {.lex_state = 437, .external_lex_state = 2},
  [13817] = {.lex_state = 24, .external_lex_state = 2},
  [13818] = {.lex_state = 24, .external_lex_state = 2},
  [13819] = {.lex_state = 24, .external_lex_state = 2},
  [13820] = {.lex_state = 437, .external_lex_state = 2},
  [13821] = {.lex_state = 437, .external_lex_state = 2},
  [13822] = {.lex_state = 437, .external_lex_state = 2},
  [13823] = {.lex_state = 437, .external_lex_state = 2},
  [13824] = {.lex_state = 437, .external_lex_state = 2},
  [13825] = {.lex_state = 437, .external_lex_state = 2},
  [13826] = {.lex_state = 258, .external_lex_state = 2},
  [13827] = {.lex_state = 437, .external_lex_state = 2},
  [13828] = {.lex_state = 437, .external_lex_state = 2},
  [13829] = {.lex_state = 24, .external_lex_state = 2},
  [13830] = {.lex_state = 437, .external_lex_state = 2},
  [13831] = {.lex_state = 437, .external_lex_state = 2},
  [13832] = {.lex_state = 437, .external_lex_state = 2},
  [13833] = {.lex_state = 437, .external_lex_state = 2},
  [13834] = {.lex_state = 437, .external_lex_state = 2},
  [13835] = {.lex_state = 437, .external_lex_state = 2},
  [13836] = {.lex_state = 437, .external_lex_state = 2},
  [13837] = {.lex_state = 437, .external_lex_state = 2},
  [13838] = {.lex_state = 437, .external_lex_state = 2},
  [13839] = {.lex_state = 437, .external_lex_state = 2},
  [13840] = {.lex_state = 437, .external_lex_state = 2},
  [13841] = {.lex_state = 242, .external_lex_state = 2},
  [13842] = {.lex_state = 437, .external_lex_state = 2},
  [13843] = {.lex_state = 437, .external_lex_state = 2},
  [13844] = {.lex_state = 437, .external_lex_state = 2},
  [13845] = {.lex_state = 437, .external_lex_state = 2},
  [13846] = {.lex_state = 24, .external_lex_state = 2},
  [13847] = {.lex_state = 24, .external_lex_state = 2},
  [13848] = {.lex_state = 24, .external_lex_state = 2},
  [13849] = {.lex_state = 24, .external_lex_state = 2},
  [13850] = {.lex_state = 24, .external_lex_state = 2},
  [13851] = {.lex_state = 24, .external_lex_state = 2},
  [13852] = {.lex_state = 437, .external_lex_state = 2},
  [13853] = {.lex_state = 24, .external_lex_state = 2},
  [13854] = {.lex_state = 437, .external_lex_state = 2},
  [13855] = {.lex_state = 245, .external_lex_state = 2},
  [13856] = {.lex_state = 437, .external_lex_state = 2},
  [13857] = {.lex_state = 437, .external_lex_state = 2},
  [13858] = {.lex_state = 24, .external_lex_state = 2},
  [13859] = {.lex_state = 437, .external_lex_state = 2},
  [13860] = {.lex_state = 437, .external_lex_state = 2},
  [13861] = {.lex_state = 24, .external_lex_state = 2},
  [13862] = {.lex_state = 437, .external_lex_state = 2},
  [13863] = {.lex_state = 437, .external_lex_state = 2},
  [13864] = {.lex_state = 437, .external_lex_state = 2},
  [13865] = {.lex_state = 437, .external_lex_state = 2},
  [13866] = {.lex_state = 24, .external_lex_state = 2},
  [13867] = {.lex_state = 24, .external_lex_state = 2},
  [13868] = {.lex_state = 437, .external_lex_state = 2},
  [13869] = {.lex_state = 437, .external_lex_state = 2},
  [13870] = {.lex_state = 437, .external_lex_state = 2},
  [13871] = {.lex_state = 437, .external_lex_state = 2},
  [13872] = {.lex_state = 437, .external_lex_state = 2},
  [13873] = {.lex_state = 437, .external_lex_state = 2},
  [13874] = {.lex_state = 437, .external_lex_state = 2},
  [13875] = {.lex_state = 437, .external_lex_state = 2},
  [13876] = {.lex_state = 437, .external_lex_state = 2},
  [13877] = {.lex_state = 437, .external_lex_state = 2},
  [13878] = {.lex_state = 24, .external_lex_state = 2},
  [13879] = {.lex_state = 24, .external_lex_state = 2},
  [13880] = {.lex_state = 437, .external_lex_state = 2},
  [13881] = {.lex_state = 437, .external_lex_state = 2},
  [13882] = {.lex_state = 437, .external_lex_state = 2},
  [13883] = {.lex_state = 437, .external_lex_state = 2},
  [13884] = {.lex_state = 437, .external_lex_state = 2},
  [13885] = {.lex_state = 437, .external_lex_state = 2},
  [13886] = {.lex_state = 437, .external_lex_state = 2},
  [13887] = {.lex_state = 437, .external_lex_state = 2},
  [13888] = {.lex_state = 24, .external_lex_state = 2},
  [13889] = {.lex_state = 437, .external_lex_state = 2},
  [13890] = {.lex_state = 24, .external_lex_state = 2},
  [13891] = {.lex_state = 437, .external_lex_state = 2},
  [13892] = {.lex_state = 437, .external_lex_state = 2},
  [13893] = {.lex_state = 437, .external_lex_state = 2},
  [13894] = {.lex_state = 437, .external_lex_state = 2},
  [13895] = {.lex_state = 24, .external_lex_state = 2},
  [13896] = {.lex_state = 24, .external_lex_state = 2},
  [13897] = {.lex_state = 437, .external_lex_state = 2},
  [13898] = {.lex_state = 24, .external_lex_state = 2},
  [13899] = {.lex_state = 258, .external_lex_state = 2},
  [13900] = {.lex_state = 437, .external_lex_state = 2},
  [13901] = {.lex_state = 437, .external_lex_state = 2},
  [13902] = {.lex_state = 437, .external_lex_state = 2},
  [13903] = {.lex_state = 437, .external_lex_state = 2},
  [13904] = {.lex_state = 437, .external_lex_state = 2},
  [13905] = {.lex_state = 437, .external_lex_state = 2},
  [13906] = {.lex_state = 437, .external_lex_state = 2},
  [13907] = {.lex_state = 437, .external_lex_state = 2},
  [13908] = {.lex_state = 437, .external_lex_state = 2},
  [13909] = {.lex_state = 437, .external_lex_state = 2},
  [13910] = {.lex_state = 24, .external_lex_state = 2},
  [13911] = {.lex_state = 437, .external_lex_state = 2},
  [13912] = {.lex_state = 24, .external_lex_state = 2},
  [13913] = {.lex_state = 437, .external_lex_state = 2},
  [13914] = {.lex_state = 437, .external_lex_state = 2},
  [13915] = {.lex_state = 24, .external_lex_state = 2},
  [13916] = {.lex_state = 437, .external_lex_state = 2},
  [13917] = {.lex_state = 437, .external_lex_state = 2},
  [13918] = {.lex_state = 437, .external_lex_state = 2},
  [13919] = {.lex_state = 24, .external_lex_state = 2},
  [13920] = {.lex_state = 437, .external_lex_state = 2},
  [13921] = {.lex_state = 437, .external_lex_state = 2},
  [13922] = {.lex_state = 437, .external_lex_state = 2},
  [13923] = {.lex_state = 437, .external_lex_state = 2},
  [13924] = {.lex_state = 24, .external_lex_state = 2},
  [13925] = {.lex_state = 437, .external_lex_state = 2},
  [13926] = {.lex_state = 242, .external_lex_state = 2},
  [13927] = {.lex_state = 226, .external_lex_state = 2},
  [13928] = {.lex_state = 19, .external_lex_state = 2},
  [13929] = {.lex_state = 242, .external_lex_state = 2},
  [13930] = {.lex_state = 437, .external_lex_state = 2},
  [13931] = {.lex_state = 437, .external_lex_state = 2},
  [13932] = {.lex_state = 236, .external_lex_state = 2},
  [13933] = {.lex_state = 242, .external_lex_state = 2},
  [13934] = {.lex_state = 242, .external_lex_state = 2},
  [13935] = {.lex_state = 437, .external_lex_state = 2},
  [13936] = {.lex_state = 242, .external_lex_state = 2},
  [13937] = {.lex_state = 242, .external_lex_state = 2},
  [13938] = {.lex_state = 242, .external_lex_state = 2},
  [13939] = {.lex_state = 437, .external_lex_state = 2},
  [13940] = {.lex_state = 242, .external_lex_state = 2},
  [13941] = {.lex_state = 242, .external_lex_state = 2},
  [13942] = {.lex_state = 437, .external_lex_state = 2},
  [13943] = {.lex_state = 242, .external_lex_state = 2},
  [13944] = {.lex_state = 242, .external_lex_state = 2},
  [13945] = {.lex_state = 242, .external_lex_state = 2},
  [13946] = {.lex_state = 242, .external_lex_state = 2},
  [13947] = {.lex_state = 242, .external_lex_state = 2},
  [13948] = {.lex_state = 437, .external_lex_state = 2},
  [13949] = {.lex_state = 226, .external_lex_state = 2},
  [13950] = {.lex_state = 242, .external_lex_state = 2},
  [13951] = {.lex_state = 437, .external_lex_state = 2},
  [13952] = {.lex_state = 242, .external_lex_state = 2},
  [13953] = {.lex_state = 242, .external_lex_state = 2},
  [13954] = {.lex_state = 226, .external_lex_state = 2},
  [13955] = {.lex_state = 242, .external_lex_state = 2},
  [13956] = {.lex_state = 242, .external_lex_state = 2},
  [13957] = {.lex_state = 24, .external_lex_state = 2},
  [13958] = {.lex_state = 242, .external_lex_state = 2},
  [13959] = {.lex_state = 437, .external_lex_state = 2},
  [13960] = {.lex_state = 437, .external_lex_state = 2},
  [13961] = {.lex_state = 242, .external_lex_state = 2},
  [13962] = {.lex_state = 242, .external_lex_state = 2},
  [13963] = {.lex_state = 242, .external_lex_state = 2},
  [13964] = {.lex_state = 216, .external_lex_state = 2},
  [13965] = {.lex_state = 242, .external_lex_state = 2},
  [13966] = {.lex_state = 242, .external_lex_state = 2},
  [13967] = {.lex_state = 242, .external_lex_state = 2},
  [13968] = {.lex_state = 242, .external_lex_state = 2},
  [13969] = {.lex_state = 52, .external_lex_state = 2},
  [13970] = {.lex_state = 242, .external_lex_state = 2},
  [13971] = {.lex_state = 216, .external_lex_state = 2},
  [13972] = {.lex_state = 242, .external_lex_state = 2},
  [13973] = {.lex_state = 437, .external_lex_state = 2},
  [13974] = {.lex_state = 216, .external_lex_state = 2},
  [13975] = {.lex_state = 242, .external_lex_state = 2},
  [13976] = {.lex_state = 242, .external_lex_state = 2},
  [13977] = {.lex_state = 242, .external_lex_state = 2},
  [13978] = {.lex_state = 226, .external_lex_state = 2},
  [13979] = {.lex_state = 437, .external_lex_state = 2},
  [13980] = {.lex_state = 24, .external_lex_state = 2},
  [13981] = {.lex_state = 216, .external_lex_state = 2},
  [13982] = {.lex_state = 24, .external_lex_state = 2},
  [13983] = {.lex_state = 8, .external_lex_state = 2},
  [13984] = {.lex_state = 216, .external_lex_state = 2},
  [13985] = {.lex_state = 216, .external_lex_state = 2},
  [13986] = {.lex_state = 232, .external_lex_state = 2},
  [13987] = {.lex_state = 8, .external_lex_state = 2},
  [13988] = {.lex_state = 216, .external_lex_state = 2},
  [13989] = {.lex_state = 245, .external_lex_state = 2},
  [13990] = {.lex_state = 24, .external_lex_state = 2},
  [13991] = {.lex_state = 8, .external_lex_state = 2},
  [13992] = {.lex_state = 216, .external_lex_state = 2},
  [13993] = {.lex_state = 216, .external_lex_state = 2},
  [13994] = {.lex_state = 24, .external_lex_state = 2},
  [13995] = {.lex_state = 216, .external_lex_state = 2},
  [13996] = {.lex_state = 216, .external_lex_state = 2},
  [13997] = {.lex_state = 216, .external_lex_state = 2},
  [13998] = {.lex_state = 232, .external_lex_state = 2},
  [13999] = {.lex_state = 232, .external_lex_state = 2},
  [14000] = {.lex_state = 8, .external_lex_state = 2},
  [14001] = {.lex_state = 216, .external_lex_state = 2},
  [14002] = {.lex_state = 232, .external_lex_state = 2},
  [14003] = {.lex_state = 216, .external_lex_state = 2},
  [14004] = {.lex_state = 262, .external_lex_state = 2},
  [14005] = {.lex_state = 8, .external_lex_state = 2},
  [14006] = {.lex_state = 216, .external_lex_state = 2},
  [14007] = {.lex_state = 7, .external_lex_state = 2},
  [14008] = {.lex_state = 8, .external_lex_state = 2},
  [14009] = {.lex_state = 8, .external_lex_state = 2},
  [14010] = {.lex_state = 216, .external_lex_state = 2},
  [14011] = {.lex_state = 232, .external_lex_state = 2},
  [14012] = {.lex_state = 216, .external_lex_state = 2},
  [14013] = {.lex_state = 8, .external_lex_state = 2},
  [14014] = {.lex_state = 216, .external_lex_state = 2},
  [14015] = {.lex_state = 216, .external_lex_state = 2},
  [14016] = {.lex_state = 216, .external_lex_state = 2},
  [14017] = {.lex_state = 216, .external_lex_state = 2},
  [14018] = {.lex_state = 232, .external_lex_state = 2},
  [14019] = {.lex_state = 216, .external_lex_state = 2},
  [14020] = {.lex_state = 24, .external_lex_state = 2},
  [14021] = {.lex_state = 216, .external_lex_state = 2},
  [14022] = {.lex_state = 24, .external_lex_state = 2},
  [14023] = {.lex_state = 24, .external_lex_state = 2},
  [14024] = {.lex_state = 262, .external_lex_state = 2},
  [14025] = {.lex_state = 216, .external_lex_state = 2},
  [14026] = {.lex_state = 259, .external_lex_state = 2},
  [14027] = {.lex_state = 259, .external_lex_state = 2},
  [14028] = {.lex_state = 24, .external_lex_state = 2},
  [14029] = {.lex_state = 259, .external_lex_state = 2},
  [14030] = {.lex_state = 24, .external_lex_state = 2},
  [14031] = {.lex_state = 24, .external_lex_state = 2},
  [14032] = {.lex_state = 259, .external_lex_state = 2},
  [14033] = {.lex_state = 259, .external_lex_state = 2},
  [14034] = {.lex_state = 24, .external_lex_state = 2},
  [14035] = {.lex_state = 245, .external_lex_state = 2},
  [14036] = {.lex_state = 259, .external_lex_state = 2},
  [14037] = {.lex_state = 437, .external_lex_state = 2},
  [14038] = {.lex_state = 4, .external_lex_state = 6},
  [14039] = {.lex_state = 24, .external_lex_state = 2},
  [14040] = {.lex_state = 259, .external_lex_state = 2},
  [14041] = {.lex_state = 259, .external_lex_state = 2},
  [14042] = {.lex_state = 259, .external_lex_state = 2},
  [14043] = {.lex_state = 437, .external_lex_state = 2},
  [14044] = {.lex_state = 259, .external_lex_state = 2},
  [14045] = {.lex_state = 24, .external_lex_state = 2},
  [14046] = {.lex_state = 216, .external_lex_state = 2},
  [14047] = {.lex_state = 232, .external_lex_state = 2},
  [14048] = {.lex_state = 259, .external_lex_state = 2},
  [14049] = {.lex_state = 4, .external_lex_state = 6},
  [14050] = {.lex_state = 437, .external_lex_state = 2},
  [14051] = {.lex_state = 437, .external_lex_state = 2},
  [14052] = {.lex_state = 4, .external_lex_state = 6},
  [14053] = {.lex_state = 437, .external_lex_state = 2},
  [14054] = {.lex_state = 4, .external_lex_state = 6},
  [14055] = {.lex_state = 216, .external_lex_state = 2},
  [14056] = {.lex_state = 259, .external_lex_state = 2},
  [14057] = {.lex_state = 259, .external_lex_state = 2},
  [14058] = {.lex_state = 4, .external_lex_state = 6},
  [14059] = {.lex_state = 259, .external_lex_state = 2},
  [14060] = {.lex_state = 437, .external_lex_state = 2},
  [14061] = {.lex_state = 437, .external_lex_state = 2},
  [14062] = {.lex_state = 4, .external_lex_state = 6},
  [14063] = {.lex_state = 24, .external_lex_state = 2},
  [14064] = {.lex_state = 259, .external_lex_state = 2},
  [14065] = {.lex_state = 24, .external_lex_state = 2},
  [14066] = {.lex_state = 437, .external_lex_state = 2},
  [14067] = {.lex_state = 4, .external_lex_state = 6},
  [14068] = {.lex_state = 259, .external_lex_state = 2},
  [14069] = {.lex_state = 24, .external_lex_state = 2},
  [14070] = {.lex_state = 216, .external_lex_state = 2},
  [14071] = {.lex_state = 259, .external_lex_state = 2},
  [14072] = {.lex_state = 24, .external_lex_state = 2},
  [14073] = {.lex_state = 232, .external_lex_state = 2},
  [14074] = {.lex_state = 24, .external_lex_state = 2},
  [14075] = {.lex_state = 24, .external_lex_state = 2},
  [14076] = {.lex_state = 4, .external_lex_state = 6},
  [14077] = {.lex_state = 259, .external_lex_state = 2},
  [14078] = {.lex_state = 4, .external_lex_state = 6},
  [14079] = {.lex_state = 259, .external_lex_state = 2},
  [14080] = {.lex_state = 259, .external_lex_state = 2},
  [14081] = {.lex_state = 4, .external_lex_state = 6},
  [14082] = {.lex_state = 245, .external_lex_state = 2},
  [14083] = {.lex_state = 216, .external_lex_state = 2},
  [14084] = {.lex_state = 4, .external_lex_state = 6},
  [14085] = {.lex_state = 4, .external_lex_state = 6},
  [14086] = {.lex_state = 259, .external_lex_state = 2},
  [14087] = {.lex_state = 4, .external_lex_state = 6},
  [14088] = {.lex_state = 437, .external_lex_state = 2},
  [14089] = {.lex_state = 4, .external_lex_state = 6},
  [14090] = {.lex_state = 437, .external_lex_state = 2},
  [14091] = {.lex_state = 4, .external_lex_state = 6},
  [14092] = {.lex_state = 259, .external_lex_state = 2},
  [14093] = {.lex_state = 4, .external_lex_state = 6},
  [14094] = {.lex_state = 8, .external_lex_state = 2},
  [14095] = {.lex_state = 4, .external_lex_state = 6},
  [14096] = {.lex_state = 226, .external_lex_state = 2},
  [14097] = {.lex_state = 24, .external_lex_state = 2},
  [14098] = {.lex_state = 437, .external_lex_state = 2},
  [14099] = {.lex_state = 4, .external_lex_state = 6},
  [14100] = {.lex_state = 259, .external_lex_state = 2},
  [14101] = {.lex_state = 4, .external_lex_state = 6},
  [14102] = {.lex_state = 4, .external_lex_state = 6},
  [14103] = {.lex_state = 262, .external_lex_state = 2},
  [14104] = {.lex_state = 8, .external_lex_state = 2},
  [14105] = {.lex_state = 4, .external_lex_state = 6},
  [14106] = {.lex_state = 4, .external_lex_state = 6},
  [14107] = {.lex_state = 4, .external_lex_state = 6},
  [14108] = {.lex_state = 259, .external_lex_state = 2},
  [14109] = {.lex_state = 4, .external_lex_state = 6},
  [14110] = {.lex_state = 437, .external_lex_state = 2},
  [14111] = {.lex_state = 437, .external_lex_state = 2},
  [14112] = {.lex_state = 4, .external_lex_state = 6},
  [14113] = {.lex_state = 259, .external_lex_state = 2},
  [14114] = {.lex_state = 259, .external_lex_state = 2},
  [14115] = {.lex_state = 4, .external_lex_state = 6},
  [14116] = {.lex_state = 254, .external_lex_state = 7},
  [14117] = {.lex_state = 4, .external_lex_state = 6},
  [14118] = {.lex_state = 437, .external_lex_state = 2},
  [14119] = {.lex_state = 4, .external_lex_state = 6},
  [14120] = {.lex_state = 4, .external_lex_state = 6},
  [14121] = {.lex_state = 262, .external_lex_state = 2},
  [14122] = {.lex_state = 232, .external_lex_state = 2},
  [14123] = {.lex_state = 4, .external_lex_state = 6},
  [14124] = {.lex_state = 437, .external_lex_state = 2},
  [14125] = {.lex_state = 4, .external_lex_state = 6},
  [14126] = {.lex_state = 24, .external_lex_state = 2},
  [14127] = {.lex_state = 4, .external_lex_state = 6},
  [14128] = {.lex_state = 4, .external_lex_state = 6},
  [14129] = {.lex_state = 24, .external_lex_state = 2},
  [14130] = {.lex_state = 4, .external_lex_state = 6},
  [14131] = {.lex_state = 259, .external_lex_state = 2},
  [14132] = {.lex_state = 4, .external_lex_state = 6},
  [14133] = {.lex_state = 259, .external_lex_state = 2},
  [14134] = {.lex_state = 24, .external_lex_state = 2},
  [14135] = {.lex_state = 259, .external_lex_state = 2},
  [14136] = {.lex_state = 4, .external_lex_state = 6},
  [14137] = {.lex_state = 259, .external_lex_state = 2},
  [14138] = {.lex_state = 4, .external_lex_state = 6},
  [14139] = {.lex_state = 8, .external_lex_state = 2},
  [14140] = {.lex_state = 245, .external_lex_state = 2},
  [14141] = {.lex_state = 4, .external_lex_state = 6},
  [14142] = {.lex_state = 437, .external_lex_state = 2},
  [14143] = {.lex_state = 216, .external_lex_state = 2},
  [14144] = {.lex_state = 437, .external_lex_state = 2},
  [14145] = {.lex_state = 4, .external_lex_state = 6},
  [14146] = {.lex_state = 4, .external_lex_state = 6},
  [14147] = {.lex_state = 245, .external_lex_state = 2},
  [14148] = {.lex_state = 4, .external_lex_state = 6},
  [14149] = {.lex_state = 4, .external_lex_state = 6},
  [14150] = {.lex_state = 4, .external_lex_state = 6},
  [14151] = {.lex_state = 4, .external_lex_state = 6},
  [14152] = {.lex_state = 4, .external_lex_state = 6},
  [14153] = {.lex_state = 4, .external_lex_state = 6},
  [14154] = {.lex_state = 4, .external_lex_state = 6},
  [14155] = {.lex_state = 4, .external_lex_state = 6},
  [14156] = {.lex_state = 4, .external_lex_state = 6},
  [14157] = {.lex_state = 4, .external_lex_state = 6},
  [14158] = {.lex_state = 4, .external_lex_state = 6},
  [14159] = {.lex_state = 4, .external_lex_state = 6},
  [14160] = {.lex_state = 4, .external_lex_state = 6},
  [14161] = {.lex_state = 4, .external_lex_state = 6},
  [14162] = {.lex_state = 8, .external_lex_state = 2},
  [14163] = {.lex_state = 437, .external_lex_state = 2},
  [14164] = {.lex_state = 259, .external_lex_state = 2},
  [14165] = {.lex_state = 24, .external_lex_state = 2},
  [14166] = {.lex_state = 24, .external_lex_state = 2},
  [14167] = {.lex_state = 8, .external_lex_state = 2},
  [14168] = {.lex_state = 8, .external_lex_state = 2},
  [14169] = {.lex_state = 259, .external_lex_state = 2},
  [14170] = {.lex_state = 24, .external_lex_state = 2},
  [14171] = {.lex_state = 24, .external_lex_state = 2},
  [14172] = {.lex_state = 8, .external_lex_state = 2},
  [14173] = {.lex_state = 24, .external_lex_state = 2},
  [14174] = {.lex_state = 259, .external_lex_state = 2},
  [14175] = {.lex_state = 24, .external_lex_state = 2},
  [14176] = {.lex_state = 259, .external_lex_state = 2},
  [14177] = {.lex_state = 24, .external_lex_state = 2},
  [14178] = {.lex_state = 8, .external_lex_state = 2},
  [14179] = {.lex_state = 24, .external_lex_state = 2},
  [14180] = {.lex_state = 8, .external_lex_state = 2},
  [14181] = {.lex_state = 437, .external_lex_state = 2},
  [14182] = {.lex_state = 8, .external_lex_state = 2},
  [14183] = {.lex_state = 259, .external_lex_state = 2},
  [14184] = {.lex_state = 437, .external_lex_state = 2},
  [14185] = {.lex_state = 24, .external_lex_state = 2},
  [14186] = {.lex_state = 259, .external_lex_state = 2},
  [14187] = {.lex_state = 8, .external_lex_state = 2},
  [14188] = {.lex_state = 24, .external_lex_state = 2},
  [14189] = {.lex_state = 24, .external_lex_state = 2},
  [14190] = {.lex_state = 259, .external_lex_state = 2},
  [14191] = {.lex_state = 8, .external_lex_state = 2},
  [14192] = {.lex_state = 24, .external_lex_state = 2},
  [14193] = {.lex_state = 259, .external_lex_state = 2},
  [14194] = {.lex_state = 4, .external_lex_state = 6},
  [14195] = {.lex_state = 8, .external_lex_state = 2},
  [14196] = {.lex_state = 216, .external_lex_state = 2},
  [14197] = {.lex_state = 437, .external_lex_state = 2},
  [14198] = {.lex_state = 259, .external_lex_state = 2},
  [14199] = {.lex_state = 437, .external_lex_state = 2},
  [14200] = {.lex_state = 437, .external_lex_state = 2},
  [14201] = {.lex_state = 437, .external_lex_state = 2},
  [14202] = {.lex_state = 259, .external_lex_state = 2},
  [14203] = {.lex_state = 437, .external_lex_state = 2},
  [14204] = {.lex_state = 216, .external_lex_state = 2},
  [14205] = {.lex_state = 24, .external_lex_state = 2},
  [14206] = {.lex_state = 8, .external_lex_state = 2},
  [14207] = {.lex_state = 24, .external_lex_state = 2},
  [14208] = {.lex_state = 259, .external_lex_state = 2},
  [14209] = {.lex_state = 24, .external_lex_state = 2},
  [14210] = {.lex_state = 245, .external_lex_state = 2},
  [14211] = {.lex_state = 24, .external_lex_state = 2},
  [14212] = {.lex_state = 259, .external_lex_state = 2},
  [14213] = {.lex_state = 4, .external_lex_state = 6},
  [14214] = {.lex_state = 24, .external_lex_state = 2},
  [14215] = {.lex_state = 232, .external_lex_state = 2},
  [14216] = {.lex_state = 24, .external_lex_state = 2},
  [14217] = {.lex_state = 216, .external_lex_state = 2},
  [14218] = {.lex_state = 259, .external_lex_state = 2},
  [14219] = {.lex_state = 24, .external_lex_state = 2},
  [14220] = {.lex_state = 216, .external_lex_state = 2},
  [14221] = {.lex_state = 24, .external_lex_state = 2},
  [14222] = {.lex_state = 7, .external_lex_state = 2},
  [14223] = {.lex_state = 216, .external_lex_state = 2},
  [14224] = {.lex_state = 242, .external_lex_state = 2},
  [14225] = {.lex_state = 24, .external_lex_state = 2},
  [14226] = {.lex_state = 216, .external_lex_state = 2},
  [14227] = {.lex_state = 216, .external_lex_state = 2},
  [14228] = {.lex_state = 52, .external_lex_state = 2},
  [14229] = {.lex_state = 24, .external_lex_state = 2},
  [14230] = {.lex_state = 216, .external_lex_state = 2},
  [14231] = {.lex_state = 24, .external_lex_state = 2},
  [14232] = {.lex_state = 7, .external_lex_state = 2},
  [14233] = {.lex_state = 24, .external_lex_state = 2},
  [14234] = {.lex_state = 7, .external_lex_state = 2},
  [14235] = {.lex_state = 24, .external_lex_state = 2},
  [14236] = {.lex_state = 7, .external_lex_state = 2},
  [14237] = {.lex_state = 24, .external_lex_state = 2},
  [14238] = {.lex_state = 24, .external_lex_state = 2},
  [14239] = {.lex_state = 24, .external_lex_state = 2},
  [14240] = {.lex_state = 24, .external_lex_state = 2},
  [14241] = {.lex_state = 24, .external_lex_state = 2},
  [14242] = {.lex_state = 24, .external_lex_state = 2},
  [14243] = {.lex_state = 7, .external_lex_state = 2},
  [14244] = {.lex_state = 7, .external_lex_state = 2},
  [14245] = {.lex_state = 216, .external_lex_state = 2},
  [14246] = {.lex_state = 7, .external_lex_state = 2},
  [14247] = {.lex_state = 24, .external_lex_state = 2},
  [14248] = {.lex_state = 437, .external_lex_state = 2},
  [14249] = {.lex_state = 24, .external_lex_state = 2},
  [14250] = {.lex_state = 24, .external_lex_state = 2},
  [14251] = {.lex_state = 24, .external_lex_state = 2},
  [14252] = {.lex_state = 254, .external_lex_state = 7},
  [14253] = {.lex_state = 7, .external_lex_state = 2},
  [14254] = {.lex_state = 24, .external_lex_state = 2},
  [14255] = {.lex_state = 437, .external_lex_state = 2},
  [14256] = {.lex_state = 24, .external_lex_state = 2},
  [14257] = {.lex_state = 7, .external_lex_state = 2},
  [14258] = {.lex_state = 24, .external_lex_state = 2},
  [14259] = {.lex_state = 254, .external_lex_state = 7},
  [14260] = {.lex_state = 24, .external_lex_state = 2},
  [14261] = {.lex_state = 7, .external_lex_state = 2},
  [14262] = {.lex_state = 52, .external_lex_state = 2},
  [14263] = {.lex_state = 445, .external_lex_state = 2},
  [14264] = {.lex_state = 216, .external_lex_state = 2},
  [14265] = {.lex_state = 7, .external_lex_state = 2},
  [14266] = {.lex_state = 7, .external_lex_state = 2},
  [14267] = {.lex_state = 7, .external_lex_state = 2},
  [14268] = {.lex_state = 7, .external_lex_state = 2},
  [14269] = {.lex_state = 7, .external_lex_state = 2},
  [14270] = {.lex_state = 24, .external_lex_state = 2},
  [14271] = {.lex_state = 24, .external_lex_state = 2},
  [14272] = {.lex_state = 24, .external_lex_state = 2},
  [14273] = {.lex_state = 232, .external_lex_state = 2},
  [14274] = {.lex_state = 7, .external_lex_state = 2},
  [14275] = {.lex_state = 7, .external_lex_state = 2},
  [14276] = {.lex_state = 7, .external_lex_state = 2},
  [14277] = {.lex_state = 24, .external_lex_state = 2},
  [14278] = {.lex_state = 7, .external_lex_state = 2},
  [14279] = {.lex_state = 445, .external_lex_state = 2},
  [14280] = {.lex_state = 445, .external_lex_state = 2},
  [14281] = {.lex_state = 445, .external_lex_state = 2},
  [14282] = {.lex_state = 445, .external_lex_state = 2},
  [14283] = {.lex_state = 24, .external_lex_state = 2},
  [14284] = {.lex_state = 24, .external_lex_state = 2},
  [14285] = {.lex_state = 7, .external_lex_state = 2},
  [14286] = {.lex_state = 7, .external_lex_state = 2},
  [14287] = {.lex_state = 24, .external_lex_state = 2},
  [14288] = {.lex_state = 24, .external_lex_state = 2},
  [14289] = {.lex_state = 7, .external_lex_state = 2},
  [14290] = {.lex_state = 7, .external_lex_state = 2},
  [14291] = {.lex_state = 7, .external_lex_state = 2},
  [14292] = {.lex_state = 7, .external_lex_state = 2},
  [14293] = {.lex_state = 7, .external_lex_state = 2},
  [14294] = {.lex_state = 7, .external_lex_state = 2},
  [14295] = {.lex_state = 184, .external_lex_state = 2},
  [14296] = {.lex_state = 8, .external_lex_state = 2},
  [14297] = {.lex_state = 24, .external_lex_state = 2},
  [14298] = {.lex_state = 24, .external_lex_state = 2},
  [14299] = {.lex_state = 216, .external_lex_state = 2},
  [14300] = {.lex_state = 24, .external_lex_state = 2},
  [14301] = {.lex_state = 216, .external_lex_state = 2},
  [14302] = {.lex_state = 216, .external_lex_state = 2},
  [14303] = {.lex_state = 24, .external_lex_state = 8},
  [14304] = {.lex_state = 24, .external_lex_state = 8},
  [14305] = {.lex_state = 24, .external_lex_state = 2},
  [14306] = {.lex_state = 24, .external_lex_state = 2},
  [14307] = {.lex_state = 24, .external_lex_state = 2},
  [14308] = {.lex_state = 24, .external_lex_state = 2},
  [14309] = {.lex_state = 6, .external_lex_state = 2},
  [14310] = {.lex_state = 24, .external_lex_state = 2},
  [14311] = {.lex_state = 24, .external_lex_state = 2},
  [14312] = {.lex_state = 445, .external_lex_state = 2},
  [14313] = {.lex_state = 24, .external_lex_state = 2},
  [14314] = {.lex_state = 24, .external_lex_state = 2},
  [14315] = {.lex_state = 8, .external_lex_state = 2},
  [14316] = {.lex_state = 24, .external_lex_state = 2},
  [14317] = {.lex_state = 24, .external_lex_state = 2},
  [14318] = {.lex_state = 24, .external_lex_state = 2},
  [14319] = {.lex_state = 24, .external_lex_state = 2},
  [14320] = {.lex_state = 242, .external_lex_state = 2},
  [14321] = {.lex_state = 232, .external_lex_state = 2},
  [14322] = {.lex_state = 24, .external_lex_state = 2},
  [14323] = {.lex_state = 24, .external_lex_state = 2},
  [14324] = {.lex_state = 24, .external_lex_state = 2},
  [14325] = {.lex_state = 24, .external_lex_state = 2},
  [14326] = {.lex_state = 24, .external_lex_state = 2},
  [14327] = {.lex_state = 24, .external_lex_state = 2},
  [14328] = {.lex_state = 24, .external_lex_state = 2},
  [14329] = {.lex_state = 24, .external_lex_state = 2},
  [14330] = {.lex_state = 24, .external_lex_state = 2},
  [14331] = {.lex_state = 24, .external_lex_state = 2},
  [14332] = {.lex_state = 24, .external_lex_state = 2},
  [14333] = {.lex_state = 8, .external_lex_state = 2},
  [14334] = {.lex_state = 232, .external_lex_state = 2},
  [14335] = {.lex_state = 24, .external_lex_state = 2},
  [14336] = {.lex_state = 24, .external_lex_state = 2},
  [14337] = {.lex_state = 24, .external_lex_state = 2},
  [14338] = {.lex_state = 24, .external_lex_state = 2},
  [14339] = {.lex_state = 24, .external_lex_state = 2},
  [14340] = {.lex_state = 6, .external_lex_state = 2},
  [14341] = {.lex_state = 24, .external_lex_state = 2},
  [14342] = {.lex_state = 24, .external_lex_state = 2},
  [14343] = {.lex_state = 24, .external_lex_state = 2},
  [14344] = {.lex_state = 6, .external_lex_state = 2},
  [14345] = {.lex_state = 24, .external_lex_state = 2},
  [14346] = {.lex_state = 24, .external_lex_state = 2},
  [14347] = {.lex_state = 24, .external_lex_state = 2},
  [14348] = {.lex_state = 24, .external_lex_state = 2},
  [14349] = {.lex_state = 24, .external_lex_state = 2},
  [14350] = {.lex_state = 24, .external_lex_state = 2},
  [14351] = {.lex_state = 24, .external_lex_state = 8},
  [14352] = {.lex_state = 24, .external_lex_state = 8},
  [14353] = {.lex_state = 24, .external_lex_state = 2},
  [14354] = {.lex_state = 24, .external_lex_state = 2},
  [14355] = {.lex_state = 24, .external_lex_state = 2},
  [14356] = {.lex_state = 24, .external_lex_state = 2},
  [14357] = {.lex_state = 24, .external_lex_state = 2},
  [14358] = {.lex_state = 184, .external_lex_state = 2},
  [14359] = {.lex_state = 24, .external_lex_state = 2},
  [14360] = {.lex_state = 6, .external_lex_state = 2},
  [14361] = {.lex_state = 24, .external_lex_state = 2},
  [14362] = {.lex_state = 24, .external_lex_state = 2},
  [14363] = {.lex_state = 24, .external_lex_state = 2},
  [14364] = {.lex_state = 24, .external_lex_state = 2},
  [14365] = {.lex_state = 24, .external_lex_state = 2},
  [14366] = {.lex_state = 24, .external_lex_state = 2},
  [14367] = {.lex_state = 232, .external_lex_state = 2},
  [14368] = {.lex_state = 52, .external_lex_state = 2},
  [14369] = {.lex_state = 8, .external_lex_state = 2},
  [14370] = {.lex_state = 24, .external_lex_state = 2},
  [14371] = {.lex_state = 24, .external_lex_state = 2},
  [14372] = {.lex_state = 24, .external_lex_state = 2},
  [14373] = {.lex_state = 8, .external_lex_state = 2},
  [14374] = {.lex_state = 216, .external_lex_state = 2},
  [14375] = {.lex_state = 232, .external_lex_state = 2},
  [14376] = {.lex_state = 24, .external_lex_state = 2},
  [14377] = {.lex_state = 24, .external_lex_state = 2},
  [14378] = {.lex_state = 216, .external_lex_state = 2},
  [14379] = {.lex_state = 24, .external_lex_state = 2},
  [14380] = {.lex_state = 24, .external_lex_state = 2},
  [14381] = {.lex_state = 24, .external_lex_state = 2},
  [14382] = {.lex_state = 24, .external_lex_state = 2},
  [14383] = {.lex_state = 24, .external_lex_state = 2},
  [14384] = {.lex_state = 8, .external_lex_state = 2},
  [14385] = {.lex_state = 24, .external_lex_state = 2},
  [14386] = {.lex_state = 232, .external_lex_state = 2},
  [14387] = {.lex_state = 24, .external_lex_state = 2},
  [14388] = {.lex_state = 24, .external_lex_state = 2},
  [14389] = {.lex_state = 24, .external_lex_state = 2},
  [14390] = {.lex_state = 24, .external_lex_state = 2},
  [14391] = {.lex_state = 24, .external_lex_state = 2},
  [14392] = {.lex_state = 24, .external_lex_state = 2},
  [14393] = {.lex_state = 24, .external_lex_state = 2},
  [14394] = {.lex_state = 24, .external_lex_state = 2},
  [14395] = {.lex_state = 232, .external_lex_state = 2},
  [14396] = {.lex_state = 24, .external_lex_state = 2},
  [14397] = {.lex_state = 24, .external_lex_state = 2},
  [14398] = {.lex_state = 24, .external_lex_state = 2},
  [14399] = {.lex_state = 24, .external_lex_state = 2},
  [14400] = {.lex_state = 24, .external_lex_state = 2},
  [14401] = {.lex_state = 24, .external_lex_state = 2},
  [14402] = {.lex_state = 24, .external_lex_state = 2},
  [14403] = {.lex_state = 216, .external_lex_state = 2},
  [14404] = {.lex_state = 24, .external_lex_state = 8},
  [14405] = {.lex_state = 24, .external_lex_state = 8},
  [14406] = {.lex_state = 24, .external_lex_state = 2},
  [14407] = {.lex_state = 24, .external_lex_state = 2},
  [14408] = {.lex_state = 216, .external_lex_state = 2},
  [14409] = {.lex_state = 24, .external_lex_state = 2},
  [14410] = {.lex_state = 8, .external_lex_state = 2},
  [14411] = {.lex_state = 24, .external_lex_state = 2},
  [14412] = {.lex_state = 184, .external_lex_state = 2},
  [14413] = {.lex_state = 24, .external_lex_state = 2},
  [14414] = {.lex_state = 24, .external_lex_state = 2},
  [14415] = {.lex_state = 24, .external_lex_state = 2},
  [14416] = {.lex_state = 6, .external_lex_state = 2},
  [14417] = {.lex_state = 232, .external_lex_state = 2},
  [14418] = {.lex_state = 24, .external_lex_state = 2},
  [14419] = {.lex_state = 24, .external_lex_state = 2},
  [14420] = {.lex_state = 216, .external_lex_state = 2},
  [14421] = {.lex_state = 24, .external_lex_state = 2},
  [14422] = {.lex_state = 24, .external_lex_state = 2},
  [14423] = {.lex_state = 24, .external_lex_state = 2},
  [14424] = {.lex_state = 24, .external_lex_state = 2},
  [14425] = {.lex_state = 24, .external_lex_state = 2},
  [14426] = {.lex_state = 24, .external_lex_state = 2},
  [14427] = {.lex_state = 6, .external_lex_state = 2},
  [14428] = {.lex_state = 24, .external_lex_state = 2},
  [14429] = {.lex_state = 24, .external_lex_state = 2},
  [14430] = {.lex_state = 24, .external_lex_state = 2},
  [14431] = {.lex_state = 24, .external_lex_state = 2},
  [14432] = {.lex_state = 24, .external_lex_state = 2},
  [14433] = {.lex_state = 216, .external_lex_state = 2},
  [14434] = {.lex_state = 24, .external_lex_state = 2},
  [14435] = {.lex_state = 216, .external_lex_state = 2},
  [14436] = {.lex_state = 24, .external_lex_state = 2},
  [14437] = {.lex_state = 24, .external_lex_state = 2},
  [14438] = {.lex_state = 24, .external_lex_state = 2},
  [14439] = {.lex_state = 216, .external_lex_state = 2},
  [14440] = {.lex_state = 24, .external_lex_state = 2},
  [14441] = {.lex_state = 24, .external_lex_state = 2},
  [14442] = {.lex_state = 24, .external_lex_state = 2},
  [14443] = {.lex_state = 24, .external_lex_state = 2},
  [14444] = {.lex_state = 232, .external_lex_state = 2},
  [14445] = {.lex_state = 24, .external_lex_state = 2},
  [14446] = {.lex_state = 24, .external_lex_state = 2},
  [14447] = {.lex_state = 184, .external_lex_state = 2},
  [14448] = {.lex_state = 24, .external_lex_state = 2},
  [14449] = {.lex_state = 24, .external_lex_state = 2},
  [14450] = {.lex_state = 24, .external_lex_state = 2},
  [14451] = {.lex_state = 24, .external_lex_state = 2},
  [14452] = {.lex_state = 24, .external_lex_state = 2},
  [14453] = {.lex_state = 24, .external_lex_state = 2},
  [14454] = {.lex_state = 24, .external_lex_state = 2},
  [14455] = {.lex_state = 24, .external_lex_state = 2},
  [14456] = {.lex_state = 24, .external_lex_state = 2},
  [14457] = {.lex_state = 24, .external_lex_state = 2},
  [14458] = {.lex_state = 24, .external_lex_state = 8},
  [14459] = {.lex_state = 24, .external_lex_state = 2},
  [14460] = {.lex_state = 24, .external_lex_state = 2},
  [14461] = {.lex_state = 24, .external_lex_state = 8},
  [14462] = {.lex_state = 24, .external_lex_state = 8},
  [14463] = {.lex_state = 24, .external_lex_state = 2},
  [14464] = {.lex_state = 24, .external_lex_state = 2},
  [14465] = {.lex_state = 24, .external_lex_state = 2},
  [14466] = {.lex_state = 24, .external_lex_state = 2},
  [14467] = {.lex_state = 25, .external_lex_state = 2},
  [14468] = {.lex_state = 24, .external_lex_state = 2},
  [14469] = {.lex_state = 24, .external_lex_state = 2},
  [14470] = {.lex_state = 24, .external_lex_state = 2},
  [14471] = {.lex_state = 216, .external_lex_state = 2},
  [14472] = {.lex_state = 24, .external_lex_state = 2},
  [14473] = {.lex_state = 24, .external_lex_state = 2},
  [14474] = {.lex_state = 24, .external_lex_state = 2},
  [14475] = {.lex_state = 24, .external_lex_state = 2},
  [14476] = {.lex_state = 24, .external_lex_state = 2},
  [14477] = {.lex_state = 6, .external_lex_state = 2},
  [14478] = {.lex_state = 6, .external_lex_state = 2},
  [14479] = {.lex_state = 216, .external_lex_state = 2},
  [14480] = {.lex_state = 24, .external_lex_state = 2},
  [14481] = {.lex_state = 24, .external_lex_state = 2},
  [14482] = {.lex_state = 24, .external_lex_state = 2},
  [14483] = {.lex_state = 6, .external_lex_state = 2},
  [14484] = {.lex_state = 24, .external_lex_state = 2},
  [14485] = {.lex_state = 216, .external_lex_state = 2},
  [14486] = {.lex_state = 24, .external_lex_state = 2},
  [14487] = {.lex_state = 232, .external_lex_state = 2},
  [14488] = {.lex_state = 24, .external_lex_state = 2},
  [14489] = {.lex_state = 232, .external_lex_state = 2},
  [14490] = {.lex_state = 24, .external_lex_state = 2},
  [14491] = {.lex_state = 24, .external_lex_state = 2},
  [14492] = {.lex_state = 24, .external_lex_state = 2},
  [14493] = {.lex_state = 232, .external_lex_state = 2},
  [14494] = {.lex_state = 24, .external_lex_state = 2},
  [14495] = {.lex_state = 24, .external_lex_state = 2},
  [14496] = {.lex_state = 232, .external_lex_state = 2},
  [14497] = {.lex_state = 24, .external_lex_state = 2},
  [14498] = {.lex_state = 24, .external_lex_state = 2},
  [14499] = {.lex_state = 24, .external_lex_state = 2},
  [14500] = {.lex_state = 24, .external_lex_state = 2},
  [14501] = {.lex_state = 24, .external_lex_state = 2},
  [14502] = {.lex_state = 216, .external_lex_state = 2},
  [14503] = {.lex_state = 24, .external_lex_state = 2},
  [14504] = {.lex_state = 24, .external_lex_state = 2},
  [14505] = {.lex_state = 24, .external_lex_state = 2},
  [14506] = {.lex_state = 24, .external_lex_state = 8},
  [14507] = {.lex_state = 216, .external_lex_state = 2},
  [14508] = {.lex_state = 24, .external_lex_state = 2},
  [14509] = {.lex_state = 8, .external_lex_state = 2},
  [14510] = {.lex_state = 24, .external_lex_state = 2},
  [14511] = {.lex_state = 24, .external_lex_state = 2},
  [14512] = {.lex_state = 24, .external_lex_state = 2},
  [14513] = {.lex_state = 8, .external_lex_state = 2},
  [14514] = {.lex_state = 24, .external_lex_state = 2},
  [14515] = {.lex_state = 24, .external_lex_state = 2},
  [14516] = {.lex_state = 24, .external_lex_state = 2},
  [14517] = {.lex_state = 24, .external_lex_state = 2},
  [14518] = {.lex_state = 8, .external_lex_state = 2},
  [14519] = {.lex_state = 24, .external_lex_state = 2},
  [14520] = {.lex_state = 6, .external_lex_state = 2},
  [14521] = {.lex_state = 24, .external_lex_state = 2},
  [14522] = {.lex_state = 24, .external_lex_state = 2},
  [14523] = {.lex_state = 184, .external_lex_state = 2},
  [14524] = {.lex_state = 216, .external_lex_state = 2},
  [14525] = {.lex_state = 6, .external_lex_state = 2},
  [14526] = {.lex_state = 24, .external_lex_state = 2},
  [14527] = {.lex_state = 24, .external_lex_state = 2},
  [14528] = {.lex_state = 24, .external_lex_state = 2},
  [14529] = {.lex_state = 24, .external_lex_state = 2},
  [14530] = {.lex_state = 8, .external_lex_state = 2},
  [14531] = {.lex_state = 8, .external_lex_state = 2},
  [14532] = {.lex_state = 24, .external_lex_state = 2},
  [14533] = {.lex_state = 8, .external_lex_state = 2},
  [14534] = {.lex_state = 24, .external_lex_state = 2},
  [14535] = {.lex_state = 24, .external_lex_state = 2},
  [14536] = {.lex_state = 8, .external_lex_state = 2},
  [14537] = {.lex_state = 8, .external_lex_state = 2},
  [14538] = {.lex_state = 8, .external_lex_state = 2},
  [14539] = {.lex_state = 24, .external_lex_state = 2},
  [14540] = {.lex_state = 24, .external_lex_state = 2},
  [14541] = {.lex_state = 246, .external_lex_state = 2},
  [14542] = {.lex_state = 24, .external_lex_state = 2},
  [14543] = {.lex_state = 8, .external_lex_state = 2},
  [14544] = {.lex_state = 232, .external_lex_state = 2},
  [14545] = {.lex_state = 8, .external_lex_state = 2},
  [14546] = {.lex_state = 25, .external_lex_state = 2},
  [14547] = {.lex_state = 8, .external_lex_state = 2},
  [14548] = {.lex_state = 24, .external_lex_state = 2},
  [14549] = {.lex_state = 254, .external_lex_state = 7},
  [14550] = {.lex_state = 8, .external_lex_state = 2},
  [14551] = {.lex_state = 8, .external_lex_state = 2},
  [14552] = {.lex_state = 232, .external_lex_state = 2},
  [14553] = {.lex_state = 24, .external_lex_state = 2},
  [14554] = {.lex_state = 8, .external_lex_state = 2},
  [14555] = {.lex_state = 24, .external_lex_state = 2},
  [14556] = {.lex_state = 232, .external_lex_state = 2},
  [14557] = {.lex_state = 232, .external_lex_state = 2},
  [14558] = {.lex_state = 6, .external_lex_state = 2},
  [14559] = {.lex_state = 8, .external_lex_state = 2},
  [14560] = {.lex_state = 24, .external_lex_state = 8},
  [14561] = {.lex_state = 24, .external_lex_state = 8},
  [14562] = {.lex_state = 232, .external_lex_state = 2},
  [14563] = {.lex_state = 24, .external_lex_state = 2},
  [14564] = {.lex_state = 232, .external_lex_state = 2},
  [14565] = {.lex_state = 8, .external_lex_state = 2},
  [14566] = {.lex_state = 232, .external_lex_state = 2},
  [14567] = {.lex_state = 232, .external_lex_state = 2},
  [14568] = {.lex_state = 24, .external_lex_state = 2},
  [14569] = {.lex_state = 232, .external_lex_state = 2},
  [14570] = {.lex_state = 246, .external_lex_state = 2},
  [14571] = {.lex_state = 184, .external_lex_state = 2},
  [14572] = {.lex_state = 24, .external_lex_state = 2},
  [14573] = {.lex_state = 184, .external_lex_state = 2},
  [14574] = {.lex_state = 24, .external_lex_state = 2},
  [14575] = {.lex_state = 184, .external_lex_state = 2},
  [14576] = {.lex_state = 24, .external_lex_state = 2},
  [14577] = {.lex_state = 184, .external_lex_state = 2},
  [14578] = {.lex_state = 24, .external_lex_state = 2},
  [14579] = {.lex_state = 24, .external_lex_state = 2},
  [14580] = {.lex_state = 24, .external_lex_state = 2},
  [14581] = {.lex_state = 24, .external_lex_state = 2},
  [14582] = {.lex_state = 6, .external_lex_state = 2},
  [14583] = {.lex_state = 24, .external_lex_state = 2},
  [14584] = {.lex_state = 24, .external_lex_state = 2},
  [14585] = {.lex_state = 6, .external_lex_state = 2},
  [14586] = {.lex_state = 184, .external_lex_state = 2},
  [14587] = {.lex_state = 24, .external_lex_state = 2},
  [14588] = {.lex_state = 24, .external_lex_state = 2},
  [14589] = {.lex_state = 24, .external_lex_state = 2},
  [14590] = {.lex_state = 24, .external_lex_state = 2},
  [14591] = {.lex_state = 24, .external_lex_state = 2},
  [14592] = {.lex_state = 216, .external_lex_state = 2},
  [14593] = {.lex_state = 24, .external_lex_state = 2},
  [14594] = {.lex_state = 24, .external_lex_state = 2},
  [14595] = {.lex_state = 24, .external_lex_state = 2},
  [14596] = {.lex_state = 24, .external_lex_state = 2},
  [14597] = {.lex_state = 24, .external_lex_state = 2},
  [14598] = {.lex_state = 24, .external_lex_state = 2},
  [14599] = {.lex_state = 24, .external_lex_state = 2},
  [14600] = {.lex_state = 24, .external_lex_state = 2},
  [14601] = {.lex_state = 227, .external_lex_state = 2},
  [14602] = {.lex_state = 184, .external_lex_state = 2},
  [14603] = {.lex_state = 184, .external_lex_state = 2},
  [14604] = {.lex_state = 184, .external_lex_state = 2},
  [14605] = {.lex_state = 246, .external_lex_state = 2},
  [14606] = {.lex_state = 232, .external_lex_state = 2},
  [14607] = {.lex_state = 24, .external_lex_state = 2},
  [14608] = {.lex_state = 227, .external_lex_state = 2},
  [14609] = {.lex_state = 24, .external_lex_state = 8},
  [14610] = {.lex_state = 24, .external_lex_state = 2},
  [14611] = {.lex_state = 24, .external_lex_state = 2},
  [14612] = {.lex_state = 246, .external_lex_state = 2},
  [14613] = {.lex_state = 24, .external_lex_state = 2},
  [14614] = {.lex_state = 24, .external_lex_state = 2},
  [14615] = {.lex_state = 232, .external_lex_state = 2},
  [14616] = {.lex_state = 8, .external_lex_state = 2},
  [14617] = {.lex_state = 232, .external_lex_state = 2},
  [14618] = {.lex_state = 232, .external_lex_state = 2},
  [14619] = {.lex_state = 232, .external_lex_state = 2},
  [14620] = {.lex_state = 232, .external_lex_state = 2},
  [14621] = {.lex_state = 232, .external_lex_state = 2},
  [14622] = {.lex_state = 24, .external_lex_state = 2},
  [14623] = {.lex_state = 24, .external_lex_state = 8},
  [14624] = {.lex_state = 24, .external_lex_state = 8},
  [14625] = {.lex_state = 232, .external_lex_state = 2},
  [14626] = {.lex_state = 8, .external_lex_state = 2},
  [14627] = {.lex_state = 232, .external_lex_state = 2},
  [14628] = {.lex_state = 8, .external_lex_state = 2},
  [14629] = {.lex_state = 232, .external_lex_state = 2},
  [14630] = {.lex_state = 8, .external_lex_state = 2},
  [14631] = {.lex_state = 184, .external_lex_state = 2},
  [14632] = {.lex_state = 24, .external_lex_state = 2},
  [14633] = {.lex_state = 227, .external_lex_state = 2},
  [14634] = {.lex_state = 227, .external_lex_state = 2},
  [14635] = {.lex_state = 6, .external_lex_state = 2},
  [14636] = {.lex_state = 24, .external_lex_state = 2},
  [14637] = {.lex_state = 6, .external_lex_state = 2},
  [14638] = {.lex_state = 24, .external_lex_state = 2},
  [14639] = {.lex_state = 6, .external_lex_state = 2},
  [14640] = {.lex_state = 6, .external_lex_state = 2},
  [14641] = {.lex_state = 6, .external_lex_state = 2},
  [14642] = {.lex_state = 6, .external_lex_state = 2},
  [14643] = {.lex_state = 6, .external_lex_state = 2},
  [14644] = {.lex_state = 6, .external_lex_state = 2},
  [14645] = {.lex_state = 6, .external_lex_state = 2},
  [14646] = {.lex_state = 6, .external_lex_state = 2},
  [14647] = {.lex_state = 6, .external_lex_state = 2},
  [14648] = {.lex_state = 6, .external_lex_state = 2},
  [14649] = {.lex_state = 24, .external_lex_state = 2},
  [14650] = {.lex_state = 6, .external_lex_state = 2},
  [14651] = {.lex_state = 24, .external_lex_state = 2},
  [14652] = {.lex_state = 6, .external_lex_state = 2},
  [14653] = {.lex_state = 6, .external_lex_state = 2},
  [14654] = {.lex_state = 24, .external_lex_state = 2},
  [14655] = {.lex_state = 6, .external_lex_state = 2},
  [14656] = {.lex_state = 6, .external_lex_state = 2},
  [14657] = {.lex_state = 24, .external_lex_state = 2},
  [14658] = {.lex_state = 24, .external_lex_state = 2},
  [14659] = {.lex_state = 24, .external_lex_state = 2},
  [14660] = {.lex_state = 24, .external_lex_state = 2},
  [14661] = {.lex_state = 24, .external_lex_state = 2},
  [14662] = {.lex_state = 6, .external_lex_state = 2},
  [14663] = {.lex_state = 24, .external_lex_state = 2},
  [14664] = {.lex_state = 24, .external_lex_state = 2},
  [14665] = {.lex_state = 24, .external_lex_state = 2},
  [14666] = {.lex_state = 24, .external_lex_state = 2},
  [14667] = {.lex_state = 6, .external_lex_state = 2},
  [14668] = {.lex_state = 6, .external_lex_state = 2},
  [14669] = {.lex_state = 24, .external_lex_state = 2},
  [14670] = {.lex_state = 6, .external_lex_state = 2},
  [14671] = {.lex_state = 24, .external_lex_state = 2},
  [14672] = {.lex_state = 24, .external_lex_state = 2},
  [14673] = {.lex_state = 24, .external_lex_state = 2},
  [14674] = {.lex_state = 6, .external_lex_state = 2},
  [14675] = {.lex_state = 24, .external_lex_state = 2},
  [14676] = {.lex_state = 24, .external_lex_state = 2},
  [14677] = {.lex_state = 24, .external_lex_state = 2},
  [14678] = {.lex_state = 24, .external_lex_state = 2},
  [14679] = {.lex_state = 24, .external_lex_state = 2},
  [14680] = {.lex_state = 24, .external_lex_state = 2},
  [14681] = {.lex_state = 24, .external_lex_state = 2},
  [14682] = {.lex_state = 6, .external_lex_state = 2},
  [14683] = {.lex_state = 24, .external_lex_state = 2},
  [14684] = {.lex_state = 24, .external_lex_state = 2},
  [14685] = {.lex_state = 6, .external_lex_state = 2},
  [14686] = {.lex_state = 24, .external_lex_state = 2},
  [14687] = {.lex_state = 24, .external_lex_state = 2},
  [14688] = {.lex_state = 6, .external_lex_state = 2},
  [14689] = {.lex_state = 6, .external_lex_state = 2},
  [14690] = {.lex_state = 24, .external_lex_state = 2},
  [14691] = {.lex_state = 24, .external_lex_state = 2},
  [14692] = {.lex_state = 24, .external_lex_state = 2},
  [14693] = {.lex_state = 24, .external_lex_state = 2},
  [14694] = {.lex_state = 24, .external_lex_state = 2},
  [14695] = {.lex_state = 6, .external_lex_state = 2},
  [14696] = {.lex_state = 6, .external_lex_state = 2},
  [14697] = {.lex_state = 24, .external_lex_state = 2},
  [14698] = {.lex_state = 24, .external_lex_state = 2},
  [14699] = {.lex_state = 24, .external_lex_state = 2},
  [14700] = {.lex_state = 24, .external_lex_state = 2},
  [14701] = {.lex_state = 24, .external_lex_state = 2},
  [14702] = {.lex_state = 24, .external_lex_state = 2},
  [14703] = {.lex_state = 24, .external_lex_state = 2},
  [14704] = {.lex_state = 24, .external_lex_state = 2},
  [14705] = {.lex_state = 24, .external_lex_state = 2},
  [14706] = {.lex_state = 24, .external_lex_state = 2},
  [14707] = {.lex_state = 24, .external_lex_state = 2},
  [14708] = {.lex_state = 24, .external_lex_state = 2},
  [14709] = {.lex_state = 24, .external_lex_state = 2},
  [14710] = {.lex_state = 24, .external_lex_state = 2},
  [14711] = {.lex_state = 24, .external_lex_state = 2},
  [14712] = {.lex_state = 24, .external_lex_state = 2},
  [14713] = {.lex_state = 24, .external_lex_state = 2},
  [14714] = {.lex_state = 24, .external_lex_state = 2},
  [14715] = {.lex_state = 24, .external_lex_state = 2},
  [14716] = {.lex_state = 24, .external_lex_state = 2},
  [14717] = {.lex_state = 24, .external_lex_state = 2},
  [14718] = {.lex_state = 24, .external_lex_state = 2},
  [14719] = {.lex_state = 24, .external_lex_state = 2},
  [14720] = {.lex_state = 24, .external_lex_state = 2},
  [14721] = {.lex_state = 24, .external_lex_state = 2},
  [14722] = {.lex_state = 6, .external_lex_state = 2},
  [14723] = {.lex_state = 24, .external_lex_state = 2},
  [14724] = {.lex_state = 24, .external_lex_state = 2},
  [14725] = {.lex_state = 6, .external_lex_state = 2},
  [14726] = {.lex_state = 24, .external_lex_state = 2},
  [14727] = {.lex_state = 24, .external_lex_state = 2},
  [14728] = {.lex_state = 6, .external_lex_state = 2},
  [14729] = {.lex_state = 24, .external_lex_state = 2},
  [14730] = {.lex_state = 24, .external_lex_state = 2},
  [14731] = {.lex_state = 6, .external_lex_state = 2},
  [14732] = {.lex_state = 24, .external_lex_state = 2},
  [14733] = {.lex_state = 24, .external_lex_state = 2},
  [14734] = {.lex_state = 24, .external_lex_state = 2},
  [14735] = {.lex_state = 24, .external_lex_state = 2},
  [14736] = {.lex_state = 24, .external_lex_state = 2},
  [14737] = {.lex_state = 24, .external_lex_state = 2},
  [14738] = {.lex_state = 24, .external_lex_state = 2},
  [14739] = {.lex_state = 24, .external_lex_state = 2},
  [14740] = {.lex_state = 24, .external_lex_state = 2},
  [14741] = {.lex_state = 6, .external_lex_state = 2},
  [14742] = {.lex_state = 24, .external_lex_state = 2},
  [14743] = {.lex_state = 24, .external_lex_state = 2},
  [14744] = {.lex_state = 22, .external_lex_state = 2},
  [14745] = {.lex_state = 24, .external_lex_state = 2},
  [14746] = {.lex_state = 24, .external_lex_state = 2},
  [14747] = {.lex_state = 24, .external_lex_state = 2},
  [14748] = {.lex_state = 6, .external_lex_state = 2},
  [14749] = {.lex_state = 6, .external_lex_state = 2},
  [14750] = {.lex_state = 24, .external_lex_state = 2},
  [14751] = {.lex_state = 24, .external_lex_state = 2},
  [14752] = {.lex_state = 24, .external_lex_state = 2},
  [14753] = {.lex_state = 24, .external_lex_state = 2},
  [14754] = {.lex_state = 6, .external_lex_state = 2},
  [14755] = {.lex_state = 24, .external_lex_state = 2},
  [14756] = {.lex_state = 24, .external_lex_state = 2},
  [14757] = {.lex_state = 6, .external_lex_state = 2},
  [14758] = {.lex_state = 445, .external_lex_state = 2},
  [14759] = {.lex_state = 24, .external_lex_state = 2},
  [14760] = {.lex_state = 6, .external_lex_state = 2},
  [14761] = {.lex_state = 6, .external_lex_state = 2},
  [14762] = {.lex_state = 6, .external_lex_state = 2},
  [14763] = {.lex_state = 24, .external_lex_state = 2},
  [14764] = {.lex_state = 24, .external_lex_state = 2},
  [14765] = {.lex_state = 6, .external_lex_state = 2},
  [14766] = {.lex_state = 6, .external_lex_state = 2},
  [14767] = {.lex_state = 445, .external_lex_state = 2},
  [14768] = {.lex_state = 24, .external_lex_state = 2},
  [14769] = {.lex_state = 24, .external_lex_state = 2},
  [14770] = {.lex_state = 6, .external_lex_state = 2},
  [14771] = {.lex_state = 24, .external_lex_state = 2},
  [14772] = {.lex_state = 6, .external_lex_state = 2},
  [14773] = {.lex_state = 24, .external_lex_state = 2},
  [14774] = {.lex_state = 6, .external_lex_state = 2},
  [14775] = {.lex_state = 24, .external_lex_state = 2},
  [14776] = {.lex_state = 6, .external_lex_state = 2},
  [14777] = {.lex_state = 24, .external_lex_state = 2},
  [14778] = {.lex_state = 24, .external_lex_state = 2},
  [14779] = {.lex_state = 24, .external_lex_state = 2},
  [14780] = {.lex_state = 24, .external_lex_state = 2},
  [14781] = {.lex_state = 24, .external_lex_state = 2},
  [14782] = {.lex_state = 24, .external_lex_state = 2},
  [14783] = {.lex_state = 6, .external_lex_state = 2},
  [14784] = {.lex_state = 6, .external_lex_state = 2},
  [14785] = {.lex_state = 24, .external_lex_state = 2},
  [14786] = {.lex_state = 24, .external_lex_state = 2},
  [14787] = {.lex_state = 24, .external_lex_state = 2},
  [14788] = {.lex_state = 24, .external_lex_state = 2},
  [14789] = {.lex_state = 24, .external_lex_state = 2},
  [14790] = {.lex_state = 24, .external_lex_state = 2},
  [14791] = {.lex_state = 24, .external_lex_state = 2},
  [14792] = {.lex_state = 24, .external_lex_state = 2},
  [14793] = {.lex_state = 24, .external_lex_state = 2},
  [14794] = {.lex_state = 24, .external_lex_state = 2},
  [14795] = {.lex_state = 24, .external_lex_state = 2},
  [14796] = {.lex_state = 24, .external_lex_state = 2},
  [14797] = {.lex_state = 24, .external_lex_state = 2},
  [14798] = {.lex_state = 6, .external_lex_state = 2},
  [14799] = {.lex_state = 24, .external_lex_state = 2},
  [14800] = {.lex_state = 24, .external_lex_state = 2},
  [14801] = {.lex_state = 6, .external_lex_state = 2},
  [14802] = {.lex_state = 24, .external_lex_state = 2},
  [14803] = {.lex_state = 24, .external_lex_state = 2},
  [14804] = {.lex_state = 6, .external_lex_state = 2},
  [14805] = {.lex_state = 24, .external_lex_state = 2},
  [14806] = {.lex_state = 24, .external_lex_state = 2},
  [14807] = {.lex_state = 6, .external_lex_state = 2},
  [14808] = {.lex_state = 24, .external_lex_state = 2},
  [14809] = {.lex_state = 22, .external_lex_state = 2},
  [14810] = {.lex_state = 6, .external_lex_state = 2},
  [14811] = {.lex_state = 6, .external_lex_state = 2},
  [14812] = {.lex_state = 24, .external_lex_state = 2},
  [14813] = {.lex_state = 6, .external_lex_state = 2},
  [14814] = {.lex_state = 6, .external_lex_state = 2},
  [14815] = {.lex_state = 22, .external_lex_state = 2},
  [14816] = {.lex_state = 22, .external_lex_state = 2},
  [14817] = {.lex_state = 24, .external_lex_state = 2},
  [14818] = {.lex_state = 24, .external_lex_state = 2},
  [14819] = {.lex_state = 24, .external_lex_state = 2},
  [14820] = {.lex_state = 6, .external_lex_state = 2},
  [14821] = {.lex_state = 6, .external_lex_state = 2},
  [14822] = {.lex_state = 6, .external_lex_state = 2},
  [14823] = {.lex_state = 24, .external_lex_state = 2},
  [14824] = {.lex_state = 24, .external_lex_state = 2},
  [14825] = {.lex_state = 6, .external_lex_state = 2},
  [14826] = {.lex_state = 24, .external_lex_state = 2},
  [14827] = {.lex_state = 24, .external_lex_state = 2},
  [14828] = {.lex_state = 24, .external_lex_state = 2},
  [14829] = {.lex_state = 24, .external_lex_state = 2},
  [14830] = {.lex_state = 24, .external_lex_state = 2},
  [14831] = {.lex_state = 24, .external_lex_state = 2},
  [14832] = {.lex_state = 6, .external_lex_state = 2},
  [14833] = {.lex_state = 24, .external_lex_state = 2},
  [14834] = {.lex_state = 24, .external_lex_state = 2},
  [14835] = {.lex_state = 6, .external_lex_state = 2},
  [14836] = {.lex_state = 24, .external_lex_state = 2},
  [14837] = {.lex_state = 6, .external_lex_state = 2},
  [14838] = {.lex_state = 24, .external_lex_state = 2},
  [14839] = {.lex_state = 6, .external_lex_state = 2},
  [14840] = {.lex_state = 24, .external_lex_state = 2},
  [14841] = {.lex_state = 24, .external_lex_state = 2},
  [14842] = {.lex_state = 24, .external_lex_state = 2},
  [14843] = {.lex_state = 24, .external_lex_state = 2},
  [14844] = {.lex_state = 6, .external_lex_state = 2},
  [14845] = {.lex_state = 24, .external_lex_state = 2},
  [14846] = {.lex_state = 6, .external_lex_state = 2},
  [14847] = {.lex_state = 24, .external_lex_state = 2},
  [14848] = {.lex_state = 6, .external_lex_state = 2},
  [14849] = {.lex_state = 24, .external_lex_state = 2},
  [14850] = {.lex_state = 24, .external_lex_state = 2},
  [14851] = {.lex_state = 24, .external_lex_state = 2},
  [14852] = {.lex_state = 24, .external_lex_state = 2},
  [14853] = {.lex_state = 6, .external_lex_state = 2},
  [14854] = {.lex_state = 24, .external_lex_state = 2},
  [14855] = {.lex_state = 24, .external_lex_state = 2},
  [14856] = {.lex_state = 24, .external_lex_state = 2},
  [14857] = {.lex_state = 24, .external_lex_state = 2},
  [14858] = {.lex_state = 24, .external_lex_state = 2},
  [14859] = {.lex_state = 6, .external_lex_state = 2},
  [14860] = {.lex_state = 6, .external_lex_state = 2},
  [14861] = {.lex_state = 6, .external_lex_state = 2},
  [14862] = {.lex_state = 24, .external_lex_state = 2},
  [14863] = {.lex_state = 24, .external_lex_state = 2},
  [14864] = {.lex_state = 24, .external_lex_state = 2},
  [14865] = {.lex_state = 22, .external_lex_state = 2},
  [14866] = {.lex_state = 24, .external_lex_state = 2},
  [14867] = {.lex_state = 22, .external_lex_state = 2},
  [14868] = {.lex_state = 24, .external_lex_state = 2},
  [14869] = {.lex_state = 22, .external_lex_state = 2},
  [14870] = {.lex_state = 22, .external_lex_state = 2},
  [14871] = {.lex_state = 6, .external_lex_state = 2},
  [14872] = {.lex_state = 24, .external_lex_state = 2},
  [14873] = {.lex_state = 6, .external_lex_state = 2},
  [14874] = {.lex_state = 6, .external_lex_state = 2},
  [14875] = {.lex_state = 24, .external_lex_state = 2},
  [14876] = {.lex_state = 24, .external_lex_state = 2},
  [14877] = {.lex_state = 24, .external_lex_state = 2},
  [14878] = {.lex_state = 24, .external_lex_state = 2},
  [14879] = {.lex_state = 6, .external_lex_state = 2},
  [14880] = {.lex_state = 6, .external_lex_state = 2},
  [14881] = {.lex_state = 24, .external_lex_state = 2},
  [14882] = {.lex_state = 24, .external_lex_state = 2},
  [14883] = {.lex_state = 6, .external_lex_state = 2},
  [14884] = {.lex_state = 24, .external_lex_state = 2},
  [14885] = {.lex_state = 6, .external_lex_state = 2},
  [14886] = {.lex_state = 6, .external_lex_state = 2},
  [14887] = {.lex_state = 6, .external_lex_state = 2},
  [14888] = {.lex_state = 24, .external_lex_state = 2},
  [14889] = {.lex_state = 6, .external_lex_state = 2},
  [14890] = {.lex_state = 24, .external_lex_state = 2},
  [14891] = {.lex_state = 24, .external_lex_state = 2},
  [14892] = {.lex_state = 24, .external_lex_state = 2},
  [14893] = {.lex_state = 24, .external_lex_state = 2},
  [14894] = {.lex_state = 24, .external_lex_state = 2},
  [14895] = {.lex_state = 24, .external_lex_state = 2},
  [14896] = {.lex_state = 24, .external_lex_state = 2},
  [14897] = {.lex_state = 24, .external_lex_state = 2},
  [14898] = {.lex_state = 24, .external_lex_state = 2},
  [14899] = {.lex_state = 6, .external_lex_state = 2},
  [14900] = {.lex_state = 24, .external_lex_state = 2},
  [14901] = {.lex_state = 24, .external_lex_state = 2},
  [14902] = {.lex_state = 24, .external_lex_state = 2},
  [14903] = {.lex_state = 24, .external_lex_state = 2},
  [14904] = {.lex_state = 6, .external_lex_state = 2},
  [14905] = {.lex_state = 24, .external_lex_state = 2},
  [14906] = {.lex_state = 24, .external_lex_state = 2},
  [14907] = {.lex_state = 22, .external_lex_state = 2},
  [14908] = {.lex_state = 22, .external_lex_state = 2},
  [14909] = {.lex_state = 24, .external_lex_state = 2},
  [14910] = {.lex_state = 24, .external_lex_state = 2},
  [14911] = {.lex_state = 24, .external_lex_state = 2},
  [14912] = {.lex_state = 22, .external_lex_state = 2},
  [14913] = {.lex_state = 22, .external_lex_state = 2},
  [14914] = {.lex_state = 6, .external_lex_state = 2},
  [14915] = {.lex_state = 24, .external_lex_state = 2},
  [14916] = {.lex_state = 24, .external_lex_state = 2},
  [14917] = {.lex_state = 24, .external_lex_state = 2},
  [14918] = {.lex_state = 6, .external_lex_state = 2},
  [14919] = {.lex_state = 24, .external_lex_state = 2},
  [14920] = {.lex_state = 6, .external_lex_state = 2},
  [14921] = {.lex_state = 6, .external_lex_state = 2},
  [14922] = {.lex_state = 24, .external_lex_state = 2},
  [14923] = {.lex_state = 24, .external_lex_state = 2},
  [14924] = {.lex_state = 24, .external_lex_state = 2},
  [14925] = {.lex_state = 24, .external_lex_state = 2},
  [14926] = {.lex_state = 6, .external_lex_state = 2},
  [14927] = {.lex_state = 24, .external_lex_state = 2},
  [14928] = {.lex_state = 22, .external_lex_state = 2},
  [14929] = {.lex_state = 22, .external_lex_state = 2},
  [14930] = {.lex_state = 22, .external_lex_state = 2},
  [14931] = {.lex_state = 24, .external_lex_state = 2},
  [14932] = {.lex_state = 24, .external_lex_state = 2},
  [14933] = {.lex_state = 6, .external_lex_state = 2},
  [14934] = {.lex_state = 22, .external_lex_state = 2},
  [14935] = {.lex_state = 24, .external_lex_state = 2},
  [14936] = {.lex_state = 6, .external_lex_state = 2},
  [14937] = {.lex_state = 24, .external_lex_state = 2},
  [14938] = {.lex_state = 6, .external_lex_state = 2},
  [14939] = {.lex_state = 6, .external_lex_state = 2},
  [14940] = {.lex_state = 24, .external_lex_state = 2},
  [14941] = {.lex_state = 24, .external_lex_state = 2},
  [14942] = {.lex_state = 8, .external_lex_state = 2},
  [14943] = {.lex_state = 6, .external_lex_state = 2},
  [14944] = {.lex_state = 8, .external_lex_state = 2},
  [14945] = {.lex_state = 6, .external_lex_state = 2},
  [14946] = {.lex_state = 445, .external_lex_state = 2},
  [14947] = {.lex_state = 24, .external_lex_state = 2},
  [14948] = {.lex_state = 6, .external_lex_state = 2},
  [14949] = {.lex_state = 6, .external_lex_state = 2},
  [14950] = {.lex_state = 6, .external_lex_state = 2},
  [14951] = {.lex_state = 24, .external_lex_state = 2},
  [14952] = {.lex_state = 24, .external_lex_state = 2},
  [14953] = {.lex_state = 24, .external_lex_state = 2},
  [14954] = {.lex_state = 24, .external_lex_state = 2},
  [14955] = {.lex_state = 24, .external_lex_state = 2},
  [14956] = {.lex_state = 24, .external_lex_state = 2},
  [14957] = {.lex_state = 24, .external_lex_state = 2},
  [14958] = {.lex_state = 24, .external_lex_state = 2},
  [14959] = {.lex_state = 24, .external_lex_state = 2},
  [14960] = {.lex_state = 24, .external_lex_state = 2},
  [14961] = {.lex_state = 22, .external_lex_state = 2},
  [14962] = {.lex_state = 6, .external_lex_state = 2},
  [14963] = {.lex_state = 24, .external_lex_state = 2},
  [14964] = {.lex_state = 24, .external_lex_state = 2},
  [14965] = {.lex_state = 24, .external_lex_state = 2},
  [14966] = {.lex_state = 24, .external_lex_state = 2},
  [14967] = {.lex_state = 24, .external_lex_state = 2},
  [14968] = {.lex_state = 24, .external_lex_state = 2},
  [14969] = {.lex_state = 24, .external_lex_state = 2},
  [14970] = {.lex_state = 22, .external_lex_state = 2},
  [14971] = {.lex_state = 24, .external_lex_state = 2},
  [14972] = {.lex_state = 24, .external_lex_state = 2},
  [14973] = {.lex_state = 24, .external_lex_state = 2},
  [14974] = {.lex_state = 24, .external_lex_state = 2},
  [14975] = {.lex_state = 24, .external_lex_state = 2},
  [14976] = {.lex_state = 24, .external_lex_state = 2},
  [14977] = {.lex_state = 24, .external_lex_state = 2},
  [14978] = {.lex_state = 24, .external_lex_state = 2},
  [14979] = {.lex_state = 6, .external_lex_state = 2},
  [14980] = {.lex_state = 24, .external_lex_state = 2},
  [14981] = {.lex_state = 24, .external_lex_state = 2},
  [14982] = {.lex_state = 24, .external_lex_state = 2},
  [14983] = {.lex_state = 24, .external_lex_state = 2},
  [14984] = {.lex_state = 24, .external_lex_state = 2},
  [14985] = {.lex_state = 24, .external_lex_state = 2},
  [14986] = {.lex_state = 6, .external_lex_state = 2},
  [14987] = {.lex_state = 24, .external_lex_state = 2},
  [14988] = {.lex_state = 24, .external_lex_state = 2},
  [14989] = {.lex_state = 24, .external_lex_state = 2},
  [14990] = {.lex_state = 24, .external_lex_state = 2},
  [14991] = {.lex_state = 24, .external_lex_state = 2},
  [14992] = {.lex_state = 24, .external_lex_state = 2},
  [14993] = {.lex_state = 6, .external_lex_state = 2},
  [14994] = {.lex_state = 24, .external_lex_state = 2},
  [14995] = {.lex_state = 11, .external_lex_state = 2},
  [14996] = {.lex_state = 24, .external_lex_state = 2},
  [14997] = {.lex_state = 6, .external_lex_state = 2},
  [14998] = {.lex_state = 24, .external_lex_state = 2},
  [14999] = {.lex_state = 232, .external_lex_state = 2},
  [15000] = {.lex_state = 6, .external_lex_state = 2},
  [15001] = {.lex_state = 24, .external_lex_state = 2},
  [15002] = {.lex_state = 24, .external_lex_state = 2},
  [15003] = {.lex_state = 6, .external_lex_state = 2},
  [15004] = {.lex_state = 24, .external_lex_state = 2},
  [15005] = {.lex_state = 24, .external_lex_state = 2},
  [15006] = {.lex_state = 24, .external_lex_state = 2},
  [15007] = {.lex_state = 24, .external_lex_state = 2},
  [15008] = {.lex_state = 437, .external_lex_state = 2},
  [15009] = {.lex_state = 11, .external_lex_state = 2},
  [15010] = {.lex_state = 24, .external_lex_state = 2},
  [15011] = {.lex_state = 6, .external_lex_state = 2},
  [15012] = {.lex_state = 24, .external_lex_state = 2},
  [15013] = {.lex_state = 6, .external_lex_state = 2},
  [15014] = {.lex_state = 6, .external_lex_state = 2},
  [15015] = {.lex_state = 24, .external_lex_state = 2},
  [15016] = {.lex_state = 232, .external_lex_state = 2},
  [15017] = {.lex_state = 437, .external_lex_state = 2},
  [15018] = {.lex_state = 24, .external_lex_state = 2},
  [15019] = {.lex_state = 24, .external_lex_state = 2},
  [15020] = {.lex_state = 24, .external_lex_state = 2},
  [15021] = {.lex_state = 24, .external_lex_state = 2},
  [15022] = {.lex_state = 24, .external_lex_state = 2},
  [15023] = {.lex_state = 24, .external_lex_state = 2},
  [15024] = {.lex_state = 24, .external_lex_state = 2},
  [15025] = {.lex_state = 6, .external_lex_state = 2},
  [15026] = {.lex_state = 24, .external_lex_state = 2},
  [15027] = {.lex_state = 24, .external_lex_state = 2},
  [15028] = {.lex_state = 6, .external_lex_state = 2},
  [15029] = {.lex_state = 6, .external_lex_state = 2},
  [15030] = {.lex_state = 6, .external_lex_state = 2},
  [15031] = {.lex_state = 24, .external_lex_state = 2},
  [15032] = {.lex_state = 24, .external_lex_state = 2},
  [15033] = {.lex_state = 24, .external_lex_state = 2},
  [15034] = {.lex_state = 24, .external_lex_state = 2},
  [15035] = {.lex_state = 24, .external_lex_state = 2},
  [15036] = {.lex_state = 6, .external_lex_state = 2},
  [15037] = {.lex_state = 24, .external_lex_state = 2},
  [15038] = {.lex_state = 24, .external_lex_state = 2},
  [15039] = {.lex_state = 24, .external_lex_state = 2},
  [15040] = {.lex_state = 24, .external_lex_state = 2},
  [15041] = {.lex_state = 6, .external_lex_state = 2},
  [15042] = {.lex_state = 24, .external_lex_state = 2},
  [15043] = {.lex_state = 24, .external_lex_state = 2},
  [15044] = {.lex_state = 24, .external_lex_state = 2},
  [15045] = {.lex_state = 24, .external_lex_state = 2},
  [15046] = {.lex_state = 437, .external_lex_state = 2},
  [15047] = {.lex_state = 11, .external_lex_state = 2},
  [15048] = {.lex_state = 6, .external_lex_state = 2},
  [15049] = {.lex_state = 437, .external_lex_state = 2},
  [15050] = {.lex_state = 24, .external_lex_state = 2},
  [15051] = {.lex_state = 24, .external_lex_state = 2},
  [15052] = {.lex_state = 24, .external_lex_state = 2},
  [15053] = {.lex_state = 6, .external_lex_state = 2},
  [15054] = {.lex_state = 437, .external_lex_state = 2},
  [15055] = {.lex_state = 24, .external_lex_state = 2},
  [15056] = {.lex_state = 24, .external_lex_state = 2},
  [15057] = {.lex_state = 24, .external_lex_state = 2},
  [15058] = {.lex_state = 24, .external_lex_state = 2},
  [15059] = {.lex_state = 24, .external_lex_state = 2},
  [15060] = {.lex_state = 6, .external_lex_state = 2},
  [15061] = {.lex_state = 437, .external_lex_state = 2},
  [15062] = {.lex_state = 24, .external_lex_state = 2},
  [15063] = {.lex_state = 24, .external_lex_state = 2},
  [15064] = {.lex_state = 6, .external_lex_state = 2},
  [15065] = {.lex_state = 6, .external_lex_state = 2},
  [15066] = {.lex_state = 24, .external_lex_state = 2},
  [15067] = {.lex_state = 24, .external_lex_state = 2},
  [15068] = {.lex_state = 6, .external_lex_state = 2},
  [15069] = {.lex_state = 11, .external_lex_state = 2},
  [15070] = {.lex_state = 24, .external_lex_state = 2},
  [15071] = {.lex_state = 32, .external_lex_state = 2},
  [15072] = {.lex_state = 437, .external_lex_state = 2},
  [15073] = {.lex_state = 24, .external_lex_state = 2},
  [15074] = {.lex_state = 24, .external_lex_state = 2},
  [15075] = {.lex_state = 24, .external_lex_state = 2},
  [15076] = {.lex_state = 24, .external_lex_state = 2},
  [15077] = {.lex_state = 24, .external_lex_state = 2},
  [15078] = {.lex_state = 24, .external_lex_state = 2},
  [15079] = {.lex_state = 24, .external_lex_state = 2},
  [15080] = {.lex_state = 32, .external_lex_state = 2},
  [15081] = {.lex_state = 6, .external_lex_state = 2},
  [15082] = {.lex_state = 24, .external_lex_state = 2},
  [15083] = {.lex_state = 24, .external_lex_state = 2},
  [15084] = {.lex_state = 24, .external_lex_state = 2},
  [15085] = {.lex_state = 6, .external_lex_state = 2},
  [15086] = {.lex_state = 437, .external_lex_state = 2},
  [15087] = {.lex_state = 24, .external_lex_state = 2},
  [15088] = {.lex_state = 6, .external_lex_state = 2},
  [15089] = {.lex_state = 24, .external_lex_state = 2},
  [15090] = {.lex_state = 24, .external_lex_state = 2},
  [15091] = {.lex_state = 11, .external_lex_state = 2},
  [15092] = {.lex_state = 24, .external_lex_state = 2},
  [15093] = {.lex_state = 10, .external_lex_state = 2},
  [15094] = {.lex_state = 6, .external_lex_state = 2},
  [15095] = {.lex_state = 24, .external_lex_state = 2},
  [15096] = {.lex_state = 24, .external_lex_state = 2},
  [15097] = {.lex_state = 24, .external_lex_state = 2},
  [15098] = {.lex_state = 24, .external_lex_state = 2},
  [15099] = {.lex_state = 11, .external_lex_state = 2},
  [15100] = {.lex_state = 24, .external_lex_state = 2},
  [15101] = {.lex_state = 24, .external_lex_state = 2},
  [15102] = {.lex_state = 6, .external_lex_state = 2},
  [15103] = {.lex_state = 6, .external_lex_state = 2},
  [15104] = {.lex_state = 11, .external_lex_state = 2},
  [15105] = {.lex_state = 24, .external_lex_state = 2},
  [15106] = {.lex_state = 6, .external_lex_state = 2},
  [15107] = {.lex_state = 24, .external_lex_state = 2},
  [15108] = {.lex_state = 24, .external_lex_state = 2},
  [15109] = {.lex_state = 6, .external_lex_state = 2},
  [15110] = {.lex_state = 6, .external_lex_state = 2},
  [15111] = {.lex_state = 437, .external_lex_state = 2},
  [15112] = {.lex_state = 6, .external_lex_state = 2},
  [15113] = {.lex_state = 24, .external_lex_state = 2},
  [15114] = {.lex_state = 24, .external_lex_state = 2},
  [15115] = {.lex_state = 24, .external_lex_state = 2},
  [15116] = {.lex_state = 437, .external_lex_state = 2},
  [15117] = {.lex_state = 24, .external_lex_state = 2},
  [15118] = {.lex_state = 24, .external_lex_state = 2},
  [15119] = {.lex_state = 24, .external_lex_state = 2},
  [15120] = {.lex_state = 445, .external_lex_state = 2},
  [15121] = {.lex_state = 445, .external_lex_state = 2},
  [15122] = {.lex_state = 24, .external_lex_state = 2},
  [15123] = {.lex_state = 6, .external_lex_state = 2},
  [15124] = {.lex_state = 8, .external_lex_state = 2},
  [15125] = {.lex_state = 24, .external_lex_state = 2},
  [15126] = {.lex_state = 445, .external_lex_state = 2},
  [15127] = {.lex_state = 437, .external_lex_state = 2},
  [15128] = {.lex_state = 6, .external_lex_state = 2},
  [15129] = {.lex_state = 24, .external_lex_state = 2},
  [15130] = {.lex_state = 437, .external_lex_state = 2},
  [15131] = {.lex_state = 24, .external_lex_state = 2},
  [15132] = {.lex_state = 24, .external_lex_state = 2},
  [15133] = {.lex_state = 24, .external_lex_state = 2},
  [15134] = {.lex_state = 24, .external_lex_state = 2},
  [15135] = {.lex_state = 24, .external_lex_state = 2},
  [15136] = {.lex_state = 24, .external_lex_state = 2},
  [15137] = {.lex_state = 437, .external_lex_state = 2},
  [15138] = {.lex_state = 437, .external_lex_state = 2},
  [15139] = {.lex_state = 24, .external_lex_state = 2},
  [15140] = {.lex_state = 24, .external_lex_state = 2},
  [15141] = {.lex_state = 6, .external_lex_state = 2},
  [15142] = {.lex_state = 437, .external_lex_state = 2},
  [15143] = {.lex_state = 43, .external_lex_state = 2},
  [15144] = {.lex_state = 437, .external_lex_state = 2},
  [15145] = {.lex_state = 24, .external_lex_state = 2},
  [15146] = {.lex_state = 6, .external_lex_state = 2},
  [15147] = {.lex_state = 437, .external_lex_state = 2},
  [15148] = {.lex_state = 43, .external_lex_state = 2},
  [15149] = {.lex_state = 24, .external_lex_state = 2},
  [15150] = {.lex_state = 24, .external_lex_state = 2},
  [15151] = {.lex_state = 6, .external_lex_state = 2},
  [15152] = {.lex_state = 6, .external_lex_state = 2},
  [15153] = {.lex_state = 6, .external_lex_state = 2},
  [15154] = {.lex_state = 437, .external_lex_state = 2},
  [15155] = {.lex_state = 11, .external_lex_state = 2},
  [15156] = {.lex_state = 11, .external_lex_state = 2},
  [15157] = {.lex_state = 24, .external_lex_state = 2},
  [15158] = {.lex_state = 445, .external_lex_state = 2},
  [15159] = {.lex_state = 24, .external_lex_state = 2},
  [15160] = {.lex_state = 6, .external_lex_state = 2},
  [15161] = {.lex_state = 6, .external_lex_state = 2},
  [15162] = {.lex_state = 437, .external_lex_state = 2},
  [15163] = {.lex_state = 232, .external_lex_state = 2},
  [15164] = {.lex_state = 24, .external_lex_state = 2},
  [15165] = {.lex_state = 6, .external_lex_state = 2},
  [15166] = {.lex_state = 24, .external_lex_state = 2},
  [15167] = {.lex_state = 24, .external_lex_state = 2},
  [15168] = {.lex_state = 6, .external_lex_state = 2},
  [15169] = {.lex_state = 24, .external_lex_state = 2},
  [15170] = {.lex_state = 6, .external_lex_state = 2},
  [15171] = {.lex_state = 24, .external_lex_state = 2},
  [15172] = {.lex_state = 24, .external_lex_state = 2},
  [15173] = {.lex_state = 32, .external_lex_state = 2},
  [15174] = {.lex_state = 24, .external_lex_state = 2},
  [15175] = {.lex_state = 43, .external_lex_state = 2},
  [15176] = {.lex_state = 24, .external_lex_state = 2},
  [15177] = {.lex_state = 24, .external_lex_state = 2},
  [15178] = {.lex_state = 24, .external_lex_state = 2},
  [15179] = {.lex_state = 6, .external_lex_state = 2},
  [15180] = {.lex_state = 24, .external_lex_state = 2},
  [15181] = {.lex_state = 24, .external_lex_state = 2},
  [15182] = {.lex_state = 437, .external_lex_state = 2},
  [15183] = {.lex_state = 232, .external_lex_state = 2},
  [15184] = {.lex_state = 437, .external_lex_state = 2},
  [15185] = {.lex_state = 437, .external_lex_state = 2},
  [15186] = {.lex_state = 6, .external_lex_state = 2},
  [15187] = {.lex_state = 24, .external_lex_state = 2},
  [15188] = {.lex_state = 24, .external_lex_state = 2},
  [15189] = {.lex_state = 11, .external_lex_state = 2},
  [15190] = {.lex_state = 24, .external_lex_state = 2},
  [15191] = {.lex_state = 437, .external_lex_state = 2},
  [15192] = {.lex_state = 6, .external_lex_state = 2},
  [15193] = {.lex_state = 24, .external_lex_state = 2},
  [15194] = {.lex_state = 24, .external_lex_state = 2},
  [15195] = {.lex_state = 437, .external_lex_state = 2},
  [15196] = {.lex_state = 11, .external_lex_state = 2},
  [15197] = {.lex_state = 24, .external_lex_state = 2},
  [15198] = {.lex_state = 24, .external_lex_state = 2},
  [15199] = {.lex_state = 24, .external_lex_state = 2},
  [15200] = {.lex_state = 32, .external_lex_state = 2},
  [15201] = {.lex_state = 24, .external_lex_state = 2},
  [15202] = {.lex_state = 24, .external_lex_state = 2},
  [15203] = {.lex_state = 24, .external_lex_state = 2},
  [15204] = {.lex_state = 437, .external_lex_state = 2},
  [15205] = {.lex_state = 24, .external_lex_state = 2},
  [15206] = {.lex_state = 6, .external_lex_state = 2},
  [15207] = {.lex_state = 437, .external_lex_state = 2},
  [15208] = {.lex_state = 32, .external_lex_state = 2},
  [15209] = {.lex_state = 437, .external_lex_state = 2},
  [15210] = {.lex_state = 6, .external_lex_state = 2},
  [15211] = {.lex_state = 437, .external_lex_state = 2},
  [15212] = {.lex_state = 6, .external_lex_state = 2},
  [15213] = {.lex_state = 437, .external_lex_state = 2},
  [15214] = {.lex_state = 24, .external_lex_state = 2},
  [15215] = {.lex_state = 24, .external_lex_state = 2},
  [15216] = {.lex_state = 24, .external_lex_state = 2},
  [15217] = {.lex_state = 24, .external_lex_state = 2},
  [15218] = {.lex_state = 24, .external_lex_state = 2},
  [15219] = {.lex_state = 24, .external_lex_state = 2},
  [15220] = {.lex_state = 437, .external_lex_state = 2},
  [15221] = {.lex_state = 32, .external_lex_state = 2},
  [15222] = {.lex_state = 32, .external_lex_state = 2},
  [15223] = {.lex_state = 6, .external_lex_state = 2},
  [15224] = {.lex_state = 437, .external_lex_state = 2},
  [15225] = {.lex_state = 437, .external_lex_state = 2},
  [15226] = {.lex_state = 437, .external_lex_state = 2},
  [15227] = {.lex_state = 6, .external_lex_state = 2},
  [15228] = {.lex_state = 24, .external_lex_state = 2},
  [15229] = {.lex_state = 24, .external_lex_state = 2},
  [15230] = {.lex_state = 437, .external_lex_state = 2},
  [15231] = {.lex_state = 24, .external_lex_state = 2},
  [15232] = {.lex_state = 437, .external_lex_state = 2},
  [15233] = {.lex_state = 24, .external_lex_state = 2},
  [15234] = {.lex_state = 437, .external_lex_state = 2},
  [15235] = {.lex_state = 24, .external_lex_state = 2},
  [15236] = {.lex_state = 437, .external_lex_state = 2},
  [15237] = {.lex_state = 24, .external_lex_state = 2},
  [15238] = {.lex_state = 6, .external_lex_state = 2},
  [15239] = {.lex_state = 32, .external_lex_state = 2},
  [15240] = {.lex_state = 6, .external_lex_state = 2},
  [15241] = {.lex_state = 437, .external_lex_state = 2},
  [15242] = {.lex_state = 24, .external_lex_state = 2},
  [15243] = {.lex_state = 24, .external_lex_state = 2},
  [15244] = {.lex_state = 32, .external_lex_state = 2},
  [15245] = {.lex_state = 437, .external_lex_state = 2},
  [15246] = {.lex_state = 6, .external_lex_state = 2},
  [15247] = {.lex_state = 6, .external_lex_state = 2},
  [15248] = {.lex_state = 32, .external_lex_state = 2},
  [15249] = {.lex_state = 32, .external_lex_state = 2},
  [15250] = {.lex_state = 6, .external_lex_state = 2},
  [15251] = {.lex_state = 24, .external_lex_state = 2},
  [15252] = {.lex_state = 6, .external_lex_state = 2},
  [15253] = {.lex_state = 24, .external_lex_state = 2},
  [15254] = {.lex_state = 32, .external_lex_state = 2},
  [15255] = {.lex_state = 437, .external_lex_state = 2},
  [15256] = {.lex_state = 437, .external_lex_state = 2},
  [15257] = {.lex_state = 6, .external_lex_state = 2},
  [15258] = {.lex_state = 437, .external_lex_state = 2},
  [15259] = {.lex_state = 6, .external_lex_state = 2},
  [15260] = {.lex_state = 24, .external_lex_state = 2},
  [15261] = {.lex_state = 22, .external_lex_state = 2},
  [15262] = {.lex_state = 437, .external_lex_state = 2},
  [15263] = {.lex_state = 437, .external_lex_state = 2},
  [15264] = {.lex_state = 6, .external_lex_state = 2},
  [15265] = {.lex_state = 24, .external_lex_state = 2},
  [15266] = {.lex_state = 24, .external_lex_state = 2},
  [15267] = {.lex_state = 24, .external_lex_state = 2},
  [15268] = {.lex_state = 24, .external_lex_state = 2},
  [15269] = {.lex_state = 24, .external_lex_state = 2},
  [15270] = {.lex_state = 24, .external_lex_state = 2},
  [15271] = {.lex_state = 24, .external_lex_state = 2},
  [15272] = {.lex_state = 32, .external_lex_state = 2},
  [15273] = {.lex_state = 32, .external_lex_state = 2},
  [15274] = {.lex_state = 24, .external_lex_state = 2},
  [15275] = {.lex_state = 437, .external_lex_state = 2},
  [15276] = {.lex_state = 24, .external_lex_state = 2},
  [15277] = {.lex_state = 6, .external_lex_state = 2},
  [15278] = {.lex_state = 6, .external_lex_state = 2},
  [15279] = {.lex_state = 437, .external_lex_state = 2},
  [15280] = {.lex_state = 6, .external_lex_state = 2},
  [15281] = {.lex_state = 24, .external_lex_state = 2},
  [15282] = {.lex_state = 24, .external_lex_state = 2},
  [15283] = {.lex_state = 24, .external_lex_state = 2},
  [15284] = {.lex_state = 437, .external_lex_state = 2},
  [15285] = {.lex_state = 6, .external_lex_state = 2},
  [15286] = {.lex_state = 24, .external_lex_state = 2},
  [15287] = {.lex_state = 32, .external_lex_state = 2},
  [15288] = {.lex_state = 6, .external_lex_state = 2},
  [15289] = {.lex_state = 24, .external_lex_state = 2},
  [15290] = {.lex_state = 24, .external_lex_state = 2},
  [15291] = {.lex_state = 24, .external_lex_state = 2},
  [15292] = {.lex_state = 24, .external_lex_state = 2},
  [15293] = {.lex_state = 437, .external_lex_state = 2},
  [15294] = {.lex_state = 32, .external_lex_state = 2},
  [15295] = {.lex_state = 6, .external_lex_state = 2},
  [15296] = {.lex_state = 32, .external_lex_state = 2},
  [15297] = {.lex_state = 437, .external_lex_state = 2},
  [15298] = {.lex_state = 6, .external_lex_state = 2},
  [15299] = {.lex_state = 32, .external_lex_state = 2},
  [15300] = {.lex_state = 32, .external_lex_state = 2},
  [15301] = {.lex_state = 6, .external_lex_state = 2},
  [15302] = {.lex_state = 32, .external_lex_state = 2},
  [15303] = {.lex_state = 6, .external_lex_state = 2},
  [15304] = {.lex_state = 24, .external_lex_state = 2},
  [15305] = {.lex_state = 24, .external_lex_state = 2},
  [15306] = {.lex_state = 437, .external_lex_state = 2},
  [15307] = {.lex_state = 32, .external_lex_state = 2},
  [15308] = {.lex_state = 437, .external_lex_state = 2},
  [15309] = {.lex_state = 437, .external_lex_state = 2},
  [15310] = {.lex_state = 437, .external_lex_state = 2},
  [15311] = {.lex_state = 32, .external_lex_state = 2},
  [15312] = {.lex_state = 6, .external_lex_state = 2},
  [15313] = {.lex_state = 437, .external_lex_state = 2},
  [15314] = {.lex_state = 437, .external_lex_state = 2},
  [15315] = {.lex_state = 6, .external_lex_state = 2},
  [15316] = {.lex_state = 437, .external_lex_state = 2},
  [15317] = {.lex_state = 24, .external_lex_state = 2},
  [15318] = {.lex_state = 24, .external_lex_state = 2},
  [15319] = {.lex_state = 437, .external_lex_state = 2},
  [15320] = {.lex_state = 437, .external_lex_state = 2},
  [15321] = {.lex_state = 437, .external_lex_state = 2},
  [15322] = {.lex_state = 24, .external_lex_state = 2},
  [15323] = {.lex_state = 24, .external_lex_state = 2},
  [15324] = {.lex_state = 6, .external_lex_state = 2},
  [15325] = {.lex_state = 24, .external_lex_state = 2},
  [15326] = {.lex_state = 24, .external_lex_state = 2},
  [15327] = {.lex_state = 24, .external_lex_state = 2},
  [15328] = {.lex_state = 6, .external_lex_state = 2},
  [15329] = {.lex_state = 265, .external_lex_state = 8},
  [15330] = {.lex_state = 6, .external_lex_state = 2},
  [15331] = {.lex_state = 437, .external_lex_state = 2},
  [15332] = {.lex_state = 24, .external_lex_state = 2},
  [15333] = {.lex_state = 437, .external_lex_state = 2},
  [15334] = {.lex_state = 437, .external_lex_state = 2},
  [15335] = {.lex_state = 437, .external_lex_state = 2},
  [15336] = {.lex_state = 24, .external_lex_state = 2},
  [15337] = {.lex_state = 11, .external_lex_state = 2},
  [15338] = {.lex_state = 437, .external_lex_state = 2},
  [15339] = {.lex_state = 6, .external_lex_state = 2},
  [15340] = {.lex_state = 437, .external_lex_state = 2},
  [15341] = {.lex_state = 6, .external_lex_state = 2},
  [15342] = {.lex_state = 6, .external_lex_state = 2},
  [15343] = {.lex_state = 437, .external_lex_state = 2},
  [15344] = {.lex_state = 24, .external_lex_state = 2},
  [15345] = {.lex_state = 32, .external_lex_state = 2},
  [15346] = {.lex_state = 24, .external_lex_state = 2},
  [15347] = {.lex_state = 6, .external_lex_state = 2},
  [15348] = {.lex_state = 24, .external_lex_state = 2},
  [15349] = {.lex_state = 6, .external_lex_state = 2},
  [15350] = {.lex_state = 6, .external_lex_state = 2},
  [15351] = {.lex_state = 24, .external_lex_state = 2},
  [15352] = {.lex_state = 437, .external_lex_state = 2},
  [15353] = {.lex_state = 24, .external_lex_state = 2},
  [15354] = {.lex_state = 32, .external_lex_state = 2},
  [15355] = {.lex_state = 24, .external_lex_state = 2},
  [15356] = {.lex_state = 32, .external_lex_state = 2},
  [15357] = {.lex_state = 437, .external_lex_state = 2},
  [15358] = {.lex_state = 24, .external_lex_state = 2},
  [15359] = {.lex_state = 24, .external_lex_state = 2},
  [15360] = {.lex_state = 32, .external_lex_state = 2},
  [15361] = {.lex_state = 6, .external_lex_state = 2},
  [15362] = {.lex_state = 6, .external_lex_state = 2},
  [15363] = {.lex_state = 6, .external_lex_state = 2},
  [15364] = {.lex_state = 24, .external_lex_state = 2},
  [15365] = {.lex_state = 32, .external_lex_state = 2},
  [15366] = {.lex_state = 437, .external_lex_state = 2},
  [15367] = {.lex_state = 216, .external_lex_state = 2},
  [15368] = {.lex_state = 24, .external_lex_state = 2},
  [15369] = {.lex_state = 8, .external_lex_state = 2},
  [15370] = {.lex_state = 265, .external_lex_state = 8},
  [15371] = {.lex_state = 6, .external_lex_state = 2},
  [15372] = {.lex_state = 437, .external_lex_state = 2},
  [15373] = {.lex_state = 24, .external_lex_state = 2},
  [15374] = {.lex_state = 437, .external_lex_state = 2},
  [15375] = {.lex_state = 437, .external_lex_state = 2},
  [15376] = {.lex_state = 24, .external_lex_state = 2},
  [15377] = {.lex_state = 24, .external_lex_state = 2},
  [15378] = {.lex_state = 24, .external_lex_state = 2},
  [15379] = {.lex_state = 24, .external_lex_state = 2},
  [15380] = {.lex_state = 32, .external_lex_state = 2},
  [15381] = {.lex_state = 10, .external_lex_state = 2},
  [15382] = {.lex_state = 32, .external_lex_state = 2},
  [15383] = {.lex_state = 24, .external_lex_state = 2},
  [15384] = {.lex_state = 437, .external_lex_state = 2},
  [15385] = {.lex_state = 437, .external_lex_state = 2},
  [15386] = {.lex_state = 437, .external_lex_state = 2},
  [15387] = {.lex_state = 24, .external_lex_state = 2},
  [15388] = {.lex_state = 24, .external_lex_state = 2},
  [15389] = {.lex_state = 24, .external_lex_state = 2},
  [15390] = {.lex_state = 32, .external_lex_state = 2},
  [15391] = {.lex_state = 32, .external_lex_state = 2},
  [15392] = {.lex_state = 24, .external_lex_state = 2},
  [15393] = {.lex_state = 32, .external_lex_state = 2},
  [15394] = {.lex_state = 6, .external_lex_state = 2},
  [15395] = {.lex_state = 437, .external_lex_state = 2},
  [15396] = {.lex_state = 24, .external_lex_state = 2},
  [15397] = {.lex_state = 24, .external_lex_state = 2},
  [15398] = {.lex_state = 8, .external_lex_state = 2},
  [15399] = {.lex_state = 24, .external_lex_state = 2},
  [15400] = {.lex_state = 6, .external_lex_state = 2},
  [15401] = {.lex_state = 24, .external_lex_state = 2},
  [15402] = {.lex_state = 32, .external_lex_state = 2},
  [15403] = {.lex_state = 11, .external_lex_state = 2},
  [15404] = {.lex_state = 11, .external_lex_state = 2},
  [15405] = {.lex_state = 32, .external_lex_state = 2},
  [15406] = {.lex_state = 32, .external_lex_state = 2},
  [15407] = {.lex_state = 32, .external_lex_state = 2},
  [15408] = {.lex_state = 437, .external_lex_state = 2},
  [15409] = {.lex_state = 6, .external_lex_state = 2},
  [15410] = {.lex_state = 24, .external_lex_state = 2},
  [15411] = {.lex_state = 24, .external_lex_state = 2},
  [15412] = {.lex_state = 24, .external_lex_state = 2},
  [15413] = {.lex_state = 32, .external_lex_state = 2},
  [15414] = {.lex_state = 437, .external_lex_state = 2},
  [15415] = {.lex_state = 24, .external_lex_state = 2},
  [15416] = {.lex_state = 437, .external_lex_state = 2},
  [15417] = {.lex_state = 437, .external_lex_state = 2},
  [15418] = {.lex_state = 24, .external_lex_state = 2},
  [15419] = {.lex_state = 24, .external_lex_state = 2},
  [15420] = {.lex_state = 437, .external_lex_state = 2},
  [15421] = {.lex_state = 437, .external_lex_state = 2},
  [15422] = {.lex_state = 11, .external_lex_state = 2},
  [15423] = {.lex_state = 24, .external_lex_state = 2},
  [15424] = {.lex_state = 24, .external_lex_state = 2},
  [15425] = {.lex_state = 24, .external_lex_state = 2},
  [15426] = {.lex_state = 24, .external_lex_state = 2},
  [15427] = {.lex_state = 24, .external_lex_state = 2},
  [15428] = {.lex_state = 24, .external_lex_state = 2},
  [15429] = {.lex_state = 437, .external_lex_state = 2},
  [15430] = {.lex_state = 437, .external_lex_state = 2},
  [15431] = {.lex_state = 32, .external_lex_state = 2},
  [15432] = {.lex_state = 32, .external_lex_state = 2},
  [15433] = {.lex_state = 24, .external_lex_state = 2},
  [15434] = {.lex_state = 32, .external_lex_state = 2},
  [15435] = {.lex_state = 8, .external_lex_state = 2},
  [15436] = {.lex_state = 24, .external_lex_state = 2},
  [15437] = {.lex_state = 24, .external_lex_state = 2},
  [15438] = {.lex_state = 24, .external_lex_state = 2},
  [15439] = {.lex_state = 265, .external_lex_state = 8},
  [15440] = {.lex_state = 22, .external_lex_state = 2},
  [15441] = {.lex_state = 24, .external_lex_state = 2},
  [15442] = {.lex_state = 32, .external_lex_state = 2},
  [15443] = {.lex_state = 24, .external_lex_state = 2},
  [15444] = {.lex_state = 24, .external_lex_state = 2},
  [15445] = {.lex_state = 32, .external_lex_state = 2},
  [15446] = {.lex_state = 437, .external_lex_state = 2},
  [15447] = {.lex_state = 24, .external_lex_state = 2},
  [15448] = {.lex_state = 6, .external_lex_state = 2},
  [15449] = {.lex_state = 32, .external_lex_state = 2},
  [15450] = {.lex_state = 32, .external_lex_state = 2},
  [15451] = {.lex_state = 6, .external_lex_state = 2},
  [15452] = {.lex_state = 6, .external_lex_state = 2},
  [15453] = {.lex_state = 32, .external_lex_state = 2},
  [15454] = {.lex_state = 437, .external_lex_state = 2},
  [15455] = {.lex_state = 437, .external_lex_state = 2},
  [15456] = {.lex_state = 437, .external_lex_state = 2},
  [15457] = {.lex_state = 24, .external_lex_state = 2},
  [15458] = {.lex_state = 24, .external_lex_state = 2},
  [15459] = {.lex_state = 24, .external_lex_state = 2},
  [15460] = {.lex_state = 24, .external_lex_state = 2},
  [15461] = {.lex_state = 437, .external_lex_state = 2},
  [15462] = {.lex_state = 437, .external_lex_state = 2},
  [15463] = {.lex_state = 24, .external_lex_state = 2},
  [15464] = {.lex_state = 24, .external_lex_state = 2},
  [15465] = {.lex_state = 8, .external_lex_state = 2},
  [15466] = {.lex_state = 437, .external_lex_state = 2},
  [15467] = {.lex_state = 24, .external_lex_state = 2},
  [15468] = {.lex_state = 24, .external_lex_state = 2},
  [15469] = {.lex_state = 437, .external_lex_state = 2},
  [15470] = {.lex_state = 24, .external_lex_state = 2},
  [15471] = {.lex_state = 437, .external_lex_state = 2},
  [15472] = {.lex_state = 22, .external_lex_state = 2},
  [15473] = {.lex_state = 437, .external_lex_state = 2},
  [15474] = {.lex_state = 24, .external_lex_state = 2},
  [15475] = {.lex_state = 24, .external_lex_state = 2},
  [15476] = {.lex_state = 24, .external_lex_state = 2},
  [15477] = {.lex_state = 24, .external_lex_state = 2},
  [15478] = {.lex_state = 24, .external_lex_state = 2},
  [15479] = {.lex_state = 54, .external_lex_state = 2},
  [15480] = {.lex_state = 32, .external_lex_state = 2},
  [15481] = {.lex_state = 32, .external_lex_state = 2},
  [15482] = {.lex_state = 6, .external_lex_state = 2},
  [15483] = {.lex_state = 437, .external_lex_state = 2},
  [15484] = {.lex_state = 32, .external_lex_state = 2},
  [15485] = {.lex_state = 32, .external_lex_state = 2},
  [15486] = {.lex_state = 6, .external_lex_state = 2},
  [15487] = {.lex_state = 24, .external_lex_state = 2},
  [15488] = {.lex_state = 6, .external_lex_state = 2},
  [15489] = {.lex_state = 24, .external_lex_state = 2},
  [15490] = {.lex_state = 24, .external_lex_state = 2},
  [15491] = {.lex_state = 32, .external_lex_state = 2},
  [15492] = {.lex_state = 437, .external_lex_state = 2},
  [15493] = {.lex_state = 32, .external_lex_state = 2},
  [15494] = {.lex_state = 437, .external_lex_state = 2},
  [15495] = {.lex_state = 437, .external_lex_state = 2},
  [15496] = {.lex_state = 437, .external_lex_state = 2},
  [15497] = {.lex_state = 24, .external_lex_state = 2},
  [15498] = {.lex_state = 24, .external_lex_state = 2},
  [15499] = {.lex_state = 6, .external_lex_state = 2},
  [15500] = {.lex_state = 24, .external_lex_state = 2},
  [15501] = {.lex_state = 24, .external_lex_state = 2},
  [15502] = {.lex_state = 24, .external_lex_state = 2},
  [15503] = {.lex_state = 24, .external_lex_state = 2},
  [15504] = {.lex_state = 24, .external_lex_state = 2},
  [15505] = {.lex_state = 8, .external_lex_state = 2},
  [15506] = {.lex_state = 437, .external_lex_state = 2},
  [15507] = {.lex_state = 437, .external_lex_state = 2},
  [15508] = {.lex_state = 437, .external_lex_state = 2},
  [15509] = {.lex_state = 32, .external_lex_state = 2},
  [15510] = {.lex_state = 24, .external_lex_state = 2},
  [15511] = {.lex_state = 437, .external_lex_state = 2},
  [15512] = {.lex_state = 437, .external_lex_state = 2},
  [15513] = {.lex_state = 437, .external_lex_state = 2},
  [15514] = {.lex_state = 437, .external_lex_state = 2},
  [15515] = {.lex_state = 8, .external_lex_state = 2},
  [15516] = {.lex_state = 32, .external_lex_state = 2},
  [15517] = {.lex_state = 32, .external_lex_state = 2},
  [15518] = {.lex_state = 24, .external_lex_state = 2},
  [15519] = {.lex_state = 32, .external_lex_state = 2},
  [15520] = {.lex_state = 437, .external_lex_state = 2},
  [15521] = {.lex_state = 24, .external_lex_state = 2},
  [15522] = {.lex_state = 6, .external_lex_state = 2},
  [15523] = {.lex_state = 24, .external_lex_state = 2},
  [15524] = {.lex_state = 24, .external_lex_state = 2},
  [15525] = {.lex_state = 24, .external_lex_state = 2},
  [15526] = {.lex_state = 32, .external_lex_state = 2},
  [15527] = {.lex_state = 32, .external_lex_state = 2},
  [15528] = {.lex_state = 32, .external_lex_state = 2},
  [15529] = {.lex_state = 24, .external_lex_state = 2},
  [15530] = {.lex_state = 24, .external_lex_state = 2},
  [15531] = {.lex_state = 6, .external_lex_state = 2},
  [15532] = {.lex_state = 11, .external_lex_state = 2},
  [15533] = {.lex_state = 6, .external_lex_state = 2},
  [15534] = {.lex_state = 32, .external_lex_state = 2},
  [15535] = {.lex_state = 437, .external_lex_state = 2},
  [15536] = {.lex_state = 6, .external_lex_state = 2},
  [15537] = {.lex_state = 437, .external_lex_state = 2},
  [15538] = {.lex_state = 32, .external_lex_state = 2},
  [15539] = {.lex_state = 24, .external_lex_state = 2},
  [15540] = {.lex_state = 437, .external_lex_state = 2},
  [15541] = {.lex_state = 24, .external_lex_state = 2},
  [15542] = {.lex_state = 437, .external_lex_state = 2},
  [15543] = {.lex_state = 11, .external_lex_state = 2},
  [15544] = {.lex_state = 24, .external_lex_state = 2},
  [15545] = {.lex_state = 32, .external_lex_state = 2},
  [15546] = {.lex_state = 32, .external_lex_state = 2},
  [15547] = {.lex_state = 24, .external_lex_state = 2},
  [15548] = {.lex_state = 6, .external_lex_state = 2},
  [15549] = {.lex_state = 24, .external_lex_state = 2},
  [15550] = {.lex_state = 24, .external_lex_state = 2},
  [15551] = {.lex_state = 24, .external_lex_state = 2},
  [15552] = {.lex_state = 32, .external_lex_state = 2},
  [15553] = {.lex_state = 437, .external_lex_state = 2},
  [15554] = {.lex_state = 437, .external_lex_state = 2},
  [15555] = {.lex_state = 24, .external_lex_state = 2},
  [15556] = {.lex_state = 32, .external_lex_state = 2},
  [15557] = {.lex_state = 437, .external_lex_state = 2},
  [15558] = {.lex_state = 32, .external_lex_state = 2},
  [15559] = {.lex_state = 32, .external_lex_state = 2},
  [15560] = {.lex_state = 437, .external_lex_state = 2},
  [15561] = {.lex_state = 24, .external_lex_state = 2},
  [15562] = {.lex_state = 24, .external_lex_state = 2},
  [15563] = {.lex_state = 24, .external_lex_state = 2},
  [15564] = {.lex_state = 24, .external_lex_state = 2},
  [15565] = {.lex_state = 437, .external_lex_state = 2},
  [15566] = {.lex_state = 24, .external_lex_state = 2},
  [15567] = {.lex_state = 32, .external_lex_state = 2},
  [15568] = {.lex_state = 24, .external_lex_state = 2},
  [15569] = {.lex_state = 24, .external_lex_state = 2},
  [15570] = {.lex_state = 24, .external_lex_state = 2},
  [15571] = {.lex_state = 437, .external_lex_state = 2},
  [15572] = {.lex_state = 6, .external_lex_state = 2},
  [15573] = {.lex_state = 437, .external_lex_state = 2},
  [15574] = {.lex_state = 32, .external_lex_state = 2},
  [15575] = {.lex_state = 32, .external_lex_state = 2},
  [15576] = {.lex_state = 22, .external_lex_state = 2},
  [15577] = {.lex_state = 24, .external_lex_state = 2},
  [15578] = {.lex_state = 437, .external_lex_state = 2},
  [15579] = {.lex_state = 24, .external_lex_state = 2},
  [15580] = {.lex_state = 6, .external_lex_state = 2},
  [15581] = {.lex_state = 22, .external_lex_state = 2},
  [15582] = {.lex_state = 24, .external_lex_state = 2},
  [15583] = {.lex_state = 24, .external_lex_state = 2},
  [15584] = {.lex_state = 24, .external_lex_state = 2},
  [15585] = {.lex_state = 32, .external_lex_state = 2},
  [15586] = {.lex_state = 437, .external_lex_state = 2},
  [15587] = {.lex_state = 437, .external_lex_state = 2},
  [15588] = {.lex_state = 32, .external_lex_state = 2},
  [15589] = {.lex_state = 32, .external_lex_state = 2},
  [15590] = {.lex_state = 24, .external_lex_state = 2},
  [15591] = {.lex_state = 437, .external_lex_state = 2},
  [15592] = {.lex_state = 24, .external_lex_state = 2},
  [15593] = {.lex_state = 6, .external_lex_state = 2},
  [15594] = {.lex_state = 437, .external_lex_state = 2},
  [15595] = {.lex_state = 24, .external_lex_state = 2},
  [15596] = {.lex_state = 24, .external_lex_state = 2},
  [15597] = {.lex_state = 437, .external_lex_state = 2},
  [15598] = {.lex_state = 24, .external_lex_state = 2},
  [15599] = {.lex_state = 24, .external_lex_state = 2},
  [15600] = {.lex_state = 24, .external_lex_state = 2},
  [15601] = {.lex_state = 24, .external_lex_state = 2},
  [15602] = {.lex_state = 24, .external_lex_state = 2},
  [15603] = {.lex_state = 24, .external_lex_state = 2},
  [15604] = {.lex_state = 24, .external_lex_state = 2},
  [15605] = {.lex_state = 24, .external_lex_state = 2},
  [15606] = {.lex_state = 24, .external_lex_state = 2},
  [15607] = {.lex_state = 24, .external_lex_state = 2},
  [15608] = {.lex_state = 24, .external_lex_state = 2},
  [15609] = {.lex_state = 24, .external_lex_state = 2},
  [15610] = {.lex_state = 24, .external_lex_state = 2},
  [15611] = {.lex_state = 32, .external_lex_state = 2},
  [15612] = {.lex_state = 32, .external_lex_state = 2},
  [15613] = {.lex_state = 437, .external_lex_state = 2},
  [15614] = {.lex_state = 6, .external_lex_state = 2},
  [15615] = {.lex_state = 24, .external_lex_state = 2},
  [15616] = {.lex_state = 8, .external_lex_state = 2},
  [15617] = {.lex_state = 216, .external_lex_state = 2},
  [15618] = {.lex_state = 6, .external_lex_state = 2},
  [15619] = {.lex_state = 437, .external_lex_state = 2},
  [15620] = {.lex_state = 24, .external_lex_state = 2},
  [15621] = {.lex_state = 24, .external_lex_state = 2},
  [15622] = {.lex_state = 32, .external_lex_state = 2},
  [15623] = {.lex_state = 32, .external_lex_state = 2},
  [15624] = {.lex_state = 437, .external_lex_state = 2},
  [15625] = {.lex_state = 6, .external_lex_state = 2},
  [15626] = {.lex_state = 437, .external_lex_state = 2},
  [15627] = {.lex_state = 437, .external_lex_state = 2},
  [15628] = {.lex_state = 32, .external_lex_state = 2},
  [15629] = {.lex_state = 437, .external_lex_state = 2},
  [15630] = {.lex_state = 24, .external_lex_state = 2},
  [15631] = {.lex_state = 24, .external_lex_state = 2},
  [15632] = {.lex_state = 437, .external_lex_state = 2},
  [15633] = {.lex_state = 24, .external_lex_state = 2},
  [15634] = {.lex_state = 437, .external_lex_state = 2},
  [15635] = {.lex_state = 32, .external_lex_state = 2},
  [15636] = {.lex_state = 437, .external_lex_state = 2},
  [15637] = {.lex_state = 24, .external_lex_state = 2},
  [15638] = {.lex_state = 6, .external_lex_state = 2},
  [15639] = {.lex_state = 24, .external_lex_state = 2},
  [15640] = {.lex_state = 437, .external_lex_state = 2},
  [15641] = {.lex_state = 32, .external_lex_state = 2},
  [15642] = {.lex_state = 437, .external_lex_state = 2},
  [15643] = {.lex_state = 11, .external_lex_state = 2},
  [15644] = {.lex_state = 437, .external_lex_state = 2},
  [15645] = {.lex_state = 32, .external_lex_state = 2},
  [15646] = {.lex_state = 32, .external_lex_state = 2},
  [15647] = {.lex_state = 24, .external_lex_state = 2},
  [15648] = {.lex_state = 6, .external_lex_state = 2},
  [15649] = {.lex_state = 24, .external_lex_state = 2},
  [15650] = {.lex_state = 7, .external_lex_state = 2},
  [15651] = {.lex_state = 32, .external_lex_state = 2},
  [15652] = {.lex_state = 437, .external_lex_state = 2},
  [15653] = {.lex_state = 6, .external_lex_state = 2},
  [15654] = {.lex_state = 437, .external_lex_state = 2},
  [15655] = {.lex_state = 437, .external_lex_state = 2},
  [15656] = {.lex_state = 24, .external_lex_state = 2},
  [15657] = {.lex_state = 24, .external_lex_state = 2},
  [15658] = {.lex_state = 437, .external_lex_state = 2},
  [15659] = {.lex_state = 6, .external_lex_state = 2},
  [15660] = {.lex_state = 437, .external_lex_state = 2},
  [15661] = {.lex_state = 437, .external_lex_state = 2},
  [15662] = {.lex_state = 8, .external_lex_state = 2},
  [15663] = {.lex_state = 24, .external_lex_state = 2},
  [15664] = {.lex_state = 24, .external_lex_state = 2},
  [15665] = {.lex_state = 24, .external_lex_state = 2},
  [15666] = {.lex_state = 24, .external_lex_state = 2},
  [15667] = {.lex_state = 24, .external_lex_state = 2},
  [15668] = {.lex_state = 22, .external_lex_state = 2},
  [15669] = {.lex_state = 24, .external_lex_state = 2},
  [15670] = {.lex_state = 24, .external_lex_state = 2},
  [15671] = {.lex_state = 437, .external_lex_state = 2},
  [15672] = {.lex_state = 24, .external_lex_state = 2},
  [15673] = {.lex_state = 437, .external_lex_state = 2},
  [15674] = {.lex_state = 437, .external_lex_state = 2},
  [15675] = {.lex_state = 22, .external_lex_state = 2},
  [15676] = {.lex_state = 6, .external_lex_state = 2},
  [15677] = {.lex_state = 22, .external_lex_state = 2},
  [15678] = {.lex_state = 24, .external_lex_state = 2},
  [15679] = {.lex_state = 32, .external_lex_state = 2},
  [15680] = {.lex_state = 6, .external_lex_state = 2},
  [15681] = {.lex_state = 24, .external_lex_state = 2},
  [15682] = {.lex_state = 24, .external_lex_state = 2},
  [15683] = {.lex_state = 24, .external_lex_state = 2},
  [15684] = {.lex_state = 6, .external_lex_state = 2},
  [15685] = {.lex_state = 24, .external_lex_state = 2},
  [15686] = {.lex_state = 24, .external_lex_state = 2},
  [15687] = {.lex_state = 24, .external_lex_state = 2},
  [15688] = {.lex_state = 24, .external_lex_state = 2},
  [15689] = {.lex_state = 24, .external_lex_state = 2},
  [15690] = {.lex_state = 24, .external_lex_state = 2},
  [15691] = {.lex_state = 6, .external_lex_state = 2},
  [15692] = {.lex_state = 24, .external_lex_state = 2},
  [15693] = {.lex_state = 24, .external_lex_state = 2},
  [15694] = {.lex_state = 437, .external_lex_state = 2},
  [15695] = {.lex_state = 437, .external_lex_state = 2},
  [15696] = {.lex_state = 24, .external_lex_state = 2},
  [15697] = {.lex_state = 24, .external_lex_state = 2},
  [15698] = {.lex_state = 437, .external_lex_state = 2},
  [15699] = {.lex_state = 437, .external_lex_state = 2},
  [15700] = {.lex_state = 437, .external_lex_state = 2},
  [15701] = {.lex_state = 24, .external_lex_state = 2},
  [15702] = {.lex_state = 32, .external_lex_state = 2},
  [15703] = {.lex_state = 32, .external_lex_state = 2},
  [15704] = {.lex_state = 24, .external_lex_state = 2},
  [15705] = {.lex_state = 24, .external_lex_state = 2},
  [15706] = {.lex_state = 437, .external_lex_state = 2},
  [15707] = {.lex_state = 437, .external_lex_state = 2},
  [15708] = {.lex_state = 24, .external_lex_state = 2},
  [15709] = {.lex_state = 32, .external_lex_state = 2},
  [15710] = {.lex_state = 24, .external_lex_state = 2},
  [15711] = {.lex_state = 6, .external_lex_state = 2},
  [15712] = {.lex_state = 24, .external_lex_state = 2},
  [15713] = {.lex_state = 6, .external_lex_state = 2},
  [15714] = {.lex_state = 24, .external_lex_state = 2},
  [15715] = {.lex_state = 32, .external_lex_state = 2},
  [15716] = {.lex_state = 6, .external_lex_state = 2},
  [15717] = {.lex_state = 6, .external_lex_state = 2},
  [15718] = {.lex_state = 24, .external_lex_state = 2},
  [15719] = {.lex_state = 24, .external_lex_state = 2},
  [15720] = {.lex_state = 32, .external_lex_state = 2},
  [15721] = {.lex_state = 437, .external_lex_state = 2},
  [15722] = {.lex_state = 32, .external_lex_state = 2},
  [15723] = {.lex_state = 32, .external_lex_state = 2},
  [15724] = {.lex_state = 24, .external_lex_state = 2},
  [15725] = {.lex_state = 32, .external_lex_state = 2},
  [15726] = {.lex_state = 32, .external_lex_state = 2},
  [15727] = {.lex_state = 24, .external_lex_state = 2},
  [15728] = {.lex_state = 437, .external_lex_state = 2},
  [15729] = {.lex_state = 32, .external_lex_state = 2},
  [15730] = {.lex_state = 32, .external_lex_state = 2},
  [15731] = {.lex_state = 32, .external_lex_state = 2},
  [15732] = {.lex_state = 8, .external_lex_state = 2},
  [15733] = {.lex_state = 10, .external_lex_state = 2},
  [15734] = {.lex_state = 437, .external_lex_state = 2},
  [15735] = {.lex_state = 437, .external_lex_state = 2},
  [15736] = {.lex_state = 6, .external_lex_state = 2},
  [15737] = {.lex_state = 8, .external_lex_state = 2},
  [15738] = {.lex_state = 32, .external_lex_state = 2},
  [15739] = {.lex_state = 32, .external_lex_state = 2},
  [15740] = {.lex_state = 437, .external_lex_state = 2},
  [15741] = {.lex_state = 24, .external_lex_state = 2},
  [15742] = {.lex_state = 24, .external_lex_state = 2},
  [15743] = {.lex_state = 24, .external_lex_state = 2},
  [15744] = {.lex_state = 24, .external_lex_state = 2},
  [15745] = {.lex_state = 6, .external_lex_state = 2},
  [15746] = {.lex_state = 24, .external_lex_state = 2},
  [15747] = {.lex_state = 24, .external_lex_state = 2},
  [15748] = {.lex_state = 32, .external_lex_state = 2},
  [15749] = {.lex_state = 6, .external_lex_state = 2},
  [15750] = {.lex_state = 24, .external_lex_state = 2},
  [15751] = {.lex_state = 32, .external_lex_state = 2},
  [15752] = {.lex_state = 32, .external_lex_state = 2},
  [15753] = {.lex_state = 24, .external_lex_state = 2},
  [15754] = {.lex_state = 437, .external_lex_state = 2},
  [15755] = {.lex_state = 437, .external_lex_state = 2},
  [15756] = {.lex_state = 6, .external_lex_state = 2},
  [15757] = {.lex_state = 24, .external_lex_state = 2},
  [15758] = {.lex_state = 10, .external_lex_state = 2},
  [15759] = {.lex_state = 24, .external_lex_state = 2},
  [15760] = {.lex_state = 437, .external_lex_state = 2},
  [15761] = {.lex_state = 24, .external_lex_state = 2},
  [15762] = {.lex_state = 24, .external_lex_state = 2},
  [15763] = {.lex_state = 24, .external_lex_state = 2},
  [15764] = {.lex_state = 24, .external_lex_state = 2},
  [15765] = {.lex_state = 24, .external_lex_state = 2},
  [15766] = {.lex_state = 437, .external_lex_state = 2},
  [15767] = {.lex_state = 437, .external_lex_state = 2},
  [15768] = {.lex_state = 32, .external_lex_state = 2},
  [15769] = {.lex_state = 24, .external_lex_state = 2},
  [15770] = {.lex_state = 24, .external_lex_state = 2},
  [15771] = {.lex_state = 437, .external_lex_state = 2},
  [15772] = {.lex_state = 24, .external_lex_state = 2},
  [15773] = {.lex_state = 24, .external_lex_state = 2},
  [15774] = {.lex_state = 24, .external_lex_state = 2},
  [15775] = {.lex_state = 24, .external_lex_state = 2},
  [15776] = {.lex_state = 22, .external_lex_state = 2},
  [15777] = {.lex_state = 10, .external_lex_state = 2},
  [15778] = {.lex_state = 24, .external_lex_state = 2},
  [15779] = {.lex_state = 24, .external_lex_state = 2},
  [15780] = {.lex_state = 32, .external_lex_state = 2},
  [15781] = {.lex_state = 24, .external_lex_state = 2},
  [15782] = {.lex_state = 24, .external_lex_state = 2},
  [15783] = {.lex_state = 6, .external_lex_state = 2},
  [15784] = {.lex_state = 10, .external_lex_state = 2},
  [15785] = {.lex_state = 24, .external_lex_state = 2},
  [15786] = {.lex_state = 32, .external_lex_state = 2},
  [15787] = {.lex_state = 6, .external_lex_state = 2},
  [15788] = {.lex_state = 24, .external_lex_state = 2},
  [15789] = {.lex_state = 24, .external_lex_state = 2},
  [15790] = {.lex_state = 10, .external_lex_state = 2},
  [15791] = {.lex_state = 24, .external_lex_state = 2},
  [15792] = {.lex_state = 10, .external_lex_state = 2},
  [15793] = {.lex_state = 24, .external_lex_state = 2},
  [15794] = {.lex_state = 10, .external_lex_state = 2},
  [15795] = {.lex_state = 24, .external_lex_state = 2},
  [15796] = {.lex_state = 24, .external_lex_state = 2},
  [15797] = {.lex_state = 10, .external_lex_state = 2},
  [15798] = {.lex_state = 24, .external_lex_state = 2},
  [15799] = {.lex_state = 24, .external_lex_state = 2},
  [15800] = {.lex_state = 10, .external_lex_state = 2},
  [15801] = {.lex_state = 24, .external_lex_state = 2},
  [15802] = {.lex_state = 437, .external_lex_state = 2},
  [15803] = {.lex_state = 10, .external_lex_state = 2},
  [15804] = {.lex_state = 24, .external_lex_state = 2},
  [15805] = {.lex_state = 437, .external_lex_state = 2},
  [15806] = {.lex_state = 10, .external_lex_state = 2},
  [15807] = {.lex_state = 24, .external_lex_state = 2},
  [15808] = {.lex_state = 10, .external_lex_state = 2},
  [15809] = {.lex_state = 10, .external_lex_state = 2},
  [15810] = {.lex_state = 24, .external_lex_state = 2},
  [15811] = {.lex_state = 437, .external_lex_state = 2},
  [15812] = {.lex_state = 10, .external_lex_state = 2},
  [15813] = {.lex_state = 437, .external_lex_state = 2},
  [15814] = {.lex_state = 10, .external_lex_state = 2},
  [15815] = {.lex_state = 24, .external_lex_state = 2},
  [15816] = {.lex_state = 10, .external_lex_state = 2},
  [15817] = {.lex_state = 437, .external_lex_state = 2},
  [15818] = {.lex_state = 24, .external_lex_state = 2},
  [15819] = {.lex_state = 10, .external_lex_state = 2},
  [15820] = {.lex_state = 24, .external_lex_state = 2},
  [15821] = {.lex_state = 10, .external_lex_state = 2},
  [15822] = {.lex_state = 32, .external_lex_state = 2},
  [15823] = {.lex_state = 10, .external_lex_state = 2},
  [15824] = {.lex_state = 10, .external_lex_state = 2},
  [15825] = {.lex_state = 10, .external_lex_state = 2},
  [15826] = {.lex_state = 6, .external_lex_state = 2},
  [15827] = {.lex_state = 10, .external_lex_state = 2},
  [15828] = {.lex_state = 437, .external_lex_state = 2},
  [15829] = {.lex_state = 10, .external_lex_state = 2},
  [15830] = {.lex_state = 10, .external_lex_state = 2},
  [15831] = {.lex_state = 10, .external_lex_state = 2},
  [15832] = {.lex_state = 10, .external_lex_state = 2},
  [15833] = {.lex_state = 32, .external_lex_state = 2},
  [15834] = {.lex_state = 32, .external_lex_state = 2},
  [15835] = {.lex_state = 10, .external_lex_state = 2},
  [15836] = {.lex_state = 10, .external_lex_state = 2},
  [15837] = {.lex_state = 6, .external_lex_state = 2},
  [15838] = {.lex_state = 10, .external_lex_state = 2},
  [15839] = {.lex_state = 10, .external_lex_state = 2},
  [15840] = {.lex_state = 6, .external_lex_state = 2},
  [15841] = {.lex_state = 10, .external_lex_state = 2},
  [15842] = {.lex_state = 10, .external_lex_state = 2},
  [15843] = {.lex_state = 32, .external_lex_state = 2},
  [15844] = {.lex_state = 437, .external_lex_state = 2},
  [15845] = {.lex_state = 10, .external_lex_state = 2},
  [15846] = {.lex_state = 24, .external_lex_state = 2},
  [15847] = {.lex_state = 10, .external_lex_state = 2},
  [15848] = {.lex_state = 10, .external_lex_state = 2},
  [15849] = {.lex_state = 437, .external_lex_state = 2},
  [15850] = {.lex_state = 10, .external_lex_state = 2},
  [15851] = {.lex_state = 437, .external_lex_state = 2},
  [15852] = {.lex_state = 437, .external_lex_state = 2},
  [15853] = {.lex_state = 10, .external_lex_state = 2},
  [15854] = {.lex_state = 437, .external_lex_state = 2},
  [15855] = {.lex_state = 6, .external_lex_state = 2},
  [15856] = {.lex_state = 10, .external_lex_state = 2},
  [15857] = {.lex_state = 10, .external_lex_state = 2},
  [15858] = {.lex_state = 10, .external_lex_state = 2},
  [15859] = {.lex_state = 24, .external_lex_state = 2},
  [15860] = {.lex_state = 24, .external_lex_state = 2},
  [15861] = {.lex_state = 10, .external_lex_state = 2},
  [15862] = {.lex_state = 24, .external_lex_state = 2},
  [15863] = {.lex_state = 24, .external_lex_state = 2},
  [15864] = {.lex_state = 24, .external_lex_state = 2},
  [15865] = {.lex_state = 8, .external_lex_state = 2},
  [15866] = {.lex_state = 24, .external_lex_state = 2},
  [15867] = {.lex_state = 24, .external_lex_state = 2},
  [15868] = {.lex_state = 32, .external_lex_state = 2},
  [15869] = {.lex_state = 24, .external_lex_state = 2},
  [15870] = {.lex_state = 445, .external_lex_state = 2},
  [15871] = {.lex_state = 24, .external_lex_state = 2},
  [15872] = {.lex_state = 24, .external_lex_state = 2},
  [15873] = {.lex_state = 437, .external_lex_state = 2},
  [15874] = {.lex_state = 437, .external_lex_state = 2},
  [15875] = {.lex_state = 437, .external_lex_state = 2},
  [15876] = {.lex_state = 32, .external_lex_state = 2},
  [15877] = {.lex_state = 6, .external_lex_state = 2},
  [15878] = {.lex_state = 437, .external_lex_state = 2},
  [15879] = {.lex_state = 22, .external_lex_state = 2},
  [15880] = {.lex_state = 8, .external_lex_state = 2},
  [15881] = {.lex_state = 24, .external_lex_state = 2},
  [15882] = {.lex_state = 437, .external_lex_state = 2},
  [15883] = {.lex_state = 24, .external_lex_state = 2},
  [15884] = {.lex_state = 32, .external_lex_state = 2},
  [15885] = {.lex_state = 32, .external_lex_state = 2},
  [15886] = {.lex_state = 32, .external_lex_state = 2},
  [15887] = {.lex_state = 24, .external_lex_state = 2},
  [15888] = {.lex_state = 32, .external_lex_state = 2},
  [15889] = {.lex_state = 437, .external_lex_state = 2},
  [15890] = {.lex_state = 24, .external_lex_state = 2},
  [15891] = {.lex_state = 24, .external_lex_state = 2},
  [15892] = {.lex_state = 6, .external_lex_state = 2},
  [15893] = {.lex_state = 24, .external_lex_state = 2},
  [15894] = {.lex_state = 32, .external_lex_state = 2},
  [15895] = {.lex_state = 32, .external_lex_state = 2},
  [15896] = {.lex_state = 32, .external_lex_state = 2},
  [15897] = {.lex_state = 24, .external_lex_state = 2},
  [15898] = {.lex_state = 24, .external_lex_state = 2},
  [15899] = {.lex_state = 32, .external_lex_state = 2},
  [15900] = {.lex_state = 32, .external_lex_state = 2},
  [15901] = {.lex_state = 32, .external_lex_state = 2},
  [15902] = {.lex_state = 24, .external_lex_state = 2},
  [15903] = {.lex_state = 32, .external_lex_state = 2},
  [15904] = {.lex_state = 24, .external_lex_state = 2},
  [15905] = {.lex_state = 437, .external_lex_state = 2},
  [15906] = {.lex_state = 24, .external_lex_state = 2},
  [15907] = {.lex_state = 6, .external_lex_state = 2},
  [15908] = {.lex_state = 24, .external_lex_state = 2},
  [15909] = {.lex_state = 24, .external_lex_state = 2},
  [15910] = {.lex_state = 437, .external_lex_state = 2},
  [15911] = {.lex_state = 43, .external_lex_state = 2},
  [15912] = {.lex_state = 54, .external_lex_state = 2},
  [15913] = {.lex_state = 445, .external_lex_state = 2},
  [15914] = {.lex_state = 32, .external_lex_state = 2},
  [15915] = {.lex_state = 32, .external_lex_state = 2},
  [15916] = {.lex_state = 144, .external_lex_state = 2},
  [15917] = {.lex_state = 144, .external_lex_state = 2},
  [15918] = {.lex_state = 54, .external_lex_state = 2},
  [15919] = {.lex_state = 43, .external_lex_state = 2},
  [15920] = {.lex_state = 43, .external_lex_state = 2},
  [15921] = {.lex_state = 54, .external_lex_state = 2},
  [15922] = {.lex_state = 43, .external_lex_state = 2},
  [15923] = {.lex_state = 24, .external_lex_state = 2},
  [15924] = {.lex_state = 54, .external_lex_state = 2},
  [15925] = {.lex_state = 437, .external_lex_state = 2},
  [15926] = {.lex_state = 54, .external_lex_state = 2},
  [15927] = {.lex_state = 54, .external_lex_state = 2},
  [15928] = {.lex_state = 54, .external_lex_state = 2},
  [15929] = {.lex_state = 259, .external_lex_state = 2},
  [15930] = {.lex_state = 437, .external_lex_state = 2},
  [15931] = {.lex_state = 445, .external_lex_state = 2},
  [15932] = {.lex_state = 54, .external_lex_state = 2},
  [15933] = {.lex_state = 32, .external_lex_state = 2},
  [15934] = {.lex_state = 32, .external_lex_state = 2},
  [15935] = {.lex_state = 54, .external_lex_state = 2},
  [15936] = {.lex_state = 24, .external_lex_state = 2},
  [15937] = {.lex_state = 54, .external_lex_state = 2},
  [15938] = {.lex_state = 24, .external_lex_state = 2},
  [15939] = {.lex_state = 54, .external_lex_state = 2},
  [15940] = {.lex_state = 54, .external_lex_state = 2},
  [15941] = {.lex_state = 144, .external_lex_state = 2},
  [15942] = {.lex_state = 265, .external_lex_state = 8},
  [15943] = {.lex_state = 437, .external_lex_state = 2},
  [15944] = {.lex_state = 54, .external_lex_state = 2},
  [15945] = {.lex_state = 32, .external_lex_state = 2},
  [15946] = {.lex_state = 54, .external_lex_state = 2},
  [15947] = {.lex_state = 259, .external_lex_state = 2},
  [15948] = {.lex_state = 437, .external_lex_state = 2},
  [15949] = {.lex_state = 437, .external_lex_state = 2},
  [15950] = {.lex_state = 54, .external_lex_state = 2},
  [15951] = {.lex_state = 7, .external_lex_state = 2},
  [15952] = {.lex_state = 32, .external_lex_state = 2},
  [15953] = {.lex_state = 54, .external_lex_state = 2},
  [15954] = {.lex_state = 54, .external_lex_state = 2},
  [15955] = {.lex_state = 144, .external_lex_state = 2},
  [15956] = {.lex_state = 54, .external_lex_state = 2},
  [15957] = {.lex_state = 54, .external_lex_state = 2},
  [15958] = {.lex_state = 54, .external_lex_state = 2},
  [15959] = {.lex_state = 32, .external_lex_state = 2},
  [15960] = {.lex_state = 54, .external_lex_state = 2},
  [15961] = {.lex_state = 32, .external_lex_state = 2},
  [15962] = {.lex_state = 437, .external_lex_state = 2},
  [15963] = {.lex_state = 445, .external_lex_state = 2},
  [15964] = {.lex_state = 437, .external_lex_state = 2},
  [15965] = {.lex_state = 437, .external_lex_state = 2},
  [15966] = {.lex_state = 32, .external_lex_state = 2},
  [15967] = {.lex_state = 54, .external_lex_state = 2},
  [15968] = {.lex_state = 32, .external_lex_state = 2},
  [15969] = {.lex_state = 437, .external_lex_state = 2},
  [15970] = {.lex_state = 54, .external_lex_state = 2},
  [15971] = {.lex_state = 437, .external_lex_state = 2},
  [15972] = {.lex_state = 54, .external_lex_state = 2},
  [15973] = {.lex_state = 437, .external_lex_state = 2},
  [15974] = {.lex_state = 445, .external_lex_state = 2},
  [15975] = {.lex_state = 437, .external_lex_state = 2},
  [15976] = {.lex_state = 32, .external_lex_state = 2},
  [15977] = {.lex_state = 32, .external_lex_state = 2},
  [15978] = {.lex_state = 32, .external_lex_state = 2},
  [15979] = {.lex_state = 54, .external_lex_state = 2},
  [15980] = {.lex_state = 54, .external_lex_state = 2},
  [15981] = {.lex_state = 54, .external_lex_state = 2},
  [15982] = {.lex_state = 54, .external_lex_state = 2},
  [15983] = {.lex_state = 54, .external_lex_state = 2},
  [15984] = {.lex_state = 437, .external_lex_state = 2},
  [15985] = {.lex_state = 43, .external_lex_state = 2},
  [15986] = {.lex_state = 54, .external_lex_state = 2},
  [15987] = {.lex_state = 54, .external_lex_state = 2},
  [15988] = {.lex_state = 445, .external_lex_state = 2},
  [15989] = {.lex_state = 54, .external_lex_state = 2},
  [15990] = {.lex_state = 32, .external_lex_state = 2},
  [15991] = {.lex_state = 32, .external_lex_state = 2},
  [15992] = {.lex_state = 54, .external_lex_state = 2},
  [15993] = {.lex_state = 144, .external_lex_state = 2},
  [15994] = {.lex_state = 54, .external_lex_state = 2},
  [15995] = {.lex_state = 54, .external_lex_state = 2},
  [15996] = {.lex_state = 144, .external_lex_state = 2},
  [15997] = {.lex_state = 24, .external_lex_state = 2},
  [15998] = {.lex_state = 32, .external_lex_state = 2},
  [15999] = {.lex_state = 259, .external_lex_state = 2},
  [16000] = {.lex_state = 54, .external_lex_state = 2},
  [16001] = {.lex_state = 43, .external_lex_state = 2},
  [16002] = {.lex_state = 43, .external_lex_state = 2},
  [16003] = {.lex_state = 265, .external_lex_state = 8},
  [16004] = {.lex_state = 54, .external_lex_state = 2},
  [16005] = {.lex_state = 54, .external_lex_state = 2},
  [16006] = {.lex_state = 54, .external_lex_state = 2},
  [16007] = {.lex_state = 144, .external_lex_state = 2},
  [16008] = {.lex_state = 54, .external_lex_state = 2},
  [16009] = {.lex_state = 54, .external_lex_state = 2},
  [16010] = {.lex_state = 54, .external_lex_state = 2},
  [16011] = {.lex_state = 54, .external_lex_state = 2},
  [16012] = {.lex_state = 54, .external_lex_state = 2},
  [16013] = {.lex_state = 32, .external_lex_state = 2},
  [16014] = {.lex_state = 54, .external_lex_state = 2},
  [16015] = {.lex_state = 54, .external_lex_state = 2},
  [16016] = {.lex_state = 437, .external_lex_state = 2},
  [16017] = {.lex_state = 54, .external_lex_state = 2},
  [16018] = {.lex_state = 437, .external_lex_state = 2},
  [16019] = {.lex_state = 445, .external_lex_state = 2},
  [16020] = {.lex_state = 32, .external_lex_state = 2},
  [16021] = {.lex_state = 259, .external_lex_state = 2},
  [16022] = {.lex_state = 32, .external_lex_state = 2},
  [16023] = {.lex_state = 437, .external_lex_state = 2},
  [16024] = {.lex_state = 437, .external_lex_state = 2},
  [16025] = {.lex_state = 32, .external_lex_state = 2},
  [16026] = {.lex_state = 437, .external_lex_state = 2},
  [16027] = {.lex_state = 43, .external_lex_state = 2},
  [16028] = {.lex_state = 32, .external_lex_state = 2},
  [16029] = {.lex_state = 54, .external_lex_state = 2},
  [16030] = {.lex_state = 54, .external_lex_state = 2},
  [16031] = {.lex_state = 43, .external_lex_state = 2},
  [16032] = {.lex_state = 54, .external_lex_state = 2},
  [16033] = {.lex_state = 144, .external_lex_state = 2},
  [16034] = {.lex_state = 445, .external_lex_state = 2},
  [16035] = {.lex_state = 54, .external_lex_state = 2},
  [16036] = {.lex_state = 54, .external_lex_state = 2},
  [16037] = {.lex_state = 54, .external_lex_state = 2},
  [16038] = {.lex_state = 54, .external_lex_state = 2},
  [16039] = {.lex_state = 144, .external_lex_state = 2},
  [16040] = {.lex_state = 11, .external_lex_state = 2},
  [16041] = {.lex_state = 259, .external_lex_state = 2},
  [16042] = {.lex_state = 42, .external_lex_state = 2},
  [16043] = {.lex_state = 54, .external_lex_state = 2},
  [16044] = {.lex_state = 445, .external_lex_state = 2},
  [16045] = {.lex_state = 32, .external_lex_state = 2},
  [16046] = {.lex_state = 32, .external_lex_state = 2},
  [16047] = {.lex_state = 32, .external_lex_state = 2},
  [16048] = {.lex_state = 54, .external_lex_state = 2},
  [16049] = {.lex_state = 54, .external_lex_state = 2},
  [16050] = {.lex_state = 24, .external_lex_state = 2},
  [16051] = {.lex_state = 445, .external_lex_state = 2},
  [16052] = {.lex_state = 54, .external_lex_state = 2},
  [16053] = {.lex_state = 265, .external_lex_state = 8},
  [16054] = {.lex_state = 54, .external_lex_state = 2},
  [16055] = {.lex_state = 32, .external_lex_state = 2},
  [16056] = {.lex_state = 437, .external_lex_state = 2},
  [16057] = {.lex_state = 437, .external_lex_state = 2},
  [16058] = {.lex_state = 437, .external_lex_state = 2},
  [16059] = {.lex_state = 54, .external_lex_state = 2},
  [16060] = {.lex_state = 437, .external_lex_state = 2},
  [16061] = {.lex_state = 54, .external_lex_state = 2},
  [16062] = {.lex_state = 32, .external_lex_state = 2},
  [16063] = {.lex_state = 54, .external_lex_state = 2},
  [16064] = {.lex_state = 54, .external_lex_state = 2},
  [16065] = {.lex_state = 259, .external_lex_state = 2},
  [16066] = {.lex_state = 54, .external_lex_state = 2},
  [16067] = {.lex_state = 144, .external_lex_state = 2},
  [16068] = {.lex_state = 437, .external_lex_state = 2},
  [16069] = {.lex_state = 437, .external_lex_state = 2},
  [16070] = {.lex_state = 144, .external_lex_state = 2},
  [16071] = {.lex_state = 54, .external_lex_state = 2},
  [16072] = {.lex_state = 437, .external_lex_state = 2},
  [16073] = {.lex_state = 54, .external_lex_state = 2},
  [16074] = {.lex_state = 437, .external_lex_state = 2},
  [16075] = {.lex_state = 437, .external_lex_state = 2},
  [16076] = {.lex_state = 144, .external_lex_state = 2},
  [16077] = {.lex_state = 11, .external_lex_state = 2},
  [16078] = {.lex_state = 11, .external_lex_state = 2},
  [16079] = {.lex_state = 259, .external_lex_state = 2},
  [16080] = {.lex_state = 445, .external_lex_state = 2},
  [16081] = {.lex_state = 445, .external_lex_state = 2},
  [16082] = {.lex_state = 32, .external_lex_state = 2},
  [16083] = {.lex_state = 32, .external_lex_state = 2},
  [16084] = {.lex_state = 54, .external_lex_state = 2},
  [16085] = {.lex_state = 32, .external_lex_state = 2},
  [16086] = {.lex_state = 437, .external_lex_state = 2},
  [16087] = {.lex_state = 43, .external_lex_state = 2},
  [16088] = {.lex_state = 54, .external_lex_state = 2},
  [16089] = {.lex_state = 32, .external_lex_state = 2},
  [16090] = {.lex_state = 445, .external_lex_state = 2},
  [16091] = {.lex_state = 24, .external_lex_state = 2},
  [16092] = {.lex_state = 32, .external_lex_state = 2},
  [16093] = {.lex_state = 32, .external_lex_state = 2},
  [16094] = {.lex_state = 265, .external_lex_state = 8},
  [16095] = {.lex_state = 32, .external_lex_state = 2},
  [16096] = {.lex_state = 54, .external_lex_state = 2},
  [16097] = {.lex_state = 259, .external_lex_state = 2},
  [16098] = {.lex_state = 259, .external_lex_state = 2},
  [16099] = {.lex_state = 54, .external_lex_state = 2},
  [16100] = {.lex_state = 24, .external_lex_state = 2},
  [16101] = {.lex_state = 437, .external_lex_state = 2},
  [16102] = {.lex_state = 437, .external_lex_state = 2},
  [16103] = {.lex_state = 437, .external_lex_state = 2},
  [16104] = {.lex_state = 259, .external_lex_state = 2},
  [16105] = {.lex_state = 437, .external_lex_state = 2},
  [16106] = {.lex_state = 437, .external_lex_state = 2},
  [16107] = {.lex_state = 54, .external_lex_state = 2},
  [16108] = {.lex_state = 54, .external_lex_state = 2},
  [16109] = {.lex_state = 54, .external_lex_state = 2},
  [16110] = {.lex_state = 54, .external_lex_state = 2},
  [16111] = {.lex_state = 32, .external_lex_state = 2},
  [16112] = {.lex_state = 24, .external_lex_state = 2},
  [16113] = {.lex_state = 445, .external_lex_state = 2},
  [16114] = {.lex_state = 24, .external_lex_state = 2},
  [16115] = {.lex_state = 32, .external_lex_state = 2},
  [16116] = {.lex_state = 54, .external_lex_state = 2},
  [16117] = {.lex_state = 32, .external_lex_state = 2},
  [16118] = {.lex_state = 265, .external_lex_state = 8},
  [16119] = {.lex_state = 144, .external_lex_state = 2},
  [16120] = {.lex_state = 144, .external_lex_state = 2},
  [16121] = {.lex_state = 54, .external_lex_state = 2},
  [16122] = {.lex_state = 32, .external_lex_state = 2},
  [16123] = {.lex_state = 54, .external_lex_state = 2},
  [16124] = {.lex_state = 54, .external_lex_state = 2},
  [16125] = {.lex_state = 54, .external_lex_state = 2},
  [16126] = {.lex_state = 54, .external_lex_state = 2},
  [16127] = {.lex_state = 437, .external_lex_state = 2},
  [16128] = {.lex_state = 437, .external_lex_state = 2},
  [16129] = {.lex_state = 43, .external_lex_state = 2},
  [16130] = {.lex_state = 54, .external_lex_state = 2},
  [16131] = {.lex_state = 437, .external_lex_state = 2},
  [16132] = {.lex_state = 437, .external_lex_state = 2},
  [16133] = {.lex_state = 54, .external_lex_state = 2},
  [16134] = {.lex_state = 54, .external_lex_state = 2},
  [16135] = {.lex_state = 32, .external_lex_state = 2},
  [16136] = {.lex_state = 43, .external_lex_state = 2},
  [16137] = {.lex_state = 24, .external_lex_state = 2},
  [16138] = {.lex_state = 54, .external_lex_state = 2},
  [16139] = {.lex_state = 32, .external_lex_state = 2},
  [16140] = {.lex_state = 54, .external_lex_state = 2},
  [16141] = {.lex_state = 265, .external_lex_state = 8},
  [16142] = {.lex_state = 54, .external_lex_state = 2},
  [16143] = {.lex_state = 54, .external_lex_state = 2},
  [16144] = {.lex_state = 144, .external_lex_state = 2},
  [16145] = {.lex_state = 43, .external_lex_state = 2},
  [16146] = {.lex_state = 54, .external_lex_state = 2},
  [16147] = {.lex_state = 54, .external_lex_state = 2},
  [16148] = {.lex_state = 144, .external_lex_state = 2},
  [16149] = {.lex_state = 437, .external_lex_state = 2},
  [16150] = {.lex_state = 437, .external_lex_state = 2},
  [16151] = {.lex_state = 437, .external_lex_state = 2},
  [16152] = {.lex_state = 437, .external_lex_state = 2},
  [16153] = {.lex_state = 54, .external_lex_state = 2},
  [16154] = {.lex_state = 54, .external_lex_state = 2},
  [16155] = {.lex_state = 32, .external_lex_state = 2},
  [16156] = {.lex_state = 54, .external_lex_state = 2},
  [16157] = {.lex_state = 54, .external_lex_state = 2},
  [16158] = {.lex_state = 445, .external_lex_state = 2},
  [16159] = {.lex_state = 24, .external_lex_state = 2},
  [16160] = {.lex_state = 32, .external_lex_state = 2},
  [16161] = {.lex_state = 32, .external_lex_state = 2},
  [16162] = {.lex_state = 144, .external_lex_state = 2},
  [16163] = {.lex_state = 54, .external_lex_state = 2},
  [16164] = {.lex_state = 43, .external_lex_state = 2},
  [16165] = {.lex_state = 265, .external_lex_state = 8},
  [16166] = {.lex_state = 54, .external_lex_state = 2},
  [16167] = {.lex_state = 54, .external_lex_state = 2},
  [16168] = {.lex_state = 54, .external_lex_state = 2},
  [16169] = {.lex_state = 54, .external_lex_state = 2},
  [16170] = {.lex_state = 54, .external_lex_state = 2},
  [16171] = {.lex_state = 54, .external_lex_state = 2},
  [16172] = {.lex_state = 259, .external_lex_state = 2},
  [16173] = {.lex_state = 445, .external_lex_state = 2},
  [16174] = {.lex_state = 259, .external_lex_state = 2},
  [16175] = {.lex_state = 54, .external_lex_state = 2},
  [16176] = {.lex_state = 437, .external_lex_state = 2},
  [16177] = {.lex_state = 54, .external_lex_state = 2},
  [16178] = {.lex_state = 437, .external_lex_state = 2},
  [16179] = {.lex_state = 437, .external_lex_state = 2},
  [16180] = {.lex_state = 32, .external_lex_state = 2},
  [16181] = {.lex_state = 54, .external_lex_state = 2},
  [16182] = {.lex_state = 144, .external_lex_state = 2},
  [16183] = {.lex_state = 437, .external_lex_state = 2},
  [16184] = {.lex_state = 437, .external_lex_state = 2},
  [16185] = {.lex_state = 445, .external_lex_state = 2},
  [16186] = {.lex_state = 32, .external_lex_state = 2},
  [16187] = {.lex_state = 32, .external_lex_state = 2},
  [16188] = {.lex_state = 445, .external_lex_state = 2},
  [16189] = {.lex_state = 11, .external_lex_state = 2},
  [16190] = {.lex_state = 32, .external_lex_state = 2},
  [16191] = {.lex_state = 24, .external_lex_state = 2},
  [16192] = {.lex_state = 54, .external_lex_state = 2},
  [16193] = {.lex_state = 265, .external_lex_state = 8},
  [16194] = {.lex_state = 32, .external_lex_state = 2},
  [16195] = {.lex_state = 32, .external_lex_state = 2},
  [16196] = {.lex_state = 437, .external_lex_state = 2},
  [16197] = {.lex_state = 32, .external_lex_state = 2},
  [16198] = {.lex_state = 32, .external_lex_state = 2},
  [16199] = {.lex_state = 437, .external_lex_state = 2},
  [16200] = {.lex_state = 54, .external_lex_state = 2},
  [16201] = {.lex_state = 43, .external_lex_state = 2},
  [16202] = {.lex_state = 54, .external_lex_state = 2},
  [16203] = {.lex_state = 437, .external_lex_state = 2},
  [16204] = {.lex_state = 43, .external_lex_state = 2},
  [16205] = {.lex_state = 437, .external_lex_state = 2},
  [16206] = {.lex_state = 437, .external_lex_state = 2},
  [16207] = {.lex_state = 54, .external_lex_state = 2},
  [16208] = {.lex_state = 259, .external_lex_state = 2},
  [16209] = {.lex_state = 437, .external_lex_state = 2},
  [16210] = {.lex_state = 437, .external_lex_state = 2},
  [16211] = {.lex_state = 24, .external_lex_state = 2},
  [16212] = {.lex_state = 265, .external_lex_state = 8},
  [16213] = {.lex_state = 437, .external_lex_state = 2},
  [16214] = {.lex_state = 54, .external_lex_state = 2},
  [16215] = {.lex_state = 54, .external_lex_state = 2},
  [16216] = {.lex_state = 54, .external_lex_state = 2},
  [16217] = {.lex_state = 54, .external_lex_state = 2},
  [16218] = {.lex_state = 24, .external_lex_state = 2},
  [16219] = {.lex_state = 54, .external_lex_state = 2},
  [16220] = {.lex_state = 32, .external_lex_state = 2},
  [16221] = {.lex_state = 54, .external_lex_state = 2},
  [16222] = {.lex_state = 437, .external_lex_state = 2},
  [16223] = {.lex_state = 24, .external_lex_state = 2},
  [16224] = {.lex_state = 437, .external_lex_state = 2},
  [16225] = {.lex_state = 54, .external_lex_state = 2},
  [16226] = {.lex_state = 437, .external_lex_state = 2},
  [16227] = {.lex_state = 437, .external_lex_state = 2},
  [16228] = {.lex_state = 445, .external_lex_state = 2},
  [16229] = {.lex_state = 11, .external_lex_state = 2},
  [16230] = {.lex_state = 54, .external_lex_state = 2},
  [16231] = {.lex_state = 54, .external_lex_state = 2},
  [16232] = {.lex_state = 32, .external_lex_state = 2},
  [16233] = {.lex_state = 54, .external_lex_state = 2},
  [16234] = {.lex_state = 54, .external_lex_state = 2},
  [16235] = {.lex_state = 24, .external_lex_state = 2},
  [16236] = {.lex_state = 24, .external_lex_state = 2},
  [16237] = {.lex_state = 54, .external_lex_state = 2},
  [16238] = {.lex_state = 265, .external_lex_state = 8},
  [16239] = {.lex_state = 32, .external_lex_state = 2},
  [16240] = {.lex_state = 54, .external_lex_state = 2},
  [16241] = {.lex_state = 144, .external_lex_state = 2},
  [16242] = {.lex_state = 32, .external_lex_state = 2},
  [16243] = {.lex_state = 54, .external_lex_state = 2},
  [16244] = {.lex_state = 259, .external_lex_state = 2},
  [16245] = {.lex_state = 437, .external_lex_state = 2},
  [16246] = {.lex_state = 437, .external_lex_state = 2},
  [16247] = {.lex_state = 43, .external_lex_state = 2},
  [16248] = {.lex_state = 437, .external_lex_state = 2},
  [16249] = {.lex_state = 437, .external_lex_state = 2},
  [16250] = {.lex_state = 24, .external_lex_state = 2},
  [16251] = {.lex_state = 32, .external_lex_state = 2},
  [16252] = {.lex_state = 43, .external_lex_state = 2},
  [16253] = {.lex_state = 265, .external_lex_state = 8},
  [16254] = {.lex_state = 32, .external_lex_state = 2},
  [16255] = {.lex_state = 43, .external_lex_state = 2},
  [16256] = {.lex_state = 54, .external_lex_state = 2},
  [16257] = {.lex_state = 54, .external_lex_state = 2},
  [16258] = {.lex_state = 24, .external_lex_state = 2},
  [16259] = {.lex_state = 54, .external_lex_state = 2},
  [16260] = {.lex_state = 259, .external_lex_state = 2},
  [16261] = {.lex_state = 54, .external_lex_state = 2},
  [16262] = {.lex_state = 144, .external_lex_state = 2},
  [16263] = {.lex_state = 11, .external_lex_state = 2},
  [16264] = {.lex_state = 24, .external_lex_state = 2},
  [16265] = {.lex_state = 437, .external_lex_state = 2},
  [16266] = {.lex_state = 259, .external_lex_state = 2},
  [16267] = {.lex_state = 437, .external_lex_state = 2},
  [16268] = {.lex_state = 259, .external_lex_state = 2},
  [16269] = {.lex_state = 437, .external_lex_state = 2},
  [16270] = {.lex_state = 437, .external_lex_state = 2},
  [16271] = {.lex_state = 24, .external_lex_state = 2},
  [16272] = {.lex_state = 54, .external_lex_state = 2},
  [16273] = {.lex_state = 54, .external_lex_state = 2},
  [16274] = {.lex_state = 265, .external_lex_state = 8},
  [16275] = {.lex_state = 54, .external_lex_state = 2},
  [16276] = {.lex_state = 445, .external_lex_state = 2},
  [16277] = {.lex_state = 437, .external_lex_state = 2},
  [16278] = {.lex_state = 54, .external_lex_state = 2},
  [16279] = {.lex_state = 32, .external_lex_state = 2},
  [16280] = {.lex_state = 54, .external_lex_state = 2},
  [16281] = {.lex_state = 32, .external_lex_state = 2},
  [16282] = {.lex_state = 445, .external_lex_state = 2},
  [16283] = {.lex_state = 437, .external_lex_state = 2},
  [16284] = {.lex_state = 32, .external_lex_state = 2},
  [16285] = {.lex_state = 437, .external_lex_state = 2},
  [16286] = {.lex_state = 32, .external_lex_state = 2},
  [16287] = {.lex_state = 32, .external_lex_state = 2},
  [16288] = {.lex_state = 437, .external_lex_state = 2},
  [16289] = {.lex_state = 43, .external_lex_state = 2},
  [16290] = {.lex_state = 437, .external_lex_state = 2},
  [16291] = {.lex_state = 437, .external_lex_state = 2},
  [16292] = {.lex_state = 43, .external_lex_state = 2},
  [16293] = {.lex_state = 24, .external_lex_state = 2},
  [16294] = {.lex_state = 54, .external_lex_state = 2},
  [16295] = {.lex_state = 265, .external_lex_state = 8},
  [16296] = {.lex_state = 54, .external_lex_state = 2},
  [16297] = {.lex_state = 54, .external_lex_state = 2},
  [16298] = {.lex_state = 54, .external_lex_state = 2},
  [16299] = {.lex_state = 33, .external_lex_state = 2},
  [16300] = {.lex_state = 24, .external_lex_state = 2},
  [16301] = {.lex_state = 437, .external_lex_state = 2},
  [16302] = {.lex_state = 437, .external_lex_state = 2},
  [16303] = {.lex_state = 54, .external_lex_state = 2},
  [16304] = {.lex_state = 437, .external_lex_state = 2},
  [16305] = {.lex_state = 437, .external_lex_state = 2},
  [16306] = {.lex_state = 24, .external_lex_state = 2},
  [16307] = {.lex_state = 259, .external_lex_state = 2},
  [16308] = {.lex_state = 265, .external_lex_state = 8},
  [16309] = {.lex_state = 54, .external_lex_state = 2},
  [16310] = {.lex_state = 445, .external_lex_state = 2},
  [16311] = {.lex_state = 32, .external_lex_state = 2},
  [16312] = {.lex_state = 32, .external_lex_state = 2},
  [16313] = {.lex_state = 144, .external_lex_state = 2},
  [16314] = {.lex_state = 54, .external_lex_state = 2},
  [16315] = {.lex_state = 32, .external_lex_state = 2},
  [16316] = {.lex_state = 54, .external_lex_state = 2},
  [16317] = {.lex_state = 445, .external_lex_state = 2},
  [16318] = {.lex_state = 32, .external_lex_state = 2},
  [16319] = {.lex_state = 54, .external_lex_state = 2},
  [16320] = {.lex_state = 437, .external_lex_state = 2},
  [16321] = {.lex_state = 437, .external_lex_state = 2},
  [16322] = {.lex_state = 32, .external_lex_state = 2},
  [16323] = {.lex_state = 437, .external_lex_state = 2},
  [16324] = {.lex_state = 437, .external_lex_state = 2},
  [16325] = {.lex_state = 24, .external_lex_state = 2},
  [16326] = {.lex_state = 54, .external_lex_state = 2},
  [16327] = {.lex_state = 54, .external_lex_state = 2},
  [16328] = {.lex_state = 437, .external_lex_state = 2},
  [16329] = {.lex_state = 265, .external_lex_state = 8},
  [16330] = {.lex_state = 259, .external_lex_state = 2},
  [16331] = {.lex_state = 32, .external_lex_state = 2},
  [16332] = {.lex_state = 32, .external_lex_state = 2},
  [16333] = {.lex_state = 43, .external_lex_state = 2},
  [16334] = {.lex_state = 259, .external_lex_state = 2},
  [16335] = {.lex_state = 54, .external_lex_state = 2},
  [16336] = {.lex_state = 54, .external_lex_state = 2},
  [16337] = {.lex_state = 437, .external_lex_state = 2},
  [16338] = {.lex_state = 437, .external_lex_state = 2},
  [16339] = {.lex_state = 144, .external_lex_state = 2},
  [16340] = {.lex_state = 437, .external_lex_state = 2},
  [16341] = {.lex_state = 437, .external_lex_state = 2},
  [16342] = {.lex_state = 24, .external_lex_state = 2},
  [16343] = {.lex_state = 265, .external_lex_state = 8},
  [16344] = {.lex_state = 32, .external_lex_state = 2},
  [16345] = {.lex_state = 54, .external_lex_state = 2},
  [16346] = {.lex_state = 54, .external_lex_state = 2},
  [16347] = {.lex_state = 437, .external_lex_state = 2},
  [16348] = {.lex_state = 11, .external_lex_state = 2},
  [16349] = {.lex_state = 54, .external_lex_state = 2},
  [16350] = {.lex_state = 437, .external_lex_state = 2},
  [16351] = {.lex_state = 445, .external_lex_state = 2},
  [16352] = {.lex_state = 437, .external_lex_state = 2},
  [16353] = {.lex_state = 437, .external_lex_state = 2},
  [16354] = {.lex_state = 437, .external_lex_state = 2},
  [16355] = {.lex_state = 54, .external_lex_state = 2},
  [16356] = {.lex_state = 437, .external_lex_state = 2},
  [16357] = {.lex_state = 437, .external_lex_state = 2},
  [16358] = {.lex_state = 54, .external_lex_state = 2},
  [16359] = {.lex_state = 24, .external_lex_state = 2},
  [16360] = {.lex_state = 144, .external_lex_state = 2},
  [16361] = {.lex_state = 265, .external_lex_state = 8},
  [16362] = {.lex_state = 54, .external_lex_state = 2},
  [16363] = {.lex_state = 54, .external_lex_state = 2},
  [16364] = {.lex_state = 54, .external_lex_state = 2},
  [16365] = {.lex_state = 437, .external_lex_state = 2},
  [16366] = {.lex_state = 144, .external_lex_state = 2},
  [16367] = {.lex_state = 32, .external_lex_state = 2},
  [16368] = {.lex_state = 54, .external_lex_state = 2},
  [16369] = {.lex_state = 437, .external_lex_state = 2},
  [16370] = {.lex_state = 437, .external_lex_state = 2},
  [16371] = {.lex_state = 445, .external_lex_state = 2},
  [16372] = {.lex_state = 32, .external_lex_state = 2},
  [16373] = {.lex_state = 32, .external_lex_state = 2},
  [16374] = {.lex_state = 32, .external_lex_state = 2},
  [16375] = {.lex_state = 437, .external_lex_state = 2},
  [16376] = {.lex_state = 437, .external_lex_state = 2},
  [16377] = {.lex_state = 54, .external_lex_state = 2},
  [16378] = {.lex_state = 24, .external_lex_state = 2},
  [16379] = {.lex_state = 43, .external_lex_state = 2},
  [16380] = {.lex_state = 24, .external_lex_state = 2},
  [16381] = {.lex_state = 265, .external_lex_state = 8},
  [16382] = {.lex_state = 43, .external_lex_state = 2},
  [16383] = {.lex_state = 32, .external_lex_state = 2},
  [16384] = {.lex_state = 54, .external_lex_state = 2},
  [16385] = {.lex_state = 54, .external_lex_state = 2},
  [16386] = {.lex_state = 437, .external_lex_state = 2},
  [16387] = {.lex_state = 54, .external_lex_state = 2},
  [16388] = {.lex_state = 259, .external_lex_state = 2},
  [16389] = {.lex_state = 437, .external_lex_state = 2},
  [16390] = {.lex_state = 437, .external_lex_state = 2},
  [16391] = {.lex_state = 437, .external_lex_state = 2},
  [16392] = {.lex_state = 437, .external_lex_state = 2},
  [16393] = {.lex_state = 437, .external_lex_state = 2},
  [16394] = {.lex_state = 24, .external_lex_state = 2},
  [16395] = {.lex_state = 265, .external_lex_state = 8},
  [16396] = {.lex_state = 437, .external_lex_state = 2},
  [16397] = {.lex_state = 54, .external_lex_state = 2},
  [16398] = {.lex_state = 54, .external_lex_state = 2},
  [16399] = {.lex_state = 32, .external_lex_state = 2},
  [16400] = {.lex_state = 144, .external_lex_state = 2},
  [16401] = {.lex_state = 24, .external_lex_state = 2},
  [16402] = {.lex_state = 445, .external_lex_state = 2},
  [16403] = {.lex_state = 437, .external_lex_state = 2},
  [16404] = {.lex_state = 445, .external_lex_state = 2},
  [16405] = {.lex_state = 32, .external_lex_state = 2},
  [16406] = {.lex_state = 32, .external_lex_state = 2},
  [16407] = {.lex_state = 437, .external_lex_state = 2},
  [16408] = {.lex_state = 437, .external_lex_state = 2},
  [16409] = {.lex_state = 437, .external_lex_state = 2},
  [16410] = {.lex_state = 24, .external_lex_state = 2},
  [16411] = {.lex_state = 437, .external_lex_state = 2},
  [16412] = {.lex_state = 437, .external_lex_state = 2},
  [16413] = {.lex_state = 265, .external_lex_state = 8},
  [16414] = {.lex_state = 54, .external_lex_state = 2},
  [16415] = {.lex_state = 54, .external_lex_state = 2},
  [16416] = {.lex_state = 54, .external_lex_state = 2},
  [16417] = {.lex_state = 437, .external_lex_state = 2},
  [16418] = {.lex_state = 24, .external_lex_state = 2},
  [16419] = {.lex_state = 54, .external_lex_state = 2},
  [16420] = {.lex_state = 54, .external_lex_state = 2},
  [16421] = {.lex_state = 265, .external_lex_state = 8},
  [16422] = {.lex_state = 54, .external_lex_state = 2},
  [16423] = {.lex_state = 32, .external_lex_state = 2},
  [16424] = {.lex_state = 54, .external_lex_state = 2},
  [16425] = {.lex_state = 54, .external_lex_state = 2},
  [16426] = {.lex_state = 144, .external_lex_state = 2},
  [16427] = {.lex_state = 24, .external_lex_state = 2},
  [16428] = {.lex_state = 265, .external_lex_state = 8},
  [16429] = {.lex_state = 259, .external_lex_state = 2},
  [16430] = {.lex_state = 43, .external_lex_state = 2},
  [16431] = {.lex_state = 54, .external_lex_state = 2},
  [16432] = {.lex_state = 24, .external_lex_state = 2},
  [16433] = {.lex_state = 54, .external_lex_state = 2},
  [16434] = {.lex_state = 265, .external_lex_state = 8},
  [16435] = {.lex_state = 54, .external_lex_state = 2},
  [16436] = {.lex_state = 54, .external_lex_state = 2},
  [16437] = {.lex_state = 54, .external_lex_state = 2},
  [16438] = {.lex_state = 265, .external_lex_state = 8},
  [16439] = {.lex_state = 24, .external_lex_state = 2},
  [16440] = {.lex_state = 265, .external_lex_state = 8},
  [16441] = {.lex_state = 54, .external_lex_state = 2},
  [16442] = {.lex_state = 144, .external_lex_state = 2},
  [16443] = {.lex_state = 54, .external_lex_state = 2},
  [16444] = {.lex_state = 24, .external_lex_state = 2},
  [16445] = {.lex_state = 54, .external_lex_state = 2},
  [16446] = {.lex_state = 54, .external_lex_state = 2},
  [16447] = {.lex_state = 265, .external_lex_state = 8},
  [16448] = {.lex_state = 54, .external_lex_state = 2},
  [16449] = {.lex_state = 445, .external_lex_state = 2},
  [16450] = {.lex_state = 54, .external_lex_state = 2},
  [16451] = {.lex_state = 437, .external_lex_state = 2},
  [16452] = {.lex_state = 54, .external_lex_state = 2},
  [16453] = {.lex_state = 54, .external_lex_state = 2},
  [16454] = {.lex_state = 144, .external_lex_state = 2},
  [16455] = {.lex_state = 24, .external_lex_state = 2},
  [16456] = {.lex_state = 437, .external_lex_state = 2},
  [16457] = {.lex_state = 437, .external_lex_state = 2},
  [16458] = {.lex_state = 265, .external_lex_state = 8},
  [16459] = {.lex_state = 24, .external_lex_state = 2},
  [16460] = {.lex_state = 437, .external_lex_state = 2},
  [16461] = {.lex_state = 22, .external_lex_state = 2},
  [16462] = {.lex_state = 54, .external_lex_state = 2},
  [16463] = {.lex_state = 24, .external_lex_state = 2},
  [16464] = {.lex_state = 24, .external_lex_state = 2},
  [16465] = {.lex_state = 265, .external_lex_state = 8},
  [16466] = {.lex_state = 54, .external_lex_state = 2},
  [16467] = {.lex_state = 54, .external_lex_state = 2},
  [16468] = {.lex_state = 54, .external_lex_state = 2},
  [16469] = {.lex_state = 54, .external_lex_state = 2},
  [16470] = {.lex_state = 54, .external_lex_state = 2},
  [16471] = {.lex_state = 445, .external_lex_state = 2},
  [16472] = {.lex_state = 32, .external_lex_state = 2},
  [16473] = {.lex_state = 24, .external_lex_state = 2},
  [16474] = {.lex_state = 144, .external_lex_state = 2},
  [16475] = {.lex_state = 24, .external_lex_state = 2},
  [16476] = {.lex_state = 32, .external_lex_state = 2},
  [16477] = {.lex_state = 32, .external_lex_state = 2},
  [16478] = {.lex_state = 265, .external_lex_state = 8},
  [16479] = {.lex_state = 24, .external_lex_state = 2},
  [16480] = {.lex_state = 54, .external_lex_state = 2},
  [16481] = {.lex_state = 54, .external_lex_state = 2},
  [16482] = {.lex_state = 43, .external_lex_state = 2},
  [16483] = {.lex_state = 54, .external_lex_state = 2},
  [16484] = {.lex_state = 54, .external_lex_state = 2},
  [16485] = {.lex_state = 144, .external_lex_state = 2},
  [16486] = {.lex_state = 24, .external_lex_state = 2},
  [16487] = {.lex_state = 54, .external_lex_state = 2},
  [16488] = {.lex_state = 265, .external_lex_state = 8},
  [16489] = {.lex_state = 144, .external_lex_state = 2},
  [16490] = {.lex_state = 43, .external_lex_state = 2},
  [16491] = {.lex_state = 259, .external_lex_state = 2},
  [16492] = {.lex_state = 265, .external_lex_state = 8},
  [16493] = {.lex_state = 24, .external_lex_state = 2},
  [16494] = {.lex_state = 259, .external_lex_state = 2},
  [16495] = {.lex_state = 24, .external_lex_state = 2},
  [16496] = {.lex_state = 437, .external_lex_state = 2},
  [16497] = {.lex_state = 54, .external_lex_state = 2},
  [16498] = {.lex_state = 265, .external_lex_state = 8},
  [16499] = {.lex_state = 144, .external_lex_state = 2},
  [16500] = {.lex_state = 32, .external_lex_state = 2},
  [16501] = {.lex_state = 54, .external_lex_state = 2},
  [16502] = {.lex_state = 24, .external_lex_state = 2},
  [16503] = {.lex_state = 24, .external_lex_state = 2},
  [16504] = {.lex_state = 445, .external_lex_state = 2},
  [16505] = {.lex_state = 265, .external_lex_state = 8},
  [16506] = {.lex_state = 24, .external_lex_state = 2},
  [16507] = {.lex_state = 54, .external_lex_state = 2},
  [16508] = {.lex_state = 32, .external_lex_state = 2},
  [16509] = {.lex_state = 54, .external_lex_state = 2},
  [16510] = {.lex_state = 32, .external_lex_state = 2},
  [16511] = {.lex_state = 24, .external_lex_state = 2},
  [16512] = {.lex_state = 24, .external_lex_state = 2},
  [16513] = {.lex_state = 54, .external_lex_state = 2},
  [16514] = {.lex_state = 265, .external_lex_state = 8},
  [16515] = {.lex_state = 54, .external_lex_state = 2},
  [16516] = {.lex_state = 24, .external_lex_state = 2},
  [16517] = {.lex_state = 54, .external_lex_state = 2},
  [16518] = {.lex_state = 259, .external_lex_state = 2},
  [16519] = {.lex_state = 24, .external_lex_state = 2},
  [16520] = {.lex_state = 54, .external_lex_state = 2},
  [16521] = {.lex_state = 24, .external_lex_state = 2},
  [16522] = {.lex_state = 265, .external_lex_state = 8},
  [16523] = {.lex_state = 54, .external_lex_state = 2},
  [16524] = {.lex_state = 437, .external_lex_state = 2},
  [16525] = {.lex_state = 54, .external_lex_state = 2},
  [16526] = {.lex_state = 24, .external_lex_state = 2},
  [16527] = {.lex_state = 24, .external_lex_state = 2},
  [16528] = {.lex_state = 43, .external_lex_state = 2},
  [16529] = {.lex_state = 437, .external_lex_state = 2},
  [16530] = {.lex_state = 265, .external_lex_state = 8},
  [16531] = {.lex_state = 259, .external_lex_state = 2},
  [16532] = {.lex_state = 54, .external_lex_state = 2},
  [16533] = {.lex_state = 54, .external_lex_state = 2},
  [16534] = {.lex_state = 24, .external_lex_state = 2},
  [16535] = {.lex_state = 54, .external_lex_state = 2},
  [16536] = {.lex_state = 445, .external_lex_state = 2},
  [16537] = {.lex_state = 32, .external_lex_state = 2},
  [16538] = {.lex_state = 32, .external_lex_state = 2},
  [16539] = {.lex_state = 24, .external_lex_state = 2},
  [16540] = {.lex_state = 43, .external_lex_state = 2},
  [16541] = {.lex_state = 265, .external_lex_state = 8},
  [16542] = {.lex_state = 54, .external_lex_state = 2},
  [16543] = {.lex_state = 437, .external_lex_state = 2},
  [16544] = {.lex_state = 54, .external_lex_state = 2},
  [16545] = {.lex_state = 43, .external_lex_state = 2},
  [16546] = {.lex_state = 24, .external_lex_state = 2},
  [16547] = {.lex_state = 54, .external_lex_state = 2},
  [16548] = {.lex_state = 24, .external_lex_state = 2},
  [16549] = {.lex_state = 265, .external_lex_state = 8},
  [16550] = {.lex_state = 144, .external_lex_state = 2},
  [16551] = {.lex_state = 43, .external_lex_state = 2},
  [16552] = {.lex_state = 54, .external_lex_state = 2},
  [16553] = {.lex_state = 32, .external_lex_state = 2},
  [16554] = {.lex_state = 54, .external_lex_state = 2},
  [16555] = {.lex_state = 54, .external_lex_state = 2},
  [16556] = {.lex_state = 54, .external_lex_state = 2},
  [16557] = {.lex_state = 24, .external_lex_state = 2},
  [16558] = {.lex_state = 54, .external_lex_state = 2},
  [16559] = {.lex_state = 54, .external_lex_state = 2},
  [16560] = {.lex_state = 32, .external_lex_state = 2},
  [16561] = {.lex_state = 265, .external_lex_state = 8},
  [16562] = {.lex_state = 54, .external_lex_state = 2},
  [16563] = {.lex_state = 144, .external_lex_state = 2},
  [16564] = {.lex_state = 54, .external_lex_state = 2},
  [16565] = {.lex_state = 437, .external_lex_state = 2},
  [16566] = {.lex_state = 54, .external_lex_state = 2},
  [16567] = {.lex_state = 54, .external_lex_state = 2},
  [16568] = {.lex_state = 54, .external_lex_state = 2},
  [16569] = {.lex_state = 24, .external_lex_state = 2},
  [16570] = {.lex_state = 437, .external_lex_state = 2},
  [16571] = {.lex_state = 265, .external_lex_state = 8},
  [16572] = {.lex_state = 32, .external_lex_state = 2},
  [16573] = {.lex_state = 54, .external_lex_state = 2},
  [16574] = {.lex_state = 259, .external_lex_state = 2},
  [16575] = {.lex_state = 54, .external_lex_state = 2},
  [16576] = {.lex_state = 437, .external_lex_state = 2},
  [16577] = {.lex_state = 32, .external_lex_state = 2},
  [16578] = {.lex_state = 54, .external_lex_state = 2},
  [16579] = {.lex_state = 24, .external_lex_state = 2},
  [16580] = {.lex_state = 265, .external_lex_state = 8},
  [16581] = {.lex_state = 43, .external_lex_state = 2},
  [16582] = {.lex_state = 437, .external_lex_state = 2},
  [16583] = {.lex_state = 259, .external_lex_state = 2},
  [16584] = {.lex_state = 54, .external_lex_state = 2},
  [16585] = {.lex_state = 144, .external_lex_state = 2},
  [16586] = {.lex_state = 24, .external_lex_state = 2},
  [16587] = {.lex_state = 54, .external_lex_state = 2},
  [16588] = {.lex_state = 265, .external_lex_state = 8},
  [16589] = {.lex_state = 437, .external_lex_state = 2},
  [16590] = {.lex_state = 24, .external_lex_state = 2},
  [16591] = {.lex_state = 265, .external_lex_state = 8},
  [16592] = {.lex_state = 24, .external_lex_state = 2},
  [16593] = {.lex_state = 445, .external_lex_state = 2},
  [16594] = {.lex_state = 265, .external_lex_state = 8},
  [16595] = {.lex_state = 144, .external_lex_state = 2},
  [16596] = {.lex_state = 24, .external_lex_state = 2},
  [16597] = {.lex_state = 54, .external_lex_state = 2},
  [16598] = {.lex_state = 54, .external_lex_state = 2},
  [16599] = {.lex_state = 265, .external_lex_state = 8},
  [16600] = {.lex_state = 24, .external_lex_state = 2},
  [16601] = {.lex_state = 32, .external_lex_state = 2},
  [16602] = {.lex_state = 265, .external_lex_state = 8},
  [16603] = {.lex_state = 24, .external_lex_state = 2},
  [16604] = {.lex_state = 265, .external_lex_state = 8},
  [16605] = {.lex_state = 24, .external_lex_state = 2},
  [16606] = {.lex_state = 32, .external_lex_state = 2},
  [16607] = {.lex_state = 265, .external_lex_state = 8},
  [16608] = {.lex_state = 24, .external_lex_state = 2},
  [16609] = {.lex_state = 265, .external_lex_state = 8},
  [16610] = {.lex_state = 24, .external_lex_state = 2},
  [16611] = {.lex_state = 265, .external_lex_state = 8},
  [16612] = {.lex_state = 24, .external_lex_state = 2},
  [16613] = {.lex_state = 32, .external_lex_state = 2},
  [16614] = {.lex_state = 265, .external_lex_state = 8},
  [16615] = {.lex_state = 24, .external_lex_state = 2},
  [16616] = {.lex_state = 445, .external_lex_state = 2},
  [16617] = {.lex_state = 265, .external_lex_state = 8},
  [16618] = {.lex_state = 24, .external_lex_state = 2},
  [16619] = {.lex_state = 54, .external_lex_state = 2},
  [16620] = {.lex_state = 265, .external_lex_state = 8},
  [16621] = {.lex_state = 24, .external_lex_state = 2},
  [16622] = {.lex_state = 265, .external_lex_state = 8},
  [16623] = {.lex_state = 24, .external_lex_state = 2},
  [16624] = {.lex_state = 32, .external_lex_state = 2},
  [16625] = {.lex_state = 265, .external_lex_state = 8},
  [16626] = {.lex_state = 24, .external_lex_state = 2},
  [16627] = {.lex_state = 265, .external_lex_state = 8},
  [16628] = {.lex_state = 24, .external_lex_state = 2},
  [16629] = {.lex_state = 265, .external_lex_state = 8},
  [16630] = {.lex_state = 259, .external_lex_state = 2},
  [16631] = {.lex_state = 265, .external_lex_state = 8},
  [16632] = {.lex_state = 24, .external_lex_state = 2},
  [16633] = {.lex_state = 265, .external_lex_state = 8},
  [16634] = {.lex_state = 24, .external_lex_state = 2},
  [16635] = {.lex_state = 265, .external_lex_state = 8},
  [16636] = {.lex_state = 24, .external_lex_state = 2},
  [16637] = {.lex_state = 265, .external_lex_state = 8},
  [16638] = {.lex_state = 24, .external_lex_state = 2},
  [16639] = {.lex_state = 265, .external_lex_state = 8},
  [16640] = {.lex_state = 24, .external_lex_state = 2},
  [16641] = {.lex_state = 265, .external_lex_state = 8},
  [16642] = {.lex_state = 24, .external_lex_state = 2},
  [16643] = {.lex_state = 265, .external_lex_state = 8},
  [16644] = {.lex_state = 24, .external_lex_state = 2},
  [16645] = {.lex_state = 265, .external_lex_state = 8},
  [16646] = {.lex_state = 24, .external_lex_state = 2},
  [16647] = {.lex_state = 265, .external_lex_state = 8},
  [16648] = {.lex_state = 24, .external_lex_state = 2},
  [16649] = {.lex_state = 265, .external_lex_state = 8},
  [16650] = {.lex_state = 24, .external_lex_state = 2},
  [16651] = {.lex_state = 265, .external_lex_state = 8},
  [16652] = {.lex_state = 24, .external_lex_state = 2},
  [16653] = {.lex_state = 265, .external_lex_state = 8},
  [16654] = {.lex_state = 24, .external_lex_state = 2},
  [16655] = {.lex_state = 265, .external_lex_state = 8},
  [16656] = {.lex_state = 24, .external_lex_state = 2},
  [16657] = {.lex_state = 265, .external_lex_state = 8},
  [16658] = {.lex_state = 24, .external_lex_state = 2},
  [16659] = {.lex_state = 265, .external_lex_state = 8},
  [16660] = {.lex_state = 24, .external_lex_state = 2},
  [16661] = {.lex_state = 265, .external_lex_state = 8},
  [16662] = {.lex_state = 24, .external_lex_state = 2},
  [16663] = {.lex_state = 265, .external_lex_state = 8},
  [16664] = {.lex_state = 24, .external_lex_state = 2},
  [16665] = {.lex_state = 265, .external_lex_state = 8},
  [16666] = {.lex_state = 24, .external_lex_state = 2},
  [16667] = {.lex_state = 265, .external_lex_state = 8},
  [16668] = {.lex_state = 24, .external_lex_state = 2},
  [16669] = {.lex_state = 265, .external_lex_state = 8},
  [16670] = {.lex_state = 24, .external_lex_state = 2},
  [16671] = {.lex_state = 265, .external_lex_state = 8},
  [16672] = {.lex_state = 24, .external_lex_state = 2},
  [16673] = {.lex_state = 265, .external_lex_state = 8},
  [16674] = {.lex_state = 11, .external_lex_state = 2},
  [16675] = {.lex_state = 437, .external_lex_state = 2},
  [16676] = {.lex_state = 54, .external_lex_state = 2},
  [16677] = {.lex_state = 54, .external_lex_state = 2},
  [16678] = {.lex_state = 32, .external_lex_state = 2},
  [16679] = {.lex_state = 24, .external_lex_state = 2},
  [16680] = {.lex_state = 259, .external_lex_state = 2},
  [16681] = {.lex_state = 24, .external_lex_state = 2},
  [16682] = {.lex_state = 43, .external_lex_state = 2},
  [16683] = {.lex_state = 445, .external_lex_state = 2},
  [16684] = {.lex_state = 437, .external_lex_state = 2},
  [16685] = {.lex_state = 54, .external_lex_state = 2},
  [16686] = {.lex_state = 437, .external_lex_state = 2},
  [16687] = {.lex_state = 54, .external_lex_state = 2},
  [16688] = {.lex_state = 54, .external_lex_state = 2},
  [16689] = {.lex_state = 24, .external_lex_state = 2},
  [16690] = {.lex_state = 24, .external_lex_state = 2},
  [16691] = {.lex_state = 32, .external_lex_state = 2},
  [16692] = {.lex_state = 32, .external_lex_state = 2},
  [16693] = {.lex_state = 32, .external_lex_state = 2},
  [16694] = {.lex_state = 144, .external_lex_state = 2},
  [16695] = {.lex_state = 54, .external_lex_state = 2},
  [16696] = {.lex_state = 54, .external_lex_state = 2},
  [16697] = {.lex_state = 10, .external_lex_state = 2},
  [16698] = {.lex_state = 54, .external_lex_state = 2},
  [16699] = {.lex_state = 54, .external_lex_state = 2},
  [16700] = {.lex_state = 144, .external_lex_state = 2},
  [16701] = {.lex_state = 54, .external_lex_state = 2},
  [16702] = {.lex_state = 32, .external_lex_state = 2},
  [16703] = {.lex_state = 54, .external_lex_state = 2},
  [16704] = {.lex_state = 32, .external_lex_state = 2},
  [16705] = {.lex_state = 54, .external_lex_state = 2},
  [16706] = {.lex_state = 54, .external_lex_state = 2},
  [16707] = {.lex_state = 445, .external_lex_state = 2},
  [16708] = {.lex_state = 32, .external_lex_state = 2},
  [16709] = {.lex_state = 32, .external_lex_state = 2},
  [16710] = {.lex_state = 10, .external_lex_state = 2},
  [16711] = {.lex_state = 437, .external_lex_state = 2},
  [16712] = {.lex_state = 54, .external_lex_state = 2},
  [16713] = {.lex_state = 54, .external_lex_state = 2},
  [16714] = {.lex_state = 43, .external_lex_state = 2},
  [16715] = {.lex_state = 54, .external_lex_state = 2},
  [16716] = {.lex_state = 54, .external_lex_state = 2},
  [16717] = {.lex_state = 259, .external_lex_state = 2},
  [16718] = {.lex_state = 445, .external_lex_state = 2},
  [16719] = {.lex_state = 54, .external_lex_state = 2},
  [16720] = {.lex_state = 54, .external_lex_state = 2},
  [16721] = {.lex_state = 144, .external_lex_state = 2},
  [16722] = {.lex_state = 437, .external_lex_state = 2},
  [16723] = {.lex_state = 144, .external_lex_state = 2},
  [16724] = {.lex_state = 437, .external_lex_state = 2},
  [16725] = {.lex_state = 32, .external_lex_state = 2},
  [16726] = {.lex_state = 259, .external_lex_state = 2},
  [16727] = {.lex_state = 32, .external_lex_state = 2},
  [16728] = {.lex_state = 144, .external_lex_state = 2},
  [16729] = {.lex_state = 144, .external_lex_state = 2},
  [16730] = {.lex_state = 437, .external_lex_state = 2},
  [16731] = {.lex_state = 437, .external_lex_state = 2},
  [16732] = {.lex_state = 54, .external_lex_state = 2},
  [16733] = {.lex_state = 24, .external_lex_state = 2},
  [16734] = {.lex_state = 144, .external_lex_state = 2},
  [16735] = {.lex_state = 445, .external_lex_state = 2},
  [16736] = {.lex_state = 54, .external_lex_state = 2},
  [16737] = {.lex_state = 32, .external_lex_state = 2},
  [16738] = {.lex_state = 32, .external_lex_state = 2},
  [16739] = {.lex_state = 32, .external_lex_state = 2},
  [16740] = {.lex_state = 437, .external_lex_state = 2},
  [16741] = {.lex_state = 437, .external_lex_state = 2},
  [16742] = {.lex_state = 144, .external_lex_state = 2},
  [16743] = {.lex_state = 144, .external_lex_state = 2},
  [16744] = {.lex_state = 24, .external_lex_state = 2},
  [16745] = {.lex_state = 437, .external_lex_state = 2},
  [16746] = {.lex_state = 32, .external_lex_state = 2},
  [16747] = {.lex_state = 259, .external_lex_state = 2},
  [16748] = {.lex_state = 54, .external_lex_state = 2},
  [16749] = {.lex_state = 24, .external_lex_state = 2},
  [16750] = {.lex_state = 54, .external_lex_state = 2},
  [16751] = {.lex_state = 54, .external_lex_state = 2},
  [16752] = {.lex_state = 54, .external_lex_state = 2},
  [16753] = {.lex_state = 54, .external_lex_state = 2},
  [16754] = {.lex_state = 10, .external_lex_state = 2},
  [16755] = {.lex_state = 144, .external_lex_state = 2},
  [16756] = {.lex_state = 10, .external_lex_state = 2},
  [16757] = {.lex_state = 10, .external_lex_state = 2},
  [16758] = {.lex_state = 32, .external_lex_state = 2},
  [16759] = {.lex_state = 437, .external_lex_state = 2},
  [16760] = {.lex_state = 43, .external_lex_state = 2},
  [16761] = {.lex_state = 24, .external_lex_state = 2},
  [16762] = {.lex_state = 32, .external_lex_state = 2},
  [16763] = {.lex_state = 54, .external_lex_state = 2},
  [16764] = {.lex_state = 32, .external_lex_state = 2},
  [16765] = {.lex_state = 10, .external_lex_state = 2},
  [16766] = {.lex_state = 54, .external_lex_state = 2},
  [16767] = {.lex_state = 11, .external_lex_state = 2},
  [16768] = {.lex_state = 24, .external_lex_state = 2},
  [16769] = {.lex_state = 32, .external_lex_state = 2},
  [16770] = {.lex_state = 54, .external_lex_state = 2},
  [16771] = {.lex_state = 265, .external_lex_state = 8},
  [16772] = {.lex_state = 54, .external_lex_state = 2},
  [16773] = {.lex_state = 24, .external_lex_state = 2},
  [16774] = {.lex_state = 54, .external_lex_state = 2},
  [16775] = {.lex_state = 259, .external_lex_state = 2},
  [16776] = {.lex_state = 437, .external_lex_state = 2},
  [16777] = {.lex_state = 54, .external_lex_state = 2},
  [16778] = {.lex_state = 43, .external_lex_state = 2},
  [16779] = {.lex_state = 445, .external_lex_state = 2},
  [16780] = {.lex_state = 445, .external_lex_state = 2},
  [16781] = {.lex_state = 54, .external_lex_state = 2},
  [16782] = {.lex_state = 10, .external_lex_state = 2},
  [16783] = {.lex_state = 24, .external_lex_state = 2},
  [16784] = {.lex_state = 24, .external_lex_state = 2},
  [16785] = {.lex_state = 54, .external_lex_state = 2},
  [16786] = {.lex_state = 54, .external_lex_state = 2},
  [16787] = {.lex_state = 10, .external_lex_state = 2},
  [16788] = {.lex_state = 24, .external_lex_state = 2},
  [16789] = {.lex_state = 445, .external_lex_state = 2},
  [16790] = {.lex_state = 54, .external_lex_state = 2},
  [16791] = {.lex_state = 445, .external_lex_state = 2},
  [16792] = {.lex_state = 32, .external_lex_state = 2},
  [16793] = {.lex_state = 54, .external_lex_state = 2},
  [16794] = {.lex_state = 437, .external_lex_state = 2},
  [16795] = {.lex_state = 445, .external_lex_state = 2},
  [16796] = {.lex_state = 144, .external_lex_state = 2},
  [16797] = {.lex_state = 437, .external_lex_state = 2},
  [16798] = {.lex_state = 54, .external_lex_state = 2},
  [16799] = {.lex_state = 54, .external_lex_state = 2},
  [16800] = {.lex_state = 32, .external_lex_state = 2},
  [16801] = {.lex_state = 54, .external_lex_state = 2},
  [16802] = {.lex_state = 54, .external_lex_state = 2},
  [16803] = {.lex_state = 24, .external_lex_state = 2},
  [16804] = {.lex_state = 32, .external_lex_state = 2},
  [16805] = {.lex_state = 32, .external_lex_state = 2},
  [16806] = {.lex_state = 10, .external_lex_state = 2},
  [16807] = {.lex_state = 32, .external_lex_state = 2},
  [16808] = {.lex_state = 437, .external_lex_state = 2},
  [16809] = {.lex_state = 54, .external_lex_state = 2},
  [16810] = {.lex_state = 10, .external_lex_state = 2},
  [16811] = {.lex_state = 259, .external_lex_state = 2},
  [16812] = {.lex_state = 33, .external_lex_state = 2},
  [16813] = {.lex_state = 24, .external_lex_state = 2},
  [16814] = {.lex_state = 54, .external_lex_state = 2},
  [16815] = {.lex_state = 54, .external_lex_state = 2},
  [16816] = {.lex_state = 437, .external_lex_state = 2},
  [16817] = {.lex_state = 54, .external_lex_state = 2},
  [16818] = {.lex_state = 24, .external_lex_state = 2},
  [16819] = {.lex_state = 10, .external_lex_state = 2},
  [16820] = {.lex_state = 24, .external_lex_state = 2},
  [16821] = {.lex_state = 10, .external_lex_state = 2},
  [16822] = {.lex_state = 24, .external_lex_state = 2},
  [16823] = {.lex_state = 144, .external_lex_state = 2},
  [16824] = {.lex_state = 43, .external_lex_state = 2},
  [16825] = {.lex_state = 24, .external_lex_state = 2},
  [16826] = {.lex_state = 10, .external_lex_state = 2},
  [16827] = {.lex_state = 437, .external_lex_state = 2},
  [16828] = {.lex_state = 10, .external_lex_state = 2},
  [16829] = {.lex_state = 24, .external_lex_state = 2},
  [16830] = {.lex_state = 32, .external_lex_state = 2},
  [16831] = {.lex_state = 10, .external_lex_state = 2},
  [16832] = {.lex_state = 10, .external_lex_state = 2},
  [16833] = {.lex_state = 24, .external_lex_state = 2},
  [16834] = {.lex_state = 54, .external_lex_state = 2},
  [16835] = {.lex_state = 437, .external_lex_state = 3},
  [16836] = {.lex_state = 54, .external_lex_state = 2},
  [16837] = {.lex_state = 10, .external_lex_state = 2},
  [16838] = {.lex_state = 54, .external_lex_state = 2},
  [16839] = {.lex_state = 32, .external_lex_state = 2},
  [16840] = {.lex_state = 10, .external_lex_state = 2},
  [16841] = {.lex_state = 24, .external_lex_state = 2},
  [16842] = {.lex_state = 54, .external_lex_state = 2},
  [16843] = {.lex_state = 265, .external_lex_state = 8},
  [16844] = {.lex_state = 54, .external_lex_state = 2},
  [16845] = {.lex_state = 259, .external_lex_state = 2},
  [16846] = {.lex_state = 437, .external_lex_state = 2},
  [16847] = {.lex_state = 10, .external_lex_state = 2},
  [16848] = {.lex_state = 10, .external_lex_state = 2},
  [16849] = {.lex_state = 24, .external_lex_state = 2},
  [16850] = {.lex_state = 54, .external_lex_state = 2},
  [16851] = {.lex_state = 437, .external_lex_state = 3},
  [16852] = {.lex_state = 32, .external_lex_state = 2},
  [16853] = {.lex_state = 10, .external_lex_state = 2},
  [16854] = {.lex_state = 10, .external_lex_state = 2},
  [16855] = {.lex_state = 24, .external_lex_state = 2},
  [16856] = {.lex_state = 54, .external_lex_state = 2},
  [16857] = {.lex_state = 54, .external_lex_state = 2},
  [16858] = {.lex_state = 54, .external_lex_state = 2},
  [16859] = {.lex_state = 32, .external_lex_state = 2},
  [16860] = {.lex_state = 10, .external_lex_state = 2},
  [16861] = {.lex_state = 10, .external_lex_state = 2},
  [16862] = {.lex_state = 24, .external_lex_state = 2},
  [16863] = {.lex_state = 54, .external_lex_state = 2},
  [16864] = {.lex_state = 54, .external_lex_state = 2},
  [16865] = {.lex_state = 10, .external_lex_state = 2},
  [16866] = {.lex_state = 10, .external_lex_state = 2},
  [16867] = {.lex_state = 24, .external_lex_state = 2},
  [16868] = {.lex_state = 54, .external_lex_state = 2},
  [16869] = {.lex_state = 10, .external_lex_state = 2},
  [16870] = {.lex_state = 10, .external_lex_state = 2},
  [16871] = {.lex_state = 24, .external_lex_state = 2},
  [16872] = {.lex_state = 437, .external_lex_state = 2},
  [16873] = {.lex_state = 259, .external_lex_state = 2},
  [16874] = {.lex_state = 54, .external_lex_state = 2},
  [16875] = {.lex_state = 43, .external_lex_state = 2},
  [16876] = {.lex_state = 10, .external_lex_state = 2},
  [16877] = {.lex_state = 10, .external_lex_state = 2},
  [16878] = {.lex_state = 24, .external_lex_state = 2},
  [16879] = {.lex_state = 54, .external_lex_state = 2},
  [16880] = {.lex_state = 54, .external_lex_state = 2},
  [16881] = {.lex_state = 54, .external_lex_state = 2},
  [16882] = {.lex_state = 10, .external_lex_state = 2},
  [16883] = {.lex_state = 10, .external_lex_state = 2},
  [16884] = {.lex_state = 24, .external_lex_state = 2},
  [16885] = {.lex_state = 54, .external_lex_state = 2},
  [16886] = {.lex_state = 54, .external_lex_state = 2},
  [16887] = {.lex_state = 54, .external_lex_state = 2},
  [16888] = {.lex_state = 54, .external_lex_state = 2},
  [16889] = {.lex_state = 10, .external_lex_state = 2},
  [16890] = {.lex_state = 144, .external_lex_state = 2},
  [16891] = {.lex_state = 10, .external_lex_state = 2},
  [16892] = {.lex_state = 24, .external_lex_state = 2},
  [16893] = {.lex_state = 54, .external_lex_state = 2},
  [16894] = {.lex_state = 24, .external_lex_state = 2},
  [16895] = {.lex_state = 10, .external_lex_state = 2},
  [16896] = {.lex_state = 10, .external_lex_state = 2},
  [16897] = {.lex_state = 24, .external_lex_state = 2},
  [16898] = {.lex_state = 54, .external_lex_state = 2},
  [16899] = {.lex_state = 54, .external_lex_state = 2},
  [16900] = {.lex_state = 54, .external_lex_state = 2},
  [16901] = {.lex_state = 32, .external_lex_state = 2},
  [16902] = {.lex_state = 10, .external_lex_state = 2},
  [16903] = {.lex_state = 54, .external_lex_state = 2},
  [16904] = {.lex_state = 10, .external_lex_state = 2},
  [16905] = {.lex_state = 24, .external_lex_state = 2},
  [16906] = {.lex_state = 43, .external_lex_state = 2},
  [16907] = {.lex_state = 445, .external_lex_state = 2},
  [16908] = {.lex_state = 10, .external_lex_state = 2},
  [16909] = {.lex_state = 54, .external_lex_state = 2},
  [16910] = {.lex_state = 10, .external_lex_state = 2},
  [16911] = {.lex_state = 24, .external_lex_state = 2},
  [16912] = {.lex_state = 54, .external_lex_state = 2},
  [16913] = {.lex_state = 32, .external_lex_state = 2},
  [16914] = {.lex_state = 144, .external_lex_state = 2},
  [16915] = {.lex_state = 10, .external_lex_state = 2},
  [16916] = {.lex_state = 10, .external_lex_state = 2},
  [16917] = {.lex_state = 24, .external_lex_state = 2},
  [16918] = {.lex_state = 32, .external_lex_state = 2},
  [16919] = {.lex_state = 144, .external_lex_state = 2},
  [16920] = {.lex_state = 10, .external_lex_state = 2},
  [16921] = {.lex_state = 54, .external_lex_state = 2},
  [16922] = {.lex_state = 10, .external_lex_state = 2},
  [16923] = {.lex_state = 24, .external_lex_state = 2},
  [16924] = {.lex_state = 144, .external_lex_state = 2},
  [16925] = {.lex_state = 54, .external_lex_state = 2},
  [16926] = {.lex_state = 43, .external_lex_state = 2},
  [16927] = {.lex_state = 43, .external_lex_state = 2},
  [16928] = {.lex_state = 10, .external_lex_state = 2},
  [16929] = {.lex_state = 10, .external_lex_state = 2},
  [16930] = {.lex_state = 24, .external_lex_state = 2},
  [16931] = {.lex_state = 437, .external_lex_state = 2},
  [16932] = {.lex_state = 54, .external_lex_state = 2},
  [16933] = {.lex_state = 54, .external_lex_state = 2},
  [16934] = {.lex_state = 54, .external_lex_state = 2},
  [16935] = {.lex_state = 10, .external_lex_state = 2},
  [16936] = {.lex_state = 10, .external_lex_state = 2},
  [16937] = {.lex_state = 24, .external_lex_state = 2},
  [16938] = {.lex_state = 144, .external_lex_state = 2},
  [16939] = {.lex_state = 54, .external_lex_state = 2},
  [16940] = {.lex_state = 54, .external_lex_state = 2},
  [16941] = {.lex_state = 10, .external_lex_state = 2},
  [16942] = {.lex_state = 10, .external_lex_state = 2},
  [16943] = {.lex_state = 24, .external_lex_state = 2},
  [16944] = {.lex_state = 54, .external_lex_state = 2},
  [16945] = {.lex_state = 54, .external_lex_state = 2},
  [16946] = {.lex_state = 144, .external_lex_state = 2},
  [16947] = {.lex_state = 54, .external_lex_state = 2},
  [16948] = {.lex_state = 54, .external_lex_state = 2},
  [16949] = {.lex_state = 54, .external_lex_state = 2},
  [16950] = {.lex_state = 10, .external_lex_state = 2},
  [16951] = {.lex_state = 10, .external_lex_state = 2},
  [16952] = {.lex_state = 24, .external_lex_state = 2},
  [16953] = {.lex_state = 54, .external_lex_state = 2},
  [16954] = {.lex_state = 445, .external_lex_state = 2},
  [16955] = {.lex_state = 32, .external_lex_state = 2},
  [16956] = {.lex_state = 32, .external_lex_state = 2},
  [16957] = {.lex_state = 10, .external_lex_state = 2},
  [16958] = {.lex_state = 54, .external_lex_state = 2},
  [16959] = {.lex_state = 10, .external_lex_state = 2},
  [16960] = {.lex_state = 24, .external_lex_state = 2},
  [16961] = {.lex_state = 259, .external_lex_state = 2},
  [16962] = {.lex_state = 43, .external_lex_state = 2},
  [16963] = {.lex_state = 43, .external_lex_state = 2},
  [16964] = {.lex_state = 54, .external_lex_state = 2},
  [16965] = {.lex_state = 10, .external_lex_state = 2},
  [16966] = {.lex_state = 144, .external_lex_state = 2},
  [16967] = {.lex_state = 10, .external_lex_state = 2},
  [16968] = {.lex_state = 24, .external_lex_state = 2},
  [16969] = {.lex_state = 10, .external_lex_state = 2},
  [16970] = {.lex_state = 144, .external_lex_state = 2},
  [16971] = {.lex_state = 445, .external_lex_state = 2},
  [16972] = {.lex_state = 10, .external_lex_state = 2},
  [16973] = {.lex_state = 10, .external_lex_state = 2},
  [16974] = {.lex_state = 24, .external_lex_state = 2},
  [16975] = {.lex_state = 259, .external_lex_state = 2},
  [16976] = {.lex_state = 54, .external_lex_state = 2},
  [16977] = {.lex_state = 10, .external_lex_state = 2},
  [16978] = {.lex_state = 10, .external_lex_state = 2},
  [16979] = {.lex_state = 24, .external_lex_state = 2},
  [16980] = {.lex_state = 437, .external_lex_state = 2},
  [16981] = {.lex_state = 32, .external_lex_state = 2},
  [16982] = {.lex_state = 10, .external_lex_state = 2},
  [16983] = {.lex_state = 32, .external_lex_state = 2},
  [16984] = {.lex_state = 10, .external_lex_state = 2},
  [16985] = {.lex_state = 24, .external_lex_state = 2},
  [16986] = {.lex_state = 54, .external_lex_state = 2},
  [16987] = {.lex_state = 445, .external_lex_state = 2},
  [16988] = {.lex_state = 10, .external_lex_state = 2},
  [16989] = {.lex_state = 10, .external_lex_state = 2},
  [16990] = {.lex_state = 24, .external_lex_state = 2},
  [16991] = {.lex_state = 445, .external_lex_state = 2},
  [16992] = {.lex_state = 32, .external_lex_state = 2},
  [16993] = {.lex_state = 32, .external_lex_state = 2},
  [16994] = {.lex_state = 32, .external_lex_state = 2},
  [16995] = {.lex_state = 54, .external_lex_state = 2},
  [16996] = {.lex_state = 10, .external_lex_state = 2},
  [16997] = {.lex_state = 32, .external_lex_state = 2},
  [16998] = {.lex_state = 10, .external_lex_state = 2},
  [16999] = {.lex_state = 24, .external_lex_state = 2},
  [17000] = {.lex_state = 32, .external_lex_state = 2},
  [17001] = {.lex_state = 54, .external_lex_state = 2},
  [17002] = {.lex_state = 10, .external_lex_state = 2},
  [17003] = {.lex_state = 144, .external_lex_state = 2},
  [17004] = {.lex_state = 10, .external_lex_state = 2},
  [17005] = {.lex_state = 24, .external_lex_state = 2},
  [17006] = {.lex_state = 54, .external_lex_state = 2},
  [17007] = {.lex_state = 10, .external_lex_state = 2},
  [17008] = {.lex_state = 10, .external_lex_state = 2},
  [17009] = {.lex_state = 24, .external_lex_state = 2},
  [17010] = {.lex_state = 32, .external_lex_state = 2},
  [17011] = {.lex_state = 10, .external_lex_state = 2},
  [17012] = {.lex_state = 32, .external_lex_state = 2},
  [17013] = {.lex_state = 10, .external_lex_state = 2},
  [17014] = {.lex_state = 24, .external_lex_state = 2},
  [17015] = {.lex_state = 54, .external_lex_state = 2},
  [17016] = {.lex_state = 54, .external_lex_state = 2},
  [17017] = {.lex_state = 54, .external_lex_state = 2},
  [17018] = {.lex_state = 259, .external_lex_state = 2},
  [17019] = {.lex_state = 10, .external_lex_state = 2},
  [17020] = {.lex_state = 10, .external_lex_state = 2},
  [17021] = {.lex_state = 24, .external_lex_state = 2},
  [17022] = {.lex_state = 24, .external_lex_state = 2},
  [17023] = {.lex_state = 43, .external_lex_state = 2},
  [17024] = {.lex_state = 437, .external_lex_state = 2},
  [17025] = {.lex_state = 10, .external_lex_state = 2},
  [17026] = {.lex_state = 10, .external_lex_state = 2},
  [17027] = {.lex_state = 24, .external_lex_state = 2},
  [17028] = {.lex_state = 259, .external_lex_state = 2},
  [17029] = {.lex_state = 54, .external_lex_state = 2},
  [17030] = {.lex_state = 10, .external_lex_state = 2},
  [17031] = {.lex_state = 259, .external_lex_state = 2},
  [17032] = {.lex_state = 10, .external_lex_state = 2},
  [17033] = {.lex_state = 24, .external_lex_state = 2},
  [17034] = {.lex_state = 54, .external_lex_state = 2},
  [17035] = {.lex_state = 54, .external_lex_state = 2},
  [17036] = {.lex_state = 10, .external_lex_state = 2},
  [17037] = {.lex_state = 10, .external_lex_state = 2},
  [17038] = {.lex_state = 24, .external_lex_state = 2},
  [17039] = {.lex_state = 54, .external_lex_state = 2},
  [17040] = {.lex_state = 32, .external_lex_state = 2},
  [17041] = {.lex_state = 43, .external_lex_state = 2},
  [17042] = {.lex_state = 54, .external_lex_state = 2},
  [17043] = {.lex_state = 54, .external_lex_state = 2},
  [17044] = {.lex_state = 10, .external_lex_state = 2},
  [17045] = {.lex_state = 10, .external_lex_state = 2},
  [17046] = {.lex_state = 24, .external_lex_state = 2},
  [17047] = {.lex_state = 43, .external_lex_state = 2},
  [17048] = {.lex_state = 32, .external_lex_state = 2},
  [17049] = {.lex_state = 24, .external_lex_state = 2},
  [17050] = {.lex_state = 445, .external_lex_state = 2},
  [17051] = {.lex_state = 10, .external_lex_state = 2},
  [17052] = {.lex_state = 54, .external_lex_state = 2},
  [17053] = {.lex_state = 10, .external_lex_state = 2},
  [17054] = {.lex_state = 24, .external_lex_state = 2},
  [17055] = {.lex_state = 32, .external_lex_state = 2},
  [17056] = {.lex_state = 10, .external_lex_state = 2},
  [17057] = {.lex_state = 24, .external_lex_state = 2},
  [17058] = {.lex_state = 24, .external_lex_state = 2},
  [17059] = {.lex_state = 54, .external_lex_state = 2},
  [17060] = {.lex_state = 10, .external_lex_state = 2},
  [17061] = {.lex_state = 24, .external_lex_state = 2},
  [17062] = {.lex_state = 10, .external_lex_state = 2},
  [17063] = {.lex_state = 24, .external_lex_state = 2},
  [17064] = {.lex_state = 10, .external_lex_state = 2},
  [17065] = {.lex_state = 24, .external_lex_state = 2},
  [17066] = {.lex_state = 10, .external_lex_state = 2},
  [17067] = {.lex_state = 24, .external_lex_state = 2},
  [17068] = {.lex_state = 10, .external_lex_state = 2},
  [17069] = {.lex_state = 24, .external_lex_state = 2},
  [17070] = {.lex_state = 10, .external_lex_state = 2},
  [17071] = {.lex_state = 24, .external_lex_state = 2},
  [17072] = {.lex_state = 10, .external_lex_state = 2},
  [17073] = {.lex_state = 24, .external_lex_state = 2},
  [17074] = {.lex_state = 10, .external_lex_state = 2},
  [17075] = {.lex_state = 24, .external_lex_state = 2},
  [17076] = {.lex_state = 10, .external_lex_state = 2},
  [17077] = {.lex_state = 24, .external_lex_state = 2},
  [17078] = {.lex_state = 10, .external_lex_state = 2},
  [17079] = {.lex_state = 24, .external_lex_state = 2},
  [17080] = {.lex_state = 10, .external_lex_state = 2},
  [17081] = {.lex_state = 24, .external_lex_state = 2},
  [17082] = {.lex_state = 10, .external_lex_state = 2},
  [17083] = {.lex_state = 24, .external_lex_state = 2},
  [17084] = {.lex_state = 10, .external_lex_state = 2},
  [17085] = {.lex_state = 24, .external_lex_state = 2},
  [17086] = {.lex_state = 24, .external_lex_state = 2},
  [17087] = {.lex_state = 24, .external_lex_state = 2},
  [17088] = {.lex_state = 24, .external_lex_state = 2},
  [17089] = {.lex_state = 24, .external_lex_state = 2},
  [17090] = {.lex_state = 24, .external_lex_state = 2},
  [17091] = {.lex_state = 24, .external_lex_state = 2},
  [17092] = {.lex_state = 24, .external_lex_state = 2},
  [17093] = {.lex_state = 24, .external_lex_state = 2},
  [17094] = {.lex_state = 24, .external_lex_state = 2},
  [17095] = {.lex_state = 24, .external_lex_state = 2},
  [17096] = {.lex_state = 24, .external_lex_state = 2},
  [17097] = {.lex_state = 24, .external_lex_state = 2},
  [17098] = {.lex_state = 24, .external_lex_state = 2},
  [17099] = {.lex_state = 24, .external_lex_state = 2},
  [17100] = {.lex_state = 24, .external_lex_state = 2},
  [17101] = {.lex_state = 24, .external_lex_state = 2},
  [17102] = {.lex_state = 24, .external_lex_state = 2},
  [17103] = {.lex_state = 24, .external_lex_state = 2},
  [17104] = {.lex_state = 24, .external_lex_state = 2},
  [17105] = {.lex_state = 24, .external_lex_state = 2},
  [17106] = {.lex_state = 24, .external_lex_state = 2},
  [17107] = {.lex_state = 24, .external_lex_state = 2},
  [17108] = {.lex_state = 24, .external_lex_state = 2},
  [17109] = {.lex_state = 32, .external_lex_state = 2},
  [17110] = {.lex_state = 24, .external_lex_state = 2},
  [17111] = {.lex_state = 54, .external_lex_state = 2},
  [17112] = {.lex_state = 437, .external_lex_state = 2},
  [17113] = {.lex_state = 265, .external_lex_state = 8},
  [17114] = {.lex_state = 437, .external_lex_state = 2},
  [17115] = {.lex_state = 259, .external_lex_state = 2},
  [17116] = {.lex_state = 43, .external_lex_state = 2},
  [17117] = {.lex_state = 54, .external_lex_state = 2},
  [17118] = {.lex_state = 54, .external_lex_state = 2},
  [17119] = {.lex_state = 437, .external_lex_state = 2},
  [17120] = {.lex_state = 144, .external_lex_state = 2},
  [17121] = {.lex_state = 445, .external_lex_state = 2},
  [17122] = {.lex_state = 32, .external_lex_state = 2},
  [17123] = {.lex_state = 54, .external_lex_state = 2},
  [17124] = {.lex_state = 43, .external_lex_state = 2},
  [17125] = {.lex_state = 54, .external_lex_state = 2},
  [17126] = {.lex_state = 437, .external_lex_state = 2},
  [17127] = {.lex_state = 54, .external_lex_state = 2},
  [17128] = {.lex_state = 11, .external_lex_state = 2},
  [17129] = {.lex_state = 437, .external_lex_state = 2},
  [17130] = {.lex_state = 437, .external_lex_state = 2},
  [17131] = {.lex_state = 24, .external_lex_state = 2},
  [17132] = {.lex_state = 54, .external_lex_state = 2},
  [17133] = {.lex_state = 437, .external_lex_state = 2},
  [17134] = {.lex_state = 437, .external_lex_state = 2},
  [17135] = {.lex_state = 437, .external_lex_state = 2},
  [17136] = {.lex_state = 437, .external_lex_state = 2},
  [17137] = {.lex_state = 437, .external_lex_state = 2},
  [17138] = {.lex_state = 445, .external_lex_state = 2},
  [17139] = {.lex_state = 54, .external_lex_state = 2},
  [17140] = {.lex_state = 32, .external_lex_state = 2},
  [17141] = {.lex_state = 54, .external_lex_state = 2},
  [17142] = {.lex_state = 54, .external_lex_state = 2},
  [17143] = {.lex_state = 437, .external_lex_state = 2},
  [17144] = {.lex_state = 24, .external_lex_state = 2},
  [17145] = {.lex_state = 24, .external_lex_state = 2},
  [17146] = {.lex_state = 54, .external_lex_state = 2},
  [17147] = {.lex_state = 24, .external_lex_state = 2},
  [17148] = {.lex_state = 54, .external_lex_state = 2},
  [17149] = {.lex_state = 24, .external_lex_state = 2},
  [17150] = {.lex_state = 32, .external_lex_state = 2},
  [17151] = {.lex_state = 437, .external_lex_state = 2},
  [17152] = {.lex_state = 10, .external_lex_state = 2},
  [17153] = {.lex_state = 144, .external_lex_state = 2},
  [17154] = {.lex_state = 32, .external_lex_state = 2},
  [17155] = {.lex_state = 437, .external_lex_state = 2},
  [17156] = {.lex_state = 437, .external_lex_state = 2},
  [17157] = {.lex_state = 437, .external_lex_state = 2},
  [17158] = {.lex_state = 54, .external_lex_state = 2},
  [17159] = {.lex_state = 54, .external_lex_state = 2},
  [17160] = {.lex_state = 54, .external_lex_state = 2},
  [17161] = {.lex_state = 32, .external_lex_state = 2},
  [17162] = {.lex_state = 437, .external_lex_state = 2},
  [17163] = {.lex_state = 24, .external_lex_state = 2},
  [17164] = {.lex_state = 54, .external_lex_state = 2},
  [17165] = {.lex_state = 24, .external_lex_state = 2},
  [17166] = {.lex_state = 437, .external_lex_state = 2},
  [17167] = {.lex_state = 445, .external_lex_state = 2},
  [17168] = {.lex_state = 32, .external_lex_state = 2},
  [17169] = {.lex_state = 24, .external_lex_state = 2},
  [17170] = {.lex_state = 32, .external_lex_state = 2},
  [17171] = {.lex_state = 54, .external_lex_state = 2},
  [17172] = {.lex_state = 437, .external_lex_state = 2},
  [17173] = {.lex_state = 54, .external_lex_state = 2},
  [17174] = {.lex_state = 32, .external_lex_state = 2},
  [17175] = {.lex_state = 437, .external_lex_state = 2},
  [17176] = {.lex_state = 54, .external_lex_state = 2},
  [17177] = {.lex_state = 43, .external_lex_state = 2},
  [17178] = {.lex_state = 32, .external_lex_state = 2},
  [17179] = {.lex_state = 54, .external_lex_state = 2},
  [17180] = {.lex_state = 54, .external_lex_state = 2},
  [17181] = {.lex_state = 144, .external_lex_state = 2},
  [17182] = {.lex_state = 24, .external_lex_state = 2},
  [17183] = {.lex_state = 437, .external_lex_state = 2},
  [17184] = {.lex_state = 43, .external_lex_state = 2},
  [17185] = {.lex_state = 437, .external_lex_state = 2},
  [17186] = {.lex_state = 54, .external_lex_state = 2},
  [17187] = {.lex_state = 54, .external_lex_state = 2},
  [17188] = {.lex_state = 437, .external_lex_state = 2},
  [17189] = {.lex_state = 24, .external_lex_state = 2},
  [17190] = {.lex_state = 32, .external_lex_state = 2},
  [17191] = {.lex_state = 32, .external_lex_state = 2},
  [17192] = {.lex_state = 24, .external_lex_state = 2},
  [17193] = {.lex_state = 54, .external_lex_state = 2},
  [17194] = {.lex_state = 24, .external_lex_state = 2},
  [17195] = {.lex_state = 24, .external_lex_state = 2},
  [17196] = {.lex_state = 32, .external_lex_state = 2},
  [17197] = {.lex_state = 24, .external_lex_state = 2},
  [17198] = {.lex_state = 24, .external_lex_state = 2},
  [17199] = {.lex_state = 24, .external_lex_state = 2},
  [17200] = {.lex_state = 437, .external_lex_state = 2},
  [17201] = {.lex_state = 24, .external_lex_state = 2},
  [17202] = {.lex_state = 437, .external_lex_state = 2},
  [17203] = {.lex_state = 24, .external_lex_state = 2},
  [17204] = {.lex_state = 54, .external_lex_state = 2},
  [17205] = {.lex_state = 437, .external_lex_state = 2},
  [17206] = {.lex_state = 437, .external_lex_state = 2},
  [17207] = {.lex_state = 24, .external_lex_state = 2},
  [17208] = {.lex_state = 437, .external_lex_state = 2},
  [17209] = {.lex_state = 24, .external_lex_state = 2},
  [17210] = {.lex_state = 437, .external_lex_state = 2},
  [17211] = {.lex_state = 32, .external_lex_state = 2},
  [17212] = {.lex_state = 437, .external_lex_state = 2},
  [17213] = {.lex_state = 24, .external_lex_state = 2},
  [17214] = {.lex_state = 24, .external_lex_state = 2},
  [17215] = {.lex_state = 32, .external_lex_state = 2},
  [17216] = {.lex_state = 24, .external_lex_state = 2},
  [17217] = {.lex_state = 32, .external_lex_state = 2},
  [17218] = {.lex_state = 24, .external_lex_state = 2},
  [17219] = {.lex_state = 24, .external_lex_state = 2},
  [17220] = {.lex_state = 437, .external_lex_state = 2},
  [17221] = {.lex_state = 24, .external_lex_state = 2},
  [17222] = {.lex_state = 437, .external_lex_state = 2},
  [17223] = {.lex_state = 437, .external_lex_state = 2},
  [17224] = {.lex_state = 24, .external_lex_state = 2},
  [17225] = {.lex_state = 24, .external_lex_state = 2},
  [17226] = {.lex_state = 437, .external_lex_state = 2},
  [17227] = {.lex_state = 437, .external_lex_state = 2},
  [17228] = {.lex_state = 32, .external_lex_state = 2},
  [17229] = {.lex_state = 24, .external_lex_state = 2},
  [17230] = {.lex_state = 24, .external_lex_state = 2},
  [17231] = {.lex_state = 24, .external_lex_state = 2},
  [17232] = {.lex_state = 32, .external_lex_state = 2},
  [17233] = {.lex_state = 24, .external_lex_state = 2},
  [17234] = {.lex_state = 8, .external_lex_state = 2},
  [17235] = {.lex_state = 24, .external_lex_state = 2},
  [17236] = {.lex_state = 24, .external_lex_state = 2},
  [17237] = {.lex_state = 24, .external_lex_state = 2},
  [17238] = {.lex_state = 32, .external_lex_state = 2},
  [17239] = {.lex_state = 437, .external_lex_state = 2},
  [17240] = {.lex_state = 24, .external_lex_state = 2},
  [17241] = {.lex_state = 437, .external_lex_state = 2},
  [17242] = {.lex_state = 32, .external_lex_state = 2},
  [17243] = {.lex_state = 437, .external_lex_state = 2},
  [17244] = {.lex_state = 32, .external_lex_state = 2},
  [17245] = {.lex_state = 24, .external_lex_state = 2},
  [17246] = {.lex_state = 24, .external_lex_state = 2},
  [17247] = {.lex_state = 437, .external_lex_state = 2},
  [17248] = {.lex_state = 437, .external_lex_state = 2},
  [17249] = {.lex_state = 437, .external_lex_state = 2},
  [17250] = {.lex_state = 437, .external_lex_state = 2},
  [17251] = {.lex_state = 437, .external_lex_state = 2},
  [17252] = {.lex_state = 437, .external_lex_state = 2},
  [17253] = {.lex_state = 437, .external_lex_state = 2},
  [17254] = {.lex_state = 437, .external_lex_state = 2},
  [17255] = {.lex_state = 24, .external_lex_state = 2},
  [17256] = {.lex_state = 437, .external_lex_state = 2},
  [17257] = {.lex_state = 24, .external_lex_state = 2},
  [17258] = {.lex_state = 24, .external_lex_state = 2},
  [17259] = {.lex_state = 32, .external_lex_state = 2},
  [17260] = {.lex_state = 32, .external_lex_state = 2},
  [17261] = {.lex_state = 24, .external_lex_state = 2},
  [17262] = {.lex_state = 24, .external_lex_state = 2},
  [17263] = {.lex_state = 437, .external_lex_state = 2},
  [17264] = {.lex_state = 24, .external_lex_state = 2},
  [17265] = {.lex_state = 437, .external_lex_state = 2},
  [17266] = {.lex_state = 24, .external_lex_state = 2},
  [17267] = {.lex_state = 437, .external_lex_state = 2},
  [17268] = {.lex_state = 437, .external_lex_state = 8},
  [17269] = {.lex_state = 437, .external_lex_state = 2},
  [17270] = {.lex_state = 24, .external_lex_state = 2},
  [17271] = {.lex_state = 437, .external_lex_state = 2},
  [17272] = {.lex_state = 437, .external_lex_state = 8},
  [17273] = {.lex_state = 437, .external_lex_state = 2},
  [17274] = {.lex_state = 437, .external_lex_state = 2},
  [17275] = {.lex_state = 8, .external_lex_state = 2},
  [17276] = {.lex_state = 24, .external_lex_state = 2},
  [17277] = {.lex_state = 437, .external_lex_state = 2},
  [17278] = {.lex_state = 32, .external_lex_state = 2},
  [17279] = {.lex_state = 437, .external_lex_state = 2},
  [17280] = {.lex_state = 32, .external_lex_state = 2},
  [17281] = {.lex_state = 437, .external_lex_state = 2},
  [17282] = {.lex_state = 24, .external_lex_state = 2},
  [17283] = {.lex_state = 24, .external_lex_state = 2},
  [17284] = {.lex_state = 24, .external_lex_state = 2},
  [17285] = {.lex_state = 8, .external_lex_state = 2},
  [17286] = {.lex_state = 54, .external_lex_state = 2},
  [17287] = {.lex_state = 54, .external_lex_state = 2},
  [17288] = {.lex_state = 54, .external_lex_state = 2},
  [17289] = {.lex_state = 24, .external_lex_state = 2},
  [17290] = {.lex_state = 24, .external_lex_state = 2},
  [17291] = {.lex_state = 24, .external_lex_state = 2},
  [17292] = {.lex_state = 437, .external_lex_state = 2},
  [17293] = {.lex_state = 24, .external_lex_state = 2},
  [17294] = {.lex_state = 32, .external_lex_state = 2},
  [17295] = {.lex_state = 24, .external_lex_state = 2},
  [17296] = {.lex_state = 24, .external_lex_state = 2},
  [17297] = {.lex_state = 32, .external_lex_state = 2},
  [17298] = {.lex_state = 437, .external_lex_state = 2},
  [17299] = {.lex_state = 437, .external_lex_state = 2},
  [17300] = {.lex_state = 437, .external_lex_state = 2},
  [17301] = {.lex_state = 24, .external_lex_state = 2},
  [17302] = {.lex_state = 32, .external_lex_state = 2},
  [17303] = {.lex_state = 32, .external_lex_state = 2},
  [17304] = {.lex_state = 24, .external_lex_state = 2},
  [17305] = {.lex_state = 24, .external_lex_state = 2},
  [17306] = {.lex_state = 437, .external_lex_state = 2},
  [17307] = {.lex_state = 24, .external_lex_state = 2},
  [17308] = {.lex_state = 24, .external_lex_state = 2},
  [17309] = {.lex_state = 437, .external_lex_state = 2},
  [17310] = {.lex_state = 24, .external_lex_state = 2},
  [17311] = {.lex_state = 24, .external_lex_state = 2},
  [17312] = {.lex_state = 437, .external_lex_state = 2},
  [17313] = {.lex_state = 24, .external_lex_state = 2},
  [17314] = {.lex_state = 24, .external_lex_state = 2},
  [17315] = {.lex_state = 24, .external_lex_state = 2},
  [17316] = {.lex_state = 54, .external_lex_state = 2},
  [17317] = {.lex_state = 24, .external_lex_state = 2},
  [17318] = {.lex_state = 24, .external_lex_state = 2},
  [17319] = {.lex_state = 24, .external_lex_state = 2},
  [17320] = {.lex_state = 24, .external_lex_state = 2},
  [17321] = {.lex_state = 32, .external_lex_state = 2},
  [17322] = {.lex_state = 437, .external_lex_state = 2},
  [17323] = {.lex_state = 24, .external_lex_state = 2},
  [17324] = {.lex_state = 32, .external_lex_state = 2},
  [17325] = {.lex_state = 24, .external_lex_state = 2},
  [17326] = {.lex_state = 54, .external_lex_state = 2},
  [17327] = {.lex_state = 32, .external_lex_state = 2},
  [17328] = {.lex_state = 24, .external_lex_state = 2},
  [17329] = {.lex_state = 32, .external_lex_state = 2},
  [17330] = {.lex_state = 437, .external_lex_state = 2},
  [17331] = {.lex_state = 24, .external_lex_state = 2},
  [17332] = {.lex_state = 24, .external_lex_state = 2},
  [17333] = {.lex_state = 24, .external_lex_state = 2},
  [17334] = {.lex_state = 24, .external_lex_state = 2},
  [17335] = {.lex_state = 24, .external_lex_state = 2},
  [17336] = {.lex_state = 24, .external_lex_state = 2},
  [17337] = {.lex_state = 437, .external_lex_state = 2},
  [17338] = {.lex_state = 437, .external_lex_state = 2},
  [17339] = {.lex_state = 437, .external_lex_state = 8},
  [17340] = {.lex_state = 24, .external_lex_state = 2},
  [17341] = {.lex_state = 32, .external_lex_state = 2},
  [17342] = {.lex_state = 437, .external_lex_state = 8},
  [17343] = {.lex_state = 32, .external_lex_state = 2},
  [17344] = {.lex_state = 24, .external_lex_state = 2},
  [17345] = {.lex_state = 437, .external_lex_state = 2},
  [17346] = {.lex_state = 24, .external_lex_state = 2},
  [17347] = {.lex_state = 32, .external_lex_state = 2},
  [17348] = {.lex_state = 437, .external_lex_state = 2},
  [17349] = {.lex_state = 437, .external_lex_state = 2},
  [17350] = {.lex_state = 437, .external_lex_state = 2},
  [17351] = {.lex_state = 437, .external_lex_state = 2},
  [17352] = {.lex_state = 24, .external_lex_state = 2},
  [17353] = {.lex_state = 32, .external_lex_state = 2},
  [17354] = {.lex_state = 54, .external_lex_state = 2},
  [17355] = {.lex_state = 54, .external_lex_state = 2},
  [17356] = {.lex_state = 54, .external_lex_state = 2},
  [17357] = {.lex_state = 24, .external_lex_state = 2},
  [17358] = {.lex_state = 24, .external_lex_state = 2},
  [17359] = {.lex_state = 24, .external_lex_state = 2},
  [17360] = {.lex_state = 437, .external_lex_state = 2},
  [17361] = {.lex_state = 24, .external_lex_state = 2},
  [17362] = {.lex_state = 32, .external_lex_state = 2},
  [17363] = {.lex_state = 437, .external_lex_state = 2},
  [17364] = {.lex_state = 24, .external_lex_state = 2},
  [17365] = {.lex_state = 437, .external_lex_state = 2},
  [17366] = {.lex_state = 24, .external_lex_state = 2},
  [17367] = {.lex_state = 437, .external_lex_state = 2},
  [17368] = {.lex_state = 24, .external_lex_state = 2},
  [17369] = {.lex_state = 24, .external_lex_state = 2},
  [17370] = {.lex_state = 24, .external_lex_state = 2},
  [17371] = {.lex_state = 24, .external_lex_state = 2},
  [17372] = {.lex_state = 24, .external_lex_state = 2},
  [17373] = {.lex_state = 24, .external_lex_state = 2},
  [17374] = {.lex_state = 24, .external_lex_state = 2},
  [17375] = {.lex_state = 24, .external_lex_state = 2},
  [17376] = {.lex_state = 32, .external_lex_state = 2},
  [17377] = {.lex_state = 24, .external_lex_state = 2},
  [17378] = {.lex_state = 437, .external_lex_state = 2},
  [17379] = {.lex_state = 24, .external_lex_state = 2},
  [17380] = {.lex_state = 24, .external_lex_state = 2},
  [17381] = {.lex_state = 24, .external_lex_state = 2},
  [17382] = {.lex_state = 437, .external_lex_state = 2},
  [17383] = {.lex_state = 24, .external_lex_state = 2},
  [17384] = {.lex_state = 24, .external_lex_state = 2},
  [17385] = {.lex_state = 437, .external_lex_state = 2},
  [17386] = {.lex_state = 437, .external_lex_state = 2},
  [17387] = {.lex_state = 437, .external_lex_state = 2},
  [17388] = {.lex_state = 32, .external_lex_state = 2},
  [17389] = {.lex_state = 24, .external_lex_state = 2},
  [17390] = {.lex_state = 8, .external_lex_state = 2},
  [17391] = {.lex_state = 437, .external_lex_state = 2},
  [17392] = {.lex_state = 24, .external_lex_state = 2},
  [17393] = {.lex_state = 437, .external_lex_state = 2},
  [17394] = {.lex_state = 24, .external_lex_state = 2},
  [17395] = {.lex_state = 437, .external_lex_state = 2},
  [17396] = {.lex_state = 24, .external_lex_state = 2},
  [17397] = {.lex_state = 24, .external_lex_state = 2},
  [17398] = {.lex_state = 437, .external_lex_state = 8},
  [17399] = {.lex_state = 24, .external_lex_state = 2},
  [17400] = {.lex_state = 437, .external_lex_state = 8},
  [17401] = {.lex_state = 24, .external_lex_state = 2},
  [17402] = {.lex_state = 24, .external_lex_state = 2},
  [17403] = {.lex_state = 437, .external_lex_state = 2},
  [17404] = {.lex_state = 24, .external_lex_state = 2},
  [17405] = {.lex_state = 437, .external_lex_state = 2},
  [17406] = {.lex_state = 11, .external_lex_state = 2},
  [17407] = {.lex_state = 24, .external_lex_state = 2},
  [17408] = {.lex_state = 54, .external_lex_state = 2},
  [17409] = {.lex_state = 54, .external_lex_state = 2},
  [17410] = {.lex_state = 54, .external_lex_state = 2},
  [17411] = {.lex_state = 437, .external_lex_state = 2},
  [17412] = {.lex_state = 24, .external_lex_state = 2},
  [17413] = {.lex_state = 437, .external_lex_state = 2},
  [17414] = {.lex_state = 24, .external_lex_state = 2},
  [17415] = {.lex_state = 32, .external_lex_state = 2},
  [17416] = {.lex_state = 24, .external_lex_state = 2},
  [17417] = {.lex_state = 437, .external_lex_state = 2},
  [17418] = {.lex_state = 11, .external_lex_state = 2},
  [17419] = {.lex_state = 24, .external_lex_state = 2},
  [17420] = {.lex_state = 24, .external_lex_state = 2},
  [17421] = {.lex_state = 32, .external_lex_state = 2},
  [17422] = {.lex_state = 437, .external_lex_state = 2},
  [17423] = {.lex_state = 24, .external_lex_state = 2},
  [17424] = {.lex_state = 11, .external_lex_state = 2},
  [17425] = {.lex_state = 437, .external_lex_state = 2},
  [17426] = {.lex_state = 437, .external_lex_state = 2},
  [17427] = {.lex_state = 32, .external_lex_state = 2},
  [17428] = {.lex_state = 24, .external_lex_state = 2},
  [17429] = {.lex_state = 24, .external_lex_state = 2},
  [17430] = {.lex_state = 24, .external_lex_state = 2},
  [17431] = {.lex_state = 437, .external_lex_state = 2},
  [17432] = {.lex_state = 437, .external_lex_state = 2},
  [17433] = {.lex_state = 32, .external_lex_state = 2},
  [17434] = {.lex_state = 24, .external_lex_state = 2},
  [17435] = {.lex_state = 437, .external_lex_state = 2},
  [17436] = {.lex_state = 437, .external_lex_state = 2},
  [17437] = {.lex_state = 437, .external_lex_state = 8},
  [17438] = {.lex_state = 24, .external_lex_state = 2},
  [17439] = {.lex_state = 437, .external_lex_state = 8},
  [17440] = {.lex_state = 24, .external_lex_state = 2},
  [17441] = {.lex_state = 32, .external_lex_state = 2},
  [17442] = {.lex_state = 24, .external_lex_state = 2},
  [17443] = {.lex_state = 437, .external_lex_state = 2},
  [17444] = {.lex_state = 54, .external_lex_state = 2},
  [17445] = {.lex_state = 54, .external_lex_state = 2},
  [17446] = {.lex_state = 54, .external_lex_state = 2},
  [17447] = {.lex_state = 24, .external_lex_state = 2},
  [17448] = {.lex_state = 437, .external_lex_state = 2},
  [17449] = {.lex_state = 32, .external_lex_state = 2},
  [17450] = {.lex_state = 32, .external_lex_state = 2},
  [17451] = {.lex_state = 437, .external_lex_state = 2},
  [17452] = {.lex_state = 24, .external_lex_state = 2},
  [17453] = {.lex_state = 24, .external_lex_state = 2},
  [17454] = {.lex_state = 437, .external_lex_state = 2},
  [17455] = {.lex_state = 11, .external_lex_state = 2},
  [17456] = {.lex_state = 24, .external_lex_state = 2},
  [17457] = {.lex_state = 32, .external_lex_state = 2},
  [17458] = {.lex_state = 437, .external_lex_state = 2},
  [17459] = {.lex_state = 24, .external_lex_state = 2},
  [17460] = {.lex_state = 32, .external_lex_state = 2},
  [17461] = {.lex_state = 24, .external_lex_state = 2},
  [17462] = {.lex_state = 24, .external_lex_state = 2},
  [17463] = {.lex_state = 24, .external_lex_state = 2},
  [17464] = {.lex_state = 24, .external_lex_state = 2},
  [17465] = {.lex_state = 437, .external_lex_state = 2},
  [17466] = {.lex_state = 32, .external_lex_state = 2},
  [17467] = {.lex_state = 54, .external_lex_state = 2},
  [17468] = {.lex_state = 437, .external_lex_state = 2},
  [17469] = {.lex_state = 24, .external_lex_state = 2},
  [17470] = {.lex_state = 437, .external_lex_state = 2},
  [17471] = {.lex_state = 437, .external_lex_state = 8},
  [17472] = {.lex_state = 24, .external_lex_state = 2},
  [17473] = {.lex_state = 437, .external_lex_state = 8},
  [17474] = {.lex_state = 24, .external_lex_state = 2},
  [17475] = {.lex_state = 32, .external_lex_state = 2},
  [17476] = {.lex_state = 24, .external_lex_state = 2},
  [17477] = {.lex_state = 437, .external_lex_state = 2},
  [17478] = {.lex_state = 54, .external_lex_state = 2},
  [17479] = {.lex_state = 54, .external_lex_state = 2},
  [17480] = {.lex_state = 54, .external_lex_state = 2},
  [17481] = {.lex_state = 24, .external_lex_state = 2},
  [17482] = {.lex_state = 437, .external_lex_state = 2},
  [17483] = {.lex_state = 24, .external_lex_state = 2},
  [17484] = {.lex_state = 32, .external_lex_state = 2},
  [17485] = {.lex_state = 54, .external_lex_state = 2},
  [17486] = {.lex_state = 437, .external_lex_state = 2},
  [17487] = {.lex_state = 24, .external_lex_state = 2},
  [17488] = {.lex_state = 54, .external_lex_state = 2},
  [17489] = {.lex_state = 24, .external_lex_state = 2},
  [17490] = {.lex_state = 54, .external_lex_state = 2},
  [17491] = {.lex_state = 24, .external_lex_state = 2},
  [17492] = {.lex_state = 437, .external_lex_state = 2},
  [17493] = {.lex_state = 437, .external_lex_state = 2},
  [17494] = {.lex_state = 437, .external_lex_state = 2},
  [17495] = {.lex_state = 437, .external_lex_state = 2},
  [17496] = {.lex_state = 24, .external_lex_state = 2},
  [17497] = {.lex_state = 24, .external_lex_state = 2},
  [17498] = {.lex_state = 24, .external_lex_state = 2},
  [17499] = {.lex_state = 437, .external_lex_state = 2},
  [17500] = {.lex_state = 437, .external_lex_state = 2},
  [17501] = {.lex_state = 24, .external_lex_state = 2},
  [17502] = {.lex_state = 24, .external_lex_state = 2},
  [17503] = {.lex_state = 437, .external_lex_state = 8},
  [17504] = {.lex_state = 24, .external_lex_state = 2},
  [17505] = {.lex_state = 437, .external_lex_state = 8},
  [17506] = {.lex_state = 437, .external_lex_state = 2},
  [17507] = {.lex_state = 24, .external_lex_state = 2},
  [17508] = {.lex_state = 54, .external_lex_state = 2},
  [17509] = {.lex_state = 54, .external_lex_state = 2},
  [17510] = {.lex_state = 54, .external_lex_state = 2},
  [17511] = {.lex_state = 24, .external_lex_state = 2},
  [17512] = {.lex_state = 437, .external_lex_state = 2},
  [17513] = {.lex_state = 32, .external_lex_state = 2},
  [17514] = {.lex_state = 24, .external_lex_state = 2},
  [17515] = {.lex_state = 437, .external_lex_state = 2},
  [17516] = {.lex_state = 24, .external_lex_state = 2},
  [17517] = {.lex_state = 54, .external_lex_state = 2},
  [17518] = {.lex_state = 54, .external_lex_state = 2},
  [17519] = {.lex_state = 24, .external_lex_state = 2},
  [17520] = {.lex_state = 437, .external_lex_state = 2},
  [17521] = {.lex_state = 32, .external_lex_state = 2},
  [17522] = {.lex_state = 437, .external_lex_state = 2},
  [17523] = {.lex_state = 32, .external_lex_state = 2},
  [17524] = {.lex_state = 437, .external_lex_state = 2},
  [17525] = {.lex_state = 24, .external_lex_state = 2},
  [17526] = {.lex_state = 437, .external_lex_state = 8},
  [17527] = {.lex_state = 437, .external_lex_state = 2},
  [17528] = {.lex_state = 437, .external_lex_state = 2},
  [17529] = {.lex_state = 437, .external_lex_state = 2},
  [17530] = {.lex_state = 54, .external_lex_state = 2},
  [17531] = {.lex_state = 54, .external_lex_state = 2},
  [17532] = {.lex_state = 54, .external_lex_state = 2},
  [17533] = {.lex_state = 24, .external_lex_state = 2},
  [17534] = {.lex_state = 32, .external_lex_state = 2},
  [17535] = {.lex_state = 32, .external_lex_state = 2},
  [17536] = {.lex_state = 437, .external_lex_state = 2},
  [17537] = {.lex_state = 24, .external_lex_state = 2},
  [17538] = {.lex_state = 24, .external_lex_state = 2},
  [17539] = {.lex_state = 32, .external_lex_state = 2},
  [17540] = {.lex_state = 437, .external_lex_state = 2},
  [17541] = {.lex_state = 24, .external_lex_state = 2},
  [17542] = {.lex_state = 437, .external_lex_state = 2},
  [17543] = {.lex_state = 24, .external_lex_state = 2},
  [17544] = {.lex_state = 437, .external_lex_state = 2},
  [17545] = {.lex_state = 24, .external_lex_state = 2},
  [17546] = {.lex_state = 437, .external_lex_state = 2},
  [17547] = {.lex_state = 32, .external_lex_state = 2},
  [17548] = {.lex_state = 24, .external_lex_state = 2},
  [17549] = {.lex_state = 437, .external_lex_state = 8},
  [17550] = {.lex_state = 24, .external_lex_state = 2},
  [17551] = {.lex_state = 437, .external_lex_state = 2},
  [17552] = {.lex_state = 24, .external_lex_state = 2},
  [17553] = {.lex_state = 54, .external_lex_state = 2},
  [17554] = {.lex_state = 54, .external_lex_state = 2},
  [17555] = {.lex_state = 54, .external_lex_state = 2},
  [17556] = {.lex_state = 24, .external_lex_state = 2},
  [17557] = {.lex_state = 32, .external_lex_state = 2},
  [17558] = {.lex_state = 437, .external_lex_state = 2},
  [17559] = {.lex_state = 24, .external_lex_state = 2},
  [17560] = {.lex_state = 437, .external_lex_state = 2},
  [17561] = {.lex_state = 24, .external_lex_state = 2},
  [17562] = {.lex_state = 24, .external_lex_state = 2},
  [17563] = {.lex_state = 32, .external_lex_state = 2},
  [17564] = {.lex_state = 24, .external_lex_state = 2},
  [17565] = {.lex_state = 437, .external_lex_state = 2},
  [17566] = {.lex_state = 437, .external_lex_state = 2},
  [17567] = {.lex_state = 437, .external_lex_state = 2},
  [17568] = {.lex_state = 437, .external_lex_state = 2},
  [17569] = {.lex_state = 24, .external_lex_state = 2},
  [17570] = {.lex_state = 437, .external_lex_state = 2},
  [17571] = {.lex_state = 24, .external_lex_state = 2},
  [17572] = {.lex_state = 43, .external_lex_state = 2},
  [17573] = {.lex_state = 437, .external_lex_state = 8},
  [17574] = {.lex_state = 437, .external_lex_state = 2},
  [17575] = {.lex_state = 24, .external_lex_state = 2},
  [17576] = {.lex_state = 437, .external_lex_state = 2},
  [17577] = {.lex_state = 24, .external_lex_state = 2},
  [17578] = {.lex_state = 32, .external_lex_state = 2},
  [17579] = {.lex_state = 54, .external_lex_state = 2},
  [17580] = {.lex_state = 54, .external_lex_state = 2},
  [17581] = {.lex_state = 54, .external_lex_state = 2},
  [17582] = {.lex_state = 24, .external_lex_state = 2},
  [17583] = {.lex_state = 437, .external_lex_state = 2},
  [17584] = {.lex_state = 24, .external_lex_state = 2},
  [17585] = {.lex_state = 437, .external_lex_state = 2},
  [17586] = {.lex_state = 437, .external_lex_state = 2},
  [17587] = {.lex_state = 437, .external_lex_state = 2},
  [17588] = {.lex_state = 24, .external_lex_state = 2},
  [17589] = {.lex_state = 437, .external_lex_state = 2},
  [17590] = {.lex_state = 32, .external_lex_state = 2},
  [17591] = {.lex_state = 437, .external_lex_state = 2},
  [17592] = {.lex_state = 24, .external_lex_state = 2},
  [17593] = {.lex_state = 24, .external_lex_state = 2},
  [17594] = {.lex_state = 437, .external_lex_state = 2},
  [17595] = {.lex_state = 437, .external_lex_state = 2},
  [17596] = {.lex_state = 437, .external_lex_state = 8},
  [17597] = {.lex_state = 24, .external_lex_state = 2},
  [17598] = {.lex_state = 437, .external_lex_state = 8},
  [17599] = {.lex_state = 437, .external_lex_state = 2},
  [17600] = {.lex_state = 437, .external_lex_state = 2},
  [17601] = {.lex_state = 54, .external_lex_state = 2},
  [17602] = {.lex_state = 24, .external_lex_state = 2},
  [17603] = {.lex_state = 54, .external_lex_state = 2},
  [17604] = {.lex_state = 54, .external_lex_state = 2},
  [17605] = {.lex_state = 54, .external_lex_state = 2},
  [17606] = {.lex_state = 24, .external_lex_state = 2},
  [17607] = {.lex_state = 437, .external_lex_state = 2},
  [17608] = {.lex_state = 437, .external_lex_state = 2},
  [17609] = {.lex_state = 32, .external_lex_state = 2},
  [17610] = {.lex_state = 24, .external_lex_state = 2},
  [17611] = {.lex_state = 437, .external_lex_state = 2},
  [17612] = {.lex_state = 32, .external_lex_state = 2},
  [17613] = {.lex_state = 32, .external_lex_state = 2},
  [17614] = {.lex_state = 437, .external_lex_state = 2},
  [17615] = {.lex_state = 24, .external_lex_state = 2},
  [17616] = {.lex_state = 437, .external_lex_state = 2},
  [17617] = {.lex_state = 24, .external_lex_state = 2},
  [17618] = {.lex_state = 24, .external_lex_state = 2},
  [17619] = {.lex_state = 24, .external_lex_state = 2},
  [17620] = {.lex_state = 437, .external_lex_state = 8},
  [17621] = {.lex_state = 24, .external_lex_state = 2},
  [17622] = {.lex_state = 437, .external_lex_state = 2},
  [17623] = {.lex_state = 437, .external_lex_state = 2},
  [17624] = {.lex_state = 437, .external_lex_state = 2},
  [17625] = {.lex_state = 437, .external_lex_state = 2},
  [17626] = {.lex_state = 54, .external_lex_state = 2},
  [17627] = {.lex_state = 54, .external_lex_state = 2},
  [17628] = {.lex_state = 54, .external_lex_state = 2},
  [17629] = {.lex_state = 24, .external_lex_state = 2},
  [17630] = {.lex_state = 24, .external_lex_state = 2},
  [17631] = {.lex_state = 32, .external_lex_state = 2},
  [17632] = {.lex_state = 32, .external_lex_state = 2},
  [17633] = {.lex_state = 437, .external_lex_state = 2},
  [17634] = {.lex_state = 24, .external_lex_state = 2},
  [17635] = {.lex_state = 24, .external_lex_state = 2},
  [17636] = {.lex_state = 24, .external_lex_state = 2},
  [17637] = {.lex_state = 24, .external_lex_state = 2},
  [17638] = {.lex_state = 437, .external_lex_state = 2},
  [17639] = {.lex_state = 24, .external_lex_state = 2},
  [17640] = {.lex_state = 24, .external_lex_state = 2},
  [17641] = {.lex_state = 24, .external_lex_state = 2},
  [17642] = {.lex_state = 437, .external_lex_state = 8},
  [17643] = {.lex_state = 437, .external_lex_state = 2},
  [17644] = {.lex_state = 54, .external_lex_state = 2},
  [17645] = {.lex_state = 54, .external_lex_state = 2},
  [17646] = {.lex_state = 54, .external_lex_state = 2},
  [17647] = {.lex_state = 24, .external_lex_state = 2},
  [17648] = {.lex_state = 437, .external_lex_state = 2},
  [17649] = {.lex_state = 24, .external_lex_state = 2},
  [17650] = {.lex_state = 437, .external_lex_state = 2},
  [17651] = {.lex_state = 11, .external_lex_state = 2},
  [17652] = {.lex_state = 437, .external_lex_state = 8},
  [17653] = {.lex_state = 437, .external_lex_state = 2},
  [17654] = {.lex_state = 24, .external_lex_state = 2},
  [17655] = {.lex_state = 437, .external_lex_state = 2},
  [17656] = {.lex_state = 54, .external_lex_state = 2},
  [17657] = {.lex_state = 54, .external_lex_state = 2},
  [17658] = {.lex_state = 54, .external_lex_state = 2},
  [17659] = {.lex_state = 24, .external_lex_state = 2},
  [17660] = {.lex_state = 437, .external_lex_state = 2},
  [17661] = {.lex_state = 437, .external_lex_state = 2},
  [17662] = {.lex_state = 437, .external_lex_state = 2},
  [17663] = {.lex_state = 437, .external_lex_state = 2},
  [17664] = {.lex_state = 437, .external_lex_state = 2},
  [17665] = {.lex_state = 24, .external_lex_state = 2},
  [17666] = {.lex_state = 437, .external_lex_state = 2},
  [17667] = {.lex_state = 24, .external_lex_state = 2},
  [17668] = {.lex_state = 24, .external_lex_state = 2},
  [17669] = {.lex_state = 437, .external_lex_state = 8},
  [17670] = {.lex_state = 54, .external_lex_state = 2},
  [17671] = {.lex_state = 437, .external_lex_state = 2},
  [17672] = {.lex_state = 437, .external_lex_state = 2},
  [17673] = {.lex_state = 437, .external_lex_state = 2},
  [17674] = {.lex_state = 54, .external_lex_state = 2},
  [17675] = {.lex_state = 54, .external_lex_state = 2},
  [17676] = {.lex_state = 54, .external_lex_state = 2},
  [17677] = {.lex_state = 24, .external_lex_state = 2},
  [17678] = {.lex_state = 24, .external_lex_state = 2},
  [17679] = {.lex_state = 32, .external_lex_state = 2},
  [17680] = {.lex_state = 437, .external_lex_state = 2},
  [17681] = {.lex_state = 437, .external_lex_state = 2},
  [17682] = {.lex_state = 32, .external_lex_state = 2},
  [17683] = {.lex_state = 24, .external_lex_state = 2},
  [17684] = {.lex_state = 24, .external_lex_state = 2},
  [17685] = {.lex_state = 437, .external_lex_state = 8},
  [17686] = {.lex_state = 32, .external_lex_state = 2},
  [17687] = {.lex_state = 437, .external_lex_state = 2},
  [17688] = {.lex_state = 24, .external_lex_state = 2},
  [17689] = {.lex_state = 437, .external_lex_state = 2},
  [17690] = {.lex_state = 437, .external_lex_state = 2},
  [17691] = {.lex_state = 54, .external_lex_state = 2},
  [17692] = {.lex_state = 54, .external_lex_state = 2},
  [17693] = {.lex_state = 54, .external_lex_state = 2},
  [17694] = {.lex_state = 437, .external_lex_state = 2},
  [17695] = {.lex_state = 437, .external_lex_state = 2},
  [17696] = {.lex_state = 24, .external_lex_state = 2},
  [17697] = {.lex_state = 437, .external_lex_state = 2},
  [17698] = {.lex_state = 437, .external_lex_state = 2},
  [17699] = {.lex_state = 32, .external_lex_state = 2},
  [17700] = {.lex_state = 24, .external_lex_state = 2},
  [17701] = {.lex_state = 437, .external_lex_state = 2},
  [17702] = {.lex_state = 437, .external_lex_state = 2},
  [17703] = {.lex_state = 437, .external_lex_state = 8},
  [17704] = {.lex_state = 24, .external_lex_state = 2},
  [17705] = {.lex_state = 32, .external_lex_state = 2},
  [17706] = {.lex_state = 437, .external_lex_state = 2},
  [17707] = {.lex_state = 437, .external_lex_state = 2},
  [17708] = {.lex_state = 437, .external_lex_state = 2},
  [17709] = {.lex_state = 54, .external_lex_state = 2},
  [17710] = {.lex_state = 54, .external_lex_state = 2},
  [17711] = {.lex_state = 54, .external_lex_state = 2},
  [17712] = {.lex_state = 24, .external_lex_state = 2},
  [17713] = {.lex_state = 437, .external_lex_state = 2},
  [17714] = {.lex_state = 24, .external_lex_state = 2},
  [17715] = {.lex_state = 437, .external_lex_state = 2},
  [17716] = {.lex_state = 32, .external_lex_state = 2},
  [17717] = {.lex_state = 437, .external_lex_state = 2},
  [17718] = {.lex_state = 32, .external_lex_state = 2},
  [17719] = {.lex_state = 24, .external_lex_state = 2},
  [17720] = {.lex_state = 24, .external_lex_state = 2},
  [17721] = {.lex_state = 24, .external_lex_state = 2},
  [17722] = {.lex_state = 24, .external_lex_state = 2},
  [17723] = {.lex_state = 437, .external_lex_state = 8},
  [17724] = {.lex_state = 437, .external_lex_state = 2},
  [17725] = {.lex_state = 437, .external_lex_state = 2},
  [17726] = {.lex_state = 24, .external_lex_state = 2},
  [17727] = {.lex_state = 54, .external_lex_state = 2},
  [17728] = {.lex_state = 54, .external_lex_state = 2},
  [17729] = {.lex_state = 54, .external_lex_state = 2},
  [17730] = {.lex_state = 43, .external_lex_state = 2},
  [17731] = {.lex_state = 24, .external_lex_state = 2},
  [17732] = {.lex_state = 24, .external_lex_state = 2},
  [17733] = {.lex_state = 437, .external_lex_state = 2},
  [17734] = {.lex_state = 24, .external_lex_state = 2},
  [17735] = {.lex_state = 437, .external_lex_state = 2},
  [17736] = {.lex_state = 24, .external_lex_state = 2},
  [17737] = {.lex_state = 437, .external_lex_state = 2},
  [17738] = {.lex_state = 437, .external_lex_state = 8},
  [17739] = {.lex_state = 32, .external_lex_state = 2},
  [17740] = {.lex_state = 437, .external_lex_state = 2},
  [17741] = {.lex_state = 24, .external_lex_state = 2},
  [17742] = {.lex_state = 54, .external_lex_state = 2},
  [17743] = {.lex_state = 54, .external_lex_state = 2},
  [17744] = {.lex_state = 54, .external_lex_state = 2},
  [17745] = {.lex_state = 437, .external_lex_state = 2},
  [17746] = {.lex_state = 24, .external_lex_state = 2},
  [17747] = {.lex_state = 32, .external_lex_state = 2},
  [17748] = {.lex_state = 437, .external_lex_state = 2},
  [17749] = {.lex_state = 24, .external_lex_state = 2},
  [17750] = {.lex_state = 437, .external_lex_state = 2},
  [17751] = {.lex_state = 437, .external_lex_state = 2},
  [17752] = {.lex_state = 24, .external_lex_state = 2},
  [17753] = {.lex_state = 437, .external_lex_state = 8},
  [17754] = {.lex_state = 437, .external_lex_state = 2},
  [17755] = {.lex_state = 437, .external_lex_state = 2},
  [17756] = {.lex_state = 24, .external_lex_state = 2},
  [17757] = {.lex_state = 54, .external_lex_state = 2},
  [17758] = {.lex_state = 54, .external_lex_state = 2},
  [17759] = {.lex_state = 54, .external_lex_state = 2},
  [17760] = {.lex_state = 32, .external_lex_state = 2},
  [17761] = {.lex_state = 437, .external_lex_state = 2},
  [17762] = {.lex_state = 24, .external_lex_state = 2},
  [17763] = {.lex_state = 437, .external_lex_state = 2},
  [17764] = {.lex_state = 32, .external_lex_state = 2},
  [17765] = {.lex_state = 437, .external_lex_state = 2},
  [17766] = {.lex_state = 32, .external_lex_state = 2},
  [17767] = {.lex_state = 54, .external_lex_state = 2},
  [17768] = {.lex_state = 437, .external_lex_state = 8},
  [17769] = {.lex_state = 24, .external_lex_state = 2},
  [17770] = {.lex_state = 54, .external_lex_state = 2},
  [17771] = {.lex_state = 437, .external_lex_state = 2},
  [17772] = {.lex_state = 54, .external_lex_state = 2},
  [17773] = {.lex_state = 54, .external_lex_state = 2},
  [17774] = {.lex_state = 54, .external_lex_state = 2},
  [17775] = {.lex_state = 54, .external_lex_state = 2},
  [17776] = {.lex_state = 24, .external_lex_state = 2},
  [17777] = {.lex_state = 437, .external_lex_state = 2},
  [17778] = {.lex_state = 24, .external_lex_state = 2},
  [17779] = {.lex_state = 437, .external_lex_state = 2},
  [17780] = {.lex_state = 24, .external_lex_state = 2},
  [17781] = {.lex_state = 24, .external_lex_state = 2},
  [17782] = {.lex_state = 24, .external_lex_state = 2},
  [17783] = {.lex_state = 437, .external_lex_state = 8},
  [17784] = {.lex_state = 437, .external_lex_state = 2},
  [17785] = {.lex_state = 32, .external_lex_state = 2},
  [17786] = {.lex_state = 24, .external_lex_state = 2},
  [17787] = {.lex_state = 54, .external_lex_state = 2},
  [17788] = {.lex_state = 54, .external_lex_state = 2},
  [17789] = {.lex_state = 54, .external_lex_state = 2},
  [17790] = {.lex_state = 24, .external_lex_state = 2},
  [17791] = {.lex_state = 437, .external_lex_state = 2},
  [17792] = {.lex_state = 437, .external_lex_state = 2},
  [17793] = {.lex_state = 32, .external_lex_state = 2},
  [17794] = {.lex_state = 437, .external_lex_state = 8},
  [17795] = {.lex_state = 32, .external_lex_state = 2},
  [17796] = {.lex_state = 54, .external_lex_state = 2},
  [17797] = {.lex_state = 54, .external_lex_state = 2},
  [17798] = {.lex_state = 54, .external_lex_state = 2},
  [17799] = {.lex_state = 54, .external_lex_state = 2},
  [17800] = {.lex_state = 54, .external_lex_state = 2},
  [17801] = {.lex_state = 437, .external_lex_state = 2},
  [17802] = {.lex_state = 437, .external_lex_state = 2},
  [17803] = {.lex_state = 24, .external_lex_state = 2},
  [17804] = {.lex_state = 437, .external_lex_state = 2},
  [17805] = {.lex_state = 32, .external_lex_state = 2},
  [17806] = {.lex_state = 437, .external_lex_state = 8},
  [17807] = {.lex_state = 32, .external_lex_state = 2},
  [17808] = {.lex_state = 24, .external_lex_state = 2},
  [17809] = {.lex_state = 54, .external_lex_state = 2},
  [17810] = {.lex_state = 54, .external_lex_state = 2},
  [17811] = {.lex_state = 54, .external_lex_state = 2},
  [17812] = {.lex_state = 437, .external_lex_state = 2},
  [17813] = {.lex_state = 437, .external_lex_state = 2},
  [17814] = {.lex_state = 437, .external_lex_state = 2},
  [17815] = {.lex_state = 437, .external_lex_state = 8},
  [17816] = {.lex_state = 437, .external_lex_state = 2},
  [17817] = {.lex_state = 32, .external_lex_state = 2},
  [17818] = {.lex_state = 54, .external_lex_state = 2},
  [17819] = {.lex_state = 54, .external_lex_state = 2},
  [17820] = {.lex_state = 54, .external_lex_state = 2},
  [17821] = {.lex_state = 437, .external_lex_state = 2},
  [17822] = {.lex_state = 437, .external_lex_state = 2},
  [17823] = {.lex_state = 437, .external_lex_state = 2},
  [17824] = {.lex_state = 24, .external_lex_state = 2},
  [17825] = {.lex_state = 32, .external_lex_state = 2},
  [17826] = {.lex_state = 437, .external_lex_state = 2},
  [17827] = {.lex_state = 10, .external_lex_state = 2},
  [17828] = {.lex_state = 24, .external_lex_state = 2},
  [17829] = {.lex_state = 32, .external_lex_state = 2},
  [17830] = {.lex_state = 437, .external_lex_state = 8},
  [17831] = {.lex_state = 24, .external_lex_state = 2},
  [17832] = {.lex_state = 437, .external_lex_state = 2},
  [17833] = {.lex_state = 54, .external_lex_state = 2},
  [17834] = {.lex_state = 54, .external_lex_state = 2},
  [17835] = {.lex_state = 54, .external_lex_state = 2},
  [17836] = {.lex_state = 24, .external_lex_state = 2},
  [17837] = {.lex_state = 437, .external_lex_state = 2},
  [17838] = {.lex_state = 24, .external_lex_state = 2},
  [17839] = {.lex_state = 437, .external_lex_state = 2},
  [17840] = {.lex_state = 24, .external_lex_state = 2},
  [17841] = {.lex_state = 32, .external_lex_state = 2},
  [17842] = {.lex_state = 24, .external_lex_state = 2},
  [17843] = {.lex_state = 10, .external_lex_state = 2},
  [17844] = {.lex_state = 437, .external_lex_state = 8},
  [17845] = {.lex_state = 24, .external_lex_state = 2},
  [17846] = {.lex_state = 54, .external_lex_state = 2},
  [17847] = {.lex_state = 54, .external_lex_state = 2},
  [17848] = {.lex_state = 54, .external_lex_state = 2},
  [17849] = {.lex_state = 437, .external_lex_state = 2},
  [17850] = {.lex_state = 437, .external_lex_state = 2},
  [17851] = {.lex_state = 437, .external_lex_state = 2},
  [17852] = {.lex_state = 437, .external_lex_state = 2},
  [17853] = {.lex_state = 437, .external_lex_state = 2},
  [17854] = {.lex_state = 437, .external_lex_state = 8},
  [17855] = {.lex_state = 24, .external_lex_state = 2},
  [17856] = {.lex_state = 24, .external_lex_state = 2},
  [17857] = {.lex_state = 54, .external_lex_state = 2},
  [17858] = {.lex_state = 54, .external_lex_state = 2},
  [17859] = {.lex_state = 54, .external_lex_state = 2},
  [17860] = {.lex_state = 24, .external_lex_state = 2},
  [17861] = {.lex_state = 437, .external_lex_state = 2},
  [17862] = {.lex_state = 437, .external_lex_state = 2},
  [17863] = {.lex_state = 24, .external_lex_state = 2},
  [17864] = {.lex_state = 54, .external_lex_state = 2},
  [17865] = {.lex_state = 437, .external_lex_state = 2},
  [17866] = {.lex_state = 437, .external_lex_state = 2},
  [17867] = {.lex_state = 54, .external_lex_state = 2},
  [17868] = {.lex_state = 437, .external_lex_state = 8},
  [17869] = {.lex_state = 437, .external_lex_state = 2},
  [17870] = {.lex_state = 437, .external_lex_state = 2},
  [17871] = {.lex_state = 32, .external_lex_state = 2},
  [17872] = {.lex_state = 437, .external_lex_state = 8},
  [17873] = {.lex_state = 54, .external_lex_state = 2},
  [17874] = {.lex_state = 54, .external_lex_state = 2},
  [17875] = {.lex_state = 54, .external_lex_state = 2},
  [17876] = {.lex_state = 437, .external_lex_state = 2},
  [17877] = {.lex_state = 32, .external_lex_state = 2},
  [17878] = {.lex_state = 437, .external_lex_state = 2},
  [17879] = {.lex_state = 24, .external_lex_state = 2},
  [17880] = {.lex_state = 437, .external_lex_state = 2},
  [17881] = {.lex_state = 437, .external_lex_state = 8},
  [17882] = {.lex_state = 437, .external_lex_state = 2},
  [17883] = {.lex_state = 437, .external_lex_state = 2},
  [17884] = {.lex_state = 54, .external_lex_state = 2},
  [17885] = {.lex_state = 54, .external_lex_state = 2},
  [17886] = {.lex_state = 54, .external_lex_state = 2},
  [17887] = {.lex_state = 437, .external_lex_state = 2},
  [17888] = {.lex_state = 24, .external_lex_state = 2},
  [17889] = {.lex_state = 24, .external_lex_state = 2},
  [17890] = {.lex_state = 437, .external_lex_state = 2},
  [17891] = {.lex_state = 24, .external_lex_state = 2},
  [17892] = {.lex_state = 32, .external_lex_state = 2},
  [17893] = {.lex_state = 437, .external_lex_state = 2},
  [17894] = {.lex_state = 32, .external_lex_state = 2},
  [17895] = {.lex_state = 437, .external_lex_state = 8},
  [17896] = {.lex_state = 54, .external_lex_state = 2},
  [17897] = {.lex_state = 54, .external_lex_state = 2},
  [17898] = {.lex_state = 54, .external_lex_state = 2},
  [17899] = {.lex_state = 24, .external_lex_state = 2},
  [17900] = {.lex_state = 32, .external_lex_state = 2},
  [17901] = {.lex_state = 437, .external_lex_state = 2},
  [17902] = {.lex_state = 24, .external_lex_state = 2},
  [17903] = {.lex_state = 437, .external_lex_state = 2},
  [17904] = {.lex_state = 24, .external_lex_state = 2},
  [17905] = {.lex_state = 437, .external_lex_state = 2},
  [17906] = {.lex_state = 24, .external_lex_state = 2},
  [17907] = {.lex_state = 437, .external_lex_state = 8},
  [17908] = {.lex_state = 54, .external_lex_state = 2},
  [17909] = {.lex_state = 54, .external_lex_state = 2},
  [17910] = {.lex_state = 54, .external_lex_state = 2},
  [17911] = {.lex_state = 32, .external_lex_state = 2},
  [17912] = {.lex_state = 437, .external_lex_state = 2},
  [17913] = {.lex_state = 437, .external_lex_state = 2},
  [17914] = {.lex_state = 24, .external_lex_state = 2},
  [17915] = {.lex_state = 24, .external_lex_state = 2},
  [17916] = {.lex_state = 24, .external_lex_state = 2},
  [17917] = {.lex_state = 437, .external_lex_state = 2},
  [17918] = {.lex_state = 32, .external_lex_state = 2},
  [17919] = {.lex_state = 437, .external_lex_state = 8},
  [17920] = {.lex_state = 437, .external_lex_state = 2},
  [17921] = {.lex_state = 32, .external_lex_state = 2},
  [17922] = {.lex_state = 24, .external_lex_state = 2},
  [17923] = {.lex_state = 24, .external_lex_state = 2},
  [17924] = {.lex_state = 54, .external_lex_state = 2},
  [17925] = {.lex_state = 54, .external_lex_state = 2},
  [17926] = {.lex_state = 54, .external_lex_state = 2},
  [17927] = {.lex_state = 24, .external_lex_state = 2},
  [17928] = {.lex_state = 437, .external_lex_state = 2},
  [17929] = {.lex_state = 24, .external_lex_state = 2},
  [17930] = {.lex_state = 437, .external_lex_state = 8},
  [17931] = {.lex_state = 24, .external_lex_state = 2},
  [17932] = {.lex_state = 437, .external_lex_state = 2},
  [17933] = {.lex_state = 32, .external_lex_state = 2},
  [17934] = {.lex_state = 24, .external_lex_state = 2},
  [17935] = {.lex_state = 54, .external_lex_state = 2},
  [17936] = {.lex_state = 54, .external_lex_state = 2},
  [17937] = {.lex_state = 54, .external_lex_state = 2},
  [17938] = {.lex_state = 437, .external_lex_state = 2},
  [17939] = {.lex_state = 24, .external_lex_state = 2},
  [17940] = {.lex_state = 437, .external_lex_state = 2},
  [17941] = {.lex_state = 24, .external_lex_state = 2},
  [17942] = {.lex_state = 437, .external_lex_state = 2},
  [17943] = {.lex_state = 24, .external_lex_state = 2},
  [17944] = {.lex_state = 54, .external_lex_state = 2},
  [17945] = {.lex_state = 437, .external_lex_state = 8},
  [17946] = {.lex_state = 24, .external_lex_state = 2},
  [17947] = {.lex_state = 54, .external_lex_state = 2},
  [17948] = {.lex_state = 54, .external_lex_state = 2},
  [17949] = {.lex_state = 54, .external_lex_state = 2},
  [17950] = {.lex_state = 437, .external_lex_state = 2},
  [17951] = {.lex_state = 24, .external_lex_state = 2},
  [17952] = {.lex_state = 437, .external_lex_state = 2},
  [17953] = {.lex_state = 437, .external_lex_state = 8},
  [17954] = {.lex_state = 32, .external_lex_state = 2},
  [17955] = {.lex_state = 24, .external_lex_state = 2},
  [17956] = {.lex_state = 437, .external_lex_state = 2},
  [17957] = {.lex_state = 54, .external_lex_state = 2},
  [17958] = {.lex_state = 54, .external_lex_state = 2},
  [17959] = {.lex_state = 54, .external_lex_state = 2},
  [17960] = {.lex_state = 24, .external_lex_state = 2},
  [17961] = {.lex_state = 437, .external_lex_state = 2},
  [17962] = {.lex_state = 437, .external_lex_state = 2},
  [17963] = {.lex_state = 24, .external_lex_state = 2},
  [17964] = {.lex_state = 437, .external_lex_state = 2},
  [17965] = {.lex_state = 437, .external_lex_state = 8},
  [17966] = {.lex_state = 24, .external_lex_state = 2},
  [17967] = {.lex_state = 54, .external_lex_state = 2},
  [17968] = {.lex_state = 54, .external_lex_state = 2},
  [17969] = {.lex_state = 54, .external_lex_state = 2},
  [17970] = {.lex_state = 437, .external_lex_state = 2},
  [17971] = {.lex_state = 24, .external_lex_state = 2},
  [17972] = {.lex_state = 32, .external_lex_state = 2},
  [17973] = {.lex_state = 437, .external_lex_state = 2},
  [17974] = {.lex_state = 11, .external_lex_state = 2},
  [17975] = {.lex_state = 437, .external_lex_state = 8},
  [17976] = {.lex_state = 437, .external_lex_state = 2},
  [17977] = {.lex_state = 24, .external_lex_state = 2},
  [17978] = {.lex_state = 24, .external_lex_state = 2},
  [17979] = {.lex_state = 54, .external_lex_state = 2},
  [17980] = {.lex_state = 54, .external_lex_state = 2},
  [17981] = {.lex_state = 54, .external_lex_state = 2},
  [17982] = {.lex_state = 437, .external_lex_state = 2},
  [17983] = {.lex_state = 437, .external_lex_state = 2},
  [17984] = {.lex_state = 437, .external_lex_state = 8},
  [17985] = {.lex_state = 24, .external_lex_state = 2},
  [17986] = {.lex_state = 24, .external_lex_state = 2},
  [17987] = {.lex_state = 54, .external_lex_state = 2},
  [17988] = {.lex_state = 54, .external_lex_state = 2},
  [17989] = {.lex_state = 54, .external_lex_state = 2},
  [17990] = {.lex_state = 437, .external_lex_state = 2},
  [17991] = {.lex_state = 24, .external_lex_state = 2},
  [17992] = {.lex_state = 24, .external_lex_state = 2},
  [17993] = {.lex_state = 54, .external_lex_state = 2},
  [17994] = {.lex_state = 24, .external_lex_state = 2},
  [17995] = {.lex_state = 437, .external_lex_state = 8},
  [17996] = {.lex_state = 24, .external_lex_state = 2},
  [17997] = {.lex_state = 32, .external_lex_state = 2},
  [17998] = {.lex_state = 437, .external_lex_state = 2},
  [17999] = {.lex_state = 32, .external_lex_state = 2},
  [18000] = {.lex_state = 54, .external_lex_state = 2},
  [18001] = {.lex_state = 54, .external_lex_state = 2},
  [18002] = {.lex_state = 54, .external_lex_state = 2},
  [18003] = {.lex_state = 437, .external_lex_state = 2},
  [18004] = {.lex_state = 32, .external_lex_state = 2},
  [18005] = {.lex_state = 32, .external_lex_state = 2},
  [18006] = {.lex_state = 32, .external_lex_state = 2},
  [18007] = {.lex_state = 437, .external_lex_state = 8},
  [18008] = {.lex_state = 437, .external_lex_state = 2},
  [18009] = {.lex_state = 32, .external_lex_state = 2},
  [18010] = {.lex_state = 54, .external_lex_state = 2},
  [18011] = {.lex_state = 54, .external_lex_state = 2},
  [18012] = {.lex_state = 54, .external_lex_state = 2},
  [18013] = {.lex_state = 24, .external_lex_state = 2},
  [18014] = {.lex_state = 24, .external_lex_state = 2},
  [18015] = {.lex_state = 437, .external_lex_state = 2},
  [18016] = {.lex_state = 437, .external_lex_state = 8},
  [18017] = {.lex_state = 54, .external_lex_state = 2},
  [18018] = {.lex_state = 54, .external_lex_state = 2},
  [18019] = {.lex_state = 54, .external_lex_state = 2},
  [18020] = {.lex_state = 437, .external_lex_state = 8},
  [18021] = {.lex_state = 54, .external_lex_state = 2},
  [18022] = {.lex_state = 54, .external_lex_state = 2},
  [18023] = {.lex_state = 54, .external_lex_state = 2},
  [18024] = {.lex_state = 24, .external_lex_state = 2},
  [18025] = {.lex_state = 24, .external_lex_state = 2},
  [18026] = {.lex_state = 437, .external_lex_state = 8},
  [18027] = {.lex_state = 54, .external_lex_state = 2},
  [18028] = {.lex_state = 54, .external_lex_state = 2},
  [18029] = {.lex_state = 54, .external_lex_state = 2},
  [18030] = {.lex_state = 32, .external_lex_state = 2},
  [18031] = {.lex_state = 437, .external_lex_state = 8},
  [18032] = {.lex_state = 54, .external_lex_state = 2},
  [18033] = {.lex_state = 54, .external_lex_state = 2},
  [18034] = {.lex_state = 54, .external_lex_state = 2},
  [18035] = {.lex_state = 437, .external_lex_state = 8},
  [18036] = {.lex_state = 54, .external_lex_state = 2},
  [18037] = {.lex_state = 54, .external_lex_state = 2},
  [18038] = {.lex_state = 54, .external_lex_state = 2},
  [18039] = {.lex_state = 32, .external_lex_state = 2},
  [18040] = {.lex_state = 437, .external_lex_state = 2},
  [18041] = {.lex_state = 437, .external_lex_state = 8},
  [18042] = {.lex_state = 54, .external_lex_state = 2},
  [18043] = {.lex_state = 54, .external_lex_state = 2},
  [18044] = {.lex_state = 54, .external_lex_state = 2},
  [18045] = {.lex_state = 437, .external_lex_state = 8},
  [18046] = {.lex_state = 54, .external_lex_state = 2},
  [18047] = {.lex_state = 54, .external_lex_state = 2},
  [18048] = {.lex_state = 54, .external_lex_state = 2},
  [18049] = {.lex_state = 24, .external_lex_state = 2},
  [18050] = {.lex_state = 437, .external_lex_state = 8},
  [18051] = {.lex_state = 54, .external_lex_state = 2},
  [18052] = {.lex_state = 54, .external_lex_state = 2},
  [18053] = {.lex_state = 54, .external_lex_state = 2},
  [18054] = {.lex_state = 437, .external_lex_state = 2},
  [18055] = {.lex_state = 437, .external_lex_state = 2},
  [18056] = {.lex_state = 437, .external_lex_state = 8},
  [18057] = {.lex_state = 54, .external_lex_state = 2},
  [18058] = {.lex_state = 54, .external_lex_state = 2},
  [18059] = {.lex_state = 54, .external_lex_state = 2},
  [18060] = {.lex_state = 437, .external_lex_state = 8},
  [18061] = {.lex_state = 54, .external_lex_state = 2},
  [18062] = {.lex_state = 54, .external_lex_state = 2},
  [18063] = {.lex_state = 54, .external_lex_state = 2},
  [18064] = {.lex_state = 32, .external_lex_state = 2},
  [18065] = {.lex_state = 54, .external_lex_state = 2},
  [18066] = {.lex_state = 437, .external_lex_state = 2},
  [18067] = {.lex_state = 437, .external_lex_state = 8},
  [18068] = {.lex_state = 54, .external_lex_state = 2},
  [18069] = {.lex_state = 54, .external_lex_state = 2},
  [18070] = {.lex_state = 54, .external_lex_state = 2},
  [18071] = {.lex_state = 437, .external_lex_state = 2},
  [18072] = {.lex_state = 437, .external_lex_state = 8},
  [18073] = {.lex_state = 54, .external_lex_state = 2},
  [18074] = {.lex_state = 54, .external_lex_state = 2},
  [18075] = {.lex_state = 54, .external_lex_state = 2},
  [18076] = {.lex_state = 24, .external_lex_state = 2},
  [18077] = {.lex_state = 437, .external_lex_state = 8},
  [18078] = {.lex_state = 54, .external_lex_state = 2},
  [18079] = {.lex_state = 54, .external_lex_state = 2},
  [18080] = {.lex_state = 54, .external_lex_state = 2},
  [18081] = {.lex_state = 32, .external_lex_state = 2},
  [18082] = {.lex_state = 24, .external_lex_state = 2},
  [18083] = {.lex_state = 437, .external_lex_state = 8},
  [18084] = {.lex_state = 54, .external_lex_state = 2},
  [18085] = {.lex_state = 54, .external_lex_state = 2},
  [18086] = {.lex_state = 54, .external_lex_state = 2},
  [18087] = {.lex_state = 32, .external_lex_state = 2},
  [18088] = {.lex_state = 24, .external_lex_state = 2},
  [18089] = {.lex_state = 437, .external_lex_state = 8},
  [18090] = {.lex_state = 437, .external_lex_state = 8},
  [18091] = {.lex_state = 437, .external_lex_state = 8},
  [18092] = {.lex_state = 437, .external_lex_state = 8},
  [18093] = {.lex_state = 437, .external_lex_state = 8},
  [18094] = {.lex_state = 32, .external_lex_state = 2},
  [18095] = {.lex_state = 437, .external_lex_state = 8},
  [18096] = {.lex_state = 32, .external_lex_state = 2},
  [18097] = {.lex_state = 437, .external_lex_state = 8},
  [18098] = {.lex_state = 437, .external_lex_state = 8},
  [18099] = {.lex_state = 24, .external_lex_state = 2},
  [18100] = {.lex_state = 437, .external_lex_state = 8},
  [18101] = {.lex_state = 437, .external_lex_state = 8},
  [18102] = {.lex_state = 437, .external_lex_state = 8},
  [18103] = {.lex_state = 437, .external_lex_state = 8},
  [18104] = {.lex_state = 437, .external_lex_state = 8},
  [18105] = {.lex_state = 32, .external_lex_state = 2},
  [18106] = {.lex_state = 437, .external_lex_state = 8},
  [18107] = {.lex_state = 32, .external_lex_state = 2},
  [18108] = {.lex_state = 437, .external_lex_state = 8},
  [18109] = {.lex_state = 24, .external_lex_state = 2},
  [18110] = {.lex_state = 437, .external_lex_state = 8},
  [18111] = {.lex_state = 437, .external_lex_state = 8},
  [18112] = {.lex_state = 437, .external_lex_state = 8},
  [18113] = {.lex_state = 437, .external_lex_state = 8},
  [18114] = {.lex_state = 437, .external_lex_state = 8},
  [18115] = {.lex_state = 32, .external_lex_state = 2},
  [18116] = {.lex_state = 437, .external_lex_state = 8},
  [18117] = {.lex_state = 32, .external_lex_state = 2},
  [18118] = {.lex_state = 437, .external_lex_state = 8},
  [18119] = {.lex_state = 24, .external_lex_state = 2},
  [18120] = {.lex_state = 437, .external_lex_state = 8},
  [18121] = {.lex_state = 24, .external_lex_state = 2},
  [18122] = {.lex_state = 437, .external_lex_state = 8},
  [18123] = {.lex_state = 24, .external_lex_state = 2},
  [18124] = {.lex_state = 24, .external_lex_state = 2},
  [18125] = {.lex_state = 437, .external_lex_state = 2},
  [18126] = {.lex_state = 24, .external_lex_state = 2},
  [18127] = {.lex_state = 32, .external_lex_state = 2},
  [18128] = {.lex_state = 24, .external_lex_state = 2},
  [18129] = {.lex_state = 32, .external_lex_state = 2},
  [18130] = {.lex_state = 24, .external_lex_state = 2},
  [18131] = {.lex_state = 24, .external_lex_state = 2},
  [18132] = {.lex_state = 24, .external_lex_state = 2},
  [18133] = {.lex_state = 32, .external_lex_state = 2},
  [18134] = {.lex_state = 32, .external_lex_state = 2},
  [18135] = {.lex_state = 24, .external_lex_state = 2},
  [18136] = {.lex_state = 437, .external_lex_state = 2},
  [18137] = {.lex_state = 24, .external_lex_state = 2},
  [18138] = {.lex_state = 24, .external_lex_state = 2},
  [18139] = {.lex_state = 32, .external_lex_state = 2},
  [18140] = {.lex_state = 24, .external_lex_state = 2},
  [18141] = {.lex_state = 32, .external_lex_state = 2},
  [18142] = {.lex_state = 24, .external_lex_state = 2},
  [18143] = {.lex_state = 32, .external_lex_state = 2},
  [18144] = {.lex_state = 24, .external_lex_state = 2},
  [18145] = {.lex_state = 437, .external_lex_state = 2},
  [18146] = {.lex_state = 8, .external_lex_state = 2},
  [18147] = {.lex_state = 10, .external_lex_state = 2},
  [18148] = {.lex_state = 32, .external_lex_state = 2},
  [18149] = {.lex_state = 32, .external_lex_state = 2},
  [18150] = {.lex_state = 32, .external_lex_state = 2},
  [18151] = {.lex_state = 437, .external_lex_state = 2},
  [18152] = {.lex_state = 10, .external_lex_state = 2},
  [18153] = {.lex_state = 32, .external_lex_state = 2},
  [18154] = {.lex_state = 32, .external_lex_state = 2},
  [18155] = {.lex_state = 24, .external_lex_state = 2},
  [18156] = {.lex_state = 54, .external_lex_state = 2},
  [18157] = {.lex_state = 24, .external_lex_state = 2},
  [18158] = {.lex_state = 54, .external_lex_state = 2},
  [18159] = {.lex_state = 437, .external_lex_state = 2},
  [18160] = {.lex_state = 24, .external_lex_state = 2},
  [18161] = {.lex_state = 24, .external_lex_state = 2},
  [18162] = {.lex_state = 24, .external_lex_state = 2},
  [18163] = {.lex_state = 24, .external_lex_state = 2},
  [18164] = {.lex_state = 437, .external_lex_state = 2},
  [18165] = {.lex_state = 32, .external_lex_state = 2},
  [18166] = {.lex_state = 32, .external_lex_state = 2},
  [18167] = {.lex_state = 437, .external_lex_state = 2},
  [18168] = {.lex_state = 437, .external_lex_state = 2},
  [18169] = {.lex_state = 24, .external_lex_state = 2},
  [18170] = {.lex_state = 32, .external_lex_state = 2},
  [18171] = {.lex_state = 24, .external_lex_state = 2},
  [18172] = {.lex_state = 437, .external_lex_state = 2},
  [18173] = {.lex_state = 437, .external_lex_state = 2},
  [18174] = {.lex_state = 24, .external_lex_state = 2},
  [18175] = {.lex_state = 24, .external_lex_state = 2},
  [18176] = {.lex_state = 24, .external_lex_state = 2},
  [18177] = {.lex_state = 54, .external_lex_state = 2},
  [18178] = {.lex_state = 54, .external_lex_state = 2},
  [18179] = {.lex_state = 32, .external_lex_state = 2},
  [18180] = {.lex_state = 32, .external_lex_state = 2},
  [18181] = {.lex_state = 24, .external_lex_state = 2},
  [18182] = {.lex_state = 32, .external_lex_state = 2},
  [18183] = {.lex_state = 437, .external_lex_state = 2},
  [18184] = {.lex_state = 24, .external_lex_state = 2},
  [18185] = {.lex_state = 32, .external_lex_state = 2},
  [18186] = {.lex_state = 10, .external_lex_state = 2},
  [18187] = {.lex_state = 24, .external_lex_state = 2},
  [18188] = {.lex_state = 24, .external_lex_state = 2},
  [18189] = {.lex_state = 437, .external_lex_state = 2},
  [18190] = {.lex_state = 10, .external_lex_state = 2},
  [18191] = {.lex_state = 24, .external_lex_state = 2},
  [18192] = {.lex_state = 24, .external_lex_state = 2},
  [18193] = {.lex_state = 24, .external_lex_state = 2},
  [18194] = {.lex_state = 24, .external_lex_state = 2},
  [18195] = {.lex_state = 437, .external_lex_state = 2},
  [18196] = {.lex_state = 437, .external_lex_state = 2},
  [18197] = {.lex_state = 24, .external_lex_state = 2},
  [18198] = {.lex_state = 32, .external_lex_state = 2},
  [18199] = {.lex_state = 437, .external_lex_state = 2},
  [18200] = {.lex_state = 32, .external_lex_state = 2},
  [18201] = {.lex_state = 24, .external_lex_state = 2},
  [18202] = {.lex_state = 24, .external_lex_state = 2},
  [18203] = {.lex_state = 437, .external_lex_state = 2},
  [18204] = {.lex_state = 32, .external_lex_state = 2},
  [18205] = {.lex_state = 24, .external_lex_state = 2},
  [18206] = {.lex_state = 32, .external_lex_state = 2},
  [18207] = {.lex_state = 32, .external_lex_state = 2},
  [18208] = {.lex_state = 437, .external_lex_state = 2},
  [18209] = {.lex_state = 24, .external_lex_state = 2},
  [18210] = {.lex_state = 24, .external_lex_state = 2},
  [18211] = {.lex_state = 32, .external_lex_state = 2},
  [18212] = {.lex_state = 10, .external_lex_state = 2},
  [18213] = {.lex_state = 437, .external_lex_state = 2},
  [18214] = {.lex_state = 107, .external_lex_state = 2},
  [18215] = {.lex_state = 32, .external_lex_state = 2},
  [18216] = {.lex_state = 10, .external_lex_state = 2},
  [18217] = {.lex_state = 24, .external_lex_state = 2},
  [18218] = {.lex_state = 11, .external_lex_state = 2},
  [18219] = {.lex_state = 24, .external_lex_state = 2},
  [18220] = {.lex_state = 437, .external_lex_state = 2},
  [18221] = {.lex_state = 24, .external_lex_state = 2},
  [18222] = {.lex_state = 32, .external_lex_state = 2},
  [18223] = {.lex_state = 437, .external_lex_state = 2},
  [18224] = {.lex_state = 24, .external_lex_state = 2},
  [18225] = {.lex_state = 107, .external_lex_state = 2},
  [18226] = {.lex_state = 32, .external_lex_state = 2},
  [18227] = {.lex_state = 24, .external_lex_state = 2},
  [18228] = {.lex_state = 24, .external_lex_state = 2},
  [18229] = {.lex_state = 24, .external_lex_state = 2},
  [18230] = {.lex_state = 32, .external_lex_state = 2},
  [18231] = {.lex_state = 437, .external_lex_state = 2},
  [18232] = {.lex_state = 437, .external_lex_state = 2},
  [18233] = {.lex_state = 24, .external_lex_state = 2},
  [18234] = {.lex_state = 24, .external_lex_state = 2},
  [18235] = {.lex_state = 24, .external_lex_state = 2},
  [18236] = {.lex_state = 32, .external_lex_state = 2},
  [18237] = {.lex_state = 24, .external_lex_state = 2},
  [18238] = {.lex_state = 24, .external_lex_state = 2},
  [18239] = {.lex_state = 437, .external_lex_state = 2},
  [18240] = {.lex_state = 437, .external_lex_state = 2},
  [18241] = {.lex_state = 24, .external_lex_state = 2},
  [18242] = {.lex_state = 24, .external_lex_state = 2},
  [18243] = {.lex_state = 24, .external_lex_state = 2},
  [18244] = {.lex_state = 32, .external_lex_state = 2},
  [18245] = {.lex_state = 32, .external_lex_state = 2},
  [18246] = {.lex_state = 437, .external_lex_state = 2},
  [18247] = {.lex_state = 437, .external_lex_state = 2},
  [18248] = {.lex_state = 24, .external_lex_state = 2},
  [18249] = {.lex_state = 24, .external_lex_state = 2},
  [18250] = {.lex_state = 437, .external_lex_state = 2},
  [18251] = {.lex_state = 437, .external_lex_state = 8},
  [18252] = {.lex_state = 437, .external_lex_state = 2},
  [18253] = {.lex_state = 24, .external_lex_state = 2},
  [18254] = {.lex_state = 437, .external_lex_state = 2},
  [18255] = {.lex_state = 24, .external_lex_state = 2},
  [18256] = {.lex_state = 24, .external_lex_state = 2},
  [18257] = {.lex_state = 24, .external_lex_state = 2},
  [18258] = {.lex_state = 437, .external_lex_state = 2},
  [18259] = {.lex_state = 437, .external_lex_state = 2},
  [18260] = {.lex_state = 437, .external_lex_state = 2},
  [18261] = {.lex_state = 437, .external_lex_state = 2},
  [18262] = {.lex_state = 24, .external_lex_state = 2},
  [18263] = {.lex_state = 32, .external_lex_state = 2},
  [18264] = {.lex_state = 54, .external_lex_state = 2},
  [18265] = {.lex_state = 11, .external_lex_state = 2},
  [18266] = {.lex_state = 437, .external_lex_state = 2},
  [18267] = {.lex_state = 437, .external_lex_state = 2},
  [18268] = {.lex_state = 24, .external_lex_state = 2},
  [18269] = {.lex_state = 437, .external_lex_state = 2},
  [18270] = {.lex_state = 437, .external_lex_state = 2},
  [18271] = {.lex_state = 54, .external_lex_state = 2},
  [18272] = {.lex_state = 437, .external_lex_state = 2},
  [18273] = {.lex_state = 437, .external_lex_state = 2},
  [18274] = {.lex_state = 24, .external_lex_state = 2},
  [18275] = {.lex_state = 24, .external_lex_state = 2},
  [18276] = {.lex_state = 437, .external_lex_state = 2},
  [18277] = {.lex_state = 24, .external_lex_state = 2},
  [18278] = {.lex_state = 437, .external_lex_state = 2},
  [18279] = {.lex_state = 437, .external_lex_state = 2},
  [18280] = {.lex_state = 24, .external_lex_state = 2},
  [18281] = {.lex_state = 32, .external_lex_state = 2},
  [18282] = {.lex_state = 24, .external_lex_state = 2},
  [18283] = {.lex_state = 437, .external_lex_state = 2},
  [18284] = {.lex_state = 24, .external_lex_state = 2},
  [18285] = {.lex_state = 437, .external_lex_state = 2},
  [18286] = {.lex_state = 24, .external_lex_state = 2},
  [18287] = {.lex_state = 24, .external_lex_state = 2},
  [18288] = {.lex_state = 24, .external_lex_state = 2},
  [18289] = {.lex_state = 24, .external_lex_state = 2},
  [18290] = {.lex_state = 437, .external_lex_state = 2},
  [18291] = {.lex_state = 24, .external_lex_state = 2},
  [18292] = {.lex_state = 24, .external_lex_state = 2},
  [18293] = {.lex_state = 437, .external_lex_state = 2},
  [18294] = {.lex_state = 437, .external_lex_state = 2},
  [18295] = {.lex_state = 24, .external_lex_state = 2},
  [18296] = {.lex_state = 437, .external_lex_state = 2},
  [18297] = {.lex_state = 24, .external_lex_state = 2},
  [18298] = {.lex_state = 24, .external_lex_state = 2},
  [18299] = {.lex_state = 32, .external_lex_state = 2},
  [18300] = {.lex_state = 24, .external_lex_state = 2},
  [18301] = {.lex_state = 24, .external_lex_state = 2},
  [18302] = {.lex_state = 32, .external_lex_state = 2},
  [18303] = {.lex_state = 437, .external_lex_state = 2},
  [18304] = {.lex_state = 54, .external_lex_state = 2},
  [18305] = {.lex_state = 24, .external_lex_state = 2},
  [18306] = {.lex_state = 437, .external_lex_state = 2},
  [18307] = {.lex_state = 54, .external_lex_state = 2},
  [18308] = {.lex_state = 54, .external_lex_state = 2},
  [18309] = {.lex_state = 437, .external_lex_state = 8},
  [18310] = {.lex_state = 437, .external_lex_state = 2},
  [18311] = {.lex_state = 24, .external_lex_state = 2},
  [18312] = {.lex_state = 32, .external_lex_state = 2},
  [18313] = {.lex_state = 24, .external_lex_state = 2},
  [18314] = {.lex_state = 24, .external_lex_state = 2},
  [18315] = {.lex_state = 107, .external_lex_state = 2},
  [18316] = {.lex_state = 32, .external_lex_state = 2},
  [18317] = {.lex_state = 24, .external_lex_state = 2},
  [18318] = {.lex_state = 24, .external_lex_state = 2},
  [18319] = {.lex_state = 54, .external_lex_state = 2},
  [18320] = {.lex_state = 54, .external_lex_state = 2},
  [18321] = {.lex_state = 437, .external_lex_state = 8},
  [18322] = {.lex_state = 24, .external_lex_state = 2},
  [18323] = {.lex_state = 24, .external_lex_state = 2},
  [18324] = {.lex_state = 32, .external_lex_state = 2},
  [18325] = {.lex_state = 32, .external_lex_state = 2},
  [18326] = {.lex_state = 24, .external_lex_state = 2},
  [18327] = {.lex_state = 437, .external_lex_state = 2},
  [18328] = {.lex_state = 437, .external_lex_state = 2},
  [18329] = {.lex_state = 437, .external_lex_state = 2},
  [18330] = {.lex_state = 24, .external_lex_state = 2},
  [18331] = {.lex_state = 24, .external_lex_state = 2},
  [18332] = {.lex_state = 32, .external_lex_state = 2},
  [18333] = {.lex_state = 32, .external_lex_state = 2},
  [18334] = {.lex_state = 54, .external_lex_state = 2},
  [18335] = {.lex_state = 24, .external_lex_state = 2},
  [18336] = {.lex_state = 437, .external_lex_state = 2},
  [18337] = {.lex_state = 54, .external_lex_state = 2},
  [18338] = {.lex_state = 24, .external_lex_state = 2},
  [18339] = {.lex_state = 437, .external_lex_state = 2},
  [18340] = {.lex_state = 24, .external_lex_state = 2},
  [18341] = {.lex_state = 54, .external_lex_state = 2},
  [18342] = {.lex_state = 24, .external_lex_state = 2},
  [18343] = {.lex_state = 54, .external_lex_state = 2},
  [18344] = {.lex_state = 32, .external_lex_state = 2},
  [18345] = {.lex_state = 437, .external_lex_state = 2},
  [18346] = {.lex_state = 437, .external_lex_state = 2},
  [18347] = {.lex_state = 24, .external_lex_state = 2},
  [18348] = {.lex_state = 24, .external_lex_state = 2},
  [18349] = {.lex_state = 24, .external_lex_state = 2},
  [18350] = {.lex_state = 24, .external_lex_state = 2},
  [18351] = {.lex_state = 32, .external_lex_state = 2},
  [18352] = {.lex_state = 24, .external_lex_state = 2},
  [18353] = {.lex_state = 54, .external_lex_state = 2},
  [18354] = {.lex_state = 54, .external_lex_state = 2},
  [18355] = {.lex_state = 54, .external_lex_state = 2},
  [18356] = {.lex_state = 24, .external_lex_state = 2},
  [18357] = {.lex_state = 32, .external_lex_state = 2},
  [18358] = {.lex_state = 32, .external_lex_state = 2},
  [18359] = {.lex_state = 24, .external_lex_state = 2},
  [18360] = {.lex_state = 24, .external_lex_state = 2},
  [18361] = {.lex_state = 437, .external_lex_state = 2},
  [18362] = {.lex_state = 24, .external_lex_state = 2},
  [18363] = {.lex_state = 437, .external_lex_state = 2},
  [18364] = {.lex_state = 24, .external_lex_state = 2},
  [18365] = {.lex_state = 32, .external_lex_state = 2},
  [18366] = {.lex_state = 437, .external_lex_state = 2},
  [18367] = {.lex_state = 32, .external_lex_state = 2},
  [18368] = {.lex_state = 24, .external_lex_state = 2},
  [18369] = {.lex_state = 24, .external_lex_state = 2},
  [18370] = {.lex_state = 437, .external_lex_state = 2},
  [18371] = {.lex_state = 32, .external_lex_state = 2},
  [18372] = {.lex_state = 437, .external_lex_state = 2},
  [18373] = {.lex_state = 24, .external_lex_state = 2},
  [18374] = {.lex_state = 437, .external_lex_state = 2},
  [18375] = {.lex_state = 24, .external_lex_state = 2},
  [18376] = {.lex_state = 8, .external_lex_state = 2},
  [18377] = {.lex_state = 32, .external_lex_state = 2},
  [18378] = {.lex_state = 437, .external_lex_state = 2},
  [18379] = {.lex_state = 24, .external_lex_state = 2},
  [18380] = {.lex_state = 24, .external_lex_state = 2},
  [18381] = {.lex_state = 24, .external_lex_state = 2},
  [18382] = {.lex_state = 24, .external_lex_state = 2},
  [18383] = {.lex_state = 24, .external_lex_state = 2},
  [18384] = {.lex_state = 54, .external_lex_state = 2},
  [18385] = {.lex_state = 24, .external_lex_state = 2},
  [18386] = {.lex_state = 24, .external_lex_state = 2},
  [18387] = {.lex_state = 24, .external_lex_state = 2},
  [18388] = {.lex_state = 54, .external_lex_state = 2},
  [18389] = {.lex_state = 32, .external_lex_state = 2},
  [18390] = {.lex_state = 437, .external_lex_state = 2},
  [18391] = {.lex_state = 24, .external_lex_state = 2},
  [18392] = {.lex_state = 24, .external_lex_state = 2},
  [18393] = {.lex_state = 437, .external_lex_state = 2},
  [18394] = {.lex_state = 24, .external_lex_state = 2},
  [18395] = {.lex_state = 24, .external_lex_state = 2},
  [18396] = {.lex_state = 24, .external_lex_state = 2},
  [18397] = {.lex_state = 24, .external_lex_state = 2},
  [18398] = {.lex_state = 24, .external_lex_state = 2},
  [18399] = {.lex_state = 437, .external_lex_state = 2},
  [18400] = {.lex_state = 24, .external_lex_state = 2},
  [18401] = {.lex_state = 32, .external_lex_state = 2},
  [18402] = {.lex_state = 24, .external_lex_state = 2},
  [18403] = {.lex_state = 437, .external_lex_state = 2},
  [18404] = {.lex_state = 32, .external_lex_state = 2},
  [18405] = {.lex_state = 24, .external_lex_state = 2},
  [18406] = {.lex_state = 24, .external_lex_state = 2},
  [18407] = {.lex_state = 437, .external_lex_state = 2},
  [18408] = {.lex_state = 24, .external_lex_state = 2},
  [18409] = {.lex_state = 437, .external_lex_state = 2},
  [18410] = {.lex_state = 437, .external_lex_state = 2},
  [18411] = {.lex_state = 437, .external_lex_state = 2},
  [18412] = {.lex_state = 32, .external_lex_state = 2},
  [18413] = {.lex_state = 24, .external_lex_state = 2},
  [18414] = {.lex_state = 24, .external_lex_state = 2},
  [18415] = {.lex_state = 24, .external_lex_state = 2},
  [18416] = {.lex_state = 32, .external_lex_state = 2},
  [18417] = {.lex_state = 437, .external_lex_state = 2},
  [18418] = {.lex_state = 437, .external_lex_state = 2},
  [18419] = {.lex_state = 24, .external_lex_state = 2},
  [18420] = {.lex_state = 32, .external_lex_state = 2},
  [18421] = {.lex_state = 32, .external_lex_state = 2},
  [18422] = {.lex_state = 54, .external_lex_state = 2},
  [18423] = {.lex_state = 437, .external_lex_state = 2},
  [18424] = {.lex_state = 38, .external_lex_state = 2},
  [18425] = {.lex_state = 437, .external_lex_state = 2},
  [18426] = {.lex_state = 437, .external_lex_state = 2},
  [18427] = {.lex_state = 437, .external_lex_state = 2},
  [18428] = {.lex_state = 32, .external_lex_state = 2},
  [18429] = {.lex_state = 32, .external_lex_state = 2},
  [18430] = {.lex_state = 437, .external_lex_state = 2},
  [18431] = {.lex_state = 437, .external_lex_state = 2},
  [18432] = {.lex_state = 437, .external_lex_state = 2},
  [18433] = {.lex_state = 437, .external_lex_state = 2},
  [18434] = {.lex_state = 437, .external_lex_state = 2},
  [18435] = {.lex_state = 437, .external_lex_state = 2},
  [18436] = {.lex_state = 32, .external_lex_state = 2},
  [18437] = {.lex_state = 11, .external_lex_state = 2},
  [18438] = {.lex_state = 11, .external_lex_state = 2},
  [18439] = {.lex_state = 32, .external_lex_state = 2},
  [18440] = {.lex_state = 11, .external_lex_state = 2},
  [18441] = {.lex_state = 437, .external_lex_state = 2},
  [18442] = {.lex_state = 11, .external_lex_state = 2},
  [18443] = {.lex_state = 437, .external_lex_state = 2},
  [18444] = {.lex_state = 437, .external_lex_state = 2},
  [18445] = {.lex_state = 437, .external_lex_state = 2},
  [18446] = {.lex_state = 437, .external_lex_state = 2},
  [18447] = {.lex_state = 437, .external_lex_state = 2},
  [18448] = {.lex_state = 437, .external_lex_state = 2},
  [18449] = {.lex_state = 437, .external_lex_state = 2},
  [18450] = {.lex_state = 437, .external_lex_state = 2},
  [18451] = {.lex_state = 437, .external_lex_state = 2},
  [18452] = {.lex_state = 437, .external_lex_state = 2},
  [18453] = {.lex_state = 437, .external_lex_state = 2},
  [18454] = {.lex_state = 11, .external_lex_state = 2},
  [18455] = {.lex_state = 437, .external_lex_state = 2},
  [18456] = {.lex_state = 32, .external_lex_state = 2},
  [18457] = {.lex_state = 437, .external_lex_state = 2},
  [18458] = {.lex_state = 437, .external_lex_state = 2},
  [18459] = {.lex_state = 437, .external_lex_state = 2},
  [18460] = {.lex_state = 437, .external_lex_state = 2},
  [18461] = {.lex_state = 437, .external_lex_state = 2},
  [18462] = {.lex_state = 437, .external_lex_state = 2},
  [18463] = {.lex_state = 437, .external_lex_state = 2},
  [18464] = {.lex_state = 32, .external_lex_state = 2},
  [18465] = {.lex_state = 437, .external_lex_state = 2},
  [18466] = {.lex_state = 437, .external_lex_state = 2},
  [18467] = {.lex_state = 437, .external_lex_state = 2},
  [18468] = {.lex_state = 437, .external_lex_state = 2},
  [18469] = {.lex_state = 437, .external_lex_state = 2},
  [18470] = {.lex_state = 437, .external_lex_state = 2},
  [18471] = {.lex_state = 10, .external_lex_state = 2},
  [18472] = {.lex_state = 437, .external_lex_state = 3},
  [18473] = {.lex_state = 437, .external_lex_state = 2},
  [18474] = {.lex_state = 437, .external_lex_state = 2},
  [18475] = {.lex_state = 437, .external_lex_state = 2},
  [18476] = {.lex_state = 437, .external_lex_state = 2},
  [18477] = {.lex_state = 437, .external_lex_state = 2},
  [18478] = {.lex_state = 32, .external_lex_state = 2},
  [18479] = {.lex_state = 437, .external_lex_state = 2},
  [18480] = {.lex_state = 437, .external_lex_state = 2},
  [18481] = {.lex_state = 437, .external_lex_state = 2},
  [18482] = {.lex_state = 437, .external_lex_state = 2},
  [18483] = {.lex_state = 437, .external_lex_state = 2},
  [18484] = {.lex_state = 437, .external_lex_state = 2},
  [18485] = {.lex_state = 437, .external_lex_state = 2},
  [18486] = {.lex_state = 437, .external_lex_state = 2},
  [18487] = {.lex_state = 437, .external_lex_state = 2},
  [18488] = {.lex_state = 437, .external_lex_state = 2},
  [18489] = {.lex_state = 437, .external_lex_state = 2},
  [18490] = {.lex_state = 437, .external_lex_state = 2},
  [18491] = {.lex_state = 437, .external_lex_state = 2},
  [18492] = {.lex_state = 437, .external_lex_state = 2},
  [18493] = {.lex_state = 32, .external_lex_state = 2},
  [18494] = {.lex_state = 437, .external_lex_state = 2},
  [18495] = {.lex_state = 11, .external_lex_state = 2},
  [18496] = {.lex_state = 32, .external_lex_state = 2},
  [18497] = {.lex_state = 437, .external_lex_state = 2},
  [18498] = {.lex_state = 437, .external_lex_state = 2},
  [18499] = {.lex_state = 11, .external_lex_state = 2},
  [18500] = {.lex_state = 437, .external_lex_state = 2},
  [18501] = {.lex_state = 437, .external_lex_state = 2},
  [18502] = {.lex_state = 437, .external_lex_state = 2},
  [18503] = {.lex_state = 437, .external_lex_state = 2},
  [18504] = {.lex_state = 437, .external_lex_state = 2},
  [18505] = {.lex_state = 437, .external_lex_state = 2},
  [18506] = {.lex_state = 437, .external_lex_state = 2},
  [18507] = {.lex_state = 10, .external_lex_state = 2},
  [18508] = {.lex_state = 437, .external_lex_state = 2},
  [18509] = {.lex_state = 437, .external_lex_state = 2},
  [18510] = {.lex_state = 437, .external_lex_state = 3},
  [18511] = {.lex_state = 32, .external_lex_state = 2},
  [18512] = {.lex_state = 437, .external_lex_state = 2},
  [18513] = {.lex_state = 437, .external_lex_state = 2},
  [18514] = {.lex_state = 437, .external_lex_state = 2},
  [18515] = {.lex_state = 437, .external_lex_state = 2},
  [18516] = {.lex_state = 437, .external_lex_state = 2},
  [18517] = {.lex_state = 11, .external_lex_state = 2},
  [18518] = {.lex_state = 437, .external_lex_state = 2},
  [18519] = {.lex_state = 437, .external_lex_state = 2},
  [18520] = {.lex_state = 437, .external_lex_state = 2},
  [18521] = {.lex_state = 24, .external_lex_state = 2},
  [18522] = {.lex_state = 437, .external_lex_state = 2},
  [18523] = {.lex_state = 437, .external_lex_state = 2},
  [18524] = {.lex_state = 437, .external_lex_state = 2},
  [18525] = {.lex_state = 437, .external_lex_state = 2},
  [18526] = {.lex_state = 437, .external_lex_state = 2},
  [18527] = {.lex_state = 437, .external_lex_state = 2},
  [18528] = {.lex_state = 437, .external_lex_state = 2},
  [18529] = {.lex_state = 437, .external_lex_state = 2},
  [18530] = {.lex_state = 437, .external_lex_state = 2},
  [18531] = {.lex_state = 437, .external_lex_state = 2},
  [18532] = {.lex_state = 437, .external_lex_state = 2},
  [18533] = {.lex_state = 437, .external_lex_state = 2},
  [18534] = {.lex_state = 437, .external_lex_state = 2},
  [18535] = {.lex_state = 437, .external_lex_state = 2},
  [18536] = {.lex_state = 437, .external_lex_state = 2},
  [18537] = {.lex_state = 437, .external_lex_state = 2},
  [18538] = {.lex_state = 32, .external_lex_state = 2},
  [18539] = {.lex_state = 11, .external_lex_state = 2},
  [18540] = {.lex_state = 437, .external_lex_state = 2},
  [18541] = {.lex_state = 437, .external_lex_state = 2},
  [18542] = {.lex_state = 32, .external_lex_state = 2},
  [18543] = {.lex_state = 437, .external_lex_state = 2},
  [18544] = {.lex_state = 11, .external_lex_state = 2},
  [18545] = {.lex_state = 437, .external_lex_state = 2},
  [18546] = {.lex_state = 437, .external_lex_state = 2},
  [18547] = {.lex_state = 437, .external_lex_state = 2},
  [18548] = {.lex_state = 32, .external_lex_state = 2},
  [18549] = {.lex_state = 437, .external_lex_state = 2},
  [18550] = {.lex_state = 437, .external_lex_state = 2},
  [18551] = {.lex_state = 437, .external_lex_state = 2},
  [18552] = {.lex_state = 437, .external_lex_state = 2},
  [18553] = {.lex_state = 437, .external_lex_state = 2},
  [18554] = {.lex_state = 437, .external_lex_state = 2},
  [18555] = {.lex_state = 32, .external_lex_state = 2},
  [18556] = {.lex_state = 32, .external_lex_state = 2},
  [18557] = {.lex_state = 437, .external_lex_state = 2},
  [18558] = {.lex_state = 437, .external_lex_state = 2},
  [18559] = {.lex_state = 24, .external_lex_state = 2},
  [18560] = {.lex_state = 11, .external_lex_state = 2},
  [18561] = {.lex_state = 32, .external_lex_state = 2},
  [18562] = {.lex_state = 437, .external_lex_state = 2},
  [18563] = {.lex_state = 437, .external_lex_state = 2},
  [18564] = {.lex_state = 24, .external_lex_state = 2},
  [18565] = {.lex_state = 11, .external_lex_state = 2},
  [18566] = {.lex_state = 11, .external_lex_state = 2},
  [18567] = {.lex_state = 437, .external_lex_state = 2},
  [18568] = {.lex_state = 32, .external_lex_state = 2},
  [18569] = {.lex_state = 437, .external_lex_state = 2},
  [18570] = {.lex_state = 437, .external_lex_state = 2},
  [18571] = {.lex_state = 437, .external_lex_state = 2},
  [18572] = {.lex_state = 437, .external_lex_state = 2},
  [18573] = {.lex_state = 32, .external_lex_state = 2},
  [18574] = {.lex_state = 437, .external_lex_state = 2},
  [18575] = {.lex_state = 437, .external_lex_state = 2},
  [18576] = {.lex_state = 32, .external_lex_state = 2},
  [18577] = {.lex_state = 437, .external_lex_state = 2},
  [18578] = {.lex_state = 437, .external_lex_state = 2},
  [18579] = {.lex_state = 437, .external_lex_state = 2},
  [18580] = {.lex_state = 437, .external_lex_state = 2},
  [18581] = {.lex_state = 11, .external_lex_state = 2},
  [18582] = {.lex_state = 32, .external_lex_state = 2},
  [18583] = {.lex_state = 437, .external_lex_state = 2},
  [18584] = {.lex_state = 437, .external_lex_state = 2},
  [18585] = {.lex_state = 437, .external_lex_state = 2},
  [18586] = {.lex_state = 437, .external_lex_state = 2},
  [18587] = {.lex_state = 32, .external_lex_state = 2},
  [18588] = {.lex_state = 437, .external_lex_state = 2},
  [18589] = {.lex_state = 32, .external_lex_state = 2},
  [18590] = {.lex_state = 437, .external_lex_state = 2},
  [18591] = {.lex_state = 32, .external_lex_state = 2},
  [18592] = {.lex_state = 32, .external_lex_state = 2},
  [18593] = {.lex_state = 11, .external_lex_state = 2},
  [18594] = {.lex_state = 11, .external_lex_state = 2},
  [18595] = {.lex_state = 437, .external_lex_state = 2},
  [18596] = {.lex_state = 437, .external_lex_state = 2},
  [18597] = {.lex_state = 32, .external_lex_state = 2},
  [18598] = {.lex_state = 437, .external_lex_state = 2},
  [18599] = {.lex_state = 11, .external_lex_state = 2},
  [18600] = {.lex_state = 437, .external_lex_state = 2},
  [18601] = {.lex_state = 32, .external_lex_state = 2},
  [18602] = {.lex_state = 11, .external_lex_state = 2},
  [18603] = {.lex_state = 11, .external_lex_state = 2},
  [18604] = {.lex_state = 11, .external_lex_state = 2},
  [18605] = {.lex_state = 437, .external_lex_state = 2},
  [18606] = {.lex_state = 437, .external_lex_state = 2},
  [18607] = {.lex_state = 437, .external_lex_state = 2},
  [18608] = {.lex_state = 437, .external_lex_state = 2},
  [18609] = {.lex_state = 32, .external_lex_state = 2},
  [18610] = {.lex_state = 11, .external_lex_state = 2},
  [18611] = {.lex_state = 32, .external_lex_state = 2},
  [18612] = {.lex_state = 437, .external_lex_state = 2},
  [18613] = {.lex_state = 437, .external_lex_state = 2},
  [18614] = {.lex_state = 437, .external_lex_state = 2},
  [18615] = {.lex_state = 437, .external_lex_state = 2},
  [18616] = {.lex_state = 437, .external_lex_state = 2},
  [18617] = {.lex_state = 437, .external_lex_state = 2},
  [18618] = {.lex_state = 437, .external_lex_state = 2},
  [18619] = {.lex_state = 32, .external_lex_state = 2},
  [18620] = {.lex_state = 437, .external_lex_state = 2},
  [18621] = {.lex_state = 11, .external_lex_state = 2},
  [18622] = {.lex_state = 11, .external_lex_state = 2},
  [18623] = {.lex_state = 32, .external_lex_state = 2},
  [18624] = {.lex_state = 24, .external_lex_state = 2},
  [18625] = {.lex_state = 437, .external_lex_state = 2},
  [18626] = {.lex_state = 437, .external_lex_state = 2},
  [18627] = {.lex_state = 437, .external_lex_state = 2},
  [18628] = {.lex_state = 437, .external_lex_state = 2},
  [18629] = {.lex_state = 437, .external_lex_state = 2},
  [18630] = {.lex_state = 437, .external_lex_state = 2},
  [18631] = {.lex_state = 437, .external_lex_state = 2},
  [18632] = {.lex_state = 437, .external_lex_state = 2},
  [18633] = {.lex_state = 32, .external_lex_state = 2},
  [18634] = {.lex_state = 437, .external_lex_state = 2},
  [18635] = {.lex_state = 437, .external_lex_state = 2},
  [18636] = {.lex_state = 437, .external_lex_state = 2},
  [18637] = {.lex_state = 437, .external_lex_state = 2},
  [18638] = {.lex_state = 437, .external_lex_state = 2},
  [18639] = {.lex_state = 437, .external_lex_state = 2},
  [18640] = {.lex_state = 32, .external_lex_state = 2},
  [18641] = {.lex_state = 437, .external_lex_state = 2},
  [18642] = {.lex_state = 437, .external_lex_state = 2},
  [18643] = {.lex_state = 437, .external_lex_state = 2},
  [18644] = {.lex_state = 32, .external_lex_state = 2},
  [18645] = {.lex_state = 11, .external_lex_state = 2},
  [18646] = {.lex_state = 437, .external_lex_state = 2},
  [18647] = {.lex_state = 437, .external_lex_state = 2},
  [18648] = {.lex_state = 10, .external_lex_state = 2},
  [18649] = {.lex_state = 437, .external_lex_state = 3},
  [18650] = {.lex_state = 437, .external_lex_state = 2},
  [18651] = {.lex_state = 24, .external_lex_state = 2},
  [18652] = {.lex_state = 437, .external_lex_state = 2},
  [18653] = {.lex_state = 437, .external_lex_state = 2},
  [18654] = {.lex_state = 437, .external_lex_state = 2},
  [18655] = {.lex_state = 32, .external_lex_state = 2},
  [18656] = {.lex_state = 437, .external_lex_state = 2},
  [18657] = {.lex_state = 437, .external_lex_state = 2},
  [18658] = {.lex_state = 437, .external_lex_state = 2},
  [18659] = {.lex_state = 437, .external_lex_state = 2},
  [18660] = {.lex_state = 437, .external_lex_state = 2},
  [18661] = {.lex_state = 437, .external_lex_state = 2},
  [18662] = {.lex_state = 437, .external_lex_state = 2},
  [18663] = {.lex_state = 437, .external_lex_state = 2},
  [18664] = {.lex_state = 437, .external_lex_state = 2},
  [18665] = {.lex_state = 437, .external_lex_state = 2},
  [18666] = {.lex_state = 437, .external_lex_state = 2},
  [18667] = {.lex_state = 437, .external_lex_state = 2},
  [18668] = {.lex_state = 437, .external_lex_state = 2},
  [18669] = {.lex_state = 32, .external_lex_state = 2},
  [18670] = {.lex_state = 437, .external_lex_state = 2},
  [18671] = {.lex_state = 437, .external_lex_state = 2},
  [18672] = {.lex_state = 437, .external_lex_state = 2},
  [18673] = {.lex_state = 10, .external_lex_state = 2},
  [18674] = {.lex_state = 437, .external_lex_state = 2},
  [18675] = {.lex_state = 10, .external_lex_state = 2},
  [18676] = {.lex_state = 437, .external_lex_state = 3},
  [18677] = {.lex_state = 32, .external_lex_state = 2},
  [18678] = {.lex_state = 32, .external_lex_state = 2},
  [18679] = {.lex_state = 32, .external_lex_state = 2},
  [18680] = {.lex_state = 437, .external_lex_state = 2},
  [18681] = {.lex_state = 437, .external_lex_state = 2},
  [18682] = {.lex_state = 437, .external_lex_state = 2},
  [18683] = {.lex_state = 24, .external_lex_state = 2},
  [18684] = {.lex_state = 437, .external_lex_state = 3},
  [18685] = {.lex_state = 11, .external_lex_state = 2},
  [18686] = {.lex_state = 32, .external_lex_state = 2},
  [18687] = {.lex_state = 32, .external_lex_state = 2},
  [18688] = {.lex_state = 437, .external_lex_state = 2},
  [18689] = {.lex_state = 32, .external_lex_state = 2},
  [18690] = {.lex_state = 11, .external_lex_state = 2},
  [18691] = {.lex_state = 437, .external_lex_state = 2},
  [18692] = {.lex_state = 437, .external_lex_state = 2},
  [18693] = {.lex_state = 437, .external_lex_state = 2},
  [18694] = {.lex_state = 437, .external_lex_state = 2},
  [18695] = {.lex_state = 437, .external_lex_state = 2},
  [18696] = {.lex_state = 437, .external_lex_state = 2},
  [18697] = {.lex_state = 437, .external_lex_state = 2},
  [18698] = {.lex_state = 437, .external_lex_state = 2},
  [18699] = {.lex_state = 437, .external_lex_state = 2},
  [18700] = {.lex_state = 437, .external_lex_state = 2},
  [18701] = {.lex_state = 437, .external_lex_state = 2},
  [18702] = {.lex_state = 32, .external_lex_state = 2},
  [18703] = {.lex_state = 437, .external_lex_state = 2},
  [18704] = {.lex_state = 32, .external_lex_state = 2},
  [18705] = {.lex_state = 32, .external_lex_state = 2},
  [18706] = {.lex_state = 437, .external_lex_state = 2},
  [18707] = {.lex_state = 32, .external_lex_state = 2},
  [18708] = {.lex_state = 437, .external_lex_state = 2},
  [18709] = {.lex_state = 437, .external_lex_state = 2},
  [18710] = {.lex_state = 437, .external_lex_state = 2},
  [18711] = {.lex_state = 437, .external_lex_state = 2},
  [18712] = {.lex_state = 437, .external_lex_state = 2},
  [18713] = {.lex_state = 437, .external_lex_state = 2},
  [18714] = {.lex_state = 437, .external_lex_state = 2},
  [18715] = {.lex_state = 437, .external_lex_state = 2},
  [18716] = {.lex_state = 437, .external_lex_state = 2},
  [18717] = {.lex_state = 437, .external_lex_state = 2},
  [18718] = {.lex_state = 437, .external_lex_state = 2},
  [18719] = {.lex_state = 437, .external_lex_state = 2},
  [18720] = {.lex_state = 437, .external_lex_state = 2},
  [18721] = {.lex_state = 437, .external_lex_state = 2},
  [18722] = {.lex_state = 437, .external_lex_state = 2},
  [18723] = {.lex_state = 437, .external_lex_state = 2},
  [18724] = {.lex_state = 437, .external_lex_state = 2},
  [18725] = {.lex_state = 32, .external_lex_state = 2},
  [18726] = {.lex_state = 437, .external_lex_state = 2},
  [18727] = {.lex_state = 437, .external_lex_state = 2},
  [18728] = {.lex_state = 437, .external_lex_state = 2},
  [18729] = {.lex_state = 437, .external_lex_state = 2},
  [18730] = {.lex_state = 437, .external_lex_state = 2},
  [18731] = {.lex_state = 437, .external_lex_state = 2},
  [18732] = {.lex_state = 437, .external_lex_state = 2},
  [18733] = {.lex_state = 32, .external_lex_state = 2},
  [18734] = {.lex_state = 437, .external_lex_state = 2},
  [18735] = {.lex_state = 437, .external_lex_state = 2},
  [18736] = {.lex_state = 437, .external_lex_state = 2},
  [18737] = {.lex_state = 437, .external_lex_state = 2},
  [18738] = {.lex_state = 437, .external_lex_state = 2},
  [18739] = {.lex_state = 437, .external_lex_state = 2},
  [18740] = {.lex_state = 437, .external_lex_state = 2},
  [18741] = {.lex_state = 32, .external_lex_state = 2},
  [18742] = {.lex_state = 32, .external_lex_state = 2},
  [18743] = {.lex_state = 437, .external_lex_state = 2},
  [18744] = {.lex_state = 437, .external_lex_state = 2},
  [18745] = {.lex_state = 11, .external_lex_state = 2},
  [18746] = {.lex_state = 437, .external_lex_state = 2},
  [18747] = {.lex_state = 437, .external_lex_state = 2},
  [18748] = {.lex_state = 437, .external_lex_state = 2},
  [18749] = {.lex_state = 32, .external_lex_state = 2},
  [18750] = {.lex_state = 437, .external_lex_state = 2},
  [18751] = {.lex_state = 24, .external_lex_state = 2},
  [18752] = {.lex_state = 437, .external_lex_state = 2},
  [18753] = {.lex_state = 32, .external_lex_state = 2},
  [18754] = {.lex_state = 32, .external_lex_state = 2},
  [18755] = {.lex_state = 24, .external_lex_state = 2},
  [18756] = {.lex_state = 11, .external_lex_state = 2},
  [18757] = {.lex_state = 437, .external_lex_state = 2},
  [18758] = {.lex_state = 32, .external_lex_state = 2},
  [18759] = {.lex_state = 437, .external_lex_state = 2},
  [18760] = {.lex_state = 437, .external_lex_state = 2},
  [18761] = {.lex_state = 437, .external_lex_state = 2},
  [18762] = {.lex_state = 437, .external_lex_state = 2},
  [18763] = {.lex_state = 437, .external_lex_state = 2},
  [18764] = {.lex_state = 437, .external_lex_state = 2},
  [18765] = {.lex_state = 437, .external_lex_state = 2},
  [18766] = {.lex_state = 437, .external_lex_state = 2},
  [18767] = {.lex_state = 437, .external_lex_state = 2},
  [18768] = {.lex_state = 437, .external_lex_state = 2},
  [18769] = {.lex_state = 437, .external_lex_state = 2},
  [18770] = {.lex_state = 437, .external_lex_state = 2},
  [18771] = {.lex_state = 437, .external_lex_state = 2},
  [18772] = {.lex_state = 437, .external_lex_state = 2},
  [18773] = {.lex_state = 437, .external_lex_state = 2},
  [18774] = {.lex_state = 32, .external_lex_state = 2},
  [18775] = {.lex_state = 32, .external_lex_state = 2},
  [18776] = {.lex_state = 437, .external_lex_state = 2},
  [18777] = {.lex_state = 437, .external_lex_state = 2},
  [18778] = {.lex_state = 437, .external_lex_state = 2},
  [18779] = {.lex_state = 437, .external_lex_state = 2},
  [18780] = {.lex_state = 32, .external_lex_state = 2},
  [18781] = {.lex_state = 437, .external_lex_state = 2},
  [18782] = {.lex_state = 437, .external_lex_state = 2},
  [18783] = {.lex_state = 32, .external_lex_state = 2},
  [18784] = {.lex_state = 437, .external_lex_state = 2},
  [18785] = {.lex_state = 32, .external_lex_state = 2},
  [18786] = {.lex_state = 437, .external_lex_state = 2},
  [18787] = {.lex_state = 437, .external_lex_state = 2},
  [18788] = {.lex_state = 437, .external_lex_state = 2},
  [18789] = {.lex_state = 437, .external_lex_state = 2},
  [18790] = {.lex_state = 437, .external_lex_state = 2},
  [18791] = {.lex_state = 32, .external_lex_state = 2},
  [18792] = {.lex_state = 437, .external_lex_state = 2},
  [18793] = {.lex_state = 437, .external_lex_state = 2},
  [18794] = {.lex_state = 437, .external_lex_state = 2},
  [18795] = {.lex_state = 437, .external_lex_state = 2},
  [18796] = {.lex_state = 437, .external_lex_state = 2},
  [18797] = {.lex_state = 437, .external_lex_state = 2},
  [18798] = {.lex_state = 437, .external_lex_state = 2},
  [18799] = {.lex_state = 11, .external_lex_state = 2},
  [18800] = {.lex_state = 437, .external_lex_state = 2},
  [18801] = {.lex_state = 437, .external_lex_state = 2},
  [18802] = {.lex_state = 437, .external_lex_state = 2},
  [18803] = {.lex_state = 437, .external_lex_state = 2},
  [18804] = {.lex_state = 437, .external_lex_state = 2},
  [18805] = {.lex_state = 437, .external_lex_state = 2},
  [18806] = {.lex_state = 437, .external_lex_state = 2},
  [18807] = {.lex_state = 11, .external_lex_state = 2},
  [18808] = {.lex_state = 11, .external_lex_state = 2},
  [18809] = {.lex_state = 437, .external_lex_state = 2},
  [18810] = {.lex_state = 437, .external_lex_state = 2},
  [18811] = {.lex_state = 32, .external_lex_state = 2},
  [18812] = {.lex_state = 437, .external_lex_state = 2},
  [18813] = {.lex_state = 437, .external_lex_state = 2},
  [18814] = {.lex_state = 437, .external_lex_state = 2},
  [18815] = {.lex_state = 437, .external_lex_state = 2},
  [18816] = {.lex_state = 437, .external_lex_state = 2},
  [18817] = {.lex_state = 437, .external_lex_state = 2},
  [18818] = {.lex_state = 437, .external_lex_state = 2},
  [18819] = {.lex_state = 437, .external_lex_state = 2},
  [18820] = {.lex_state = 437, .external_lex_state = 2},
  [18821] = {.lex_state = 437, .external_lex_state = 2},
  [18822] = {.lex_state = 437, .external_lex_state = 2},
  [18823] = {.lex_state = 437, .external_lex_state = 2},
  [18824] = {.lex_state = 437, .external_lex_state = 2},
  [18825] = {.lex_state = 437, .external_lex_state = 2},
  [18826] = {.lex_state = 437, .external_lex_state = 2},
  [18827] = {.lex_state = 10, .external_lex_state = 2},
  [18828] = {.lex_state = 437, .external_lex_state = 2},
  [18829] = {.lex_state = 437, .external_lex_state = 2},
  [18830] = {.lex_state = 437, .external_lex_state = 2},
  [18831] = {.lex_state = 32, .external_lex_state = 2},
  [18832] = {.lex_state = 32, .external_lex_state = 2},
  [18833] = {.lex_state = 437, .external_lex_state = 2},
  [18834] = {.lex_state = 32, .external_lex_state = 2},
  [18835] = {.lex_state = 437, .external_lex_state = 2},
  [18836] = {.lex_state = 437, .external_lex_state = 3},
  [18837] = {.lex_state = 437, .external_lex_state = 2},
  [18838] = {.lex_state = 10, .external_lex_state = 2},
  [18839] = {.lex_state = 10, .external_lex_state = 2},
  [18840] = {.lex_state = 32, .external_lex_state = 2},
  [18841] = {.lex_state = 437, .external_lex_state = 2},
  [18842] = {.lex_state = 437, .external_lex_state = 2},
  [18843] = {.lex_state = 437, .external_lex_state = 2},
  [18844] = {.lex_state = 437, .external_lex_state = 2},
  [18845] = {.lex_state = 437, .external_lex_state = 2},
  [18846] = {.lex_state = 437, .external_lex_state = 2},
  [18847] = {.lex_state = 24, .external_lex_state = 2},
  [18848] = {.lex_state = 32, .external_lex_state = 2},
  [18849] = {.lex_state = 32, .external_lex_state = 2},
  [18850] = {.lex_state = 32, .external_lex_state = 2},
  [18851] = {.lex_state = 437, .external_lex_state = 3},
  [18852] = {.lex_state = 437, .external_lex_state = 2},
  [18853] = {.lex_state = 437, .external_lex_state = 2},
  [18854] = {.lex_state = 437, .external_lex_state = 2},
  [18855] = {.lex_state = 437, .external_lex_state = 2},
  [18856] = {.lex_state = 437, .external_lex_state = 2},
  [18857] = {.lex_state = 437, .external_lex_state = 2},
  [18858] = {.lex_state = 437, .external_lex_state = 2},
  [18859] = {.lex_state = 32, .external_lex_state = 2},
  [18860] = {.lex_state = 437, .external_lex_state = 2},
  [18861] = {.lex_state = 437, .external_lex_state = 3},
  [18862] = {.lex_state = 32, .external_lex_state = 2},
  [18863] = {.lex_state = 437, .external_lex_state = 2},
  [18864] = {.lex_state = 32, .external_lex_state = 2},
  [18865] = {.lex_state = 437, .external_lex_state = 2},
  [18866] = {.lex_state = 437, .external_lex_state = 2},
  [18867] = {.lex_state = 437, .external_lex_state = 2},
  [18868] = {.lex_state = 437, .external_lex_state = 2},
  [18869] = {.lex_state = 437, .external_lex_state = 2},
  [18870] = {.lex_state = 437, .external_lex_state = 2},
  [18871] = {.lex_state = 437, .external_lex_state = 2},
  [18872] = {.lex_state = 437, .external_lex_state = 2},
  [18873] = {.lex_state = 32, .external_lex_state = 2},
  [18874] = {.lex_state = 437, .external_lex_state = 2},
  [18875] = {.lex_state = 437, .external_lex_state = 2},
  [18876] = {.lex_state = 437, .external_lex_state = 2},
  [18877] = {.lex_state = 437, .external_lex_state = 2},
  [18878] = {.lex_state = 437, .external_lex_state = 2},
  [18879] = {.lex_state = 437, .external_lex_state = 2},
  [18880] = {.lex_state = 437, .external_lex_state = 2},
  [18881] = {.lex_state = 437, .external_lex_state = 2},
  [18882] = {.lex_state = 437, .external_lex_state = 2},
  [18883] = {.lex_state = 11, .external_lex_state = 2},
  [18884] = {.lex_state = 11, .external_lex_state = 2},
  [18885] = {.lex_state = 11, .external_lex_state = 2},
  [18886] = {.lex_state = 11, .external_lex_state = 2},
  [18887] = {.lex_state = 11, .external_lex_state = 2},
  [18888] = {.lex_state = 11, .external_lex_state = 2},
  [18889] = {.lex_state = 437, .external_lex_state = 2},
  [18890] = {.lex_state = 11, .external_lex_state = 2},
  [18891] = {.lex_state = 437, .external_lex_state = 2},
  [18892] = {.lex_state = 11, .external_lex_state = 2},
  [18893] = {.lex_state = 437, .external_lex_state = 2},
  [18894] = {.lex_state = 437, .external_lex_state = 2},
  [18895] = {.lex_state = 11, .external_lex_state = 2},
  [18896] = {.lex_state = 437, .external_lex_state = 2},
  [18897] = {.lex_state = 437, .external_lex_state = 2},
  [18898] = {.lex_state = 437, .external_lex_state = 2},
  [18899] = {.lex_state = 11, .external_lex_state = 2},
  [18900] = {.lex_state = 11, .external_lex_state = 2},
  [18901] = {.lex_state = 11, .external_lex_state = 2},
  [18902] = {.lex_state = 437, .external_lex_state = 2},
  [18903] = {.lex_state = 11, .external_lex_state = 2},
  [18904] = {.lex_state = 437, .external_lex_state = 2},
  [18905] = {.lex_state = 437, .external_lex_state = 2},
  [18906] = {.lex_state = 10, .external_lex_state = 2},
  [18907] = {.lex_state = 11, .external_lex_state = 2},
  [18908] = {.lex_state = 437, .external_lex_state = 2},
  [18909] = {.lex_state = 437, .external_lex_state = 2},
  [18910] = {.lex_state = 437, .external_lex_state = 2},
  [18911] = {.lex_state = 437, .external_lex_state = 2},
  [18912] = {.lex_state = 32, .external_lex_state = 2},
  [18913] = {.lex_state = 437, .external_lex_state = 2},
  [18914] = {.lex_state = 437, .external_lex_state = 2},
  [18915] = {.lex_state = 437, .external_lex_state = 2},
  [18916] = {.lex_state = 437, .external_lex_state = 2},
  [18917] = {.lex_state = 24, .external_lex_state = 2},
  [18918] = {.lex_state = 437, .external_lex_state = 2},
  [18919] = {.lex_state = 32, .external_lex_state = 2},
  [18920] = {.lex_state = 437, .external_lex_state = 2},
  [18921] = {.lex_state = 437, .external_lex_state = 2},
  [18922] = {.lex_state = 437, .external_lex_state = 3},
  [18923] = {.lex_state = 32, .external_lex_state = 2},
  [18924] = {.lex_state = 437, .external_lex_state = 2},
  [18925] = {.lex_state = 437, .external_lex_state = 2},
  [18926] = {.lex_state = 437, .external_lex_state = 2},
  [18927] = {.lex_state = 32, .external_lex_state = 2},
  [18928] = {.lex_state = 437, .external_lex_state = 2},
  [18929] = {.lex_state = 437, .external_lex_state = 2},
  [18930] = {.lex_state = 437, .external_lex_state = 2},
  [18931] = {.lex_state = 437, .external_lex_state = 2},
  [18932] = {.lex_state = 437, .external_lex_state = 2},
  [18933] = {.lex_state = 437, .external_lex_state = 2},
  [18934] = {.lex_state = 437, .external_lex_state = 2},
  [18935] = {.lex_state = 437, .external_lex_state = 2},
  [18936] = {.lex_state = 437, .external_lex_state = 2},
  [18937] = {.lex_state = 32, .external_lex_state = 2},
  [18938] = {.lex_state = 10, .external_lex_state = 2},
  [18939] = {.lex_state = 437, .external_lex_state = 2},
  [18940] = {.lex_state = 437, .external_lex_state = 3},
  [18941] = {.lex_state = 437, .external_lex_state = 2},
  [18942] = {.lex_state = 32, .external_lex_state = 2},
  [18943] = {.lex_state = 437, .external_lex_state = 2},
  [18944] = {.lex_state = 24, .external_lex_state = 2},
  [18945] = {.lex_state = 32, .external_lex_state = 2},
  [18946] = {.lex_state = 437, .external_lex_state = 2},
  [18947] = {.lex_state = 437, .external_lex_state = 2},
  [18948] = {.lex_state = 437, .external_lex_state = 2},
  [18949] = {.lex_state = 437, .external_lex_state = 2},
  [18950] = {.lex_state = 437, .external_lex_state = 2},
  [18951] = {.lex_state = 437, .external_lex_state = 2},
  [18952] = {.lex_state = 437, .external_lex_state = 2},
  [18953] = {.lex_state = 32, .external_lex_state = 2},
  [18954] = {.lex_state = 437, .external_lex_state = 2},
  [18955] = {.lex_state = 437, .external_lex_state = 2},
  [18956] = {.lex_state = 437, .external_lex_state = 2},
  [18957] = {.lex_state = 10, .external_lex_state = 2},
  [18958] = {.lex_state = 437, .external_lex_state = 3},
  [18959] = {.lex_state = 32, .external_lex_state = 2},
  [18960] = {.lex_state = 32, .external_lex_state = 2},
  [18961] = {.lex_state = 32, .external_lex_state = 2},
  [18962] = {.lex_state = 437, .external_lex_state = 2},
  [18963] = {.lex_state = 437, .external_lex_state = 2},
  [18964] = {.lex_state = 437, .external_lex_state = 2},
  [18965] = {.lex_state = 437, .external_lex_state = 2},
  [18966] = {.lex_state = 437, .external_lex_state = 2},
  [18967] = {.lex_state = 437, .external_lex_state = 2},
  [18968] = {.lex_state = 437, .external_lex_state = 2},
  [18969] = {.lex_state = 24, .external_lex_state = 2},
  [18970] = {.lex_state = 32, .external_lex_state = 2},
  [18971] = {.lex_state = 437, .external_lex_state = 2},
  [18972] = {.lex_state = 11, .external_lex_state = 2},
  [18973] = {.lex_state = 437, .external_lex_state = 2},
  [18974] = {.lex_state = 437, .external_lex_state = 2},
  [18975] = {.lex_state = 437, .external_lex_state = 2},
  [18976] = {.lex_state = 11, .external_lex_state = 2},
  [18977] = {.lex_state = 32, .external_lex_state = 2},
  [18978] = {.lex_state = 437, .external_lex_state = 2},
  [18979] = {.lex_state = 24, .external_lex_state = 2},
  [18980] = {.lex_state = 437, .external_lex_state = 2},
  [18981] = {.lex_state = 32, .external_lex_state = 2},
  [18982] = {.lex_state = 437, .external_lex_state = 2},
  [18983] = {.lex_state = 437, .external_lex_state = 2},
  [18984] = {.lex_state = 11, .external_lex_state = 2},
  [18985] = {.lex_state = 437, .external_lex_state = 2},
  [18986] = {.lex_state = 437, .external_lex_state = 2},
  [18987] = {.lex_state = 437, .external_lex_state = 2},
  [18988] = {.lex_state = 437, .external_lex_state = 2},
  [18989] = {.lex_state = 24, .external_lex_state = 2},
  [18990] = {.lex_state = 32, .external_lex_state = 2},
  [18991] = {.lex_state = 437, .external_lex_state = 2},
  [18992] = {.lex_state = 437, .external_lex_state = 2},
  [18993] = {.lex_state = 437, .external_lex_state = 2},
  [18994] = {.lex_state = 437, .external_lex_state = 2},
  [18995] = {.lex_state = 437, .external_lex_state = 2},
  [18996] = {.lex_state = 11, .external_lex_state = 2},
  [18997] = {.lex_state = 437, .external_lex_state = 2},
  [18998] = {.lex_state = 437, .external_lex_state = 2},
  [18999] = {.lex_state = 437, .external_lex_state = 2},
  [19000] = {.lex_state = 437, .external_lex_state = 2},
  [19001] = {.lex_state = 32, .external_lex_state = 2},
  [19002] = {.lex_state = 10, .external_lex_state = 2},
  [19003] = {.lex_state = 32, .external_lex_state = 2},
  [19004] = {.lex_state = 437, .external_lex_state = 2},
  [19005] = {.lex_state = 437, .external_lex_state = 2},
  [19006] = {.lex_state = 437, .external_lex_state = 2},
  [19007] = {.lex_state = 32, .external_lex_state = 2},
  [19008] = {.lex_state = 437, .external_lex_state = 3},
  [19009] = {.lex_state = 11, .external_lex_state = 2},
  [19010] = {.lex_state = 437, .external_lex_state = 2},
  [19011] = {.lex_state = 11, .external_lex_state = 2},
  [19012] = {.lex_state = 437, .external_lex_state = 2},
  [19013] = {.lex_state = 437, .external_lex_state = 2},
  [19014] = {.lex_state = 437, .external_lex_state = 2},
  [19015] = {.lex_state = 32, .external_lex_state = 2},
  [19016] = {.lex_state = 11, .external_lex_state = 2},
  [19017] = {.lex_state = 437, .external_lex_state = 2},
  [19018] = {.lex_state = 437, .external_lex_state = 2},
  [19019] = {.lex_state = 10, .external_lex_state = 2},
  [19020] = {.lex_state = 437, .external_lex_state = 2},
  [19021] = {.lex_state = 437, .external_lex_state = 2},
  [19022] = {.lex_state = 437, .external_lex_state = 2},
  [19023] = {.lex_state = 437, .external_lex_state = 3},
  [19024] = {.lex_state = 437, .external_lex_state = 2},
  [19025] = {.lex_state = 437, .external_lex_state = 2},
  [19026] = {.lex_state = 10, .external_lex_state = 2},
  [19027] = {.lex_state = 437, .external_lex_state = 2},
  [19028] = {.lex_state = 24, .external_lex_state = 2},
  [19029] = {.lex_state = 437, .external_lex_state = 2},
  [19030] = {.lex_state = 437, .external_lex_state = 2},
  [19031] = {.lex_state = 437, .external_lex_state = 2},
  [19032] = {.lex_state = 32, .external_lex_state = 2},
  [19033] = {.lex_state = 24, .external_lex_state = 2},
  [19034] = {.lex_state = 11, .external_lex_state = 2},
  [19035] = {.lex_state = 437, .external_lex_state = 2},
  [19036] = {.lex_state = 437, .external_lex_state = 2},
  [19037] = {.lex_state = 437, .external_lex_state = 2},
  [19038] = {.lex_state = 437, .external_lex_state = 2},
  [19039] = {.lex_state = 437, .external_lex_state = 2},
  [19040] = {.lex_state = 437, .external_lex_state = 2},
  [19041] = {.lex_state = 437, .external_lex_state = 2},
  [19042] = {.lex_state = 437, .external_lex_state = 2},
  [19043] = {.lex_state = 437, .external_lex_state = 2},
  [19044] = {.lex_state = 437, .external_lex_state = 2},
  [19045] = {.lex_state = 10, .external_lex_state = 2},
  [19046] = {.lex_state = 32, .external_lex_state = 2},
  [19047] = {.lex_state = 32, .external_lex_state = 2},
  [19048] = {.lex_state = 11, .external_lex_state = 2},
  [19049] = {.lex_state = 32, .external_lex_state = 2},
  [19050] = {.lex_state = 437, .external_lex_state = 2},
  [19051] = {.lex_state = 437, .external_lex_state = 2},
  [19052] = {.lex_state = 437, .external_lex_state = 2},
  [19053] = {.lex_state = 437, .external_lex_state = 2},
  [19054] = {.lex_state = 437, .external_lex_state = 2},
  [19055] = {.lex_state = 437, .external_lex_state = 2},
  [19056] = {.lex_state = 437, .external_lex_state = 2},
  [19057] = {.lex_state = 437, .external_lex_state = 2},
  [19058] = {.lex_state = 437, .external_lex_state = 2},
  [19059] = {.lex_state = 24, .external_lex_state = 2},
  [19060] = {.lex_state = 437, .external_lex_state = 2},
  [19061] = {.lex_state = 32, .external_lex_state = 2},
  [19062] = {.lex_state = 437, .external_lex_state = 2},
  [19063] = {.lex_state = 437, .external_lex_state = 2},
  [19064] = {.lex_state = 437, .external_lex_state = 2},
  [19065] = {.lex_state = 437, .external_lex_state = 2},
  [19066] = {.lex_state = 437, .external_lex_state = 2},
  [19067] = {.lex_state = 437, .external_lex_state = 2},
  [19068] = {.lex_state = 437, .external_lex_state = 2},
  [19069] = {.lex_state = 437, .external_lex_state = 2},
  [19070] = {.lex_state = 437, .external_lex_state = 2},
  [19071] = {.lex_state = 11, .external_lex_state = 2},
  [19072] = {.lex_state = 32, .external_lex_state = 2},
  [19073] = {.lex_state = 437, .external_lex_state = 2},
  [19074] = {.lex_state = 437, .external_lex_state = 2},
  [19075] = {.lex_state = 32, .external_lex_state = 2},
  [19076] = {.lex_state = 11, .external_lex_state = 2},
  [19077] = {.lex_state = 437, .external_lex_state = 2},
  [19078] = {.lex_state = 437, .external_lex_state = 2},
  [19079] = {.lex_state = 437, .external_lex_state = 2},
  [19080] = {.lex_state = 437, .external_lex_state = 2},
  [19081] = {.lex_state = 437, .external_lex_state = 2},
  [19082] = {.lex_state = 437, .external_lex_state = 2},
  [19083] = {.lex_state = 437, .external_lex_state = 2},
  [19084] = {.lex_state = 437, .external_lex_state = 2},
  [19085] = {.lex_state = 11, .external_lex_state = 2},
  [19086] = {.lex_state = 437, .external_lex_state = 2},
  [19087] = {.lex_state = 437, .external_lex_state = 2},
  [19088] = {.lex_state = 32, .external_lex_state = 2},
  [19089] = {.lex_state = 437, .external_lex_state = 2},
  [19090] = {.lex_state = 32, .external_lex_state = 2},
  [19091] = {.lex_state = 437, .external_lex_state = 2},
  [19092] = {.lex_state = 437, .external_lex_state = 2},
  [19093] = {.lex_state = 32, .external_lex_state = 2},
  [19094] = {.lex_state = 437, .external_lex_state = 2},
  [19095] = {.lex_state = 437, .external_lex_state = 2},
  [19096] = {.lex_state = 437, .external_lex_state = 2},
  [19097] = {.lex_state = 437, .external_lex_state = 2},
  [19098] = {.lex_state = 437, .external_lex_state = 2},
  [19099] = {.lex_state = 11, .external_lex_state = 2},
  [19100] = {.lex_state = 32, .external_lex_state = 2},
  [19101] = {.lex_state = 437, .external_lex_state = 2},
  [19102] = {.lex_state = 32, .external_lex_state = 2},
  [19103] = {.lex_state = 437, .external_lex_state = 2},
  [19104] = {.lex_state = 437, .external_lex_state = 2},
  [19105] = {.lex_state = 437, .external_lex_state = 2},
  [19106] = {.lex_state = 437, .external_lex_state = 2},
  [19107] = {.lex_state = 437, .external_lex_state = 2},
  [19108] = {.lex_state = 437, .external_lex_state = 2},
  [19109] = {.lex_state = 437, .external_lex_state = 2},
  [19110] = {.lex_state = 32, .external_lex_state = 2},
  [19111] = {.lex_state = 32, .external_lex_state = 2},
  [19112] = {.lex_state = 437, .external_lex_state = 2},
  [19113] = {.lex_state = 437, .external_lex_state = 2},
  [19114] = {.lex_state = 437, .external_lex_state = 2},
  [19115] = {.lex_state = 11, .external_lex_state = 2},
  [19116] = {.lex_state = 437, .external_lex_state = 2},
  [19117] = {.lex_state = 437, .external_lex_state = 2},
  [19118] = {.lex_state = 32, .external_lex_state = 2},
  [19119] = {.lex_state = 437, .external_lex_state = 2},
  [19120] = {.lex_state = 437, .external_lex_state = 2},
  [19121] = {.lex_state = 437, .external_lex_state = 2},
  [19122] = {.lex_state = 437, .external_lex_state = 2},
  [19123] = {.lex_state = 437, .external_lex_state = 2},
  [19124] = {.lex_state = 437, .external_lex_state = 2},
  [19125] = {.lex_state = 437, .external_lex_state = 2},
  [19126] = {.lex_state = 437, .external_lex_state = 2},
  [19127] = {.lex_state = 437, .external_lex_state = 2},
  [19128] = {.lex_state = 437, .external_lex_state = 2},
  [19129] = {.lex_state = 32, .external_lex_state = 2},
  [19130] = {.lex_state = 437, .external_lex_state = 2},
  [19131] = {.lex_state = 437, .external_lex_state = 2},
  [19132] = {.lex_state = 437, .external_lex_state = 3},
  [19133] = {.lex_state = 32, .external_lex_state = 2},
  [19134] = {.lex_state = 437, .external_lex_state = 2},
  [19135] = {.lex_state = 437, .external_lex_state = 2},
  [19136] = {.lex_state = 437, .external_lex_state = 2},
  [19137] = {.lex_state = 437, .external_lex_state = 2},
  [19138] = {.lex_state = 437, .external_lex_state = 2},
  [19139] = {.lex_state = 32, .external_lex_state = 2},
  [19140] = {.lex_state = 437, .external_lex_state = 2},
  [19141] = {.lex_state = 437, .external_lex_state = 2},
  [19142] = {.lex_state = 437, .external_lex_state = 2},
  [19143] = {.lex_state = 437, .external_lex_state = 2},
  [19144] = {.lex_state = 437, .external_lex_state = 2},
  [19145] = {.lex_state = 437, .external_lex_state = 2},
  [19146] = {.lex_state = 437, .external_lex_state = 2},
  [19147] = {.lex_state = 32, .external_lex_state = 2},
  [19148] = {.lex_state = 437, .external_lex_state = 2},
  [19149] = {.lex_state = 437, .external_lex_state = 2},
  [19150] = {.lex_state = 11, .external_lex_state = 2},
  [19151] = {.lex_state = 32, .external_lex_state = 2},
  [19152] = {.lex_state = 437, .external_lex_state = 2},
  [19153] = {.lex_state = 437, .external_lex_state = 2},
  [19154] = {.lex_state = 437, .external_lex_state = 2},
  [19155] = {.lex_state = 437, .external_lex_state = 2},
  [19156] = {.lex_state = 437, .external_lex_state = 2},
  [19157] = {.lex_state = 437, .external_lex_state = 2},
  [19158] = {.lex_state = 437, .external_lex_state = 2},
  [19159] = {.lex_state = 437, .external_lex_state = 2},
  [19160] = {.lex_state = 437, .external_lex_state = 2},
  [19161] = {.lex_state = 437, .external_lex_state = 2},
  [19162] = {.lex_state = 437, .external_lex_state = 2},
  [19163] = {.lex_state = 437, .external_lex_state = 2},
  [19164] = {.lex_state = 437, .external_lex_state = 2},
  [19165] = {.lex_state = 437, .external_lex_state = 2},
  [19166] = {.lex_state = 437, .external_lex_state = 2},
  [19167] = {.lex_state = 437, .external_lex_state = 2},
  [19168] = {.lex_state = 437, .external_lex_state = 2},
  [19169] = {.lex_state = 32, .external_lex_state = 2},
  [19170] = {.lex_state = 437, .external_lex_state = 2},
  [19171] = {.lex_state = 437, .external_lex_state = 2},
  [19172] = {.lex_state = 437, .external_lex_state = 2},
  [19173] = {.lex_state = 437, .external_lex_state = 2},
  [19174] = {.lex_state = 437, .external_lex_state = 2},
  [19175] = {.lex_state = 437, .external_lex_state = 2},
  [19176] = {.lex_state = 437, .external_lex_state = 2},
  [19177] = {.lex_state = 437, .external_lex_state = 2},
  [19178] = {.lex_state = 437, .external_lex_state = 2},
  [19179] = {.lex_state = 437, .external_lex_state = 2},
  [19180] = {.lex_state = 437, .external_lex_state = 2},
  [19181] = {.lex_state = 437, .external_lex_state = 2},
  [19182] = {.lex_state = 437, .external_lex_state = 2},
  [19183] = {.lex_state = 437, .external_lex_state = 2},
  [19184] = {.lex_state = 437, .external_lex_state = 2},
  [19185] = {.lex_state = 437, .external_lex_state = 2},
  [19186] = {.lex_state = 32, .external_lex_state = 2},
  [19187] = {.lex_state = 32, .external_lex_state = 2},
  [19188] = {.lex_state = 10, .external_lex_state = 2},
  [19189] = {.lex_state = 437, .external_lex_state = 2},
  [19190] = {.lex_state = 11, .external_lex_state = 2},
  [19191] = {.lex_state = 11, .external_lex_state = 2},
  [19192] = {.lex_state = 11, .external_lex_state = 2},
  [19193] = {.lex_state = 11, .external_lex_state = 2},
  [19194] = {.lex_state = 437, .external_lex_state = 2},
  [19195] = {.lex_state = 437, .external_lex_state = 2},
  [19196] = {.lex_state = 11, .external_lex_state = 2},
  [19197] = {.lex_state = 32, .external_lex_state = 2},
  [19198] = {.lex_state = 437, .external_lex_state = 2},
  [19199] = {.lex_state = 24, .external_lex_state = 2},
  [19200] = {.lex_state = 437, .external_lex_state = 2},
  [19201] = {.lex_state = 437, .external_lex_state = 2},
  [19202] = {.lex_state = 437, .external_lex_state = 2},
  [19203] = {.lex_state = 437, .external_lex_state = 2},
  [19204] = {.lex_state = 437, .external_lex_state = 2},
  [19205] = {.lex_state = 437, .external_lex_state = 2},
  [19206] = {.lex_state = 437, .external_lex_state = 2},
  [19207] = {.lex_state = 437, .external_lex_state = 2},
  [19208] = {.lex_state = 437, .external_lex_state = 2},
  [19209] = {.lex_state = 437, .external_lex_state = 2},
  [19210] = {.lex_state = 437, .external_lex_state = 2},
  [19211] = {.lex_state = 437, .external_lex_state = 2},
  [19212] = {.lex_state = 437, .external_lex_state = 2},
  [19213] = {.lex_state = 32, .external_lex_state = 2},
  [19214] = {.lex_state = 437, .external_lex_state = 2},
  [19215] = {.lex_state = 437, .external_lex_state = 2},
  [19216] = {.lex_state = 437, .external_lex_state = 2},
  [19217] = {.lex_state = 437, .external_lex_state = 2},
  [19218] = {.lex_state = 437, .external_lex_state = 2},
  [19219] = {.lex_state = 437, .external_lex_state = 2},
  [19220] = {.lex_state = 10, .external_lex_state = 2},
  [19221] = {.lex_state = 437, .external_lex_state = 2},
  [19222] = {.lex_state = 10, .external_lex_state = 2},
  [19223] = {.lex_state = 437, .external_lex_state = 3},
  [19224] = {.lex_state = 437, .external_lex_state = 2},
  [19225] = {.lex_state = 437, .external_lex_state = 2},
  [19226] = {.lex_state = 437, .external_lex_state = 3},
  [19227] = {.lex_state = 32, .external_lex_state = 2},
  [19228] = {.lex_state = 437, .external_lex_state = 2},
  [19229] = {.lex_state = 437, .external_lex_state = 2},
  [19230] = {.lex_state = 437, .external_lex_state = 2},
  [19231] = {.lex_state = 437, .external_lex_state = 2},
  [19232] = {.lex_state = 437, .external_lex_state = 2},
  [19233] = {.lex_state = 24, .external_lex_state = 2},
  [19234] = {.lex_state = 437, .external_lex_state = 2},
  [19235] = {.lex_state = 437, .external_lex_state = 2},
  [19236] = {.lex_state = 32, .external_lex_state = 2},
  [19237] = {.lex_state = 437, .external_lex_state = 2},
  [19238] = {.lex_state = 32, .external_lex_state = 2},
  [19239] = {.lex_state = 32, .external_lex_state = 2},
  [19240] = {.lex_state = 437, .external_lex_state = 2},
  [19241] = {.lex_state = 437, .external_lex_state = 2},
  [19242] = {.lex_state = 437, .external_lex_state = 2},
  [19243] = {.lex_state = 437, .external_lex_state = 2},
  [19244] = {.lex_state = 437, .external_lex_state = 2},
  [19245] = {.lex_state = 437, .external_lex_state = 2},
  [19246] = {.lex_state = 437, .external_lex_state = 2},
  [19247] = {.lex_state = 24, .external_lex_state = 2},
  [19248] = {.lex_state = 32, .external_lex_state = 2},
  [19249] = {.lex_state = 437, .external_lex_state = 2},
  [19250] = {.lex_state = 437, .external_lex_state = 2},
  [19251] = {.lex_state = 437, .external_lex_state = 2},
  [19252] = {.lex_state = 437, .external_lex_state = 2},
  [19253] = {.lex_state = 32, .external_lex_state = 2},
  [19254] = {.lex_state = 437, .external_lex_state = 2},
  [19255] = {.lex_state = 437, .external_lex_state = 2},
  [19256] = {.lex_state = 437, .external_lex_state = 2},
  [19257] = {.lex_state = 437, .external_lex_state = 2},
  [19258] = {.lex_state = 11, .external_lex_state = 2},
  [19259] = {.lex_state = 437, .external_lex_state = 2},
  [19260] = {.lex_state = 11, .external_lex_state = 2},
  [19261] = {.lex_state = 11, .external_lex_state = 2},
  [19262] = {.lex_state = 11, .external_lex_state = 2},
  [19263] = {.lex_state = 437, .external_lex_state = 2},
  [19264] = {.lex_state = 437, .external_lex_state = 2},
  [19265] = {.lex_state = 437, .external_lex_state = 2},
  [19266] = {.lex_state = 437, .external_lex_state = 2},
  [19267] = {.lex_state = 24, .external_lex_state = 2},
  [19268] = {.lex_state = 11, .external_lex_state = 2},
  [19269] = {.lex_state = 437, .external_lex_state = 2},
  [19270] = {.lex_state = 437, .external_lex_state = 2},
  [19271] = {.lex_state = 437, .external_lex_state = 2},
  [19272] = {.lex_state = 32, .external_lex_state = 2},
  [19273] = {.lex_state = 32, .external_lex_state = 2},
  [19274] = {.lex_state = 437, .external_lex_state = 2},
  [19275] = {.lex_state = 437, .external_lex_state = 2},
  [19276] = {.lex_state = 437, .external_lex_state = 2},
  [19277] = {.lex_state = 437, .external_lex_state = 2},
  [19278] = {.lex_state = 437, .external_lex_state = 2},
  [19279] = {.lex_state = 32, .external_lex_state = 2},
  [19280] = {.lex_state = 437, .external_lex_state = 2},
  [19281] = {.lex_state = 437, .external_lex_state = 2},
  [19282] = {.lex_state = 437, .external_lex_state = 2},
  [19283] = {.lex_state = 437, .external_lex_state = 2},
  [19284] = {.lex_state = 437, .external_lex_state = 2},
  [19285] = {.lex_state = 437, .external_lex_state = 2},
  [19286] = {.lex_state = 11, .external_lex_state = 2},
  [19287] = {.lex_state = 32, .external_lex_state = 2},
  [19288] = {.lex_state = 11, .external_lex_state = 2},
  [19289] = {.lex_state = 11, .external_lex_state = 2},
  [19290] = {.lex_state = 437, .external_lex_state = 2},
  [19291] = {.lex_state = 437, .external_lex_state = 2},
  [19292] = {.lex_state = 32, .external_lex_state = 2},
  [19293] = {.lex_state = 437, .external_lex_state = 2},
  [19294] = {.lex_state = 437, .external_lex_state = 2},
  [19295] = {.lex_state = 437, .external_lex_state = 2},
  [19296] = {.lex_state = 437, .external_lex_state = 2},
  [19297] = {.lex_state = 437, .external_lex_state = 2},
  [19298] = {.lex_state = 437, .external_lex_state = 2},
  [19299] = {.lex_state = 437, .external_lex_state = 2},
  [19300] = {.lex_state = 437, .external_lex_state = 2},
  [19301] = {.lex_state = 11, .external_lex_state = 2},
  [19302] = {.lex_state = 437, .external_lex_state = 2},
  [19303] = {.lex_state = 32, .external_lex_state = 2},
  [19304] = {.lex_state = 437, .external_lex_state = 2},
  [19305] = {.lex_state = 437, .external_lex_state = 2},
  [19306] = {.lex_state = 437, .external_lex_state = 2},
  [19307] = {.lex_state = 437, .external_lex_state = 2},
  [19308] = {.lex_state = 10, .external_lex_state = 2},
  [19309] = {.lex_state = 437, .external_lex_state = 2},
  [19310] = {.lex_state = 32, .external_lex_state = 2},
  [19311] = {.lex_state = 437, .external_lex_state = 2},
  [19312] = {.lex_state = 11, .external_lex_state = 2},
  [19313] = {.lex_state = 437, .external_lex_state = 3},
  [19314] = {.lex_state = 437, .external_lex_state = 2},
  [19315] = {.lex_state = 437, .external_lex_state = 2},
  [19316] = {.lex_state = 32, .external_lex_state = 2},
  [19317] = {.lex_state = 32, .external_lex_state = 2},
  [19318] = {.lex_state = 437, .external_lex_state = 2},
  [19319] = {.lex_state = 24, .external_lex_state = 2},
  [19320] = {.lex_state = 437, .external_lex_state = 2},
  [19321] = {.lex_state = 437, .external_lex_state = 2},
  [19322] = {.lex_state = 437, .external_lex_state = 2},
  [19323] = {.lex_state = 437, .external_lex_state = 2},
  [19324] = {.lex_state = 437, .external_lex_state = 2},
  [19325] = {.lex_state = 32, .external_lex_state = 2},
  [19326] = {.lex_state = 437, .external_lex_state = 2},
  [19327] = {.lex_state = 437, .external_lex_state = 2},
  [19328] = {.lex_state = 437, .external_lex_state = 2},
  [19329] = {.lex_state = 32, .external_lex_state = 2},
  [19330] = {.lex_state = 437, .external_lex_state = 2},
  [19331] = {.lex_state = 437, .external_lex_state = 2},
  [19332] = {.lex_state = 437, .external_lex_state = 2},
  [19333] = {.lex_state = 11, .external_lex_state = 2},
  [19334] = {.lex_state = 437, .external_lex_state = 2},
  [19335] = {.lex_state = 437, .external_lex_state = 2},
  [19336] = {.lex_state = 437, .external_lex_state = 2},
  [19337] = {.lex_state = 437, .external_lex_state = 2},
  [19338] = {.lex_state = 437, .external_lex_state = 2},
  [19339] = {.lex_state = 437, .external_lex_state = 2},
  [19340] = {.lex_state = 437, .external_lex_state = 2},
  [19341] = {.lex_state = 437, .external_lex_state = 2},
  [19342] = {.lex_state = 11, .external_lex_state = 2},
  [19343] = {.lex_state = 437, .external_lex_state = 2},
  [19344] = {.lex_state = 437, .external_lex_state = 2},
  [19345] = {.lex_state = 437, .external_lex_state = 2},
  [19346] = {.lex_state = 437, .external_lex_state = 2},
  [19347] = {.lex_state = 11, .external_lex_state = 2},
  [19348] = {.lex_state = 32, .external_lex_state = 2},
  [19349] = {.lex_state = 437, .external_lex_state = 2},
  [19350] = {.lex_state = 437, .external_lex_state = 2},
  [19351] = {.lex_state = 437, .external_lex_state = 2},
  [19352] = {.lex_state = 11, .external_lex_state = 2},
  [19353] = {.lex_state = 437, .external_lex_state = 2},
  [19354] = {.lex_state = 437, .external_lex_state = 2},
  [19355] = {.lex_state = 437, .external_lex_state = 2},
  [19356] = {.lex_state = 437, .external_lex_state = 2},
  [19357] = {.lex_state = 437, .external_lex_state = 2},
  [19358] = {.lex_state = 32, .external_lex_state = 2},
  [19359] = {.lex_state = 437, .external_lex_state = 2},
  [19360] = {.lex_state = 437, .external_lex_state = 2},
  [19361] = {.lex_state = 437, .external_lex_state = 2},
  [19362] = {.lex_state = 437, .external_lex_state = 2},
  [19363] = {.lex_state = 437, .external_lex_state = 2},
  [19364] = {.lex_state = 10, .external_lex_state = 2},
  [19365] = {.lex_state = 437, .external_lex_state = 2},
  [19366] = {.lex_state = 437, .external_lex_state = 3},
  [19367] = {.lex_state = 32, .external_lex_state = 2},
  [19368] = {.lex_state = 24, .external_lex_state = 2},
  [19369] = {.lex_state = 32, .external_lex_state = 2},
  [19370] = {.lex_state = 32, .external_lex_state = 2},
  [19371] = {.lex_state = 437, .external_lex_state = 2},
  [19372] = {.lex_state = 437, .external_lex_state = 2},
  [19373] = {.lex_state = 437, .external_lex_state = 2},
  [19374] = {.lex_state = 437, .external_lex_state = 2},
  [19375] = {.lex_state = 437, .external_lex_state = 2},
  [19376] = {.lex_state = 437, .external_lex_state = 2},
  [19377] = {.lex_state = 437, .external_lex_state = 2},
  [19378] = {.lex_state = 437, .external_lex_state = 2},
  [19379] = {.lex_state = 11, .external_lex_state = 2},
  [19380] = {.lex_state = 11, .external_lex_state = 2},
  [19381] = {.lex_state = 437, .external_lex_state = 2},
  [19382] = {.lex_state = 437, .external_lex_state = 2},
  [19383] = {.lex_state = 32, .external_lex_state = 2},
  [19384] = {.lex_state = 437, .external_lex_state = 2},
  [19385] = {.lex_state = 437, .external_lex_state = 2},
  [19386] = {.lex_state = 437, .external_lex_state = 2},
  [19387] = {.lex_state = 437, .external_lex_state = 2},
  [19388] = {.lex_state = 437, .external_lex_state = 2},
  [19389] = {.lex_state = 437, .external_lex_state = 2},
  [19390] = {.lex_state = 437, .external_lex_state = 2},
  [19391] = {.lex_state = 38, .external_lex_state = 2},
  [19392] = {.lex_state = 32, .external_lex_state = 2},
  [19393] = {.lex_state = 437, .external_lex_state = 2},
  [19394] = {.lex_state = 437, .external_lex_state = 2},
  [19395] = {.lex_state = 32, .external_lex_state = 2},
  [19396] = {.lex_state = 437, .external_lex_state = 2},
  [19397] = {.lex_state = 437, .external_lex_state = 2},
  [19398] = {.lex_state = 24, .external_lex_state = 2},
  [19399] = {.lex_state = 437, .external_lex_state = 2},
  [19400] = {.lex_state = 437, .external_lex_state = 2},
  [19401] = {.lex_state = 437, .external_lex_state = 2},
  [19402] = {.lex_state = 437, .external_lex_state = 2},
  [19403] = {.lex_state = 437, .external_lex_state = 2},
  [19404] = {.lex_state = 32, .external_lex_state = 2},
  [19405] = {.lex_state = 437, .external_lex_state = 2},
  [19406] = {.lex_state = 11, .external_lex_state = 2},
  [19407] = {.lex_state = 32, .external_lex_state = 2},
  [19408] = {.lex_state = 32, .external_lex_state = 2},
  [19409] = {.lex_state = 32, .external_lex_state = 2},
  [19410] = {.lex_state = 11, .external_lex_state = 2},
  [19411] = {.lex_state = 437, .external_lex_state = 2},
  [19412] = {.lex_state = 32, .external_lex_state = 2},
  [19413] = {.lex_state = 32, .external_lex_state = 2},
  [19414] = {.lex_state = 32, .external_lex_state = 2},
  [19415] = {.lex_state = 437, .external_lex_state = 2},
  [19416] = {.lex_state = 437, .external_lex_state = 2},
  [19417] = {.lex_state = 437, .external_lex_state = 2},
  [19418] = {.lex_state = 437, .external_lex_state = 2},
  [19419] = {.lex_state = 437, .external_lex_state = 2},
  [19420] = {.lex_state = 437, .external_lex_state = 2},
  [19421] = {.lex_state = 437, .external_lex_state = 2},
  [19422] = {.lex_state = 437, .external_lex_state = 2},
  [19423] = {.lex_state = 437, .external_lex_state = 2},
  [19424] = {.lex_state = 437, .external_lex_state = 2},
  [19425] = {.lex_state = 437, .external_lex_state = 2},
  [19426] = {.lex_state = 437, .external_lex_state = 2},
  [19427] = {.lex_state = 437, .external_lex_state = 2},
  [19428] = {.lex_state = 437, .external_lex_state = 2},
  [19429] = {.lex_state = 437, .external_lex_state = 2},
  [19430] = {.lex_state = 437, .external_lex_state = 2},
  [19431] = {.lex_state = 32, .external_lex_state = 2},
  [19432] = {.lex_state = 437, .external_lex_state = 2},
  [19433] = {.lex_state = 437, .external_lex_state = 2},
  [19434] = {.lex_state = 437, .external_lex_state = 2},
  [19435] = {.lex_state = 437, .external_lex_state = 2},
  [19436] = {.lex_state = 437, .external_lex_state = 2},
  [19437] = {.lex_state = 437, .external_lex_state = 2},
  [19438] = {.lex_state = 32, .external_lex_state = 2},
  [19439] = {.lex_state = 32, .external_lex_state = 2},
  [19440] = {.lex_state = 437, .external_lex_state = 2},
  [19441] = {.lex_state = 437, .external_lex_state = 2},
  [19442] = {.lex_state = 437, .external_lex_state = 2},
  [19443] = {.lex_state = 437, .external_lex_state = 2},
  [19444] = {.lex_state = 32, .external_lex_state = 2},
  [19445] = {.lex_state = 437, .external_lex_state = 2},
  [19446] = {.lex_state = 437, .external_lex_state = 2},
  [19447] = {.lex_state = 11, .external_lex_state = 2},
  [19448] = {.lex_state = 437, .external_lex_state = 2},
  [19449] = {.lex_state = 437, .external_lex_state = 2},
  [19450] = {.lex_state = 24, .external_lex_state = 2},
  [19451] = {.lex_state = 437, .external_lex_state = 2},
  [19452] = {.lex_state = 437, .external_lex_state = 2},
  [19453] = {.lex_state = 437, .external_lex_state = 2},
  [19454] = {.lex_state = 437, .external_lex_state = 2},
  [19455] = {.lex_state = 437, .external_lex_state = 2},
  [19456] = {.lex_state = 437, .external_lex_state = 2},
  [19457] = {.lex_state = 437, .external_lex_state = 2},
  [19458] = {.lex_state = 437, .external_lex_state = 2},
  [19459] = {.lex_state = 437, .external_lex_state = 2},
  [19460] = {.lex_state = 437, .external_lex_state = 2},
  [19461] = {.lex_state = 437, .external_lex_state = 2},
  [19462] = {.lex_state = 437, .external_lex_state = 2},
  [19463] = {.lex_state = 437, .external_lex_state = 2},
  [19464] = {.lex_state = 437, .external_lex_state = 2},
  [19465] = {.lex_state = 437, .external_lex_state = 2},
  [19466] = {.lex_state = 437, .external_lex_state = 2},
  [19467] = {.lex_state = 437, .external_lex_state = 2},
  [19468] = {.lex_state = 437, .external_lex_state = 2},
  [19469] = {.lex_state = 437, .external_lex_state = 2},
  [19470] = {.lex_state = 437, .external_lex_state = 2},
  [19471] = {.lex_state = 437, .external_lex_state = 2},
  [19472] = {.lex_state = 11, .external_lex_state = 2},
  [19473] = {.lex_state = 437, .external_lex_state = 2},
  [19474] = {.lex_state = 437, .external_lex_state = 2},
  [19475] = {.lex_state = 11, .external_lex_state = 2},
  [19476] = {.lex_state = 11, .external_lex_state = 2},
  [19477] = {.lex_state = 437, .external_lex_state = 2},
  [19478] = {.lex_state = 11, .external_lex_state = 2},
  [19479] = {.lex_state = 437, .external_lex_state = 2},
  [19480] = {.lex_state = 437, .external_lex_state = 2},
  [19481] = {.lex_state = 437, .external_lex_state = 2},
  [19482] = {.lex_state = 437, .external_lex_state = 2},
  [19483] = {.lex_state = 437, .external_lex_state = 2},
  [19484] = {.lex_state = 107, .external_lex_state = 2},
  [19485] = {.lex_state = 437, .external_lex_state = 2},
  [19486] = {.lex_state = 437, .external_lex_state = 2},
  [19487] = {.lex_state = 107, .external_lex_state = 2},
  [19488] = {.lex_state = 107, .external_lex_state = 2},
  [19489] = {.lex_state = 32, .external_lex_state = 2},
  [19490] = {.lex_state = 437, .external_lex_state = 2},
  [19491] = {.lex_state = 437, .external_lex_state = 2},
  [19492] = {.lex_state = 32, .external_lex_state = 2},
  [19493] = {.lex_state = 32, .external_lex_state = 2},
  [19494] = {.lex_state = 437, .external_lex_state = 2},
  [19495] = {.lex_state = 437, .external_lex_state = 2},
  [19496] = {.lex_state = 437, .external_lex_state = 2},
  [19497] = {.lex_state = 437, .external_lex_state = 2},
  [19498] = {.lex_state = 437, .external_lex_state = 2},
  [19499] = {.lex_state = 437, .external_lex_state = 2},
  [19500] = {.lex_state = 437, .external_lex_state = 2},
  [19501] = {.lex_state = 32, .external_lex_state = 2},
  [19502] = {.lex_state = 32, .external_lex_state = 2},
  [19503] = {.lex_state = 437, .external_lex_state = 2},
  [19504] = {.lex_state = 437, .external_lex_state = 2},
  [19505] = {.lex_state = 437, .external_lex_state = 2},
  [19506] = {.lex_state = 437, .external_lex_state = 2},
  [19507] = {.lex_state = 11, .external_lex_state = 2},
  [19508] = {.lex_state = 437, .external_lex_state = 2},
  [19509] = {.lex_state = 437, .external_lex_state = 2},
  [19510] = {.lex_state = 32, .external_lex_state = 2},
  [19511] = {.lex_state = 437, .external_lex_state = 2},
  [19512] = {.lex_state = 437, .external_lex_state = 2},
  [19513] = {.lex_state = 437, .external_lex_state = 2},
  [19514] = {.lex_state = 437, .external_lex_state = 2},
  [19515] = {.lex_state = 437, .external_lex_state = 2},
  [19516] = {.lex_state = 437, .external_lex_state = 2},
  [19517] = {.lex_state = 32, .external_lex_state = 2},
  [19518] = {.lex_state = 437, .external_lex_state = 2},
  [19519] = {.lex_state = 437, .external_lex_state = 2},
  [19520] = {.lex_state = 437, .external_lex_state = 2},
  [19521] = {.lex_state = 437, .external_lex_state = 2},
  [19522] = {.lex_state = 437, .external_lex_state = 2},
  [19523] = {.lex_state = 437, .external_lex_state = 2},
  [19524] = {.lex_state = 437, .external_lex_state = 2},
  [19525] = {.lex_state = 437, .external_lex_state = 2},
  [19526] = {.lex_state = 437, .external_lex_state = 2},
  [19527] = {.lex_state = 437, .external_lex_state = 2},
  [19528] = {.lex_state = 437, .external_lex_state = 2},
  [19529] = {.lex_state = 437, .external_lex_state = 2},
  [19530] = {.lex_state = 437, .external_lex_state = 2},
  [19531] = {.lex_state = 437, .external_lex_state = 2},
  [19532] = {.lex_state = 437, .external_lex_state = 2},
  [19533] = {.lex_state = 437, .external_lex_state = 2},
  [19534] = {.lex_state = 437, .external_lex_state = 2},
  [19535] = {.lex_state = 437, .external_lex_state = 2},
  [19536] = {.lex_state = 437, .external_lex_state = 2},
  [19537] = {.lex_state = 437, .external_lex_state = 2},
  [19538] = {.lex_state = 437, .external_lex_state = 2},
  [19539] = {.lex_state = 437, .external_lex_state = 2},
  [19540] = {.lex_state = 32, .external_lex_state = 2},
  [19541] = {.lex_state = 437, .external_lex_state = 2},
  [19542] = {.lex_state = 437, .external_lex_state = 2},
  [19543] = {.lex_state = 437, .external_lex_state = 2},
  [19544] = {.lex_state = 437, .external_lex_state = 2},
  [19545] = {.lex_state = 437, .external_lex_state = 2},
  [19546] = {.lex_state = 32, .external_lex_state = 2},
  [19547] = {.lex_state = 437, .external_lex_state = 2},
  [19548] = {.lex_state = 24, .external_lex_state = 2},
  [19549] = {.lex_state = 437, .external_lex_state = 2},
  [19550] = {.lex_state = 437, .external_lex_state = 2},
  [19551] = {.lex_state = 437, .external_lex_state = 2},
  [19552] = {.lex_state = 437, .external_lex_state = 2},
  [19553] = {.lex_state = 437, .external_lex_state = 2},
  [19554] = {.lex_state = 437, .external_lex_state = 2},
  [19555] = {.lex_state = 437, .external_lex_state = 2},
  [19556] = {.lex_state = 437, .external_lex_state = 2},
  [19557] = {.lex_state = 437, .external_lex_state = 2},
  [19558] = {.lex_state = 437, .external_lex_state = 2},
  [19559] = {.lex_state = 437, .external_lex_state = 2},
  [19560] = {.lex_state = 437, .external_lex_state = 2},
  [19561] = {.lex_state = 437, .external_lex_state = 2},
  [19562] = {.lex_state = 437, .external_lex_state = 2},
  [19563] = {.lex_state = 437, .external_lex_state = 2},
  [19564] = {.lex_state = 437, .external_lex_state = 2},
  [19565] = {.lex_state = 437, .external_lex_state = 2},
  [19566] = {.lex_state = 32, .external_lex_state = 2},
  [19567] = {.lex_state = 437, .external_lex_state = 2},
  [19568] = {.lex_state = 437, .external_lex_state = 2},
  [19569] = {.lex_state = 437, .external_lex_state = 2},
  [19570] = {.lex_state = 437, .external_lex_state = 2},
  [19571] = {.lex_state = 437, .external_lex_state = 2},
  [19572] = {.lex_state = 437, .external_lex_state = 2},
  [19573] = {.lex_state = 437, .external_lex_state = 2},
  [19574] = {.lex_state = 32, .external_lex_state = 2},
  [19575] = {.lex_state = 24, .external_lex_state = 2},
  [19576] = {.lex_state = 11, .external_lex_state = 2},
  [19577] = {.lex_state = 437, .external_lex_state = 2},
  [19578] = {.lex_state = 32, .external_lex_state = 2},
  [19579] = {.lex_state = 11, .external_lex_state = 2},
  [19580] = {.lex_state = 437, .external_lex_state = 2},
  [19581] = {.lex_state = 437, .external_lex_state = 2},
  [19582] = {.lex_state = 437, .external_lex_state = 2},
  [19583] = {.lex_state = 11, .external_lex_state = 2},
  [19584] = {.lex_state = 11, .external_lex_state = 2},
  [19585] = {.lex_state = 437, .external_lex_state = 2},
  [19586] = {.lex_state = 437, .external_lex_state = 2},
  [19587] = {.lex_state = 11, .external_lex_state = 2},
  [19588] = {.lex_state = 437, .external_lex_state = 2},
  [19589] = {.lex_state = 11, .external_lex_state = 2},
  [19590] = {.lex_state = 437, .external_lex_state = 2},
  [19591] = {.lex_state = 11, .external_lex_state = 2},
  [19592] = {.lex_state = 437, .external_lex_state = 2},
  [19593] = {.lex_state = 11, .external_lex_state = 2},
  [19594] = {.lex_state = 437, .external_lex_state = 2},
  [19595] = {.lex_state = 437, .external_lex_state = 2},
  [19596] = {.lex_state = 437, .external_lex_state = 2},
  [19597] = {.lex_state = 437, .external_lex_state = 2},
  [19598] = {.lex_state = 437, .external_lex_state = 2},
  [19599] = {.lex_state = 437, .external_lex_state = 2},
  [19600] = {.lex_state = 11, .external_lex_state = 2},
  [19601] = {.lex_state = 437, .external_lex_state = 2},
  [19602] = {.lex_state = 437, .external_lex_state = 2},
  [19603] = {.lex_state = 437, .external_lex_state = 2},
  [19604] = {.lex_state = 11, .external_lex_state = 2},
  [19605] = {.lex_state = 437, .external_lex_state = 2},
  [19606] = {.lex_state = 437, .external_lex_state = 2},
  [19607] = {.lex_state = 32, .external_lex_state = 2},
  [19608] = {.lex_state = 437, .external_lex_state = 2},
  [19609] = {.lex_state = 437, .external_lex_state = 2},
  [19610] = {.lex_state = 437, .external_lex_state = 2},
  [19611] = {.lex_state = 437, .external_lex_state = 2},
  [19612] = {.lex_state = 32, .external_lex_state = 2},
  [19613] = {.lex_state = 437, .external_lex_state = 2},
  [19614] = {.lex_state = 437, .external_lex_state = 2},
  [19615] = {.lex_state = 437, .external_lex_state = 2},
  [19616] = {.lex_state = 437, .external_lex_state = 2},
  [19617] = {.lex_state = 437, .external_lex_state = 2},
  [19618] = {.lex_state = 437, .external_lex_state = 2},
  [19619] = {.lex_state = 437, .external_lex_state = 2},
  [19620] = {.lex_state = 32, .external_lex_state = 2},
  [19621] = {.lex_state = 437, .external_lex_state = 2},
  [19622] = {.lex_state = 32, .external_lex_state = 2},
  [19623] = {.lex_state = 437, .external_lex_state = 2},
  [19624] = {.lex_state = 437, .external_lex_state = 2},
  [19625] = {.lex_state = 437, .external_lex_state = 2},
  [19626] = {.lex_state = 437, .external_lex_state = 2},
  [19627] = {.lex_state = 437, .external_lex_state = 2},
  [19628] = {.lex_state = 437, .external_lex_state = 2},
  [19629] = {.lex_state = 32, .external_lex_state = 2},
  [19630] = {.lex_state = 437, .external_lex_state = 2},
  [19631] = {.lex_state = 437, .external_lex_state = 2},
  [19632] = {.lex_state = 32, .external_lex_state = 2},
  [19633] = {.lex_state = 32, .external_lex_state = 2},
  [19634] = {.lex_state = 437, .external_lex_state = 2},
  [19635] = {.lex_state = 437, .external_lex_state = 2},
  [19636] = {.lex_state = 437, .external_lex_state = 2},
  [19637] = {.lex_state = 437, .external_lex_state = 2},
  [19638] = {.lex_state = 437, .external_lex_state = 2},
  [19639] = {.lex_state = 437, .external_lex_state = 2},
  [19640] = {.lex_state = 437, .external_lex_state = 2},
  [19641] = {.lex_state = 437, .external_lex_state = 2},
  [19642] = {.lex_state = 437, .external_lex_state = 2},
  [19643] = {.lex_state = 437, .external_lex_state = 2},
  [19644] = {.lex_state = 437, .external_lex_state = 2},
  [19645] = {.lex_state = 437, .external_lex_state = 2},
  [19646] = {.lex_state = 32, .external_lex_state = 2},
  [19647] = {.lex_state = 437, .external_lex_state = 2},
  [19648] = {.lex_state = 437, .external_lex_state = 2},
  [19649] = {.lex_state = 437, .external_lex_state = 2},
  [19650] = {.lex_state = 437, .external_lex_state = 2},
  [19651] = {.lex_state = 437, .external_lex_state = 2},
  [19652] = {.lex_state = 10, .external_lex_state = 2},
  [19653] = {.lex_state = 437, .external_lex_state = 2},
  [19654] = {.lex_state = 437, .external_lex_state = 3},
  [19655] = {.lex_state = 437, .external_lex_state = 2},
  [19656] = {.lex_state = 437, .external_lex_state = 2},
  [19657] = {.lex_state = 437, .external_lex_state = 2},
  [19658] = {.lex_state = 437, .external_lex_state = 2},
  [19659] = {.lex_state = 11, .external_lex_state = 2},
  [19660] = {.lex_state = 437, .external_lex_state = 2},
  [19661] = {.lex_state = 437, .external_lex_state = 2},
  [19662] = {.lex_state = 32, .external_lex_state = 2},
  [19663] = {.lex_state = 32, .external_lex_state = 2},
  [19664] = {.lex_state = 11, .external_lex_state = 2},
  [19665] = {.lex_state = 10, .external_lex_state = 2},
  [19666] = {.lex_state = 437, .external_lex_state = 2},
  [19667] = {.lex_state = 11, .external_lex_state = 2},
  [19668] = {.lex_state = 437, .external_lex_state = 2},
  [19669] = {.lex_state = 437, .external_lex_state = 3},
  [19670] = {.lex_state = 11, .external_lex_state = 2},
  [19671] = {.lex_state = 24, .external_lex_state = 2},
  [19672] = {.lex_state = 437, .external_lex_state = 2},
  [19673] = {.lex_state = 437, .external_lex_state = 2},
  [19674] = {.lex_state = 437, .external_lex_state = 2},
  [19675] = {.lex_state = 437, .external_lex_state = 2},
  [19676] = {.lex_state = 24, .external_lex_state = 2},
  [19677] = {.lex_state = 11, .external_lex_state = 2},
  [19678] = {.lex_state = 437, .external_lex_state = 2},
  [19679] = {.lex_state = 437, .external_lex_state = 2},
  [19680] = {.lex_state = 437, .external_lex_state = 2},
  [19681] = {.lex_state = 437, .external_lex_state = 2},
  [19682] = {.lex_state = 437, .external_lex_state = 2},
  [19683] = {.lex_state = 437, .external_lex_state = 2},
  [19684] = {.lex_state = 11, .external_lex_state = 2},
  [19685] = {.lex_state = 437, .external_lex_state = 2},
  [19686] = {.lex_state = 437, .external_lex_state = 2},
  [19687] = {.lex_state = 437, .external_lex_state = 2},
  [19688] = {.lex_state = 437, .external_lex_state = 2},
  [19689] = {.lex_state = 32, .external_lex_state = 2},
  [19690] = {.lex_state = 437, .external_lex_state = 2},
  [19691] = {.lex_state = 11, .external_lex_state = 2},
  [19692] = {.lex_state = 32, .external_lex_state = 2},
  [19693] = {.lex_state = 11, .external_lex_state = 2},
  [19694] = {.lex_state = 437, .external_lex_state = 2},
  [19695] = {.lex_state = 437, .external_lex_state = 2},
  [19696] = {.lex_state = 32, .external_lex_state = 2},
  [19697] = {.lex_state = 437, .external_lex_state = 2},
  [19698] = {.lex_state = 32, .external_lex_state = 2},
  [19699] = {.lex_state = 437, .external_lex_state = 2},
  [19700] = {.lex_state = 437, .external_lex_state = 2},
  [19701] = {.lex_state = 437, .external_lex_state = 2},
  [19702] = {.lex_state = 11, .external_lex_state = 2},
  [19703] = {.lex_state = 437, .external_lex_state = 2},
  [19704] = {.lex_state = 437, .external_lex_state = 2},
  [19705] = {.lex_state = 437, .external_lex_state = 2},
  [19706] = {.lex_state = 437, .external_lex_state = 2},
  [19707] = {.lex_state = 437, .external_lex_state = 2},
  [19708] = {.lex_state = 437, .external_lex_state = 2},
  [19709] = {.lex_state = 437, .external_lex_state = 2},
  [19710] = {.lex_state = 437, .external_lex_state = 2},
  [19711] = {.lex_state = 437, .external_lex_state = 2},
  [19712] = {.lex_state = 437, .external_lex_state = 2},
  [19713] = {.lex_state = 10, .external_lex_state = 2},
  [19714] = {.lex_state = 437, .external_lex_state = 3},
  [19715] = {.lex_state = 437, .external_lex_state = 2},
  [19716] = {.lex_state = 437, .external_lex_state = 2},
  [19717] = {.lex_state = 437, .external_lex_state = 2},
  [19718] = {.lex_state = 437, .external_lex_state = 2},
  [19719] = {.lex_state = 437, .external_lex_state = 2},
  [19720] = {.lex_state = 32, .external_lex_state = 2},
  [19721] = {.lex_state = 437, .external_lex_state = 2},
  [19722] = {.lex_state = 437, .external_lex_state = 2},
  [19723] = {.lex_state = 437, .external_lex_state = 2},
  [19724] = {.lex_state = 437, .external_lex_state = 2},
  [19725] = {.lex_state = 32, .external_lex_state = 2},
  [19726] = {.lex_state = 32, .external_lex_state = 2},
  [19727] = {.lex_state = 32, .external_lex_state = 2},
  [19728] = {.lex_state = 437, .external_lex_state = 2},
  [19729] = {.lex_state = 32, .external_lex_state = 2},
  [19730] = {.lex_state = 437, .external_lex_state = 2},
  [19731] = {.lex_state = 437, .external_lex_state = 2},
  [19732] = {.lex_state = 437, .external_lex_state = 2},
  [19733] = {.lex_state = 32, .external_lex_state = 2},
  [19734] = {.lex_state = 437, .external_lex_state = 2},
  [19735] = {.lex_state = 32, .external_lex_state = 2},
  [19736] = {.lex_state = 437, .external_lex_state = 2},
  [19737] = {.lex_state = 11, .external_lex_state = 2},
  [19738] = {.lex_state = 437, .external_lex_state = 2},
  [19739] = {.lex_state = 437, .external_lex_state = 2},
  [19740] = {.lex_state = 437, .external_lex_state = 2},
  [19741] = {.lex_state = 437, .external_lex_state = 2},
  [19742] = {.lex_state = 437, .external_lex_state = 2},
  [19743] = {.lex_state = 437, .external_lex_state = 2},
  [19744] = {.lex_state = 437, .external_lex_state = 2},
  [19745] = {.lex_state = 437, .external_lex_state = 2},
  [19746] = {.lex_state = 437, .external_lex_state = 2},
  [19747] = {.lex_state = 437, .external_lex_state = 2},
  [19748] = {.lex_state = 437, .external_lex_state = 2},
  [19749] = {.lex_state = 437, .external_lex_state = 2},
  [19750] = {.lex_state = 437, .external_lex_state = 2},
  [19751] = {.lex_state = 437, .external_lex_state = 2},
  [19752] = {.lex_state = 32, .external_lex_state = 2},
  [19753] = {.lex_state = 437, .external_lex_state = 2},
  [19754] = {.lex_state = 437, .external_lex_state = 2},
  [19755] = {.lex_state = 437, .external_lex_state = 2},
  [19756] = {.lex_state = 437, .external_lex_state = 2},
  [19757] = {.lex_state = 437, .external_lex_state = 2},
  [19758] = {.lex_state = 437, .external_lex_state = 2},
  [19759] = {.lex_state = 437, .external_lex_state = 2},
  [19760] = {.lex_state = 437, .external_lex_state = 2},
  [19761] = {.lex_state = 437, .external_lex_state = 2},
  [19762] = {.lex_state = 437, .external_lex_state = 2},
  [19763] = {.lex_state = 437, .external_lex_state = 2},
  [19764] = {.lex_state = 437, .external_lex_state = 2},
  [19765] = {.lex_state = 437, .external_lex_state = 2},
  [19766] = {.lex_state = 32, .external_lex_state = 2},
  [19767] = {.lex_state = 437, .external_lex_state = 2},
  [19768] = {.lex_state = 437, .external_lex_state = 2},
  [19769] = {.lex_state = 437, .external_lex_state = 2},
  [19770] = {.lex_state = 437, .external_lex_state = 2},
  [19771] = {.lex_state = 437, .external_lex_state = 2},
  [19772] = {.lex_state = 437, .external_lex_state = 2},
  [19773] = {.lex_state = 437, .external_lex_state = 2},
  [19774] = {.lex_state = 437, .external_lex_state = 2},
  [19775] = {.lex_state = 437, .external_lex_state = 2},
  [19776] = {.lex_state = 32, .external_lex_state = 2},
  [19777] = {.lex_state = 437, .external_lex_state = 2},
  [19778] = {.lex_state = 437, .external_lex_state = 2},
  [19779] = {.lex_state = 32, .external_lex_state = 2},
  [19780] = {.lex_state = 437, .external_lex_state = 2},
  [19781] = {.lex_state = 11, .external_lex_state = 2},
  [19782] = {.lex_state = 437, .external_lex_state = 2},
  [19783] = {.lex_state = 437, .external_lex_state = 2},
  [19784] = {.lex_state = 437, .external_lex_state = 2},
  [19785] = {.lex_state = 437, .external_lex_state = 2},
  [19786] = {.lex_state = 437, .external_lex_state = 2},
  [19787] = {.lex_state = 437, .external_lex_state = 2},
  [19788] = {.lex_state = 32, .external_lex_state = 2},
  [19789] = {.lex_state = 32, .external_lex_state = 2},
  [19790] = {.lex_state = 437, .external_lex_state = 2},
  [19791] = {.lex_state = 437, .external_lex_state = 2},
  [19792] = {.lex_state = 437, .external_lex_state = 2},
  [19793] = {.lex_state = 32, .external_lex_state = 2},
  [19794] = {.lex_state = 24, .external_lex_state = 2},
  [19795] = {.lex_state = 437, .external_lex_state = 2},
  [19796] = {.lex_state = 437, .external_lex_state = 2},
  [19797] = {.lex_state = 437, .external_lex_state = 2},
  [19798] = {.lex_state = 437, .external_lex_state = 2},
  [19799] = {.lex_state = 437, .external_lex_state = 2},
  [19800] = {.lex_state = 437, .external_lex_state = 2},
  [19801] = {.lex_state = 437, .external_lex_state = 2},
  [19802] = {.lex_state = 437, .external_lex_state = 2},
  [19803] = {.lex_state = 11, .external_lex_state = 2},
  [19804] = {.lex_state = 437, .external_lex_state = 2},
  [19805] = {.lex_state = 437, .external_lex_state = 2},
  [19806] = {.lex_state = 437, .external_lex_state = 2},
  [19807] = {.lex_state = 437, .external_lex_state = 2},
  [19808] = {.lex_state = 437, .external_lex_state = 2},
  [19809] = {.lex_state = 437, .external_lex_state = 2},
  [19810] = {.lex_state = 437, .external_lex_state = 2},
  [19811] = {.lex_state = 437, .external_lex_state = 2},
  [19812] = {.lex_state = 10, .external_lex_state = 2},
  [19813] = {.lex_state = 437, .external_lex_state = 2},
  [19814] = {.lex_state = 437, .external_lex_state = 2},
  [19815] = {.lex_state = 437, .external_lex_state = 3},
  [19816] = {.lex_state = 32, .external_lex_state = 2},
  [19817] = {.lex_state = 32, .external_lex_state = 2},
  [19818] = {.lex_state = 437, .external_lex_state = 2},
  [19819] = {.lex_state = 437, .external_lex_state = 2},
  [19820] = {.lex_state = 437, .external_lex_state = 2},
  [19821] = {.lex_state = 437, .external_lex_state = 2},
  [19822] = {.lex_state = 437, .external_lex_state = 2},
  [19823] = {.lex_state = 11, .external_lex_state = 2},
  [19824] = {.lex_state = 437, .external_lex_state = 2},
  [19825] = {.lex_state = 32, .external_lex_state = 2},
  [19826] = {.lex_state = 437, .external_lex_state = 2},
  [19827] = {.lex_state = 437, .external_lex_state = 2},
  [19828] = {.lex_state = 437, .external_lex_state = 2},
  [19829] = {.lex_state = 437, .external_lex_state = 2},
  [19830] = {.lex_state = 437, .external_lex_state = 2},
  [19831] = {.lex_state = 437, .external_lex_state = 2},
  [19832] = {.lex_state = 437, .external_lex_state = 2},
  [19833] = {.lex_state = 437, .external_lex_state = 2},
  [19834] = {.lex_state = 437, .external_lex_state = 2},
  [19835] = {.lex_state = 437, .external_lex_state = 2},
  [19836] = {.lex_state = 437, .external_lex_state = 2},
  [19837] = {.lex_state = 437, .external_lex_state = 2},
  [19838] = {.lex_state = 437, .external_lex_state = 2},
  [19839] = {.lex_state = 437, .external_lex_state = 2},
  [19840] = {.lex_state = 437, .external_lex_state = 2},
  [19841] = {.lex_state = 437, .external_lex_state = 2},
  [19842] = {.lex_state = 437, .external_lex_state = 2},
  [19843] = {.lex_state = 437, .external_lex_state = 2},
  [19844] = {.lex_state = 437, .external_lex_state = 2},
  [19845] = {.lex_state = 437, .external_lex_state = 2},
  [19846] = {.lex_state = 437, .external_lex_state = 2},
  [19847] = {.lex_state = 437, .external_lex_state = 2},
  [19848] = {.lex_state = 437, .external_lex_state = 2},
  [19849] = {.lex_state = 32, .external_lex_state = 2},
  [19850] = {.lex_state = 437, .external_lex_state = 2},
  [19851] = {.lex_state = 11, .external_lex_state = 2},
  [19852] = {.lex_state = 437, .external_lex_state = 2},
  [19853] = {.lex_state = 437, .external_lex_state = 2},
  [19854] = {.lex_state = 437, .external_lex_state = 2},
  [19855] = {.lex_state = 437, .external_lex_state = 2},
  [19856] = {.lex_state = 437, .external_lex_state = 2},
  [19857] = {.lex_state = 437, .external_lex_state = 2},
  [19858] = {.lex_state = 437, .external_lex_state = 2},
  [19859] = {.lex_state = 437, .external_lex_state = 2},
  [19860] = {.lex_state = 437, .external_lex_state = 2},
  [19861] = {.lex_state = 437, .external_lex_state = 2},
  [19862] = {.lex_state = 24, .external_lex_state = 2},
  [19863] = {.lex_state = 437, .external_lex_state = 2},
  [19864] = {.lex_state = 10, .external_lex_state = 2},
  [19865] = {.lex_state = 437, .external_lex_state = 2},
  [19866] = {.lex_state = 437, .external_lex_state = 2},
  [19867] = {.lex_state = 437, .external_lex_state = 2},
  [19868] = {.lex_state = 437, .external_lex_state = 2},
  [19869] = {.lex_state = 11, .external_lex_state = 2},
  [19870] = {.lex_state = 437, .external_lex_state = 2},
  [19871] = {.lex_state = 11, .external_lex_state = 2},
  [19872] = {.lex_state = 11, .external_lex_state = 2},
  [19873] = {.lex_state = 437, .external_lex_state = 2},
  [19874] = {.lex_state = 32, .external_lex_state = 2},
  [19875] = {.lex_state = 437, .external_lex_state = 2},
  [19876] = {.lex_state = 10, .external_lex_state = 2},
  [19877] = {.lex_state = 437, .external_lex_state = 2},
  [19878] = {.lex_state = 437, .external_lex_state = 2},
  [19879] = {.lex_state = 437, .external_lex_state = 2},
  [19880] = {.lex_state = 437, .external_lex_state = 2},
  [19881] = {.lex_state = 437, .external_lex_state = 2},
  [19882] = {.lex_state = 437, .external_lex_state = 2},
  [19883] = {.lex_state = 11, .external_lex_state = 2},
  [19884] = {.lex_state = 437, .external_lex_state = 2},
  [19885] = {.lex_state = 437, .external_lex_state = 2},
  [19886] = {.lex_state = 437, .external_lex_state = 2},
  [19887] = {.lex_state = 32, .external_lex_state = 2},
  [19888] = {.lex_state = 10, .external_lex_state = 2},
  [19889] = {.lex_state = 437, .external_lex_state = 2},
  [19890] = {.lex_state = 437, .external_lex_state = 2},
  [19891] = {.lex_state = 437, .external_lex_state = 2},
  [19892] = {.lex_state = 437, .external_lex_state = 2},
  [19893] = {.lex_state = 10, .external_lex_state = 2},
  [19894] = {.lex_state = 437, .external_lex_state = 3},
  [19895] = {.lex_state = 437, .external_lex_state = 2},
  [19896] = {.lex_state = 32, .external_lex_state = 2},
  [19897] = {.lex_state = 437, .external_lex_state = 2},
  [19898] = {.lex_state = 437, .external_lex_state = 2},
  [19899] = {.lex_state = 11, .external_lex_state = 2},
  [19900] = {.lex_state = 437, .external_lex_state = 2},
  [19901] = {.lex_state = 437, .external_lex_state = 2},
  [19902] = {.lex_state = 437, .external_lex_state = 2},
  [19903] = {.lex_state = 437, .external_lex_state = 2},
  [19904] = {.lex_state = 437, .external_lex_state = 2},
  [19905] = {.lex_state = 32, .external_lex_state = 2},
  [19906] = {.lex_state = 11, .external_lex_state = 2},
  [19907] = {.lex_state = 32, .external_lex_state = 2},
  [19908] = {.lex_state = 437, .external_lex_state = 2},
  [19909] = {.lex_state = 24, .external_lex_state = 2},
  [19910] = {.lex_state = 437, .external_lex_state = 2},
  [19911] = {.lex_state = 437, .external_lex_state = 2},
  [19912] = {.lex_state = 437, .external_lex_state = 2},
  [19913] = {.lex_state = 437, .external_lex_state = 2},
  [19914] = {.lex_state = 32, .external_lex_state = 2},
  [19915] = {.lex_state = 437, .external_lex_state = 2},
  [19916] = {.lex_state = 437, .external_lex_state = 2},
  [19917] = {.lex_state = 437, .external_lex_state = 2},
  [19918] = {.lex_state = 437, .external_lex_state = 2},
  [19919] = {.lex_state = 437, .external_lex_state = 3},
  [19920] = {.lex_state = 437, .external_lex_state = 2},
  [19921] = {.lex_state = 437, .external_lex_state = 2},
  [19922] = {.lex_state = 437, .external_lex_state = 2},
  [19923] = {.lex_state = 32, .external_lex_state = 2},
  [19924] = {.lex_state = 437, .external_lex_state = 2},
  [19925] = {.lex_state = 437, .external_lex_state = 2},
  [19926] = {.lex_state = 437, .external_lex_state = 2},
  [19927] = {.lex_state = 437, .external_lex_state = 2},
  [19928] = {.lex_state = 437, .external_lex_state = 2},
  [19929] = {.lex_state = 437, .external_lex_state = 2},
  [19930] = {.lex_state = 437, .external_lex_state = 2},
  [19931] = {.lex_state = 437, .external_lex_state = 2},
  [19932] = {.lex_state = 437, .external_lex_state = 2},
  [19933] = {.lex_state = 437, .external_lex_state = 2},
  [19934] = {.lex_state = 38, .external_lex_state = 2},
  [19935] = {.lex_state = 437, .external_lex_state = 2},
  [19936] = {.lex_state = 437, .external_lex_state = 2},
  [19937] = {.lex_state = 32, .external_lex_state = 2},
  [19938] = {.lex_state = 32, .external_lex_state = 2},
  [19939] = {.lex_state = 32, .external_lex_state = 2},
  [19940] = {.lex_state = 437, .external_lex_state = 2},
  [19941] = {.lex_state = 437, .external_lex_state = 2},
  [19942] = {.lex_state = 437, .external_lex_state = 2},
  [19943] = {.lex_state = 32, .external_lex_state = 2},
  [19944] = {.lex_state = 437, .external_lex_state = 2},
  [19945] = {.lex_state = 32, .external_lex_state = 2},
  [19946] = {.lex_state = 437, .external_lex_state = 2},
  [19947] = {.lex_state = 437, .external_lex_state = 2},
  [19948] = {.lex_state = 437, .external_lex_state = 2},
  [19949] = {.lex_state = 32, .external_lex_state = 2},
  [19950] = {.lex_state = 437, .external_lex_state = 2},
  [19951] = {.lex_state = 437, .external_lex_state = 2},
  [19952] = {.lex_state = 437, .external_lex_state = 2},
  [19953] = {.lex_state = 437, .external_lex_state = 2},
  [19954] = {.lex_state = 24, .external_lex_state = 2},
  [19955] = {.lex_state = 437, .external_lex_state = 2},
  [19956] = {.lex_state = 11, .external_lex_state = 2},
  [19957] = {.lex_state = 11, .external_lex_state = 2},
  [19958] = {.lex_state = 437, .external_lex_state = 2},
  [19959] = {.lex_state = 437, .external_lex_state = 2},
  [19960] = {.lex_state = 437, .external_lex_state = 2},
  [19961] = {.lex_state = 437, .external_lex_state = 2},
  [19962] = {.lex_state = 437, .external_lex_state = 2},
  [19963] = {.lex_state = 32, .external_lex_state = 2},
  [19964] = {.lex_state = 437, .external_lex_state = 2},
  [19965] = {.lex_state = 10, .external_lex_state = 2},
  [19966] = {.lex_state = 437, .external_lex_state = 2},
  [19967] = {.lex_state = 437, .external_lex_state = 2},
  [19968] = {.lex_state = 32, .external_lex_state = 2},
  [19969] = {.lex_state = 10, .external_lex_state = 2},
  [19970] = {.lex_state = 437, .external_lex_state = 2},
  [19971] = {.lex_state = 437, .external_lex_state = 2},
  [19972] = {.lex_state = 437, .external_lex_state = 2},
  [19973] = {.lex_state = 437, .external_lex_state = 2},
  [19974] = {.lex_state = 32, .external_lex_state = 2},
  [19975] = {.lex_state = 24, .external_lex_state = 2},
  [19976] = {.lex_state = 11, .external_lex_state = 2},
  [19977] = {.lex_state = 11, .external_lex_state = 2},
  [19978] = {.lex_state = 437, .external_lex_state = 3},
  [19979] = {.lex_state = 32, .external_lex_state = 2},
  [19980] = {.lex_state = 437, .external_lex_state = 2},
  [19981] = {.lex_state = 437, .external_lex_state = 2},
  [19982] = {.lex_state = 437, .external_lex_state = 2},
  [19983] = {.lex_state = 437, .external_lex_state = 2},
  [19984] = {.lex_state = 437, .external_lex_state = 2},
  [19985] = {.lex_state = 437, .external_lex_state = 2},
  [19986] = {.lex_state = 437, .external_lex_state = 2},
  [19987] = {.lex_state = 437, .external_lex_state = 3},
  [19988] = {.lex_state = 437, .external_lex_state = 2},
  [19989] = {.lex_state = 24, .external_lex_state = 2},
  [19990] = {.lex_state = 437, .external_lex_state = 2},
  [19991] = {.lex_state = 437, .external_lex_state = 2},
  [19992] = {.lex_state = 437, .external_lex_state = 2},
  [19993] = {.lex_state = 437, .external_lex_state = 2},
  [19994] = {.lex_state = 437, .external_lex_state = 2},
  [19995] = {.lex_state = 437, .external_lex_state = 2},
  [19996] = {.lex_state = 437, .external_lex_state = 2},
  [19997] = {.lex_state = 437, .external_lex_state = 2},
  [19998] = {.lex_state = 437, .external_lex_state = 2},
  [19999] = {.lex_state = 437, .external_lex_state = 2},
  [20000] = {.lex_state = 437, .external_lex_state = 2},
  [20001] = {.lex_state = 437, .external_lex_state = 2},
  [20002] = {.lex_state = 10, .external_lex_state = 2},
  [20003] = {.lex_state = 437, .external_lex_state = 3},
  [20004] = {.lex_state = 437, .external_lex_state = 2},
  [20005] = {.lex_state = 437, .external_lex_state = 2},
  [20006] = {.lex_state = 437, .external_lex_state = 2},
  [20007] = {.lex_state = 437, .external_lex_state = 2},
  [20008] = {.lex_state = 437, .external_lex_state = 2},
  [20009] = {.lex_state = 437, .external_lex_state = 2},
  [20010] = {.lex_state = 11, .external_lex_state = 2},
  [20011] = {.lex_state = 437, .external_lex_state = 2},
  [20012] = {.lex_state = 437, .external_lex_state = 2},
  [20013] = {.lex_state = 437, .external_lex_state = 2},
  [20014] = {.lex_state = 437, .external_lex_state = 2},
  [20015] = {.lex_state = 32, .external_lex_state = 2},
  [20016] = {.lex_state = 437, .external_lex_state = 2},
  [20017] = {.lex_state = 32, .external_lex_state = 2},
  [20018] = {.lex_state = 437, .external_lex_state = 2},
  [20019] = {.lex_state = 437, .external_lex_state = 2},
  [20020] = {.lex_state = 437, .external_lex_state = 2},
  [20021] = {.lex_state = 24, .external_lex_state = 2},
  [20022] = {.lex_state = 11, .external_lex_state = 2},
  [20023] = {.lex_state = 437, .external_lex_state = 2},
  [20024] = {.lex_state = 10, .external_lex_state = 2},
  [20025] = {.lex_state = 32, .external_lex_state = 2},
  [20026] = {.lex_state = 437, .external_lex_state = 3},
  [20027] = {.lex_state = 437, .external_lex_state = 2},
  [20028] = {.lex_state = 24, .external_lex_state = 2},
  [20029] = {.lex_state = 437, .external_lex_state = 2},
  [20030] = {.lex_state = 437, .external_lex_state = 2},
  [20031] = {.lex_state = 437, .external_lex_state = 2},
  [20032] = {.lex_state = 437, .external_lex_state = 2},
  [20033] = {.lex_state = 437, .external_lex_state = 2},
  [20034] = {.lex_state = 437, .external_lex_state = 2},
  [20035] = {.lex_state = 437, .external_lex_state = 2},
  [20036] = {.lex_state = 437, .external_lex_state = 2},
  [20037] = {.lex_state = 437, .external_lex_state = 2},
  [20038] = {.lex_state = 10, .external_lex_state = 2},
  [20039] = {.lex_state = 10, .external_lex_state = 2},
  [20040] = {.lex_state = 437, .external_lex_state = 2},
  [20041] = {.lex_state = 437, .external_lex_state = 2},
  [20042] = {.lex_state = 437, .external_lex_state = 2},
  [20043] = {.lex_state = 437, .external_lex_state = 2},
  [20044] = {.lex_state = 437, .external_lex_state = 2},
  [20045] = {.lex_state = 437, .external_lex_state = 2},
  [20046] = {.lex_state = 437, .external_lex_state = 2},
  [20047] = {.lex_state = 10, .external_lex_state = 2},
  [20048] = {.lex_state = 437, .external_lex_state = 3},
  [20049] = {.lex_state = 437, .external_lex_state = 2},
  [20050] = {.lex_state = 437, .external_lex_state = 2},
  [20051] = {.lex_state = 437, .external_lex_state = 2},
  [20052] = {.lex_state = 437, .external_lex_state = 2},
  [20053] = {.lex_state = 437, .external_lex_state = 2},
  [20054] = {.lex_state = 437, .external_lex_state = 2},
  [20055] = {.lex_state = 437, .external_lex_state = 2},
  [20056] = {.lex_state = 437, .external_lex_state = 2},
  [20057] = {.lex_state = 437, .external_lex_state = 2},
  [20058] = {.lex_state = 437, .external_lex_state = 2},
  [20059] = {.lex_state = 437, .external_lex_state = 2},
  [20060] = {.lex_state = 437, .external_lex_state = 2},
  [20061] = {.lex_state = 437, .external_lex_state = 2},
  [20062] = {.lex_state = 437, .external_lex_state = 2},
  [20063] = {.lex_state = 437, .external_lex_state = 2},
  [20064] = {.lex_state = 437, .external_lex_state = 2},
  [20065] = {.lex_state = 437, .external_lex_state = 2},
  [20066] = {.lex_state = 10, .external_lex_state = 2},
  [20067] = {.lex_state = 437, .external_lex_state = 2},
  [20068] = {.lex_state = 32, .external_lex_state = 2},
  [20069] = {.lex_state = 10, .external_lex_state = 2},
  [20070] = {.lex_state = 32, .external_lex_state = 2},
  [20071] = {.lex_state = 437, .external_lex_state = 2},
  [20072] = {.lex_state = 38, .external_lex_state = 2},
  [20073] = {.lex_state = 32, .external_lex_state = 2},
  [20074] = {.lex_state = 437, .external_lex_state = 2},
  [20075] = {.lex_state = 32, .external_lex_state = 2},
  [20076] = {.lex_state = 437, .external_lex_state = 3},
  [20077] = {.lex_state = 32, .external_lex_state = 2},
  [20078] = {.lex_state = 437, .external_lex_state = 2},
  [20079] = {.lex_state = 437, .external_lex_state = 2},
  [20080] = {.lex_state = 437, .external_lex_state = 2},
  [20081] = {.lex_state = 437, .external_lex_state = 2},
  [20082] = {.lex_state = 32, .external_lex_state = 2},
  [20083] = {.lex_state = 437, .external_lex_state = 2},
  [20084] = {.lex_state = 437, .external_lex_state = 2},
  [20085] = {.lex_state = 10, .external_lex_state = 2},
  [20086] = {.lex_state = 437, .external_lex_state = 2},
  [20087] = {.lex_state = 32, .external_lex_state = 2},
  [20088] = {.lex_state = 437, .external_lex_state = 2},
  [20089] = {.lex_state = 437, .external_lex_state = 2},
  [20090] = {.lex_state = 437, .external_lex_state = 2},
  [20091] = {.lex_state = 437, .external_lex_state = 2},
  [20092] = {.lex_state = 437, .external_lex_state = 2},
  [20093] = {.lex_state = 11, .external_lex_state = 2},
  [20094] = {.lex_state = 38, .external_lex_state = 2},
  [20095] = {.lex_state = 437, .external_lex_state = 2},
  [20096] = {.lex_state = 437, .external_lex_state = 2},
  [20097] = {.lex_state = 437, .external_lex_state = 2},
  [20098] = {.lex_state = 437, .external_lex_state = 2},
  [20099] = {.lex_state = 11, .external_lex_state = 2},
  [20100] = {.lex_state = 437, .external_lex_state = 2},
  [20101] = {.lex_state = 437, .external_lex_state = 2},
  [20102] = {.lex_state = 11, .external_lex_state = 2},
  [20103] = {.lex_state = 24, .external_lex_state = 2},
  [20104] = {.lex_state = 10, .external_lex_state = 2},
  [20105] = {.lex_state = 32, .external_lex_state = 2},
  [20106] = {.lex_state = 437, .external_lex_state = 3},
  [20107] = {.lex_state = 11, .external_lex_state = 2},
  [20108] = {.lex_state = 437, .external_lex_state = 2},
  [20109] = {.lex_state = 24, .external_lex_state = 2},
  [20110] = {.lex_state = 11, .external_lex_state = 2},
  [20111] = {.lex_state = 437, .external_lex_state = 2},
  [20112] = {.lex_state = 437, .external_lex_state = 2},
  [20113] = {.lex_state = 11, .external_lex_state = 2},
  [20114] = {.lex_state = 437, .external_lex_state = 2},
  [20115] = {.lex_state = 437, .external_lex_state = 2},
  [20116] = {.lex_state = 437, .external_lex_state = 2},
  [20117] = {.lex_state = 437, .external_lex_state = 2},
  [20118] = {.lex_state = 437, .external_lex_state = 2},
  [20119] = {.lex_state = 437, .external_lex_state = 2},
  [20120] = {.lex_state = 11, .external_lex_state = 2},
  [20121] = {.lex_state = 437, .external_lex_state = 2},
  [20122] = {.lex_state = 437, .external_lex_state = 2},
  [20123] = {.lex_state = 437, .external_lex_state = 2},
  [20124] = {.lex_state = 437, .external_lex_state = 2},
  [20125] = {.lex_state = 437, .external_lex_state = 2},
  [20126] = {.lex_state = 437, .external_lex_state = 2},
  [20127] = {.lex_state = 437, .external_lex_state = 2},
  [20128] = {.lex_state = 437, .external_lex_state = 2},
  [20129] = {.lex_state = 32, .external_lex_state = 2},
  [20130] = {.lex_state = 437, .external_lex_state = 2},
  [20131] = {.lex_state = 437, .external_lex_state = 2},
  [20132] = {.lex_state = 32, .external_lex_state = 2},
  [20133] = {.lex_state = 437, .external_lex_state = 3},
  [20134] = {.lex_state = 437, .external_lex_state = 2},
  [20135] = {.lex_state = 257, .external_lex_state = 2},
  [20136] = {.lex_state = 32, .external_lex_state = 2},
  [20137] = {.lex_state = 437, .external_lex_state = 2},
  [20138] = {.lex_state = 437, .external_lex_state = 2},
  [20139] = {.lex_state = 437, .external_lex_state = 2},
  [20140] = {.lex_state = 437, .external_lex_state = 2},
  [20141] = {.lex_state = 437, .external_lex_state = 2},
  [20142] = {.lex_state = 10, .external_lex_state = 2},
  [20143] = {.lex_state = 24, .external_lex_state = 2},
  [20144] = {.lex_state = 437, .external_lex_state = 3},
  [20145] = {.lex_state = 24, .external_lex_state = 2},
  [20146] = {.lex_state = 437, .external_lex_state = 2},
  [20147] = {.lex_state = 32, .external_lex_state = 2},
  [20148] = {.lex_state = 437, .external_lex_state = 2},
  [20149] = {.lex_state = 24, .external_lex_state = 2},
  [20150] = {.lex_state = 437, .external_lex_state = 2},
  [20151] = {.lex_state = 437, .external_lex_state = 2},
  [20152] = {.lex_state = 437, .external_lex_state = 2},
  [20153] = {.lex_state = 10, .external_lex_state = 2},
  [20154] = {.lex_state = 437, .external_lex_state = 3},
  [20155] = {.lex_state = 437, .external_lex_state = 2},
  [20156] = {.lex_state = 437, .external_lex_state = 2},
  [20157] = {.lex_state = 437, .external_lex_state = 2},
  [20158] = {.lex_state = 437, .external_lex_state = 2},
  [20159] = {.lex_state = 24, .external_lex_state = 2},
  [20160] = {.lex_state = 437, .external_lex_state = 2},
  [20161] = {.lex_state = 10, .external_lex_state = 2},
  [20162] = {.lex_state = 437, .external_lex_state = 2},
  [20163] = {.lex_state = 437, .external_lex_state = 2},
  [20164] = {.lex_state = 437, .external_lex_state = 2},
  [20165] = {.lex_state = 437, .external_lex_state = 2},
  [20166] = {.lex_state = 32, .external_lex_state = 2},
  [20167] = {.lex_state = 437, .external_lex_state = 2},
  [20168] = {.lex_state = 437, .external_lex_state = 2},
  [20169] = {.lex_state = 437, .external_lex_state = 2},
  [20170] = {.lex_state = 11, .external_lex_state = 2},
  [20171] = {.lex_state = 437, .external_lex_state = 2},
  [20172] = {.lex_state = 32, .external_lex_state = 2},
  [20173] = {.lex_state = 437, .external_lex_state = 3},
  [20174] = {.lex_state = 437, .external_lex_state = 2},
  [20175] = {.lex_state = 437, .external_lex_state = 2},
  [20176] = {.lex_state = 107, .external_lex_state = 2},
  [20177] = {.lex_state = 107, .external_lex_state = 2},
  [20178] = {.lex_state = 107, .external_lex_state = 2},
  [20179] = {.lex_state = 437, .external_lex_state = 2},
  [20180] = {.lex_state = 32, .external_lex_state = 2},
  [20181] = {.lex_state = 10, .external_lex_state = 2},
  [20182] = {.lex_state = 437, .external_lex_state = 3},
  [20183] = {.lex_state = 437, .external_lex_state = 2},
  [20184] = {.lex_state = 437, .external_lex_state = 2},
  [20185] = {.lex_state = 437, .external_lex_state = 2},
  [20186] = {.lex_state = 437, .external_lex_state = 2},
  [20187] = {.lex_state = 437, .external_lex_state = 2},
  [20188] = {.lex_state = 437, .external_lex_state = 2},
  [20189] = {.lex_state = 437, .external_lex_state = 2},
  [20190] = {.lex_state = 437, .external_lex_state = 2},
  [20191] = {.lex_state = 437, .external_lex_state = 2},
  [20192] = {.lex_state = 32, .external_lex_state = 2},
  [20193] = {.lex_state = 32, .external_lex_state = 2},
  [20194] = {.lex_state = 437, .external_lex_state = 2},
  [20195] = {.lex_state = 32, .external_lex_state = 2},
  [20196] = {.lex_state = 32, .external_lex_state = 2},
  [20197] = {.lex_state = 437, .external_lex_state = 2},
  [20198] = {.lex_state = 437, .external_lex_state = 2},
  [20199] = {.lex_state = 437, .external_lex_state = 2},
  [20200] = {.lex_state = 437, .external_lex_state = 2},
  [20201] = {.lex_state = 437, .external_lex_state = 2},
  [20202] = {.lex_state = 437, .external_lex_state = 2},
  [20203] = {.lex_state = 32, .external_lex_state = 2},
  [20204] = {.lex_state = 437, .external_lex_state = 2},
  [20205] = {.lex_state = 437, .external_lex_state = 2},
  [20206] = {.lex_state = 32, .external_lex_state = 2},
  [20207] = {.lex_state = 11, .external_lex_state = 2},
  [20208] = {.lex_state = 437, .external_lex_state = 2},
  [20209] = {.lex_state = 32, .external_lex_state = 2},
  [20210] = {.lex_state = 11, .external_lex_state = 2},
  [20211] = {.lex_state = 437, .external_lex_state = 2},
  [20212] = {.lex_state = 437, .external_lex_state = 2},
  [20213] = {.lex_state = 32, .external_lex_state = 2},
  [20214] = {.lex_state = 437, .external_lex_state = 2},
  [20215] = {.lex_state = 11, .external_lex_state = 2},
  [20216] = {.lex_state = 32, .external_lex_state = 2},
  [20217] = {.lex_state = 437, .external_lex_state = 2},
  [20218] = {.lex_state = 437, .external_lex_state = 2},
  [20219] = {.lex_state = 437, .external_lex_state = 2},
  [20220] = {.lex_state = 437, .external_lex_state = 2},
  [20221] = {.lex_state = 437, .external_lex_state = 2},
  [20222] = {.lex_state = 437, .external_lex_state = 2},
  [20223] = {.lex_state = 437, .external_lex_state = 2},
  [20224] = {.lex_state = 437, .external_lex_state = 2},
  [20225] = {.lex_state = 437, .external_lex_state = 2},
  [20226] = {.lex_state = 437, .external_lex_state = 2},
  [20227] = {.lex_state = 437, .external_lex_state = 2},
  [20228] = {.lex_state = 10, .external_lex_state = 2},
  [20229] = {.lex_state = 437, .external_lex_state = 3},
  [20230] = {.lex_state = 437, .external_lex_state = 2},
  [20231] = {.lex_state = 437, .external_lex_state = 2},
  [20232] = {.lex_state = 24, .external_lex_state = 2},
  [20233] = {.lex_state = 437, .external_lex_state = 2},
  [20234] = {.lex_state = 437, .external_lex_state = 2},
  [20235] = {.lex_state = 437, .external_lex_state = 2},
  [20236] = {.lex_state = 437, .external_lex_state = 2},
  [20237] = {.lex_state = 32, .external_lex_state = 2},
  [20238] = {.lex_state = 437, .external_lex_state = 2},
  [20239] = {.lex_state = 437, .external_lex_state = 2},
  [20240] = {.lex_state = 437, .external_lex_state = 2},
  [20241] = {.lex_state = 437, .external_lex_state = 2},
  [20242] = {.lex_state = 437, .external_lex_state = 2},
  [20243] = {.lex_state = 437, .external_lex_state = 2},
  [20244] = {.lex_state = 437, .external_lex_state = 2},
  [20245] = {.lex_state = 437, .external_lex_state = 2},
  [20246] = {.lex_state = 437, .external_lex_state = 2},
  [20247] = {.lex_state = 437, .external_lex_state = 2},
  [20248] = {.lex_state = 437, .external_lex_state = 2},
  [20249] = {.lex_state = 437, .external_lex_state = 3},
  [20250] = {.lex_state = 32, .external_lex_state = 2},
  [20251] = {.lex_state = 437, .external_lex_state = 2},
  [20252] = {.lex_state = 38, .external_lex_state = 2},
  [20253] = {.lex_state = 437, .external_lex_state = 2},
  [20254] = {.lex_state = 437, .external_lex_state = 2},
  [20255] = {.lex_state = 437, .external_lex_state = 2},
  [20256] = {.lex_state = 437, .external_lex_state = 2},
  [20257] = {.lex_state = 32, .external_lex_state = 2},
  [20258] = {.lex_state = 437, .external_lex_state = 2},
  [20259] = {.lex_state = 437, .external_lex_state = 2},
  [20260] = {.lex_state = 437, .external_lex_state = 2},
  [20261] = {.lex_state = 437, .external_lex_state = 2},
  [20262] = {.lex_state = 437, .external_lex_state = 2},
  [20263] = {.lex_state = 10, .external_lex_state = 2},
  [20264] = {.lex_state = 437, .external_lex_state = 2},
  [20265] = {.lex_state = 38, .external_lex_state = 2},
  [20266] = {.lex_state = 437, .external_lex_state = 2},
  [20267] = {.lex_state = 24, .external_lex_state = 2},
  [20268] = {.lex_state = 437, .external_lex_state = 2},
  [20269] = {.lex_state = 437, .external_lex_state = 2},
  [20270] = {.lex_state = 437, .external_lex_state = 3},
  [20271] = {.lex_state = 437, .external_lex_state = 2},
  [20272] = {.lex_state = 437, .external_lex_state = 2},
  [20273] = {.lex_state = 437, .external_lex_state = 2},
  [20274] = {.lex_state = 437, .external_lex_state = 2},
  [20275] = {.lex_state = 437, .external_lex_state = 2},
  [20276] = {.lex_state = 437, .external_lex_state = 2},
  [20277] = {.lex_state = 437, .external_lex_state = 2},
  [20278] = {.lex_state = 437, .external_lex_state = 2},
  [20279] = {.lex_state = 32, .external_lex_state = 2},
  [20280] = {.lex_state = 437, .external_lex_state = 2},
  [20281] = {.lex_state = 437, .external_lex_state = 2},
  [20282] = {.lex_state = 437, .external_lex_state = 2},
  [20283] = {.lex_state = 437, .external_lex_state = 2},
  [20284] = {.lex_state = 437, .external_lex_state = 2},
  [20285] = {.lex_state = 437, .external_lex_state = 2},
  [20286] = {.lex_state = 24, .external_lex_state = 2},
  [20287] = {.lex_state = 437, .external_lex_state = 2},
  [20288] = {.lex_state = 32, .external_lex_state = 2},
  [20289] = {.lex_state = 437, .external_lex_state = 2},
  [20290] = {.lex_state = 24, .external_lex_state = 2},
  [20291] = {.lex_state = 32, .external_lex_state = 2},
  [20292] = {.lex_state = 437, .external_lex_state = 2},
  [20293] = {.lex_state = 437, .external_lex_state = 2},
  [20294] = {.lex_state = 437, .external_lex_state = 2},
  [20295] = {.lex_state = 24, .external_lex_state = 2},
  [20296] = {.lex_state = 437, .external_lex_state = 2},
  [20297] = {.lex_state = 32, .external_lex_state = 2},
  [20298] = {.lex_state = 32, .external_lex_state = 2},
  [20299] = {.lex_state = 437, .external_lex_state = 2},
  [20300] = {.lex_state = 437, .external_lex_state = 2},
  [20301] = {.lex_state = 437, .external_lex_state = 2},
  [20302] = {.lex_state = 437, .external_lex_state = 2},
  [20303] = {.lex_state = 437, .external_lex_state = 2},
  [20304] = {.lex_state = 437, .external_lex_state = 2},
  [20305] = {.lex_state = 437, .external_lex_state = 2},
  [20306] = {.lex_state = 437, .external_lex_state = 2},
  [20307] = {.lex_state = 437, .external_lex_state = 2},
  [20308] = {.lex_state = 107, .external_lex_state = 2},
  [20309] = {.lex_state = 107, .external_lex_state = 2},
  [20310] = {.lex_state = 107, .external_lex_state = 2},
  [20311] = {.lex_state = 437, .external_lex_state = 2},
  [20312] = {.lex_state = 437, .external_lex_state = 2},
  [20313] = {.lex_state = 437, .external_lex_state = 2},
  [20314] = {.lex_state = 437, .external_lex_state = 2},
  [20315] = {.lex_state = 437, .external_lex_state = 2},
  [20316] = {.lex_state = 437, .external_lex_state = 2},
  [20317] = {.lex_state = 437, .external_lex_state = 2},
  [20318] = {.lex_state = 10, .external_lex_state = 2},
  [20319] = {.lex_state = 437, .external_lex_state = 2},
  [20320] = {.lex_state = 437, .external_lex_state = 2},
  [20321] = {.lex_state = 437, .external_lex_state = 2},
  [20322] = {.lex_state = 32, .external_lex_state = 2},
  [20323] = {.lex_state = 32, .external_lex_state = 2},
  [20324] = {.lex_state = 437, .external_lex_state = 2},
  [20325] = {.lex_state = 437, .external_lex_state = 3},
  [20326] = {.lex_state = 437, .external_lex_state = 2},
  [20327] = {.lex_state = 437, .external_lex_state = 2},
  [20328] = {.lex_state = 437, .external_lex_state = 2},
  [20329] = {.lex_state = 437, .external_lex_state = 2},
  [20330] = {.lex_state = 32, .external_lex_state = 2},
  [20331] = {.lex_state = 32, .external_lex_state = 2},
  [20332] = {.lex_state = 437, .external_lex_state = 2},
  [20333] = {.lex_state = 437, .external_lex_state = 2},
  [20334] = {.lex_state = 437, .external_lex_state = 2},
  [20335] = {.lex_state = 437, .external_lex_state = 2},
  [20336] = {.lex_state = 437, .external_lex_state = 2},
  [20337] = {.lex_state = 11, .external_lex_state = 2},
  [20338] = {.lex_state = 11, .external_lex_state = 2},
  [20339] = {.lex_state = 437, .external_lex_state = 2},
  [20340] = {.lex_state = 437, .external_lex_state = 2},
  [20341] = {.lex_state = 11, .external_lex_state = 2},
  [20342] = {.lex_state = 437, .external_lex_state = 2},
  [20343] = {.lex_state = 32, .external_lex_state = 2},
  [20344] = {.lex_state = 437, .external_lex_state = 2},
  [20345] = {.lex_state = 437, .external_lex_state = 2},
  [20346] = {.lex_state = 11, .external_lex_state = 2},
  [20347] = {.lex_state = 437, .external_lex_state = 2},
  [20348] = {.lex_state = 437, .external_lex_state = 2},
  [20349] = {.lex_state = 437, .external_lex_state = 2},
  [20350] = {.lex_state = 437, .external_lex_state = 2},
  [20351] = {.lex_state = 437, .external_lex_state = 2},
  [20352] = {.lex_state = 437, .external_lex_state = 2},
  [20353] = {.lex_state = 437, .external_lex_state = 2},
  [20354] = {.lex_state = 437, .external_lex_state = 2},
  [20355] = {.lex_state = 437, .external_lex_state = 2},
  [20356] = {.lex_state = 437, .external_lex_state = 2},
  [20357] = {.lex_state = 437, .external_lex_state = 2},
  [20358] = {.lex_state = 32, .external_lex_state = 2},
  [20359] = {.lex_state = 437, .external_lex_state = 2},
  [20360] = {.lex_state = 437, .external_lex_state = 2},
  [20361] = {.lex_state = 437, .external_lex_state = 2},
  [20362] = {.lex_state = 437, .external_lex_state = 2},
  [20363] = {.lex_state = 24, .external_lex_state = 2},
  [20364] = {.lex_state = 32, .external_lex_state = 2},
  [20365] = {.lex_state = 32, .external_lex_state = 2},
  [20366] = {.lex_state = 437, .external_lex_state = 2},
  [20367] = {.lex_state = 437, .external_lex_state = 2},
  [20368] = {.lex_state = 10, .external_lex_state = 2},
  [20369] = {.lex_state = 437, .external_lex_state = 3},
  [20370] = {.lex_state = 437, .external_lex_state = 2},
  [20371] = {.lex_state = 437, .external_lex_state = 2},
  [20372] = {.lex_state = 437, .external_lex_state = 2},
  [20373] = {.lex_state = 437, .external_lex_state = 2},
  [20374] = {.lex_state = 437, .external_lex_state = 2},
  [20375] = {.lex_state = 10, .external_lex_state = 2},
  [20376] = {.lex_state = 437, .external_lex_state = 3},
  [20377] = {.lex_state = 437, .external_lex_state = 2},
  [20378] = {.lex_state = 437, .external_lex_state = 2},
  [20379] = {.lex_state = 437, .external_lex_state = 2},
  [20380] = {.lex_state = 24, .external_lex_state = 2},
  [20381] = {.lex_state = 32, .external_lex_state = 2},
  [20382] = {.lex_state = 32, .external_lex_state = 2},
  [20383] = {.lex_state = 24, .external_lex_state = 2},
  [20384] = {.lex_state = 24, .external_lex_state = 2},
  [20385] = {.lex_state = 32, .external_lex_state = 2},
  [20386] = {.lex_state = 437, .external_lex_state = 9},
  [20387] = {.lex_state = 437, .external_lex_state = 2},
  [20388] = {.lex_state = 437, .external_lex_state = 2},
  [20389] = {.lex_state = 437, .external_lex_state = 2},
  [20390] = {.lex_state = 437, .external_lex_state = 2},
  [20391] = {.lex_state = 437, .external_lex_state = 2},
  [20392] = {.lex_state = 437, .external_lex_state = 2},
  [20393] = {.lex_state = 437, .external_lex_state = 2},
  [20394] = {.lex_state = 437, .external_lex_state = 2},
  [20395] = {.lex_state = 437, .external_lex_state = 2},
  [20396] = {.lex_state = 437, .external_lex_state = 2},
  [20397] = {.lex_state = 437, .external_lex_state = 2},
  [20398] = {.lex_state = 437, .external_lex_state = 2},
  [20399] = {.lex_state = 437, .external_lex_state = 2},
  [20400] = {.lex_state = 437, .external_lex_state = 2},
  [20401] = {.lex_state = 437, .external_lex_state = 2},
  [20402] = {.lex_state = 107, .external_lex_state = 2},
  [20403] = {.lex_state = 107, .external_lex_state = 2},
  [20404] = {.lex_state = 107, .external_lex_state = 2},
  [20405] = {.lex_state = 437, .external_lex_state = 2},
  [20406] = {.lex_state = 437, .external_lex_state = 2},
  [20407] = {.lex_state = 32, .external_lex_state = 2},
  [20408] = {.lex_state = 437, .external_lex_state = 2},
  [20409] = {.lex_state = 24, .external_lex_state = 2},
  [20410] = {.lex_state = 437, .external_lex_state = 2},
  [20411] = {.lex_state = 32, .external_lex_state = 2},
  [20412] = {.lex_state = 24, .external_lex_state = 2},
  [20413] = {.lex_state = 437, .external_lex_state = 2},
  [20414] = {.lex_state = 32, .external_lex_state = 2},
  [20415] = {.lex_state = 437, .external_lex_state = 2},
  [20416] = {.lex_state = 10, .external_lex_state = 2},
  [20417] = {.lex_state = 437, .external_lex_state = 2},
  [20418] = {.lex_state = 437, .external_lex_state = 2},
  [20419] = {.lex_state = 437, .external_lex_state = 3},
  [20420] = {.lex_state = 437, .external_lex_state = 2},
  [20421] = {.lex_state = 24, .external_lex_state = 2},
  [20422] = {.lex_state = 32, .external_lex_state = 2},
  [20423] = {.lex_state = 24, .external_lex_state = 2},
  [20424] = {.lex_state = 437, .external_lex_state = 2},
  [20425] = {.lex_state = 24, .external_lex_state = 2},
  [20426] = {.lex_state = 437, .external_lex_state = 2},
  [20427] = {.lex_state = 437, .external_lex_state = 2},
  [20428] = {.lex_state = 437, .external_lex_state = 2},
  [20429] = {.lex_state = 437, .external_lex_state = 2},
  [20430] = {.lex_state = 437, .external_lex_state = 2},
  [20431] = {.lex_state = 437, .external_lex_state = 2},
  [20432] = {.lex_state = 24, .external_lex_state = 2},
  [20433] = {.lex_state = 437, .external_lex_state = 2},
  [20434] = {.lex_state = 32, .external_lex_state = 2},
  [20435] = {.lex_state = 437, .external_lex_state = 2},
  [20436] = {.lex_state = 437, .external_lex_state = 2},
  [20437] = {.lex_state = 437, .external_lex_state = 2},
  [20438] = {.lex_state = 437, .external_lex_state = 2},
  [20439] = {.lex_state = 437, .external_lex_state = 2},
  [20440] = {.lex_state = 437, .external_lex_state = 2},
  [20441] = {.lex_state = 437, .external_lex_state = 2},
  [20442] = {.lex_state = 437, .external_lex_state = 2},
  [20443] = {.lex_state = 437, .external_lex_state = 2},
  [20444] = {.lex_state = 437, .external_lex_state = 2},
  [20445] = {.lex_state = 32, .external_lex_state = 2},
  [20446] = {.lex_state = 437, .external_lex_state = 2},
  [20447] = {.lex_state = 32, .external_lex_state = 2},
  [20448] = {.lex_state = 32, .external_lex_state = 2},
  [20449] = {.lex_state = 437, .external_lex_state = 2},
  [20450] = {.lex_state = 437, .external_lex_state = 2},
  [20451] = {.lex_state = 437, .external_lex_state = 2},
  [20452] = {.lex_state = 437, .external_lex_state = 2},
  [20453] = {.lex_state = 437, .external_lex_state = 2},
  [20454] = {.lex_state = 437, .external_lex_state = 2},
  [20455] = {.lex_state = 437, .external_lex_state = 2},
  [20456] = {.lex_state = 437, .external_lex_state = 2},
  [20457] = {.lex_state = 437, .external_lex_state = 2},
  [20458] = {.lex_state = 437, .external_lex_state = 2},
  [20459] = {.lex_state = 437, .external_lex_state = 2},
  [20460] = {.lex_state = 437, .external_lex_state = 2},
  [20461] = {.lex_state = 24, .external_lex_state = 2},
  [20462] = {.lex_state = 32, .external_lex_state = 2},
  [20463] = {.lex_state = 437, .external_lex_state = 2},
  [20464] = {.lex_state = 24, .external_lex_state = 2},
  [20465] = {.lex_state = 437, .external_lex_state = 3},
  [20466] = {.lex_state = 437, .external_lex_state = 2},
  [20467] = {.lex_state = 437, .external_lex_state = 2},
  [20468] = {.lex_state = 437, .external_lex_state = 2},
  [20469] = {.lex_state = 437, .external_lex_state = 2},
  [20470] = {.lex_state = 107, .external_lex_state = 2},
  [20471] = {.lex_state = 107, .external_lex_state = 2},
  [20472] = {.lex_state = 107, .external_lex_state = 2},
  [20473] = {.lex_state = 437, .external_lex_state = 2},
  [20474] = {.lex_state = 32, .external_lex_state = 2},
  [20475] = {.lex_state = 24, .external_lex_state = 2},
  [20476] = {.lex_state = 437, .external_lex_state = 2},
  [20477] = {.lex_state = 437, .external_lex_state = 2},
  [20478] = {.lex_state = 437, .external_lex_state = 2},
  [20479] = {.lex_state = 437, .external_lex_state = 2},
  [20480] = {.lex_state = 437, .external_lex_state = 2},
  [20481] = {.lex_state = 437, .external_lex_state = 2},
  [20482] = {.lex_state = 437, .external_lex_state = 2},
  [20483] = {.lex_state = 437, .external_lex_state = 2},
  [20484] = {.lex_state = 437, .external_lex_state = 2},
  [20485] = {.lex_state = 437, .external_lex_state = 2},
  [20486] = {.lex_state = 437, .external_lex_state = 2},
  [20487] = {.lex_state = 437, .external_lex_state = 2},
  [20488] = {.lex_state = 437, .external_lex_state = 2},
  [20489] = {.lex_state = 437, .external_lex_state = 2},
  [20490] = {.lex_state = 437, .external_lex_state = 2},
  [20491] = {.lex_state = 24, .external_lex_state = 2},
  [20492] = {.lex_state = 24, .external_lex_state = 2},
  [20493] = {.lex_state = 32, .external_lex_state = 2},
  [20494] = {.lex_state = 437, .external_lex_state = 2},
  [20495] = {.lex_state = 24, .external_lex_state = 2},
  [20496] = {.lex_state = 437, .external_lex_state = 2},
  [20497] = {.lex_state = 107, .external_lex_state = 2},
  [20498] = {.lex_state = 107, .external_lex_state = 2},
  [20499] = {.lex_state = 107, .external_lex_state = 2},
  [20500] = {.lex_state = 437, .external_lex_state = 2},
  [20501] = {.lex_state = 437, .external_lex_state = 2},
  [20502] = {.lex_state = 437, .external_lex_state = 2},
  [20503] = {.lex_state = 437, .external_lex_state = 2},
  [20504] = {.lex_state = 437, .external_lex_state = 2},
  [20505] = {.lex_state = 437, .external_lex_state = 2},
  [20506] = {.lex_state = 437, .external_lex_state = 2},
  [20507] = {.lex_state = 437, .external_lex_state = 2},
  [20508] = {.lex_state = 437, .external_lex_state = 2},
  [20509] = {.lex_state = 32, .external_lex_state = 2},
  [20510] = {.lex_state = 437, .external_lex_state = 2},
  [20511] = {.lex_state = 437, .external_lex_state = 2},
  [20512] = {.lex_state = 437, .external_lex_state = 2},
  [20513] = {.lex_state = 437, .external_lex_state = 2},
  [20514] = {.lex_state = 437, .external_lex_state = 2},
  [20515] = {.lex_state = 24, .external_lex_state = 2},
  [20516] = {.lex_state = 32, .external_lex_state = 2},
  [20517] = {.lex_state = 437, .external_lex_state = 2},
  [20518] = {.lex_state = 24, .external_lex_state = 2},
  [20519] = {.lex_state = 32, .external_lex_state = 2},
  [20520] = {.lex_state = 107, .external_lex_state = 2},
  [20521] = {.lex_state = 107, .external_lex_state = 2},
  [20522] = {.lex_state = 107, .external_lex_state = 2},
  [20523] = {.lex_state = 437, .external_lex_state = 2},
  [20524] = {.lex_state = 437, .external_lex_state = 2},
  [20525] = {.lex_state = 437, .external_lex_state = 2},
  [20526] = {.lex_state = 32, .external_lex_state = 2},
  [20527] = {.lex_state = 437, .external_lex_state = 2},
  [20528] = {.lex_state = 11, .external_lex_state = 2},
  [20529] = {.lex_state = 437, .external_lex_state = 2},
  [20530] = {.lex_state = 437, .external_lex_state = 2},
  [20531] = {.lex_state = 437, .external_lex_state = 2},
  [20532] = {.lex_state = 437, .external_lex_state = 2},
  [20533] = {.lex_state = 32, .external_lex_state = 2},
  [20534] = {.lex_state = 437, .external_lex_state = 2},
  [20535] = {.lex_state = 11, .external_lex_state = 2},
  [20536] = {.lex_state = 32, .external_lex_state = 2},
  [20537] = {.lex_state = 437, .external_lex_state = 2},
  [20538] = {.lex_state = 24, .external_lex_state = 2},
  [20539] = {.lex_state = 11, .external_lex_state = 2},
  [20540] = {.lex_state = 107, .external_lex_state = 2},
  [20541] = {.lex_state = 107, .external_lex_state = 2},
  [20542] = {.lex_state = 107, .external_lex_state = 2},
  [20543] = {.lex_state = 437, .external_lex_state = 2},
  [20544] = {.lex_state = 437, .external_lex_state = 2},
  [20545] = {.lex_state = 24, .external_lex_state = 2},
  [20546] = {.lex_state = 437, .external_lex_state = 2},
  [20547] = {.lex_state = 11, .external_lex_state = 2},
  [20548] = {.lex_state = 437, .external_lex_state = 2},
  [20549] = {.lex_state = 32, .external_lex_state = 2},
  [20550] = {.lex_state = 11, .external_lex_state = 2},
  [20551] = {.lex_state = 437, .external_lex_state = 2},
  [20552] = {.lex_state = 437, .external_lex_state = 2},
  [20553] = {.lex_state = 437, .external_lex_state = 2},
  [20554] = {.lex_state = 437, .external_lex_state = 2},
  [20555] = {.lex_state = 437, .external_lex_state = 2},
  [20556] = {.lex_state = 32, .external_lex_state = 2},
  [20557] = {.lex_state = 437, .external_lex_state = 2},
  [20558] = {.lex_state = 24, .external_lex_state = 2},
  [20559] = {.lex_state = 11, .external_lex_state = 2},
  [20560] = {.lex_state = 107, .external_lex_state = 2},
  [20561] = {.lex_state = 107, .external_lex_state = 2},
  [20562] = {.lex_state = 107, .external_lex_state = 2},
  [20563] = {.lex_state = 437, .external_lex_state = 2},
  [20564] = {.lex_state = 437, .external_lex_state = 2},
  [20565] = {.lex_state = 437, .external_lex_state = 2},
  [20566] = {.lex_state = 437, .external_lex_state = 2},
  [20567] = {.lex_state = 11, .external_lex_state = 2},
  [20568] = {.lex_state = 11, .external_lex_state = 2},
  [20569] = {.lex_state = 11, .external_lex_state = 2},
  [20570] = {.lex_state = 437, .external_lex_state = 2},
  [20571] = {.lex_state = 437, .external_lex_state = 2},
  [20572] = {.lex_state = 437, .external_lex_state = 2},
  [20573] = {.lex_state = 437, .external_lex_state = 2},
  [20574] = {.lex_state = 437, .external_lex_state = 2},
  [20575] = {.lex_state = 32, .external_lex_state = 2},
  [20576] = {.lex_state = 11, .external_lex_state = 2},
  [20577] = {.lex_state = 24, .external_lex_state = 2},
  [20578] = {.lex_state = 11, .external_lex_state = 2},
  [20579] = {.lex_state = 107, .external_lex_state = 2},
  [20580] = {.lex_state = 107, .external_lex_state = 2},
  [20581] = {.lex_state = 107, .external_lex_state = 2},
  [20582] = {.lex_state = 437, .external_lex_state = 2},
  [20583] = {.lex_state = 437, .external_lex_state = 2},
  [20584] = {.lex_state = 437, .external_lex_state = 2},
  [20585] = {.lex_state = 437, .external_lex_state = 2},
  [20586] = {.lex_state = 11, .external_lex_state = 2},
  [20587] = {.lex_state = 437, .external_lex_state = 2},
  [20588] = {.lex_state = 437, .external_lex_state = 2},
  [20589] = {.lex_state = 32, .external_lex_state = 2},
  [20590] = {.lex_state = 32, .external_lex_state = 2},
  [20591] = {.lex_state = 437, .external_lex_state = 2},
  [20592] = {.lex_state = 437, .external_lex_state = 2},
  [20593] = {.lex_state = 32, .external_lex_state = 2},
  [20594] = {.lex_state = 437, .external_lex_state = 2},
  [20595] = {.lex_state = 24, .external_lex_state = 2},
  [20596] = {.lex_state = 437, .external_lex_state = 2},
  [20597] = {.lex_state = 107, .external_lex_state = 2},
  [20598] = {.lex_state = 107, .external_lex_state = 2},
  [20599] = {.lex_state = 107, .external_lex_state = 2},
  [20600] = {.lex_state = 437, .external_lex_state = 2},
  [20601] = {.lex_state = 437, .external_lex_state = 2},
  [20602] = {.lex_state = 437, .external_lex_state = 2},
  [20603] = {.lex_state = 437, .external_lex_state = 2},
  [20604] = {.lex_state = 437, .external_lex_state = 2},
  [20605] = {.lex_state = 32, .external_lex_state = 2},
  [20606] = {.lex_state = 437, .external_lex_state = 2},
  [20607] = {.lex_state = 437, .external_lex_state = 2},
  [20608] = {.lex_state = 437, .external_lex_state = 2},
  [20609] = {.lex_state = 437, .external_lex_state = 2},
  [20610] = {.lex_state = 437, .external_lex_state = 2},
  [20611] = {.lex_state = 32, .external_lex_state = 2},
  [20612] = {.lex_state = 32, .external_lex_state = 2},
  [20613] = {.lex_state = 24, .external_lex_state = 2},
  [20614] = {.lex_state = 437, .external_lex_state = 2},
  [20615] = {.lex_state = 107, .external_lex_state = 2},
  [20616] = {.lex_state = 107, .external_lex_state = 2},
  [20617] = {.lex_state = 107, .external_lex_state = 2},
  [20618] = {.lex_state = 437, .external_lex_state = 2},
  [20619] = {.lex_state = 437, .external_lex_state = 2},
  [20620] = {.lex_state = 437, .external_lex_state = 2},
  [20621] = {.lex_state = 32, .external_lex_state = 2},
  [20622] = {.lex_state = 437, .external_lex_state = 2},
  [20623] = {.lex_state = 437, .external_lex_state = 2},
  [20624] = {.lex_state = 437, .external_lex_state = 2},
  [20625] = {.lex_state = 437, .external_lex_state = 2},
  [20626] = {.lex_state = 10, .external_lex_state = 2},
  [20627] = {.lex_state = 437, .external_lex_state = 2},
  [20628] = {.lex_state = 32, .external_lex_state = 2},
  [20629] = {.lex_state = 437, .external_lex_state = 3},
  [20630] = {.lex_state = 24, .external_lex_state = 2},
  [20631] = {.lex_state = 437, .external_lex_state = 2},
  [20632] = {.lex_state = 107, .external_lex_state = 2},
  [20633] = {.lex_state = 107, .external_lex_state = 2},
  [20634] = {.lex_state = 107, .external_lex_state = 2},
  [20635] = {.lex_state = 437, .external_lex_state = 2},
  [20636] = {.lex_state = 32, .external_lex_state = 2},
  [20637] = {.lex_state = 437, .external_lex_state = 2},
  [20638] = {.lex_state = 24, .external_lex_state = 2},
  [20639] = {.lex_state = 32, .external_lex_state = 2},
  [20640] = {.lex_state = 32, .external_lex_state = 2},
  [20641] = {.lex_state = 437, .external_lex_state = 2},
  [20642] = {.lex_state = 437, .external_lex_state = 2},
  [20643] = {.lex_state = 437, .external_lex_state = 2},
  [20644] = {.lex_state = 32, .external_lex_state = 2},
  [20645] = {.lex_state = 437, .external_lex_state = 2},
  [20646] = {.lex_state = 24, .external_lex_state = 2},
  [20647] = {.lex_state = 437, .external_lex_state = 2},
  [20648] = {.lex_state = 107, .external_lex_state = 2},
  [20649] = {.lex_state = 107, .external_lex_state = 2},
  [20650] = {.lex_state = 107, .external_lex_state = 2},
  [20651] = {.lex_state = 437, .external_lex_state = 2},
  [20652] = {.lex_state = 437, .external_lex_state = 2},
  [20653] = {.lex_state = 32, .external_lex_state = 2},
  [20654] = {.lex_state = 437, .external_lex_state = 2},
  [20655] = {.lex_state = 437, .external_lex_state = 2},
  [20656] = {.lex_state = 32, .external_lex_state = 2},
  [20657] = {.lex_state = 437, .external_lex_state = 2},
  [20658] = {.lex_state = 437, .external_lex_state = 2},
  [20659] = {.lex_state = 11, .external_lex_state = 2},
  [20660] = {.lex_state = 32, .external_lex_state = 2},
  [20661] = {.lex_state = 437, .external_lex_state = 2},
  [20662] = {.lex_state = 24, .external_lex_state = 2},
  [20663] = {.lex_state = 437, .external_lex_state = 2},
  [20664] = {.lex_state = 107, .external_lex_state = 2},
  [20665] = {.lex_state = 107, .external_lex_state = 2},
  [20666] = {.lex_state = 107, .external_lex_state = 2},
  [20667] = {.lex_state = 437, .external_lex_state = 2},
  [20668] = {.lex_state = 437, .external_lex_state = 2},
  [20669] = {.lex_state = 11, .external_lex_state = 2},
  [20670] = {.lex_state = 11, .external_lex_state = 2},
  [20671] = {.lex_state = 437, .external_lex_state = 2},
  [20672] = {.lex_state = 437, .external_lex_state = 2},
  [20673] = {.lex_state = 11, .external_lex_state = 2},
  [20674] = {.lex_state = 437, .external_lex_state = 2},
  [20675] = {.lex_state = 437, .external_lex_state = 2},
  [20676] = {.lex_state = 32, .external_lex_state = 2},
  [20677] = {.lex_state = 32, .external_lex_state = 2},
  [20678] = {.lex_state = 24, .external_lex_state = 2},
  [20679] = {.lex_state = 437, .external_lex_state = 2},
  [20680] = {.lex_state = 107, .external_lex_state = 2},
  [20681] = {.lex_state = 107, .external_lex_state = 2},
  [20682] = {.lex_state = 107, .external_lex_state = 2},
  [20683] = {.lex_state = 32, .external_lex_state = 2},
  [20684] = {.lex_state = 437, .external_lex_state = 2},
  [20685] = {.lex_state = 437, .external_lex_state = 2},
  [20686] = {.lex_state = 11, .external_lex_state = 2},
  [20687] = {.lex_state = 437, .external_lex_state = 2},
  [20688] = {.lex_state = 437, .external_lex_state = 2},
  [20689] = {.lex_state = 32, .external_lex_state = 2},
  [20690] = {.lex_state = 437, .external_lex_state = 2},
  [20691] = {.lex_state = 437, .external_lex_state = 2},
  [20692] = {.lex_state = 32, .external_lex_state = 2},
  [20693] = {.lex_state = 437, .external_lex_state = 2},
  [20694] = {.lex_state = 24, .external_lex_state = 2},
  [20695] = {.lex_state = 437, .external_lex_state = 2},
  [20696] = {.lex_state = 107, .external_lex_state = 2},
  [20697] = {.lex_state = 107, .external_lex_state = 2},
  [20698] = {.lex_state = 107, .external_lex_state = 2},
  [20699] = {.lex_state = 437, .external_lex_state = 2},
  [20700] = {.lex_state = 437, .external_lex_state = 2},
  [20701] = {.lex_state = 437, .external_lex_state = 2},
  [20702] = {.lex_state = 437, .external_lex_state = 2},
  [20703] = {.lex_state = 437, .external_lex_state = 2},
  [20704] = {.lex_state = 437, .external_lex_state = 2},
  [20705] = {.lex_state = 32, .external_lex_state = 2},
  [20706] = {.lex_state = 32, .external_lex_state = 2},
  [20707] = {.lex_state = 437, .external_lex_state = 2},
  [20708] = {.lex_state = 32, .external_lex_state = 2},
  [20709] = {.lex_state = 437, .external_lex_state = 2},
  [20710] = {.lex_state = 24, .external_lex_state = 2},
  [20711] = {.lex_state = 11, .external_lex_state = 2},
  [20712] = {.lex_state = 107, .external_lex_state = 2},
  [20713] = {.lex_state = 107, .external_lex_state = 2},
  [20714] = {.lex_state = 107, .external_lex_state = 2},
  [20715] = {.lex_state = 437, .external_lex_state = 2},
  [20716] = {.lex_state = 437, .external_lex_state = 2},
  [20717] = {.lex_state = 437, .external_lex_state = 2},
  [20718] = {.lex_state = 437, .external_lex_state = 2},
  [20719] = {.lex_state = 437, .external_lex_state = 2},
  [20720] = {.lex_state = 437, .external_lex_state = 2},
  [20721] = {.lex_state = 437, .external_lex_state = 2},
  [20722] = {.lex_state = 437, .external_lex_state = 2},
  [20723] = {.lex_state = 437, .external_lex_state = 2},
  [20724] = {.lex_state = 32, .external_lex_state = 2},
  [20725] = {.lex_state = 437, .external_lex_state = 2},
  [20726] = {.lex_state = 24, .external_lex_state = 2},
  [20727] = {.lex_state = 11, .external_lex_state = 2},
  [20728] = {.lex_state = 107, .external_lex_state = 2},
  [20729] = {.lex_state = 107, .external_lex_state = 2},
  [20730] = {.lex_state = 107, .external_lex_state = 2},
  [20731] = {.lex_state = 437, .external_lex_state = 2},
  [20732] = {.lex_state = 32, .external_lex_state = 2},
  [20733] = {.lex_state = 437, .external_lex_state = 2},
  [20734] = {.lex_state = 437, .external_lex_state = 2},
  [20735] = {.lex_state = 437, .external_lex_state = 2},
  [20736] = {.lex_state = 32, .external_lex_state = 2},
  [20737] = {.lex_state = 437, .external_lex_state = 2},
  [20738] = {.lex_state = 437, .external_lex_state = 2},
  [20739] = {.lex_state = 11, .external_lex_state = 2},
  [20740] = {.lex_state = 32, .external_lex_state = 2},
  [20741] = {.lex_state = 32, .external_lex_state = 2},
  [20742] = {.lex_state = 24, .external_lex_state = 2},
  [20743] = {.lex_state = 437, .external_lex_state = 2},
  [20744] = {.lex_state = 107, .external_lex_state = 2},
  [20745] = {.lex_state = 107, .external_lex_state = 2},
  [20746] = {.lex_state = 107, .external_lex_state = 2},
  [20747] = {.lex_state = 437, .external_lex_state = 2},
  [20748] = {.lex_state = 437, .external_lex_state = 2},
  [20749] = {.lex_state = 437, .external_lex_state = 2},
  [20750] = {.lex_state = 32, .external_lex_state = 2},
  [20751] = {.lex_state = 437, .external_lex_state = 2},
  [20752] = {.lex_state = 437, .external_lex_state = 2},
  [20753] = {.lex_state = 437, .external_lex_state = 2},
  [20754] = {.lex_state = 32, .external_lex_state = 2},
  [20755] = {.lex_state = 437, .external_lex_state = 2},
  [20756] = {.lex_state = 32, .external_lex_state = 2},
  [20757] = {.lex_state = 32, .external_lex_state = 2},
  [20758] = {.lex_state = 24, .external_lex_state = 2},
  [20759] = {.lex_state = 437, .external_lex_state = 2},
  [20760] = {.lex_state = 107, .external_lex_state = 2},
  [20761] = {.lex_state = 107, .external_lex_state = 2},
  [20762] = {.lex_state = 107, .external_lex_state = 2},
  [20763] = {.lex_state = 437, .external_lex_state = 2},
  [20764] = {.lex_state = 10, .external_lex_state = 2},
  [20765] = {.lex_state = 437, .external_lex_state = 3},
  [20766] = {.lex_state = 32, .external_lex_state = 2},
  [20767] = {.lex_state = 11, .external_lex_state = 2},
  [20768] = {.lex_state = 437, .external_lex_state = 2},
  [20769] = {.lex_state = 437, .external_lex_state = 2},
  [20770] = {.lex_state = 437, .external_lex_state = 2},
  [20771] = {.lex_state = 437, .external_lex_state = 2},
  [20772] = {.lex_state = 32, .external_lex_state = 2},
  [20773] = {.lex_state = 32, .external_lex_state = 2},
  [20774] = {.lex_state = 24, .external_lex_state = 2},
  [20775] = {.lex_state = 437, .external_lex_state = 2},
  [20776] = {.lex_state = 107, .external_lex_state = 2},
  [20777] = {.lex_state = 107, .external_lex_state = 2},
  [20778] = {.lex_state = 107, .external_lex_state = 2},
  [20779] = {.lex_state = 437, .external_lex_state = 2},
  [20780] = {.lex_state = 437, .external_lex_state = 2},
  [20781] = {.lex_state = 437, .external_lex_state = 2},
  [20782] = {.lex_state = 32, .external_lex_state = 2},
  [20783] = {.lex_state = 437, .external_lex_state = 2},
  [20784] = {.lex_state = 24, .external_lex_state = 2},
  [20785] = {.lex_state = 32, .external_lex_state = 2},
  [20786] = {.lex_state = 32, .external_lex_state = 2},
  [20787] = {.lex_state = 437, .external_lex_state = 2},
  [20788] = {.lex_state = 437, .external_lex_state = 2},
  [20789] = {.lex_state = 24, .external_lex_state = 2},
  [20790] = {.lex_state = 437, .external_lex_state = 2},
  [20791] = {.lex_state = 107, .external_lex_state = 2},
  [20792] = {.lex_state = 107, .external_lex_state = 2},
  [20793] = {.lex_state = 107, .external_lex_state = 2},
  [20794] = {.lex_state = 437, .external_lex_state = 2},
  [20795] = {.lex_state = 437, .external_lex_state = 2},
  [20796] = {.lex_state = 437, .external_lex_state = 2},
  [20797] = {.lex_state = 437, .external_lex_state = 2},
  [20798] = {.lex_state = 437, .external_lex_state = 2},
  [20799] = {.lex_state = 437, .external_lex_state = 2},
  [20800] = {.lex_state = 437, .external_lex_state = 2},
  [20801] = {.lex_state = 437, .external_lex_state = 2},
  [20802] = {.lex_state = 437, .external_lex_state = 2},
  [20803] = {.lex_state = 437, .external_lex_state = 2},
  [20804] = {.lex_state = 24, .external_lex_state = 2},
  [20805] = {.lex_state = 32, .external_lex_state = 2},
  [20806] = {.lex_state = 107, .external_lex_state = 2},
  [20807] = {.lex_state = 107, .external_lex_state = 2},
  [20808] = {.lex_state = 107, .external_lex_state = 2},
  [20809] = {.lex_state = 437, .external_lex_state = 2},
  [20810] = {.lex_state = 11, .external_lex_state = 2},
  [20811] = {.lex_state = 437, .external_lex_state = 2},
  [20812] = {.lex_state = 11, .external_lex_state = 2},
  [20813] = {.lex_state = 10, .external_lex_state = 2},
  [20814] = {.lex_state = 437, .external_lex_state = 2},
  [20815] = {.lex_state = 32, .external_lex_state = 2},
  [20816] = {.lex_state = 437, .external_lex_state = 3},
  [20817] = {.lex_state = 437, .external_lex_state = 2},
  [20818] = {.lex_state = 437, .external_lex_state = 2},
  [20819] = {.lex_state = 24, .external_lex_state = 2},
  [20820] = {.lex_state = 437, .external_lex_state = 2},
  [20821] = {.lex_state = 107, .external_lex_state = 2},
  [20822] = {.lex_state = 107, .external_lex_state = 2},
  [20823] = {.lex_state = 107, .external_lex_state = 2},
  [20824] = {.lex_state = 24, .external_lex_state = 2},
  [20825] = {.lex_state = 11, .external_lex_state = 2},
  [20826] = {.lex_state = 437, .external_lex_state = 2},
  [20827] = {.lex_state = 437, .external_lex_state = 2},
  [20828] = {.lex_state = 437, .external_lex_state = 2},
  [20829] = {.lex_state = 437, .external_lex_state = 2},
  [20830] = {.lex_state = 437, .external_lex_state = 2},
  [20831] = {.lex_state = 32, .external_lex_state = 2},
  [20832] = {.lex_state = 32, .external_lex_state = 2},
  [20833] = {.lex_state = 437, .external_lex_state = 2},
  [20834] = {.lex_state = 24, .external_lex_state = 2},
  [20835] = {.lex_state = 437, .external_lex_state = 2},
  [20836] = {.lex_state = 107, .external_lex_state = 2},
  [20837] = {.lex_state = 107, .external_lex_state = 2},
  [20838] = {.lex_state = 107, .external_lex_state = 2},
  [20839] = {.lex_state = 437, .external_lex_state = 2},
  [20840] = {.lex_state = 437, .external_lex_state = 2},
  [20841] = {.lex_state = 437, .external_lex_state = 2},
  [20842] = {.lex_state = 10, .external_lex_state = 2},
  [20843] = {.lex_state = 437, .external_lex_state = 2},
  [20844] = {.lex_state = 437, .external_lex_state = 2},
  [20845] = {.lex_state = 10, .external_lex_state = 2},
  [20846] = {.lex_state = 437, .external_lex_state = 2},
  [20847] = {.lex_state = 32, .external_lex_state = 2},
  [20848] = {.lex_state = 437, .external_lex_state = 2},
  [20849] = {.lex_state = 24, .external_lex_state = 2},
  [20850] = {.lex_state = 437, .external_lex_state = 2},
  [20851] = {.lex_state = 107, .external_lex_state = 2},
  [20852] = {.lex_state = 107, .external_lex_state = 2},
  [20853] = {.lex_state = 107, .external_lex_state = 2},
  [20854] = {.lex_state = 437, .external_lex_state = 3},
  [20855] = {.lex_state = 437, .external_lex_state = 2},
  [20856] = {.lex_state = 32, .external_lex_state = 2},
  [20857] = {.lex_state = 437, .external_lex_state = 2},
  [20858] = {.lex_state = 32, .external_lex_state = 2},
  [20859] = {.lex_state = 437, .external_lex_state = 2},
  [20860] = {.lex_state = 437, .external_lex_state = 3},
  [20861] = {.lex_state = 437, .external_lex_state = 2},
  [20862] = {.lex_state = 32, .external_lex_state = 2},
  [20863] = {.lex_state = 437, .external_lex_state = 2},
  [20864] = {.lex_state = 24, .external_lex_state = 2},
  [20865] = {.lex_state = 437, .external_lex_state = 2},
  [20866] = {.lex_state = 107, .external_lex_state = 2},
  [20867] = {.lex_state = 107, .external_lex_state = 2},
  [20868] = {.lex_state = 107, .external_lex_state = 2},
  [20869] = {.lex_state = 24, .external_lex_state = 2},
  [20870] = {.lex_state = 32, .external_lex_state = 2},
  [20871] = {.lex_state = 32, .external_lex_state = 2},
  [20872] = {.lex_state = 10, .external_lex_state = 2},
  [20873] = {.lex_state = 437, .external_lex_state = 2},
  [20874] = {.lex_state = 32, .external_lex_state = 2},
  [20875] = {.lex_state = 437, .external_lex_state = 2},
  [20876] = {.lex_state = 24, .external_lex_state = 2},
  [20877] = {.lex_state = 11, .external_lex_state = 2},
  [20878] = {.lex_state = 437, .external_lex_state = 2},
  [20879] = {.lex_state = 24, .external_lex_state = 2},
  [20880] = {.lex_state = 437, .external_lex_state = 2},
  [20881] = {.lex_state = 107, .external_lex_state = 2},
  [20882] = {.lex_state = 107, .external_lex_state = 2},
  [20883] = {.lex_state = 107, .external_lex_state = 2},
  [20884] = {.lex_state = 437, .external_lex_state = 2},
  [20885] = {.lex_state = 437, .external_lex_state = 2},
  [20886] = {.lex_state = 437, .external_lex_state = 2},
  [20887] = {.lex_state = 32, .external_lex_state = 2},
  [20888] = {.lex_state = 32, .external_lex_state = 2},
  [20889] = {.lex_state = 437, .external_lex_state = 2},
  [20890] = {.lex_state = 437, .external_lex_state = 2},
  [20891] = {.lex_state = 32, .external_lex_state = 2},
  [20892] = {.lex_state = 32, .external_lex_state = 2},
  [20893] = {.lex_state = 32, .external_lex_state = 2},
  [20894] = {.lex_state = 24, .external_lex_state = 2},
  [20895] = {.lex_state = 437, .external_lex_state = 2},
  [20896] = {.lex_state = 107, .external_lex_state = 2},
  [20897] = {.lex_state = 107, .external_lex_state = 2},
  [20898] = {.lex_state = 107, .external_lex_state = 2},
  [20899] = {.lex_state = 437, .external_lex_state = 2},
  [20900] = {.lex_state = 437, .external_lex_state = 2},
  [20901] = {.lex_state = 437, .external_lex_state = 2},
  [20902] = {.lex_state = 24, .external_lex_state = 2},
  [20903] = {.lex_state = 437, .external_lex_state = 2},
  [20904] = {.lex_state = 437, .external_lex_state = 2},
  [20905] = {.lex_state = 437, .external_lex_state = 2},
  [20906] = {.lex_state = 437, .external_lex_state = 2},
  [20907] = {.lex_state = 437, .external_lex_state = 2},
  [20908] = {.lex_state = 437, .external_lex_state = 2},
  [20909] = {.lex_state = 24, .external_lex_state = 2},
  [20910] = {.lex_state = 437, .external_lex_state = 2},
  [20911] = {.lex_state = 107, .external_lex_state = 2},
  [20912] = {.lex_state = 107, .external_lex_state = 2},
  [20913] = {.lex_state = 107, .external_lex_state = 2},
  [20914] = {.lex_state = 437, .external_lex_state = 2},
  [20915] = {.lex_state = 437, .external_lex_state = 2},
  [20916] = {.lex_state = 437, .external_lex_state = 2},
  [20917] = {.lex_state = 437, .external_lex_state = 2},
  [20918] = {.lex_state = 437, .external_lex_state = 2},
  [20919] = {.lex_state = 437, .external_lex_state = 2},
  [20920] = {.lex_state = 10, .external_lex_state = 2},
  [20921] = {.lex_state = 437, .external_lex_state = 3},
  [20922] = {.lex_state = 437, .external_lex_state = 2},
  [20923] = {.lex_state = 437, .external_lex_state = 2},
  [20924] = {.lex_state = 24, .external_lex_state = 2},
  [20925] = {.lex_state = 437, .external_lex_state = 2},
  [20926] = {.lex_state = 107, .external_lex_state = 2},
  [20927] = {.lex_state = 107, .external_lex_state = 2},
  [20928] = {.lex_state = 107, .external_lex_state = 2},
  [20929] = {.lex_state = 437, .external_lex_state = 2},
  [20930] = {.lex_state = 437, .external_lex_state = 2},
  [20931] = {.lex_state = 437, .external_lex_state = 2},
  [20932] = {.lex_state = 437, .external_lex_state = 2},
  [20933] = {.lex_state = 437, .external_lex_state = 2},
  [20934] = {.lex_state = 32, .external_lex_state = 2},
  [20935] = {.lex_state = 32, .external_lex_state = 2},
  [20936] = {.lex_state = 437, .external_lex_state = 2},
  [20937] = {.lex_state = 32, .external_lex_state = 2},
  [20938] = {.lex_state = 437, .external_lex_state = 2},
  [20939] = {.lex_state = 24, .external_lex_state = 2},
  [20940] = {.lex_state = 437, .external_lex_state = 2},
  [20941] = {.lex_state = 107, .external_lex_state = 2},
  [20942] = {.lex_state = 107, .external_lex_state = 2},
  [20943] = {.lex_state = 107, .external_lex_state = 2},
  [20944] = {.lex_state = 437, .external_lex_state = 2},
  [20945] = {.lex_state = 32, .external_lex_state = 2},
  [20946] = {.lex_state = 24, .external_lex_state = 2},
  [20947] = {.lex_state = 32, .external_lex_state = 2},
  [20948] = {.lex_state = 437, .external_lex_state = 2},
  [20949] = {.lex_state = 437, .external_lex_state = 2},
  [20950] = {.lex_state = 437, .external_lex_state = 2},
  [20951] = {.lex_state = 437, .external_lex_state = 2},
  [20952] = {.lex_state = 32, .external_lex_state = 2},
  [20953] = {.lex_state = 437, .external_lex_state = 2},
  [20954] = {.lex_state = 24, .external_lex_state = 2},
  [20955] = {.lex_state = 437, .external_lex_state = 2},
  [20956] = {.lex_state = 107, .external_lex_state = 2},
  [20957] = {.lex_state = 107, .external_lex_state = 2},
  [20958] = {.lex_state = 107, .external_lex_state = 2},
  [20959] = {.lex_state = 24, .external_lex_state = 2},
  [20960] = {.lex_state = 437, .external_lex_state = 2},
  [20961] = {.lex_state = 32, .external_lex_state = 2},
  [20962] = {.lex_state = 437, .external_lex_state = 2},
  [20963] = {.lex_state = 32, .external_lex_state = 2},
  [20964] = {.lex_state = 437, .external_lex_state = 2},
  [20965] = {.lex_state = 437, .external_lex_state = 2},
  [20966] = {.lex_state = 437, .external_lex_state = 2},
  [20967] = {.lex_state = 437, .external_lex_state = 2},
  [20968] = {.lex_state = 437, .external_lex_state = 2},
  [20969] = {.lex_state = 24, .external_lex_state = 2},
  [20970] = {.lex_state = 437, .external_lex_state = 2},
  [20971] = {.lex_state = 107, .external_lex_state = 2},
  [20972] = {.lex_state = 107, .external_lex_state = 2},
  [20973] = {.lex_state = 107, .external_lex_state = 2},
  [20974] = {.lex_state = 11, .external_lex_state = 2},
  [20975] = {.lex_state = 32, .external_lex_state = 2},
  [20976] = {.lex_state = 437, .external_lex_state = 2},
  [20977] = {.lex_state = 437, .external_lex_state = 2},
  [20978] = {.lex_state = 11, .external_lex_state = 2},
  [20979] = {.lex_state = 437, .external_lex_state = 2},
  [20980] = {.lex_state = 437, .external_lex_state = 2},
  [20981] = {.lex_state = 437, .external_lex_state = 2},
  [20982] = {.lex_state = 32, .external_lex_state = 2},
  [20983] = {.lex_state = 32, .external_lex_state = 2},
  [20984] = {.lex_state = 24, .external_lex_state = 2},
  [20985] = {.lex_state = 437, .external_lex_state = 2},
  [20986] = {.lex_state = 107, .external_lex_state = 2},
  [20987] = {.lex_state = 107, .external_lex_state = 2},
  [20988] = {.lex_state = 107, .external_lex_state = 2},
  [20989] = {.lex_state = 437, .external_lex_state = 2},
  [20990] = {.lex_state = 11, .external_lex_state = 2},
  [20991] = {.lex_state = 32, .external_lex_state = 2},
  [20992] = {.lex_state = 437, .external_lex_state = 2},
  [20993] = {.lex_state = 10, .external_lex_state = 2},
  [20994] = {.lex_state = 437, .external_lex_state = 2},
  [20995] = {.lex_state = 32, .external_lex_state = 2},
  [20996] = {.lex_state = 32, .external_lex_state = 2},
  [20997] = {.lex_state = 32, .external_lex_state = 2},
  [20998] = {.lex_state = 437, .external_lex_state = 2},
  [20999] = {.lex_state = 24, .external_lex_state = 2},
  [21000] = {.lex_state = 32, .external_lex_state = 2},
  [21001] = {.lex_state = 107, .external_lex_state = 2},
  [21002] = {.lex_state = 107, .external_lex_state = 2},
  [21003] = {.lex_state = 107, .external_lex_state = 2},
  [21004] = {.lex_state = 437, .external_lex_state = 2},
  [21005] = {.lex_state = 437, .external_lex_state = 2},
  [21006] = {.lex_state = 437, .external_lex_state = 2},
  [21007] = {.lex_state = 437, .external_lex_state = 2},
  [21008] = {.lex_state = 437, .external_lex_state = 2},
  [21009] = {.lex_state = 11, .external_lex_state = 2},
  [21010] = {.lex_state = 437, .external_lex_state = 2},
  [21011] = {.lex_state = 437, .external_lex_state = 2},
  [21012] = {.lex_state = 437, .external_lex_state = 2},
  [21013] = {.lex_state = 437, .external_lex_state = 2},
  [21014] = {.lex_state = 24, .external_lex_state = 2},
  [21015] = {.lex_state = 437, .external_lex_state = 2},
  [21016] = {.lex_state = 107, .external_lex_state = 2},
  [21017] = {.lex_state = 107, .external_lex_state = 2},
  [21018] = {.lex_state = 107, .external_lex_state = 2},
  [21019] = {.lex_state = 437, .external_lex_state = 2},
  [21020] = {.lex_state = 437, .external_lex_state = 2},
  [21021] = {.lex_state = 437, .external_lex_state = 2},
  [21022] = {.lex_state = 437, .external_lex_state = 2},
  [21023] = {.lex_state = 437, .external_lex_state = 2},
  [21024] = {.lex_state = 437, .external_lex_state = 2},
  [21025] = {.lex_state = 437, .external_lex_state = 2},
  [21026] = {.lex_state = 437, .external_lex_state = 2},
  [21027] = {.lex_state = 437, .external_lex_state = 3},
  [21028] = {.lex_state = 437, .external_lex_state = 2},
  [21029] = {.lex_state = 437, .external_lex_state = 2},
  [21030] = {.lex_state = 107, .external_lex_state = 2},
  [21031] = {.lex_state = 107, .external_lex_state = 2},
  [21032] = {.lex_state = 107, .external_lex_state = 2},
  [21033] = {.lex_state = 437, .external_lex_state = 2},
  [21034] = {.lex_state = 437, .external_lex_state = 2},
  [21035] = {.lex_state = 437, .external_lex_state = 2},
  [21036] = {.lex_state = 437, .external_lex_state = 2},
  [21037] = {.lex_state = 437, .external_lex_state = 2},
  [21038] = {.lex_state = 32, .external_lex_state = 2},
  [21039] = {.lex_state = 437, .external_lex_state = 2},
  [21040] = {.lex_state = 10, .external_lex_state = 2},
  [21041] = {.lex_state = 437, .external_lex_state = 2},
  [21042] = {.lex_state = 32, .external_lex_state = 2},
  [21043] = {.lex_state = 437, .external_lex_state = 2},
  [21044] = {.lex_state = 107, .external_lex_state = 2},
  [21045] = {.lex_state = 107, .external_lex_state = 2},
  [21046] = {.lex_state = 107, .external_lex_state = 2},
  [21047] = {.lex_state = 437, .external_lex_state = 3},
  [21048] = {.lex_state = 437, .external_lex_state = 2},
  [21049] = {.lex_state = 10, .external_lex_state = 2},
  [21050] = {.lex_state = 24, .external_lex_state = 2},
  [21051] = {.lex_state = 437, .external_lex_state = 2},
  [21052] = {.lex_state = 11, .external_lex_state = 2},
  [21053] = {.lex_state = 437, .external_lex_state = 2},
  [21054] = {.lex_state = 437, .external_lex_state = 2},
  [21055] = {.lex_state = 32, .external_lex_state = 2},
  [21056] = {.lex_state = 437, .external_lex_state = 2},
  [21057] = {.lex_state = 32, .external_lex_state = 2},
  [21058] = {.lex_state = 107, .external_lex_state = 2},
  [21059] = {.lex_state = 107, .external_lex_state = 2},
  [21060] = {.lex_state = 107, .external_lex_state = 2},
  [21061] = {.lex_state = 11, .external_lex_state = 2},
  [21062] = {.lex_state = 437, .external_lex_state = 2},
  [21063] = {.lex_state = 437, .external_lex_state = 2},
  [21064] = {.lex_state = 32, .external_lex_state = 2},
  [21065] = {.lex_state = 437, .external_lex_state = 2},
  [21066] = {.lex_state = 437, .external_lex_state = 2},
  [21067] = {.lex_state = 437, .external_lex_state = 2},
  [21068] = {.lex_state = 437, .external_lex_state = 2},
  [21069] = {.lex_state = 437, .external_lex_state = 2},
  [21070] = {.lex_state = 437, .external_lex_state = 2},
  [21071] = {.lex_state = 437, .external_lex_state = 2},
  [21072] = {.lex_state = 107, .external_lex_state = 2},
  [21073] = {.lex_state = 107, .external_lex_state = 2},
  [21074] = {.lex_state = 107, .external_lex_state = 2},
  [21075] = {.lex_state = 11, .external_lex_state = 2},
  [21076] = {.lex_state = 437, .external_lex_state = 2},
  [21077] = {.lex_state = 437, .external_lex_state = 2},
  [21078] = {.lex_state = 437, .external_lex_state = 2},
  [21079] = {.lex_state = 437, .external_lex_state = 2},
  [21080] = {.lex_state = 437, .external_lex_state = 2},
  [21081] = {.lex_state = 32, .external_lex_state = 2},
  [21082] = {.lex_state = 32, .external_lex_state = 2},
  [21083] = {.lex_state = 437, .external_lex_state = 2},
  [21084] = {.lex_state = 107, .external_lex_state = 2},
  [21085] = {.lex_state = 107, .external_lex_state = 2},
  [21086] = {.lex_state = 107, .external_lex_state = 2},
  [21087] = {.lex_state = 437, .external_lex_state = 2},
  [21088] = {.lex_state = 437, .external_lex_state = 2},
  [21089] = {.lex_state = 437, .external_lex_state = 2},
  [21090] = {.lex_state = 437, .external_lex_state = 2},
  [21091] = {.lex_state = 437, .external_lex_state = 2},
  [21092] = {.lex_state = 437, .external_lex_state = 2},
  [21093] = {.lex_state = 437, .external_lex_state = 2},
  [21094] = {.lex_state = 437, .external_lex_state = 2},
  [21095] = {.lex_state = 11, .external_lex_state = 2},
  [21096] = {.lex_state = 107, .external_lex_state = 2},
  [21097] = {.lex_state = 107, .external_lex_state = 2},
  [21098] = {.lex_state = 107, .external_lex_state = 2},
  [21099] = {.lex_state = 437, .external_lex_state = 2},
  [21100] = {.lex_state = 437, .external_lex_state = 2},
  [21101] = {.lex_state = 107, .external_lex_state = 2},
  [21102] = {.lex_state = 107, .external_lex_state = 2},
  [21103] = {.lex_state = 107, .external_lex_state = 2},
  [21104] = {.lex_state = 437, .external_lex_state = 2},
  [21105] = {.lex_state = 437, .external_lex_state = 2},
  [21106] = {.lex_state = 107, .external_lex_state = 2},
  [21107] = {.lex_state = 107, .external_lex_state = 2},
  [21108] = {.lex_state = 107, .external_lex_state = 2},
  [21109] = {.lex_state = 437, .external_lex_state = 2},
  [21110] = {.lex_state = 437, .external_lex_state = 2},
  [21111] = {.lex_state = 107, .external_lex_state = 2},
  [21112] = {.lex_state = 107, .external_lex_state = 2},
  [21113] = {.lex_state = 107, .external_lex_state = 2},
  [21114] = {.lex_state = 437, .external_lex_state = 2},
  [21115] = {.lex_state = 32, .external_lex_state = 2},
  [21116] = {.lex_state = 107, .external_lex_state = 2},
  [21117] = {.lex_state = 107, .external_lex_state = 2},
  [21118] = {.lex_state = 107, .external_lex_state = 2},
  [21119] = {.lex_state = 32, .external_lex_state = 2},
  [21120] = {.lex_state = 437, .external_lex_state = 2},
  [21121] = {.lex_state = 107, .external_lex_state = 2},
  [21122] = {.lex_state = 107, .external_lex_state = 2},
  [21123] = {.lex_state = 107, .external_lex_state = 2},
  [21124] = {.lex_state = 437, .external_lex_state = 2},
  [21125] = {.lex_state = 437, .external_lex_state = 2},
  [21126] = {.lex_state = 107, .external_lex_state = 2},
  [21127] = {.lex_state = 107, .external_lex_state = 2},
  [21128] = {.lex_state = 107, .external_lex_state = 2},
  [21129] = {.lex_state = 437, .external_lex_state = 2},
  [21130] = {.lex_state = 437, .external_lex_state = 3},
  [21131] = {.lex_state = 107, .external_lex_state = 2},
  [21132] = {.lex_state = 107, .external_lex_state = 2},
  [21133] = {.lex_state = 107, .external_lex_state = 2},
  [21134] = {.lex_state = 437, .external_lex_state = 2},
  [21135] = {.lex_state = 32, .external_lex_state = 2},
  [21136] = {.lex_state = 107, .external_lex_state = 2},
  [21137] = {.lex_state = 107, .external_lex_state = 2},
  [21138] = {.lex_state = 107, .external_lex_state = 2},
  [21139] = {.lex_state = 437, .external_lex_state = 2},
  [21140] = {.lex_state = 437, .external_lex_state = 2},
  [21141] = {.lex_state = 107, .external_lex_state = 2},
  [21142] = {.lex_state = 107, .external_lex_state = 2},
  [21143] = {.lex_state = 107, .external_lex_state = 2},
  [21144] = {.lex_state = 437, .external_lex_state = 2},
  [21145] = {.lex_state = 437, .external_lex_state = 2},
  [21146] = {.lex_state = 107, .external_lex_state = 2},
  [21147] = {.lex_state = 107, .external_lex_state = 2},
  [21148] = {.lex_state = 107, .external_lex_state = 2},
  [21149] = {.lex_state = 11, .external_lex_state = 2},
  [21150] = {.lex_state = 437, .external_lex_state = 2},
  [21151] = {.lex_state = 107, .external_lex_state = 2},
  [21152] = {.lex_state = 107, .external_lex_state = 2},
  [21153] = {.lex_state = 107, .external_lex_state = 2},
  [21154] = {.lex_state = 437, .external_lex_state = 2},
  [21155] = {.lex_state = 437, .external_lex_state = 2},
  [21156] = {.lex_state = 107, .external_lex_state = 2},
  [21157] = {.lex_state = 107, .external_lex_state = 2},
  [21158] = {.lex_state = 107, .external_lex_state = 2},
  [21159] = {.lex_state = 437, .external_lex_state = 2},
  [21160] = {.lex_state = 437, .external_lex_state = 2},
  [21161] = {.lex_state = 11, .external_lex_state = 2},
  [21162] = {.lex_state = 437, .external_lex_state = 2},
  [21163] = {.lex_state = 437, .external_lex_state = 2},
  [21164] = {.lex_state = 437, .external_lex_state = 2},
  [21165] = {.lex_state = 437, .external_lex_state = 2},
  [21166] = {.lex_state = 32, .external_lex_state = 2},
  [21167] = {.lex_state = 437, .external_lex_state = 2},
  [21168] = {.lex_state = 437, .external_lex_state = 2},
  [21169] = {.lex_state = 437, .external_lex_state = 2},
  [21170] = {.lex_state = 437, .external_lex_state = 2},
  [21171] = {.lex_state = 437, .external_lex_state = 2},
  [21172] = {.lex_state = 437, .external_lex_state = 3},
  [21173] = {.lex_state = 437, .external_lex_state = 2},
  [21174] = {.lex_state = 437, .external_lex_state = 2},
  [21175] = {.lex_state = 437, .external_lex_state = 2},
  [21176] = {.lex_state = 437, .external_lex_state = 2},
  [21177] = {.lex_state = 437, .external_lex_state = 2},
  [21178] = {.lex_state = 437, .external_lex_state = 2},
  [21179] = {.lex_state = 437, .external_lex_state = 2},
  [21180] = {.lex_state = 437, .external_lex_state = 2},
  [21181] = {.lex_state = 437, .external_lex_state = 2},
  [21182] = {.lex_state = 24, .external_lex_state = 2},
  [21183] = {.lex_state = 437, .external_lex_state = 2},
  [21184] = {.lex_state = 437, .external_lex_state = 2},
  [21185] = {.lex_state = 437, .external_lex_state = 2},
  [21186] = {.lex_state = 32, .external_lex_state = 2},
  [21187] = {.lex_state = 437, .external_lex_state = 2},
  [21188] = {.lex_state = 437, .external_lex_state = 2},
  [21189] = {.lex_state = 437, .external_lex_state = 2},
  [21190] = {.lex_state = 32, .external_lex_state = 2},
  [21191] = {.lex_state = 257, .external_lex_state = 2},
  [21192] = {.lex_state = 38, .external_lex_state = 2},
  [21193] = {.lex_state = 437, .external_lex_state = 2},
  [21194] = {.lex_state = 437, .external_lex_state = 2},
  [21195] = {.lex_state = 437, .external_lex_state = 2},
  [21196] = {.lex_state = 32, .external_lex_state = 2},
  [21197] = {.lex_state = 32, .external_lex_state = 2},
  [21198] = {.lex_state = 32, .external_lex_state = 2},
  [21199] = {.lex_state = 11, .external_lex_state = 2},
  [21200] = {.lex_state = 437, .external_lex_state = 2},
  [21201] = {.lex_state = 32, .external_lex_state = 2},
  [21202] = {.lex_state = 11, .external_lex_state = 2},
  [21203] = {.lex_state = 11, .external_lex_state = 2},
  [21204] = {.lex_state = 437, .external_lex_state = 2},
  [21205] = {.lex_state = 11, .external_lex_state = 2},
  [21206] = {.lex_state = 32, .external_lex_state = 2},
  [21207] = {.lex_state = 11, .external_lex_state = 2},
  [21208] = {.lex_state = 11, .external_lex_state = 2},
  [21209] = {.lex_state = 32, .external_lex_state = 2},
  [21210] = {.lex_state = 24, .external_lex_state = 2},
  [21211] = {.lex_state = 32, .external_lex_state = 2},
  [21212] = {.lex_state = 437, .external_lex_state = 2},
  [21213] = {.lex_state = 437, .external_lex_state = 2},
  [21214] = {.lex_state = 24, .external_lex_state = 2},
  [21215] = {.lex_state = 437, .external_lex_state = 2},
  [21216] = {.lex_state = 32, .external_lex_state = 2},
  [21217] = {.lex_state = 24, .external_lex_state = 2},
  [21218] = {.lex_state = 437, .external_lex_state = 2},
  [21219] = {.lex_state = 437, .external_lex_state = 2},
  [21220] = {.lex_state = 437, .external_lex_state = 2},
  [21221] = {.lex_state = 437, .external_lex_state = 2},
  [21222] = {.lex_state = 11, .external_lex_state = 2},
  [21223] = {.lex_state = 11, .external_lex_state = 2},
  [21224] = {.lex_state = 437, .external_lex_state = 2},
  [21225] = {.lex_state = 32, .external_lex_state = 2},
  [21226] = {.lex_state = 257, .external_lex_state = 2},
  [21227] = {.lex_state = 11, .external_lex_state = 2},
  [21228] = {.lex_state = 437, .external_lex_state = 2},
  [21229] = {.lex_state = 437, .external_lex_state = 2},
  [21230] = {.lex_state = 32, .external_lex_state = 2},
  [21231] = {.lex_state = 11, .external_lex_state = 2},
  [21232] = {.lex_state = 437, .external_lex_state = 2},
  [21233] = {.lex_state = 437, .external_lex_state = 2},
  [21234] = {.lex_state = 437, .external_lex_state = 2},
  [21235] = {.lex_state = 437, .external_lex_state = 2},
  [21236] = {.lex_state = 437, .external_lex_state = 2},
  [21237] = {.lex_state = 437, .external_lex_state = 2},
  [21238] = {.lex_state = 437, .external_lex_state = 2},
  [21239] = {.lex_state = 437, .external_lex_state = 2},
  [21240] = {.lex_state = 437, .external_lex_state = 2},
  [21241] = {.lex_state = 257, .external_lex_state = 2},
  [21242] = {.lex_state = 437, .external_lex_state = 2},
  [21243] = {.lex_state = 437, .external_lex_state = 2},
  [21244] = {.lex_state = 437, .external_lex_state = 2},
  [21245] = {.lex_state = 437, .external_lex_state = 2},
  [21246] = {.lex_state = 437, .external_lex_state = 2},
  [21247] = {.lex_state = 437, .external_lex_state = 2},
  [21248] = {.lex_state = 437, .external_lex_state = 2},
  [21249] = {.lex_state = 437, .external_lex_state = 2},
  [21250] = {.lex_state = 32, .external_lex_state = 2},
  [21251] = {.lex_state = 32, .external_lex_state = 2},
  [21252] = {.lex_state = 257, .external_lex_state = 2},
  [21253] = {.lex_state = 437, .external_lex_state = 2},
  [21254] = {.lex_state = 437, .external_lex_state = 2},
  [21255] = {.lex_state = 437, .external_lex_state = 2},
  [21256] = {.lex_state = 437, .external_lex_state = 2},
  [21257] = {.lex_state = 437, .external_lex_state = 2},
  [21258] = {.lex_state = 32, .external_lex_state = 2},
  [21259] = {.lex_state = 257, .external_lex_state = 2},
  [21260] = {.lex_state = 257, .external_lex_state = 2},
  [21261] = {.lex_state = 257, .external_lex_state = 2},
  [21262] = {.lex_state = 257, .external_lex_state = 2},
  [21263] = {.lex_state = 257, .external_lex_state = 2},
  [21264] = {.lex_state = 257, .external_lex_state = 2},
  [21265] = {.lex_state = 257, .external_lex_state = 2},
  [21266] = {.lex_state = 257, .external_lex_state = 2},
  [21267] = {.lex_state = 257, .external_lex_state = 2},
  [21268] = {.lex_state = 257, .external_lex_state = 2},
  [21269] = {.lex_state = 257, .external_lex_state = 2},
  [21270] = {.lex_state = 257, .external_lex_state = 2},
  [21271] = {.lex_state = 257, .external_lex_state = 2},
  [21272] = {.lex_state = 257, .external_lex_state = 2},
  [21273] = {.lex_state = 257, .external_lex_state = 2},
  [21274] = {.lex_state = 257, .external_lex_state = 2},
  [21275] = {.lex_state = 257, .external_lex_state = 2},
  [21276] = {.lex_state = 257, .external_lex_state = 2},
  [21277] = {.lex_state = 257, .external_lex_state = 2},
  [21278] = {.lex_state = 257, .external_lex_state = 2},
  [21279] = {.lex_state = 257, .external_lex_state = 2},
  [21280] = {.lex_state = 257, .external_lex_state = 2},
  [21281] = {.lex_state = 257, .external_lex_state = 2},
  [21282] = {.lex_state = 257, .external_lex_state = 2},
  [21283] = {.lex_state = 257, .external_lex_state = 2},
  [21284] = {.lex_state = 257, .external_lex_state = 2},
  [21285] = {.lex_state = 257, .external_lex_state = 2},
  [21286] = {.lex_state = 257, .external_lex_state = 2},
  [21287] = {.lex_state = 257, .external_lex_state = 2},
  [21288] = {.lex_state = 257, .external_lex_state = 2},
  [21289] = {.lex_state = 257, .external_lex_state = 2},
  [21290] = {.lex_state = 257, .external_lex_state = 2},
  [21291] = {.lex_state = 257, .external_lex_state = 2},
  [21292] = {.lex_state = 257, .external_lex_state = 2},
  [21293] = {.lex_state = 257, .external_lex_state = 2},
  [21294] = {.lex_state = 257, .external_lex_state = 2},
  [21295] = {.lex_state = 257, .external_lex_state = 2},
  [21296] = {.lex_state = 257, .external_lex_state = 2},
  [21297] = {.lex_state = 257, .external_lex_state = 2},
  [21298] = {.lex_state = 257, .external_lex_state = 2},
  [21299] = {.lex_state = 257, .external_lex_state = 2},
  [21300] = {.lex_state = 257, .external_lex_state = 2},
  [21301] = {.lex_state = 257, .external_lex_state = 2},
  [21302] = {.lex_state = 257, .external_lex_state = 2},
  [21303] = {.lex_state = 257, .external_lex_state = 2},
  [21304] = {.lex_state = 257, .external_lex_state = 2},
  [21305] = {.lex_state = 257, .external_lex_state = 2},
  [21306] = {.lex_state = 257, .external_lex_state = 2},
  [21307] = {.lex_state = 257, .external_lex_state = 2},
  [21308] = {.lex_state = 257, .external_lex_state = 2},
  [21309] = {.lex_state = 257, .external_lex_state = 2},
  [21310] = {.lex_state = 437, .external_lex_state = 2},
  [21311] = {.lex_state = 437, .external_lex_state = 2},
  [21312] = {.lex_state = 24, .external_lex_state = 2},
  [21313] = {.lex_state = 32, .external_lex_state = 2},
  [21314] = {.lex_state = 10, .external_lex_state = 2},
  [21315] = {.lex_state = 437, .external_lex_state = 2},
  [21316] = {.lex_state = 437, .external_lex_state = 3},
  [21317] = {.lex_state = 32, .external_lex_state = 2},
  [21318] = {.lex_state = 32, .external_lex_state = 2},
  [21319] = {.lex_state = 437, .external_lex_state = 2},
  [21320] = {.lex_state = 437, .external_lex_state = 2},
  [21321] = {.lex_state = 32, .external_lex_state = 2},
  [21322] = {.lex_state = 32, .external_lex_state = 2},
  [21323] = {.lex_state = 32, .external_lex_state = 2},
  [21324] = {.lex_state = 437, .external_lex_state = 2},
  [21325] = {.lex_state = 437, .external_lex_state = 2},
  [21326] = {.lex_state = 437, .external_lex_state = 2},
  [21327] = {.lex_state = 437, .external_lex_state = 2},
  [21328] = {.lex_state = 437, .external_lex_state = 2},
  [21329] = {.lex_state = 24, .external_lex_state = 2},
  [21330] = {.lex_state = 10, .external_lex_state = 2},
  [21331] = {.lex_state = 437, .external_lex_state = 3},
  [21332] = {.lex_state = 437, .external_lex_state = 2},
  [21333] = {.lex_state = 437, .external_lex_state = 2},
  [21334] = {.lex_state = 437, .external_lex_state = 2},
  [21335] = {.lex_state = 437, .external_lex_state = 2},
  [21336] = {.lex_state = 437, .external_lex_state = 2},
  [21337] = {.lex_state = 11, .external_lex_state = 2},
  [21338] = {.lex_state = 32, .external_lex_state = 2},
  [21339] = {.lex_state = 11, .external_lex_state = 2},
  [21340] = {.lex_state = 32, .external_lex_state = 2},
  [21341] = {.lex_state = 32, .external_lex_state = 2},
  [21342] = {.lex_state = 32, .external_lex_state = 2},
  [21343] = {.lex_state = 11, .external_lex_state = 2},
  [21344] = {.lex_state = 32, .external_lex_state = 2},
  [21345] = {.lex_state = 32, .external_lex_state = 2},
  [21346] = {.lex_state = 32, .external_lex_state = 2},
  [21347] = {.lex_state = 437, .external_lex_state = 2},
  [21348] = {.lex_state = 24, .external_lex_state = 2},
  [21349] = {.lex_state = 437, .external_lex_state = 2},
  [21350] = {.lex_state = 437, .external_lex_state = 2},
  [21351] = {.lex_state = 24, .external_lex_state = 2},
  [21352] = {.lex_state = 437, .external_lex_state = 2},
  [21353] = {.lex_state = 437, .external_lex_state = 2},
  [21354] = {.lex_state = 437, .external_lex_state = 2},
  [21355] = {.lex_state = 437, .external_lex_state = 2},
  [21356] = {.lex_state = 11, .external_lex_state = 2},
  [21357] = {.lex_state = 437, .external_lex_state = 2},
  [21358] = {.lex_state = 32, .external_lex_state = 2},
  [21359] = {.lex_state = 437, .external_lex_state = 2},
  [21360] = {.lex_state = 437, .external_lex_state = 2},
  [21361] = {.lex_state = 32, .external_lex_state = 2},
  [21362] = {.lex_state = 437, .external_lex_state = 2},
  [21363] = {.lex_state = 32, .external_lex_state = 2},
  [21364] = {.lex_state = 11, .external_lex_state = 2},
  [21365] = {.lex_state = 437, .external_lex_state = 2},
  [21366] = {.lex_state = 32, .external_lex_state = 2},
  [21367] = {.lex_state = 437, .external_lex_state = 2},
  [21368] = {.lex_state = 437, .external_lex_state = 2},
  [21369] = {.lex_state = 437, .external_lex_state = 2},
  [21370] = {.lex_state = 32, .external_lex_state = 2},
  [21371] = {.lex_state = 32, .external_lex_state = 2},
  [21372] = {.lex_state = 437, .external_lex_state = 2},
  [21373] = {.lex_state = 437, .external_lex_state = 2},
  [21374] = {.lex_state = 32, .external_lex_state = 2},
  [21375] = {.lex_state = 437, .external_lex_state = 2},
  [21376] = {.lex_state = 437, .external_lex_state = 2},
  [21377] = {.lex_state = 437, .external_lex_state = 2},
  [21378] = {.lex_state = 437, .external_lex_state = 2},
  [21379] = {.lex_state = 10, .external_lex_state = 2},
  [21380] = {.lex_state = 437, .external_lex_state = 2},
  [21381] = {.lex_state = 437, .external_lex_state = 2},
  [21382] = {.lex_state = 437, .external_lex_state = 2},
  [21383] = {.lex_state = 11, .external_lex_state = 2},
  [21384] = {.lex_state = 437, .external_lex_state = 2},
  [21385] = {.lex_state = 437, .external_lex_state = 2},
  [21386] = {.lex_state = 437, .external_lex_state = 2},
  [21387] = {.lex_state = 437, .external_lex_state = 2},
  [21388] = {.lex_state = 437, .external_lex_state = 2},
  [21389] = {.lex_state = 11, .external_lex_state = 2},
  [21390] = {.lex_state = 11, .external_lex_state = 2},
  [21391] = {.lex_state = 437, .external_lex_state = 2},
  [21392] = {.lex_state = 11, .external_lex_state = 2},
  [21393] = {.lex_state = 24, .external_lex_state = 2},
  [21394] = {.lex_state = 437, .external_lex_state = 2},
  [21395] = {.lex_state = 437, .external_lex_state = 2},
  [21396] = {.lex_state = 437, .external_lex_state = 2},
  [21397] = {.lex_state = 11, .external_lex_state = 2},
  [21398] = {.lex_state = 437, .external_lex_state = 2},
  [21399] = {.lex_state = 437, .external_lex_state = 2},
  [21400] = {.lex_state = 437, .external_lex_state = 2},
  [21401] = {.lex_state = 11, .external_lex_state = 2},
  [21402] = {.lex_state = 32, .external_lex_state = 2},
  [21403] = {.lex_state = 437, .external_lex_state = 2},
  [21404] = {.lex_state = 11, .external_lex_state = 2},
  [21405] = {.lex_state = 437, .external_lex_state = 2},
  [21406] = {.lex_state = 437, .external_lex_state = 2},
  [21407] = {.lex_state = 11, .external_lex_state = 2},
  [21408] = {.lex_state = 437, .external_lex_state = 2},
  [21409] = {.lex_state = 437, .external_lex_state = 2},
  [21410] = {.lex_state = 437, .external_lex_state = 2},
  [21411] = {.lex_state = 437, .external_lex_state = 2},
  [21412] = {.lex_state = 437, .external_lex_state = 2},
  [21413] = {.lex_state = 32, .external_lex_state = 2},
  [21414] = {.lex_state = 11, .external_lex_state = 2},
  [21415] = {.lex_state = 437, .external_lex_state = 3},
  [21416] = {.lex_state = 32, .external_lex_state = 2},
  [21417] = {.lex_state = 32, .external_lex_state = 2},
  [21418] = {(TSStateId)(-1)},
  [21419] = {(TSStateId)(-1)},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_attribute] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym__lowercase_identifier] = ACTIONS(1),
    [anon_sym_SEMI_SEMI] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_rec] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_COLON_GT] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_external] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_nonrec] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_COLON2] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_mutable] = ACTIONS(1),
    [anon_sym_constraint] = ACTIONS(1),
    [anon_sym_exception] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_open] = ACTIONS(1),
    [anon_sym_include] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_virtual] = ACTIONS(1),
    [anon_sym_val] = ACTIONS(1),
    [anon_sym_sig] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_functor] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_method] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_fun] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_LBRACK_GT] = ACTIONS(1),
    [anon_sym_LBRACK_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_RBRACK] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_lazy] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_LBRACE_LT] = ACTIONS(1),
    [anon_sym_begin] = ACTIONS(1),
    [sym_ocamlyacc_value] = ACTIONS(1),
    [anon_sym_effect] = ACTIONS(1),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [aux_sym_number_token1] = ACTIONS(1),
    [aux_sym_signed_number_token1] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE2] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [aux_sym_string_content_token2] = ACTIONS(1),
    [aux_sym_string_content_token4] = ACTIONS(1),
    [aux_sym_string_content_token5] = ACTIONS(1),
    [aux_sym_escape_sequence_token1] = ACTIONS(1),
    [aux_sym_escape_sequence_token2] = ACTIONS(1),
    [aux_sym_escape_sequence_token3] = ACTIONS(1),
    [aux_sym_escape_sequence_token4] = ACTIONS(1),
    [sym_pretty_printing_indication] = ACTIONS(1),
    [aux_sym_sign_operator_token1] = ACTIONS(1),
    [sym_hash_operator] = ACTIONS(1),
    [sym_concat_operator] = ACTIONS(1),
    [sym_and_operator] = ACTIONS(1),
    [sym_or_operator] = ACTIONS(1),
    [sym_assign_operator] = ACTIONS(1),
    [sym_let_operator] = ACTIONS(1),
    [sym_let_and_operator] = ACTIONS(1),
    [sym_match_operator] = ACTIONS(1),
    [sym__uppercase_identifier] = ACTIONS(1),
    [aux_sym_directive_token1] = ACTIONS(1),
    [aux_sym_type_variable_token1] = ACTIONS(1),
    [aux_sym_tag_token1] = ACTIONS(1),
    [aux_sym_attribute_id_token1] = ACTIONS(1),
    [sym_comment] = ACTIONS(5),
    [sym__left_quoted_string_delimiter] = ACTIONS(1),
    [sym__right_quoted_string_delimiter] = ACTIONS(1),
    [sym_line_number_directive] = ACTIONS(5),
    [sym__null] = ACTIONS(1),
    [sym__error_sentinel] = ACTIONS(1),
  },
  [1] = {
    [sym_compilation_unit] = STATE(20214),
    [sym__signature] = STATE(20417),
    [sym_external] = STATE(13539),
    [sym_type_definition] = STATE(13539),
    [sym_exception_definition] = STATE(13539),
    [sym_module_definition] = STATE(13539),
    [sym_module_type_definition] = STATE(13539),
    [sym_open_module] = STATE(13539),
    [sym_class_definition] = STATE(13539),
    [sym_class_type_definition] = STATE(13539),
    [sym__signature_item] = STATE(13542),
    [sym_value_specification] = STATE(13539),
    [sym_include_module_type] = STATE(13539),
    [sym_attribute] = STATE(1),
    [sym_floating_attribute] = STATE(13539),
    [sym_item_extension] = STATE(13539),
    [sym_quoted_item_extension] = STATE(13539),
    [aux_sym__structure_repeat1] = STATE(9327),
    [aux_sym__signature_repeat1] = STATE(9281),
    [ts_builtin_sym_end] = ACTIONS(7),
    [anon_sym_SEMI_SEMI] = ACTIONS(9),
    [anon_sym_external] = ACTIONS(11),
    [anon_sym_type] = ACTIONS(13),
    [anon_sym_exception] = ACTIONS(15),
    [anon_sym_module] = ACTIONS(17),
    [anon_sym_open] = ACTIONS(19),
    [anon_sym_include] = ACTIONS(21),
    [anon_sym_class] = ACTIONS(23),
    [anon_sym_val] = ACTIONS(25),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(2),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19680),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(3),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20731),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(125),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [4] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(4),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18448),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [5] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(5),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19327),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(129),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [6] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(6),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18575),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [7] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(7),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20875),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(133),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [8] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(8),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18902),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(135),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [9] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(9),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19051),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(137),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [10] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(10),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18723),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(139),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [11] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(11),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19913),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(141),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [12] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(12),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18975),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(143),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [13] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(13),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19497),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(145),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [14] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(14),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18711),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(147),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [15] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(15),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19706),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(149),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [16] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(16),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20658),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(151),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [17] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(17),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19060),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(153),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [18] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(18),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20759),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(155),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [19] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(19),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20930),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(157),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [20] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(20),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19271),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [21] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(21),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19298),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(161),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [22] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(22),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(21011),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [23] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(23),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18612),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(165),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [24] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(24),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20803),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(167),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [25] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(25),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18858),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(169),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [26] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(26),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20830),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(171),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [27] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(27),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19052),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(173),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [28] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(28),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20138),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(175),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [29] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(29),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19318),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [30] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(30),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20285),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(179),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [31] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(31),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18523),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(181),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [32] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(32),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18993),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(183),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [33] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(33),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19328),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(185),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [34] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(34),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20162),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(187),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [35] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(35),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20389),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(189),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [36] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(36),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20800),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(191),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [37] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(37),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(21334),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(193),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [38] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(38),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19396),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(195),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [39] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(39),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(21408),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(197),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [40] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(40),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19994),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(199),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [41] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(41),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19252),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(201),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [42] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(42),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20884),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(203),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [43] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(43),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18450),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(205),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [44] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(44),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20313),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(207),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [45] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(45),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19057),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(209),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [46] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(46),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19877),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(211),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [47] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(47),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(21069),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(213),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [48] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(48),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18654),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(215),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [49] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(49),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(18946),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(217),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [50] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(50),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19372),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(219),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [51] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(51),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19716),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(221),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [52] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(52),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19895),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(223),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [53] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(53),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20005),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(225),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [54] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(54),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20027),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(227),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [55] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(55),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20050),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(229),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [56] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(56),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20078),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(231),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [57] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(57),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20108),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(233),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [58] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(58),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20148),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(235),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [59] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(59),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20183),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(237),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [60] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(60),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20230),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(239),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [61] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(61),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20274),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(241),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [62] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(62),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20327),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(243),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [63] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(63),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20372),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [64] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(64),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20420),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(247),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [65] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(65),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20466),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(249),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [66] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(66),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20481),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(251),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [67] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(67),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20496),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(253),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [68] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(68),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20510),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(255),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [69] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(69),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20524),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(257),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [70] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(70),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20544),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(259),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [71] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(71),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20554),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(261),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [72] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(72),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20564),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(263),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [73] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(73),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20571),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(265),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [74] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(74),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20583),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(267),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [75] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(75),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20592),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(269),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [76] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(76),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20604),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(271),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [77] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(77),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20614),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(273),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [78] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(78),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20627),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(275),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [79] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(79),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20643),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(277),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [80] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(80),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20654),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(279),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [81] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(81),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20663),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(281),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [82] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(82),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20674),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(283),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [83] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(83),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20685),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(285),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [84] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(84),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20691),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [85] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(85),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20701),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(289),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [86] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(86),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20715),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(291),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [87] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(87),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(20722),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(293),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [88] = {
    [sym__structure] = STATE(20370),
    [sym_expression_item] = STATE(8708),
    [sym_toplevel_directive] = STATE(8708),
    [sym__structure_item] = STATE(8708),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(88),
    [sym_floating_attribute] = STATE(13305),
    [sym_attribute_payload] = STATE(19037),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(93),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_QMARK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(295),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_COLON2] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [89] = {
    [sym__structure] = STATE(20391),
    [sym_expression_item] = STATE(8701),
    [sym_toplevel_directive] = STATE(8701),
    [sym__structure_item] = STATE(8701),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(89),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(299),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_end] = ACTIONS(319),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [90] = {
    [sym__structure] = STATE(21362),
    [sym_expression_item] = STATE(8701),
    [sym_toplevel_directive] = STATE(8701),
    [sym__structure_item] = STATE(8701),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(90),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(103),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(299),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_end] = ACTIONS(365),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [91] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8537),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(91),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__attribute] = STATE(1581),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(405),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(407),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [92] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8498),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(92),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__attribute] = STATE(1793),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(461),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(463),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [93] = {
    [sym_expression_item] = STATE(8703),
    [sym_toplevel_directive] = STATE(8703),
    [sym__structure_item] = STATE(8703),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(93),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(5087),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(479),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [94] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(94),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(5062),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(299),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_end] = ACTIONS(481),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [95] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8622),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(95),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__attribute] = STATE(1804),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(517),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(519),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [96] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8641),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(96),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__attribute] = STATE(1792),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(569),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(571),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [97] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(97),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(5062),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(299),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_end] = ACTIONS(587),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [98] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8657),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(98),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__attribute] = STATE(1560),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(623),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(625),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [99] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8660),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(99),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__attribute] = STATE(1685),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(675),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(677),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [100] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(100),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(5087),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [101] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(101),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(5087),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [102] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(102),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(5087),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(697),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [103] = {
    [sym_expression_item] = STATE(8714),
    [sym_toplevel_directive] = STATE(8714),
    [sym__structure_item] = STATE(8714),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(103),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(5062),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(299),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_end] = ACTIONS(699),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [104] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(104),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(5062),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(299),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_end] = ACTIONS(701),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [105] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13334),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9277),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(105),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_directive] = STATE(8191),
    [sym_tag] = STATE(4695),
    [aux_sym__structure_repeat1] = STATE(5087),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(313),
    [anon_sym_module] = ACTIONS(315),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(317),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(355),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(361),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [106] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8731),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(106),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__attribute] = STATE(1707),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(737),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(739),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [107] = {
    [sym_expression_item] = STATE(13224),
    [sym_toplevel_directive] = STATE(13224),
    [sym__structure_item] = STATE(13224),
    [sym_value_definition] = STATE(13302),
    [sym_external] = STATE(13305),
    [sym_type_definition] = STATE(13305),
    [sym_exception_definition] = STATE(13305),
    [sym_module_definition] = STATE(13305),
    [sym_module_type_definition] = STATE(13305),
    [sym_open_module] = STATE(13305),
    [sym_include_module] = STATE(13305),
    [sym_class_definition] = STATE(13305),
    [sym_class_type_definition] = STATE(13305),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9202),
    [sym__sequence_expression] = STATE(12382),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(107),
    [sym_floating_attribute] = STATE(13305),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym_item_extension] = STATE(13305),
    [sym_quoted_item_extension] = STATE(13305),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_directive] = STATE(8311),
    [sym_tag] = STATE(4471),
    [aux_sym__structure_repeat1] = STATE(5087),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(47),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(59),
    [anon_sym_module] = ACTIONS(61),
    [anon_sym_open] = ACTIONS(63),
    [anon_sym_include] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(115),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(121),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [108] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8674),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(108),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__attribute] = STATE(1554),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(791),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [109] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(9037),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(109),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__attribute] = STATE(1601),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(841),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(843),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [110] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8926),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(110),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__attribute] = STATE(1584),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(893),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(895),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [111] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9189),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(111),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__attribute] = STATE(1700),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [112] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9066),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(112),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__attribute] = STATE(1726),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [113] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9770),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(113),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__attribute] = STATE(1803),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_constraint] = ACTIONS(373),
    [anon_sym_val] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_inherit] = ACTIONS(373),
    [anon_sym_method] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_initializer] = ACTIONS(373),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(959),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [114] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10300),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(114),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__attribute] = STATE(1662),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_constraint] = ACTIONS(373),
    [anon_sym_val] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_inherit] = ACTIONS(373),
    [anon_sym_method] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_initializer] = ACTIONS(373),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(959),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [115] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10089),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(115),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__attribute] = STATE(1667),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_constraint] = ACTIONS(373),
    [anon_sym_val] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_inherit] = ACTIONS(373),
    [anon_sym_method] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_initializer] = ACTIONS(373),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1033),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [116] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10378),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(116),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__attribute] = STATE(1800),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_constraint] = ACTIONS(373),
    [anon_sym_val] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_inherit] = ACTIONS(373),
    [anon_sym_method] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_initializer] = ACTIONS(373),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1033),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [117] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10627),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(117),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__attribute] = STATE(1624),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_COLON_GT] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_COLON2] = ACTIONS(373),
    [anon_sym_DASH_GT] = ACTIONS(373),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_GT_RBRACE] = ACTIONS(369),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [118] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(11127),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(118),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__attribute] = STATE(1788),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_COLON_GT] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_COLON2] = ACTIONS(373),
    [anon_sym_DASH_GT] = ACTIONS(373),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_GT_RBRACE] = ACTIONS(369),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [119] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(11121),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(119),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__attribute] = STATE(1578),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_COLON_GT] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_COLON2] = ACTIONS(373),
    [anon_sym_DASH_GT] = ACTIONS(373),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_GT_RBRACE] = ACTIONS(369),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [120] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11402),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(120),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__attribute] = STATE(1735),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_COLON_GT] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_COLON2] = ACTIONS(373),
    [anon_sym_DASH_GT] = ACTIONS(373),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_GT_RBRACE] = ACTIONS(369),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [121] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8772),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(121),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__attribute] = STATE(1507),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(569),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(571),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [122] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8739),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(122),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__attribute] = STATE(1545),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(517),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(519),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [123] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11723),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11032),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(123),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__attribute] = STATE(1541),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [124] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12409),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(124),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__attribute] = STATE(1528),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [125] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(9058),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(125),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__attribute] = STATE(1511),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(791),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [126] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(9001),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(126),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__attribute] = STATE(1672),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(737),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(739),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [127] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12114),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11032),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(127),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__attribute] = STATE(1572),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [128] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15875),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(128),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20324),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1397),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1399),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1401),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1403),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1407),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1409),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1417),
    [sym_let_and_operator] = ACTIONS(1409),
    [sym_match_operator] = ACTIONS(1419),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [129] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19927),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(129),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1421),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1425),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1429),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1433),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1435),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [130] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15619),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(130),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21311),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1437),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1439),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1441),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1443),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1445),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1447),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1449),
    [sym_let_and_operator] = ACTIONS(1447),
    [sym_match_operator] = ACTIONS(1451),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [131] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18973),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(131),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21311),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1453),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1439),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1441),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1443),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1445),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1447),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1449),
    [sym_let_and_operator] = ACTIONS(1447),
    [sym_match_operator] = ACTIONS(1451),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [132] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15699),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(132),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18904),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1455),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1457),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1459),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1461),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1463),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1465),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1467),
    [sym_let_and_operator] = ACTIONS(1465),
    [sym_match_operator] = ACTIONS(1469),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [133] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20189),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(133),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18904),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1471),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1457),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1459),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1461),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1463),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1465),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1467),
    [sym_let_and_operator] = ACTIONS(1465),
    [sym_match_operator] = ACTIONS(1469),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [134] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15802),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(134),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20608),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1473),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1475),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1477),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1481),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1483),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1485),
    [sym_let_and_operator] = ACTIONS(1483),
    [sym_match_operator] = ACTIONS(1487),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [135] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20889),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(135),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20608),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1489),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1475),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1477),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1479),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1481),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1483),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1485),
    [sym_let_and_operator] = ACTIONS(1483),
    [sym_match_operator] = ACTIONS(1487),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [136] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15495),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(136),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21139),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1491),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1425),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1495),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1497),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1499),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1501),
    [sym_let_and_operator] = ACTIONS(1499),
    [sym_match_operator] = ACTIONS(1503),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [137] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19927),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(137),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21139),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1421),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1425),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1495),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1497),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1499),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1501),
    [sym_let_and_operator] = ACTIONS(1499),
    [sym_match_operator] = ACTIONS(1503),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [138] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15889),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(138),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18891),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1505),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1507),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1509),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1511),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1513),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1515),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1517),
    [sym_let_and_operator] = ACTIONS(1515),
    [sym_match_operator] = ACTIONS(1519),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [139] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18787),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(139),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18891),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1521),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1507),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1509),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1511),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1513),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1515),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1517),
    [sym_let_and_operator] = ACTIONS(1515),
    [sym_match_operator] = ACTIONS(1519),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [140] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15309),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(140),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20454),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1523),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1525),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1527),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1529),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1531),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1533),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1535),
    [sym_let_and_operator] = ACTIONS(1533),
    [sym_match_operator] = ACTIONS(1537),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [141] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21391),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(141),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20454),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1539),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1525),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1527),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1529),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1531),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1533),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1535),
    [sym_let_and_operator] = ACTIONS(1533),
    [sym_match_operator] = ACTIONS(1537),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [142] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15905),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(142),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19311),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1541),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1543),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1545),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1547),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1549),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1551),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1553),
    [sym_let_and_operator] = ACTIONS(1551),
    [sym_match_operator] = ACTIONS(1555),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [143] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19276),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(143),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19311),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1557),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1543),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1545),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1547),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1549),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1551),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1553),
    [sym_let_and_operator] = ACTIONS(1551),
    [sym_match_operator] = ACTIONS(1555),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [144] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15429),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(144),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19244),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1559),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1561),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1563),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1565),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1567),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1569),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1571),
    [sym_let_and_operator] = ACTIONS(1569),
    [sym_match_operator] = ACTIONS(1573),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [145] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19688),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(145),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19244),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1575),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1561),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1563),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1565),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1567),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1569),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1571),
    [sym_let_and_operator] = ACTIONS(1569),
    [sym_match_operator] = ACTIONS(1573),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [146] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15654),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(146),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19569),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1577),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1579),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1581),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1583),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1587),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1589),
    [sym_let_and_operator] = ACTIONS(1587),
    [sym_match_operator] = ACTIONS(1591),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [147] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19790),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(147),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19569),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1593),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1579),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1581),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1583),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1585),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1587),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1589),
    [sym_let_and_operator] = ACTIONS(1587),
    [sym_match_operator] = ACTIONS(1591),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [148] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15805),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(148),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20090),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1595),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1597),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1599),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1603),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1605),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1607),
    [sym_let_and_operator] = ACTIONS(1605),
    [sym_match_operator] = ACTIONS(1609),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [149] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19387),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(149),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20090),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1611),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1597),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1599),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1601),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1603),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1605),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1607),
    [sym_let_and_operator] = ACTIONS(1605),
    [sym_match_operator] = ACTIONS(1609),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [150] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15230),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(150),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20637),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1613),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1615),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1617),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1619),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1621),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1623),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1625),
    [sym_let_and_operator] = ACTIONS(1623),
    [sym_match_operator] = ACTIONS(1627),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [151] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20356),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(151),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20637),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1629),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1615),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1617),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1619),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1621),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1623),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1625),
    [sym_let_and_operator] = ACTIONS(1623),
    [sym_match_operator] = ACTIONS(1627),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [152] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15279),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(152),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21218),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1631),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1633),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1635),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1637),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1639),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1641),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1643),
    [sym_let_and_operator] = ACTIONS(1641),
    [sym_match_operator] = ACTIONS(1645),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [153] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19586),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(153),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21218),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1647),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1633),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1635),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1637),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1639),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1641),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1643),
    [sym_let_and_operator] = ACTIONS(1641),
    [sym_match_operator] = ACTIONS(1645),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [154] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15335),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(154),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20699),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1649),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1651),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1653),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1657),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1659),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1661),
    [sym_let_and_operator] = ACTIONS(1659),
    [sym_match_operator] = ACTIONS(1663),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [155] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19499),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(155),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20699),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1651),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1653),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1657),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1659),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1661),
    [sym_let_and_operator] = ACTIONS(1659),
    [sym_match_operator] = ACTIONS(1663),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [156] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15385),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(156),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20861),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1667),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1669),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1671),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1673),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1675),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1677),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1679),
    [sym_let_and_operator] = ACTIONS(1677),
    [sym_match_operator] = ACTIONS(1681),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [157] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21168),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(157),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20861),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1683),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1669),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1671),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1673),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1675),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1677),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1679),
    [sym_let_and_operator] = ACTIONS(1677),
    [sym_match_operator] = ACTIONS(1681),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [158] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15430),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(158),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19299),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1687),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1689),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1691),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1693),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1695),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1697),
    [sym_let_and_operator] = ACTIONS(1695),
    [sym_match_operator] = ACTIONS(1699),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [159] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21253),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(159),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19299),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1701),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1687),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1689),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1691),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1693),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1695),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1697),
    [sym_let_and_operator] = ACTIONS(1695),
    [sym_match_operator] = ACTIONS(1699),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [160] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15469),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(160),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18928),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1707),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1709),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1711),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1713),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1715),
    [sym_let_and_operator] = ACTIONS(1713),
    [sym_match_operator] = ACTIONS(1717),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [161] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18441),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(161),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18928),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1719),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1707),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1709),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1711),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1713),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1715),
    [sym_let_and_operator] = ACTIONS(1713),
    [sym_match_operator] = ACTIONS(1717),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [162] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15508),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(162),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20652),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1721),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1723),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1725),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1727),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1729),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1731),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1733),
    [sym_let_and_operator] = ACTIONS(1731),
    [sym_match_operator] = ACTIONS(1735),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [163] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19435),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(163),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20652),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1737),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1723),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1725),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1727),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1729),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1731),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1733),
    [sym_let_and_operator] = ACTIONS(1731),
    [sym_match_operator] = ACTIONS(1735),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [164] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15553),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(164),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21376),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1739),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1741),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1743),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1745),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1747),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1749),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1751),
    [sym_let_and_operator] = ACTIONS(1749),
    [sym_match_operator] = ACTIONS(1753),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [165] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12504),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(165),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__attribute] = STATE(1690),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [166] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20929),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(166),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21376),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1761),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1741),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1743),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1745),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1747),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1749),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1751),
    [sym_let_and_operator] = ACTIONS(1749),
    [sym_match_operator] = ACTIONS(1753),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [167] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15597),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(167),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19436),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1763),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1765),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1767),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1771),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1773),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1775),
    [sym_let_and_operator] = ACTIONS(1773),
    [sym_match_operator] = ACTIONS(1777),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [168] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18724),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(168),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19436),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1779),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1765),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1767),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1771),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1773),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1775),
    [sym_let_and_operator] = ACTIONS(1773),
    [sym_match_operator] = ACTIONS(1777),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [169] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15642),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(169),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18777),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1781),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1783),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1785),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1789),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1791),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1793),
    [sym_let_and_operator] = ACTIONS(1791),
    [sym_match_operator] = ACTIONS(1795),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [170] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19140),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(170),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18777),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1797),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1783),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1785),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1789),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1791),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1793),
    [sym_let_and_operator] = ACTIONS(1791),
    [sym_match_operator] = ACTIONS(1795),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [171] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15671),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(171),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19640),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1799),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1801),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1803),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1805),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1807),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1809),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1811),
    [sym_let_and_operator] = ACTIONS(1809),
    [sym_match_operator] = ACTIONS(1813),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [172] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15495),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(172),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1425),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1429),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1433),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1435),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [173] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15700),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(173),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20768),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1819),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1821),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1825),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1827),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1829),
    [sym_let_and_operator] = ACTIONS(1827),
    [sym_match_operator] = ACTIONS(1831),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [174] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19806),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(174),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20768),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1833),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1819),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1821),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1825),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1827),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1829),
    [sym_let_and_operator] = ACTIONS(1827),
    [sym_match_operator] = ACTIONS(1831),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [175] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15734),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(175),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18577),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1835),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1837),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1839),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1841),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1843),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1845),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1847),
    [sym_let_and_operator] = ACTIONS(1845),
    [sym_match_operator] = ACTIONS(1849),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [176] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20246),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(176),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18577),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1851),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1837),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1839),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1841),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1843),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1845),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1847),
    [sym_let_and_operator] = ACTIONS(1845),
    [sym_match_operator] = ACTIONS(1849),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [177] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15771),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(177),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18876),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1853),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1855),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1857),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1861),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1863),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1865),
    [sym_let_and_operator] = ACTIONS(1863),
    [sym_match_operator] = ACTIONS(1867),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [178] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20468),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(178),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18876),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1869),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1855),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1857),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1861),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1863),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1865),
    [sym_let_and_operator] = ACTIONS(1863),
    [sym_match_operator] = ACTIONS(1867),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [179] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15817),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(179),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19275),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1871),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1873),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1875),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1879),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1881),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1883),
    [sym_let_and_operator] = ACTIONS(1881),
    [sym_match_operator] = ACTIONS(1885),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [180] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21034),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(180),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19275),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1873),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1875),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1879),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1881),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1883),
    [sym_let_and_operator] = ACTIONS(1881),
    [sym_match_operator] = ACTIONS(1885),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [181] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15873),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(181),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19644),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1893),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1895),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1897),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1899),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1901),
    [sym_let_and_operator] = ACTIONS(1899),
    [sym_match_operator] = ACTIONS(1903),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [182] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19758),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(182),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19644),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1893),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1895),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1897),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1899),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1901),
    [sym_let_and_operator] = ACTIONS(1899),
    [sym_match_operator] = ACTIONS(1903),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [183] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15207),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(183),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19828),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1907),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1909),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1911),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1913),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1915),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1917),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1919),
    [sym_let_and_operator] = ACTIONS(1917),
    [sym_match_operator] = ACTIONS(1921),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [184] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19198),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(184),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19828),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1923),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1909),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1911),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1913),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1915),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1917),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1919),
    [sym_let_and_operator] = ACTIONS(1917),
    [sym_match_operator] = ACTIONS(1921),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [185] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15220),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(185),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19996),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1927),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1929),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1931),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1933),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1935),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1937),
    [sym_let_and_operator] = ACTIONS(1935),
    [sym_match_operator] = ACTIONS(1939),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [186] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21248),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(186),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19996),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1927),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1929),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1931),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1933),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1935),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1937),
    [sym_let_and_operator] = ACTIONS(1935),
    [sym_match_operator] = ACTIONS(1939),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [187] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15232),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(187),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20018),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1945),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1947),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1949),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1951),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1953),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1955),
    [sym_let_and_operator] = ACTIONS(1953),
    [sym_match_operator] = ACTIONS(1957),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [188] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18487),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(188),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20018),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1945),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1947),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1949),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1951),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1953),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1955),
    [sym_let_and_operator] = ACTIONS(1953),
    [sym_match_operator] = ACTIONS(1957),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [189] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15245),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(189),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20041),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1965),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1967),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1969),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1971),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1973),
    [sym_let_and_operator] = ACTIONS(1971),
    [sym_match_operator] = ACTIONS(1975),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [190] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12535),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11032),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(190),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__attribute] = STATE(1514),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_to] = ACTIONS(373),
    [anon_sym_downto] = ACTIONS(373),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [191] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19678),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(191),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20041),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2029),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1965),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1967),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1969),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1971),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1973),
    [sym_let_and_operator] = ACTIONS(1971),
    [sym_match_operator] = ACTIONS(1975),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [192] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15256),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(192),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20062),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2031),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2033),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2035),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2037),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2039),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2041),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2043),
    [sym_let_and_operator] = ACTIONS(2041),
    [sym_match_operator] = ACTIONS(2045),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [193] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21124),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(193),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20062),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2047),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2033),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2035),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2037),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2039),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2041),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2043),
    [sym_let_and_operator] = ACTIONS(2041),
    [sym_match_operator] = ACTIONS(2045),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [194] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15275),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(194),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20097),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2049),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2051),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2053),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2055),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2057),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2059),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2061),
    [sym_let_and_operator] = ACTIONS(2059),
    [sym_match_operator] = ACTIONS(2063),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [195] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20820),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(195),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20097),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2065),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2051),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2053),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2055),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2057),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2059),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2061),
    [sym_let_and_operator] = ACTIONS(2059),
    [sym_match_operator] = ACTIONS(2063),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [196] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15284),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(196),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20130),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2067),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2069),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2071),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2073),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2075),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2077),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2079),
    [sym_let_and_operator] = ACTIONS(2077),
    [sym_match_operator] = ACTIONS(2081),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [197] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18463),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(197),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20130),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2083),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2069),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2071),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2073),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2075),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2077),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2079),
    [sym_let_and_operator] = ACTIONS(2077),
    [sym_match_operator] = ACTIONS(2081),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [198] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15293),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(198),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20167),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2085),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2087),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2089),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2091),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2093),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2095),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2097),
    [sym_let_and_operator] = ACTIONS(2095),
    [sym_match_operator] = ACTIONS(2099),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [199] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19357),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(199),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20167),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2101),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2087),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2089),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2091),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2093),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2095),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2097),
    [sym_let_and_operator] = ACTIONS(2095),
    [sym_match_operator] = ACTIONS(2099),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [200] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15306),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(200),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20217),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2103),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2105),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2107),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2109),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2111),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2113),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2115),
    [sym_let_and_operator] = ACTIONS(2113),
    [sym_match_operator] = ACTIONS(2117),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [201] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20241),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(201),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20217),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2119),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2105),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2107),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2109),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2111),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2113),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2115),
    [sym_let_and_operator] = ACTIONS(2113),
    [sym_match_operator] = ACTIONS(2117),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [202] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15321),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(202),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20251),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2121),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2123),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2125),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2127),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2129),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2131),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2133),
    [sym_let_and_operator] = ACTIONS(2131),
    [sym_match_operator] = ACTIONS(2135),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [203] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18488),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(203),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20251),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2137),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2123),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2125),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2127),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2129),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2131),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2133),
    [sym_let_and_operator] = ACTIONS(2131),
    [sym_match_operator] = ACTIONS(2135),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [204] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15334),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(204),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20302),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2139),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2141),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2143),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2145),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2147),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2149),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2151),
    [sym_let_and_operator] = ACTIONS(2149),
    [sym_match_operator] = ACTIONS(2153),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [205] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15204),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(205),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18793),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2155),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2157),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2159),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2161),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2163),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2165),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2167),
    [sym_let_and_operator] = ACTIONS(2165),
    [sym_match_operator] = ACTIONS(2169),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [206] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18776),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(206),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20302),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2171),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2141),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2143),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2145),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2147),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2149),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2151),
    [sym_let_and_operator] = ACTIONS(2149),
    [sym_match_operator] = ACTIONS(2153),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [207] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15343),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(207),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20359),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2173),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2175),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2177),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2179),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2181),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2183),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2185),
    [sym_let_and_operator] = ACTIONS(2183),
    [sym_match_operator] = ACTIONS(2187),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [208] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19092),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(208),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20359),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2189),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2175),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2177),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2179),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2181),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2183),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2185),
    [sym_let_and_operator] = ACTIONS(2183),
    [sym_match_operator] = ACTIONS(2187),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [209] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15357),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(209),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20399),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2191),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2193),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2195),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2197),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2199),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2201),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2203),
    [sym_let_and_operator] = ACTIONS(2201),
    [sym_match_operator] = ACTIONS(2205),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [210] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19532),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(210),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20399),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2207),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2193),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2195),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2197),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2199),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2201),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2203),
    [sym_let_and_operator] = ACTIONS(2201),
    [sym_match_operator] = ACTIONS(2205),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [211] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18929),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(211),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(18793),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2209),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2157),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2159),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2161),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2163),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2165),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2167),
    [sym_let_and_operator] = ACTIONS(2165),
    [sym_match_operator] = ACTIONS(2169),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [212] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(15314),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(212),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19518),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2211),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2213),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2215),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2217),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2219),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2221),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2223),
    [sym_let_and_operator] = ACTIONS(2221),
    [sym_match_operator] = ACTIONS(2225),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [213] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19467),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(213),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(20324),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2227),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1399),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1401),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1403),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1407),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1409),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1417),
    [sym_let_and_operator] = ACTIONS(1409),
    [sym_match_operator] = ACTIONS(1419),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [214] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20925),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(214),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19518),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(2213),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(2215),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(2217),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(2219),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(2221),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(2223),
    [sym_let_and_operator] = ACTIONS(2221),
    [sym_match_operator] = ACTIONS(2225),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [215] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19423),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(215),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__infix_operator] = STATE(19640),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(2231),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(1801),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_module] = ACTIONS(1803),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_COLON_COLON] = ACTIONS(1805),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1807),
    [aux_sym_sign_operator_token1] = ACTIONS(1405),
    [sym_hash_operator] = ACTIONS(1809),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1811),
    [sym_let_and_operator] = ACTIONS(1809),
    [sym_match_operator] = ACTIONS(1813),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [216] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12675),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(216),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__attribute] = STATE(1780),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_PIPE_RBRACK] = ACTIONS(369),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [217] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9259),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(217),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__attribute] = STATE(1525),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [218] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9260),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(218),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__attribute] = STATE(1799),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_SEMI_SEMI] = ACTIONS(369),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(373),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_exception] = ACTIONS(373),
    [anon_sym_module] = ACTIONS(373),
    [anon_sym_open] = ACTIONS(373),
    [anon_sym_include] = ACTIONS(373),
    [anon_sym_class] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(369),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [219] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12603),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(219),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__attribute] = STATE(1749),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_do] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [220] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12607),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(220),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__attribute] = STATE(1786),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [221] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12601),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(221),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__attribute] = STATE(1704),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_then] = ACTIONS(373),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [222] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12893),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11032),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(222),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__attribute] = STATE(1500),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [223] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12616),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11032),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(223),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__attribute] = STATE(1547),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_to] = ACTIONS(373),
    [anon_sym_downto] = ACTIONS(373),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [224] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12605),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(224),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__attribute] = STATE(1770),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_with] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [225] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12968),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(225),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__attribute] = STATE(1682),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_do] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [226] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13139),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11032),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(226),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__attribute] = STATE(1666),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [227] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13102),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(227),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__attribute] = STATE(1559),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_then] = ACTIONS(373),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [228] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13121),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(228),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__attribute] = STATE(1795),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_with] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [229] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(12989),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(229),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1647),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_then] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [230] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13110),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(230),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1658),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_with] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [231] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13036),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(231),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(1652),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_do] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [232] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13248),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8476),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(232),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1663),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [233] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12944),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(233),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__attribute] = STATE(1529),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_else] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [234] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13217),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(234),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__attribute] = STATE(1642),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_PIPE] = ACTIONS(373),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [235] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13424),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(235),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1790),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [236] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13441),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(236),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1779),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_with] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [237] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13524),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(237),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1750),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_then] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [238] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13556),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(238),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(1766),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_COLON_COLON] = ACTIONS(369),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_do] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(409),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(105),
    [sym_pow_operator] = ACTIONS(373),
    [sym_mult_operator] = ACTIONS(373),
    [aux_sym_add_operator_token1] = ACTIONS(373),
    [sym_concat_operator] = ACTIONS(369),
    [sym_rel_operator] = ACTIONS(373),
    [sym_and_operator] = ACTIONS(373),
    [sym_or_operator] = ACTIONS(373),
    [sym_assign_operator] = ACTIONS(369),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [239] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10470),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(239),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__attribute] = STATE(1720),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_constraint] = ACTIONS(373),
    [anon_sym_val] = ACTIONS(373),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_inherit] = ACTIONS(373),
    [anon_sym_method] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_initializer] = ACTIONS(373),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(373),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1033),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(369),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [240] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11821),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(240),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__attribute] = STATE(1653),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_COLON_GT] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_COLON2] = ACTIONS(373),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [241] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12562),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9187),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(241),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__attribute] = STATE(1668),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_and] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_in] = ACTIONS(373),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(369),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_let_and_operator] = ACTIONS(369),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [242] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18821),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(242),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(964),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2945),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [243] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19967),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(243),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1106),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2947),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [244] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18821),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(244),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(964),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2949),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [245] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19014),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(245),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1114),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2951),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [246] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18795),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(246),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(758),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2953),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [247] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20158),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(247),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1122),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2955),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [248] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18670),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(248),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(979),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2957),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [249] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18505),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(249),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1130),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2959),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [250] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18955),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(250),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1138),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2961),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [251] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20797),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(251),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1014),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2963),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [252] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19306),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(252),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1146),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2965),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [253] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19650),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(253),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1154),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2967),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [254] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20146),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(254),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1162),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2969),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [255] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18992),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(255),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1023),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2971),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [256] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20374),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(256),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1170),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2973),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [257] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20752),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(257),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1178),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2975),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [258] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21310),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(258),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1186),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2977),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [259] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18492),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(259),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1194),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2979),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [260] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20970),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(260),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1032),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2981),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [261] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21325),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(261),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1202),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2983),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [262] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18815),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(262),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1098),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2985),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [263] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19206),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(263),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1218),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2987),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [264] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18666),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(264),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1041),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2989),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [265] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20843),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(265),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1226),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2991),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [266] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19682),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(266),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1234),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2993),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [267] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19660),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(267),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(992),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2995),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [268] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20063),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(268),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1241),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2997),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [269] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19221),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(269),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1050),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(2999),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [270] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18971),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(270),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1248),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3001),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [271] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19811),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(271),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1255),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3003),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [272] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20840),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(272),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1058),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3005),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [273] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21037),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(273),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1262),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3007),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [274] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18647),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(274),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1269),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3009),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [275] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21012),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(275),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1066),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3011),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [276] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18936),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(276),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1276),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3013),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [277] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21349),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(277),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(910),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [278] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19359),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(278),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1283),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3017),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [279] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19935),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(279),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1074),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3019),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [280] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18822),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(280),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1082),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3021),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [281] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20625),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(281),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1005),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3023),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [282] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13226),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(282),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__attribute] = STATE(1805),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_to] = ACTIONS(373),
    [anon_sym_downto] = ACTIONS(373),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [283] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18470),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(283),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(947),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3025),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [284] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20809),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(284),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1090),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3027),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [285] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19839),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(285),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1210),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(3029),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [286] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17866),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(286),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(659),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [287] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17870),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(287),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(554),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [288] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(288),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [289] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(289),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [290] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(290),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [291] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(291),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [292] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(292),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [293] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(293),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [294] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(294),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [295] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(295),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [296] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(296),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [297] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(297),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [298] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13553),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(298),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1778),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_then] = ACTIONS(373),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [299] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(299),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [300] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(300),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [301] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(301),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [302] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(13081),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_refutation_case] = STATE(13081),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(302),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [303] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(10891),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(10891),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(303),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [304] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(304),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [305] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(305),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [306] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(11178),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(11178),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(306),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [307] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19730),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(307),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(606),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [308] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(308),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [309] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(13059),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_refutation_case] = STATE(13059),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(309),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [310] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(310),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [311] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(311),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [312] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(312),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [313] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13569),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(313),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(1775),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_do] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [314] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(314),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [315] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(11178),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(11178),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(315),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [316] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(316),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [317] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(317),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [318] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13365),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(7967),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(318),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__attribute] = STATE(1679),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [319] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13499),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(319),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1806),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_with] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [320] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(320),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [321] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(10891),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(10891),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(321),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [322] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20397),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(322),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(747),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [323] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(323),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [324] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(324),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [325] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(325),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [326] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(326),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [327] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(327),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [328] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(328),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [329] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(329),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [330] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(11178),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(11178),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(330),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [331] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(331),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [332] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13408),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5533),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(332),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__attribute] = STATE(1665),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [333] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(333),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [334] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13387),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(18679),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(334),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__attribute] = STATE(1773),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_DASH_GT] = ACTIONS(369),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [335] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(335),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [336] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(336),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [337] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(337),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [338] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(338),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [339] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(10891),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(10891),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(339),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [340] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(11178),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(11178),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(340),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [341] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(341),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [342] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(10891),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(10891),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(342),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [343] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(13081),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_refutation_case] = STATE(13081),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(343),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [344] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(13059),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_refutation_case] = STATE(13059),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(344),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_DOT] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [345] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(11178),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(11178),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(345),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [346] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(346),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [347] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(347),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [348] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(348),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [349] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(349),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [350] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(350),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [351] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17689),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(351),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1471),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [352] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(352),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [353] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8453),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8453),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(353),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [354] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8566),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8566),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(354),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [355] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(355),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [356] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(10891),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(10891),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(356),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [357] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(11178),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(11178),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(357),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [358] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18346),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(358),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(849),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [359] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(18361),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(359),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(909),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [360] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(10891),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_refutation_case] = STATE(10891),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(360),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_DOT] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [361] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8449),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_refutation_case] = STATE(8449),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(361),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_DOT] = ACTIONS(3031),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [362] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17227),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(362),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(940),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [363] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17574),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(363),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(946),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [364] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17568),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(364),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1314),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [365] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17365),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(365),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__attribute] = STATE(963),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [366] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17363),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(366),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1422),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [367] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17661),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(367),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(556),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [368] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17964),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(368),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(583),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [369] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18254),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(369),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(609),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [370] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17702),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(370),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(626),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [371] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17724),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(371),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(642),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [372] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8529),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_refutation_case] = STATE(8529),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(372),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(3033),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [373] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17223),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(373),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(676),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [374] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17816),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(374),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(691),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [375] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17250),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(375),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(942),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [376] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17492),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(376),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(719),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [377] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17252),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(377),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(732),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [378] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17701),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(378),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(737),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [379] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18276),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(379),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(743),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [380] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17206),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(380),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(749),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [381] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17271),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(381),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(755),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [382] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17382),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(382),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(761),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [383] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17499),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(383),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(767),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [384] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17611),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(384),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(773),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [385] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17751),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(385),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(779),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [386] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17851),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(386),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(785),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [387] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17962),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(387),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(791),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [388] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17248),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(388),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(941),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [389] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17251),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(389),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(797),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [390] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18136),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(390),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(802),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [391] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18203),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(391),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(808),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [392] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18260),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(392),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(814),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [393] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18390),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(393),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(820),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [394] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17273),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(394),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(825),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [395] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17254),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(395),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(943),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [396] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18303),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(396),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(908),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [397] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20903),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(397),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1294),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [398] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20910),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(398),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1295),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [399] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17265),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(399),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(945),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [400] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(400),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1300),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [401] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19734),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(401),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1301),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [402] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17337),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(402),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(962),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [403] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18557),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(403),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1306),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [404] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18574),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(404),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1307),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [405] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17395),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(405),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(978),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [406] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19156),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(406),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1310),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [407] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19179),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(407),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1311),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [408] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17436),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(408),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(991),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [409] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19551),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(409),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1316),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [410] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19556),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(410),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1317),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [411] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17470),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(411),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1004),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [412] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19917),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(412),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1320),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [413] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19925),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(413),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1321),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [414] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17500),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(414),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1013),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [415] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20092),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(415),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1325),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [416] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20119),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(416),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1326),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [417] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17524),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(417),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1022),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [418] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20398),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(418),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1330),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [419] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20408),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(419),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1331),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [420] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17546),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(420),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1031),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [421] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20827),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(421),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1335),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [422] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20841),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(422),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1336),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [423] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17570),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(423),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1040),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [424] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21174),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(424),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1341),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [425] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21187),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(425),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1342),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [426] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17594),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(426),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(1049),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [427] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18443),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(427),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1346),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [428] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18446),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(428),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1347),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [429] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18513),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(429),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1350),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [430] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18514),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(430),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1351),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [431] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18570),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(431),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1353),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [432] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18571),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(432),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1354),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [433] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18625),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(433),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1357),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [434] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18626),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(434),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1358),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [435] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18680),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(435),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1361),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [436] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18681),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(436),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1362),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [437] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18734),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(437),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1364),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [438] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18735),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(438),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1365),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [439] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18788),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(439),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1368),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [440] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18789),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(440),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1369),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [441] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18842),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(441),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1373),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [442] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18843),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(442),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1374),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [443] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18896),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(443),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1378),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [444] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18897),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(444),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1379),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [445] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18950),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(445),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1383),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [446] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18951),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(446),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1384),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [447] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19004),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(447),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1388),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [448] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19005),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(448),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1389),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [449] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19054),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(449),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1393),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [450] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19055),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(450),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1394),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [451] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19095),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(451),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1398),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [452] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19096),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(452),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1399),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [453] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19135),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(453),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1403),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [454] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19136),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(454),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1404),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [455] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19175),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(455),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1408),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [456] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19176),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(456),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1409),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [457] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19215),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(457),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1411),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [458] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19216),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(458),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1412),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [459] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19255),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(459),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1415),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [460] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19256),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(460),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1416),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [461] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19295),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(461),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1420),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [462] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19296),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(462),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1421),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [463] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19335),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(463),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1425),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [464] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19336),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(464),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1426),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [465] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19375),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(465),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1429),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [466] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19376),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(466),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1430),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [467] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19415),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(467),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1433),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [468] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19416),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(468),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1434),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [469] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19455),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(469),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1438),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [470] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19456),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(470),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1439),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [471] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19494),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(471),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1442),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [472] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19495),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(472),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1443),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [473] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19533),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(473),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1446),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [474] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19534),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(474),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1447),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [475] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19571),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(475),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1451),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [476] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19572),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(476),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1452),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [477] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19609),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(477),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1456),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [478] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19610),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(478),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1457),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [479] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19647),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(479),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1460),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [480] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19648),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(480),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1461),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [481] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19685),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(481),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1464),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [482] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19686),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(482),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1465),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [483] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19722),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(483),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1469),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [484] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19723),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(484),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1470),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [485] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19759),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(485),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1473),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [486] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19760),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(486),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1474),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [487] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19795),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(487),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1477),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [488] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19796),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(488),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1478),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [489] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19830),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(489),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1482),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [490] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19831),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(490),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1483),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [491] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19853),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(491),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1487),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [492] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19854),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(492),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__attribute] = STATE(1488),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [493] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18266),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(493),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__attribute] = STATE(706),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [anon_sym_PERCENT] = ACTIONS(1277),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [494] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(494),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3095),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [495] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(495),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3097),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [496] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(496),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3099),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [497] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(497),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3101),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [498] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(498),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3103),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [499] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(499),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3105),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [500] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(500),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3107),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [501] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(501),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3109),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [502] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(502),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3111),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [503] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(503),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3113),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [504] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(504),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3115),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [505] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(505),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3117),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [506] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(506),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3119),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [507] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(507),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3121),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [508] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(508),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3123),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [509] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13562),
    [sym__sequence_expression] = STATE(20039),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(509),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(3125),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [510] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(510),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3127),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [511] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(511),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [512] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(512),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3131),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [513] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(513),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3133),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [514] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(514),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3135),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [515] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(515),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3137),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [516] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13562),
    [sym__sequence_expression] = STATE(19876),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(516),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(3139),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [517] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(517),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3141),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [518] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(518),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3143),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [519] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(519),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3145),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [520] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(520),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3147),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [521] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(521),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3149),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [522] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13562),
    [sym__sequence_expression] = STATE(19188),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(522),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(3151),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [523] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(523),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3153),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [524] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(524),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [525] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(525),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3157),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [526] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(526),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3159),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [527] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(527),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3161),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [528] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(528),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3163),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [529] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(529),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3165),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [530] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(530),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3167),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [531] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(531),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3169),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [532] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(532),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3171),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [533] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(533),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3173),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [534] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(534),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3175),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [535] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(535),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3177),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [536] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13562),
    [sym__sequence_expression] = STATE(20872),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(536),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_done] = ACTIONS(3179),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [537] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(537),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3181),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [538] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(538),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3183),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [539] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(539),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3185),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [540] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(540),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_RPAREN] = ACTIONS(3187),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [541] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(541),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [542] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(542),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [543] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(543),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [544] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(544),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [545] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(545),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [546] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(546),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [547] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(547),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [548] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(548),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [549] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(549),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [550] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(550),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [551] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8542),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(551),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [552] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(552),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [553] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(553),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [554] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17274),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(554),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [555] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(555),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [556] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17540),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(556),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [557] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(557),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [558] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(558),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [559] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(559),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [560] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19386),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(560),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [561] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(561),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [562] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(562),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [563] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(563),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [564] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(564),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [565] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(565),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [566] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(566),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [567] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(567),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [568] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(568),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [569] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(569),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [570] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10270),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(570),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [571] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(571),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [572] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(572),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [573] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(573),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [574] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(574),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [575] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(575),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [576] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(576),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [577] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(577),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [578] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8584),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(578),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [579] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19426),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(579),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [580] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13475),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(580),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [581] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(581),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [582] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19427),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(582),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [583] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17814),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(583),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [584] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(584),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [585] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(585),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [586] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(586),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [587] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(587),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [588] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(588),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [589] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(589),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [590] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(590),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [591] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(591),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [592] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(592),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [593] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(593),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [594] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(594),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [595] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(595),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [596] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12851),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(596),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [597] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(597),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [598] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(598),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [599] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(599),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [600] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(600),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [601] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(601),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [602] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(602),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [603] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(603),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [604] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8593),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(604),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [605] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(605),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [606] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18494),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(606),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [607] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13418),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(607),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [608] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(608),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [609] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18189),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(609),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [610] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(10883),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(610),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [611] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(611),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [612] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(612),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [613] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(613),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [614] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(614),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [615] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(615),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [616] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(616),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [617] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(617),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [618] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(618),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [619] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(619),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [620] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(620),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [621] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(621),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [622] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12514),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(622),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [623] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(10889),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(623),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [624] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(624),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [625] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(625),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [626] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18329),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(626),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [627] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13364),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(627),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [628] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(628),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [629] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13775),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(629),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [630] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(630),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [631] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(631),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [632] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(632),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [633] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(633),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [634] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(634),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [635] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(635),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [636] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(636),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [637] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(637),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [638] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11831),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(638),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [639] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(639),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [640] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(640),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [641] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(641),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [642] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17893),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(642),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [643] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(643),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [644] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(644),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [645] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10428),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(645),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [646] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(646),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [647] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(647),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [648] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(648),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [649] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(649),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [650] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(650),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [651] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(651),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [652] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(652),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [653] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(653),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [654] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10752),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(654),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [655] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13860),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(655),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [656] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(656),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [657] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(657),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [658] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(658),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [659] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17821),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(659),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [660] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(660),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [661] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(661),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [662] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(662),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [663] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8661),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(663),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [664] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(664),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [665] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(665),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [666] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(666),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [667] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(667),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [668] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(668),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [669] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(669),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [670] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(670),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [671] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12765),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(671),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [672] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(672),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [673] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(673),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [674] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(674),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [675] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(675),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [676] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17694),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(676),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [677] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(677),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [678] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(678),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [679] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(679),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [680] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(680),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [681] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(681),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [682] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(682),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [683] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(683),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [684] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(684),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [685] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(685),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [686] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12620),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(686),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [687] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(687),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [688] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(688),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [689] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8958),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(689),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [690] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(690),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [691] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17583),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(691),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [692] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(692),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [693] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(693),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [694] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(694),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [695] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(695),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [696] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(696),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [697] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(697),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [698] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(698),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [699] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(699),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [700] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(700),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [701] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(701),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [702] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12655),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(702),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [703] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(703),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [704] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(704),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [705] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(705),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [706] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18159),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(706),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [707] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(707),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [708] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(708),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [709] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(709),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [710] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(710),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [711] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(711),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [712] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(712),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [713] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(713),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [714] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(714),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [715] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9797),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(715),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [716] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13256),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(716),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [717] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(717),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [718] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(718),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [719] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18003),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(719),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [720] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(720),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [721] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(721),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [722] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(722),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [723] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(723),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [724] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(724),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [725] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(725),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [726] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(726),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [727] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(727),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [728] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11636),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(728),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [729] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(729),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [730] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(730),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [731] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(731),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [732] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18370),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(732),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [733] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(733),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [734] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12800),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(734),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [735] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(735),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [736] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(17843),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(736),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [737] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17558),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(737),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [738] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(738),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [739] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(739),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [740] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(740),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [741] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(741),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [742] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(742),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [743] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18066),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(743),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [744] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(744),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [745] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8653),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(745),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [746] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(746),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [747] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21411),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(747),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [748] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(748),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [749] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18418),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(749),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [750] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(750),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [751] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(751),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [752] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(752),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [753] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(753),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [754] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(754),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [755] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17241),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(755),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [756] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8894),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(756),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [757] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(757),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [758] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18743),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(758),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [759] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(759),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [760] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(760),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [761] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17349),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(761),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [762] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(762),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [763] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(763),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [764] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(764),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [765] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(765),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [766] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12435),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(766),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [767] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17458),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(767),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [768] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(768),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [769] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20360),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(769),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [770] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(770),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [771] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(771),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [772] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(772),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [773] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17585),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(773),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [774] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(774),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [775] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(775),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [776] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(776),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [777] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10946),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(777),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [778] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(778),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [779] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17708),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(779),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [780] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20405),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(780),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [781] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(781),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [782] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(782),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [783] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(783),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [784] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(784),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [785] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17823),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(785),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [786] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(786),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [787] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(787),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [788] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10893),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(788),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [789] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(789),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [790] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20433),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(790),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [791] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17920),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(791),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [792] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(792),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [793] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(793),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [794] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(794),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [795] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(795),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [796] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(796),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [797] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18054),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(797),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [798] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(798),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [799] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12931),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(799),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [800] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(800),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [801] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(801),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [802] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18183),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(802),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [803] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(803),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [804] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(804),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [805] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(805),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [806] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(806),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [807] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(807),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [808] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18246),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(808),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [809] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8719),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(809),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [810] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18522),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(810),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [811] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(11205),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(811),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [812] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(10851),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(812),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [813] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13769),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(813),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [814] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18374),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(814),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [815] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13837),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(815),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [816] = {
    [sym__simple_expression] = STATE(3261),
    [sym_typed_expression] = STATE(3250),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_labeled_argument] = STATE(4325),
    [sym_prefix_expression] = STATE(3250),
    [sym_hash_expression] = STATE(3250),
    [sym_field_get_expression] = STATE(3250),
    [sym_array_get_expression] = STATE(3250),
    [sym_string_get_expression] = STATE(3250),
    [sym_bigarray_get_expression] = STATE(3250),
    [sym_coercion_expression] = STATE(3250),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(816),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [aux_sym_class_application_repeat1] = STATE(2443),
    [sym__lowercase_identifier] = ACTIONS(3189),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3195),
    [anon_sym_QMARK] = ACTIONS(3195),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_DOT] = ACTIONS(3197),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_in] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(3199),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(405),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(407),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3201),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [817] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13921),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(817),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [818] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13720),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(818),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [819] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13722),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(819),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [820] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17566),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(820),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [821] = {
    [sym__simple_expression] = STATE(3320),
    [sym_typed_expression] = STATE(3312),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_labeled_argument] = STATE(4166),
    [sym_prefix_expression] = STATE(3312),
    [sym_hash_expression] = STATE(3312),
    [sym_field_get_expression] = STATE(3312),
    [sym_array_get_expression] = STATE(3312),
    [sym_string_get_expression] = STATE(3312),
    [sym_bigarray_get_expression] = STATE(3312),
    [sym_coercion_expression] = STATE(3312),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(821),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [aux_sym_class_application_repeat1] = STATE(2446),
    [sym__lowercase_identifier] = ACTIONS(3203),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3205),
    [anon_sym_QMARK] = ACTIONS(3205),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_DOT] = ACTIONS(3207),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_in] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(3209),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(461),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(463),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3211),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [822] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(822),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [823] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(18168),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(823),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [824] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18921),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(824),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [825] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18008),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(825),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [826] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(10968),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(826),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [827] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(10969),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(827),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [828] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13922),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(828),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [829] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13728),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(829),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [830] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13748),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(830),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [831] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13761),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(831),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [832] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13762),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(832),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [833] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13801),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(833),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [834] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13857),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(834),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [835] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(18247),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(835),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [836] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20236),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(836),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [837] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(11154),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(837),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [838] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13854),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(838),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [839] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13882),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(839),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [840] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13757),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(840),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [841] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13717),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(841),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [842] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13754),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(842),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [843] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13796),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(843),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [844] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18818),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(844),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [845] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13871),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(845),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [846] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13872),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(846),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [847] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13709),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(847),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [848] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13836),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(848),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [849] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17595),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(849),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [850] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(850),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [851] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(10800),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(851),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [852] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13412),
    [sym__sequence_expression] = STATE(17466),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(21361),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(852),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [853] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19730),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(853),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [854] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(854),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [855] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(10883),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(855),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [856] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(10889),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(856),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [857] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(11205),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(857),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [858] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(10851),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(858),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [859] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(10968),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(859),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [860] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(10969),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(860),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [861] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8700),
    [sym__sequence_expression] = STATE(11154),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(861),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [862] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(862),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [863] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(863),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [864] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(864),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [865] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(865),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [866] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(866),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [867] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(867),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [868] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(868),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [869] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(869),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [870] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(870),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [871] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13125),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(871),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [872] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(872),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [873] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(873),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [874] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(874),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [875] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(875),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [876] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(876),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [877] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(877),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [878] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(878),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [879] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(879),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [880] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14961),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(880),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [881] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13070),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(881),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [882] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(882),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [883] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(883),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [884] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(884),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [885] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(885),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [886] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(886),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [887] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(887),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [888] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(888),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [889] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(889),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [890] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(890),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [891] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(12933),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(891),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [892] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(892),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [893] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(893),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [894] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(894),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [895] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(895),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [896] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(896),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [897] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(897),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [898] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(898),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [899] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(12987),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(899),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [900] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(900),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [901] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(901),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [902] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(902),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [903] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(903),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [904] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(904),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [905] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(905),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [906] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(906),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [907] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10293),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(907),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [908] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17600),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(908),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [909] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17623),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(909),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [910] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18786),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(910),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [911] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20738),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(911),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [912] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18646),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(912),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [913] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18809),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(913),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [914] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19228),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(914),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [915] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19285),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(915),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [916] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19356),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(916),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [917] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19856),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(917),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [918] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17529),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(918),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [919] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20743),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(919),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [920] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17587),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(920),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [921] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21394),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(921),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [922] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21406),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(922),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [923] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(923),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [924] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(924),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [925] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(925),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [926] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(926),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [927] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(927),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [928] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(928),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [929] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(929),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [930] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13358),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(930),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [931] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(931),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [932] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(932),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [933] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(933),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [934] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(934),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [935] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(935),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [936] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(936),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [937] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(937),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [938] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12695),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(938),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [939] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(939),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [940] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18410),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(940),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [941] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17247),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(941),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [942] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17249),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(942),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [943] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17253),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(943),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [944] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(11228),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(944),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [945] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17973),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(945),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [946] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17982),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(946),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [947] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19848),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(947),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [948] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20901),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(948),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [949] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20907),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(949),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [950] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20908),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(950),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [951] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21177),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(951),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [952] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21178),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(952),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [953] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21180),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(953),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [954] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21212),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(954),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [955] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(18403),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(955),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [956] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21381),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(956),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [957] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(18417),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(957),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [958] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21400),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(958),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [959] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21403),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(959),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [960] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(10810),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(960),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [961] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(10859),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(961),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [962] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17425),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(962),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [963] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17426),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(963),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [964] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19459),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(964),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [965] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19908),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(965),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [966] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(966),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [967] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19918),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(967),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [968] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20191),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(968),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [969] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20197),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(969),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [970] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20198),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(970),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [971] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20245),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(971),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [972] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17522),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(972),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [973] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20401),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(973),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [974] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13422),
    [sym__sequence_expression] = STATE(17528),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(974),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [975] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20500),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(975),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [976] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20529),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(976),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [977] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(11009),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(977),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [978] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17715),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(978),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [979] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18841),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(979),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [980] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18965),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(980),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [981] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18966),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(981),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [982] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18967),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(982),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [983] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19078),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(983),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [984] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19079),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(984),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [985] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19084),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(985),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [986] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19094),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(986),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [987] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19134),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(987),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [988] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19153),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(988),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [989] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19157),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(989),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [990] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(10823),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(990),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [991] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18015),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(991),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [992] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19885),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(992),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [993] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20185),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(993),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [994] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20186),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(994),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [995] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20187),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(995),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [996] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20273),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(996),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [997] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20275),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(997),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [998] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20276),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(998),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [999] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20281),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(999),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1000] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20305),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1000),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1001] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20316),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1001),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1002] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20317),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1002),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1003] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(11109),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1003),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1004] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18273),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1004),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1005] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20780),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1005),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1006] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20878),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1006),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1007] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20885),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1007),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1008] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20886),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1008),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1009] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20964),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1009),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1010] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20965),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1010),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1011] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20966),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1011),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1012] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(11118),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1012),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1013] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17952),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1013),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1014] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20179),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1014),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1015] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18445),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1015),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1016] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18632),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1016),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1017] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18650),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1017),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1018] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20817),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1018),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1019] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20859),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1019),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1020] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21091),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1020),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1021] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(11817),
    [sym__sequence_expression] = STATE(10846),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(10913),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1021),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1022] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17239),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1022),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1023] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18460),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1023),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1024] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21238),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1024),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1025] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21242),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1025),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1026] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21319),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1026),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1027] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18810),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1027),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1028] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18813),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1028),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1029] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18817),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1029),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1030] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1030),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1031] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(18071),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1031),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1032] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20880),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1032),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1033] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18999),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1033),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1034] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19024),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1034),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1035] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19070),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1035),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1036] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20057),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1036),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1037] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20441),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1037),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1038] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20442),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1038),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1039] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14815),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1039),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1040] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17338),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1040),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1041] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18744),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1041),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1042] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19512),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1042),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1043] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19537),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1043),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1044] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19550),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1044),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1045] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20388),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1045),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1046] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20439),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1046),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1047] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20449),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1047),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1048] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1048),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1049] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17912),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1049),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1050] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19528),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1050),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1051] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19757),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1051),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1052] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19765),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1052),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1053] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19767),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1053),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1054] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20096),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1054),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1055] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20111),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1055),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1056] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20115),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1056),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1057] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1057),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1058] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21245),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1058),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1059] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18732),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1059),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1060] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18739),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1060),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1061] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18949),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1061),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1062] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20056),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1062),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1063] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20157),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1063),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1064] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20428),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1064),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1065] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1065),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1066] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19294),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1066),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1067] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20100),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1067),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1068] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20164),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1068),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1069] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20171),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1069),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1070] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20938),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1070),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1071] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20944),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1071),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1072] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20955),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1072),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1073] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1073),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1074] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19067),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1074),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1075] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19479),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1075),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1076] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19509),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1076),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1077] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19538),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1077),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1078] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20152),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1078),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1079] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20307),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1079),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1080] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20326),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1080),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1081] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1081),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1082] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19126),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1082),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1083] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19449),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1083),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1084] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19468),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1084),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1085] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19485),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1085),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1086] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19715),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1086),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1087] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19719),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1087),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1088] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19751),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1088),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1089] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1089),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1090] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21008),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1090),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1091] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21154),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1091),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1092] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21155),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1092),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1093] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21163),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1093),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1094] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21353),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1094),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1095] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21359),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1095),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1096] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21365),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1096),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1097] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12986),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1097),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1098] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20035),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1098),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1099] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20948),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1099),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1100] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20985),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1100),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1101] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21089),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1101),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1102] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18706),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1102),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1103] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18721),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1103),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1104] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18726),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1104),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1105] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8478),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1105),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1106] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21007),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1106),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1107] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21410),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1107),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1108] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21412),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1108),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1109] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18426),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1109),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1110] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18533),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1110),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1111] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18534),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1111),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1112] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18537),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1112),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1113] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14816),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1113),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1114] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19218),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1114),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1115] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19397),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1115),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1116] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19405),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1116),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1117] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19419),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1117),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1118] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19565),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1118),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1119] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19606),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1119),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1120] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19615),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1120),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1121] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8468),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1121),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1122] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20645),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1122),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1123] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20890),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1123),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1124] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20904),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1124),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1125] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20905),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1125),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1126] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21109),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1126),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1127] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21144),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1127),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1128] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21159),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1128),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1129] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8535),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1129),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1130] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18616),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1130),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1131] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18697),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1131),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1132] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18709),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1132),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1133] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18720),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1133),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1134] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18761),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1134),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1135] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18763),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1135),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1136] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18765),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1136),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1137] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8563),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1137),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1138] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19053),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1138),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1139] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19127),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1139),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1140] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19128),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1140),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1141] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19130),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1141),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1142] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19170),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1142),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1143] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19173),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1143),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1144] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19174),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1144),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1145] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8448),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1145),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1146] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19382),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1146),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1147] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19418),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1147),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1148] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19420),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1148),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1149] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19421),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1149),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1150] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19461),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1150),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1151] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19462),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1151),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1152] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19463),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1152),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1153] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8451),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1153),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1154] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19743),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1154),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1155] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19800),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1155),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1156] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19801),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1156),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1157] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19802),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1157),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1158] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19847),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1158),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1159] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19850),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1159),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1160] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19852),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1160),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1161] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8452),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1161),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1162] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20211),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1162),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1163] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20242),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1163),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1164] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20243),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1164),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1165] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20244),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1165),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1166] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20264),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1166),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1167] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20266),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1167),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1168] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20269),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1168),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1169] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12615),
    [sym__sequence_expression] = STATE(8444),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8502),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1169),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1170] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20431),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1170),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1171] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20459),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1171),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1172] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20460),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1172),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1173] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20463),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1173),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1174] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20494),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1174),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1175] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20505),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1175),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1176] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20506),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1176),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1177] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1177),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1178] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20919),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1178),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1179] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21022),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1179),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1180] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21025),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1180),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1181] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21026),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1181),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1182] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21063),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1182),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1183] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21066),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1183),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1184] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21076),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1184),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1185] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1185),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1186] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21382),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1186),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1187] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21184),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1187),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1188] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19066),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1188),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1189] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18714),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1189),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1190] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21219),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1190),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1191] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18779),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1191),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1192] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19679),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1192),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1193] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1193),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1194] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21244),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1194),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1195] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19020),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1195),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1196] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19036),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1196),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1197] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19043),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1197),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1198] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19523),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1198),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1199] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19531),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1199),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1200] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19563),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1200),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1201] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1201),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1202] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18750),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1202),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1203] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21068),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1203),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1204] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21169),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1204),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1205] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21204),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1205),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1206] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18635),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1206),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1207] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18637),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1207),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1208] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18667),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1208),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1209] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1209),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1210] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20918),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1210),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1211] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18451),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1211),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1212] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18455),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1212),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1213] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18457),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1213),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1214] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18641),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1214),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1215] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18658),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1215),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1216] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18664),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1216),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1217] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1217),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1218] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19422),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1218),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1219] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19616),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1219),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1220] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19638),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1220),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1221] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19639),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1221),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1222] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19824),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1222),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1223] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19881),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1223),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1224] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19884),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1224),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1225] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1225),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1226] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20994),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1226),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1227] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21104),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1227),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1228] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21105),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1228),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1229] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21110),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1229),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1230] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21167),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1230),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1231] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21175),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1231),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1232] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21179),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1232),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1233] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8800),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1233),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1234] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19705),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1234),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1235] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20300),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1235),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1236] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20312),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1236),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1237] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20392),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1237),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1238] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18600),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1238),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1239] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18629),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1239),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1240] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18671),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1240),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1241] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21125),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1241),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1242] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(21395),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1242),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1243] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18432),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1243),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1244] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18452),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1244),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1245] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18518),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1245),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1246] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18524),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1246),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1247] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18526),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1247),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1248] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19208),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1248),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1249] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19346),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1249),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1250] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19350),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1250),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1251] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19351),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1251),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1252] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19432),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1252),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1253] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19452),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1253),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1254] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19458),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1254),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1255] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(20031),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1255),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1256] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20218),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1256),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1257] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20222),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1257),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1258] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20225),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1258),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1259] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20349),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1259),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1260] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20350),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1260),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1261] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(20379),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1261),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1262] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(21360),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1262),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1263] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18474),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1263),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1264] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18477),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1264),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1265] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18482),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1265),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1266] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18503),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1266),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1267] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18506),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1267),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1268] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18509),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1268),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1269] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(18719),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1269),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1270] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18760),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1270),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1271] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18767),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1271),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1272] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18768),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1272),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1273] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18797),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1273),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1274] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18804),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1274),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1275] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(18805),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1275),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1276] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19021),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1276),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1277] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19073),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1277),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1278] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19086),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1278),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1279] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19089),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1279),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1280] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19146),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1280),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1281] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19158),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1281),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1282] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19166),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1282),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1283] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13470),
    [sym__sequence_expression] = STATE(19448),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1283),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1284] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19524),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1284),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1285] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19525),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1285),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1286] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19530),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1286),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1287] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19582),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1287),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1288] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19595),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1288),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1289] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19601),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1289),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1290] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1290),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1291] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1291),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1292] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1292),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1293] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20903),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1293),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1294] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21071),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1294),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1295] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21080),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1295),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1296] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8730),
    [sym__sequence_expression] = STATE(10800),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(1296),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1297] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(17466),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1297),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1298] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14865),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1298),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1299] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19703),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1299),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1300] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20009),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1300),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1301] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20019),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1301),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1302] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14870),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1302),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1303] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9135),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1303),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1304] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14908),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1304),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1305] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18557),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1305),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1306] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18699),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1306),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1307] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18701),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1307),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1308] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14912),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1308),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1309] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19156),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1309),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1310] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19231),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1310),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1311] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19235),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1311),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1312] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12550),
    [sym__sequence_expression] = STATE(14930),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1312),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1313] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1313),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1314] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17625),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1314),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1315] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19551),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1315),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1316] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19626),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1316),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1317] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19630),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1317),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1318] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(10800),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1318),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1319] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19917),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1319),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1320] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19953),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1320),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1321] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19955),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1321),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1322] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1322),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1323] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1323),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1324] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20092),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1324),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1325] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20190),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1325),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1326] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20194),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1326),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1327] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(10883),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1327),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1328] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(10889),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1328),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1329] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20398),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1329),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1330] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20455),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1330),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1331] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20458),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1331),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1332] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(11205),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1332),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1333] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(10851),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1333),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1334] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20827),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1334),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1335] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20906),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1335),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1336] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(20917),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1336),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1337] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(10968),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1337),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1338] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(10969),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1338),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1339] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8887),
    [sym__sequence_expression] = STATE(11154),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1339),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1340] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21174),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1340),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1341] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21233),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1341),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1342] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(21239),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1342),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1343] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1343),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1344] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1344),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1345] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18443),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1345),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1346] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18459),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1346),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1347] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18461),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1347),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1348] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9124),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1348),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1349] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18513),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1349),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1350] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18527),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1350),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1351] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18528),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1351),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1352] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18570),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1352),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1353] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18583),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1353),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1354] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18584),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1354),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1355] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1355),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1356] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18625),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1356),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1357] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18638),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1357),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1358] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18639),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1358),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1359] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1359),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1360] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18680),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1360),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1361] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18693),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1361),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1362] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18694),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1362),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1363] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18734),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1363),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1364] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18747),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1364),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1365] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18748),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1365),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1366] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1366),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1367] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18788),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1367),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1368] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18801),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1368),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1369] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18802),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1369),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1370] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1370),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1371] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1371),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1372] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18842),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1372),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1373] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18855),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1373),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1374] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18856),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1374),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1375] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1375),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1376] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1376),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1377] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18896),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1377),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1378] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18909),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1378),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1379] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18910),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1379),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1380] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1380),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1381] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1381),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1382] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18950),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1382),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1383] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18963),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1383),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1384] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(18964),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1384),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1385] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(18216),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1385),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1386] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13030),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1386),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1387] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19004),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1387),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1388] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19017),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1388),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1389] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19018),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1389),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1390] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8464),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1390),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1391] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8486),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1391),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1392] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19054),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1392),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1393] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19064),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1393),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1394] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19065),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1394),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1395] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8490),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1395),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1396] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8511),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1396),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1397] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19095),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1397),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1398] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19104),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1398),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1399] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19105),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1399),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1400] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8559),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1400),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1401] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8471),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1401),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1402] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19135),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1402),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1403] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19144),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1403),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1404] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19145),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1404),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1405] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8475),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1405),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1406] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8488),
    [sym__sequence_expression] = STATE(8541),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1406),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1407] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19175),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1407),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1408] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19184),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1408),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1409] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19185),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1409),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1410] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19215),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1410),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1411] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19224),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1411),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1412] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19225),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1412),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1413] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11448),
    [sym__sequence_expression] = STATE(8426),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1413),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1414] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19255),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1414),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1415] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19264),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1415),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1416] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19265),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1416),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1417] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1417),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1418] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10397),
    [sym__sequence_expression] = STATE(13908),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1418),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1419] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19295),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1419),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1420] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19304),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1420),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1421] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19305),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1421),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1422] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17200),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1422),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1423] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(18212),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1423),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1424] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19335),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1424),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1425] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19344),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1425),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1426] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19345),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1426),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1427] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(10800),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1427),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1428] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19375),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1428),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1429] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19384),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1429),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1430] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19385),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1430),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1431] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1431),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1432] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19415),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1432),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1433] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19424),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1433),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1434] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19425),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1434),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1435] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1435),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1436] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(10883),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1436),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1437] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19455),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1437),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1438] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19464),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1438),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1439] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19465),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1439),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1440] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(10889),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1440),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1441] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19494),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1441),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1442] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19503),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1442),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1443] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19504),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1443),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1444] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(11205),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1444),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1445] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19533),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1445),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1446] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19542),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1446),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1447] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19543),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1447),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1448] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(10851),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1448),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1449] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(10968),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1449),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1450] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19571),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1450),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1451] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19580),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1451),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1452] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19581),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1452),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1453] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(10969),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1453),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1454] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8983),
    [sym__sequence_expression] = STATE(11154),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1454),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1455] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19609),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1455),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1456] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19618),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1456),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1457] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19619),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1457),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1458] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1458),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1459] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19647),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1459),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1460] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19656),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1460),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1461] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19657),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1461),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1462] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(17827),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1462),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1463] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19685),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1463),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1464] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19694),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1464),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1465] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19695),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1465),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1466] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8430),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1466),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1467] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13446),
    [sym__sequence_expression] = STATE(8178),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1467),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1468] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19722),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1468),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1469] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19731),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1469),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1470] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19732),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1470),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1471] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13530),
    [sym__sequence_expression] = STATE(17205),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1471),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1472] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19759),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1472),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1473] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19768),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1473),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1474] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19769),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1474),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1475] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8192),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1475),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1476] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19795),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1476),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1477] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19804),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1477),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1478] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19805),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1478),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1479] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8313),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1479),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1480] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8330),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1480),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1481] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19830),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1481),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1482] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19835),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1482),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1483] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19836),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1483),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1484] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8333),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1484),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1485] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13064),
    [sym__sequence_expression] = STATE(8431),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9160),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1485),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1486] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19853),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1486),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1487] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19858),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1487),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1488] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13416),
    [sym__sequence_expression] = STATE(19859),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1488),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1489] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(18147),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1489),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1490] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(18152),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1490),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1491] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(18186),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1491),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1492] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13016),
    [sym__sequence_expression] = STATE(18190),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(8016),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1492),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1493] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12220),
    [sym__sequence_expression] = STATE(19916),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5468),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1493),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1494] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13033),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1494),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3213),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1495] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1495),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3215),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1496] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1496),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3217),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1497] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13316),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1497),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3219),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1498] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1498),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3221),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1499] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1499),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3223),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1500] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12895),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11105),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(1500),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1501] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13060),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1501),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3225),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1502] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13039),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1502),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3227),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1503] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13055),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1503),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3229),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1504] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13272),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1504),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1505] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13293),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1505),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3233),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1506] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13062),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1506),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3235),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1507] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8678),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(1507),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1508] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1508),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3237),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1509] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1509),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3239),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1510] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13318),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1510),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1511] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8912),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1511),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1512] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1512),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3243),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1513] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1513),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3245),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1514] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12540),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11105),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(1514),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1515] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1515),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3247),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1516] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13122),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1516),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3249),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1517] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13150),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1517),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3251),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1518] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1518),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3253),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1519] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1519),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3255),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1520] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1520),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3257),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1521] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1521),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3259),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1522] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1522),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3261),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1523] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1523),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3263),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1524] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1524),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3265),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1525] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9213),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1525),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1526] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1526),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3267),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1527] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1527),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3269),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1528] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12410),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(1528),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1529] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12953),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1529),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1530] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13204),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1530),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3271),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1531] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13205),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1531),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3273),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1532] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1532),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3275),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1533] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1533),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3277),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1534] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1534),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3279),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1535] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1535),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3281),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1536] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1536),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3283),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1537] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1537),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3285),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1538] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1538),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3287),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1539] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1539),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3289),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1540] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1540),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3291),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1541] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11735),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11105),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(1541),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1542] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1542),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3293),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1543] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13246),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1543),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3295),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1544] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13251),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1544),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3297),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1545] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8729),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(1545),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1546] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1546),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3299),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1547] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12656),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11105),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1547),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1548] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13275),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1548),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3301),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1549] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1549),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3303),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1550] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1550),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3305),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1551] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13312),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1551),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3307),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1552] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1552),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3309),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1553] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1553),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3311),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1554] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8761),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1554),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1555] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13288),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1555),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3313),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1556] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13298),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1556),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3315),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1557] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1557),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3317),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1558] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13341),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1558),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3319),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1559] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13207),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1559),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1560] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8658),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(1560),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1561] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1561),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3321),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1562] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1562),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3323),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1563] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1563),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3325),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1564] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1564),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3327),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1565] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1565),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3329),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1566] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1566),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3331),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1567] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13324),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1567),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3333),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1568] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13331),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1568),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3335),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1569] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13252),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1569),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3337),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1570] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1570),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3339),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1571] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1571),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3341),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1572] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12115),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11105),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1572),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1573] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1573),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3343),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1574] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1574),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3345),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1575] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13254),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1575),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3347),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1576] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1576),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3349),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1577] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1577),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3351),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1578] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(11129),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(1578),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1579] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13258),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1579),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3353),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1580] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13265),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1580),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3355),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1581] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8457),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1581),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1582] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1582),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3357),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1583] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1583),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3359),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1584] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8929),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(1584),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1585] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1585),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3361),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1586] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1586),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3363),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1587] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1587),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3365),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1588] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1588),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3367),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1589] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1589),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3369),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1590] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1590),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3371),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1591] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12945),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1591),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3373),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1592] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12947),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1592),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3375),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1593] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13307),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1593),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3377),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1594] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12955),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1594),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3379),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1595] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12959),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1595),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3381),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1596] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13319),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1596),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3383),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1597] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1597),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3385),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1598] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1598),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3387),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1599] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12984),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1599),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3389),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1600] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12994),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1600),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3391),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1601] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(9042),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(1601),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1602] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1602),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3393),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1603] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1603),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3395),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1604] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1604),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3397),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1605] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13098),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1605),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3399),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1606] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13099),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1606),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3401),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1607] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13170),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1607),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3403),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1608] = {
    [sym__simple_expression] = STATE(3662),
    [sym_typed_expression] = STATE(3632),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_labeled_argument] = STATE(4470),
    [sym_prefix_expression] = STATE(3632),
    [sym_hash_expression] = STATE(3632),
    [sym_field_get_expression] = STATE(3632),
    [sym_array_get_expression] = STATE(3632),
    [sym_string_get_expression] = STATE(3632),
    [sym_bigarray_get_expression] = STATE(3632),
    [sym_coercion_expression] = STATE(3632),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(1608),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [aux_sym_class_application_repeat1] = STATE(2452),
    [sym__lowercase_identifier] = ACTIONS(3405),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3407),
    [anon_sym_QMARK] = ACTIONS(3407),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_DOT] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_POUND] = ACTIONS(3411),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(623),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(625),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3413),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1609] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1609),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3415),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1610] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1610),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3417),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1611] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1611),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3419),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1612] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1612),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3421),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1613] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1613),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3423),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1614] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1614),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1615] = {
    [sym__simple_expression] = STATE(3531),
    [sym_typed_expression] = STATE(3522),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_labeled_argument] = STATE(4513),
    [sym_prefix_expression] = STATE(3522),
    [sym_hash_expression] = STATE(3522),
    [sym_field_get_expression] = STATE(3522),
    [sym_array_get_expression] = STATE(3522),
    [sym_string_get_expression] = STATE(3522),
    [sym_bigarray_get_expression] = STATE(3522),
    [sym_coercion_expression] = STATE(3522),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(1615),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [aux_sym_class_application_repeat1] = STATE(2457),
    [sym__lowercase_identifier] = ACTIONS(3427),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3429),
    [anon_sym_QMARK] = ACTIONS(3429),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_DOT] = ACTIONS(3431),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_POUND] = ACTIONS(3433),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(675),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(677),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3435),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1616] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1616),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3437),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1617] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1617),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3439),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1618] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1618),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3441),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1619] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1619),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3443),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1620] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13194),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1620),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3445),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1621] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13202),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1621),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3447),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1622] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1622),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3449),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1623] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1623),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1624] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10731),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(1624),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1625] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1625),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3453),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1626] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1626),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3455),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1627] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1627),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3457),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1628] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1628),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3459),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1629] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1629),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3461),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1630] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1630),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3463),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1631] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1631),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3465),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1632] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12995),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1632),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3467),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1633] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13266),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1633),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3469),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1634] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13271),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1634),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3471),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1635] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13003),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1635),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3473),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1636] = {
    [sym__simple_expression] = STATE(3648),
    [sym_typed_expression] = STATE(3557),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_labeled_argument] = STATE(4699),
    [sym_prefix_expression] = STATE(3557),
    [sym_hash_expression] = STATE(3557),
    [sym_field_get_expression] = STATE(3557),
    [sym_array_get_expression] = STATE(3557),
    [sym_string_get_expression] = STATE(3557),
    [sym_bigarray_get_expression] = STATE(3557),
    [sym_coercion_expression] = STATE(3557),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(1636),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [aux_sym_class_application_repeat1] = STATE(2456),
    [sym__lowercase_identifier] = ACTIONS(3475),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3477),
    [anon_sym_QMARK] = ACTIONS(3477),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_DOT] = ACTIONS(3479),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_in] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(569),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(571),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3483),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1637] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1637),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3485),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1638] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1638),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3487),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1639] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1639),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3489),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1640] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1640),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3491),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1641] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1641),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3493),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1642] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13218),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1642),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1643] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1643),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3495),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1644] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12999),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1644),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3497),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1645] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13348),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1645),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3499),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1646] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13350),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1646),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3501),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1647] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13028),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1647),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1648] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1648),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3503),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1649] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1649),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3505),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1650] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1650),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3507),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1651] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1651),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3509),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1652] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13056),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1652),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1653] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11848),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1653),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1654] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1654),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3511),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1655] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1655),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3513),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1656] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1656),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3515),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1657] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1657),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3517),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1658] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13193),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1658),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1659] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1659),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3519),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1660] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12929),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1660),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3521),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1661] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12934),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1661),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3523),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1662] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10013),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(1662),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1663] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13297),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1663),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1664] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1664),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3525),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1665] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13518),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1665),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1666] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(12998),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(11105),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(1666),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1667] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10090),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1667),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1668] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12421),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1668),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1669] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1669),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3527),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1670] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13035),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1670),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3529),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1671] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1671),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3531),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1672] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(9050),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1672),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1673] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1673),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3533),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1674] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13089),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1674),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3535),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1675] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12950),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1675),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3537),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1676] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12954),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1676),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3539),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1677] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13214),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1677),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3541),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1678] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13092),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1678),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3543),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1679] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13549),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(1679),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1680] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1680),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3545),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1681] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1681),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3547),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1682] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12981),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1682),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1683] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1683),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3549),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1684] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1684),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3551),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1685] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8663),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(1685),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1686] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12966),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1686),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3553),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1687] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12967),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1687),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3555),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1688] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1688),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3557),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1689] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1689),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3559),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1690] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12437),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(1690),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1691] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1691),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3561),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1692] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1692),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3563),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1693] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1693),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3565),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1694] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1694),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3567),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1695] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1695),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3569),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1696] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1696),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3571),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1697] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12973),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1697),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3573),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1698] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12979),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1698),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3575),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1699] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1699),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3577),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1700] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9067),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1700),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1701] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1701),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3579),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1702] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1702),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3581),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1703] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1703),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3583),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1704] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12602),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1704),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1705] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1705),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3585),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1706] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1706),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3587),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1707] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8754),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1707),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1708] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12991),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1708),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3589),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1709] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12993),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1709),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3591),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1710] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1710),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3593),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1711] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1711),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3595),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1712] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13067),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1712),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3597),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1713] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1713),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3599),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1714] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1714),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3601),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1715] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13069),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1715),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3603),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1716] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1716),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3605),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1717] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1717),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3607),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1718] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12997),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1718),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3609),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1719] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1719),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3611),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1720] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10426),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1720),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1721] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13011),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1721),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3613),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1722] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13002),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1722),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3615),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1723] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13012),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1723),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3617),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1724] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1724),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3619),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1725] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1725),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3621),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1726] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9112),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1726),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1727] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1727),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3623),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1728] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1728),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3625),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1729] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13154),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1729),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3627),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1730] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1730),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3629),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1731] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1731),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3631),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1732] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1732),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3633),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1733] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13027),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1733),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3635),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1734] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13029),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1734),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3637),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1735] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11404),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1735),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1736] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1736),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3639),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1737] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1737),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3641),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1738] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1738),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3643),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1739] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1739),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3645),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1740] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1740),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3647),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1741] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1741),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3649),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1742] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1742),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3651),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1743] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1743),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3653),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1744] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1744),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3655),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1745] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1745),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3657),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1746] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13053),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1746),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3659),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1747] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13054),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1747),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1748] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1748),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3663),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1749] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12604),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1749),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1750] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13534),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1750),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1751] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1751),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3665),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1752] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1752),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3667),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1753] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1753),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3669),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1754] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1754),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3671),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1755] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1755),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3673),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1756] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1756),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3675),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1757] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1757),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3677),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1758] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13107),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1758),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3679),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1759] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13118),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1759),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3681),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1760] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1760),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1761] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13227),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1761),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3685),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1762] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13255),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1762),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3687),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1763] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1763),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3689),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1764] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1764),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3691),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1765] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1765),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3693),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1766] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13568),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1766),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1767] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1767),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3695),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1768] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1768),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3697),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1769] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1769),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3699),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1770] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12606),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1770),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1771] = {
    [sym__simple_expression] = STATE(3674),
    [sym_typed_expression] = STATE(3757),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_labeled_argument] = STATE(4505),
    [sym_prefix_expression] = STATE(3757),
    [sym_hash_expression] = STATE(3757),
    [sym_field_get_expression] = STATE(3757),
    [sym_array_get_expression] = STATE(3757),
    [sym_string_get_expression] = STATE(3757),
    [sym_bigarray_get_expression] = STATE(3757),
    [sym_coercion_expression] = STATE(3757),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(1771),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [aux_sym_class_application_repeat1] = STATE(2451),
    [sym__lowercase_identifier] = ACTIONS(3701),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_DOT] = ACTIONS(3705),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_in] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(3707),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(517),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(519),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3709),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1772] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13245),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1772),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3711),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1773] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13398),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(20805),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1773),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1774] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13253),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1774),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3713),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1775] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13420),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1775),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1776] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1776),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3715),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1777] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1777),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3717),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1778] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13367),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1778),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1779] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13370),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1779),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1780] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12676),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(1780),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1781] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1781),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3719),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1782] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1782),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3721),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1783] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1783),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3723),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1784] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1784),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3725),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1785] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1785),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3727),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1786] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12608),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1786),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1787] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1787),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3729),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1788] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(11179),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(1788),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1789] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13313),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1789),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3731),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1790] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13447),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1790),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1791] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13314),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1791),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3733),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1792] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8642),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(1792),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1793] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8503),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1793),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1794] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13166),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1794),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3735),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1795] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13176),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(9060),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1795),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1796] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1796),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3737),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1797] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1797),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3739),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1798] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1798),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3741),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1799] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9244),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1799),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1800] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10344),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1800),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1801] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1801),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3743),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1802] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1802),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3745),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1803] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9771),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym__sequence_expression_anonymous] = STATE(8530),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(1803),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1804] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8629),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(1804),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1805] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(13162),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym__sequence_expression_anonymous] = STATE(7730),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(1805),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1806] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13533),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym__sequence_expression_anonymous] = STATE(5471),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1806),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1807] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12976),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1807),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3747),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1808] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12977),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1808),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3749),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1809] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13351),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1809),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3751),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1810] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13360),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1810),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3753),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1811] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(1811),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3755),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1812] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12932),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1812),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1813] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8680),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1813),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1814] = {
    [sym__simple_expression] = STATE(4025),
    [sym_typed_expression] = STATE(3882),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_labeled_argument] = STATE(4773),
    [sym_prefix_expression] = STATE(3882),
    [sym_hash_expression] = STATE(3882),
    [sym_field_get_expression] = STATE(3882),
    [sym_array_get_expression] = STATE(3882),
    [sym_string_get_expression] = STATE(3882),
    [sym_bigarray_get_expression] = STATE(3882),
    [sym_coercion_expression] = STATE(3882),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(1814),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [aux_sym_class_application_repeat1] = STATE(2458),
    [sym__lowercase_identifier] = ACTIONS(3757),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3759),
    [anon_sym_QMARK] = ACTIONS(3759),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_DOT] = ACTIONS(3761),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_POUND] = ACTIONS(3763),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(791),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3765),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1815] = {
    [sym__simple_expression] = STATE(4078),
    [sym_typed_expression] = STATE(4014),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_labeled_argument] = STATE(4770),
    [sym_prefix_expression] = STATE(4014),
    [sym_hash_expression] = STATE(4014),
    [sym_field_get_expression] = STATE(4014),
    [sym_array_get_expression] = STATE(4014),
    [sym_string_get_expression] = STATE(4014),
    [sym_bigarray_get_expression] = STATE(4014),
    [sym_coercion_expression] = STATE(4014),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1815),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [aux_sym_class_application_repeat1] = STATE(2459),
    [sym__lowercase_identifier] = ACTIONS(3767),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3769),
    [anon_sym_QMARK] = ACTIONS(3769),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_DOT] = ACTIONS(3771),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_POUND] = ACTIONS(3773),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(737),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(739),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3775),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1816] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8909),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(1816),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1817] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13001),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1817),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1818] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13034),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1818),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1819] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13144),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(13436),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1819),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1820] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13151),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1820),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1821] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13153),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1821),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1822] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13159),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1822),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1823] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13160),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1823),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1824] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13161),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1824),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1825] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(12919),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1825),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1826] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13164),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1826),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1827] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13165),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1827),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1828] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13169),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1828),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1829] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13173),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1829),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1830] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9127),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1830),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1831] = {
    [sym_value_definition] = STATE(19472),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13198),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(19293),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6760),
    [sym_array_get_expression] = STATE(6760),
    [sym_string_get_expression] = STATE(6760),
    [sym_bigarray_get_expression] = STATE(6760),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(1831),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(1818),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(19310),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2671),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2675),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2699),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1832] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13257),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1832),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1833] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13212),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(13478),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1833),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1834] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13220),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1834),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1835] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13221),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1835),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1836] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13228),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1836),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1837] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13229),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1837),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1838] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13230),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1838),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1839] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13231),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1839),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1840] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13233),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1840),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1841] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13234),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1841),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1842] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13235),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1842),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1843] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13236),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1843),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1844] = {
    [sym_value_definition] = STATE(20010),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13250),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(19904),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6761),
    [sym_array_get_expression] = STATE(6761),
    [sym_string_get_expression] = STATE(6761),
    [sym_bigarray_get_expression] = STATE(6761),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(1844),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(1832),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(19905),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2771),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2775),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2779),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2803),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1845] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13111),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1845),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1846] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13280),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(13520),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1846),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1847] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13282),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1847),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1848] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13284),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1848),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1849] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13285),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1849),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1850] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13286),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1850),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1851] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13287),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1851),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1852] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13290),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1852),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1853] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13294),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1853),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1854] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13299),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1854),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1855] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13300),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1855),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1856] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13304),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1856),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1857] = {
    [sym_value_definition] = STATE(18899),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13310),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(18854),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6762),
    [sym_array_get_expression] = STATE(6762),
    [sym_string_get_expression] = STATE(6762),
    [sym_bigarray_get_expression] = STATE(6762),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(1857),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(1845),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(18859),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2719),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2723),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2727),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2751),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1858] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13215),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1858),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1859] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13330),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(13560),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1859),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1860] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13333),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1860),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1861] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13335),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1861),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1862] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13336),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1862),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1863] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13337),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1863),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1864] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13338),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1864),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1865] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13340),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1865),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1866] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13344),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1866),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1867] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13345),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1867),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1868] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13349),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1868),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1869] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13352),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1869),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1870] = {
    [sym_value_definition] = STATE(19604),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13136),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(19555),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6763),
    [sym_array_get_expression] = STATE(6763),
    [sym_string_get_expression] = STATE(6763),
    [sym_bigarray_get_expression] = STATE(6763),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(1870),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(1858),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(19566),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2823),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2829),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2833),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2855),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1871] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10236),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1871),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1872] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(9993),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(10320),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1872),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1873] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(9994),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1873),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1874] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(9996),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1874),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1875] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10002),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1875),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1876] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10003),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1876),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1877] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10004),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1877),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1878] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10005),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1878),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1879] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10006),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1879),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1880] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10007),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1880),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1881] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10008),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1881),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1882] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10009),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1882),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1883] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9085),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(9198),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1883),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1884] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9092),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1884),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1885] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9084),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1885),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1886] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9132),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1886),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1887] = {
    [sym_value_definition] = STATE(21231),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10016),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21215),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4991),
    [sym_array_get_expression] = STATE(4991),
    [sym_string_get_expression] = STATE(4991),
    [sym_bigarray_get_expression] = STATE(4991),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(1887),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(1871),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21216),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1011),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1015),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1017),
    [anon_sym_function] = ACTIONS(1019),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1043),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1888] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9134),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1888),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1889] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9137),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1889),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1890] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9068),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1890),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1891] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9082),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1891),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1892] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9078),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1892),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1893] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9087),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1893),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1894] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9088),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1894),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1895] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13116),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1895),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1896] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13109),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(13458),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1896),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1897] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13112),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1897),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1898] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13113),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1898),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1899] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13114),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1899),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1900] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13115),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1900),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1901] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13137),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1901),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1902] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13138),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1902),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1903] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13145),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1903),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1904] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13155),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1904),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1905] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13172),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1905),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1906] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13174),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1906),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1907] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13195),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1907),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1908] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12902),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1908),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1909] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12583),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(13240),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1909),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1910] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12584),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1910),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1911] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12585),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1911),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1912] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12586),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1912),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1913] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12587),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1913),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1914] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12588),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1914),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1915] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12589),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1915),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1916] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12590),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1916),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1917] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12591),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1917),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1918] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12592),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1918),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1919] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12593),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1919),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1920] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12595),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(1920),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1921] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8753),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1921),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1922] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8683),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(8842),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1922),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1923] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8713),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1923),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1924] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8715),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1924),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1925] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8723),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1925),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1926] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8724),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1926),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1927] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8725),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1927),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1928] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8726),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1928),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1929] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8728),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1929),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1930] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8733),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1930),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1931] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8736),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1931),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1932] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8766),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1932),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1933] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10848),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(1933),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1934] = {
    [sym_value_definition] = STATE(20346),
    [sym__simple_expression] = STATE(1815),
    [sym__expression] = STATE(8779),
    [sym_typed_expression] = STATE(4014),
    [sym_labeled_tuple_element] = STATE(20329),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4014),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4014),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3518),
    [sym_array_get_expression] = STATE(3518),
    [sym_string_get_expression] = STATE(3518),
    [sym_bigarray_get_expression] = STATE(3518),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4014),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(1934),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym_sign_operator] = STATE(1921),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__instance_variable_name] = STATE(20331),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [sym__lowercase_identifier] = ACTIONS(703),
    [anon_sym_let] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_fun] = ACTIONS(717),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(723),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3077),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(749),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1935] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9105),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(9237),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1935),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1936] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8522),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1936),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1937] = {
    [sym_value_definition] = STATE(18907),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(13219),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18863),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6615),
    [sym_array_get_expression] = STATE(6615),
    [sym_string_get_expression] = STATE(6615),
    [sym_bigarray_get_expression] = STATE(6615),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(1937),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(1895),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18864),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2561),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2565),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2571),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1938] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9079),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1938),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1939] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9178),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1939),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1940] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9063),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1940),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1941] = {
    [sym_value_definition] = STATE(20576),
    [sym__simple_expression] = STATE(2455),
    [sym__expression] = STATE(9159),
    [sym_typed_expression] = STATE(4695),
    [sym_labeled_tuple_element] = STATE(20320),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4695),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4695),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4252),
    [sym_array_get_expression] = STATE(4252),
    [sym_string_get_expression] = STATE(4252),
    [sym_bigarray_get_expression] = STATE(4252),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4695),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(1941),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym_sign_operator] = STATE(1830),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__instance_variable_name] = STATE(20322),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [sym__lowercase_identifier] = ACTIONS(297),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_fun] = ACTIONS(323),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(333),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3039),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3041),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(357),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1942] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9073),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1942),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1943] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13213),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1943),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1944] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13320),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(13468),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1944),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1945] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13321),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1945),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1946] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13325),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1946),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1947] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12920),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1947),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1948] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12921),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1948),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1949] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12922),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1949),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1950] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12923),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1950),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1951] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12924),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1951),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1952] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12925),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1952),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1953] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12926),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1953),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1954] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12927),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1954),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1955] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9074),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1955),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1956] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9075),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1956),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1957] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8558),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1957),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1958] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8479),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(8647),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1958),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1959] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8481),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1959),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1960] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8487),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1960),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1961] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8493),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1961),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1962] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8494),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1962),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1963] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8495),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1963),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1964] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8496),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1964),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1965] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8500),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1965),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1966] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8504),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1966),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1967] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8505),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1967),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1968] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8507),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1968),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1969] = {
    [sym_value_definition] = STATE(19312),
    [sym__simple_expression] = STATE(816),
    [sym__expression] = STATE(8524),
    [sym_typed_expression] = STATE(3250),
    [sym_labeled_tuple_element] = STATE(20126),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3250),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3250),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3130),
    [sym_array_get_expression] = STATE(3130),
    [sym_string_get_expression] = STATE(3130),
    [sym_bigarray_get_expression] = STATE(3130),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3250),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(1969),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym_sign_operator] = STATE(1957),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__instance_variable_name] = STATE(20519),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [sym__lowercase_identifier] = ACTIONS(367),
    [anon_sym_let] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_fun] = ACTIONS(385),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_if] = ACTIONS(389),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(391),
    [anon_sym_function] = ACTIONS(393),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3063),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3065),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(421),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1970] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9076),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1970),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1971] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9086),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1971),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1972] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9102),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1972),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1973] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8499),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1973),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1974] = {
    [sym_value_definition] = STATE(18454),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(13103),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(18427),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6618),
    [sym_array_get_expression] = STATE(6618),
    [sym_string_get_expression] = STATE(6618),
    [sym_bigarray_get_expression] = STATE(6618),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(1974),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(1943),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(18429),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2641),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2645),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2649),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2651),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1975] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9117),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(1975),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1976] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13005),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1976),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1977] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13126),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(13429),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1977),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1978] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13127),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1978),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1979] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13128),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1979),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1980] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13129),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1980),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1981] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13130),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1981),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1982] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13131),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1982),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1983] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13132),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1983),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1984] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13133),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1984),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1985] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13134),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1985),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1986] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13135),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1986),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1987] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13141),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1987),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1988] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13143),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(1988),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1989] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8439),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1989),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1990] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8527),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(8614),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1990),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1991] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8532),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1991),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1992] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8533),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1992),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1993] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8546),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1993),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1994] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8547),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1994),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1995] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8549),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1995),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1996] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8562),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1996),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1997] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8567),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1997),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1998] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8438),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1998),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [1999] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8441),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(1999),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2000] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8442),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(2000),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2001] = {
    [sym_value_definition] = STATE(19016),
    [sym__simple_expression] = STATE(821),
    [sym__expression] = STATE(8446),
    [sym_typed_expression] = STATE(3312),
    [sym_labeled_tuple_element] = STATE(18908),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3312),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3312),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3115),
    [sym_array_get_expression] = STATE(3115),
    [sym_string_get_expression] = STATE(3115),
    [sym_bigarray_get_expression] = STATE(3115),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3312),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(2001),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym_sign_operator] = STATE(1989),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__instance_variable_name] = STATE(18927),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [sym__lowercase_identifier] = ACTIONS(427),
    [anon_sym_let] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_fun] = ACTIONS(441),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_if] = ACTIONS(445),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(447),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3051),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3053),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(473),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2002] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8624),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2002),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2003] = {
    [sym_value_definition] = STATE(19268),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(13211),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(19237),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6622),
    [sym_array_get_expression] = STATE(6622),
    [sym_string_get_expression] = STATE(6622),
    [sym_bigarray_get_expression] = STATE(6622),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2003),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(1976),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(19238),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2863),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2865),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2869),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2873),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2004] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11389),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2004),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2005] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10118),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2005),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2006] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10102),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(10401),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2006),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(3783),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2007] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10104),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2007),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2008] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10105),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2008),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2009] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10107),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2009),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2010] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10108),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2010),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2011] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10109),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2011),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2012] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10114),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2012),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2013] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10115),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2013),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2014] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10116),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2014),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2015] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10117),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2015),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2016] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10120),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2016),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2017] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10122),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2017),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2018] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8665),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2018),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2019] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8590),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(8694),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2019),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2020] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8591),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2020),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2021] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8592),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2021),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2022] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8596),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2022),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2023] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8600),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2023),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2024] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8601),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2024),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2025] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8602),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2025),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2026] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8603),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2026),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2027] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8604),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2027),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2028] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8605),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2028),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2029] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8606),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2029),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2030] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11519),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(11730),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2030),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2031] = {
    [sym_value_definition] = STATE(18903),
    [sym__simple_expression] = STATE(1608),
    [sym__expression] = STATE(8608),
    [sym_typed_expression] = STATE(3632),
    [sym_labeled_tuple_element] = STATE(18569),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3632),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3632),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3486),
    [sym_array_get_expression] = STATE(3486),
    [sym_string_get_expression] = STATE(3486),
    [sym_bigarray_get_expression] = STATE(3486),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3632),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2031),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym_sign_operator] = STATE(2018),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__instance_variable_name] = STATE(18573),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [sym__lowercase_identifier] = ACTIONS(589),
    [anon_sym_let] = ACTIONS(591),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_fun] = ACTIONS(603),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(611),
    [anon_sym_try] = ACTIONS(613),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3085),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(635),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2032] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11375),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2032),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2033] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11305),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2033),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2034] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11481),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2034),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2035] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11368),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2035),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2036] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11424),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2036),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2037] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11331),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2037),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2038] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11285),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2038),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2039] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11395),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2039),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2040] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11397),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2040),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2041] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11263),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2041),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2042] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8645),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2042),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2043] = {
    [sym_value_definition] = STATE(20686),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(10228),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(20620),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(4939),
    [sym_array_get_expression] = STATE(4939),
    [sym_string_get_expression] = STATE(4939),
    [sym_bigarray_get_expression] = STATE(4939),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2043),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2005),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(20621),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(977),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(979),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(985),
    [anon_sym_function] = ACTIONS(987),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(995),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2044] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12658),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2044),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2045] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12694),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(12935),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2045),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2046] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12696),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2046),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2047] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12697),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2047),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2048] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12698),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2048),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2049] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12699),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2049),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2050] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12700),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2050),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2051] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12701),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2051),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2052] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12702),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2052),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2053] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12703),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2053),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2054] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12705),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2054),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2055] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12706),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2055),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2056] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12739),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2056),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2057] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8615),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2057),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2058] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8627),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(8699),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2058),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2059] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8628),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2059),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2060] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8630),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2060),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2061] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8631),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2061),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2062] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8632),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2062),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2063] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8633),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2063),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2064] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8634),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2064),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2065] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8635),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2065),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2066] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8636),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2066),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2067] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8637),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2067),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2068] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8638),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2068),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2069] = {
    [sym_value_definition] = STATE(19301),
    [sym__simple_expression] = STATE(1615),
    [sym__expression] = STATE(8640),
    [sym_typed_expression] = STATE(3522),
    [sym_labeled_tuple_element] = STATE(18868),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3522),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3522),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3489),
    [sym_array_get_expression] = STATE(3489),
    [sym_string_get_expression] = STATE(3489),
    [sym_bigarray_get_expression] = STATE(3489),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3522),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2069),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym_sign_operator] = STATE(2057),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__instance_variable_name] = STATE(18873),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [sym__lowercase_identifier] = ACTIONS(641),
    [anon_sym_let] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_fun] = ACTIONS(655),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(659),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(663),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3035),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3037),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(687),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2070] = {
    [sym_value_definition] = STATE(21052),
    [sym__simple_expression] = STATE(2523),
    [sym__expression] = STATE(12582),
    [sym_typed_expression] = STATE(6951),
    [sym_labeled_tuple_element] = STATE(20826),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6951),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6951),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6265),
    [sym_array_get_expression] = STATE(6265),
    [sym_string_get_expression] = STATE(6265),
    [sym_bigarray_get_expression] = STATE(6265),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6951),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2070),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym_sign_operator] = STATE(2044),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__instance_variable_name] = STATE(20831),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [sym__lowercase_identifier] = ACTIONS(2403),
    [anon_sym_let] = ACTIONS(2405),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_fun] = ACTIONS(2417),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_if] = ACTIONS(2421),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2423),
    [anon_sym_function] = ACTIONS(2425),
    [anon_sym_try] = ACTIONS(2427),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2449),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2071] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(11511),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2071),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2072] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12549),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2072),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2073] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12521),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(12673),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2073),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2074] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12523),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2074),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2075] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12525),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2075),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2076] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12526),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2076),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2077] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12527),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2077),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2078] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12528),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2078),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2079] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12529),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2079),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2080] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12530),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2080),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2081] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12531),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2081),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2082] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12532),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2082),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2083] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12533),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2083),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2084] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12538),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2084),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2085] = {
    [sym_value_definition] = STATE(19406),
    [sym__simple_expression] = STATE(2517),
    [sym__expression] = STATE(12463),
    [sym_typed_expression] = STATE(6355),
    [sym_labeled_tuple_element] = STATE(19259),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6355),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6355),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6067),
    [sym_array_get_expression] = STATE(6067),
    [sym_string_get_expression] = STATE(6067),
    [sym_bigarray_get_expression] = STATE(6067),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6355),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2085),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym_sign_operator] = STATE(2072),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__instance_variable_name] = STATE(19292),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [sym__lowercase_identifier] = ACTIONS(1977),
    [anon_sym_let] = ACTIONS(1979),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_fun] = ACTIONS(1991),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_if] = ACTIONS(1995),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1997),
    [anon_sym_function] = ACTIONS(1999),
    [anon_sym_try] = ACTIONS(2001),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2023),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2086] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12275),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2086),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2087] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12258),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(12425),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2087),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2088] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12259),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2088),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2089] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12260),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2089),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2090] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12261),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2090),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2091] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12262),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2091),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2092] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12263),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2092),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2093] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12264),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2093),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2094] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12265),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2094),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2095] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12266),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2095),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2096] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12267),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2096),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2097] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12268),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2097),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2098] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12270),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2098),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2099] = {
    [sym_value_definition] = STATE(20767),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(12273),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(20610),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5755),
    [sym_array_get_expression] = STATE(5755),
    [sym_string_get_expression] = STATE(5755),
    [sym_bigarray_get_expression] = STATE(5755),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2099),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2086),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(20639),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1339),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1341),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1343),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2100] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10631),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2100),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2101] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10692),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(10929),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2101),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2102] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10694),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2102),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2103] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10695),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2103),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2104] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10696),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2104),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2105] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10697),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2105),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2106] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10698),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2106),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2107] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10701),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2107),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2108] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10702),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2108),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2109] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10703),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2109),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2110] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10704),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2110),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2111] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10705),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2111),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2112] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13535),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2112),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2113] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10710),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2113),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2114] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13552),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(13608),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2114),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2115] = {
    [sym_value_definition] = STATE(19702),
    [sym__simple_expression] = STATE(2476),
    [sym__expression] = STATE(10628),
    [sym_typed_expression] = STATE(5398),
    [sym_labeled_tuple_element] = STATE(21369),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5398),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5398),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5225),
    [sym_array_get_expression] = STATE(5225),
    [sym_string_get_expression] = STATE(5225),
    [sym_bigarray_get_expression] = STATE(5225),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5398),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2115),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym_sign_operator] = STATE(2100),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__instance_variable_name] = STATE(21371),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [sym__lowercase_identifier] = ACTIONS(1063),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_fun] = ACTIONS(1077),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1083),
    [anon_sym_function] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1111),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2116] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13554),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2116),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2117] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13555),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2117),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2118] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13557),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2118),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2119] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13581),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2119),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2120] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13484),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2120),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2121] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12715),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2121),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2122] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13522),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2122),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2123] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12677),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(13327),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2123),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2124] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12678),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2124),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2125] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12679),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2125),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2126] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12680),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2126),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2127] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12681),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2127),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2128] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12682),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2128),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2129] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12683),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2129),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2130] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12684),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2130),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2131] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12685),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2131),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2132] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12686),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2132),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2133] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12687),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2133),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2134] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13459),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2134),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2135] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13396),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2135),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2136] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13434),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2136),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2137] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13444),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2137),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2138] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12689),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2138),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2139] = {
    [sym_value_definition] = STATE(18900),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12763),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(19373),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6256),
    [sym_array_get_expression] = STATE(6256),
    [sym_string_get_expression] = STATE(6256),
    [sym_bigarray_get_expression] = STATE(6256),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2139),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(1908),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(19431),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2353),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2365),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2369),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2373),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2397),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2140] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12743),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2140),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2141] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12726),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(12982),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2141),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2142] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12727),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2142),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2143] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12728),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2143),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2144] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12729),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2144),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2145] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12730),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2145),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2146] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12731),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2146),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2147] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12732),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2147),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2148] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12733),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2148),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2149] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12734),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2149),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2150] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12735),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2150),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2151] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12736),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2151),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2152] = {
    [sym_value_definition] = STATE(19507),
    [sym__simple_expression] = STATE(2533),
    [sym__expression] = STATE(13448),
    [sym_typed_expression] = STATE(7186),
    [sym_labeled_tuple_element] = STATE(20587),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7186),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7186),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7137),
    [sym_array_get_expression] = STATE(7137),
    [sym_string_get_expression] = STATE(7137),
    [sym_bigarray_get_expression] = STATE(7137),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7186),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2152),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym_sign_operator] = STATE(2112),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__instance_variable_name] = STATE(20636),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [sym__lowercase_identifier] = ACTIONS(2653),
    [anon_sym_let] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_fun] = ACTIONS(2919),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2921),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2925),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2929),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2153] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12738),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2153),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2154] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13426),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2154),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2155] = {
    [sym_value_definition] = STATE(19737),
    [sym__simple_expression] = STATE(2522),
    [sym__expression] = STATE(12643),
    [sym_typed_expression] = STATE(6686),
    [sym_labeled_tuple_element] = STATE(18746),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6686),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6686),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6257),
    [sym_array_get_expression] = STATE(6257),
    [sym_string_get_expression] = STATE(6257),
    [sym_bigarray_get_expression] = STATE(6257),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6686),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2155),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym_sign_operator] = STATE(2121),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__instance_variable_name] = STATE(18774),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [sym__lowercase_identifier] = ACTIONS(2247),
    [anon_sym_let] = ACTIONS(2249),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_fun] = ACTIONS(2261),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2265),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2267),
    [anon_sym_function] = ACTIONS(2269),
    [anon_sym_try] = ACTIONS(2271),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2293),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2156] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12761),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2156),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2157] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12745),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(13021),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2157),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2158] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12746),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2158),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2159] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12747),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2159),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2160] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12748),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2160),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2161] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12749),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2161),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2162] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12750),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2162),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2163] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12751),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2163),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2164] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12752),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2164),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2165] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12754),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2165),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2166] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12755),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2166),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2167] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13564),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(13614),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2167),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2168] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13576),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2168),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2169] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13579),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2169),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2170] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13580),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2170),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2171] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13363),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2171),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2172] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12757),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2172),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2173] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13372),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2173),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2174] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13374),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2174),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2175] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13375),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2175),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2176] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13377),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2176),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2177] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13378),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2177),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2178] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13392),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2178),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2179] = {
    [sym_value_definition] = STATE(20877),
    [sym__simple_expression] = STATE(2524),
    [sym__expression] = STATE(12717),
    [sym_typed_expression] = STATE(6736),
    [sym_labeled_tuple_element] = STATE(19625),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6736),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6736),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6258),
    [sym_array_get_expression] = STATE(6258),
    [sym_string_get_expression] = STATE(6258),
    [sym_bigarray_get_expression] = STATE(6258),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6736),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2179),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym_sign_operator] = STATE(2140),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__instance_variable_name] = STATE(19629),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [sym__lowercase_identifier] = ACTIONS(2507),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_fun] = ACTIONS(2521),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_if] = ACTIONS(2525),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2527),
    [anon_sym_function] = ACTIONS(2529),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2553),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2180] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9880),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2180),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2181] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9851),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(10298),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2181),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2182] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9852),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2182),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2183] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9853),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2183),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2184] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9854),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2184),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2185] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9855),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2185),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2186] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9856),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2186),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2187] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9857),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2187),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2188] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9858),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2188),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2189] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9859),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2189),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2190] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9861),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2190),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2191] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9863),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2191),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2192] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9866),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2192),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2193] = {
    [sym_value_definition] = STATE(20110),
    [sym__simple_expression] = STATE(2541),
    [sym__expression] = STATE(13435),
    [sym_typed_expression] = STATE(7419),
    [sym_labeled_tuple_element] = STATE(18540),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7419),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7419),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7188),
    [sym_array_get_expression] = STATE(7188),
    [sym_string_get_expression] = STATE(7188),
    [sym_bigarray_get_expression] = STATE(7188),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7419),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2193),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym_sign_operator] = STATE(2154),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__instance_variable_name] = STATE(18542),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [sym__lowercase_identifier] = ACTIONS(2757),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_fun] = ACTIONS(2933),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2937),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2941),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2943),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2194] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13437),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2194),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2195] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12918),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2195),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2196] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13417),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2196),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2197] = {
    [sym_value_definition] = STATE(19684),
    [sym__simple_expression] = STATE(2470),
    [sym__expression] = STATE(9848),
    [sym_typed_expression] = STATE(4942),
    [sym_labeled_tuple_element] = STATE(19263),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(4942),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(4942),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(4811),
    [sym_array_get_expression] = STATE(4811),
    [sym_string_get_expression] = STATE(4811),
    [sym_bigarray_get_expression] = STATE(4811),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(4942),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2197),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym_sign_operator] = STATE(2180),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__instance_variable_name] = STATE(19273),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [sym__lowercase_identifier] = ACTIONS(915),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_fun] = ACTIONS(929),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(939),
    [anon_sym_function] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3055),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3057),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(969),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2198] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13497),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(13597),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2198),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2199] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13500),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2199),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2200] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13501),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2200),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2201] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13502),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2201),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2202] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13503),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2202),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2203] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13504),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2203),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2204] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13505),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2204),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2205] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13506),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2205),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2206] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13507),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2206),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2207] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13508),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2207),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2208] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13509),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2208),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2209] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9126),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(2209),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2210] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8905),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2210),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2211] = {
    [sym_value_definition] = STATE(18560),
    [sym__simple_expression] = STATE(2535),
    [sym__expression] = STATE(13541),
    [sym_typed_expression] = STATE(7511),
    [sym_labeled_tuple_element] = STATE(19516),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7511),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7511),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7421),
    [sym_array_get_expression] = STATE(7421),
    [sym_string_get_expression] = STATE(7421),
    [sym_bigarray_get_expression] = STATE(7421),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7511),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2211),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym_sign_operator] = STATE(2196),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__instance_variable_name] = STATE(19517),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [sym__lowercase_identifier] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_fun] = ACTIONS(2905),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2909),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2913),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2915),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2212] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13471),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2212),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2213] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13536),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(13607),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2213),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2214] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13515),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2214),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2215] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13401),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2215),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2216] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13381),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2216),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2217] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13382),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2217),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2218] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13385),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2218),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2219] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13388),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2219),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2220] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13403),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2220),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2221] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13419),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2221),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2222] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13433),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2222),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2223] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13442),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2223),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2224] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13481),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2224),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2225] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12802),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2225),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2226] = {
    [sym_value_definition] = STATE(18621),
    [sym__simple_expression] = STATE(2531),
    [sym__expression] = STATE(13488),
    [sym_typed_expression] = STATE(7319),
    [sym_labeled_tuple_element] = STATE(20525),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(7319),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(7319),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(7514),
    [sym_array_get_expression] = STATE(7514),
    [sym_string_get_expression] = STATE(7514),
    [sym_bigarray_get_expression] = STATE(7514),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(7319),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2226),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym_sign_operator] = STATE(2212),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__instance_variable_name] = STATE(20526),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [sym__lowercase_identifier] = ACTIONS(2809),
    [anon_sym_let] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_fun] = ACTIONS(2891),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_if] = ACTIONS(2893),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2901),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2227] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10399),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2227),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2228] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10431),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(10713),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2228),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(3783),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2229] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10496),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2229),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2230] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10330),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2230),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2231] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10480),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2231),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2232] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10544),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2232),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2233] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10445),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2233),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2234] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10313),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2234),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2235] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10349),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2235),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2236] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10469),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2236),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2237] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10497),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2237),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2238] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10504),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2238),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2239] = {
    [sym_value_definition] = STATE(21364),
    [sym__simple_expression] = STATE(2471),
    [sym__expression] = STATE(10331),
    [sym_typed_expression] = STATE(5054),
    [sym_labeled_tuple_element] = STATE(21257),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5054),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5054),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5105),
    [sym_array_get_expression] = STATE(5105),
    [sym_string_get_expression] = STATE(5105),
    [sym_bigarray_get_expression] = STATE(5105),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5054),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2239),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym_sign_operator] = STATE(2227),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__instance_variable_name] = STATE(21258),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [sym__lowercase_identifier] = ACTIONS(997),
    [anon_sym_let] = ACTIONS(1049),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_fun] = ACTIONS(1051),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1055),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(991),
    [anon_sym_lazy] = ACTIONS(993),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3071),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3073),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1061),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2240] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8579),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2240),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2241] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8666),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(8797),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2241),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2242] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8668),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2242),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2243] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8667),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2243),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2244] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8610),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2244),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2245] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8585),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2245),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2246] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8598),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2246),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2247] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8613),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2247),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2248] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8644),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2248),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2249] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8650),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2249),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2250] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8655),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2250),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2251] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8580),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2251),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2252] = {
    [sym_value_definition] = STATE(19475),
    [sym__simple_expression] = STATE(1771),
    [sym__expression] = STATE(8571),
    [sym_typed_expression] = STATE(3757),
    [sym_labeled_tuple_element] = STATE(19205),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3757),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3757),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3487),
    [sym_array_get_expression] = STATE(3487),
    [sym_string_get_expression] = STATE(3487),
    [sym_bigarray_get_expression] = STATE(3487),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3757),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2252),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym_sign_operator] = STATE(2240),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__instance_variable_name] = STATE(18669),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [sym__lowercase_identifier] = ACTIONS(483),
    [anon_sym_let] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_fun] = ACTIONS(497),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(501),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(505),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3059),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3061),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(529),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2253] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(9032),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2253),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2254] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8845),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(9188),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2254),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2255] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8855),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2255),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2256] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8856),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2256),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2257] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8857),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2257),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2258] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8858),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2258),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2259] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8859),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2259),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2260] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8861),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2260),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2261] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8862),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2261),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2262] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8870),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2262),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2263] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8874),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2263),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2264] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(8883),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2264),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2265] = {
    [sym_value_definition] = STATE(21383),
    [sym__simple_expression] = STATE(2445),
    [sym__expression] = STATE(9005),
    [sym_typed_expression] = STATE(4163),
    [sym_labeled_tuple_element] = STATE(20585),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4163),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4163),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3994),
    [sym_array_get_expression] = STATE(3994),
    [sym_string_get_expression] = STATE(3994),
    [sym_bigarray_get_expression] = STATE(3994),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4163),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2265),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym_sign_operator] = STATE(2253),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__instance_variable_name] = STATE(20605),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [sym__lowercase_identifier] = ACTIONS(807),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_fun] = ACTIONS(821),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(827),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3079),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3081),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(853),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2266] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13090),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2266),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2267] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13017),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(13376),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2267),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2268] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13018),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2268),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2269] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13037),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2269),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2270] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13038),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2270),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2271] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13040),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2271),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2272] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13041),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2272),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2273] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13042),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2273),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2274] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13043),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2274),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2275] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13044),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2275),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2276] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13046),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2276),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2277] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13047),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2277),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2278] = {
    [sym_value_definition] = STATE(18756),
    [sym__simple_expression] = STATE(2528),
    [sym__expression] = STATE(13083),
    [sym_typed_expression] = STATE(7057),
    [sym_labeled_tuple_element] = STATE(21114),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(7057),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(7057),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6524),
    [sym_array_get_expression] = STATE(6524),
    [sym_string_get_expression] = STATE(6524),
    [sym_bigarray_get_expression] = STATE(6524),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(7057),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2278),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym_sign_operator] = STATE(2266),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__instance_variable_name] = STATE(21115),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [sym__lowercase_identifier] = ACTIONS(2573),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_fun] = ACTIONS(2587),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2593),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2597),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2619),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2279] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(12597),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2279),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2280] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13514),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2280),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2281] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12884),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2281),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2282] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13270),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2282),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2283] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13179),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(13423),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2283),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2284] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13180),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2284),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2285] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13182),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2285),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2286] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13184),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2286),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2287] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13185),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2287),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2288] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13186),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2288),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2289] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13187),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2289),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2290] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13188),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2290),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2291] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13189),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2291),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2292] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13190),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2292),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2293] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13191),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2293),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2294] = {
    [sym_value_definition] = STATE(20113),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13196),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(21243),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6948),
    [sym_array_get_expression] = STATE(6948),
    [sym_string_get_expression] = STATE(6948),
    [sym_bigarray_get_expression] = STATE(6948),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2294),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2282),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(21251),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(2877),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2881),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2885),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2887),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2295] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12305),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2295),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2296] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12237),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(12484),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2296),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2297] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12238),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2297),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2298] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12239),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2298),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2299] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12240),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2299),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2300] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12241),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2300),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2301] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12242),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2301),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2302] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12243),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2302),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2303] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12244),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2303),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2304] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12245),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2304),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2305] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12246),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2305),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2306] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12247),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2306),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2307] = {
    [sym_value_definition] = STATE(21414),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12248),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19142),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5748),
    [sym_array_get_expression] = STATE(5748),
    [sym_string_get_expression] = STATE(5748),
    [sym_bigarray_get_expression] = STATE(5748),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2307),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2295),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19151),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1347),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1359),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2308] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12690),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2308),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2309] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12660),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(13263),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2309),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2310] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12661),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2310),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2311] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12662),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2311),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2312] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12663),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2312),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2313] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12664),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2313),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2314] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12665),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2314),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2315] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12666),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2315),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2316] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12667),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2316),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2317] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12573),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2317),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2318] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12668),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2318),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2319] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12669),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2319),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2320] = {
    [sym_value_definition] = STATE(19193),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(12672),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(19152),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6341),
    [sym_array_get_expression] = STATE(6341),
    [sym_string_get_expression] = STATE(6341),
    [sym_bigarray_get_expression] = STATE(6341),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2320),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2308),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(19186),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(2233),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(2235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(2237),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2239),
    [anon_sym_function] = ACTIONS(2241),
    [anon_sym_try] = ACTIONS(2243),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2245),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2321] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11575),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2321),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2322] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11658),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(12274),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2322),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2323] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11672),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2323),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2324] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11689),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2324),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2325] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11757),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2325),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2326] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11760),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2326),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2327] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11791),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2327),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2328] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11590),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2328),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2329] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11591),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2329),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2330] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11592),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2330),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2331] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11593),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2331),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2332] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11595),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2332),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2333] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11603),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2333),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2334] = {
    [sym_value_definition] = STATE(19872),
    [sym__simple_expression] = STATE(2499),
    [sym__expression] = STATE(11771),
    [sym_typed_expression] = STATE(5762),
    [sym_labeled_tuple_element] = STATE(19249),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(5762),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(5762),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(5636),
    [sym_array_get_expression] = STATE(5636),
    [sym_string_get_expression] = STATE(5636),
    [sym_bigarray_get_expression] = STATE(5636),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(5762),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2334),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym_sign_operator] = STATE(2321),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__instance_variable_name] = STATE(19253),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [sym__lowercase_identifier] = ACTIONS(1279),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_fun] = ACTIONS(1293),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1303),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_try] = ACTIONS(1307),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1333),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2335] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12790),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2335),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2336] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12824),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(13175),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2336),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2337] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12826),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2337),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2338] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12828),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2338),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2339] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12829),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2339),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2340] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12830),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2340),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2341] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12831),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2341),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2342] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12832),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2342),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2343] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12834),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2343),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2344] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12835),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2344),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2345] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12836),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2345),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2346] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12837),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2346),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2347] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13526),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2347),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2348] = {
    [sym_value_definition] = STATE(19034),
    [sym__simple_expression] = STATE(2518),
    [sym__expression] = STATE(12857),
    [sym_typed_expression] = STATE(6549),
    [sym_labeled_tuple_element] = STATE(18845),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6549),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6549),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6153),
    [sym_array_get_expression] = STATE(6153),
    [sym_string_get_expression] = STATE(6153),
    [sym_bigarray_get_expression] = STATE(6153),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6549),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2348),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym_sign_operator] = STATE(2335),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__instance_variable_name] = STATE(18849),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [sym__lowercase_identifier] = ACTIONS(2455),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_fun] = ACTIONS(2469),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_if] = ACTIONS(2473),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(2475),
    [anon_sym_function] = ACTIONS(2477),
    [anon_sym_try] = ACTIONS(2479),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2501),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2349] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8646),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2349),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2350] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8662),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(8693),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2350),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2351] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8572),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2351),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2352] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8573),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2352),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2353] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8574),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2353),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2354] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8575),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2354),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2355] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8576),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2355),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2356] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8577),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2356),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2357] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8578),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2357),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2358] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8586),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2358),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2359] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8594),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2359),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2360] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8597),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2360),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2361] = {
    [sym_value_definition] = STATE(19600),
    [sym__simple_expression] = STATE(2448),
    [sym__expression] = STATE(9133),
    [sym_typed_expression] = STATE(4471),
    [sym_labeled_tuple_element] = STATE(20430),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4471),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4471),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4280),
    [sym_array_get_expression] = STATE(4280),
    [sym_string_get_expression] = STATE(4280),
    [sym_bigarray_get_expression] = STATE(4280),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4471),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(2361),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym_sign_operator] = STATE(2209),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__instance_variable_name] = STATE(21081),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [sym__lowercase_identifier] = ACTIONS(33),
    [anon_sym_let] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_fun] = ACTIONS(71),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_if] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(81),
    [anon_sym_function] = ACTIONS(83),
    [anon_sym_try] = ACTIONS(85),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3087),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3089),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(117),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2362] = {
    [sym_value_definition] = STATE(20586),
    [sym__simple_expression] = STATE(1636),
    [sym__expression] = STATE(8656),
    [sym_typed_expression] = STATE(3557),
    [sym_labeled_tuple_element] = STATE(20440),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3557),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3557),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3349),
    [sym_array_get_expression] = STATE(3349),
    [sym_string_get_expression] = STATE(3349),
    [sym_bigarray_get_expression] = STATE(3349),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3557),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2362),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym_sign_operator] = STATE(2349),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__instance_variable_name] = STATE(20445),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [sym__lowercase_identifier] = ACTIONS(535),
    [anon_sym_let] = ACTIONS(537),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_fun] = ACTIONS(549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(553),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(557),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3091),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3093),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(581),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2363] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8895),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2363),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2364] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(9026),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(9152),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2364),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2365] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(9035),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2365),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2366] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(9040),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2366),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2367] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(9043),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2367),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2368] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(9047),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2368),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2369] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(9052),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2369),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2370] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8804),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2370),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2371] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8805),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2371),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2372] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8811),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2372),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2373] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8812),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2373),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2374] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8813),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2374),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2375] = {
    [sym_value_definition] = STATE(19150),
    [sym__simple_expression] = STATE(2444),
    [sym__expression] = STATE(8848),
    [sym_typed_expression] = STATE(4323),
    [sym_labeled_tuple_element] = STATE(18508),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(4323),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(4323),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(4072),
    [sym_array_get_expression] = STATE(4072),
    [sym_string_get_expression] = STATE(4072),
    [sym_bigarray_get_expression] = STATE(4072),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(4323),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2375),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym_sign_operator] = STATE(2363),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__instance_variable_name] = STATE(18707),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [sym__lowercase_identifier] = ACTIONS(859),
    [anon_sym_let] = ACTIONS(861),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_fun] = ACTIONS(873),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(879),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3067),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3069),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(905),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2376] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12560),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2376),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2377] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12434),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(12596),
    [sym__tuple_expression] = STATE(11208),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2377),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(3785),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2378] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12450),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2378),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2379] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12572),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2379),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2380] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12499),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2380),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2381] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12501),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2381),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2382] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12502),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2382),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2383] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12503),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2383),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2384] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12506),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2384),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2385] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12513),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2385),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2386] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12561),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2386),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2387] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12419),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2387),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2388] = {
    [sym_value_definition] = STATE(18499),
    [sym__simple_expression] = STATE(2516),
    [sym__expression] = STATE(12426),
    [sym_typed_expression] = STATE(6059),
    [sym_labeled_tuple_element] = STATE(19570),
    [sym__tuple_expression] = STATE(11056),
    [sym_cons_expression] = STATE(11071),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_application_expression] = STATE(11071),
    [sym_prefix_expression] = STATE(6059),
    [sym_sign_expression] = STATE(11071),
    [sym_hash_expression] = STATE(6059),
    [sym_infix_expression] = STATE(11071),
    [sym_field_get_expression] = STATE(6041),
    [sym_array_get_expression] = STATE(6041),
    [sym_string_get_expression] = STATE(6041),
    [sym_bigarray_get_expression] = STATE(6041),
    [sym_set_expression] = STATE(11071),
    [sym_if_expression] = STATE(11071),
    [sym_while_expression] = STATE(11071),
    [sym_for_expression] = STATE(11071),
    [sym_match_expression] = STATE(11071),
    [sym_function_expression] = STATE(11071),
    [sym_fun_expression] = STATE(11071),
    [sym_try_expression] = STATE(11071),
    [sym_let_expression] = STATE(11071),
    [sym_coercion_expression] = STATE(6059),
    [sym_assert_expression] = STATE(11071),
    [sym_lazy_expression] = STATE(11071),
    [sym_let_module_expression] = STATE(11071),
    [sym_let_open_expression] = STATE(11071),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_let_exception_expression] = STATE(11071),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2388),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym_sign_operator] = STATE(2376),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__instance_variable_name] = STATE(19776),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [sym__lowercase_identifier] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1755),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_fun] = ACTIONS(1757),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1759),
    [anon_sym_while] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1301),
    [anon_sym_match] = ACTIONS(1365),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_try] = ACTIONS(1369),
    [anon_sym_assert] = ACTIONS(1309),
    [anon_sym_lazy] = ACTIONS(1311),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1391),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2389] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(11170),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2389),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2390] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10824),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(11514),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2390),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2391] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10825),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2391),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2392] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10826),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2392),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2393] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10827),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2393),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2394] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10828),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2394),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2395] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10829),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2395),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2396] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10830),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2396),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2397] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10832),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2397),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2398] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10833),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2398),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2399] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10834),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2399),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2400] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10835),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2400),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2401] = {
    [sym_value_definition] = STATE(18622),
    [sym__simple_expression] = STATE(2472),
    [sym__expression] = STATE(10862),
    [sym_typed_expression] = STATE(5255),
    [sym_labeled_tuple_element] = STATE(18531),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5255),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5255),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5325),
    [sym_array_get_expression] = STATE(5325),
    [sym_string_get_expression] = STATE(5325),
    [sym_bigarray_get_expression] = STATE(5325),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5255),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2401),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym_sign_operator] = STATE(2389),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__instance_variable_name] = STATE(18538),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [sym__lowercase_identifier] = ACTIONS(1169),
    [anon_sym_let] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_fun] = ACTIONS(1183),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_if] = ACTIONS(1187),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1189),
    [anon_sym_function] = ACTIONS(1191),
    [anon_sym_try] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1219),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2402] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10984),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2402),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2403] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10935),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(11418),
    [sym__tuple_expression] = STATE(8480),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2403),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(3777),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2404] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10938),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2404),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2405] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10940),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2405),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2406] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10948),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2406),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2407] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10950),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2407),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2408] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10952),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2408),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2409] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10953),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2409),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2410] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10954),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2410),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2411] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10957),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2411),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2412] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10958),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2412),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2413] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(10959),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2413),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2414] = {
    [sym_value_definition] = STATE(20659),
    [sym__simple_expression] = STATE(2478),
    [sym__expression] = STATE(11028),
    [sym_typed_expression] = STATE(5554),
    [sym_labeled_tuple_element] = STATE(20396),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(5554),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(5554),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(5323),
    [sym_array_get_expression] = STATE(5323),
    [sym_string_get_expression] = STATE(5323),
    [sym_bigarray_get_expression] = STATE(5323),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(5554),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2414),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym_sign_operator] = STATE(2402),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__instance_variable_name] = STATE(20414),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [sym__lowercase_identifier] = ACTIONS(1117),
    [anon_sym_let] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_fun] = ACTIONS(1131),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1135),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(1137),
    [anon_sym_function] = ACTIONS(1139),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1163),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2415] = {
    [sym_value_definition] = STATE(21095),
    [sym__simple_expression] = STATE(2475),
    [sym__expression] = STATE(13415),
    [sym_typed_expression] = STATE(5371),
    [sym_labeled_tuple_element] = STATE(18703),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(5371),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(5371),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(5511),
    [sym_array_get_expression] = STATE(5511),
    [sym_string_get_expression] = STATE(5511),
    [sym_bigarray_get_expression] = STATE(5511),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(5371),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2415),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym_sign_operator] = STATE(2004),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__instance_variable_name] = STATE(18733),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [sym__lowercase_identifier] = ACTIONS(1225),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_fun] = ACTIONS(1239),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_if] = ACTIONS(1243),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(1245),
    [anon_sym_function] = ACTIONS(1247),
    [anon_sym_try] = ACTIONS(1249),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(1271),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2416] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13100),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2416),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2417] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13274),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(13491),
    [sym__tuple_expression] = STATE(8195),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2417),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(3781),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2418] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13311),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2418),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2419] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13326),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2419),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2420] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13356),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2420),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2421] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13357),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2421),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2422] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13163),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2422),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2423] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12937),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2423),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2424] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12938),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2424),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2425] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12940),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2425),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2426] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12941),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2426),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2427] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(12942),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2427),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2428] = {
    [sym_value_definition] = STATE(19447),
    [sym__simple_expression] = STATE(2521),
    [sym__expression] = STATE(13206),
    [sym_typed_expression] = STATE(6638),
    [sym_labeled_tuple_element] = STATE(20960),
    [sym__tuple_expression] = STATE(8416),
    [sym_cons_expression] = STATE(8425),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_application_expression] = STATE(8425),
    [sym_prefix_expression] = STATE(6638),
    [sym_sign_expression] = STATE(8425),
    [sym_hash_expression] = STATE(6638),
    [sym_infix_expression] = STATE(8425),
    [sym_field_get_expression] = STATE(6598),
    [sym_array_get_expression] = STATE(6598),
    [sym_string_get_expression] = STATE(6598),
    [sym_bigarray_get_expression] = STATE(6598),
    [sym_set_expression] = STATE(8425),
    [sym_if_expression] = STATE(8425),
    [sym_while_expression] = STATE(8425),
    [sym_for_expression] = STATE(8425),
    [sym_match_expression] = STATE(8425),
    [sym_function_expression] = STATE(8425),
    [sym_fun_expression] = STATE(8425),
    [sym_try_expression] = STATE(8425),
    [sym_let_expression] = STATE(8425),
    [sym_coercion_expression] = STATE(6638),
    [sym_assert_expression] = STATE(8425),
    [sym_lazy_expression] = STATE(8425),
    [sym_let_module_expression] = STATE(8425),
    [sym_let_open_expression] = STATE(8425),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_let_exception_expression] = STATE(8425),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2428),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym_sign_operator] = STATE(2416),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__instance_variable_name] = STATE(21038),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [sym__lowercase_identifier] = ACTIONS(2351),
    [anon_sym_let] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_fun] = ACTIONS(2627),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2629),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(983),
    [anon_sym_match] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2633),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_lazy] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2637),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2429] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8727),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2429),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2430] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8767),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(8945),
    [sym__tuple_expression] = STATE(8455),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2430),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2431] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8774),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2431),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2432] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8781),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2432),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2433] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8784),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2433),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2434] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8787),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2434),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2435] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8788),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2435),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2436] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8789),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2436),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2437] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8793),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2437),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2438] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8794),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2438),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2439] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8796),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2439),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2440] = {
    [sym_value_definition] = STATE(20120),
    [sym__simple_expression] = STATE(1814),
    [sym__expression] = STATE(8799),
    [sym_typed_expression] = STATE(3882),
    [sym_labeled_tuple_element] = STATE(20081),
    [sym__tuple_expression] = STATE(8512),
    [sym_cons_expression] = STATE(8519),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_application_expression] = STATE(8519),
    [sym_prefix_expression] = STATE(3882),
    [sym_sign_expression] = STATE(8519),
    [sym_hash_expression] = STATE(3882),
    [sym_infix_expression] = STATE(8519),
    [sym_field_get_expression] = STATE(3598),
    [sym_array_get_expression] = STATE(3598),
    [sym_string_get_expression] = STATE(3598),
    [sym_bigarray_get_expression] = STATE(3598),
    [sym_set_expression] = STATE(8519),
    [sym_if_expression] = STATE(8519),
    [sym_while_expression] = STATE(8519),
    [sym_for_expression] = STATE(8519),
    [sym_match_expression] = STATE(8519),
    [sym_function_expression] = STATE(8519),
    [sym_fun_expression] = STATE(8519),
    [sym_try_expression] = STATE(8519),
    [sym_let_expression] = STATE(8519),
    [sym_coercion_expression] = STATE(3882),
    [sym_assert_expression] = STATE(8519),
    [sym_lazy_expression] = STATE(8519),
    [sym_let_module_expression] = STATE(8519),
    [sym_let_open_expression] = STATE(8519),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_let_exception_expression] = STATE(8519),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2440),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym_sign_operator] = STATE(2429),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__instance_variable_name] = STATE(20087),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [sym__lowercase_identifier] = ACTIONS(755),
    [anon_sym_let] = ACTIONS(757),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_fun] = ACTIONS(769),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_match] = ACTIONS(775),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(87),
    [anon_sym_lazy] = ACTIONS(89),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3043),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3045),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(801),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2441] = {
    [sym_value_definition] = STATE(18604),
    [sym__simple_expression] = STATE(2520),
    [sym__expression] = STATE(12753),
    [sym_typed_expression] = STATE(6791),
    [sym_labeled_tuple_element] = STATE(20755),
    [sym__tuple_expression] = STATE(8440),
    [sym_cons_expression] = STATE(8443),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_application_expression] = STATE(8443),
    [sym_prefix_expression] = STATE(6791),
    [sym_sign_expression] = STATE(8443),
    [sym_hash_expression] = STATE(6791),
    [sym_infix_expression] = STATE(8443),
    [sym_field_get_expression] = STATE(6259),
    [sym_array_get_expression] = STATE(6259),
    [sym_string_get_expression] = STATE(6259),
    [sym_bigarray_get_expression] = STATE(6259),
    [sym_set_expression] = STATE(8443),
    [sym_if_expression] = STATE(8443),
    [sym_while_expression] = STATE(8443),
    [sym_for_expression] = STATE(8443),
    [sym_match_expression] = STATE(8443),
    [sym_function_expression] = STATE(8443),
    [sym_fun_expression] = STATE(8443),
    [sym_try_expression] = STATE(8443),
    [sym_let_expression] = STATE(8443),
    [sym_coercion_expression] = STATE(6791),
    [sym_assert_expression] = STATE(8443),
    [sym_lazy_expression] = STATE(8443),
    [sym_let_module_expression] = STATE(8443),
    [sym_let_open_expression] = STATE(8443),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_let_exception_expression] = STATE(8443),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2441),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym_sign_operator] = STATE(2156),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__instance_variable_name] = STATE(20757),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [sym__lowercase_identifier] = ACTIONS(2299),
    [anon_sym_let] = ACTIONS(2301),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_fun] = ACTIONS(2313),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2317),
    [anon_sym_while] = ACTIONS(935),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_match] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2321),
    [anon_sym_try] = ACTIONS(2323),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_lazy] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(105),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(113),
    [sym_let_operator] = ACTIONS(419),
    [sym_match_operator] = ACTIONS(2345),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2442] = {
    [sym__simple_expression] = STATE(3320),
    [sym_typed_expression] = STATE(3312),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_labeled_argument] = STATE(4166),
    [sym_prefix_expression] = STATE(3312),
    [sym_hash_expression] = STATE(3312),
    [sym_field_get_expression] = STATE(3312),
    [sym_array_get_expression] = STATE(3312),
    [sym_string_get_expression] = STATE(3312),
    [sym_bigarray_get_expression] = STATE(3312),
    [sym_coercion_expression] = STATE(3312),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(2442),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [aux_sym_class_application_repeat1] = STATE(2442),
    [sym__lowercase_identifier] = ACTIONS(3787),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(3794),
    [anon_sym_QMARK] = ACTIONS(3794),
    [anon_sym_LPAREN] = ACTIONS(3797),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(3800),
    [anon_sym_true] = ACTIONS(3803),
    [anon_sym_false] = ACTIONS(3803),
    [anon_sym_LBRACE] = ACTIONS(3806),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(3809),
    [anon_sym_in] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(3812),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(3815),
    [anon_sym_LBRACE_LT] = ACTIONS(3818),
    [anon_sym_begin] = ACTIONS(3821),
    [sym_ocamlyacc_value] = ACTIONS(3824),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3827),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3830),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(3833),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(3836),
    [anon_sym_DQUOTE] = ACTIONS(3839),
    [sym_prefix_operator] = ACTIONS(3842),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(3845),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(3848),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2443] = {
    [sym__simple_expression] = STATE(3261),
    [sym_typed_expression] = STATE(3250),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_labeled_argument] = STATE(4325),
    [sym_prefix_expression] = STATE(3250),
    [sym_hash_expression] = STATE(3250),
    [sym_field_get_expression] = STATE(3250),
    [sym_array_get_expression] = STATE(3250),
    [sym_string_get_expression] = STATE(3250),
    [sym_bigarray_get_expression] = STATE(3250),
    [sym_coercion_expression] = STATE(3250),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(2443),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [aux_sym_class_application_repeat1] = STATE(2447),
    [sym__lowercase_identifier] = ACTIONS(3189),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3195),
    [anon_sym_QMARK] = ACTIONS(3195),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_LBRACE] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(383),
    [anon_sym_in] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(387),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(397),
    [anon_sym_LBRACE_LT] = ACTIONS(399),
    [anon_sym_begin] = ACTIONS(401),
    [sym_ocamlyacc_value] = ACTIONS(403),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(405),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(407),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(411),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(415),
    [sym_prefix_operator] = ACTIONS(417),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(423),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2444] = {
    [sym__simple_expression] = STATE(4397),
    [sym_typed_expression] = STATE(4323),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_labeled_argument] = STATE(4774),
    [sym_prefix_expression] = STATE(4323),
    [sym_hash_expression] = STATE(4323),
    [sym_field_get_expression] = STATE(4323),
    [sym_array_get_expression] = STATE(4323),
    [sym_string_get_expression] = STATE(4323),
    [sym_bigarray_get_expression] = STATE(4323),
    [sym_coercion_expression] = STATE(4323),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2444),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [aux_sym_class_application_repeat1] = STATE(2463),
    [sym__lowercase_identifier] = ACTIONS(3855),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3857),
    [anon_sym_QMARK] = ACTIONS(3857),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_DOT] = ACTIONS(3859),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_POUND] = ACTIONS(3861),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(893),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(895),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3863),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2445] = {
    [sym__simple_expression] = STATE(4258),
    [sym_typed_expression] = STATE(4163),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_labeled_argument] = STATE(4776),
    [sym_prefix_expression] = STATE(4163),
    [sym_hash_expression] = STATE(4163),
    [sym_field_get_expression] = STATE(4163),
    [sym_array_get_expression] = STATE(4163),
    [sym_string_get_expression] = STATE(4163),
    [sym_bigarray_get_expression] = STATE(4163),
    [sym_coercion_expression] = STATE(4163),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2445),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [aux_sym_class_application_repeat1] = STATE(2465),
    [sym__lowercase_identifier] = ACTIONS(3865),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3867),
    [anon_sym_QMARK] = ACTIONS(3867),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_POUND] = ACTIONS(3871),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(841),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(843),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3873),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2446] = {
    [sym__simple_expression] = STATE(3320),
    [sym_typed_expression] = STATE(3312),
    [sym_list_expression] = STATE(3312),
    [sym_array_expression] = STATE(3312),
    [sym_record_expression] = STATE(3312),
    [sym_labeled_argument] = STATE(4166),
    [sym_prefix_expression] = STATE(3312),
    [sym_hash_expression] = STATE(3312),
    [sym_field_get_expression] = STATE(3312),
    [sym_array_get_expression] = STATE(3312),
    [sym_string_get_expression] = STATE(3312),
    [sym_bigarray_get_expression] = STATE(3312),
    [sym_coercion_expression] = STATE(3312),
    [sym_local_open_expression] = STATE(3312),
    [sym_package_expression] = STATE(3312),
    [sym_new_expression] = STATE(3312),
    [sym_object_copy_expression] = STATE(3312),
    [sym_method_invocation] = STATE(3312),
    [sym_object_expression] = STATE(3312),
    [sym_parenthesized_expression] = STATE(3312),
    [sym_attribute] = STATE(2446),
    [sym_extension] = STATE(3312),
    [sym_quoted_extension] = STATE(3312),
    [sym__constant] = STATE(3312),
    [sym_number] = STATE(3351),
    [sym_character] = STATE(3351),
    [sym_string] = STATE(3351),
    [sym_quoted_string] = STATE(3351),
    [sym_boolean] = STATE(3351),
    [sym_unit] = STATE(3351),
    [sym__value_name] = STATE(3358),
    [sym_parenthesized_operator] = STATE(3440),
    [sym_value_path] = STATE(3312),
    [sym_module_path] = STATE(19605),
    [sym_constructor_path] = STATE(3312),
    [sym__constructor_name] = STATE(3458),
    [sym_tag] = STATE(3312),
    [aux_sym_class_application_repeat1] = STATE(2442),
    [sym__lowercase_identifier] = ACTIONS(3203),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3205),
    [anon_sym_QMARK] = ACTIONS(3205),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(433),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(437),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(439),
    [anon_sym_in] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(443),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(453),
    [anon_sym_LBRACE_LT] = ACTIONS(455),
    [anon_sym_begin] = ACTIONS(457),
    [sym_ocamlyacc_value] = ACTIONS(459),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(461),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(463),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(465),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_prefix_operator] = ACTIONS(471),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(475),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(477),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2447] = {
    [sym__simple_expression] = STATE(3261),
    [sym_typed_expression] = STATE(3250),
    [sym_list_expression] = STATE(3250),
    [sym_array_expression] = STATE(3250),
    [sym_record_expression] = STATE(3250),
    [sym_labeled_argument] = STATE(4325),
    [sym_prefix_expression] = STATE(3250),
    [sym_hash_expression] = STATE(3250),
    [sym_field_get_expression] = STATE(3250),
    [sym_array_get_expression] = STATE(3250),
    [sym_string_get_expression] = STATE(3250),
    [sym_bigarray_get_expression] = STATE(3250),
    [sym_coercion_expression] = STATE(3250),
    [sym_local_open_expression] = STATE(3250),
    [sym_package_expression] = STATE(3250),
    [sym_new_expression] = STATE(3250),
    [sym_object_copy_expression] = STATE(3250),
    [sym_method_invocation] = STATE(3250),
    [sym_object_expression] = STATE(3250),
    [sym_parenthesized_expression] = STATE(3250),
    [sym_attribute] = STATE(2447),
    [sym_extension] = STATE(3250),
    [sym_quoted_extension] = STATE(3250),
    [sym__constant] = STATE(3250),
    [sym_number] = STATE(3462),
    [sym_character] = STATE(3462),
    [sym_string] = STATE(3462),
    [sym_quoted_string] = STATE(3462),
    [sym_boolean] = STATE(3462),
    [sym_unit] = STATE(3462),
    [sym__value_name] = STATE(3297),
    [sym_parenthesized_operator] = STATE(3362),
    [sym_value_path] = STATE(3250),
    [sym_module_path] = STATE(19490),
    [sym_constructor_path] = STATE(3250),
    [sym__constructor_name] = STATE(3463),
    [sym_tag] = STATE(3250),
    [aux_sym_class_application_repeat1] = STATE(2447),
    [sym__lowercase_identifier] = ACTIONS(3875),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(3878),
    [anon_sym_QMARK] = ACTIONS(3878),
    [anon_sym_LPAREN] = ACTIONS(3881),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(3884),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(3887),
    [anon_sym_false] = ACTIONS(3887),
    [anon_sym_LBRACE] = ACTIONS(3890),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(3893),
    [anon_sym_in] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(3896),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(3899),
    [anon_sym_LBRACE_LT] = ACTIONS(3902),
    [anon_sym_begin] = ACTIONS(3905),
    [sym_ocamlyacc_value] = ACTIONS(3908),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3911),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3914),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(3917),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(3920),
    [anon_sym_DQUOTE] = ACTIONS(3923),
    [sym_prefix_operator] = ACTIONS(3926),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(3929),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(3932),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2448] = {
    [sym__simple_expression] = STATE(4482),
    [sym_typed_expression] = STATE(4471),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_labeled_argument] = STATE(4783),
    [sym_prefix_expression] = STATE(4471),
    [sym_hash_expression] = STATE(4471),
    [sym_field_get_expression] = STATE(4471),
    [sym_array_get_expression] = STATE(4471),
    [sym_string_get_expression] = STATE(4471),
    [sym_bigarray_get_expression] = STATE(4471),
    [sym_coercion_expression] = STATE(4471),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(2448),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [aux_sym_class_application_repeat1] = STATE(2468),
    [sym__lowercase_identifier] = ACTIONS(3935),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_DOT] = ACTIONS(3939),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_POUND] = ACTIONS(3941),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(3943),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2449] = {
    [sym__simple_expression] = STATE(3662),
    [sym_typed_expression] = STATE(3632),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_labeled_argument] = STATE(4470),
    [sym_prefix_expression] = STATE(3632),
    [sym_hash_expression] = STATE(3632),
    [sym_field_get_expression] = STATE(3632),
    [sym_array_get_expression] = STATE(3632),
    [sym_string_get_expression] = STATE(3632),
    [sym_bigarray_get_expression] = STATE(3632),
    [sym_coercion_expression] = STATE(3632),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2449),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [aux_sym_class_application_repeat1] = STATE(2449),
    [sym__lowercase_identifier] = ACTIONS(3945),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_QMARK] = ACTIONS(3948),
    [anon_sym_LPAREN] = ACTIONS(3951),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(3954),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(3957),
    [anon_sym_false] = ACTIONS(3957),
    [anon_sym_LBRACE] = ACTIONS(3960),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(3963),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(3966),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(3969),
    [anon_sym_LBRACE_LT] = ACTIONS(3972),
    [anon_sym_begin] = ACTIONS(3975),
    [sym_ocamlyacc_value] = ACTIONS(3978),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(3981),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(3984),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(3987),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(3990),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_prefix_operator] = ACTIONS(3996),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(3999),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4002),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2450] = {
    [sym__simple_expression] = STATE(3531),
    [sym_typed_expression] = STATE(3522),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_labeled_argument] = STATE(4513),
    [sym_prefix_expression] = STATE(3522),
    [sym_hash_expression] = STATE(3522),
    [sym_field_get_expression] = STATE(3522),
    [sym_array_get_expression] = STATE(3522),
    [sym_string_get_expression] = STATE(3522),
    [sym_bigarray_get_expression] = STATE(3522),
    [sym_coercion_expression] = STATE(3522),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2450),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [aux_sym_class_application_repeat1] = STATE(2450),
    [sym__lowercase_identifier] = ACTIONS(4005),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4008),
    [anon_sym_QMARK] = ACTIONS(4008),
    [anon_sym_LPAREN] = ACTIONS(4011),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4014),
    [anon_sym_true] = ACTIONS(4017),
    [anon_sym_false] = ACTIONS(4017),
    [anon_sym_LBRACE] = ACTIONS(4020),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4023),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4026),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(4029),
    [anon_sym_LBRACE_LT] = ACTIONS(4032),
    [anon_sym_begin] = ACTIONS(4035),
    [sym_ocamlyacc_value] = ACTIONS(4038),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4041),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4044),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4047),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4050),
    [anon_sym_DQUOTE] = ACTIONS(4053),
    [sym_prefix_operator] = ACTIONS(4056),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4059),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4062),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2451] = {
    [sym__simple_expression] = STATE(3674),
    [sym_typed_expression] = STATE(3757),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_labeled_argument] = STATE(4505),
    [sym_prefix_expression] = STATE(3757),
    [sym_hash_expression] = STATE(3757),
    [sym_field_get_expression] = STATE(3757),
    [sym_array_get_expression] = STATE(3757),
    [sym_string_get_expression] = STATE(3757),
    [sym_bigarray_get_expression] = STATE(3757),
    [sym_coercion_expression] = STATE(3757),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2451),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [aux_sym_class_application_repeat1] = STATE(2453),
    [sym__lowercase_identifier] = ACTIONS(3701),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(491),
    [anon_sym_false] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(495),
    [anon_sym_in] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(499),
    [anon_sym_new] = ACTIONS(509),
    [anon_sym_LBRACE_LT] = ACTIONS(511),
    [anon_sym_begin] = ACTIONS(513),
    [sym_ocamlyacc_value] = ACTIONS(515),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(517),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(519),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(521),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_prefix_operator] = ACTIONS(527),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(531),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(533),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2452] = {
    [sym__simple_expression] = STATE(3662),
    [sym_typed_expression] = STATE(3632),
    [sym_list_expression] = STATE(3632),
    [sym_array_expression] = STATE(3632),
    [sym_record_expression] = STATE(3632),
    [sym_labeled_argument] = STATE(4470),
    [sym_prefix_expression] = STATE(3632),
    [sym_hash_expression] = STATE(3632),
    [sym_field_get_expression] = STATE(3632),
    [sym_array_get_expression] = STATE(3632),
    [sym_string_get_expression] = STATE(3632),
    [sym_bigarray_get_expression] = STATE(3632),
    [sym_coercion_expression] = STATE(3632),
    [sym_local_open_expression] = STATE(3632),
    [sym_package_expression] = STATE(3632),
    [sym_new_expression] = STATE(3632),
    [sym_object_copy_expression] = STATE(3632),
    [sym_method_invocation] = STATE(3632),
    [sym_object_expression] = STATE(3632),
    [sym_parenthesized_expression] = STATE(3632),
    [sym_attribute] = STATE(2452),
    [sym_extension] = STATE(3632),
    [sym_quoted_extension] = STATE(3632),
    [sym__constant] = STATE(3632),
    [sym_number] = STATE(3524),
    [sym_character] = STATE(3524),
    [sym_string] = STATE(3524),
    [sym_quoted_string] = STATE(3524),
    [sym_boolean] = STATE(3524),
    [sym_unit] = STATE(3524),
    [sym__value_name] = STATE(3523),
    [sym_parenthesized_operator] = STATE(3706),
    [sym_value_path] = STATE(3632),
    [sym_module_path] = STATE(19718),
    [sym_constructor_path] = STATE(3632),
    [sym__constructor_name] = STATE(3764),
    [sym_tag] = STATE(3632),
    [aux_sym_class_application_repeat1] = STATE(2449),
    [sym__lowercase_identifier] = ACTIONS(3405),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3407),
    [anon_sym_QMARK] = ACTIONS(3407),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(597),
    [anon_sym_false] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(601),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(605),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(615),
    [anon_sym_LBRACE_LT] = ACTIONS(617),
    [anon_sym_begin] = ACTIONS(619),
    [sym_ocamlyacc_value] = ACTIONS(621),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(623),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(625),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(627),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(629),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_prefix_operator] = ACTIONS(633),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(637),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(639),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2453] = {
    [sym__simple_expression] = STATE(3674),
    [sym_typed_expression] = STATE(3757),
    [sym_list_expression] = STATE(3757),
    [sym_array_expression] = STATE(3757),
    [sym_record_expression] = STATE(3757),
    [sym_labeled_argument] = STATE(4505),
    [sym_prefix_expression] = STATE(3757),
    [sym_hash_expression] = STATE(3757),
    [sym_field_get_expression] = STATE(3757),
    [sym_array_get_expression] = STATE(3757),
    [sym_string_get_expression] = STATE(3757),
    [sym_bigarray_get_expression] = STATE(3757),
    [sym_coercion_expression] = STATE(3757),
    [sym_local_open_expression] = STATE(3757),
    [sym_package_expression] = STATE(3757),
    [sym_new_expression] = STATE(3757),
    [sym_object_copy_expression] = STATE(3757),
    [sym_method_invocation] = STATE(3757),
    [sym_object_expression] = STATE(3757),
    [sym_parenthesized_expression] = STATE(3757),
    [sym_attribute] = STATE(2453),
    [sym_extension] = STATE(3757),
    [sym_quoted_extension] = STATE(3757),
    [sym__constant] = STATE(3757),
    [sym_number] = STATE(3574),
    [sym_character] = STATE(3574),
    [sym_string] = STATE(3574),
    [sym_quoted_string] = STATE(3574),
    [sym_boolean] = STATE(3574),
    [sym_unit] = STATE(3574),
    [sym__value_name] = STATE(3640),
    [sym_parenthesized_operator] = STATE(3554),
    [sym_value_path] = STATE(3757),
    [sym_module_path] = STATE(21100),
    [sym_constructor_path] = STATE(3757),
    [sym__constructor_name] = STATE(3721),
    [sym_tag] = STATE(3757),
    [aux_sym_class_application_repeat1] = STATE(2453),
    [sym__lowercase_identifier] = ACTIONS(4065),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4068),
    [anon_sym_QMARK] = ACTIONS(4068),
    [anon_sym_LPAREN] = ACTIONS(4071),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4074),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(4077),
    [anon_sym_false] = ACTIONS(4077),
    [anon_sym_LBRACE] = ACTIONS(4080),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4083),
    [anon_sym_in] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4086),
    [anon_sym_new] = ACTIONS(4089),
    [anon_sym_LBRACE_LT] = ACTIONS(4092),
    [anon_sym_begin] = ACTIONS(4095),
    [sym_ocamlyacc_value] = ACTIONS(4098),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4101),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4104),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4107),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4110),
    [anon_sym_DQUOTE] = ACTIONS(4113),
    [sym_prefix_operator] = ACTIONS(4116),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4119),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4122),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2454] = {
    [sym__simple_expression] = STATE(3648),
    [sym_typed_expression] = STATE(3557),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_labeled_argument] = STATE(4699),
    [sym_prefix_expression] = STATE(3557),
    [sym_hash_expression] = STATE(3557),
    [sym_field_get_expression] = STATE(3557),
    [sym_array_get_expression] = STATE(3557),
    [sym_string_get_expression] = STATE(3557),
    [sym_bigarray_get_expression] = STATE(3557),
    [sym_coercion_expression] = STATE(3557),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2454),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [aux_sym_class_application_repeat1] = STATE(2454),
    [sym__lowercase_identifier] = ACTIONS(4125),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4128),
    [anon_sym_QMARK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4131),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4134),
    [anon_sym_true] = ACTIONS(4137),
    [anon_sym_false] = ACTIONS(4137),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4143),
    [anon_sym_in] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4146),
    [anon_sym_new] = ACTIONS(4149),
    [anon_sym_LBRACE_LT] = ACTIONS(4152),
    [anon_sym_begin] = ACTIONS(4155),
    [sym_ocamlyacc_value] = ACTIONS(4158),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4161),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4164),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4167),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4170),
    [anon_sym_DQUOTE] = ACTIONS(4173),
    [sym_prefix_operator] = ACTIONS(4176),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4179),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4182),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2455] = {
    [sym__simple_expression] = STATE(4458),
    [sym_typed_expression] = STATE(4695),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_labeled_argument] = STATE(4786),
    [sym_prefix_expression] = STATE(4695),
    [sym_hash_expression] = STATE(4695),
    [sym_field_get_expression] = STATE(4695),
    [sym_array_get_expression] = STATE(4695),
    [sym_string_get_expression] = STATE(4695),
    [sym_bigarray_get_expression] = STATE(4695),
    [sym_coercion_expression] = STATE(4695),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(2455),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [aux_sym_class_application_repeat1] = STATE(2466),
    [sym__lowercase_identifier] = ACTIONS(4185),
    [anon_sym_SEMI_SEMI] = ACTIONS(3191),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(4187),
    [anon_sym_QMARK] = ACTIONS(4187),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_DOT] = ACTIONS(4189),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_SEMI] = ACTIONS(3193),
    [anon_sym_exception] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_open] = ACTIONS(3193),
    [anon_sym_include] = ACTIONS(3193),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_POUND] = ACTIONS(4191),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4193),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(3193),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2456] = {
    [sym__simple_expression] = STATE(3648),
    [sym_typed_expression] = STATE(3557),
    [sym_list_expression] = STATE(3557),
    [sym_array_expression] = STATE(3557),
    [sym_record_expression] = STATE(3557),
    [sym_labeled_argument] = STATE(4699),
    [sym_prefix_expression] = STATE(3557),
    [sym_hash_expression] = STATE(3557),
    [sym_field_get_expression] = STATE(3557),
    [sym_array_get_expression] = STATE(3557),
    [sym_string_get_expression] = STATE(3557),
    [sym_bigarray_get_expression] = STATE(3557),
    [sym_coercion_expression] = STATE(3557),
    [sym_local_open_expression] = STATE(3557),
    [sym_package_expression] = STATE(3557),
    [sym_new_expression] = STATE(3557),
    [sym_object_copy_expression] = STATE(3557),
    [sym_method_invocation] = STATE(3557),
    [sym_object_expression] = STATE(3557),
    [sym_parenthesized_expression] = STATE(3557),
    [sym_attribute] = STATE(2456),
    [sym_extension] = STATE(3557),
    [sym_quoted_extension] = STATE(3557),
    [sym__constant] = STATE(3557),
    [sym_number] = STATE(3809),
    [sym_character] = STATE(3809),
    [sym_string] = STATE(3809),
    [sym_quoted_string] = STATE(3809),
    [sym_boolean] = STATE(3809),
    [sym_unit] = STATE(3809),
    [sym__value_name] = STATE(3643),
    [sym_parenthesized_operator] = STATE(3769),
    [sym_value_path] = STATE(3557),
    [sym_module_path] = STATE(18672),
    [sym_constructor_path] = STATE(3557),
    [sym__constructor_name] = STATE(3811),
    [sym_tag] = STATE(3557),
    [aux_sym_class_application_repeat1] = STATE(2454),
    [sym__lowercase_identifier] = ACTIONS(3475),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3477),
    [anon_sym_QMARK] = ACTIONS(3477),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(541),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(545),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(547),
    [anon_sym_in] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(551),
    [anon_sym_new] = ACTIONS(561),
    [anon_sym_LBRACE_LT] = ACTIONS(563),
    [anon_sym_begin] = ACTIONS(565),
    [sym_ocamlyacc_value] = ACTIONS(567),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(569),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(571),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(573),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [sym_prefix_operator] = ACTIONS(579),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(583),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(585),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2457] = {
    [sym__simple_expression] = STATE(3531),
    [sym_typed_expression] = STATE(3522),
    [sym_list_expression] = STATE(3522),
    [sym_array_expression] = STATE(3522),
    [sym_record_expression] = STATE(3522),
    [sym_labeled_argument] = STATE(4513),
    [sym_prefix_expression] = STATE(3522),
    [sym_hash_expression] = STATE(3522),
    [sym_field_get_expression] = STATE(3522),
    [sym_array_get_expression] = STATE(3522),
    [sym_string_get_expression] = STATE(3522),
    [sym_bigarray_get_expression] = STATE(3522),
    [sym_coercion_expression] = STATE(3522),
    [sym_local_open_expression] = STATE(3522),
    [sym_package_expression] = STATE(3522),
    [sym_new_expression] = STATE(3522),
    [sym_object_copy_expression] = STATE(3522),
    [sym_method_invocation] = STATE(3522),
    [sym_object_expression] = STATE(3522),
    [sym_parenthesized_expression] = STATE(3522),
    [sym_attribute] = STATE(2457),
    [sym_extension] = STATE(3522),
    [sym_quoted_extension] = STATE(3522),
    [sym__constant] = STATE(3522),
    [sym_number] = STATE(3810),
    [sym_character] = STATE(3810),
    [sym_string] = STATE(3810),
    [sym_quoted_string] = STATE(3810),
    [sym_boolean] = STATE(3810),
    [sym_unit] = STATE(3810),
    [sym__value_name] = STATE(3606),
    [sym_parenthesized_operator] = STATE(3709),
    [sym_value_path] = STATE(3522),
    [sym_module_path] = STATE(19755),
    [sym_constructor_path] = STATE(3522),
    [sym__constructor_name] = STATE(3521),
    [sym_tag] = STATE(3522),
    [aux_sym_class_application_repeat1] = STATE(2450),
    [sym__lowercase_identifier] = ACTIONS(3427),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3429),
    [anon_sym_QMARK] = ACTIONS(3429),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_LBRACE] = ACTIONS(651),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(653),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(657),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(667),
    [anon_sym_LBRACE_LT] = ACTIONS(669),
    [anon_sym_begin] = ACTIONS(671),
    [sym_ocamlyacc_value] = ACTIONS(673),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(675),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(677),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(679),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE] = ACTIONS(683),
    [sym_prefix_operator] = ACTIONS(685),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(689),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(691),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2458] = {
    [sym__simple_expression] = STATE(4025),
    [sym_typed_expression] = STATE(3882),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_labeled_argument] = STATE(4773),
    [sym_prefix_expression] = STATE(3882),
    [sym_hash_expression] = STATE(3882),
    [sym_field_get_expression] = STATE(3882),
    [sym_array_get_expression] = STATE(3882),
    [sym_string_get_expression] = STATE(3882),
    [sym_bigarray_get_expression] = STATE(3882),
    [sym_coercion_expression] = STATE(3882),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2458),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [aux_sym_class_application_repeat1] = STATE(2461),
    [sym__lowercase_identifier] = ACTIONS(3757),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3759),
    [anon_sym_QMARK] = ACTIONS(3759),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(761),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(771),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_LBRACE_LT] = ACTIONS(783),
    [anon_sym_begin] = ACTIONS(785),
    [sym_ocamlyacc_value] = ACTIONS(787),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(789),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(791),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(793),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [sym_prefix_operator] = ACTIONS(799),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(803),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2459] = {
    [sym__simple_expression] = STATE(4078),
    [sym_typed_expression] = STATE(4014),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_labeled_argument] = STATE(4770),
    [sym_prefix_expression] = STATE(4014),
    [sym_hash_expression] = STATE(4014),
    [sym_field_get_expression] = STATE(4014),
    [sym_array_get_expression] = STATE(4014),
    [sym_string_get_expression] = STATE(4014),
    [sym_bigarray_get_expression] = STATE(4014),
    [sym_coercion_expression] = STATE(4014),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(2459),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [aux_sym_class_application_repeat1] = STATE(2460),
    [sym__lowercase_identifier] = ACTIONS(3767),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3769),
    [anon_sym_QMARK] = ACTIONS(3769),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(715),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(719),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_LBRACE_LT] = ACTIONS(731),
    [anon_sym_begin] = ACTIONS(733),
    [sym_ocamlyacc_value] = ACTIONS(735),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(737),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(739),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(741),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [sym_prefix_operator] = ACTIONS(747),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(751),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2460] = {
    [sym__simple_expression] = STATE(4078),
    [sym_typed_expression] = STATE(4014),
    [sym_list_expression] = STATE(4014),
    [sym_array_expression] = STATE(4014),
    [sym_record_expression] = STATE(4014),
    [sym_labeled_argument] = STATE(4770),
    [sym_prefix_expression] = STATE(4014),
    [sym_hash_expression] = STATE(4014),
    [sym_field_get_expression] = STATE(4014),
    [sym_array_get_expression] = STATE(4014),
    [sym_string_get_expression] = STATE(4014),
    [sym_bigarray_get_expression] = STATE(4014),
    [sym_coercion_expression] = STATE(4014),
    [sym_local_open_expression] = STATE(4014),
    [sym_package_expression] = STATE(4014),
    [sym_new_expression] = STATE(4014),
    [sym_object_copy_expression] = STATE(4014),
    [sym_method_invocation] = STATE(4014),
    [sym_object_expression] = STATE(4014),
    [sym_parenthesized_expression] = STATE(4014),
    [sym_attribute] = STATE(2460),
    [sym_extension] = STATE(4014),
    [sym_quoted_extension] = STATE(4014),
    [sym__constant] = STATE(4014),
    [sym_number] = STATE(3857),
    [sym_character] = STATE(3857),
    [sym_string] = STATE(3857),
    [sym_quoted_string] = STATE(3857),
    [sym_boolean] = STATE(3857),
    [sym_unit] = STATE(3857),
    [sym__value_name] = STATE(4074),
    [sym_parenthesized_operator] = STATE(3949),
    [sym_value_path] = STATE(4014),
    [sym_module_path] = STATE(19331),
    [sym_constructor_path] = STATE(4014),
    [sym__constructor_name] = STATE(3859),
    [sym_tag] = STATE(4014),
    [aux_sym_class_application_repeat1] = STATE(2460),
    [sym__lowercase_identifier] = ACTIONS(4195),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4198),
    [anon_sym_QMARK] = ACTIONS(4198),
    [anon_sym_LPAREN] = ACTIONS(4201),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_true] = ACTIONS(4207),
    [anon_sym_false] = ACTIONS(4207),
    [anon_sym_LBRACE] = ACTIONS(4210),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4213),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4216),
    [anon_sym_new] = ACTIONS(4219),
    [anon_sym_LBRACE_LT] = ACTIONS(4222),
    [anon_sym_begin] = ACTIONS(4225),
    [sym_ocamlyacc_value] = ACTIONS(4228),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4231),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4234),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4237),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4240),
    [anon_sym_DQUOTE] = ACTIONS(4243),
    [sym_prefix_operator] = ACTIONS(4246),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4249),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4252),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2461] = {
    [sym__simple_expression] = STATE(4025),
    [sym_typed_expression] = STATE(3882),
    [sym_list_expression] = STATE(3882),
    [sym_array_expression] = STATE(3882),
    [sym_record_expression] = STATE(3882),
    [sym_labeled_argument] = STATE(4773),
    [sym_prefix_expression] = STATE(3882),
    [sym_hash_expression] = STATE(3882),
    [sym_field_get_expression] = STATE(3882),
    [sym_array_get_expression] = STATE(3882),
    [sym_string_get_expression] = STATE(3882),
    [sym_bigarray_get_expression] = STATE(3882),
    [sym_coercion_expression] = STATE(3882),
    [sym_local_open_expression] = STATE(3882),
    [sym_package_expression] = STATE(3882),
    [sym_new_expression] = STATE(3882),
    [sym_object_copy_expression] = STATE(3882),
    [sym_method_invocation] = STATE(3882),
    [sym_object_expression] = STATE(3882),
    [sym_parenthesized_expression] = STATE(3882),
    [sym_attribute] = STATE(2461),
    [sym_extension] = STATE(3882),
    [sym_quoted_extension] = STATE(3882),
    [sym__constant] = STATE(3882),
    [sym_number] = STATE(3838),
    [sym_character] = STATE(3838),
    [sym_string] = STATE(3838),
    [sym_quoted_string] = STATE(3838),
    [sym_boolean] = STATE(3838),
    [sym_unit] = STATE(3838),
    [sym__value_name] = STATE(4010),
    [sym_parenthesized_operator] = STATE(3867),
    [sym_value_path] = STATE(3882),
    [sym_module_path] = STATE(19251),
    [sym_constructor_path] = STATE(3882),
    [sym__constructor_name] = STATE(3839),
    [sym_tag] = STATE(3882),
    [aux_sym_class_application_repeat1] = STATE(2461),
    [sym__lowercase_identifier] = ACTIONS(4255),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4258),
    [anon_sym_QMARK] = ACTIONS(4258),
    [anon_sym_LPAREN] = ACTIONS(4261),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4264),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(4267),
    [anon_sym_false] = ACTIONS(4267),
    [anon_sym_LBRACE] = ACTIONS(4270),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4273),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4276),
    [anon_sym_new] = ACTIONS(4279),
    [anon_sym_LBRACE_LT] = ACTIONS(4282),
    [anon_sym_begin] = ACTIONS(4285),
    [sym_ocamlyacc_value] = ACTIONS(4288),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4291),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4294),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4297),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4300),
    [anon_sym_DQUOTE] = ACTIONS(4303),
    [sym_prefix_operator] = ACTIONS(4306),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4309),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4312),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2462] = {
    [sym__simple_expression] = STATE(4258),
    [sym_typed_expression] = STATE(4163),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_labeled_argument] = STATE(4776),
    [sym_prefix_expression] = STATE(4163),
    [sym_hash_expression] = STATE(4163),
    [sym_field_get_expression] = STATE(4163),
    [sym_array_get_expression] = STATE(4163),
    [sym_string_get_expression] = STATE(4163),
    [sym_bigarray_get_expression] = STATE(4163),
    [sym_coercion_expression] = STATE(4163),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2462),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [aux_sym_class_application_repeat1] = STATE(2462),
    [sym__lowercase_identifier] = ACTIONS(4315),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4318),
    [anon_sym_QMARK] = ACTIONS(4318),
    [anon_sym_LPAREN] = ACTIONS(4321),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4324),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(4327),
    [anon_sym_false] = ACTIONS(4327),
    [anon_sym_LBRACE] = ACTIONS(4330),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4333),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4336),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(4339),
    [anon_sym_LBRACE_LT] = ACTIONS(4342),
    [anon_sym_begin] = ACTIONS(4345),
    [sym_ocamlyacc_value] = ACTIONS(4348),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4351),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4354),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4357),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4360),
    [anon_sym_DQUOTE] = ACTIONS(4363),
    [sym_prefix_operator] = ACTIONS(4366),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4369),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4372),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2463] = {
    [sym__simple_expression] = STATE(4397),
    [sym_typed_expression] = STATE(4323),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_labeled_argument] = STATE(4774),
    [sym_prefix_expression] = STATE(4323),
    [sym_hash_expression] = STATE(4323),
    [sym_field_get_expression] = STATE(4323),
    [sym_array_get_expression] = STATE(4323),
    [sym_string_get_expression] = STATE(4323),
    [sym_bigarray_get_expression] = STATE(4323),
    [sym_coercion_expression] = STATE(4323),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2463),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [aux_sym_class_application_repeat1] = STATE(2464),
    [sym__lowercase_identifier] = ACTIONS(3855),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3857),
    [anon_sym_QMARK] = ACTIONS(3857),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(865),
    [anon_sym_true] = ACTIONS(867),
    [anon_sym_false] = ACTIONS(867),
    [anon_sym_LBRACE] = ACTIONS(869),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(875),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_LBRACE_LT] = ACTIONS(887),
    [anon_sym_begin] = ACTIONS(889),
    [sym_ocamlyacc_value] = ACTIONS(891),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(893),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(895),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(897),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [sym_prefix_operator] = ACTIONS(903),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(907),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2464] = {
    [sym__simple_expression] = STATE(4397),
    [sym_typed_expression] = STATE(4323),
    [sym_list_expression] = STATE(4323),
    [sym_array_expression] = STATE(4323),
    [sym_record_expression] = STATE(4323),
    [sym_labeled_argument] = STATE(4774),
    [sym_prefix_expression] = STATE(4323),
    [sym_hash_expression] = STATE(4323),
    [sym_field_get_expression] = STATE(4323),
    [sym_array_get_expression] = STATE(4323),
    [sym_string_get_expression] = STATE(4323),
    [sym_bigarray_get_expression] = STATE(4323),
    [sym_coercion_expression] = STATE(4323),
    [sym_local_open_expression] = STATE(4323),
    [sym_package_expression] = STATE(4323),
    [sym_new_expression] = STATE(4323),
    [sym_object_copy_expression] = STATE(4323),
    [sym_method_invocation] = STATE(4323),
    [sym_object_expression] = STATE(4323),
    [sym_parenthesized_expression] = STATE(4323),
    [sym_attribute] = STATE(2464),
    [sym_extension] = STATE(4323),
    [sym_quoted_extension] = STATE(4323),
    [sym__constant] = STATE(4323),
    [sym_number] = STATE(4134),
    [sym_character] = STATE(4134),
    [sym_string] = STATE(4134),
    [sym_quoted_string] = STATE(4134),
    [sym_boolean] = STATE(4134),
    [sym_unit] = STATE(4134),
    [sym__value_name] = STATE(4385),
    [sym_parenthesized_operator] = STATE(4251),
    [sym_value_path] = STATE(4323),
    [sym_module_path] = STATE(18727),
    [sym_constructor_path] = STATE(4323),
    [sym__constructor_name] = STATE(4140),
    [sym_tag] = STATE(4323),
    [aux_sym_class_application_repeat1] = STATE(2464),
    [sym__lowercase_identifier] = ACTIONS(4375),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4378),
    [anon_sym_QMARK] = ACTIONS(4378),
    [anon_sym_LPAREN] = ACTIONS(4381),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4384),
    [anon_sym_true] = ACTIONS(4387),
    [anon_sym_false] = ACTIONS(4387),
    [anon_sym_LBRACE] = ACTIONS(4390),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4393),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4396),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(4399),
    [anon_sym_LBRACE_LT] = ACTIONS(4402),
    [anon_sym_begin] = ACTIONS(4405),
    [sym_ocamlyacc_value] = ACTIONS(4408),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4411),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4414),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4417),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4420),
    [anon_sym_DQUOTE] = ACTIONS(4423),
    [sym_prefix_operator] = ACTIONS(4426),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4429),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4432),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2465] = {
    [sym__simple_expression] = STATE(4258),
    [sym_typed_expression] = STATE(4163),
    [sym_list_expression] = STATE(4163),
    [sym_array_expression] = STATE(4163),
    [sym_record_expression] = STATE(4163),
    [sym_labeled_argument] = STATE(4776),
    [sym_prefix_expression] = STATE(4163),
    [sym_hash_expression] = STATE(4163),
    [sym_field_get_expression] = STATE(4163),
    [sym_array_get_expression] = STATE(4163),
    [sym_string_get_expression] = STATE(4163),
    [sym_bigarray_get_expression] = STATE(4163),
    [sym_coercion_expression] = STATE(4163),
    [sym_local_open_expression] = STATE(4163),
    [sym_package_expression] = STATE(4163),
    [sym_new_expression] = STATE(4163),
    [sym_object_copy_expression] = STATE(4163),
    [sym_method_invocation] = STATE(4163),
    [sym_object_expression] = STATE(4163),
    [sym_parenthesized_expression] = STATE(4163),
    [sym_attribute] = STATE(2465),
    [sym_extension] = STATE(4163),
    [sym_quoted_extension] = STATE(4163),
    [sym__constant] = STATE(4163),
    [sym_number] = STATE(4380),
    [sym_character] = STATE(4380),
    [sym_string] = STATE(4380),
    [sym_quoted_string] = STATE(4380),
    [sym_boolean] = STATE(4380),
    [sym_unit] = STATE(4380),
    [sym__value_name] = STATE(4257),
    [sym_parenthesized_operator] = STATE(4384),
    [sym_value_path] = STATE(4163),
    [sym_module_path] = STATE(18504),
    [sym_constructor_path] = STATE(4163),
    [sym__constructor_name] = STATE(4382),
    [sym_tag] = STATE(4163),
    [aux_sym_class_application_repeat1] = STATE(2462),
    [sym__lowercase_identifier] = ACTIONS(3865),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3867),
    [anon_sym_QMARK] = ACTIONS(3867),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(813),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(815),
    [anon_sym_false] = ACTIONS(815),
    [anon_sym_LBRACE] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(819),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(823),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_LBRACE_LT] = ACTIONS(835),
    [anon_sym_begin] = ACTIONS(837),
    [sym_ocamlyacc_value] = ACTIONS(839),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(841),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(843),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(845),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_prefix_operator] = ACTIONS(851),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(855),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2466] = {
    [sym__simple_expression] = STATE(4458),
    [sym_typed_expression] = STATE(4695),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_labeled_argument] = STATE(4786),
    [sym_prefix_expression] = STATE(4695),
    [sym_hash_expression] = STATE(4695),
    [sym_field_get_expression] = STATE(4695),
    [sym_array_get_expression] = STATE(4695),
    [sym_string_get_expression] = STATE(4695),
    [sym_bigarray_get_expression] = STATE(4695),
    [sym_coercion_expression] = STATE(4695),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(2466),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [aux_sym_class_application_repeat1] = STATE(2469),
    [sym__lowercase_identifier] = ACTIONS(4185),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(4187),
    [anon_sym_QMARK] = ACTIONS(4187),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(307),
    [anon_sym_true] = ACTIONS(309),
    [anon_sym_false] = ACTIONS(309),
    [anon_sym_LBRACE] = ACTIONS(311),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(321),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(325),
    [anon_sym_new] = ACTIONS(335),
    [anon_sym_LBRACE_LT] = ACTIONS(337),
    [anon_sym_begin] = ACTIONS(339),
    [sym_ocamlyacc_value] = ACTIONS(341),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(343),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(345),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(347),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(351),
    [sym_prefix_operator] = ACTIONS(353),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(359),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(363),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2467] = {
    [sym__simple_expression] = STATE(4482),
    [sym_typed_expression] = STATE(4471),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_labeled_argument] = STATE(4783),
    [sym_prefix_expression] = STATE(4471),
    [sym_hash_expression] = STATE(4471),
    [sym_field_get_expression] = STATE(4471),
    [sym_array_get_expression] = STATE(4471),
    [sym_string_get_expression] = STATE(4471),
    [sym_bigarray_get_expression] = STATE(4471),
    [sym_coercion_expression] = STATE(4471),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(2467),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [aux_sym_class_application_repeat1] = STATE(2467),
    [sym__lowercase_identifier] = ACTIONS(4435),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4438),
    [anon_sym_QMARK] = ACTIONS(4438),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4444),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(4447),
    [anon_sym_false] = ACTIONS(4447),
    [anon_sym_LBRACE] = ACTIONS(4450),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4453),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4456),
    [anon_sym_new] = ACTIONS(4459),
    [anon_sym_LBRACE_LT] = ACTIONS(4462),
    [anon_sym_begin] = ACTIONS(4465),
    [sym_ocamlyacc_value] = ACTIONS(4468),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4471),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4474),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4477),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4480),
    [anon_sym_DQUOTE] = ACTIONS(4483),
    [sym_prefix_operator] = ACTIONS(4486),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4489),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4492),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2468] = {
    [sym__simple_expression] = STATE(4482),
    [sym_typed_expression] = STATE(4471),
    [sym_list_expression] = STATE(4471),
    [sym_array_expression] = STATE(4471),
    [sym_record_expression] = STATE(4471),
    [sym_labeled_argument] = STATE(4783),
    [sym_prefix_expression] = STATE(4471),
    [sym_hash_expression] = STATE(4471),
    [sym_field_get_expression] = STATE(4471),
    [sym_array_get_expression] = STATE(4471),
    [sym_string_get_expression] = STATE(4471),
    [sym_bigarray_get_expression] = STATE(4471),
    [sym_coercion_expression] = STATE(4471),
    [sym_local_open_expression] = STATE(4471),
    [sym_package_expression] = STATE(4471),
    [sym_new_expression] = STATE(4471),
    [sym_object_copy_expression] = STATE(4471),
    [sym_method_invocation] = STATE(4471),
    [sym_object_expression] = STATE(4471),
    [sym_parenthesized_expression] = STATE(4471),
    [sym_attribute] = STATE(2468),
    [sym_extension] = STATE(4471),
    [sym_quoted_extension] = STATE(4471),
    [sym__constant] = STATE(4471),
    [sym_number] = STATE(4421),
    [sym_character] = STATE(4421),
    [sym_string] = STATE(4421),
    [sym_quoted_string] = STATE(4421),
    [sym_boolean] = STATE(4421),
    [sym_unit] = STATE(4421),
    [sym__value_name] = STATE(4446),
    [sym_parenthesized_operator] = STATE(4662),
    [sym_value_path] = STATE(4471),
    [sym_module_path] = STATE(21079),
    [sym_constructor_path] = STATE(4471),
    [sym__constructor_name] = STATE(4448),
    [sym_tag] = STATE(4471),
    [aux_sym_class_application_repeat1] = STATE(2467),
    [sym__lowercase_identifier] = ACTIONS(3935),
    [anon_sym_SEMI_SEMI] = ACTIONS(3851),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_external] = ACTIONS(3853),
    [anon_sym_type] = ACTIONS(3853),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(49),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(53),
    [anon_sym_false] = ACTIONS(53),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_SEMI] = ACTIONS(3853),
    [anon_sym_exception] = ACTIONS(3853),
    [anon_sym_module] = ACTIONS(3853),
    [anon_sym_open] = ACTIONS(3853),
    [anon_sym_include] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(73),
    [anon_sym_new] = ACTIONS(91),
    [anon_sym_LBRACE_LT] = ACTIONS(93),
    [anon_sym_begin] = ACTIONS(95),
    [sym_ocamlyacc_value] = ACTIONS(97),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(99),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(101),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(103),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(109),
    [sym_prefix_operator] = ACTIONS(111),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(119),
    [aux_sym_directive_token1] = ACTIONS(3851),
    [aux_sym_tag_token1] = ACTIONS(123),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2469] = {
    [sym__simple_expression] = STATE(4458),
    [sym_typed_expression] = STATE(4695),
    [sym_list_expression] = STATE(4695),
    [sym_array_expression] = STATE(4695),
    [sym_record_expression] = STATE(4695),
    [sym_labeled_argument] = STATE(4786),
    [sym_prefix_expression] = STATE(4695),
    [sym_hash_expression] = STATE(4695),
    [sym_field_get_expression] = STATE(4695),
    [sym_array_get_expression] = STATE(4695),
    [sym_string_get_expression] = STATE(4695),
    [sym_bigarray_get_expression] = STATE(4695),
    [sym_coercion_expression] = STATE(4695),
    [sym_local_open_expression] = STATE(4695),
    [sym_package_expression] = STATE(4695),
    [sym_new_expression] = STATE(4695),
    [sym_object_copy_expression] = STATE(4695),
    [sym_method_invocation] = STATE(4695),
    [sym_object_expression] = STATE(4695),
    [sym_parenthesized_expression] = STATE(4695),
    [sym_attribute] = STATE(2469),
    [sym_extension] = STATE(4695),
    [sym_quoted_extension] = STATE(4695),
    [sym__constant] = STATE(4695),
    [sym_number] = STATE(4735),
    [sym_character] = STATE(4735),
    [sym_string] = STATE(4735),
    [sym_quoted_string] = STATE(4735),
    [sym_boolean] = STATE(4735),
    [sym_unit] = STATE(4735),
    [sym__value_name] = STATE(4737),
    [sym_parenthesized_operator] = STATE(4691),
    [sym_value_path] = STATE(4695),
    [sym_module_path] = STATE(20799),
    [sym_constructor_path] = STATE(4695),
    [sym__constructor_name] = STATE(4743),
    [sym_tag] = STATE(4695),
    [aux_sym_class_application_repeat1] = STATE(2469),
    [sym__lowercase_identifier] = ACTIONS(4495),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(4498),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_LPAREN] = ACTIONS(4501),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_true] = ACTIONS(4507),
    [anon_sym_false] = ACTIONS(4507),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4513),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4516),
    [anon_sym_new] = ACTIONS(4519),
    [anon_sym_LBRACE_LT] = ACTIONS(4522),
    [anon_sym_begin] = ACTIONS(4525),
    [sym_ocamlyacc_value] = ACTIONS(4528),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4531),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4534),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4537),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4540),
    [anon_sym_DQUOTE] = ACTIONS(4543),
    [sym_prefix_operator] = ACTIONS(4546),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4549),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(4552),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2470] = {
    [sym__simple_expression] = STATE(5029),
    [sym_typed_expression] = STATE(4942),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_labeled_argument] = STATE(5303),
    [sym_prefix_expression] = STATE(4942),
    [sym_hash_expression] = STATE(4942),
    [sym_field_get_expression] = STATE(4942),
    [sym_array_get_expression] = STATE(4942),
    [sym_string_get_expression] = STATE(4942),
    [sym_bigarray_get_expression] = STATE(4942),
    [sym_coercion_expression] = STATE(4942),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2470),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [aux_sym_class_application_repeat1] = STATE(2473),
    [sym__lowercase_identifier] = ACTIONS(4555),
    [anon_sym_TILDE] = ACTIONS(4557),
    [anon_sym_QMARK] = ACTIONS(4557),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_DOT] = ACTIONS(4559),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_constraint] = ACTIONS(3193),
    [anon_sym_val] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_inherit] = ACTIONS(3193),
    [anon_sym_method] = ACTIONS(3193),
    [anon_sym_initializer] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(4561),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(959),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4563),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2471] = {
    [sym__simple_expression] = STATE(5082),
    [sym_typed_expression] = STATE(5054),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_labeled_argument] = STATE(5537),
    [sym_prefix_expression] = STATE(5054),
    [sym_hash_expression] = STATE(5054),
    [sym_field_get_expression] = STATE(5054),
    [sym_array_get_expression] = STATE(5054),
    [sym_string_get_expression] = STATE(5054),
    [sym_bigarray_get_expression] = STATE(5054),
    [sym_coercion_expression] = STATE(5054),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2471),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [aux_sym_class_application_repeat1] = STATE(2481),
    [sym__lowercase_identifier] = ACTIONS(4565),
    [anon_sym_TILDE] = ACTIONS(4567),
    [anon_sym_QMARK] = ACTIONS(4567),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_DOT] = ACTIONS(4569),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_constraint] = ACTIONS(3193),
    [anon_sym_val] = ACTIONS(3193),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_inherit] = ACTIONS(3193),
    [anon_sym_method] = ACTIONS(3193),
    [anon_sym_initializer] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(4571),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3193),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1033),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3191),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3191),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4573),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2472] = {
    [sym__simple_expression] = STATE(5242),
    [sym_typed_expression] = STATE(5255),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_labeled_argument] = STATE(5726),
    [sym_prefix_expression] = STATE(5255),
    [sym_hash_expression] = STATE(5255),
    [sym_field_get_expression] = STATE(5255),
    [sym_array_get_expression] = STATE(5255),
    [sym_string_get_expression] = STATE(5255),
    [sym_bigarray_get_expression] = STATE(5255),
    [sym_coercion_expression] = STATE(5255),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2472),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [aux_sym_class_application_repeat1] = STATE(2487),
    [sym__lowercase_identifier] = ACTIONS(4575),
    [anon_sym_COLON_GT] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_RPAREN] = ACTIONS(3191),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_COLON2] = ACTIONS(3193),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_DASH_GT] = ACTIONS(3193),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_RBRACE] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_POUND] = ACTIONS(4581),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3191),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_GT_RBRACE] = ACTIONS(3191),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4583),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2473] = {
    [sym__simple_expression] = STATE(5029),
    [sym_typed_expression] = STATE(4942),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_labeled_argument] = STATE(5303),
    [sym_prefix_expression] = STATE(4942),
    [sym_hash_expression] = STATE(4942),
    [sym_field_get_expression] = STATE(4942),
    [sym_array_get_expression] = STATE(4942),
    [sym_string_get_expression] = STATE(4942),
    [sym_bigarray_get_expression] = STATE(4942),
    [sym_coercion_expression] = STATE(4942),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2473),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [aux_sym_class_application_repeat1] = STATE(2474),
    [sym__lowercase_identifier] = ACTIONS(4555),
    [anon_sym_TILDE] = ACTIONS(4557),
    [anon_sym_QMARK] = ACTIONS(4557),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(921),
    [anon_sym_true] = ACTIONS(923),
    [anon_sym_false] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_constraint] = ACTIONS(3853),
    [anon_sym_val] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(927),
    [anon_sym_inherit] = ACTIONS(3853),
    [anon_sym_method] = ACTIONS(3853),
    [anon_sym_initializer] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(931),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_LBRACE_LT] = ACTIONS(951),
    [anon_sym_begin] = ACTIONS(953),
    [sym_ocamlyacc_value] = ACTIONS(955),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(957),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(959),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(961),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [sym_prefix_operator] = ACTIONS(967),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(971),
    [aux_sym_tag_token1] = ACTIONS(973),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2474] = {
    [sym__simple_expression] = STATE(5029),
    [sym_typed_expression] = STATE(4942),
    [sym_list_expression] = STATE(4942),
    [sym_array_expression] = STATE(4942),
    [sym_record_expression] = STATE(4942),
    [sym_labeled_argument] = STATE(5303),
    [sym_prefix_expression] = STATE(4942),
    [sym_hash_expression] = STATE(4942),
    [sym_field_get_expression] = STATE(4942),
    [sym_array_get_expression] = STATE(4942),
    [sym_string_get_expression] = STATE(4942),
    [sym_bigarray_get_expression] = STATE(4942),
    [sym_coercion_expression] = STATE(4942),
    [sym_local_open_expression] = STATE(4942),
    [sym_package_expression] = STATE(4942),
    [sym_new_expression] = STATE(4942),
    [sym_object_copy_expression] = STATE(4942),
    [sym_method_invocation] = STATE(4942),
    [sym_object_expression] = STATE(4942),
    [sym_parenthesized_expression] = STATE(4942),
    [sym_attribute] = STATE(2474),
    [sym_extension] = STATE(4942),
    [sym_quoted_extension] = STATE(4942),
    [sym__constant] = STATE(4942),
    [sym_number] = STATE(4904),
    [sym_character] = STATE(4904),
    [sym_string] = STATE(4904),
    [sym_quoted_string] = STATE(4904),
    [sym_boolean] = STATE(4904),
    [sym_unit] = STATE(4904),
    [sym__value_name] = STATE(4913),
    [sym_parenthesized_operator] = STATE(4967),
    [sym_value_path] = STATE(4942),
    [sym_module_path] = STATE(19451),
    [sym_constructor_path] = STATE(4942),
    [sym__constructor_name] = STATE(4925),
    [sym_tag] = STATE(4942),
    [aux_sym_class_application_repeat1] = STATE(2474),
    [sym__lowercase_identifier] = ACTIONS(4585),
    [anon_sym_TILDE] = ACTIONS(4588),
    [anon_sym_QMARK] = ACTIONS(4588),
    [anon_sym_LPAREN] = ACTIONS(4591),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4594),
    [anon_sym_true] = ACTIONS(4597),
    [anon_sym_false] = ACTIONS(4597),
    [anon_sym_LBRACE] = ACTIONS(4600),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_constraint] = ACTIONS(3792),
    [anon_sym_val] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4603),
    [anon_sym_inherit] = ACTIONS(3792),
    [anon_sym_method] = ACTIONS(3792),
    [anon_sym_initializer] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(4609),
    [anon_sym_LBRACE_LT] = ACTIONS(4612),
    [anon_sym_begin] = ACTIONS(4615),
    [sym_ocamlyacc_value] = ACTIONS(4618),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4621),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4624),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4627),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4630),
    [anon_sym_DQUOTE] = ACTIONS(4633),
    [sym_prefix_operator] = ACTIONS(4636),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4639),
    [aux_sym_tag_token1] = ACTIONS(4642),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2475] = {
    [sym__simple_expression] = STATE(5402),
    [sym_typed_expression] = STATE(5371),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_labeled_argument] = STATE(5797),
    [sym_prefix_expression] = STATE(5371),
    [sym_hash_expression] = STATE(5371),
    [sym_field_get_expression] = STATE(5371),
    [sym_array_get_expression] = STATE(5371),
    [sym_string_get_expression] = STATE(5371),
    [sym_bigarray_get_expression] = STATE(5371),
    [sym_coercion_expression] = STATE(5371),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2475),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [aux_sym_class_application_repeat1] = STATE(2502),
    [sym__lowercase_identifier] = ACTIONS(4645),
    [anon_sym_COLON_GT] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(4647),
    [anon_sym_QMARK] = ACTIONS(4647),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(3191),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_COLON2] = ACTIONS(3193),
    [anon_sym_DOT] = ACTIONS(4649),
    [anon_sym_DASH_GT] = ACTIONS(3193),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_RBRACE] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_POUND] = ACTIONS(4651),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3191),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_GT_RBRACE] = ACTIONS(3191),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4653),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2476] = {
    [sym__simple_expression] = STATE(5400),
    [sym_typed_expression] = STATE(5398),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_labeled_argument] = STATE(5782),
    [sym_prefix_expression] = STATE(5398),
    [sym_hash_expression] = STATE(5398),
    [sym_field_get_expression] = STATE(5398),
    [sym_array_get_expression] = STATE(5398),
    [sym_string_get_expression] = STATE(5398),
    [sym_bigarray_get_expression] = STATE(5398),
    [sym_coercion_expression] = STATE(5398),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2476),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [aux_sym_class_application_repeat1] = STATE(2501),
    [sym__lowercase_identifier] = ACTIONS(4655),
    [anon_sym_COLON_GT] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(4657),
    [anon_sym_QMARK] = ACTIONS(4657),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_RPAREN] = ACTIONS(3191),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_COLON2] = ACTIONS(3193),
    [anon_sym_DOT] = ACTIONS(4659),
    [anon_sym_DASH_GT] = ACTIONS(3193),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_RBRACE] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_POUND] = ACTIONS(4661),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_GT_RBRACE] = ACTIONS(3191),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4663),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2477] = {
    [sym__parenthesized_abstract_type] = STATE(4587),
    [sym__simple_binding_pattern] = STATE(5728),
    [sym__binding_pattern] = STATE(5681),
    [sym_alias_binding_pattern] = STATE(5728),
    [sym_typed_binding_pattern] = STATE(5736),
    [sym__or_binding_pattern_anonymous] = STATE(5737),
    [sym_constructor_binding_pattern] = STATE(5728),
    [sym_tag_binding_pattern] = STATE(5728),
    [sym_polymorphic_variant_pattern] = STATE(5736),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20855),
    [sym__tuple_binding_pattern] = STATE(5740),
    [sym_record_binding_pattern] = STATE(5741),
    [sym_list_binding_pattern] = STATE(5585),
    [sym_cons_binding_pattern] = STATE(5728),
    [sym_array_binding_pattern] = STATE(5586),
    [sym_range_pattern] = STATE(5728),
    [sym_lazy_binding_pattern] = STATE(5728),
    [sym_local_open_binding_pattern] = STATE(5736),
    [sym_package_pattern] = STATE(5736),
    [sym_parenthesized_binding_pattern] = STATE(5736),
    [sym_attribute] = STATE(2477),
    [sym_extension] = STATE(5736),
    [sym_quoted_extension] = STATE(5736),
    [sym__constant] = STATE(5513),
    [sym__signed_constant] = STATE(5571),
    [sym_number] = STATE(5558),
    [sym_signed_number] = STATE(5513),
    [sym_character] = STATE(5558),
    [sym_string] = STATE(5558),
    [sym_quoted_string] = STATE(5558),
    [sym_boolean] = STATE(5558),
    [sym_unit] = STATE(5558),
    [sym__value_name] = STATE(5736),
    [sym_parenthesized_operator] = STATE(5708),
    [sym_module_path] = STATE(20857),
    [sym_constructor_path] = STATE(2477),
    [sym__constructor_name] = STATE(5565),
    [sym_tag] = STATE(2482),
    [sym__lowercase_identifier] = ACTIONS(4665),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(4673),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(4675),
    [anon_sym_true] = ACTIONS(4677),
    [anon_sym_false] = ACTIONS(4677),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(4679),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_end] = ACTIONS(4669),
    [anon_sym_in] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(4681),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4683),
    [anon_sym_lazy] = ACTIONS(4685),
    [anon_sym_begin] = ACTIONS(4687),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4689),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4691),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(4693),
    [aux_sym_signed_number_token1] = ACTIONS(4695),
    [anon_sym_SQUOTE] = ACTIONS(4697),
    [anon_sym_DQUOTE] = ACTIONS(4699),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(4701),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(4703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2478] = {
    [sym__simple_expression] = STATE(5576),
    [sym_typed_expression] = STATE(5554),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_labeled_argument] = STATE(5959),
    [sym_prefix_expression] = STATE(5554),
    [sym_hash_expression] = STATE(5554),
    [sym_field_get_expression] = STATE(5554),
    [sym_array_get_expression] = STATE(5554),
    [sym_string_get_expression] = STATE(5554),
    [sym_bigarray_get_expression] = STATE(5554),
    [sym_coercion_expression] = STATE(5554),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2478),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [aux_sym_class_application_repeat1] = STATE(2503),
    [sym__lowercase_identifier] = ACTIONS(4705),
    [anon_sym_COLON_GT] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(4707),
    [anon_sym_QMARK] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_RPAREN] = ACTIONS(3191),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_RBRACK] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_COLON2] = ACTIONS(3193),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_DASH_GT] = ACTIONS(3193),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_RBRACE] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_POUND] = ACTIONS(4711),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_GT_RBRACE] = ACTIONS(3191),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(4713),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2479] = {
    [sym__simple_expression] = STATE(5082),
    [sym_typed_expression] = STATE(5054),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_labeled_argument] = STATE(5537),
    [sym_prefix_expression] = STATE(5054),
    [sym_hash_expression] = STATE(5054),
    [sym_field_get_expression] = STATE(5054),
    [sym_array_get_expression] = STATE(5054),
    [sym_string_get_expression] = STATE(5054),
    [sym_bigarray_get_expression] = STATE(5054),
    [sym_coercion_expression] = STATE(5054),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2479),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [aux_sym_class_application_repeat1] = STATE(2479),
    [sym__lowercase_identifier] = ACTIONS(4715),
    [anon_sym_TILDE] = ACTIONS(4718),
    [anon_sym_QMARK] = ACTIONS(4718),
    [anon_sym_LPAREN] = ACTIONS(4721),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4724),
    [anon_sym_true] = ACTIONS(4727),
    [anon_sym_false] = ACTIONS(4727),
    [anon_sym_LBRACE] = ACTIONS(4730),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_constraint] = ACTIONS(3792),
    [anon_sym_val] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(4733),
    [anon_sym_inherit] = ACTIONS(3792),
    [anon_sym_method] = ACTIONS(3792),
    [anon_sym_initializer] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4736),
    [anon_sym_new] = ACTIONS(4739),
    [anon_sym_LBRACE_LT] = ACTIONS(4742),
    [anon_sym_begin] = ACTIONS(4745),
    [sym_ocamlyacc_value] = ACTIONS(4748),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4751),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4754),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(4757),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4760),
    [anon_sym_DQUOTE] = ACTIONS(4763),
    [sym_prefix_operator] = ACTIONS(4766),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4769),
    [aux_sym_tag_token1] = ACTIONS(4772),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2480] = {
    [sym__parenthesized_abstract_type] = STATE(4427),
    [sym__simple_binding_pattern] = STATE(5627),
    [sym__binding_pattern] = STATE(5691),
    [sym_alias_binding_pattern] = STATE(5627),
    [sym_typed_binding_pattern] = STATE(5646),
    [sym__or_binding_pattern_anonymous] = STATE(5649),
    [sym_constructor_binding_pattern] = STATE(5627),
    [sym_tag_binding_pattern] = STATE(5627),
    [sym_polymorphic_variant_pattern] = STATE(5646),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20333),
    [sym__tuple_binding_pattern] = STATE(5652),
    [sym_record_binding_pattern] = STATE(5666),
    [sym_list_binding_pattern] = STATE(5674),
    [sym_cons_binding_pattern] = STATE(5627),
    [sym_array_binding_pattern] = STATE(5618),
    [sym_range_pattern] = STATE(5627),
    [sym_lazy_binding_pattern] = STATE(5627),
    [sym_local_open_binding_pattern] = STATE(5646),
    [sym_package_pattern] = STATE(5646),
    [sym_parenthesized_binding_pattern] = STATE(5646),
    [sym_attribute] = STATE(2480),
    [sym_extension] = STATE(5646),
    [sym_quoted_extension] = STATE(5646),
    [sym__constant] = STATE(5536),
    [sym__signed_constant] = STATE(5488),
    [sym_number] = STATE(5559),
    [sym_signed_number] = STATE(5536),
    [sym_character] = STATE(5559),
    [sym_string] = STATE(5559),
    [sym_quoted_string] = STATE(5559),
    [sym_boolean] = STATE(5559),
    [sym_unit] = STATE(5559),
    [sym__value_name] = STATE(5646),
    [sym_parenthesized_operator] = STATE(5641),
    [sym_module_path] = STATE(20427),
    [sym_constructor_path] = STATE(2480),
    [sym__constructor_name] = STATE(5573),
    [sym_tag] = STATE(2489),
    [sym__lowercase_identifier] = ACTIONS(4775),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(4777),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(4779),
    [anon_sym_RBRACK] = ACTIONS(4667),
    [anon_sym_true] = ACTIONS(4781),
    [anon_sym_false] = ACTIONS(4781),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(4783),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_in] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(4785),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4787),
    [anon_sym_lazy] = ACTIONS(4789),
    [anon_sym_begin] = ACTIONS(4791),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4793),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4795),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(4797),
    [aux_sym_signed_number_token1] = ACTIONS(4799),
    [anon_sym_SQUOTE] = ACTIONS(4801),
    [anon_sym_DQUOTE] = ACTIONS(4803),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(4805),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(4807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2481] = {
    [sym__simple_expression] = STATE(5082),
    [sym_typed_expression] = STATE(5054),
    [sym_list_expression] = STATE(5054),
    [sym_array_expression] = STATE(5054),
    [sym_record_expression] = STATE(5054),
    [sym_labeled_argument] = STATE(5537),
    [sym_prefix_expression] = STATE(5054),
    [sym_hash_expression] = STATE(5054),
    [sym_field_get_expression] = STATE(5054),
    [sym_array_get_expression] = STATE(5054),
    [sym_string_get_expression] = STATE(5054),
    [sym_bigarray_get_expression] = STATE(5054),
    [sym_coercion_expression] = STATE(5054),
    [sym_local_open_expression] = STATE(5054),
    [sym_package_expression] = STATE(5054),
    [sym_new_expression] = STATE(5054),
    [sym_object_copy_expression] = STATE(5054),
    [sym_method_invocation] = STATE(5054),
    [sym_object_expression] = STATE(5054),
    [sym_parenthesized_expression] = STATE(5054),
    [sym_attribute] = STATE(2481),
    [sym_extension] = STATE(5054),
    [sym_quoted_extension] = STATE(5054),
    [sym__constant] = STATE(5054),
    [sym_number] = STATE(5036),
    [sym_character] = STATE(5036),
    [sym_string] = STATE(5036),
    [sym_quoted_string] = STATE(5036),
    [sym_boolean] = STATE(5036),
    [sym_unit] = STATE(5036),
    [sym__value_name] = STATE(5079),
    [sym_parenthesized_operator] = STATE(5041),
    [sym_value_path] = STATE(5054),
    [sym_module_path] = STATE(20345),
    [sym_constructor_path] = STATE(5054),
    [sym__constructor_name] = STATE(5064),
    [sym_tag] = STATE(5054),
    [aux_sym_class_application_repeat1] = STATE(2479),
    [sym__lowercase_identifier] = ACTIONS(4565),
    [anon_sym_TILDE] = ACTIONS(4567),
    [anon_sym_QMARK] = ACTIONS(4567),
    [anon_sym_LPAREN] = ACTIONS(1001),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1003),
    [anon_sym_true] = ACTIONS(1005),
    [anon_sym_false] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_constraint] = ACTIONS(3853),
    [anon_sym_val] = ACTIONS(3853),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(1009),
    [anon_sym_inherit] = ACTIONS(3853),
    [anon_sym_method] = ACTIONS(3853),
    [anon_sym_initializer] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1013),
    [anon_sym_new] = ACTIONS(1023),
    [anon_sym_LBRACE_LT] = ACTIONS(1025),
    [anon_sym_begin] = ACTIONS(1027),
    [sym_ocamlyacc_value] = ACTIONS(1029),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3853),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1031),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1033),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3851),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3851),
    [aux_sym_number_token1] = ACTIONS(1035),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE] = ACTIONS(1039),
    [sym_prefix_operator] = ACTIONS(1041),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1045),
    [aux_sym_tag_token1] = ACTIONS(1047),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2482] = {
    [sym__simple_binding_pattern] = STATE(5728),
    [sym__binding_pattern] = STATE(5693),
    [sym_alias_binding_pattern] = STATE(5728),
    [sym_typed_binding_pattern] = STATE(5736),
    [sym__or_binding_pattern_anonymous] = STATE(5737),
    [sym_constructor_binding_pattern] = STATE(5728),
    [sym_tag_binding_pattern] = STATE(5728),
    [sym_polymorphic_variant_pattern] = STATE(5736),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20855),
    [sym__tuple_binding_pattern] = STATE(5740),
    [sym_record_binding_pattern] = STATE(5741),
    [sym_list_binding_pattern] = STATE(5585),
    [sym_cons_binding_pattern] = STATE(5728),
    [sym_array_binding_pattern] = STATE(5586),
    [sym_range_pattern] = STATE(5728),
    [sym_lazy_binding_pattern] = STATE(5728),
    [sym_local_open_binding_pattern] = STATE(5736),
    [sym_package_pattern] = STATE(5736),
    [sym_parenthesized_binding_pattern] = STATE(5736),
    [sym_attribute] = STATE(2482),
    [sym_extension] = STATE(5736),
    [sym_quoted_extension] = STATE(5736),
    [sym__constant] = STATE(5513),
    [sym__signed_constant] = STATE(5571),
    [sym_number] = STATE(5558),
    [sym_signed_number] = STATE(5513),
    [sym_character] = STATE(5558),
    [sym_string] = STATE(5558),
    [sym_quoted_string] = STATE(5558),
    [sym_boolean] = STATE(5558),
    [sym_unit] = STATE(5558),
    [sym__value_name] = STATE(5736),
    [sym_parenthesized_operator] = STATE(5708),
    [sym_module_path] = STATE(20857),
    [sym_constructor_path] = STATE(2477),
    [sym__constructor_name] = STATE(5565),
    [sym_tag] = STATE(2482),
    [sym__lowercase_identifier] = ACTIONS(4665),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(4809),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(4675),
    [anon_sym_true] = ACTIONS(4677),
    [anon_sym_false] = ACTIONS(4677),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(4679),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_end] = ACTIONS(4669),
    [anon_sym_in] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(4681),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4683),
    [anon_sym_lazy] = ACTIONS(4685),
    [anon_sym_begin] = ACTIONS(4687),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4689),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4691),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(4693),
    [aux_sym_signed_number_token1] = ACTIONS(4695),
    [anon_sym_SQUOTE] = ACTIONS(4697),
    [anon_sym_DQUOTE] = ACTIONS(4699),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(4701),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(4703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2483] = {
    [sym__abstract_type] = STATE(19708),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14580),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2483),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18869),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4817),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4825),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4831),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4835),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4857),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4857),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4857),
    [sym_let_and_operator] = ACTIONS(4857),
    [sym_match_operator] = ACTIONS(4857),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2484] = {
    [sym__abstract_type] = STATE(18757),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14503),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2484),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19798),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4863),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4867),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4869),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4871),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4871),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4871),
    [sym_let_and_operator] = ACTIONS(4871),
    [sym_match_operator] = ACTIONS(4871),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2485] = {
    [sym__abstract_type] = STATE(18994),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14337),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2485),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21213),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4873),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4875),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4877),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4879),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4881),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4881),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4881),
    [sym_let_and_operator] = ACTIONS(4881),
    [sym_match_operator] = ACTIONS(4881),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2486] = {
    [sym__abstract_type] = STATE(19536),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14448),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2486),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(20720),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4883),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4885),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4887),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4889),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4891),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4891),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4891),
    [sym_let_and_operator] = ACTIONS(4891),
    [sym_match_operator] = ACTIONS(4891),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2487] = {
    [sym__simple_expression] = STATE(5242),
    [sym_typed_expression] = STATE(5255),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_labeled_argument] = STATE(5726),
    [sym_prefix_expression] = STATE(5255),
    [sym_hash_expression] = STATE(5255),
    [sym_field_get_expression] = STATE(5255),
    [sym_array_get_expression] = STATE(5255),
    [sym_string_get_expression] = STATE(5255),
    [sym_bigarray_get_expression] = STATE(5255),
    [sym_coercion_expression] = STATE(5255),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2487),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [aux_sym_class_application_repeat1] = STATE(2490),
    [sym__lowercase_identifier] = ACTIONS(4575),
    [anon_sym_COLON_GT] = ACTIONS(3851),
    [anon_sym_TILDE] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_RPAREN] = ACTIONS(3851),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1175),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(1177),
    [anon_sym_false] = ACTIONS(1177),
    [anon_sym_COLON2] = ACTIONS(3853),
    [anon_sym_DASH_GT] = ACTIONS(3853),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_RBRACE] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1181),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1185),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3851),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_LBRACE_LT] = ACTIONS(1201),
    [anon_sym_GT_RBRACE] = ACTIONS(3851),
    [anon_sym_begin] = ACTIONS(1203),
    [sym_ocamlyacc_value] = ACTIONS(1205),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1207),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1209),
    [aux_sym_number_token1] = ACTIONS(1211),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_prefix_operator] = ACTIONS(1217),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1221),
    [aux_sym_tag_token1] = ACTIONS(1223),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2488] = {
    [sym__abstract_type] = STATE(18713),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14475),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2488),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19936),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4893),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4895),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4897),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4899),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4901),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4901),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4901),
    [sym_let_and_operator] = ACTIONS(4901),
    [sym_match_operator] = ACTIONS(4901),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2489] = {
    [sym__simple_binding_pattern] = STATE(5627),
    [sym__binding_pattern] = STATE(5694),
    [sym_alias_binding_pattern] = STATE(5627),
    [sym_typed_binding_pattern] = STATE(5646),
    [sym__or_binding_pattern_anonymous] = STATE(5649),
    [sym_constructor_binding_pattern] = STATE(5627),
    [sym_tag_binding_pattern] = STATE(5627),
    [sym_polymorphic_variant_pattern] = STATE(5646),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20333),
    [sym__tuple_binding_pattern] = STATE(5652),
    [sym_record_binding_pattern] = STATE(5666),
    [sym_list_binding_pattern] = STATE(5674),
    [sym_cons_binding_pattern] = STATE(5627),
    [sym_array_binding_pattern] = STATE(5618),
    [sym_range_pattern] = STATE(5627),
    [sym_lazy_binding_pattern] = STATE(5627),
    [sym_local_open_binding_pattern] = STATE(5646),
    [sym_package_pattern] = STATE(5646),
    [sym_parenthesized_binding_pattern] = STATE(5646),
    [sym_attribute] = STATE(2489),
    [sym_extension] = STATE(5646),
    [sym_quoted_extension] = STATE(5646),
    [sym__constant] = STATE(5536),
    [sym__signed_constant] = STATE(5488),
    [sym_number] = STATE(5559),
    [sym_signed_number] = STATE(5536),
    [sym_character] = STATE(5559),
    [sym_string] = STATE(5559),
    [sym_quoted_string] = STATE(5559),
    [sym_boolean] = STATE(5559),
    [sym_unit] = STATE(5559),
    [sym__value_name] = STATE(5646),
    [sym_parenthesized_operator] = STATE(5641),
    [sym_module_path] = STATE(20427),
    [sym_constructor_path] = STATE(2480),
    [sym__constructor_name] = STATE(5573),
    [sym_tag] = STATE(2489),
    [sym__lowercase_identifier] = ACTIONS(4775),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(4903),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(4779),
    [anon_sym_RBRACK] = ACTIONS(4667),
    [anon_sym_true] = ACTIONS(4781),
    [anon_sym_false] = ACTIONS(4781),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(4783),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_in] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(4785),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4787),
    [anon_sym_lazy] = ACTIONS(4789),
    [anon_sym_begin] = ACTIONS(4791),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4793),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4795),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(4797),
    [aux_sym_signed_number_token1] = ACTIONS(4799),
    [anon_sym_SQUOTE] = ACTIONS(4801),
    [anon_sym_DQUOTE] = ACTIONS(4803),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(4805),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(4807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2490] = {
    [sym__simple_expression] = STATE(5242),
    [sym_typed_expression] = STATE(5255),
    [sym_list_expression] = STATE(5255),
    [sym_array_expression] = STATE(5255),
    [sym_record_expression] = STATE(5255),
    [sym_labeled_argument] = STATE(5726),
    [sym_prefix_expression] = STATE(5255),
    [sym_hash_expression] = STATE(5255),
    [sym_field_get_expression] = STATE(5255),
    [sym_array_get_expression] = STATE(5255),
    [sym_string_get_expression] = STATE(5255),
    [sym_bigarray_get_expression] = STATE(5255),
    [sym_coercion_expression] = STATE(5255),
    [sym_local_open_expression] = STATE(5255),
    [sym_package_expression] = STATE(5255),
    [sym_new_expression] = STATE(5255),
    [sym_object_copy_expression] = STATE(5255),
    [sym_method_invocation] = STATE(5255),
    [sym_object_expression] = STATE(5255),
    [sym_parenthesized_expression] = STATE(5255),
    [sym_attribute] = STATE(2490),
    [sym_extension] = STATE(5255),
    [sym_quoted_extension] = STATE(5255),
    [sym__constant] = STATE(5255),
    [sym_number] = STATE(5187),
    [sym_character] = STATE(5187),
    [sym_string] = STATE(5187),
    [sym_quoted_string] = STATE(5187),
    [sym_boolean] = STATE(5187),
    [sym_unit] = STATE(5187),
    [sym__value_name] = STATE(5154),
    [sym_parenthesized_operator] = STATE(5253),
    [sym_value_path] = STATE(5255),
    [sym_module_path] = STATE(18889),
    [sym_constructor_path] = STATE(5255),
    [sym__constructor_name] = STATE(5188),
    [sym_tag] = STATE(5255),
    [aux_sym_class_application_repeat1] = STATE(2490),
    [sym__lowercase_identifier] = ACTIONS(4905),
    [anon_sym_COLON_GT] = ACTIONS(3790),
    [anon_sym_TILDE] = ACTIONS(4908),
    [anon_sym_QMARK] = ACTIONS(4908),
    [anon_sym_LPAREN] = ACTIONS(4911),
    [anon_sym_RPAREN] = ACTIONS(3790),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(4914),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(4917),
    [anon_sym_false] = ACTIONS(4917),
    [anon_sym_COLON2] = ACTIONS(3792),
    [anon_sym_DASH_GT] = ACTIONS(3792),
    [anon_sym_LBRACE] = ACTIONS(4920),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_RBRACE] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(4923),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4926),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3790),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(4929),
    [anon_sym_LBRACE_LT] = ACTIONS(4932),
    [anon_sym_GT_RBRACE] = ACTIONS(3790),
    [anon_sym_begin] = ACTIONS(4935),
    [sym_ocamlyacc_value] = ACTIONS(4938),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4941),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4944),
    [aux_sym_number_token1] = ACTIONS(4947),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(4950),
    [anon_sym_DQUOTE] = ACTIONS(4953),
    [sym_prefix_operator] = ACTIONS(4956),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(4959),
    [aux_sym_tag_token1] = ACTIONS(4962),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2491] = {
    [sym__parenthesized_abstract_type] = STATE(4629),
    [sym__simple_binding_pattern] = STATE(5801),
    [sym__binding_pattern] = STATE(5852),
    [sym_alias_binding_pattern] = STATE(5801),
    [sym_typed_binding_pattern] = STATE(5803),
    [sym__or_binding_pattern_anonymous] = STATE(5837),
    [sym_constructor_binding_pattern] = STATE(5801),
    [sym_tag_binding_pattern] = STATE(5801),
    [sym_polymorphic_variant_pattern] = STATE(5803),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20060),
    [sym__tuple_binding_pattern] = STATE(5838),
    [sym_record_binding_pattern] = STATE(5848),
    [sym_list_binding_pattern] = STATE(5849),
    [sym_cons_binding_pattern] = STATE(5801),
    [sym_array_binding_pattern] = STATE(5853),
    [sym_range_pattern] = STATE(5801),
    [sym_lazy_binding_pattern] = STATE(5801),
    [sym_local_open_binding_pattern] = STATE(5803),
    [sym_package_pattern] = STATE(5803),
    [sym_parenthesized_binding_pattern] = STATE(5803),
    [sym_attribute] = STATE(2491),
    [sym_extension] = STATE(5803),
    [sym_quoted_extension] = STATE(5803),
    [sym__constant] = STATE(5612),
    [sym__signed_constant] = STATE(5624),
    [sym_number] = STATE(5702),
    [sym_signed_number] = STATE(5612),
    [sym_character] = STATE(5702),
    [sym_string] = STATE(5702),
    [sym_quoted_string] = STATE(5702),
    [sym_boolean] = STATE(5702),
    [sym_unit] = STATE(5702),
    [sym__value_name] = STATE(5803),
    [sym_parenthesized_operator] = STATE(5806),
    [sym_module_path] = STATE(19898),
    [sym_constructor_path] = STATE(2491),
    [sym__constructor_name] = STATE(5716),
    [sym_tag] = STATE(2500),
    [sym__lowercase_identifier] = ACTIONS(4965),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(4967),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(4969),
    [anon_sym_true] = ACTIONS(4971),
    [anon_sym_false] = ACTIONS(4971),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(4973),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_end] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(4975),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4977),
    [anon_sym_lazy] = ACTIONS(4979),
    [anon_sym_begin] = ACTIONS(4981),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4983),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4985),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(4987),
    [aux_sym_signed_number_token1] = ACTIONS(4989),
    [anon_sym_SQUOTE] = ACTIONS(4991),
    [anon_sym_DQUOTE] = ACTIONS(4993),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(4995),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(4997),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2492] = {
    [sym__abstract_type] = STATE(20668),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14383),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2492),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(20332),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4999),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5001),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5003),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5005),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5007),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5007),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5007),
    [sym_let_and_operator] = ACTIONS(5007),
    [sym_match_operator] = ACTIONS(5007),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2493] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14456),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2493),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(20527),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(5009),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5011),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5013),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5017),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5017),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5017),
    [sym_let_and_operator] = ACTIONS(5017),
    [sym_match_operator] = ACTIONS(5017),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2494] = {
    [sym__parenthesized_abstract_type] = STATE(4570),
    [sym__simple_binding_pattern] = STATE(5928),
    [sym__binding_pattern] = STATE(5843),
    [sym_alias_binding_pattern] = STATE(5928),
    [sym_typed_binding_pattern] = STATE(5931),
    [sym__or_binding_pattern_anonymous] = STATE(5942),
    [sym_constructor_binding_pattern] = STATE(5928),
    [sym_tag_binding_pattern] = STATE(5928),
    [sym_polymorphic_variant_pattern] = STATE(5931),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19897),
    [sym__tuple_binding_pattern] = STATE(5759),
    [sym_record_binding_pattern] = STATE(5760),
    [sym_list_binding_pattern] = STATE(5763),
    [sym_cons_binding_pattern] = STATE(5928),
    [sym_array_binding_pattern] = STATE(5792),
    [sym_range_pattern] = STATE(5928),
    [sym_lazy_binding_pattern] = STATE(5928),
    [sym_local_open_binding_pattern] = STATE(5931),
    [sym_package_pattern] = STATE(5931),
    [sym_parenthesized_binding_pattern] = STATE(5931),
    [sym_attribute] = STATE(2494),
    [sym_extension] = STATE(5931),
    [sym_quoted_extension] = STATE(5931),
    [sym__constant] = STATE(5663),
    [sym__signed_constant] = STATE(5661),
    [sym_number] = STATE(5685),
    [sym_signed_number] = STATE(5663),
    [sym_character] = STATE(5685),
    [sym_string] = STATE(5685),
    [sym_quoted_string] = STATE(5685),
    [sym_boolean] = STATE(5685),
    [sym_unit] = STATE(5685),
    [sym__value_name] = STATE(5931),
    [sym_parenthesized_operator] = STATE(5868),
    [sym_module_path] = STATE(19526),
    [sym_constructor_path] = STATE(2494),
    [sym__constructor_name] = STATE(5657),
    [sym_tag] = STATE(2496),
    [sym__lowercase_identifier] = ACTIONS(5019),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(5021),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(5023),
    [anon_sym_RBRACK] = ACTIONS(4667),
    [anon_sym_true] = ACTIONS(5025),
    [anon_sym_false] = ACTIONS(5025),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(5027),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5031),
    [anon_sym_lazy] = ACTIONS(5033),
    [anon_sym_begin] = ACTIONS(5035),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5037),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5039),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(5041),
    [aux_sym_signed_number_token1] = ACTIONS(5043),
    [anon_sym_SQUOTE] = ACTIONS(5045),
    [anon_sym_DQUOTE] = ACTIONS(5047),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(5049),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(5051),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2495] = {
    [sym__abstract_type] = STATE(18757),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14343),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2495),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2496] = {
    [sym__simple_binding_pattern] = STATE(5928),
    [sym__binding_pattern] = STATE(5855),
    [sym_alias_binding_pattern] = STATE(5928),
    [sym_typed_binding_pattern] = STATE(5931),
    [sym__or_binding_pattern_anonymous] = STATE(5942),
    [sym_constructor_binding_pattern] = STATE(5928),
    [sym_tag_binding_pattern] = STATE(5928),
    [sym_polymorphic_variant_pattern] = STATE(5931),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19897),
    [sym__tuple_binding_pattern] = STATE(5759),
    [sym_record_binding_pattern] = STATE(5760),
    [sym_list_binding_pattern] = STATE(5763),
    [sym_cons_binding_pattern] = STATE(5928),
    [sym_array_binding_pattern] = STATE(5792),
    [sym_range_pattern] = STATE(5928),
    [sym_lazy_binding_pattern] = STATE(5928),
    [sym_local_open_binding_pattern] = STATE(5931),
    [sym_package_pattern] = STATE(5931),
    [sym_parenthesized_binding_pattern] = STATE(5931),
    [sym_attribute] = STATE(2496),
    [sym_extension] = STATE(5931),
    [sym_quoted_extension] = STATE(5931),
    [sym__constant] = STATE(5663),
    [sym__signed_constant] = STATE(5661),
    [sym_number] = STATE(5685),
    [sym_signed_number] = STATE(5663),
    [sym_character] = STATE(5685),
    [sym_string] = STATE(5685),
    [sym_quoted_string] = STATE(5685),
    [sym_boolean] = STATE(5685),
    [sym_unit] = STATE(5685),
    [sym__value_name] = STATE(5931),
    [sym_parenthesized_operator] = STATE(5868),
    [sym_module_path] = STATE(19526),
    [sym_constructor_path] = STATE(2494),
    [sym__constructor_name] = STATE(5657),
    [sym_tag] = STATE(2496),
    [sym__lowercase_identifier] = ACTIONS(5019),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(5057),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(5023),
    [anon_sym_RBRACK] = ACTIONS(4667),
    [anon_sym_true] = ACTIONS(5025),
    [anon_sym_false] = ACTIONS(5025),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(5027),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5031),
    [anon_sym_lazy] = ACTIONS(5033),
    [anon_sym_begin] = ACTIONS(5035),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5037),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5039),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(5041),
    [aux_sym_signed_number_token1] = ACTIONS(5043),
    [anon_sym_SQUOTE] = ACTIONS(5045),
    [anon_sym_DQUOTE] = ACTIONS(5047),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(5049),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(5051),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2497] = {
    [sym__simple_expression] = STATE(5400),
    [sym_typed_expression] = STATE(5398),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_labeled_argument] = STATE(5782),
    [sym_prefix_expression] = STATE(5398),
    [sym_hash_expression] = STATE(5398),
    [sym_field_get_expression] = STATE(5398),
    [sym_array_get_expression] = STATE(5398),
    [sym_string_get_expression] = STATE(5398),
    [sym_bigarray_get_expression] = STATE(5398),
    [sym_coercion_expression] = STATE(5398),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2497),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [aux_sym_class_application_repeat1] = STATE(2497),
    [sym__lowercase_identifier] = ACTIONS(5059),
    [anon_sym_COLON_GT] = ACTIONS(3790),
    [anon_sym_TILDE] = ACTIONS(5062),
    [anon_sym_QMARK] = ACTIONS(5062),
    [anon_sym_LPAREN] = ACTIONS(5065),
    [anon_sym_RPAREN] = ACTIONS(3790),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5068),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(5071),
    [anon_sym_false] = ACTIONS(5071),
    [anon_sym_COLON2] = ACTIONS(3792),
    [anon_sym_DASH_GT] = ACTIONS(3792),
    [anon_sym_LBRACE] = ACTIONS(5074),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_RBRACE] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(5077),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5080),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(5083),
    [anon_sym_LBRACE_LT] = ACTIONS(5086),
    [anon_sym_GT_RBRACE] = ACTIONS(3790),
    [anon_sym_begin] = ACTIONS(5089),
    [sym_ocamlyacc_value] = ACTIONS(5092),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5095),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5098),
    [aux_sym_number_token1] = ACTIONS(5101),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(5104),
    [anon_sym_DQUOTE] = ACTIONS(5107),
    [sym_prefix_operator] = ACTIONS(5110),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5113),
    [aux_sym_tag_token1] = ACTIONS(5116),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2498] = {
    [sym__simple_expression] = STATE(5402),
    [sym_typed_expression] = STATE(5371),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_labeled_argument] = STATE(5797),
    [sym_prefix_expression] = STATE(5371),
    [sym_hash_expression] = STATE(5371),
    [sym_field_get_expression] = STATE(5371),
    [sym_array_get_expression] = STATE(5371),
    [sym_string_get_expression] = STATE(5371),
    [sym_bigarray_get_expression] = STATE(5371),
    [sym_coercion_expression] = STATE(5371),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2498),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [aux_sym_class_application_repeat1] = STATE(2498),
    [sym__lowercase_identifier] = ACTIONS(5119),
    [anon_sym_COLON_GT] = ACTIONS(3790),
    [anon_sym_TILDE] = ACTIONS(5122),
    [anon_sym_QMARK] = ACTIONS(5122),
    [anon_sym_LPAREN] = ACTIONS(5125),
    [anon_sym_RPAREN] = ACTIONS(3790),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5128),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(5131),
    [anon_sym_false] = ACTIONS(5131),
    [anon_sym_COLON2] = ACTIONS(3792),
    [anon_sym_DASH_GT] = ACTIONS(3792),
    [anon_sym_LBRACE] = ACTIONS(5134),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_RBRACE] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(5137),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5140),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3790),
    [anon_sym_new] = ACTIONS(5143),
    [anon_sym_LBRACE_LT] = ACTIONS(5146),
    [anon_sym_GT_RBRACE] = ACTIONS(3790),
    [anon_sym_begin] = ACTIONS(5149),
    [sym_ocamlyacc_value] = ACTIONS(5152),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5155),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5158),
    [aux_sym_number_token1] = ACTIONS(5161),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(5164),
    [anon_sym_DQUOTE] = ACTIONS(5167),
    [sym_prefix_operator] = ACTIONS(5170),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5173),
    [aux_sym_tag_token1] = ACTIONS(5176),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2499] = {
    [sym__simple_expression] = STATE(5780),
    [sym_typed_expression] = STATE(5762),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_labeled_argument] = STATE(7017),
    [sym_prefix_expression] = STATE(5762),
    [sym_hash_expression] = STATE(5762),
    [sym_field_get_expression] = STATE(5762),
    [sym_array_get_expression] = STATE(5762),
    [sym_string_get_expression] = STATE(5762),
    [sym_bigarray_get_expression] = STATE(5762),
    [sym_coercion_expression] = STATE(5762),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2499),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [aux_sym_class_application_repeat1] = STATE(2525),
    [sym__lowercase_identifier] = ACTIONS(5179),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(5181),
    [anon_sym_QMARK] = ACTIONS(5181),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_DOT] = ACTIONS(5183),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_in] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(5185),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5187),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2500] = {
    [sym__simple_binding_pattern] = STATE(5801),
    [sym__binding_pattern] = STATE(5857),
    [sym_alias_binding_pattern] = STATE(5801),
    [sym_typed_binding_pattern] = STATE(5803),
    [sym__or_binding_pattern_anonymous] = STATE(5837),
    [sym_constructor_binding_pattern] = STATE(5801),
    [sym_tag_binding_pattern] = STATE(5801),
    [sym_polymorphic_variant_pattern] = STATE(5803),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20060),
    [sym__tuple_binding_pattern] = STATE(5838),
    [sym_record_binding_pattern] = STATE(5848),
    [sym_list_binding_pattern] = STATE(5849),
    [sym_cons_binding_pattern] = STATE(5801),
    [sym_array_binding_pattern] = STATE(5853),
    [sym_range_pattern] = STATE(5801),
    [sym_lazy_binding_pattern] = STATE(5801),
    [sym_local_open_binding_pattern] = STATE(5803),
    [sym_package_pattern] = STATE(5803),
    [sym_parenthesized_binding_pattern] = STATE(5803),
    [sym_attribute] = STATE(2500),
    [sym_extension] = STATE(5803),
    [sym_quoted_extension] = STATE(5803),
    [sym__constant] = STATE(5612),
    [sym__signed_constant] = STATE(5624),
    [sym_number] = STATE(5702),
    [sym_signed_number] = STATE(5612),
    [sym_character] = STATE(5702),
    [sym_string] = STATE(5702),
    [sym_quoted_string] = STATE(5702),
    [sym_boolean] = STATE(5702),
    [sym_unit] = STATE(5702),
    [sym__value_name] = STATE(5803),
    [sym_parenthesized_operator] = STATE(5806),
    [sym_module_path] = STATE(19898),
    [sym_constructor_path] = STATE(2491),
    [sym__constructor_name] = STATE(5716),
    [sym_tag] = STATE(2500),
    [sym__lowercase_identifier] = ACTIONS(4965),
    [anon_sym_SEMI_SEMI] = ACTIONS(4667),
    [anon_sym_let] = ACTIONS(4669),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(5189),
    [anon_sym_external] = ACTIONS(4669),
    [anon_sym_type] = ACTIONS(4669),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(4969),
    [anon_sym_true] = ACTIONS(4971),
    [anon_sym_false] = ACTIONS(4971),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(4973),
    [anon_sym_exception] = ACTIONS(4669),
    [anon_sym_module] = ACTIONS(4669),
    [anon_sym_open] = ACTIONS(4669),
    [anon_sym_include] = ACTIONS(4669),
    [anon_sym_class] = ACTIONS(4669),
    [anon_sym_end] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(4975),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4977),
    [anon_sym_lazy] = ACTIONS(4979),
    [anon_sym_begin] = ACTIONS(4981),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4669),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4983),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4985),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(4667),
    [aux_sym_number_token1] = ACTIONS(4987),
    [aux_sym_signed_number_token1] = ACTIONS(4989),
    [anon_sym_SQUOTE] = ACTIONS(4991),
    [anon_sym_DQUOTE] = ACTIONS(4993),
    [sym_let_operator] = ACTIONS(4667),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(4995),
    [aux_sym_directive_token1] = ACTIONS(4669),
    [aux_sym_tag_token1] = ACTIONS(4997),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2501] = {
    [sym__simple_expression] = STATE(5400),
    [sym_typed_expression] = STATE(5398),
    [sym_list_expression] = STATE(5398),
    [sym_array_expression] = STATE(5398),
    [sym_record_expression] = STATE(5398),
    [sym_labeled_argument] = STATE(5782),
    [sym_prefix_expression] = STATE(5398),
    [sym_hash_expression] = STATE(5398),
    [sym_field_get_expression] = STATE(5398),
    [sym_array_get_expression] = STATE(5398),
    [sym_string_get_expression] = STATE(5398),
    [sym_bigarray_get_expression] = STATE(5398),
    [sym_coercion_expression] = STATE(5398),
    [sym_local_open_expression] = STATE(5398),
    [sym_package_expression] = STATE(5398),
    [sym_new_expression] = STATE(5398),
    [sym_object_copy_expression] = STATE(5398),
    [sym_method_invocation] = STATE(5398),
    [sym_object_expression] = STATE(5398),
    [sym_parenthesized_expression] = STATE(5398),
    [sym_attribute] = STATE(2501),
    [sym_extension] = STATE(5398),
    [sym_quoted_extension] = STATE(5398),
    [sym__constant] = STATE(5398),
    [sym_number] = STATE(5434),
    [sym_character] = STATE(5434),
    [sym_string] = STATE(5434),
    [sym_quoted_string] = STATE(5434),
    [sym_boolean] = STATE(5434),
    [sym_unit] = STATE(5434),
    [sym__value_name] = STATE(5409),
    [sym_parenthesized_operator] = STATE(5461),
    [sym_value_path] = STATE(5398),
    [sym_module_path] = STATE(19681),
    [sym_constructor_path] = STATE(5398),
    [sym__constructor_name] = STATE(5460),
    [sym_tag] = STATE(5398),
    [aux_sym_class_application_repeat1] = STATE(2497),
    [sym__lowercase_identifier] = ACTIONS(4655),
    [anon_sym_COLON_GT] = ACTIONS(3851),
    [anon_sym_TILDE] = ACTIONS(4657),
    [anon_sym_QMARK] = ACTIONS(4657),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_RPAREN] = ACTIONS(3851),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(1071),
    [anon_sym_false] = ACTIONS(1071),
    [anon_sym_COLON2] = ACTIONS(3853),
    [anon_sym_DASH_GT] = ACTIONS(3853),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_RBRACE] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1075),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1079),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_LBRACE_LT] = ACTIONS(1091),
    [anon_sym_GT_RBRACE] = ACTIONS(3851),
    [anon_sym_begin] = ACTIONS(1093),
    [sym_ocamlyacc_value] = ACTIONS(1095),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1099),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1101),
    [aux_sym_number_token1] = ACTIONS(1103),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE] = ACTIONS(1107),
    [sym_prefix_operator] = ACTIONS(1109),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1113),
    [aux_sym_tag_token1] = ACTIONS(1115),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2502] = {
    [sym__simple_expression] = STATE(5402),
    [sym_typed_expression] = STATE(5371),
    [sym_list_expression] = STATE(5371),
    [sym_array_expression] = STATE(5371),
    [sym_record_expression] = STATE(5371),
    [sym_labeled_argument] = STATE(5797),
    [sym_prefix_expression] = STATE(5371),
    [sym_hash_expression] = STATE(5371),
    [sym_field_get_expression] = STATE(5371),
    [sym_array_get_expression] = STATE(5371),
    [sym_string_get_expression] = STATE(5371),
    [sym_bigarray_get_expression] = STATE(5371),
    [sym_coercion_expression] = STATE(5371),
    [sym_local_open_expression] = STATE(5371),
    [sym_package_expression] = STATE(5371),
    [sym_new_expression] = STATE(5371),
    [sym_object_copy_expression] = STATE(5371),
    [sym_method_invocation] = STATE(5371),
    [sym_object_expression] = STATE(5371),
    [sym_parenthesized_expression] = STATE(5371),
    [sym_attribute] = STATE(2502),
    [sym_extension] = STATE(5371),
    [sym_quoted_extension] = STATE(5371),
    [sym__constant] = STATE(5371),
    [sym_number] = STATE(5322),
    [sym_character] = STATE(5322),
    [sym_string] = STATE(5322),
    [sym_quoted_string] = STATE(5322),
    [sym_boolean] = STATE(5322),
    [sym_unit] = STATE(5322),
    [sym__value_name] = STATE(5375),
    [sym_parenthesized_operator] = STATE(5358),
    [sym_value_path] = STATE(5371),
    [sym_module_path] = STATE(19433),
    [sym_constructor_path] = STATE(5371),
    [sym__constructor_name] = STATE(5328),
    [sym_tag] = STATE(5371),
    [aux_sym_class_application_repeat1] = STATE(2498),
    [sym__lowercase_identifier] = ACTIONS(4645),
    [anon_sym_COLON_GT] = ACTIONS(3851),
    [anon_sym_TILDE] = ACTIONS(4647),
    [anon_sym_QMARK] = ACTIONS(4647),
    [anon_sym_LPAREN] = ACTIONS(1229),
    [anon_sym_RPAREN] = ACTIONS(3851),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1231),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(1233),
    [anon_sym_false] = ACTIONS(1233),
    [anon_sym_COLON2] = ACTIONS(3853),
    [anon_sym_DASH_GT] = ACTIONS(3853),
    [anon_sym_LBRACE] = ACTIONS(1235),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_RBRACE] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1237),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1241),
    [anon_sym_PIPE_RBRACK] = ACTIONS(3851),
    [anon_sym_new] = ACTIONS(1251),
    [anon_sym_LBRACE_LT] = ACTIONS(1253),
    [anon_sym_GT_RBRACE] = ACTIONS(3851),
    [anon_sym_begin] = ACTIONS(1255),
    [sym_ocamlyacc_value] = ACTIONS(1257),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1259),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1261),
    [aux_sym_number_token1] = ACTIONS(1263),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [sym_prefix_operator] = ACTIONS(1269),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1273),
    [aux_sym_tag_token1] = ACTIONS(1275),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2503] = {
    [sym__simple_expression] = STATE(5576),
    [sym_typed_expression] = STATE(5554),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_labeled_argument] = STATE(5959),
    [sym_prefix_expression] = STATE(5554),
    [sym_hash_expression] = STATE(5554),
    [sym_field_get_expression] = STATE(5554),
    [sym_array_get_expression] = STATE(5554),
    [sym_string_get_expression] = STATE(5554),
    [sym_bigarray_get_expression] = STATE(5554),
    [sym_coercion_expression] = STATE(5554),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2503),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [aux_sym_class_application_repeat1] = STATE(2507),
    [sym__lowercase_identifier] = ACTIONS(4705),
    [anon_sym_COLON_GT] = ACTIONS(3851),
    [anon_sym_TILDE] = ACTIONS(4707),
    [anon_sym_QMARK] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(1121),
    [anon_sym_RPAREN] = ACTIONS(3851),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1123),
    [anon_sym_RBRACK] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(1125),
    [anon_sym_false] = ACTIONS(1125),
    [anon_sym_COLON2] = ACTIONS(3853),
    [anon_sym_DASH_GT] = ACTIONS(3853),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_RBRACE] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1129),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1133),
    [anon_sym_new] = ACTIONS(1143),
    [anon_sym_LBRACE_LT] = ACTIONS(1145),
    [anon_sym_GT_RBRACE] = ACTIONS(3851),
    [anon_sym_begin] = ACTIONS(1147),
    [sym_ocamlyacc_value] = ACTIONS(1149),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1151),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1153),
    [aux_sym_number_token1] = ACTIONS(1155),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE] = ACTIONS(1159),
    [sym_prefix_operator] = ACTIONS(1161),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1165),
    [aux_sym_tag_token1] = ACTIONS(1167),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2504] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14258),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2504),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(20527),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(5009),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5011),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5013),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5017),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5017),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5017),
    [sym_let_and_operator] = ACTIONS(5017),
    [sym_match_operator] = ACTIONS(5017),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2505] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14284),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2505),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21213),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4873),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4875),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4877),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4879),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4881),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4881),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4881),
    [sym_let_and_operator] = ACTIONS(4881),
    [sym_match_operator] = ACTIONS(4881),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2506] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14343),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2506),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(1427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2507] = {
    [sym__simple_expression] = STATE(5576),
    [sym_typed_expression] = STATE(5554),
    [sym_list_expression] = STATE(5554),
    [sym_array_expression] = STATE(5554),
    [sym_record_expression] = STATE(5554),
    [sym_labeled_argument] = STATE(5959),
    [sym_prefix_expression] = STATE(5554),
    [sym_hash_expression] = STATE(5554),
    [sym_field_get_expression] = STATE(5554),
    [sym_array_get_expression] = STATE(5554),
    [sym_string_get_expression] = STATE(5554),
    [sym_bigarray_get_expression] = STATE(5554),
    [sym_coercion_expression] = STATE(5554),
    [sym_local_open_expression] = STATE(5554),
    [sym_package_expression] = STATE(5554),
    [sym_new_expression] = STATE(5554),
    [sym_object_copy_expression] = STATE(5554),
    [sym_method_invocation] = STATE(5554),
    [sym_object_expression] = STATE(5554),
    [sym_parenthesized_expression] = STATE(5554),
    [sym_attribute] = STATE(2507),
    [sym_extension] = STATE(5554),
    [sym_quoted_extension] = STATE(5554),
    [sym__constant] = STATE(5554),
    [sym_number] = STATE(5523),
    [sym_character] = STATE(5523),
    [sym_string] = STATE(5523),
    [sym_quoted_string] = STATE(5523),
    [sym_boolean] = STATE(5523),
    [sym_unit] = STATE(5523),
    [sym__value_name] = STATE(5532),
    [sym_parenthesized_operator] = STATE(5522),
    [sym_value_path] = STATE(5554),
    [sym_module_path] = STATE(18943),
    [sym_constructor_path] = STATE(5554),
    [sym__constructor_name] = STATE(5526),
    [sym_tag] = STATE(5554),
    [aux_sym_class_application_repeat1] = STATE(2507),
    [sym__lowercase_identifier] = ACTIONS(5191),
    [anon_sym_COLON_GT] = ACTIONS(3790),
    [anon_sym_TILDE] = ACTIONS(5194),
    [anon_sym_QMARK] = ACTIONS(5194),
    [anon_sym_LPAREN] = ACTIONS(5197),
    [anon_sym_RPAREN] = ACTIONS(3790),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5200),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(5203),
    [anon_sym_false] = ACTIONS(5203),
    [anon_sym_COLON2] = ACTIONS(3792),
    [anon_sym_DASH_GT] = ACTIONS(3792),
    [anon_sym_LBRACE] = ACTIONS(5206),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_RBRACE] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(5209),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5212),
    [anon_sym_new] = ACTIONS(5215),
    [anon_sym_LBRACE_LT] = ACTIONS(5218),
    [anon_sym_GT_RBRACE] = ACTIONS(3790),
    [anon_sym_begin] = ACTIONS(5221),
    [sym_ocamlyacc_value] = ACTIONS(5224),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5227),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5230),
    [aux_sym_number_token1] = ACTIONS(5233),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(5236),
    [anon_sym_DQUOTE] = ACTIONS(5239),
    [sym_prefix_operator] = ACTIONS(5242),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5245),
    [aux_sym_tag_token1] = ACTIONS(5248),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2508] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14503),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2508),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19798),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4863),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4867),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4869),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4871),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4871),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4871),
    [sym_let_and_operator] = ACTIONS(4871),
    [sym_match_operator] = ACTIONS(4871),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2509] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14503),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2509),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19798),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4863),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4867),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5251),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4871),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4871),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4871),
    [sym_let_and_operator] = ACTIONS(4871),
    [sym_match_operator] = ACTIONS(4871),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2510] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14249),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2510),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(20332),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4999),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5001),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5003),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5005),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5007),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5007),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5007),
    [sym_let_and_operator] = ACTIONS(5007),
    [sym_match_operator] = ACTIONS(5007),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2511] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14235),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2511),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19936),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4893),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4895),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4897),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4899),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4901),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4901),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4901),
    [sym_let_and_operator] = ACTIONS(4901),
    [sym_match_operator] = ACTIONS(4901),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2512] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14343),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2512),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2513] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14229),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2513),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18869),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4817),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4825),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4831),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4835),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4857),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4857),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4857),
    [sym_let_and_operator] = ACTIONS(4857),
    [sym_match_operator] = ACTIONS(4857),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2514] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14343),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2514),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5253),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2515] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14287),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2515),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(20720),
    [sym_add_operator] = STATE(20795),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(4883),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4885),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_module] = ACTIONS(4887),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(4889),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4891),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4891),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4891),
    [sym_let_and_operator] = ACTIONS(4891),
    [sym_match_operator] = ACTIONS(4891),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2516] = {
    [sym__simple_expression] = STATE(6051),
    [sym_typed_expression] = STATE(6059),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_labeled_argument] = STATE(7158),
    [sym_prefix_expression] = STATE(6059),
    [sym_hash_expression] = STATE(6059),
    [sym_field_get_expression] = STATE(6059),
    [sym_array_get_expression] = STATE(6059),
    [sym_string_get_expression] = STATE(6059),
    [sym_bigarray_get_expression] = STATE(6059),
    [sym_coercion_expression] = STATE(6059),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2516),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [aux_sym_class_application_repeat1] = STATE(2537),
    [sym__lowercase_identifier] = ACTIONS(5255),
    [anon_sym_and] = ACTIONS(3193),
    [anon_sym_TILDE] = ACTIONS(5257),
    [anon_sym_QMARK] = ACTIONS(5257),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_DOT] = ACTIONS(5259),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_in] = ACTIONS(3193),
    [anon_sym_POUND] = ACTIONS(5261),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3191),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5263),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym_let_and_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2517] = {
    [sym__simple_expression] = STATE(6361),
    [sym_typed_expression] = STATE(6355),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_labeled_argument] = STATE(7666),
    [sym_prefix_expression] = STATE(6355),
    [sym_hash_expression] = STATE(6355),
    [sym_field_get_expression] = STATE(6355),
    [sym_array_get_expression] = STATE(6355),
    [sym_string_get_expression] = STATE(6355),
    [sym_bigarray_get_expression] = STATE(6355),
    [sym_coercion_expression] = STATE(6355),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2517),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [aux_sym_class_application_repeat1] = STATE(2551),
    [sym__lowercase_identifier] = ACTIONS(5265),
    [anon_sym_TILDE] = ACTIONS(5267),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_DOT] = ACTIONS(5269),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_POUND] = ACTIONS(5271),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_to] = ACTIONS(3193),
    [anon_sym_downto] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5273),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2518] = {
    [sym__simple_expression] = STATE(6591),
    [sym_typed_expression] = STATE(6549),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_labeled_argument] = STATE(7883),
    [sym_prefix_expression] = STATE(6549),
    [sym_hash_expression] = STATE(6549),
    [sym_field_get_expression] = STATE(6549),
    [sym_array_get_expression] = STATE(6549),
    [sym_string_get_expression] = STATE(6549),
    [sym_bigarray_get_expression] = STATE(6549),
    [sym_coercion_expression] = STATE(6549),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2518),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [aux_sym_class_application_repeat1] = STATE(2563),
    [sym__lowercase_identifier] = ACTIONS(5275),
    [anon_sym_TILDE] = ACTIONS(5277),
    [anon_sym_QMARK] = ACTIONS(5277),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_DOT] = ACTIONS(5279),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_POUND] = ACTIONS(5281),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_to] = ACTIONS(3193),
    [anon_sym_downto] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5283),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2519] = {
    [sym__simple_expression] = STATE(5780),
    [sym_typed_expression] = STATE(5762),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_labeled_argument] = STATE(7017),
    [sym_prefix_expression] = STATE(5762),
    [sym_hash_expression] = STATE(5762),
    [sym_field_get_expression] = STATE(5762),
    [sym_array_get_expression] = STATE(5762),
    [sym_string_get_expression] = STATE(5762),
    [sym_bigarray_get_expression] = STATE(5762),
    [sym_coercion_expression] = STATE(5762),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2519),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [aux_sym_class_application_repeat1] = STATE(2519),
    [sym__lowercase_identifier] = ACTIONS(5285),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_LPAREN] = ACTIONS(5291),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5294),
    [anon_sym_true] = ACTIONS(5297),
    [anon_sym_false] = ACTIONS(5297),
    [anon_sym_LBRACE] = ACTIONS(5300),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(5303),
    [anon_sym_in] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5306),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(5309),
    [anon_sym_LBRACE_LT] = ACTIONS(5312),
    [anon_sym_begin] = ACTIONS(5315),
    [sym_ocamlyacc_value] = ACTIONS(5318),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5324),
    [aux_sym_number_token1] = ACTIONS(5327),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(5330),
    [anon_sym_DQUOTE] = ACTIONS(5333),
    [sym_prefix_operator] = ACTIONS(5336),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5339),
    [aux_sym_tag_token1] = ACTIONS(5342),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2520] = {
    [sym__simple_expression] = STATE(6874),
    [sym_typed_expression] = STATE(6791),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_labeled_argument] = STATE(7741),
    [sym_prefix_expression] = STATE(6791),
    [sym_hash_expression] = STATE(6791),
    [sym_field_get_expression] = STATE(6791),
    [sym_array_get_expression] = STATE(6791),
    [sym_string_get_expression] = STATE(6791),
    [sym_bigarray_get_expression] = STATE(6791),
    [sym_coercion_expression] = STATE(6791),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2520),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [aux_sym_class_application_repeat1] = STATE(2569),
    [sym__lowercase_identifier] = ACTIONS(5345),
    [anon_sym_TILDE] = ACTIONS(5347),
    [anon_sym_QMARK] = ACTIONS(5347),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_DOT] = ACTIONS(5349),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_POUND] = ACTIONS(5351),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5353),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2521] = {
    [sym__simple_expression] = STATE(6744),
    [sym_typed_expression] = STATE(6638),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_labeled_argument] = STATE(7739),
    [sym_prefix_expression] = STATE(6638),
    [sym_hash_expression] = STATE(6638),
    [sym_field_get_expression] = STATE(6638),
    [sym_array_get_expression] = STATE(6638),
    [sym_string_get_expression] = STATE(6638),
    [sym_bigarray_get_expression] = STATE(6638),
    [sym_coercion_expression] = STATE(6638),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2521),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [aux_sym_class_application_repeat1] = STATE(2574),
    [sym__lowercase_identifier] = ACTIONS(5355),
    [anon_sym_TILDE] = ACTIONS(5357),
    [anon_sym_QMARK] = ACTIONS(5357),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_DOT] = ACTIONS(5359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_POUND] = ACTIONS(5361),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_then] = ACTIONS(3193),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5363),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2522] = {
    [sym__simple_expression] = STATE(6800),
    [sym_typed_expression] = STATE(6686),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_labeled_argument] = STATE(7865),
    [sym_prefix_expression] = STATE(6686),
    [sym_hash_expression] = STATE(6686),
    [sym_field_get_expression] = STATE(6686),
    [sym_array_get_expression] = STATE(6686),
    [sym_string_get_expression] = STATE(6686),
    [sym_bigarray_get_expression] = STATE(6686),
    [sym_coercion_expression] = STATE(6686),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2522),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [aux_sym_class_application_repeat1] = STATE(2576),
    [sym__lowercase_identifier] = ACTIONS(5365),
    [anon_sym_TILDE] = ACTIONS(5367),
    [anon_sym_QMARK] = ACTIONS(5367),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_DOT] = ACTIONS(5369),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_POUND] = ACTIONS(5371),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_do] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5373),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2523] = {
    [sym__simple_expression] = STATE(6957),
    [sym_typed_expression] = STATE(6951),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_labeled_argument] = STATE(7888),
    [sym_prefix_expression] = STATE(6951),
    [sym_hash_expression] = STATE(6951),
    [sym_field_get_expression] = STATE(6951),
    [sym_array_get_expression] = STATE(6951),
    [sym_string_get_expression] = STATE(6951),
    [sym_bigarray_get_expression] = STATE(6951),
    [sym_coercion_expression] = STATE(6951),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2523),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [aux_sym_class_application_repeat1] = STATE(2556),
    [sym__lowercase_identifier] = ACTIONS(5375),
    [anon_sym_TILDE] = ACTIONS(5377),
    [anon_sym_QMARK] = ACTIONS(5377),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_DOT] = ACTIONS(5379),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_POUND] = ACTIONS(5381),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_done] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5383),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2524] = {
    [sym__simple_expression] = STATE(6851),
    [sym_typed_expression] = STATE(6736),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_labeled_argument] = STATE(7976),
    [sym_prefix_expression] = STATE(6736),
    [sym_hash_expression] = STATE(6736),
    [sym_field_get_expression] = STATE(6736),
    [sym_array_get_expression] = STATE(6736),
    [sym_string_get_expression] = STATE(6736),
    [sym_bigarray_get_expression] = STATE(6736),
    [sym_coercion_expression] = STATE(6736),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2524),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [aux_sym_class_application_repeat1] = STATE(2573),
    [sym__lowercase_identifier] = ACTIONS(5385),
    [anon_sym_TILDE] = ACTIONS(5387),
    [anon_sym_QMARK] = ACTIONS(5387),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_DOT] = ACTIONS(5389),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_with] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_POUND] = ACTIONS(5391),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_else] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5393),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2525] = {
    [sym__simple_expression] = STATE(5780),
    [sym_typed_expression] = STATE(5762),
    [sym_list_expression] = STATE(5762),
    [sym_array_expression] = STATE(5762),
    [sym_record_expression] = STATE(5762),
    [sym_labeled_argument] = STATE(7017),
    [sym_prefix_expression] = STATE(5762),
    [sym_hash_expression] = STATE(5762),
    [sym_field_get_expression] = STATE(5762),
    [sym_array_get_expression] = STATE(5762),
    [sym_string_get_expression] = STATE(5762),
    [sym_bigarray_get_expression] = STATE(5762),
    [sym_coercion_expression] = STATE(5762),
    [sym_local_open_expression] = STATE(5762),
    [sym_package_expression] = STATE(5762),
    [sym_new_expression] = STATE(5762),
    [sym_object_copy_expression] = STATE(5762),
    [sym_method_invocation] = STATE(5762),
    [sym_object_expression] = STATE(5762),
    [sym_parenthesized_expression] = STATE(5762),
    [sym_attribute] = STATE(2525),
    [sym_extension] = STATE(5762),
    [sym_quoted_extension] = STATE(5762),
    [sym__constant] = STATE(5762),
    [sym_number] = STATE(5901),
    [sym_character] = STATE(5901),
    [sym_string] = STATE(5901),
    [sym_quoted_string] = STATE(5901),
    [sym_boolean] = STATE(5901),
    [sym_unit] = STATE(5901),
    [sym__value_name] = STATE(5769),
    [sym_parenthesized_operator] = STATE(5953),
    [sym_value_path] = STATE(5762),
    [sym_module_path] = STATE(19643),
    [sym_constructor_path] = STATE(5762),
    [sym__constructor_name] = STATE(5915),
    [sym_tag] = STATE(5762),
    [aux_sym_class_application_repeat1] = STATE(2519),
    [sym__lowercase_identifier] = ACTIONS(5179),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(5181),
    [anon_sym_QMARK] = ACTIONS(5181),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1285),
    [anon_sym_true] = ACTIONS(1287),
    [anon_sym_false] = ACTIONS(1287),
    [anon_sym_LBRACE] = ACTIONS(1289),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1291),
    [anon_sym_in] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1295),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(1313),
    [anon_sym_LBRACE_LT] = ACTIONS(1315),
    [anon_sym_begin] = ACTIONS(1317),
    [sym_ocamlyacc_value] = ACTIONS(1319),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1321),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1323),
    [aux_sym_number_token1] = ACTIONS(1325),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [anon_sym_DQUOTE] = ACTIONS(1329),
    [sym_prefix_operator] = ACTIONS(1331),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1335),
    [aux_sym_tag_token1] = ACTIONS(1337),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2526] = {
    [sym_parameter] = STATE(10790),
    [sym__polymorphic_typed] = STATE(18245),
    [sym__parenthesized_abstract_type] = STATE(10790),
    [sym__simple_pattern] = STATE(10586),
    [sym_typed_pattern] = STATE(10736),
    [sym_polymorphic_variant_pattern] = STATE(10736),
    [sym_record_pattern] = STATE(10736),
    [sym_list_pattern] = STATE(10736),
    [sym_array_pattern] = STATE(10736),
    [sym_local_open_pattern] = STATE(10736),
    [sym_package_pattern] = STATE(10736),
    [sym_parenthesized_pattern] = STATE(10736),
    [sym_attribute] = STATE(2526),
    [sym_item_attribute] = STATE(11669),
    [sym_extension] = STATE(10736),
    [sym_quoted_extension] = STATE(10736),
    [sym__constant] = STATE(10744),
    [sym__signed_constant] = STATE(10736),
    [sym_number] = STATE(10787),
    [sym_signed_number] = STATE(10744),
    [sym_character] = STATE(10787),
    [sym_string] = STATE(10787),
    [sym_quoted_string] = STATE(10787),
    [sym_boolean] = STATE(10787),
    [sym_unit] = STATE(10787),
    [sym__simple_value_pattern] = STATE(10736),
    [sym_parenthesized_operator] = STATE(10736),
    [sym_module_path] = STATE(19549),
    [sym_constructor_path] = STATE(10736),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(10736),
    [aux_sym_expression_item_repeat1] = STATE(11190),
    [aux_sym_let_binding_repeat1] = STATE(4790),
    [sym__lowercase_identifier] = ACTIONS(5395),
    [anon_sym_SEMI_SEMI] = ACTIONS(5397),
    [anon_sym_let] = ACTIONS(5399),
    [anon_sym_and] = ACTIONS(5399),
    [anon_sym_COLON_GT] = ACTIONS(5401),
    [anon_sym_EQ] = ACTIONS(5403),
    [anon_sym_TILDE] = ACTIONS(5405),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_LPAREN] = ACTIONS(5407),
    [anon_sym_external] = ACTIONS(5399),
    [anon_sym_type] = ACTIONS(5399),
    [anon_sym_COMMA] = ACTIONS(5409),
    [anon_sym_PIPE] = ACTIONS(5411),
    [anon_sym_LBRACK] = ACTIONS(5413),
    [anon_sym_RBRACK] = ACTIONS(5397),
    [anon_sym_true] = ACTIONS(5415),
    [anon_sym_false] = ACTIONS(5415),
    [anon_sym_COLON2] = ACTIONS(5417),
    [anon_sym_LBRACE] = ACTIONS(5419),
    [anon_sym_exception] = ACTIONS(5399),
    [anon_sym_module] = ACTIONS(5399),
    [anon_sym_open] = ACTIONS(5399),
    [anon_sym_include] = ACTIONS(5399),
    [anon_sym_class] = ACTIONS(5399),
    [anon_sym_in] = ACTIONS(5399),
    [anon_sym_as] = ACTIONS(5421),
    [anon_sym_POUND] = ACTIONS(5423),
    [anon_sym_COLON_COLON] = ACTIONS(5425),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5427),
    [anon_sym_begin] = ACTIONS(5429),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5431),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5397),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5433),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5435),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5397),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5397),
    [aux_sym_number_token1] = ACTIONS(5437),
    [aux_sym_signed_number_token1] = ACTIONS(5439),
    [anon_sym_SQUOTE] = ACTIONS(5441),
    [anon_sym_DQUOTE] = ACTIONS(5443),
    [sym_let_operator] = ACTIONS(5397),
    [sym_let_and_operator] = ACTIONS(5397),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_directive_token1] = ACTIONS(5399),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2527] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14583),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2527),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18430),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5455),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5459),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5463),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5465),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5471),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5471),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5471),
    [sym_let_and_operator] = ACTIONS(5471),
    [sym_match_operator] = ACTIONS(5471),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2528] = {
    [sym__simple_expression] = STATE(7095),
    [sym_typed_expression] = STATE(7057),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_labeled_argument] = STATE(8121),
    [sym_prefix_expression] = STATE(7057),
    [sym_hash_expression] = STATE(7057),
    [sym_field_get_expression] = STATE(7057),
    [sym_array_get_expression] = STATE(7057),
    [sym_string_get_expression] = STATE(7057),
    [sym_bigarray_get_expression] = STATE(7057),
    [sym_coercion_expression] = STATE(7057),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2528),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [aux_sym_class_application_repeat1] = STATE(2582),
    [sym__lowercase_identifier] = ACTIONS(5473),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_DOT] = ACTIONS(5477),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_POUND] = ACTIONS(5479),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_done] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5481),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2529] = {
    [sym__simple_expression] = STATE(6051),
    [sym_typed_expression] = STATE(6059),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_labeled_argument] = STATE(7158),
    [sym_prefix_expression] = STATE(6059),
    [sym_hash_expression] = STATE(6059),
    [sym_field_get_expression] = STATE(6059),
    [sym_array_get_expression] = STATE(6059),
    [sym_string_get_expression] = STATE(6059),
    [sym_bigarray_get_expression] = STATE(6059),
    [sym_coercion_expression] = STATE(6059),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2529),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [aux_sym_class_application_repeat1] = STATE(2529),
    [sym__lowercase_identifier] = ACTIONS(5483),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(5486),
    [anon_sym_QMARK] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5489),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5492),
    [anon_sym_true] = ACTIONS(5495),
    [anon_sym_false] = ACTIONS(5495),
    [anon_sym_LBRACE] = ACTIONS(5498),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(5501),
    [anon_sym_in] = ACTIONS(3792),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5504),
    [anon_sym_new] = ACTIONS(5507),
    [anon_sym_LBRACE_LT] = ACTIONS(5510),
    [anon_sym_begin] = ACTIONS(5513),
    [sym_ocamlyacc_value] = ACTIONS(5516),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5519),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5522),
    [aux_sym_number_token1] = ACTIONS(5525),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(5528),
    [anon_sym_DQUOTE] = ACTIONS(5531),
    [sym_prefix_operator] = ACTIONS(5534),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym_let_and_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5537),
    [aux_sym_tag_token1] = ACTIONS(5540),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2530] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14341),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2530),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18541),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5543),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5545),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5547),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5551),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5551),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5551),
    [sym_let_and_operator] = ACTIONS(5551),
    [sym_match_operator] = ACTIONS(5551),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2531] = {
    [sym__simple_expression] = STATE(7424),
    [sym_typed_expression] = STATE(7319),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_labeled_argument] = STATE(8018),
    [sym_prefix_expression] = STATE(7319),
    [sym_hash_expression] = STATE(7319),
    [sym_field_get_expression] = STATE(7319),
    [sym_array_get_expression] = STATE(7319),
    [sym_string_get_expression] = STATE(7319),
    [sym_bigarray_get_expression] = STATE(7319),
    [sym_coercion_expression] = STATE(7319),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2531),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [aux_sym_class_application_repeat1] = STATE(2580),
    [sym__lowercase_identifier] = ACTIONS(5553),
    [anon_sym_TILDE] = ACTIONS(5555),
    [anon_sym_QMARK] = ACTIONS(5555),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_DOT] = ACTIONS(5557),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_end] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_POUND] = ACTIONS(5559),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5561),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2532] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14413),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2532),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18738),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5563),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5565),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5567),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5569),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5571),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5571),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5571),
    [sym_let_and_operator] = ACTIONS(5571),
    [sym_match_operator] = ACTIONS(5571),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2533] = {
    [sym__simple_expression] = STATE(7145),
    [sym_typed_expression] = STATE(7186),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_labeled_argument] = STATE(8045),
    [sym_prefix_expression] = STATE(7186),
    [sym_hash_expression] = STATE(7186),
    [sym_field_get_expression] = STATE(7186),
    [sym_array_get_expression] = STATE(7186),
    [sym_string_get_expression] = STATE(7186),
    [sym_bigarray_get_expression] = STATE(7186),
    [sym_coercion_expression] = STATE(7186),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2533),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [aux_sym_class_application_repeat1] = STATE(2578),
    [sym__lowercase_identifier] = ACTIONS(5573),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_QMARK] = ACTIONS(5575),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_DOT] = ACTIONS(5577),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_POUND] = ACTIONS(5579),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_then] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5581),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2534] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14480),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2534),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18866),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5583),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5585),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5587),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5589),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5591),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5591),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5591),
    [sym_let_and_operator] = ACTIONS(5591),
    [sym_match_operator] = ACTIONS(5591),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2535] = {
    [sym__simple_expression] = STATE(7433),
    [sym_typed_expression] = STATE(7511),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_labeled_argument] = STATE(8135),
    [sym_prefix_expression] = STATE(7511),
    [sym_hash_expression] = STATE(7511),
    [sym_field_get_expression] = STATE(7511),
    [sym_array_get_expression] = STATE(7511),
    [sym_string_get_expression] = STATE(7511),
    [sym_bigarray_get_expression] = STATE(7511),
    [sym_coercion_expression] = STATE(7511),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2535),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [aux_sym_class_application_repeat1] = STATE(2584),
    [sym__lowercase_identifier] = ACTIONS(5593),
    [anon_sym_TILDE] = ACTIONS(5595),
    [anon_sym_QMARK] = ACTIONS(5595),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_DOT] = ACTIONS(5597),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_with] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_POUND] = ACTIONS(5599),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5601),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2536] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14553),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2536),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18546),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5603),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5605),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5607),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5609),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5611),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5611),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5611),
    [sym_let_and_operator] = ACTIONS(5611),
    [sym_match_operator] = ACTIONS(5611),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2537] = {
    [sym__simple_expression] = STATE(6051),
    [sym_typed_expression] = STATE(6059),
    [sym_list_expression] = STATE(6059),
    [sym_array_expression] = STATE(6059),
    [sym_record_expression] = STATE(6059),
    [sym_labeled_argument] = STATE(7158),
    [sym_prefix_expression] = STATE(6059),
    [sym_hash_expression] = STATE(6059),
    [sym_field_get_expression] = STATE(6059),
    [sym_array_get_expression] = STATE(6059),
    [sym_string_get_expression] = STATE(6059),
    [sym_bigarray_get_expression] = STATE(6059),
    [sym_coercion_expression] = STATE(6059),
    [sym_local_open_expression] = STATE(6059),
    [sym_package_expression] = STATE(6059),
    [sym_new_expression] = STATE(6059),
    [sym_object_copy_expression] = STATE(6059),
    [sym_method_invocation] = STATE(6059),
    [sym_object_expression] = STATE(6059),
    [sym_parenthesized_expression] = STATE(6059),
    [sym_attribute] = STATE(2537),
    [sym_extension] = STATE(6059),
    [sym_quoted_extension] = STATE(6059),
    [sym__constant] = STATE(6059),
    [sym_number] = STATE(6016),
    [sym_character] = STATE(6016),
    [sym_string] = STATE(6016),
    [sym_quoted_string] = STATE(6016),
    [sym_boolean] = STATE(6016),
    [sym_unit] = STATE(6016),
    [sym__value_name] = STATE(6002),
    [sym_parenthesized_operator] = STATE(6069),
    [sym_value_path] = STATE(6059),
    [sym_module_path] = STATE(18835),
    [sym_constructor_path] = STATE(6059),
    [sym__constructor_name] = STATE(6018),
    [sym_tag] = STATE(6059),
    [aux_sym_class_application_repeat1] = STATE(2529),
    [sym__lowercase_identifier] = ACTIONS(5255),
    [anon_sym_and] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(5257),
    [anon_sym_QMARK] = ACTIONS(5257),
    [anon_sym_LPAREN] = ACTIONS(1349),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1357),
    [anon_sym_in] = ACTIONS(3853),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1361),
    [anon_sym_new] = ACTIONS(1371),
    [anon_sym_LBRACE_LT] = ACTIONS(1373),
    [anon_sym_begin] = ACTIONS(1375),
    [sym_ocamlyacc_value] = ACTIONS(1377),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3851),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(1379),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(1381),
    [aux_sym_number_token1] = ACTIONS(1383),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(1385),
    [anon_sym_DQUOTE] = ACTIONS(1387),
    [sym_prefix_operator] = ACTIONS(1389),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym_let_and_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(1393),
    [aux_sym_tag_token1] = ACTIONS(1395),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2538] = {
    [sym_parameter] = STATE(10790),
    [sym__polymorphic_typed] = STATE(18332),
    [sym__parenthesized_abstract_type] = STATE(10790),
    [sym__simple_pattern] = STATE(10586),
    [sym_typed_pattern] = STATE(10736),
    [sym_polymorphic_variant_pattern] = STATE(10736),
    [sym_record_pattern] = STATE(10736),
    [sym_list_pattern] = STATE(10736),
    [sym_array_pattern] = STATE(10736),
    [sym_local_open_pattern] = STATE(10736),
    [sym_package_pattern] = STATE(10736),
    [sym_parenthesized_pattern] = STATE(10736),
    [sym_attribute] = STATE(2538),
    [sym_item_attribute] = STATE(11669),
    [sym_extension] = STATE(10736),
    [sym_quoted_extension] = STATE(10736),
    [sym__constant] = STATE(10744),
    [sym__signed_constant] = STATE(10736),
    [sym_number] = STATE(10787),
    [sym_signed_number] = STATE(10744),
    [sym_character] = STATE(10787),
    [sym_string] = STATE(10787),
    [sym_quoted_string] = STATE(10787),
    [sym_boolean] = STATE(10787),
    [sym_unit] = STATE(10787),
    [sym__simple_value_pattern] = STATE(10736),
    [sym_parenthesized_operator] = STATE(10736),
    [sym_module_path] = STATE(19549),
    [sym_constructor_path] = STATE(10736),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(10736),
    [aux_sym_expression_item_repeat1] = STATE(11190),
    [aux_sym_let_binding_repeat1] = STATE(4792),
    [sym__lowercase_identifier] = ACTIONS(5395),
    [anon_sym_SEMI_SEMI] = ACTIONS(5397),
    [anon_sym_let] = ACTIONS(5399),
    [anon_sym_and] = ACTIONS(5399),
    [anon_sym_COLON_GT] = ACTIONS(5613),
    [anon_sym_EQ] = ACTIONS(5615),
    [anon_sym_TILDE] = ACTIONS(5405),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_LPAREN] = ACTIONS(5407),
    [anon_sym_external] = ACTIONS(5399),
    [anon_sym_type] = ACTIONS(5399),
    [anon_sym_COMMA] = ACTIONS(5617),
    [anon_sym_PIPE] = ACTIONS(5619),
    [anon_sym_LBRACK] = ACTIONS(5413),
    [anon_sym_true] = ACTIONS(5415),
    [anon_sym_false] = ACTIONS(5415),
    [anon_sym_COLON2] = ACTIONS(5417),
    [anon_sym_LBRACE] = ACTIONS(5419),
    [anon_sym_exception] = ACTIONS(5399),
    [anon_sym_module] = ACTIONS(5399),
    [anon_sym_open] = ACTIONS(5399),
    [anon_sym_include] = ACTIONS(5399),
    [anon_sym_class] = ACTIONS(5399),
    [anon_sym_end] = ACTIONS(5399),
    [anon_sym_in] = ACTIONS(5399),
    [anon_sym_as] = ACTIONS(5621),
    [anon_sym_POUND] = ACTIONS(5423),
    [anon_sym_COLON_COLON] = ACTIONS(5623),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5427),
    [anon_sym_begin] = ACTIONS(5429),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5431),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5397),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5433),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5435),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5397),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5397),
    [aux_sym_number_token1] = ACTIONS(5437),
    [aux_sym_signed_number_token1] = ACTIONS(5439),
    [anon_sym_SQUOTE] = ACTIONS(5441),
    [anon_sym_DQUOTE] = ACTIONS(5443),
    [sym_let_operator] = ACTIONS(5397),
    [sym_let_and_operator] = ACTIONS(5397),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_directive_token1] = ACTIONS(5399),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2539] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14508),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2539),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2540] = {
    [sym__abstract_type] = STATE(19119),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14306),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2540),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19798),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(4863),
    [anon_sym_type] = ACTIONS(4819),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(4867),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(1709),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4871),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4871),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4871),
    [sym_let_and_operator] = ACTIONS(4871),
    [sym_match_operator] = ACTIONS(4871),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2541] = {
    [sym__simple_expression] = STATE(7216),
    [sym_typed_expression] = STATE(7419),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_labeled_argument] = STATE(8160),
    [sym_prefix_expression] = STATE(7419),
    [sym_hash_expression] = STATE(7419),
    [sym_field_get_expression] = STATE(7419),
    [sym_array_get_expression] = STATE(7419),
    [sym_string_get_expression] = STATE(7419),
    [sym_bigarray_get_expression] = STATE(7419),
    [sym_coercion_expression] = STATE(7419),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2541),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [aux_sym_class_application_repeat1] = STATE(2581),
    [sym__lowercase_identifier] = ACTIONS(5625),
    [anon_sym_TILDE] = ACTIONS(5627),
    [anon_sym_QMARK] = ACTIONS(5627),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_COMMA] = ACTIONS(3191),
    [anon_sym_PIPE] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_DOT] = ACTIONS(5629),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_POUND] = ACTIONS(5631),
    [anon_sym_COLON_COLON] = ACTIONS(3191),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_do] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(3193),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(3193),
    [sym_hash_operator] = ACTIONS(5633),
    [sym_pow_operator] = ACTIONS(3193),
    [sym_mult_operator] = ACTIONS(3193),
    [aux_sym_add_operator_token1] = ACTIONS(3193),
    [sym_concat_operator] = ACTIONS(3191),
    [sym_rel_operator] = ACTIONS(3193),
    [sym_and_operator] = ACTIONS(3193),
    [sym_or_operator] = ACTIONS(3193),
    [sym_assign_operator] = ACTIONS(3191),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2542] = {
    [sym__simple_expression] = STATE(6171),
    [sym_typed_expression] = STATE(6278),
    [sym_list_expression] = STATE(6278),
    [sym_array_expression] = STATE(6278),
    [sym_record_expression] = STATE(6278),
    [sym_labeled_argument] = STATE(7605),
    [sym_prefix_expression] = STATE(6278),
    [sym_hash_expression] = STATE(6278),
    [sym_field_get_expression] = STATE(6278),
    [sym_array_get_expression] = STATE(6278),
    [sym_string_get_expression] = STATE(6278),
    [sym_bigarray_get_expression] = STATE(6278),
    [sym_coercion_expression] = STATE(6278),
    [sym_local_open_expression] = STATE(6278),
    [sym_package_expression] = STATE(6278),
    [sym_new_expression] = STATE(6278),
    [sym_object_copy_expression] = STATE(6278),
    [sym_method_invocation] = STATE(6278),
    [sym_object_expression] = STATE(6278),
    [sym_parenthesized_expression] = STATE(6278),
    [sym_attribute] = STATE(2542),
    [sym_extension] = STATE(6278),
    [sym_quoted_extension] = STATE(6278),
    [sym__constant] = STATE(6278),
    [sym_number] = STATE(6109),
    [sym_character] = STATE(6109),
    [sym_string] = STATE(6109),
    [sym_quoted_string] = STATE(6109),
    [sym_boolean] = STATE(6109),
    [sym_unit] = STATE(6109),
    [sym__value_name] = STATE(6323),
    [sym_parenthesized_operator] = STATE(6342),
    [sym_value_path] = STATE(6278),
    [sym_module_path] = STATE(19291),
    [sym_constructor_path] = STATE(6278),
    [sym__constructor_name] = STATE(6110),
    [sym_tag] = STATE(6278),
    [aux_sym_class_application_repeat1] = STATE(2542),
    [sym__lowercase_identifier] = ACTIONS(5635),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(5638),
    [anon_sym_QMARK] = ACTIONS(5638),
    [anon_sym_LPAREN] = ACTIONS(5641),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5644),
    [anon_sym_true] = ACTIONS(5647),
    [anon_sym_false] = ACTIONS(5647),
    [anon_sym_LBRACE] = ACTIONS(5650),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(5653),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5656),
    [anon_sym_new] = ACTIONS(5659),
    [anon_sym_LBRACE_LT] = ACTIONS(5662),
    [anon_sym_begin] = ACTIONS(5665),
    [sym_ocamlyacc_value] = ACTIONS(5668),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5671),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5674),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(5677),
    [anon_sym_SQUOTE] = ACTIONS(5680),
    [anon_sym_DQUOTE] = ACTIONS(5683),
    [sym_prefix_operator] = ACTIONS(5686),
    [sym_let_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5689),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(5692),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2543] = {
    [sym__simple_expression] = STATE(6171),
    [sym_typed_expression] = STATE(6278),
    [sym_list_expression] = STATE(6278),
    [sym_array_expression] = STATE(6278),
    [sym_record_expression] = STATE(6278),
    [sym_labeled_argument] = STATE(7605),
    [sym_prefix_expression] = STATE(6278),
    [sym_hash_expression] = STATE(6278),
    [sym_field_get_expression] = STATE(6278),
    [sym_array_get_expression] = STATE(6278),
    [sym_string_get_expression] = STATE(6278),
    [sym_bigarray_get_expression] = STATE(6278),
    [sym_coercion_expression] = STATE(6278),
    [sym_local_open_expression] = STATE(6278),
    [sym_package_expression] = STATE(6278),
    [sym_new_expression] = STATE(6278),
    [sym_object_copy_expression] = STATE(6278),
    [sym_method_invocation] = STATE(6278),
    [sym_object_expression] = STATE(6278),
    [sym_parenthesized_expression] = STATE(6278),
    [sym_attribute] = STATE(2543),
    [sym_extension] = STATE(6278),
    [sym_quoted_extension] = STATE(6278),
    [sym__constant] = STATE(6278),
    [sym_number] = STATE(6109),
    [sym_character] = STATE(6109),
    [sym_string] = STATE(6109),
    [sym_quoted_string] = STATE(6109),
    [sym_boolean] = STATE(6109),
    [sym_unit] = STATE(6109),
    [sym__value_name] = STATE(6323),
    [sym_parenthesized_operator] = STATE(6342),
    [sym_value_path] = STATE(6278),
    [sym_module_path] = STATE(19291),
    [sym_constructor_path] = STATE(6278),
    [sym__constructor_name] = STATE(6110),
    [sym_tag] = STATE(6278),
    [aux_sym_class_application_repeat1] = STATE(2542),
    [sym__lowercase_identifier] = ACTIONS(5695),
    [anon_sym_SEMI_SEMI] = ACTIONS(5697),
    [anon_sym_let] = ACTIONS(5699),
    [anon_sym_and] = ACTIONS(5699),
    [anon_sym_TILDE] = ACTIONS(5701),
    [anon_sym_QMARK] = ACTIONS(5701),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [anon_sym_external] = ACTIONS(5699),
    [anon_sym_type] = ACTIONS(5699),
    [anon_sym_LBRACK] = ACTIONS(5705),
    [anon_sym_true] = ACTIONS(5707),
    [anon_sym_false] = ACTIONS(5707),
    [anon_sym_LBRACE] = ACTIONS(5709),
    [anon_sym_exception] = ACTIONS(5699),
    [anon_sym_module] = ACTIONS(5699),
    [anon_sym_open] = ACTIONS(5699),
    [anon_sym_include] = ACTIONS(5699),
    [anon_sym_class] = ACTIONS(5699),
    [anon_sym_end] = ACTIONS(5699),
    [anon_sym_object] = ACTIONS(5711),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5713),
    [anon_sym_new] = ACTIONS(5715),
    [anon_sym_LBRACE_LT] = ACTIONS(5717),
    [anon_sym_begin] = ACTIONS(5719),
    [sym_ocamlyacc_value] = ACTIONS(5721),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5699),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5697),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5723),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5725),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5697),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5697),
    [aux_sym_number_token1] = ACTIONS(5727),
    [anon_sym_SQUOTE] = ACTIONS(5729),
    [anon_sym_DQUOTE] = ACTIONS(5731),
    [sym_prefix_operator] = ACTIONS(5733),
    [sym_let_operator] = ACTIONS(5697),
    [sym__uppercase_identifier] = ACTIONS(5735),
    [aux_sym_directive_token1] = ACTIONS(5697),
    [aux_sym_tag_token1] = ACTIONS(5737),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2544] = {
    [sym_parameter] = STATE(10790),
    [sym__polymorphic_typed] = STATE(17278),
    [sym__parenthesized_abstract_type] = STATE(10790),
    [sym__simple_pattern] = STATE(10586),
    [sym_typed_pattern] = STATE(10736),
    [sym_polymorphic_variant_pattern] = STATE(10736),
    [sym_record_pattern] = STATE(10736),
    [sym_list_pattern] = STATE(10736),
    [sym_array_pattern] = STATE(10736),
    [sym_local_open_pattern] = STATE(10736),
    [sym_package_pattern] = STATE(10736),
    [sym_parenthesized_pattern] = STATE(10736),
    [sym_attribute] = STATE(2544),
    [sym_item_attribute] = STATE(11669),
    [sym_extension] = STATE(10736),
    [sym_quoted_extension] = STATE(10736),
    [sym__constant] = STATE(10744),
    [sym__signed_constant] = STATE(10736),
    [sym_number] = STATE(10787),
    [sym_signed_number] = STATE(10744),
    [sym_character] = STATE(10787),
    [sym_string] = STATE(10787),
    [sym_quoted_string] = STATE(10787),
    [sym_boolean] = STATE(10787),
    [sym_unit] = STATE(10787),
    [sym__simple_value_pattern] = STATE(10736),
    [sym_parenthesized_operator] = STATE(10736),
    [sym_module_path] = STATE(19549),
    [sym_constructor_path] = STATE(10736),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(10736),
    [aux_sym_expression_item_repeat1] = STATE(11190),
    [aux_sym_let_binding_repeat1] = STATE(4791),
    [sym__lowercase_identifier] = ACTIONS(5395),
    [anon_sym_SEMI_SEMI] = ACTIONS(5397),
    [anon_sym_let] = ACTIONS(5399),
    [anon_sym_and] = ACTIONS(5399),
    [anon_sym_COLON_GT] = ACTIONS(5739),
    [anon_sym_EQ] = ACTIONS(5741),
    [anon_sym_TILDE] = ACTIONS(5405),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_LPAREN] = ACTIONS(5407),
    [anon_sym_external] = ACTIONS(5399),
    [anon_sym_type] = ACTIONS(5399),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_PIPE] = ACTIONS(5745),
    [anon_sym_LBRACK] = ACTIONS(5413),
    [anon_sym_RBRACK] = ACTIONS(5397),
    [anon_sym_true] = ACTIONS(5415),
    [anon_sym_false] = ACTIONS(5415),
    [anon_sym_COLON2] = ACTIONS(5417),
    [anon_sym_LBRACE] = ACTIONS(5419),
    [anon_sym_exception] = ACTIONS(5399),
    [anon_sym_module] = ACTIONS(5399),
    [anon_sym_open] = ACTIONS(5399),
    [anon_sym_include] = ACTIONS(5399),
    [anon_sym_class] = ACTIONS(5399),
    [anon_sym_as] = ACTIONS(5747),
    [anon_sym_POUND] = ACTIONS(5423),
    [anon_sym_COLON_COLON] = ACTIONS(5749),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5427),
    [anon_sym_begin] = ACTIONS(5429),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5431),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5397),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5433),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5435),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5397),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5397),
    [aux_sym_number_token1] = ACTIONS(5437),
    [aux_sym_signed_number_token1] = ACTIONS(5439),
    [anon_sym_SQUOTE] = ACTIONS(5441),
    [anon_sym_DQUOTE] = ACTIONS(5443),
    [sym_let_operator] = ACTIONS(5397),
    [sym_let_and_operator] = ACTIONS(5397),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_directive_token1] = ACTIONS(5399),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2545] = {
    [sym__simple_expression] = STATE(6361),
    [sym_typed_expression] = STATE(6355),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_labeled_argument] = STATE(7666),
    [sym_prefix_expression] = STATE(6355),
    [sym_hash_expression] = STATE(6355),
    [sym_field_get_expression] = STATE(6355),
    [sym_array_get_expression] = STATE(6355),
    [sym_string_get_expression] = STATE(6355),
    [sym_bigarray_get_expression] = STATE(6355),
    [sym_coercion_expression] = STATE(6355),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2545),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [aux_sym_class_application_repeat1] = STATE(2545),
    [sym__lowercase_identifier] = ACTIONS(5751),
    [anon_sym_TILDE] = ACTIONS(5754),
    [anon_sym_QMARK] = ACTIONS(5754),
    [anon_sym_LPAREN] = ACTIONS(5757),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5760),
    [anon_sym_true] = ACTIONS(5763),
    [anon_sym_false] = ACTIONS(5763),
    [anon_sym_LBRACE] = ACTIONS(5766),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(5769),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5772),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_to] = ACTIONS(3792),
    [anon_sym_downto] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(5775),
    [anon_sym_LBRACE_LT] = ACTIONS(5778),
    [anon_sym_begin] = ACTIONS(5781),
    [sym_ocamlyacc_value] = ACTIONS(5784),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5787),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5790),
    [aux_sym_number_token1] = ACTIONS(5793),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(5796),
    [anon_sym_DQUOTE] = ACTIONS(5799),
    [sym_prefix_operator] = ACTIONS(5802),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5805),
    [aux_sym_tag_token1] = ACTIONS(5808),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2546] = {
    [sym__simple_expression] = STATE(6158),
    [sym_typed_expression] = STATE(6176),
    [sym_list_expression] = STATE(6176),
    [sym_array_expression] = STATE(6176),
    [sym_record_expression] = STATE(6176),
    [sym_labeled_argument] = STATE(7654),
    [sym_prefix_expression] = STATE(6176),
    [sym_hash_expression] = STATE(6176),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_coercion_expression] = STATE(6176),
    [sym_local_open_expression] = STATE(6176),
    [sym_package_expression] = STATE(6176),
    [sym_new_expression] = STATE(6176),
    [sym_object_copy_expression] = STATE(6176),
    [sym_method_invocation] = STATE(6176),
    [sym_object_expression] = STATE(6176),
    [sym_parenthesized_expression] = STATE(6176),
    [sym_attribute] = STATE(2546),
    [sym_extension] = STATE(6176),
    [sym_quoted_extension] = STATE(6176),
    [sym__constant] = STATE(6176),
    [sym_number] = STATE(6075),
    [sym_character] = STATE(6075),
    [sym_string] = STATE(6075),
    [sym_quoted_string] = STATE(6075),
    [sym_boolean] = STATE(6075),
    [sym_unit] = STATE(6075),
    [sym__value_name] = STATE(6219),
    [sym_parenthesized_operator] = STATE(6275),
    [sym_value_path] = STATE(6176),
    [sym_module_path] = STATE(18997),
    [sym_constructor_path] = STATE(6176),
    [sym__constructor_name] = STATE(6076),
    [sym_tag] = STATE(6176),
    [aux_sym_class_application_repeat1] = STATE(2547),
    [sym__lowercase_identifier] = ACTIONS(5811),
    [anon_sym_SEMI_SEMI] = ACTIONS(5813),
    [anon_sym_let] = ACTIONS(5815),
    [anon_sym_and] = ACTIONS(5815),
    [anon_sym_TILDE] = ACTIONS(5817),
    [anon_sym_QMARK] = ACTIONS(5817),
    [anon_sym_LPAREN] = ACTIONS(5819),
    [anon_sym_external] = ACTIONS(5815),
    [anon_sym_type] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5821),
    [anon_sym_RBRACK] = ACTIONS(5813),
    [anon_sym_true] = ACTIONS(5823),
    [anon_sym_false] = ACTIONS(5823),
    [anon_sym_LBRACE] = ACTIONS(5825),
    [anon_sym_exception] = ACTIONS(5815),
    [anon_sym_module] = ACTIONS(5815),
    [anon_sym_open] = ACTIONS(5815),
    [anon_sym_include] = ACTIONS(5815),
    [anon_sym_class] = ACTIONS(5815),
    [anon_sym_object] = ACTIONS(5827),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5829),
    [anon_sym_new] = ACTIONS(5831),
    [anon_sym_LBRACE_LT] = ACTIONS(5833),
    [anon_sym_begin] = ACTIONS(5835),
    [sym_ocamlyacc_value] = ACTIONS(5837),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5815),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5813),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5839),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5841),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5813),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5813),
    [aux_sym_number_token1] = ACTIONS(5843),
    [anon_sym_SQUOTE] = ACTIONS(5845),
    [anon_sym_DQUOTE] = ACTIONS(5847),
    [sym_prefix_operator] = ACTIONS(5849),
    [sym_let_operator] = ACTIONS(5813),
    [sym__uppercase_identifier] = ACTIONS(5851),
    [aux_sym_directive_token1] = ACTIONS(5813),
    [aux_sym_tag_token1] = ACTIONS(5853),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2547] = {
    [sym__simple_expression] = STATE(6158),
    [sym_typed_expression] = STATE(6176),
    [sym_list_expression] = STATE(6176),
    [sym_array_expression] = STATE(6176),
    [sym_record_expression] = STATE(6176),
    [sym_labeled_argument] = STATE(7654),
    [sym_prefix_expression] = STATE(6176),
    [sym_hash_expression] = STATE(6176),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_coercion_expression] = STATE(6176),
    [sym_local_open_expression] = STATE(6176),
    [sym_package_expression] = STATE(6176),
    [sym_new_expression] = STATE(6176),
    [sym_object_copy_expression] = STATE(6176),
    [sym_method_invocation] = STATE(6176),
    [sym_object_expression] = STATE(6176),
    [sym_parenthesized_expression] = STATE(6176),
    [sym_attribute] = STATE(2547),
    [sym_extension] = STATE(6176),
    [sym_quoted_extension] = STATE(6176),
    [sym__constant] = STATE(6176),
    [sym_number] = STATE(6075),
    [sym_character] = STATE(6075),
    [sym_string] = STATE(6075),
    [sym_quoted_string] = STATE(6075),
    [sym_boolean] = STATE(6075),
    [sym_unit] = STATE(6075),
    [sym__value_name] = STATE(6219),
    [sym_parenthesized_operator] = STATE(6275),
    [sym_value_path] = STATE(6176),
    [sym_module_path] = STATE(18997),
    [sym_constructor_path] = STATE(6176),
    [sym__constructor_name] = STATE(6076),
    [sym_tag] = STATE(6176),
    [aux_sym_class_application_repeat1] = STATE(2549),
    [sym__lowercase_identifier] = ACTIONS(5811),
    [anon_sym_SEMI_SEMI] = ACTIONS(5697),
    [anon_sym_let] = ACTIONS(5699),
    [anon_sym_and] = ACTIONS(5699),
    [anon_sym_TILDE] = ACTIONS(5817),
    [anon_sym_QMARK] = ACTIONS(5817),
    [anon_sym_LPAREN] = ACTIONS(5819),
    [anon_sym_external] = ACTIONS(5699),
    [anon_sym_type] = ACTIONS(5699),
    [anon_sym_LBRACK] = ACTIONS(5821),
    [anon_sym_RBRACK] = ACTIONS(5697),
    [anon_sym_true] = ACTIONS(5823),
    [anon_sym_false] = ACTIONS(5823),
    [anon_sym_LBRACE] = ACTIONS(5825),
    [anon_sym_exception] = ACTIONS(5699),
    [anon_sym_module] = ACTIONS(5699),
    [anon_sym_open] = ACTIONS(5699),
    [anon_sym_include] = ACTIONS(5699),
    [anon_sym_class] = ACTIONS(5699),
    [anon_sym_object] = ACTIONS(5827),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5829),
    [anon_sym_new] = ACTIONS(5831),
    [anon_sym_LBRACE_LT] = ACTIONS(5833),
    [anon_sym_begin] = ACTIONS(5835),
    [sym_ocamlyacc_value] = ACTIONS(5837),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5699),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5697),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5839),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5841),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5697),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5697),
    [aux_sym_number_token1] = ACTIONS(5843),
    [anon_sym_SQUOTE] = ACTIONS(5845),
    [anon_sym_DQUOTE] = ACTIONS(5847),
    [sym_prefix_operator] = ACTIONS(5849),
    [sym_let_operator] = ACTIONS(5697),
    [sym__uppercase_identifier] = ACTIONS(5851),
    [aux_sym_directive_token1] = ACTIONS(5697),
    [aux_sym_tag_token1] = ACTIONS(5853),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2548] = {
    [sym_parameter] = STATE(10790),
    [sym__polymorphic_typed] = STATE(17347),
    [sym__parenthesized_abstract_type] = STATE(10790),
    [sym__simple_pattern] = STATE(10586),
    [sym_typed_pattern] = STATE(10736),
    [sym_polymorphic_variant_pattern] = STATE(10736),
    [sym_record_pattern] = STATE(10736),
    [sym_list_pattern] = STATE(10736),
    [sym_array_pattern] = STATE(10736),
    [sym_local_open_pattern] = STATE(10736),
    [sym_package_pattern] = STATE(10736),
    [sym_parenthesized_pattern] = STATE(10736),
    [sym_attribute] = STATE(2548),
    [sym_item_attribute] = STATE(11669),
    [sym_extension] = STATE(10736),
    [sym_quoted_extension] = STATE(10736),
    [sym__constant] = STATE(10744),
    [sym__signed_constant] = STATE(10736),
    [sym_number] = STATE(10787),
    [sym_signed_number] = STATE(10744),
    [sym_character] = STATE(10787),
    [sym_string] = STATE(10787),
    [sym_quoted_string] = STATE(10787),
    [sym_boolean] = STATE(10787),
    [sym_unit] = STATE(10787),
    [sym__simple_value_pattern] = STATE(10736),
    [sym_parenthesized_operator] = STATE(10736),
    [sym_module_path] = STATE(19549),
    [sym_constructor_path] = STATE(10736),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(10736),
    [aux_sym_expression_item_repeat1] = STATE(11190),
    [aux_sym_let_binding_repeat1] = STATE(4782),
    [sym__lowercase_identifier] = ACTIONS(5395),
    [anon_sym_SEMI_SEMI] = ACTIONS(5397),
    [anon_sym_let] = ACTIONS(5399),
    [anon_sym_and] = ACTIONS(5399),
    [anon_sym_COLON_GT] = ACTIONS(5855),
    [anon_sym_EQ] = ACTIONS(5857),
    [anon_sym_TILDE] = ACTIONS(5405),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_LPAREN] = ACTIONS(5407),
    [anon_sym_external] = ACTIONS(5399),
    [anon_sym_type] = ACTIONS(5399),
    [anon_sym_COMMA] = ACTIONS(5859),
    [anon_sym_PIPE] = ACTIONS(5861),
    [anon_sym_LBRACK] = ACTIONS(5413),
    [anon_sym_true] = ACTIONS(5415),
    [anon_sym_false] = ACTIONS(5415),
    [anon_sym_COLON2] = ACTIONS(5417),
    [anon_sym_LBRACE] = ACTIONS(5419),
    [anon_sym_exception] = ACTIONS(5399),
    [anon_sym_module] = ACTIONS(5399),
    [anon_sym_open] = ACTIONS(5399),
    [anon_sym_include] = ACTIONS(5399),
    [anon_sym_class] = ACTIONS(5399),
    [anon_sym_end] = ACTIONS(5399),
    [anon_sym_as] = ACTIONS(5863),
    [anon_sym_POUND] = ACTIONS(5423),
    [anon_sym_COLON_COLON] = ACTIONS(5865),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5427),
    [anon_sym_begin] = ACTIONS(5429),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5431),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5397),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5433),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5435),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5397),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5397),
    [aux_sym_number_token1] = ACTIONS(5437),
    [aux_sym_signed_number_token1] = ACTIONS(5439),
    [anon_sym_SQUOTE] = ACTIONS(5441),
    [anon_sym_DQUOTE] = ACTIONS(5443),
    [sym_let_operator] = ACTIONS(5397),
    [sym_let_and_operator] = ACTIONS(5397),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_directive_token1] = ACTIONS(5399),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2549] = {
    [sym__simple_expression] = STATE(6158),
    [sym_typed_expression] = STATE(6176),
    [sym_list_expression] = STATE(6176),
    [sym_array_expression] = STATE(6176),
    [sym_record_expression] = STATE(6176),
    [sym_labeled_argument] = STATE(7654),
    [sym_prefix_expression] = STATE(6176),
    [sym_hash_expression] = STATE(6176),
    [sym_field_get_expression] = STATE(6176),
    [sym_array_get_expression] = STATE(6176),
    [sym_string_get_expression] = STATE(6176),
    [sym_bigarray_get_expression] = STATE(6176),
    [sym_coercion_expression] = STATE(6176),
    [sym_local_open_expression] = STATE(6176),
    [sym_package_expression] = STATE(6176),
    [sym_new_expression] = STATE(6176),
    [sym_object_copy_expression] = STATE(6176),
    [sym_method_invocation] = STATE(6176),
    [sym_object_expression] = STATE(6176),
    [sym_parenthesized_expression] = STATE(6176),
    [sym_attribute] = STATE(2549),
    [sym_extension] = STATE(6176),
    [sym_quoted_extension] = STATE(6176),
    [sym__constant] = STATE(6176),
    [sym_number] = STATE(6075),
    [sym_character] = STATE(6075),
    [sym_string] = STATE(6075),
    [sym_quoted_string] = STATE(6075),
    [sym_boolean] = STATE(6075),
    [sym_unit] = STATE(6075),
    [sym__value_name] = STATE(6219),
    [sym_parenthesized_operator] = STATE(6275),
    [sym_value_path] = STATE(6176),
    [sym_module_path] = STATE(18997),
    [sym_constructor_path] = STATE(6176),
    [sym__constructor_name] = STATE(6076),
    [sym_tag] = STATE(6176),
    [aux_sym_class_application_repeat1] = STATE(2549),
    [sym__lowercase_identifier] = ACTIONS(5867),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_let] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(5870),
    [anon_sym_QMARK] = ACTIONS(5870),
    [anon_sym_LPAREN] = ACTIONS(5873),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5876),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(5879),
    [anon_sym_false] = ACTIONS(5879),
    [anon_sym_LBRACE] = ACTIONS(5882),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(5885),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5888),
    [anon_sym_new] = ACTIONS(5891),
    [anon_sym_LBRACE_LT] = ACTIONS(5894),
    [anon_sym_begin] = ACTIONS(5897),
    [sym_ocamlyacc_value] = ACTIONS(5900),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5903),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5906),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(5909),
    [anon_sym_SQUOTE] = ACTIONS(5912),
    [anon_sym_DQUOTE] = ACTIONS(5915),
    [sym_prefix_operator] = ACTIONS(5918),
    [sym_let_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(5921),
    [aux_sym_directive_token1] = ACTIONS(3790),
    [aux_sym_tag_token1] = ACTIONS(5924),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2550] = {
    [sym__simple_expression] = STATE(6171),
    [sym_typed_expression] = STATE(6278),
    [sym_list_expression] = STATE(6278),
    [sym_array_expression] = STATE(6278),
    [sym_record_expression] = STATE(6278),
    [sym_labeled_argument] = STATE(7605),
    [sym_prefix_expression] = STATE(6278),
    [sym_hash_expression] = STATE(6278),
    [sym_field_get_expression] = STATE(6278),
    [sym_array_get_expression] = STATE(6278),
    [sym_string_get_expression] = STATE(6278),
    [sym_bigarray_get_expression] = STATE(6278),
    [sym_coercion_expression] = STATE(6278),
    [sym_local_open_expression] = STATE(6278),
    [sym_package_expression] = STATE(6278),
    [sym_new_expression] = STATE(6278),
    [sym_object_copy_expression] = STATE(6278),
    [sym_method_invocation] = STATE(6278),
    [sym_object_expression] = STATE(6278),
    [sym_parenthesized_expression] = STATE(6278),
    [sym_attribute] = STATE(2550),
    [sym_extension] = STATE(6278),
    [sym_quoted_extension] = STATE(6278),
    [sym__constant] = STATE(6278),
    [sym_number] = STATE(6109),
    [sym_character] = STATE(6109),
    [sym_string] = STATE(6109),
    [sym_quoted_string] = STATE(6109),
    [sym_boolean] = STATE(6109),
    [sym_unit] = STATE(6109),
    [sym__value_name] = STATE(6323),
    [sym_parenthesized_operator] = STATE(6342),
    [sym_value_path] = STATE(6278),
    [sym_module_path] = STATE(19291),
    [sym_constructor_path] = STATE(6278),
    [sym__constructor_name] = STATE(6110),
    [sym_tag] = STATE(6278),
    [aux_sym_class_application_repeat1] = STATE(2543),
    [sym__lowercase_identifier] = ACTIONS(5695),
    [anon_sym_SEMI_SEMI] = ACTIONS(5813),
    [anon_sym_let] = ACTIONS(5815),
    [anon_sym_and] = ACTIONS(5815),
    [anon_sym_TILDE] = ACTIONS(5701),
    [anon_sym_QMARK] = ACTIONS(5701),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [anon_sym_external] = ACTIONS(5815),
    [anon_sym_type] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5705),
    [anon_sym_true] = ACTIONS(5707),
    [anon_sym_false] = ACTIONS(5707),
    [anon_sym_LBRACE] = ACTIONS(5709),
    [anon_sym_exception] = ACTIONS(5815),
    [anon_sym_module] = ACTIONS(5815),
    [anon_sym_open] = ACTIONS(5815),
    [anon_sym_include] = ACTIONS(5815),
    [anon_sym_class] = ACTIONS(5815),
    [anon_sym_end] = ACTIONS(5815),
    [anon_sym_object] = ACTIONS(5711),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5713),
    [anon_sym_new] = ACTIONS(5715),
    [anon_sym_LBRACE_LT] = ACTIONS(5717),
    [anon_sym_begin] = ACTIONS(5719),
    [sym_ocamlyacc_value] = ACTIONS(5721),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5815),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5813),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5723),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5725),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5813),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5813),
    [aux_sym_number_token1] = ACTIONS(5727),
    [anon_sym_SQUOTE] = ACTIONS(5729),
    [anon_sym_DQUOTE] = ACTIONS(5731),
    [sym_prefix_operator] = ACTIONS(5733),
    [sym_let_operator] = ACTIONS(5813),
    [sym__uppercase_identifier] = ACTIONS(5735),
    [aux_sym_directive_token1] = ACTIONS(5813),
    [aux_sym_tag_token1] = ACTIONS(5737),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2551] = {
    [sym__simple_expression] = STATE(6361),
    [sym_typed_expression] = STATE(6355),
    [sym_list_expression] = STATE(6355),
    [sym_array_expression] = STATE(6355),
    [sym_record_expression] = STATE(6355),
    [sym_labeled_argument] = STATE(7666),
    [sym_prefix_expression] = STATE(6355),
    [sym_hash_expression] = STATE(6355),
    [sym_field_get_expression] = STATE(6355),
    [sym_array_get_expression] = STATE(6355),
    [sym_string_get_expression] = STATE(6355),
    [sym_bigarray_get_expression] = STATE(6355),
    [sym_coercion_expression] = STATE(6355),
    [sym_local_open_expression] = STATE(6355),
    [sym_package_expression] = STATE(6355),
    [sym_new_expression] = STATE(6355),
    [sym_object_copy_expression] = STATE(6355),
    [sym_method_invocation] = STATE(6355),
    [sym_object_expression] = STATE(6355),
    [sym_parenthesized_expression] = STATE(6355),
    [sym_attribute] = STATE(2551),
    [sym_extension] = STATE(6355),
    [sym_quoted_extension] = STATE(6355),
    [sym__constant] = STATE(6355),
    [sym_number] = STATE(6128),
    [sym_character] = STATE(6128),
    [sym_string] = STATE(6128),
    [sym_quoted_string] = STATE(6128),
    [sym_boolean] = STATE(6128),
    [sym_unit] = STATE(6128),
    [sym__value_name] = STATE(6393),
    [sym_parenthesized_operator] = STATE(6099),
    [sym_value_path] = STATE(6355),
    [sym_module_path] = STATE(19567),
    [sym_constructor_path] = STATE(6355),
    [sym__constructor_name] = STATE(6129),
    [sym_tag] = STATE(6355),
    [aux_sym_class_application_repeat1] = STATE(2545),
    [sym__lowercase_identifier] = ACTIONS(5265),
    [anon_sym_TILDE] = ACTIONS(5267),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_LPAREN] = ACTIONS(1981),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(1983),
    [anon_sym_true] = ACTIONS(1985),
    [anon_sym_false] = ACTIONS(1985),
    [anon_sym_LBRACE] = ACTIONS(1987),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(1989),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1993),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_to] = ACTIONS(3853),
    [anon_sym_downto] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2003),
    [anon_sym_LBRACE_LT] = ACTIONS(2005),
    [anon_sym_begin] = ACTIONS(2007),
    [sym_ocamlyacc_value] = ACTIONS(2009),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2011),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2013),
    [aux_sym_number_token1] = ACTIONS(2015),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2017),
    [anon_sym_DQUOTE] = ACTIONS(2019),
    [sym_prefix_operator] = ACTIONS(2021),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2025),
    [aux_sym_tag_token1] = ACTIONS(2027),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2552] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14480),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2552),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18866),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5583),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5585),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5587),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5589),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5591),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5591),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5591),
    [sym_let_and_operator] = ACTIONS(5591),
    [sym_match_operator] = ACTIONS(5591),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2553] = {
    [sym__simple_expression] = STATE(6944),
    [sym_typed_expression] = STATE(6477),
    [sym_list_expression] = STATE(6477),
    [sym_array_expression] = STATE(6477),
    [sym_record_expression] = STATE(6477),
    [sym_labeled_argument] = STATE(7880),
    [sym_prefix_expression] = STATE(6477),
    [sym_hash_expression] = STATE(6477),
    [sym_field_get_expression] = STATE(6477),
    [sym_array_get_expression] = STATE(6477),
    [sym_string_get_expression] = STATE(6477),
    [sym_bigarray_get_expression] = STATE(6477),
    [sym_coercion_expression] = STATE(6477),
    [sym_local_open_expression] = STATE(6477),
    [sym_package_expression] = STATE(6477),
    [sym_new_expression] = STATE(6477),
    [sym_object_copy_expression] = STATE(6477),
    [sym_method_invocation] = STATE(6477),
    [sym_object_expression] = STATE(6477),
    [sym_parenthesized_expression] = STATE(6477),
    [sym_attribute] = STATE(2553),
    [sym_extension] = STATE(6477),
    [sym_quoted_extension] = STATE(6477),
    [sym__constant] = STATE(6477),
    [sym_number] = STATE(6688),
    [sym_character] = STATE(6688),
    [sym_string] = STATE(6688),
    [sym_quoted_string] = STATE(6688),
    [sym_boolean] = STATE(6688),
    [sym_unit] = STATE(6688),
    [sym__value_name] = STATE(6525),
    [sym_parenthesized_operator] = STATE(6548),
    [sym_value_path] = STATE(6477),
    [sym_module_path] = STATE(20775),
    [sym_constructor_path] = STATE(6477),
    [sym__constructor_name] = STATE(6640),
    [sym_tag] = STATE(6477),
    [aux_sym_class_application_repeat1] = STATE(2553),
    [ts_builtin_sym_end] = ACTIONS(3790),
    [sym__lowercase_identifier] = ACTIONS(5927),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(5930),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_LPAREN] = ACTIONS(5933),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5936),
    [anon_sym_RBRACK] = ACTIONS(3790),
    [anon_sym_true] = ACTIONS(5939),
    [anon_sym_false] = ACTIONS(5939),
    [anon_sym_LBRACE] = ACTIONS(5942),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_val] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(5945),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5948),
    [anon_sym_new] = ACTIONS(5951),
    [anon_sym_LBRACE_LT] = ACTIONS(5954),
    [anon_sym_begin] = ACTIONS(5957),
    [sym_ocamlyacc_value] = ACTIONS(5960),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(5963),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(5966),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(5969),
    [anon_sym_SQUOTE] = ACTIONS(5972),
    [anon_sym_DQUOTE] = ACTIONS(5975),
    [sym_prefix_operator] = ACTIONS(5978),
    [sym__uppercase_identifier] = ACTIONS(5981),
    [aux_sym_tag_token1] = ACTIONS(5984),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2554] = {
    [sym__simple_expression] = STATE(6744),
    [sym_typed_expression] = STATE(6638),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_labeled_argument] = STATE(7739),
    [sym_prefix_expression] = STATE(6638),
    [sym_hash_expression] = STATE(6638),
    [sym_field_get_expression] = STATE(6638),
    [sym_array_get_expression] = STATE(6638),
    [sym_string_get_expression] = STATE(6638),
    [sym_bigarray_get_expression] = STATE(6638),
    [sym_coercion_expression] = STATE(6638),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2554),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [aux_sym_class_application_repeat1] = STATE(2554),
    [sym__lowercase_identifier] = ACTIONS(5987),
    [anon_sym_TILDE] = ACTIONS(5990),
    [anon_sym_QMARK] = ACTIONS(5990),
    [anon_sym_LPAREN] = ACTIONS(5993),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(5996),
    [anon_sym_true] = ACTIONS(5999),
    [anon_sym_false] = ACTIONS(5999),
    [anon_sym_LBRACE] = ACTIONS(6002),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6005),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6008),
    [anon_sym_then] = ACTIONS(3792),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6011),
    [anon_sym_LBRACE_LT] = ACTIONS(6014),
    [anon_sym_begin] = ACTIONS(6017),
    [sym_ocamlyacc_value] = ACTIONS(6020),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6023),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6026),
    [aux_sym_number_token1] = ACTIONS(6029),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6032),
    [anon_sym_DQUOTE] = ACTIONS(6035),
    [sym_prefix_operator] = ACTIONS(6038),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6041),
    [aux_sym_tag_token1] = ACTIONS(6044),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2555] = {
    [sym__simple_expression] = STATE(6800),
    [sym_typed_expression] = STATE(6686),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_labeled_argument] = STATE(7865),
    [sym_prefix_expression] = STATE(6686),
    [sym_hash_expression] = STATE(6686),
    [sym_field_get_expression] = STATE(6686),
    [sym_array_get_expression] = STATE(6686),
    [sym_string_get_expression] = STATE(6686),
    [sym_bigarray_get_expression] = STATE(6686),
    [sym_coercion_expression] = STATE(6686),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2555),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [aux_sym_class_application_repeat1] = STATE(2555),
    [sym__lowercase_identifier] = ACTIONS(6047),
    [anon_sym_TILDE] = ACTIONS(6050),
    [anon_sym_QMARK] = ACTIONS(6050),
    [anon_sym_LPAREN] = ACTIONS(6053),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [anon_sym_true] = ACTIONS(6059),
    [anon_sym_false] = ACTIONS(6059),
    [anon_sym_LBRACE] = ACTIONS(6062),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6065),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6068),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_do] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6071),
    [anon_sym_LBRACE_LT] = ACTIONS(6074),
    [anon_sym_begin] = ACTIONS(6077),
    [sym_ocamlyacc_value] = ACTIONS(6080),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6083),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6086),
    [aux_sym_number_token1] = ACTIONS(6089),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6092),
    [anon_sym_DQUOTE] = ACTIONS(6095),
    [sym_prefix_operator] = ACTIONS(6098),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6101),
    [aux_sym_tag_token1] = ACTIONS(6104),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2556] = {
    [sym__simple_expression] = STATE(6957),
    [sym_typed_expression] = STATE(6951),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_labeled_argument] = STATE(7888),
    [sym_prefix_expression] = STATE(6951),
    [sym_hash_expression] = STATE(6951),
    [sym_field_get_expression] = STATE(6951),
    [sym_array_get_expression] = STATE(6951),
    [sym_string_get_expression] = STATE(6951),
    [sym_bigarray_get_expression] = STATE(6951),
    [sym_coercion_expression] = STATE(6951),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2556),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [aux_sym_class_application_repeat1] = STATE(2570),
    [sym__lowercase_identifier] = ACTIONS(5375),
    [anon_sym_TILDE] = ACTIONS(5377),
    [anon_sym_QMARK] = ACTIONS(5377),
    [anon_sym_LPAREN] = ACTIONS(2407),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2409),
    [anon_sym_true] = ACTIONS(2411),
    [anon_sym_false] = ACTIONS(2411),
    [anon_sym_LBRACE] = ACTIONS(2413),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2415),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2419),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_done] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_LBRACE_LT] = ACTIONS(2431),
    [anon_sym_begin] = ACTIONS(2433),
    [sym_ocamlyacc_value] = ACTIONS(2435),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2437),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2439),
    [aux_sym_number_token1] = ACTIONS(2441),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2443),
    [anon_sym_DQUOTE] = ACTIONS(2445),
    [sym_prefix_operator] = ACTIONS(2447),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2451),
    [aux_sym_tag_token1] = ACTIONS(2453),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2557] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14413),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2557),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18738),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5563),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5565),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5567),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5569),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5571),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5571),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5571),
    [sym_let_and_operator] = ACTIONS(5571),
    [sym_match_operator] = ACTIONS(5571),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2558] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14341),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2558),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18541),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5543),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5545),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5547),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5549),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5551),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5551),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5551),
    [sym_let_and_operator] = ACTIONS(5551),
    [sym_match_operator] = ACTIONS(5551),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2559] = {
    [sym__simple_expression] = STATE(6851),
    [sym_typed_expression] = STATE(6736),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_labeled_argument] = STATE(7976),
    [sym_prefix_expression] = STATE(6736),
    [sym_hash_expression] = STATE(6736),
    [sym_field_get_expression] = STATE(6736),
    [sym_array_get_expression] = STATE(6736),
    [sym_string_get_expression] = STATE(6736),
    [sym_bigarray_get_expression] = STATE(6736),
    [sym_coercion_expression] = STATE(6736),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2559),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [aux_sym_class_application_repeat1] = STATE(2559),
    [sym__lowercase_identifier] = ACTIONS(6107),
    [anon_sym_TILDE] = ACTIONS(6110),
    [anon_sym_QMARK] = ACTIONS(6110),
    [anon_sym_LPAREN] = ACTIONS(6113),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [anon_sym_true] = ACTIONS(6119),
    [anon_sym_false] = ACTIONS(6119),
    [anon_sym_LBRACE] = ACTIONS(6122),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_with] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(6125),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6128),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6131),
    [anon_sym_LBRACE_LT] = ACTIONS(6134),
    [anon_sym_begin] = ACTIONS(6137),
    [sym_ocamlyacc_value] = ACTIONS(6140),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6143),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6146),
    [aux_sym_number_token1] = ACTIONS(6149),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6152),
    [anon_sym_DQUOTE] = ACTIONS(6155),
    [sym_prefix_operator] = ACTIONS(6158),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6161),
    [aux_sym_tag_token1] = ACTIONS(6164),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2560] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14508),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2560),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5253),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2561] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14306),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2561),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19798),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(4863),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(4867),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5251),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4871),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4871),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4871),
    [sym_let_and_operator] = ACTIONS(4871),
    [sym_match_operator] = ACTIONS(4871),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2562] = {
    [sym__simple_expression] = STATE(6944),
    [sym_typed_expression] = STATE(6477),
    [sym_list_expression] = STATE(6477),
    [sym_array_expression] = STATE(6477),
    [sym_record_expression] = STATE(6477),
    [sym_labeled_argument] = STATE(7880),
    [sym_prefix_expression] = STATE(6477),
    [sym_hash_expression] = STATE(6477),
    [sym_field_get_expression] = STATE(6477),
    [sym_array_get_expression] = STATE(6477),
    [sym_string_get_expression] = STATE(6477),
    [sym_bigarray_get_expression] = STATE(6477),
    [sym_coercion_expression] = STATE(6477),
    [sym_local_open_expression] = STATE(6477),
    [sym_package_expression] = STATE(6477),
    [sym_new_expression] = STATE(6477),
    [sym_object_copy_expression] = STATE(6477),
    [sym_method_invocation] = STATE(6477),
    [sym_object_expression] = STATE(6477),
    [sym_parenthesized_expression] = STATE(6477),
    [sym_attribute] = STATE(2562),
    [sym_extension] = STATE(6477),
    [sym_quoted_extension] = STATE(6477),
    [sym__constant] = STATE(6477),
    [sym_number] = STATE(6688),
    [sym_character] = STATE(6688),
    [sym_string] = STATE(6688),
    [sym_quoted_string] = STATE(6688),
    [sym_boolean] = STATE(6688),
    [sym_unit] = STATE(6688),
    [sym__value_name] = STATE(6525),
    [sym_parenthesized_operator] = STATE(6548),
    [sym_value_path] = STATE(6477),
    [sym_module_path] = STATE(20775),
    [sym_constructor_path] = STATE(6477),
    [sym__constructor_name] = STATE(6640),
    [sym_tag] = STATE(6477),
    [aux_sym_class_application_repeat1] = STATE(2553),
    [ts_builtin_sym_end] = ACTIONS(5697),
    [sym__lowercase_identifier] = ACTIONS(6167),
    [anon_sym_SEMI_SEMI] = ACTIONS(5697),
    [anon_sym_and] = ACTIONS(5699),
    [anon_sym_TILDE] = ACTIONS(6169),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_LPAREN] = ACTIONS(6171),
    [anon_sym_external] = ACTIONS(5699),
    [anon_sym_type] = ACTIONS(5699),
    [anon_sym_LBRACK] = ACTIONS(6173),
    [anon_sym_RBRACK] = ACTIONS(5697),
    [anon_sym_true] = ACTIONS(6175),
    [anon_sym_false] = ACTIONS(6175),
    [anon_sym_LBRACE] = ACTIONS(6177),
    [anon_sym_exception] = ACTIONS(5699),
    [anon_sym_module] = ACTIONS(5699),
    [anon_sym_open] = ACTIONS(5699),
    [anon_sym_include] = ACTIONS(5699),
    [anon_sym_class] = ACTIONS(5699),
    [anon_sym_val] = ACTIONS(5699),
    [anon_sym_object] = ACTIONS(6179),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6181),
    [anon_sym_new] = ACTIONS(6183),
    [anon_sym_LBRACE_LT] = ACTIONS(6185),
    [anon_sym_begin] = ACTIONS(6187),
    [sym_ocamlyacc_value] = ACTIONS(6189),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5699),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5697),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6191),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6193),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5697),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5697),
    [aux_sym_number_token1] = ACTIONS(6195),
    [anon_sym_SQUOTE] = ACTIONS(6197),
    [anon_sym_DQUOTE] = ACTIONS(6199),
    [sym_prefix_operator] = ACTIONS(6201),
    [sym__uppercase_identifier] = ACTIONS(6203),
    [aux_sym_tag_token1] = ACTIONS(6205),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2563] = {
    [sym__simple_expression] = STATE(6591),
    [sym_typed_expression] = STATE(6549),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_labeled_argument] = STATE(7883),
    [sym_prefix_expression] = STATE(6549),
    [sym_hash_expression] = STATE(6549),
    [sym_field_get_expression] = STATE(6549),
    [sym_array_get_expression] = STATE(6549),
    [sym_string_get_expression] = STATE(6549),
    [sym_bigarray_get_expression] = STATE(6549),
    [sym_coercion_expression] = STATE(6549),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2563),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [aux_sym_class_application_repeat1] = STATE(2571),
    [sym__lowercase_identifier] = ACTIONS(5275),
    [anon_sym_TILDE] = ACTIONS(5277),
    [anon_sym_QMARK] = ACTIONS(5277),
    [anon_sym_LPAREN] = ACTIONS(2459),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2461),
    [anon_sym_true] = ACTIONS(2463),
    [anon_sym_false] = ACTIONS(2463),
    [anon_sym_LBRACE] = ACTIONS(2465),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2467),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2471),
    [anon_sym_to] = ACTIONS(3853),
    [anon_sym_downto] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_LBRACE_LT] = ACTIONS(2483),
    [anon_sym_begin] = ACTIONS(2485),
    [sym_ocamlyacc_value] = ACTIONS(2487),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2489),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2491),
    [aux_sym_number_token1] = ACTIONS(2493),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2495),
    [anon_sym_DQUOTE] = ACTIONS(2497),
    [sym_prefix_operator] = ACTIONS(2499),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2503),
    [aux_sym_tag_token1] = ACTIONS(2505),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2564] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14306),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2564),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(19798),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(4863),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(4867),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(1709),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(4871),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(4871),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(4871),
    [sym_let_and_operator] = ACTIONS(4871),
    [sym_match_operator] = ACTIONS(4871),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2565] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14553),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2565),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18546),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5603),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5605),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5607),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5609),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5611),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5611),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5611),
    [sym_let_and_operator] = ACTIONS(5611),
    [sym_match_operator] = ACTIONS(5611),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2566] = {
    [sym__simple_expression] = STATE(6874),
    [sym_typed_expression] = STATE(6791),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_labeled_argument] = STATE(7741),
    [sym_prefix_expression] = STATE(6791),
    [sym_hash_expression] = STATE(6791),
    [sym_field_get_expression] = STATE(6791),
    [sym_array_get_expression] = STATE(6791),
    [sym_string_get_expression] = STATE(6791),
    [sym_bigarray_get_expression] = STATE(6791),
    [sym_coercion_expression] = STATE(6791),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2566),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [aux_sym_class_application_repeat1] = STATE(2566),
    [sym__lowercase_identifier] = ACTIONS(6207),
    [anon_sym_TILDE] = ACTIONS(6210),
    [anon_sym_QMARK] = ACTIONS(6210),
    [anon_sym_LPAREN] = ACTIONS(6213),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6216),
    [anon_sym_true] = ACTIONS(6219),
    [anon_sym_false] = ACTIONS(6219),
    [anon_sym_LBRACE] = ACTIONS(6222),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(6225),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6228),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6231),
    [anon_sym_LBRACE_LT] = ACTIONS(6234),
    [anon_sym_begin] = ACTIONS(6237),
    [sym_ocamlyacc_value] = ACTIONS(6240),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6243),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6246),
    [aux_sym_number_token1] = ACTIONS(6249),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6252),
    [anon_sym_DQUOTE] = ACTIONS(6255),
    [sym_prefix_operator] = ACTIONS(6258),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6261),
    [aux_sym_tag_token1] = ACTIONS(6264),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2567] = {
    [sym__simple_expression] = STATE(6944),
    [sym_typed_expression] = STATE(6477),
    [sym_list_expression] = STATE(6477),
    [sym_array_expression] = STATE(6477),
    [sym_record_expression] = STATE(6477),
    [sym_labeled_argument] = STATE(7880),
    [sym_prefix_expression] = STATE(6477),
    [sym_hash_expression] = STATE(6477),
    [sym_field_get_expression] = STATE(6477),
    [sym_array_get_expression] = STATE(6477),
    [sym_string_get_expression] = STATE(6477),
    [sym_bigarray_get_expression] = STATE(6477),
    [sym_coercion_expression] = STATE(6477),
    [sym_local_open_expression] = STATE(6477),
    [sym_package_expression] = STATE(6477),
    [sym_new_expression] = STATE(6477),
    [sym_object_copy_expression] = STATE(6477),
    [sym_method_invocation] = STATE(6477),
    [sym_object_expression] = STATE(6477),
    [sym_parenthesized_expression] = STATE(6477),
    [sym_attribute] = STATE(2567),
    [sym_extension] = STATE(6477),
    [sym_quoted_extension] = STATE(6477),
    [sym__constant] = STATE(6477),
    [sym_number] = STATE(6688),
    [sym_character] = STATE(6688),
    [sym_string] = STATE(6688),
    [sym_quoted_string] = STATE(6688),
    [sym_boolean] = STATE(6688),
    [sym_unit] = STATE(6688),
    [sym__value_name] = STATE(6525),
    [sym_parenthesized_operator] = STATE(6548),
    [sym_value_path] = STATE(6477),
    [sym_module_path] = STATE(20775),
    [sym_constructor_path] = STATE(6477),
    [sym__constructor_name] = STATE(6640),
    [sym_tag] = STATE(6477),
    [aux_sym_class_application_repeat1] = STATE(2562),
    [ts_builtin_sym_end] = ACTIONS(5813),
    [sym__lowercase_identifier] = ACTIONS(6167),
    [anon_sym_SEMI_SEMI] = ACTIONS(5813),
    [anon_sym_and] = ACTIONS(5815),
    [anon_sym_TILDE] = ACTIONS(6169),
    [anon_sym_QMARK] = ACTIONS(6169),
    [anon_sym_LPAREN] = ACTIONS(6171),
    [anon_sym_external] = ACTIONS(5815),
    [anon_sym_type] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(6173),
    [anon_sym_RBRACK] = ACTIONS(5813),
    [anon_sym_true] = ACTIONS(6175),
    [anon_sym_false] = ACTIONS(6175),
    [anon_sym_LBRACE] = ACTIONS(6177),
    [anon_sym_exception] = ACTIONS(5815),
    [anon_sym_module] = ACTIONS(5815),
    [anon_sym_open] = ACTIONS(5815),
    [anon_sym_include] = ACTIONS(5815),
    [anon_sym_class] = ACTIONS(5815),
    [anon_sym_val] = ACTIONS(5815),
    [anon_sym_object] = ACTIONS(6179),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6181),
    [anon_sym_new] = ACTIONS(6183),
    [anon_sym_LBRACE_LT] = ACTIONS(6185),
    [anon_sym_begin] = ACTIONS(6187),
    [sym_ocamlyacc_value] = ACTIONS(6189),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5815),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5813),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6191),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6193),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5813),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5813),
    [aux_sym_number_token1] = ACTIONS(6195),
    [anon_sym_SQUOTE] = ACTIONS(6197),
    [anon_sym_DQUOTE] = ACTIONS(6199),
    [sym_prefix_operator] = ACTIONS(6201),
    [sym__uppercase_identifier] = ACTIONS(6203),
    [aux_sym_tag_token1] = ACTIONS(6205),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2568] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14508),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2568),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(1427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2569] = {
    [sym__simple_expression] = STATE(6874),
    [sym_typed_expression] = STATE(6791),
    [sym_list_expression] = STATE(6791),
    [sym_array_expression] = STATE(6791),
    [sym_record_expression] = STATE(6791),
    [sym_labeled_argument] = STATE(7741),
    [sym_prefix_expression] = STATE(6791),
    [sym_hash_expression] = STATE(6791),
    [sym_field_get_expression] = STATE(6791),
    [sym_array_get_expression] = STATE(6791),
    [sym_string_get_expression] = STATE(6791),
    [sym_bigarray_get_expression] = STATE(6791),
    [sym_coercion_expression] = STATE(6791),
    [sym_local_open_expression] = STATE(6791),
    [sym_package_expression] = STATE(6791),
    [sym_new_expression] = STATE(6791),
    [sym_object_copy_expression] = STATE(6791),
    [sym_method_invocation] = STATE(6791),
    [sym_object_expression] = STATE(6791),
    [sym_parenthesized_expression] = STATE(6791),
    [sym_attribute] = STATE(2569),
    [sym_extension] = STATE(6791),
    [sym_quoted_extension] = STATE(6791),
    [sym__constant] = STATE(6791),
    [sym_number] = STATE(7001),
    [sym_character] = STATE(7001),
    [sym_string] = STATE(7001),
    [sym_quoted_string] = STATE(7001),
    [sym_boolean] = STATE(7001),
    [sym_unit] = STATE(7001),
    [sym__value_name] = STATE(6848),
    [sym_parenthesized_operator] = STATE(6936),
    [sym_value_path] = STATE(6791),
    [sym_module_path] = STATE(19211),
    [sym_constructor_path] = STATE(6791),
    [sym__constructor_name] = STATE(7002),
    [sym_tag] = STATE(6791),
    [aux_sym_class_application_repeat1] = STATE(2566),
    [sym__lowercase_identifier] = ACTIONS(5345),
    [anon_sym_TILDE] = ACTIONS(5347),
    [anon_sym_QMARK] = ACTIONS(5347),
    [anon_sym_LPAREN] = ACTIONS(2303),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2305),
    [anon_sym_true] = ACTIONS(2307),
    [anon_sym_false] = ACTIONS(2307),
    [anon_sym_LBRACE] = ACTIONS(2309),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(2311),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2315),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2325),
    [anon_sym_LBRACE_LT] = ACTIONS(2327),
    [anon_sym_begin] = ACTIONS(2329),
    [sym_ocamlyacc_value] = ACTIONS(2331),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2333),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2335),
    [aux_sym_number_token1] = ACTIONS(2337),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2339),
    [anon_sym_DQUOTE] = ACTIONS(2341),
    [sym_prefix_operator] = ACTIONS(2343),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2347),
    [aux_sym_tag_token1] = ACTIONS(2349),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2570] = {
    [sym__simple_expression] = STATE(6957),
    [sym_typed_expression] = STATE(6951),
    [sym_list_expression] = STATE(6951),
    [sym_array_expression] = STATE(6951),
    [sym_record_expression] = STATE(6951),
    [sym_labeled_argument] = STATE(7888),
    [sym_prefix_expression] = STATE(6951),
    [sym_hash_expression] = STATE(6951),
    [sym_field_get_expression] = STATE(6951),
    [sym_array_get_expression] = STATE(6951),
    [sym_string_get_expression] = STATE(6951),
    [sym_bigarray_get_expression] = STATE(6951),
    [sym_coercion_expression] = STATE(6951),
    [sym_local_open_expression] = STATE(6951),
    [sym_package_expression] = STATE(6951),
    [sym_new_expression] = STATE(6951),
    [sym_object_copy_expression] = STATE(6951),
    [sym_method_invocation] = STATE(6951),
    [sym_object_expression] = STATE(6951),
    [sym_parenthesized_expression] = STATE(6951),
    [sym_attribute] = STATE(2570),
    [sym_extension] = STATE(6951),
    [sym_quoted_extension] = STATE(6951),
    [sym__constant] = STATE(6951),
    [sym_number] = STATE(6430),
    [sym_character] = STATE(6430),
    [sym_string] = STATE(6430),
    [sym_quoted_string] = STATE(6430),
    [sym_boolean] = STATE(6430),
    [sym_unit] = STATE(6430),
    [sym__value_name] = STATE(6991),
    [sym_parenthesized_operator] = STATE(6682),
    [sym_value_path] = STATE(6951),
    [sym_module_path] = STATE(19529),
    [sym_constructor_path] = STATE(6951),
    [sym__constructor_name] = STATE(6431),
    [sym_tag] = STATE(6951),
    [aux_sym_class_application_repeat1] = STATE(2570),
    [sym__lowercase_identifier] = ACTIONS(6267),
    [anon_sym_TILDE] = ACTIONS(6270),
    [anon_sym_QMARK] = ACTIONS(6270),
    [anon_sym_LPAREN] = ACTIONS(6273),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6276),
    [anon_sym_true] = ACTIONS(6279),
    [anon_sym_false] = ACTIONS(6279),
    [anon_sym_LBRACE] = ACTIONS(6282),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6285),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6288),
    [anon_sym_else] = ACTIONS(3792),
    [anon_sym_done] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6291),
    [anon_sym_LBRACE_LT] = ACTIONS(6294),
    [anon_sym_begin] = ACTIONS(6297),
    [sym_ocamlyacc_value] = ACTIONS(6300),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6303),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6306),
    [aux_sym_number_token1] = ACTIONS(6309),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6312),
    [anon_sym_DQUOTE] = ACTIONS(6315),
    [sym_prefix_operator] = ACTIONS(6318),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6321),
    [aux_sym_tag_token1] = ACTIONS(6324),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2571] = {
    [sym__simple_expression] = STATE(6591),
    [sym_typed_expression] = STATE(6549),
    [sym_list_expression] = STATE(6549),
    [sym_array_expression] = STATE(6549),
    [sym_record_expression] = STATE(6549),
    [sym_labeled_argument] = STATE(7883),
    [sym_prefix_expression] = STATE(6549),
    [sym_hash_expression] = STATE(6549),
    [sym_field_get_expression] = STATE(6549),
    [sym_array_get_expression] = STATE(6549),
    [sym_string_get_expression] = STATE(6549),
    [sym_bigarray_get_expression] = STATE(6549),
    [sym_coercion_expression] = STATE(6549),
    [sym_local_open_expression] = STATE(6549),
    [sym_package_expression] = STATE(6549),
    [sym_new_expression] = STATE(6549),
    [sym_object_copy_expression] = STATE(6549),
    [sym_method_invocation] = STATE(6549),
    [sym_object_expression] = STATE(6549),
    [sym_parenthesized_expression] = STATE(6549),
    [sym_attribute] = STATE(2571),
    [sym_extension] = STATE(6549),
    [sym_quoted_extension] = STATE(6549),
    [sym__constant] = STATE(6549),
    [sym_number] = STATE(6928),
    [sym_character] = STATE(6928),
    [sym_string] = STATE(6928),
    [sym_quoted_string] = STATE(6928),
    [sym_boolean] = STATE(6928),
    [sym_unit] = STATE(6928),
    [sym__value_name] = STATE(6590),
    [sym_parenthesized_operator] = STATE(6621),
    [sym_value_path] = STATE(6549),
    [sym_module_path] = STATE(18617),
    [sym_constructor_path] = STATE(6549),
    [sym__constructor_name] = STATE(6929),
    [sym_tag] = STATE(6549),
    [aux_sym_class_application_repeat1] = STATE(2571),
    [sym__lowercase_identifier] = ACTIONS(6327),
    [anon_sym_TILDE] = ACTIONS(6330),
    [anon_sym_QMARK] = ACTIONS(6330),
    [anon_sym_LPAREN] = ACTIONS(6333),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6336),
    [anon_sym_true] = ACTIONS(6339),
    [anon_sym_false] = ACTIONS(6339),
    [anon_sym_LBRACE] = ACTIONS(6342),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6345),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6348),
    [anon_sym_to] = ACTIONS(3792),
    [anon_sym_downto] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6351),
    [anon_sym_LBRACE_LT] = ACTIONS(6354),
    [anon_sym_begin] = ACTIONS(6357),
    [sym_ocamlyacc_value] = ACTIONS(6360),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6363),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6366),
    [aux_sym_number_token1] = ACTIONS(6369),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6372),
    [anon_sym_DQUOTE] = ACTIONS(6375),
    [sym_prefix_operator] = ACTIONS(6378),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6381),
    [aux_sym_tag_token1] = ACTIONS(6384),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2572] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14508),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2572),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(21355),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(1815),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(1423),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5053),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(1431),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(1431),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(1431),
    [sym_let_and_operator] = ACTIONS(1431),
    [sym_match_operator] = ACTIONS(1431),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2573] = {
    [sym__simple_expression] = STATE(6851),
    [sym_typed_expression] = STATE(6736),
    [sym_list_expression] = STATE(6736),
    [sym_array_expression] = STATE(6736),
    [sym_record_expression] = STATE(6736),
    [sym_labeled_argument] = STATE(7976),
    [sym_prefix_expression] = STATE(6736),
    [sym_hash_expression] = STATE(6736),
    [sym_field_get_expression] = STATE(6736),
    [sym_array_get_expression] = STATE(6736),
    [sym_string_get_expression] = STATE(6736),
    [sym_bigarray_get_expression] = STATE(6736),
    [sym_coercion_expression] = STATE(6736),
    [sym_local_open_expression] = STATE(6736),
    [sym_package_expression] = STATE(6736),
    [sym_new_expression] = STATE(6736),
    [sym_object_copy_expression] = STATE(6736),
    [sym_method_invocation] = STATE(6736),
    [sym_object_expression] = STATE(6736),
    [sym_parenthesized_expression] = STATE(6736),
    [sym_attribute] = STATE(2573),
    [sym_extension] = STATE(6736),
    [sym_quoted_extension] = STATE(6736),
    [sym__constant] = STATE(6736),
    [sym_number] = STATE(6880),
    [sym_character] = STATE(6880),
    [sym_string] = STATE(6880),
    [sym_quoted_string] = STATE(6880),
    [sym_boolean] = STATE(6880),
    [sym_unit] = STATE(6880),
    [sym__value_name] = STATE(6792),
    [sym_parenthesized_operator] = STATE(6922),
    [sym_value_path] = STATE(6736),
    [sym_module_path] = STATE(19171),
    [sym_constructor_path] = STATE(6736),
    [sym__constructor_name] = STATE(6882),
    [sym_tag] = STATE(6736),
    [aux_sym_class_application_repeat1] = STATE(2559),
    [sym__lowercase_identifier] = ACTIONS(5385),
    [anon_sym_TILDE] = ACTIONS(5387),
    [anon_sym_QMARK] = ACTIONS(5387),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2513),
    [anon_sym_true] = ACTIONS(2515),
    [anon_sym_false] = ACTIONS(2515),
    [anon_sym_LBRACE] = ACTIONS(2517),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_with] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(2519),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2523),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2533),
    [anon_sym_LBRACE_LT] = ACTIONS(2535),
    [anon_sym_begin] = ACTIONS(2537),
    [sym_ocamlyacc_value] = ACTIONS(2539),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2541),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2543),
    [aux_sym_number_token1] = ACTIONS(2545),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2547),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [sym_prefix_operator] = ACTIONS(2551),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2555),
    [aux_sym_tag_token1] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2574] = {
    [sym__simple_expression] = STATE(6744),
    [sym_typed_expression] = STATE(6638),
    [sym_list_expression] = STATE(6638),
    [sym_array_expression] = STATE(6638),
    [sym_record_expression] = STATE(6638),
    [sym_labeled_argument] = STATE(7739),
    [sym_prefix_expression] = STATE(6638),
    [sym_hash_expression] = STATE(6638),
    [sym_field_get_expression] = STATE(6638),
    [sym_array_get_expression] = STATE(6638),
    [sym_string_get_expression] = STATE(6638),
    [sym_bigarray_get_expression] = STATE(6638),
    [sym_coercion_expression] = STATE(6638),
    [sym_local_open_expression] = STATE(6638),
    [sym_package_expression] = STATE(6638),
    [sym_new_expression] = STATE(6638),
    [sym_object_copy_expression] = STATE(6638),
    [sym_method_invocation] = STATE(6638),
    [sym_object_expression] = STATE(6638),
    [sym_parenthesized_expression] = STATE(6638),
    [sym_attribute] = STATE(2574),
    [sym_extension] = STATE(6638),
    [sym_quoted_extension] = STATE(6638),
    [sym__constant] = STATE(6638),
    [sym_number] = STATE(6582),
    [sym_character] = STATE(6582),
    [sym_string] = STATE(6582),
    [sym_quoted_string] = STATE(6582),
    [sym_boolean] = STATE(6582),
    [sym_unit] = STATE(6582),
    [sym__value_name] = STATE(6689),
    [sym_parenthesized_operator] = STATE(6871),
    [sym_value_path] = STATE(6638),
    [sym_module_path] = STATE(19050),
    [sym_constructor_path] = STATE(6638),
    [sym__constructor_name] = STATE(6587),
    [sym_tag] = STATE(6638),
    [aux_sym_class_application_repeat1] = STATE(2554),
    [sym__lowercase_identifier] = ACTIONS(5355),
    [anon_sym_TILDE] = ACTIONS(5357),
    [anon_sym_QMARK] = ACTIONS(5357),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2357),
    [anon_sym_true] = ACTIONS(2359),
    [anon_sym_false] = ACTIONS(2359),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2367),
    [anon_sym_then] = ACTIONS(3853),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2377),
    [anon_sym_LBRACE_LT] = ACTIONS(2379),
    [anon_sym_begin] = ACTIONS(2381),
    [sym_ocamlyacc_value] = ACTIONS(2383),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2385),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2387),
    [aux_sym_number_token1] = ACTIONS(2389),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2393),
    [sym_prefix_operator] = ACTIONS(2395),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2399),
    [aux_sym_tag_token1] = ACTIONS(2401),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2575] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14583),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2575),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__infix_operator] = STATE(18430),
    [sym_add_operator] = STATE(20795),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5451),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5455),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(5459),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_module] = ACTIONS(5463),
    [anon_sym_POUND] = ACTIONS(4833),
    [anon_sym_COLON_COLON] = ACTIONS(5465),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(4851),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym_prefix_operator] = ACTIONS(5471),
    [aux_sym_sign_operator_token1] = ACTIONS(1413),
    [sym_hash_operator] = ACTIONS(5471),
    [sym_pow_operator] = ACTIONS(1411),
    [sym_mult_operator] = ACTIONS(1411),
    [aux_sym_add_operator_token1] = ACTIONS(1413),
    [sym_concat_operator] = ACTIONS(1415),
    [sym_rel_operator] = ACTIONS(1411),
    [sym_and_operator] = ACTIONS(1411),
    [sym_or_operator] = ACTIONS(1411),
    [sym_assign_operator] = ACTIONS(1415),
    [sym_let_operator] = ACTIONS(5471),
    [sym_let_and_operator] = ACTIONS(5471),
    [sym_match_operator] = ACTIONS(5471),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2576] = {
    [sym__simple_expression] = STATE(6800),
    [sym_typed_expression] = STATE(6686),
    [sym_list_expression] = STATE(6686),
    [sym_array_expression] = STATE(6686),
    [sym_record_expression] = STATE(6686),
    [sym_labeled_argument] = STATE(7865),
    [sym_prefix_expression] = STATE(6686),
    [sym_hash_expression] = STATE(6686),
    [sym_field_get_expression] = STATE(6686),
    [sym_array_get_expression] = STATE(6686),
    [sym_string_get_expression] = STATE(6686),
    [sym_bigarray_get_expression] = STATE(6686),
    [sym_coercion_expression] = STATE(6686),
    [sym_local_open_expression] = STATE(6686),
    [sym_package_expression] = STATE(6686),
    [sym_new_expression] = STATE(6686),
    [sym_object_copy_expression] = STATE(6686),
    [sym_method_invocation] = STATE(6686),
    [sym_object_expression] = STATE(6686),
    [sym_parenthesized_expression] = STATE(6686),
    [sym_attribute] = STATE(2576),
    [sym_extension] = STATE(6686),
    [sym_quoted_extension] = STATE(6686),
    [sym__constant] = STATE(6686),
    [sym_number] = STATE(6726),
    [sym_character] = STATE(6726),
    [sym_string] = STATE(6726),
    [sym_quoted_string] = STATE(6726),
    [sym_boolean] = STATE(6726),
    [sym_unit] = STATE(6726),
    [sym__value_name] = STATE(6737),
    [sym_parenthesized_operator] = STATE(6901),
    [sym_value_path] = STATE(6686),
    [sym_module_path] = STATE(19091),
    [sym_constructor_path] = STATE(6686),
    [sym__constructor_name] = STATE(6727),
    [sym_tag] = STATE(6686),
    [aux_sym_class_application_repeat1] = STATE(2555),
    [sym__lowercase_identifier] = ACTIONS(5365),
    [anon_sym_TILDE] = ACTIONS(5367),
    [anon_sym_QMARK] = ACTIONS(5367),
    [anon_sym_LPAREN] = ACTIONS(2251),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2253),
    [anon_sym_true] = ACTIONS(2255),
    [anon_sym_false] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(2257),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2259),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2263),
    [anon_sym_else] = ACTIONS(3853),
    [anon_sym_do] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2273),
    [anon_sym_LBRACE_LT] = ACTIONS(2275),
    [anon_sym_begin] = ACTIONS(2277),
    [sym_ocamlyacc_value] = ACTIONS(2279),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2281),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2283),
    [aux_sym_number_token1] = ACTIONS(2285),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2287),
    [anon_sym_DQUOTE] = ACTIONS(2289),
    [sym_prefix_operator] = ACTIONS(2291),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2295),
    [aux_sym_tag_token1] = ACTIONS(2297),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2577] = {
    [sym__simple_expression] = STATE(7152),
    [sym_typed_expression] = STATE(7367),
    [sym_list_expression] = STATE(7367),
    [sym_array_expression] = STATE(7367),
    [sym_record_expression] = STATE(7367),
    [sym_labeled_argument] = STATE(8021),
    [sym_prefix_expression] = STATE(7367),
    [sym_hash_expression] = STATE(7367),
    [sym_field_get_expression] = STATE(7367),
    [sym_array_get_expression] = STATE(7367),
    [sym_string_get_expression] = STATE(7367),
    [sym_bigarray_get_expression] = STATE(7367),
    [sym_coercion_expression] = STATE(7367),
    [sym_local_open_expression] = STATE(7367),
    [sym_package_expression] = STATE(7367),
    [sym_new_expression] = STATE(7367),
    [sym_object_copy_expression] = STATE(7367),
    [sym_method_invocation] = STATE(7367),
    [sym_object_expression] = STATE(7367),
    [sym_parenthesized_expression] = STATE(7367),
    [sym_attribute] = STATE(2577),
    [sym_extension] = STATE(7367),
    [sym_quoted_extension] = STATE(7367),
    [sym__constant] = STATE(7367),
    [sym_number] = STATE(7133),
    [sym_character] = STATE(7133),
    [sym_string] = STATE(7133),
    [sym_quoted_string] = STATE(7133),
    [sym_boolean] = STATE(7133),
    [sym_unit] = STATE(7133),
    [sym__value_name] = STATE(7422),
    [sym_parenthesized_operator] = STATE(7501),
    [sym_value_path] = STATE(7367),
    [sym_module_path] = STATE(19371),
    [sym_constructor_path] = STATE(7367),
    [sym__constructor_name] = STATE(7134),
    [sym_tag] = STATE(7367),
    [aux_sym_class_application_repeat1] = STATE(2587),
    [sym__lowercase_identifier] = ACTIONS(6387),
    [anon_sym_SEMI_SEMI] = ACTIONS(5697),
    [anon_sym_and] = ACTIONS(5699),
    [anon_sym_TILDE] = ACTIONS(6389),
    [anon_sym_QMARK] = ACTIONS(6389),
    [anon_sym_LPAREN] = ACTIONS(6391),
    [anon_sym_external] = ACTIONS(5699),
    [anon_sym_type] = ACTIONS(5699),
    [anon_sym_LBRACK] = ACTIONS(6393),
    [anon_sym_true] = ACTIONS(6395),
    [anon_sym_false] = ACTIONS(6395),
    [anon_sym_LBRACE] = ACTIONS(6397),
    [anon_sym_exception] = ACTIONS(5699),
    [anon_sym_module] = ACTIONS(5699),
    [anon_sym_open] = ACTIONS(5699),
    [anon_sym_include] = ACTIONS(5699),
    [anon_sym_class] = ACTIONS(5699),
    [anon_sym_val] = ACTIONS(5699),
    [anon_sym_end] = ACTIONS(5699),
    [anon_sym_object] = ACTIONS(6399),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6401),
    [anon_sym_new] = ACTIONS(6403),
    [anon_sym_LBRACE_LT] = ACTIONS(6405),
    [anon_sym_begin] = ACTIONS(6407),
    [sym_ocamlyacc_value] = ACTIONS(6409),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5699),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5697),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6411),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6413),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5697),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5697),
    [aux_sym_number_token1] = ACTIONS(6415),
    [anon_sym_SQUOTE] = ACTIONS(6417),
    [anon_sym_DQUOTE] = ACTIONS(6419),
    [sym_prefix_operator] = ACTIONS(6421),
    [sym__uppercase_identifier] = ACTIONS(6423),
    [aux_sym_tag_token1] = ACTIONS(6425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2578] = {
    [sym__simple_expression] = STATE(7145),
    [sym_typed_expression] = STATE(7186),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_labeled_argument] = STATE(8045),
    [sym_prefix_expression] = STATE(7186),
    [sym_hash_expression] = STATE(7186),
    [sym_field_get_expression] = STATE(7186),
    [sym_array_get_expression] = STATE(7186),
    [sym_string_get_expression] = STATE(7186),
    [sym_bigarray_get_expression] = STATE(7186),
    [sym_coercion_expression] = STATE(7186),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2578),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [aux_sym_class_application_repeat1] = STATE(2586),
    [sym__lowercase_identifier] = ACTIONS(5573),
    [anon_sym_TILDE] = ACTIONS(5575),
    [anon_sym_QMARK] = ACTIONS(5575),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2659),
    [anon_sym_true] = ACTIONS(2661),
    [anon_sym_false] = ACTIONS(2661),
    [anon_sym_LBRACE] = ACTIONS(2663),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2665),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2669),
    [anon_sym_then] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2679),
    [anon_sym_LBRACE_LT] = ACTIONS(2681),
    [anon_sym_begin] = ACTIONS(2683),
    [sym_ocamlyacc_value] = ACTIONS(2685),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2687),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2689),
    [aux_sym_number_token1] = ACTIONS(2691),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2693),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [sym_prefix_operator] = ACTIONS(2697),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2701),
    [aux_sym_tag_token1] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2579] = {
    [sym__simple_expression] = STATE(7216),
    [sym_typed_expression] = STATE(7419),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_labeled_argument] = STATE(8160),
    [sym_prefix_expression] = STATE(7419),
    [sym_hash_expression] = STATE(7419),
    [sym_field_get_expression] = STATE(7419),
    [sym_array_get_expression] = STATE(7419),
    [sym_string_get_expression] = STATE(7419),
    [sym_bigarray_get_expression] = STATE(7419),
    [sym_coercion_expression] = STATE(7419),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2579),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [aux_sym_class_application_repeat1] = STATE(2579),
    [sym__lowercase_identifier] = ACTIONS(6427),
    [anon_sym_TILDE] = ACTIONS(6430),
    [anon_sym_QMARK] = ACTIONS(6430),
    [anon_sym_LPAREN] = ACTIONS(6433),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6436),
    [anon_sym_true] = ACTIONS(6439),
    [anon_sym_false] = ACTIONS(6439),
    [anon_sym_LBRACE] = ACTIONS(6442),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6445),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6448),
    [anon_sym_do] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6451),
    [anon_sym_LBRACE_LT] = ACTIONS(6454),
    [anon_sym_begin] = ACTIONS(6457),
    [sym_ocamlyacc_value] = ACTIONS(6460),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6463),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6466),
    [aux_sym_number_token1] = ACTIONS(6469),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6472),
    [anon_sym_DQUOTE] = ACTIONS(6475),
    [sym_prefix_operator] = ACTIONS(6478),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6481),
    [aux_sym_tag_token1] = ACTIONS(6484),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2580] = {
    [sym__simple_expression] = STATE(7424),
    [sym_typed_expression] = STATE(7319),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_labeled_argument] = STATE(8018),
    [sym_prefix_expression] = STATE(7319),
    [sym_hash_expression] = STATE(7319),
    [sym_field_get_expression] = STATE(7319),
    [sym_array_get_expression] = STATE(7319),
    [sym_string_get_expression] = STATE(7319),
    [sym_bigarray_get_expression] = STATE(7319),
    [sym_coercion_expression] = STATE(7319),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2580),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [aux_sym_class_application_repeat1] = STATE(2585),
    [sym__lowercase_identifier] = ACTIONS(5553),
    [anon_sym_TILDE] = ACTIONS(5555),
    [anon_sym_QMARK] = ACTIONS(5555),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2815),
    [anon_sym_true] = ACTIONS(2817),
    [anon_sym_false] = ACTIONS(2817),
    [anon_sym_LBRACE] = ACTIONS(2819),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_end] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(2821),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2825),
    [anon_sym_new] = ACTIONS(2835),
    [anon_sym_LBRACE_LT] = ACTIONS(2837),
    [anon_sym_begin] = ACTIONS(2839),
    [sym_ocamlyacc_value] = ACTIONS(2841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2845),
    [aux_sym_number_token1] = ACTIONS(2847),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_prefix_operator] = ACTIONS(2853),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2857),
    [aux_sym_tag_token1] = ACTIONS(2859),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2581] = {
    [sym__simple_expression] = STATE(7216),
    [sym_typed_expression] = STATE(7419),
    [sym_list_expression] = STATE(7419),
    [sym_array_expression] = STATE(7419),
    [sym_record_expression] = STATE(7419),
    [sym_labeled_argument] = STATE(8160),
    [sym_prefix_expression] = STATE(7419),
    [sym_hash_expression] = STATE(7419),
    [sym_field_get_expression] = STATE(7419),
    [sym_array_get_expression] = STATE(7419),
    [sym_string_get_expression] = STATE(7419),
    [sym_bigarray_get_expression] = STATE(7419),
    [sym_coercion_expression] = STATE(7419),
    [sym_local_open_expression] = STATE(7419),
    [sym_package_expression] = STATE(7419),
    [sym_new_expression] = STATE(7419),
    [sym_object_copy_expression] = STATE(7419),
    [sym_method_invocation] = STATE(7419),
    [sym_object_expression] = STATE(7419),
    [sym_parenthesized_expression] = STATE(7419),
    [sym_attribute] = STATE(2581),
    [sym_extension] = STATE(7419),
    [sym_quoted_extension] = STATE(7419),
    [sym__constant] = STATE(7419),
    [sym_number] = STATE(7138),
    [sym_character] = STATE(7138),
    [sym_string] = STATE(7138),
    [sym_quoted_string] = STATE(7138),
    [sym_boolean] = STATE(7138),
    [sym_unit] = STATE(7138),
    [sym__value_name] = STATE(7423),
    [sym_parenthesized_operator] = STATE(7510),
    [sym_value_path] = STATE(7419),
    [sym_module_path] = STATE(19106),
    [sym_constructor_path] = STATE(7419),
    [sym__constructor_name] = STATE(7282),
    [sym_tag] = STATE(7419),
    [aux_sym_class_application_repeat1] = STATE(2579),
    [sym__lowercase_identifier] = ACTIONS(5625),
    [anon_sym_TILDE] = ACTIONS(5627),
    [anon_sym_QMARK] = ACTIONS(5627),
    [anon_sym_LPAREN] = ACTIONS(2761),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_true] = ACTIONS(2765),
    [anon_sym_false] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2773),
    [anon_sym_do] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2783),
    [anon_sym_LBRACE_LT] = ACTIONS(2785),
    [anon_sym_begin] = ACTIONS(2787),
    [sym_ocamlyacc_value] = ACTIONS(2789),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2791),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2793),
    [aux_sym_number_token1] = ACTIONS(2795),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2799),
    [sym_prefix_operator] = ACTIONS(2801),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2805),
    [aux_sym_tag_token1] = ACTIONS(2807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2582] = {
    [sym__simple_expression] = STATE(7095),
    [sym_typed_expression] = STATE(7057),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_labeled_argument] = STATE(8121),
    [sym_prefix_expression] = STATE(7057),
    [sym_hash_expression] = STATE(7057),
    [sym_field_get_expression] = STATE(7057),
    [sym_array_get_expression] = STATE(7057),
    [sym_string_get_expression] = STATE(7057),
    [sym_bigarray_get_expression] = STATE(7057),
    [sym_coercion_expression] = STATE(7057),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2582),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [aux_sym_class_application_repeat1] = STATE(2588),
    [sym__lowercase_identifier] = ACTIONS(5473),
    [anon_sym_TILDE] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5475),
    [anon_sym_LPAREN] = ACTIONS(2577),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2579),
    [anon_sym_true] = ACTIONS(2581),
    [anon_sym_false] = ACTIONS(2581),
    [anon_sym_LBRACE] = ACTIONS(2583),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_object] = ACTIONS(2585),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2589),
    [anon_sym_done] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_LBRACE_LT] = ACTIONS(2601),
    [anon_sym_begin] = ACTIONS(2603),
    [sym_ocamlyacc_value] = ACTIONS(2605),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2607),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2609),
    [aux_sym_number_token1] = ACTIONS(2611),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2615),
    [sym_prefix_operator] = ACTIONS(2617),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2621),
    [aux_sym_tag_token1] = ACTIONS(2623),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2583] = {
    [sym__simple_expression] = STATE(7152),
    [sym_typed_expression] = STATE(7367),
    [sym_list_expression] = STATE(7367),
    [sym_array_expression] = STATE(7367),
    [sym_record_expression] = STATE(7367),
    [sym_labeled_argument] = STATE(8021),
    [sym_prefix_expression] = STATE(7367),
    [sym_hash_expression] = STATE(7367),
    [sym_field_get_expression] = STATE(7367),
    [sym_array_get_expression] = STATE(7367),
    [sym_string_get_expression] = STATE(7367),
    [sym_bigarray_get_expression] = STATE(7367),
    [sym_coercion_expression] = STATE(7367),
    [sym_local_open_expression] = STATE(7367),
    [sym_package_expression] = STATE(7367),
    [sym_new_expression] = STATE(7367),
    [sym_object_copy_expression] = STATE(7367),
    [sym_method_invocation] = STATE(7367),
    [sym_object_expression] = STATE(7367),
    [sym_parenthesized_expression] = STATE(7367),
    [sym_attribute] = STATE(2583),
    [sym_extension] = STATE(7367),
    [sym_quoted_extension] = STATE(7367),
    [sym__constant] = STATE(7367),
    [sym_number] = STATE(7133),
    [sym_character] = STATE(7133),
    [sym_string] = STATE(7133),
    [sym_quoted_string] = STATE(7133),
    [sym_boolean] = STATE(7133),
    [sym_unit] = STATE(7133),
    [sym__value_name] = STATE(7422),
    [sym_parenthesized_operator] = STATE(7501),
    [sym_value_path] = STATE(7367),
    [sym_module_path] = STATE(19371),
    [sym_constructor_path] = STATE(7367),
    [sym__constructor_name] = STATE(7134),
    [sym_tag] = STATE(7367),
    [aux_sym_class_application_repeat1] = STATE(2577),
    [sym__lowercase_identifier] = ACTIONS(6387),
    [anon_sym_SEMI_SEMI] = ACTIONS(5813),
    [anon_sym_and] = ACTIONS(5815),
    [anon_sym_TILDE] = ACTIONS(6389),
    [anon_sym_QMARK] = ACTIONS(6389),
    [anon_sym_LPAREN] = ACTIONS(6391),
    [anon_sym_external] = ACTIONS(5815),
    [anon_sym_type] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(6393),
    [anon_sym_true] = ACTIONS(6395),
    [anon_sym_false] = ACTIONS(6395),
    [anon_sym_LBRACE] = ACTIONS(6397),
    [anon_sym_exception] = ACTIONS(5815),
    [anon_sym_module] = ACTIONS(5815),
    [anon_sym_open] = ACTIONS(5815),
    [anon_sym_include] = ACTIONS(5815),
    [anon_sym_class] = ACTIONS(5815),
    [anon_sym_val] = ACTIONS(5815),
    [anon_sym_end] = ACTIONS(5815),
    [anon_sym_object] = ACTIONS(6399),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6401),
    [anon_sym_new] = ACTIONS(6403),
    [anon_sym_LBRACE_LT] = ACTIONS(6405),
    [anon_sym_begin] = ACTIONS(6407),
    [sym_ocamlyacc_value] = ACTIONS(6409),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5815),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5813),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6411),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6413),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5813),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5813),
    [aux_sym_number_token1] = ACTIONS(6415),
    [anon_sym_SQUOTE] = ACTIONS(6417),
    [anon_sym_DQUOTE] = ACTIONS(6419),
    [sym_prefix_operator] = ACTIONS(6421),
    [sym__uppercase_identifier] = ACTIONS(6423),
    [aux_sym_tag_token1] = ACTIONS(6425),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2584] = {
    [sym__simple_expression] = STATE(7433),
    [sym_typed_expression] = STATE(7511),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_labeled_argument] = STATE(8135),
    [sym_prefix_expression] = STATE(7511),
    [sym_hash_expression] = STATE(7511),
    [sym_field_get_expression] = STATE(7511),
    [sym_array_get_expression] = STATE(7511),
    [sym_string_get_expression] = STATE(7511),
    [sym_bigarray_get_expression] = STATE(7511),
    [sym_coercion_expression] = STATE(7511),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2584),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [aux_sym_class_application_repeat1] = STATE(2589),
    [sym__lowercase_identifier] = ACTIONS(5593),
    [anon_sym_TILDE] = ACTIONS(5595),
    [anon_sym_QMARK] = ACTIONS(5595),
    [anon_sym_LPAREN] = ACTIONS(2709),
    [anon_sym_COMMA] = ACTIONS(3851),
    [anon_sym_PIPE] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_true] = ACTIONS(2713),
    [anon_sym_false] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_with] = ACTIONS(3853),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_COLON_COLON] = ACTIONS(3851),
    [anon_sym_LBRACK_PIPE] = ACTIONS(2721),
    [anon_sym_new] = ACTIONS(2731),
    [anon_sym_LBRACE_LT] = ACTIONS(2733),
    [anon_sym_begin] = ACTIONS(2735),
    [sym_ocamlyacc_value] = ACTIONS(2737),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(2739),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(2741),
    [aux_sym_number_token1] = ACTIONS(2743),
    [aux_sym_signed_number_token1] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2747),
    [sym_prefix_operator] = ACTIONS(2749),
    [aux_sym_sign_operator_token1] = ACTIONS(3853),
    [sym_pow_operator] = ACTIONS(3853),
    [sym_mult_operator] = ACTIONS(3853),
    [aux_sym_add_operator_token1] = ACTIONS(3853),
    [sym_concat_operator] = ACTIONS(3851),
    [sym_rel_operator] = ACTIONS(3853),
    [sym_and_operator] = ACTIONS(3853),
    [sym_or_operator] = ACTIONS(3853),
    [sym_assign_operator] = ACTIONS(3851),
    [sym__uppercase_identifier] = ACTIONS(2753),
    [aux_sym_tag_token1] = ACTIONS(2755),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2585] = {
    [sym__simple_expression] = STATE(7424),
    [sym_typed_expression] = STATE(7319),
    [sym_list_expression] = STATE(7319),
    [sym_array_expression] = STATE(7319),
    [sym_record_expression] = STATE(7319),
    [sym_labeled_argument] = STATE(8018),
    [sym_prefix_expression] = STATE(7319),
    [sym_hash_expression] = STATE(7319),
    [sym_field_get_expression] = STATE(7319),
    [sym_array_get_expression] = STATE(7319),
    [sym_string_get_expression] = STATE(7319),
    [sym_bigarray_get_expression] = STATE(7319),
    [sym_coercion_expression] = STATE(7319),
    [sym_local_open_expression] = STATE(7319),
    [sym_package_expression] = STATE(7319),
    [sym_new_expression] = STATE(7319),
    [sym_object_copy_expression] = STATE(7319),
    [sym_method_invocation] = STATE(7319),
    [sym_object_expression] = STATE(7319),
    [sym_parenthesized_expression] = STATE(7319),
    [sym_attribute] = STATE(2585),
    [sym_extension] = STATE(7319),
    [sym_quoted_extension] = STATE(7319),
    [sym__constant] = STATE(7319),
    [sym_number] = STATE(7039),
    [sym_character] = STATE(7039),
    [sym_string] = STATE(7039),
    [sym_quoted_string] = STATE(7039),
    [sym_boolean] = STATE(7039),
    [sym_unit] = STATE(7039),
    [sym__value_name] = STATE(7325),
    [sym_parenthesized_operator] = STATE(7116),
    [sym_value_path] = STATE(7319),
    [sym_module_path] = STATE(19882),
    [sym_constructor_path] = STATE(7319),
    [sym__constructor_name] = STATE(7040),
    [sym_tag] = STATE(7319),
    [aux_sym_class_application_repeat1] = STATE(2585),
    [sym__lowercase_identifier] = ACTIONS(6487),
    [anon_sym_TILDE] = ACTIONS(6490),
    [anon_sym_QMARK] = ACTIONS(6490),
    [anon_sym_LPAREN] = ACTIONS(6493),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6496),
    [anon_sym_true] = ACTIONS(6499),
    [anon_sym_false] = ACTIONS(6499),
    [anon_sym_LBRACE] = ACTIONS(6502),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(6505),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6508),
    [anon_sym_new] = ACTIONS(6511),
    [anon_sym_LBRACE_LT] = ACTIONS(6514),
    [anon_sym_begin] = ACTIONS(6517),
    [sym_ocamlyacc_value] = ACTIONS(6520),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6523),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6526),
    [aux_sym_number_token1] = ACTIONS(6529),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6532),
    [anon_sym_DQUOTE] = ACTIONS(6535),
    [sym_prefix_operator] = ACTIONS(6538),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6541),
    [aux_sym_tag_token1] = ACTIONS(6544),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2586] = {
    [sym__simple_expression] = STATE(7145),
    [sym_typed_expression] = STATE(7186),
    [sym_list_expression] = STATE(7186),
    [sym_array_expression] = STATE(7186),
    [sym_record_expression] = STATE(7186),
    [sym_labeled_argument] = STATE(8045),
    [sym_prefix_expression] = STATE(7186),
    [sym_hash_expression] = STATE(7186),
    [sym_field_get_expression] = STATE(7186),
    [sym_array_get_expression] = STATE(7186),
    [sym_string_get_expression] = STATE(7186),
    [sym_bigarray_get_expression] = STATE(7186),
    [sym_coercion_expression] = STATE(7186),
    [sym_local_open_expression] = STATE(7186),
    [sym_package_expression] = STATE(7186),
    [sym_new_expression] = STATE(7186),
    [sym_object_copy_expression] = STATE(7186),
    [sym_method_invocation] = STATE(7186),
    [sym_object_expression] = STATE(7186),
    [sym_parenthesized_expression] = STATE(7186),
    [sym_attribute] = STATE(2586),
    [sym_extension] = STATE(7186),
    [sym_quoted_extension] = STATE(7186),
    [sym__constant] = STATE(7186),
    [sym_number] = STATE(7324),
    [sym_character] = STATE(7324),
    [sym_string] = STATE(7324),
    [sym_quoted_string] = STATE(7324),
    [sym_boolean] = STATE(7324),
    [sym_unit] = STATE(7324),
    [sym__value_name] = STATE(7189),
    [sym_parenthesized_operator] = STATE(7418),
    [sym_value_path] = STATE(7186),
    [sym_module_path] = STATE(18498),
    [sym_constructor_path] = STATE(7186),
    [sym__constructor_name] = STATE(7160),
    [sym_tag] = STATE(7186),
    [aux_sym_class_application_repeat1] = STATE(2586),
    [sym__lowercase_identifier] = ACTIONS(6547),
    [anon_sym_TILDE] = ACTIONS(6550),
    [anon_sym_QMARK] = ACTIONS(6550),
    [anon_sym_LPAREN] = ACTIONS(6553),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6556),
    [anon_sym_true] = ACTIONS(6559),
    [anon_sym_false] = ACTIONS(6559),
    [anon_sym_LBRACE] = ACTIONS(6562),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6565),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6568),
    [anon_sym_then] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6571),
    [anon_sym_LBRACE_LT] = ACTIONS(6574),
    [anon_sym_begin] = ACTIONS(6577),
    [sym_ocamlyacc_value] = ACTIONS(6580),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6586),
    [aux_sym_number_token1] = ACTIONS(6589),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6592),
    [anon_sym_DQUOTE] = ACTIONS(6595),
    [sym_prefix_operator] = ACTIONS(6598),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6601),
    [aux_sym_tag_token1] = ACTIONS(6604),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2587] = {
    [sym__simple_expression] = STATE(7152),
    [sym_typed_expression] = STATE(7367),
    [sym_list_expression] = STATE(7367),
    [sym_array_expression] = STATE(7367),
    [sym_record_expression] = STATE(7367),
    [sym_labeled_argument] = STATE(8021),
    [sym_prefix_expression] = STATE(7367),
    [sym_hash_expression] = STATE(7367),
    [sym_field_get_expression] = STATE(7367),
    [sym_array_get_expression] = STATE(7367),
    [sym_string_get_expression] = STATE(7367),
    [sym_bigarray_get_expression] = STATE(7367),
    [sym_coercion_expression] = STATE(7367),
    [sym_local_open_expression] = STATE(7367),
    [sym_package_expression] = STATE(7367),
    [sym_new_expression] = STATE(7367),
    [sym_object_copy_expression] = STATE(7367),
    [sym_method_invocation] = STATE(7367),
    [sym_object_expression] = STATE(7367),
    [sym_parenthesized_expression] = STATE(7367),
    [sym_attribute] = STATE(2587),
    [sym_extension] = STATE(7367),
    [sym_quoted_extension] = STATE(7367),
    [sym__constant] = STATE(7367),
    [sym_number] = STATE(7133),
    [sym_character] = STATE(7133),
    [sym_string] = STATE(7133),
    [sym_quoted_string] = STATE(7133),
    [sym_boolean] = STATE(7133),
    [sym_unit] = STATE(7133),
    [sym__value_name] = STATE(7422),
    [sym_parenthesized_operator] = STATE(7501),
    [sym_value_path] = STATE(7367),
    [sym_module_path] = STATE(19371),
    [sym_constructor_path] = STATE(7367),
    [sym__constructor_name] = STATE(7134),
    [sym_tag] = STATE(7367),
    [aux_sym_class_application_repeat1] = STATE(2587),
    [sym__lowercase_identifier] = ACTIONS(6607),
    [anon_sym_SEMI_SEMI] = ACTIONS(3790),
    [anon_sym_and] = ACTIONS(3792),
    [anon_sym_TILDE] = ACTIONS(6610),
    [anon_sym_QMARK] = ACTIONS(6610),
    [anon_sym_LPAREN] = ACTIONS(6613),
    [anon_sym_external] = ACTIONS(3792),
    [anon_sym_type] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6616),
    [anon_sym_true] = ACTIONS(6619),
    [anon_sym_false] = ACTIONS(6619),
    [anon_sym_LBRACE] = ACTIONS(6622),
    [anon_sym_exception] = ACTIONS(3792),
    [anon_sym_module] = ACTIONS(3792),
    [anon_sym_open] = ACTIONS(3792),
    [anon_sym_include] = ACTIONS(3792),
    [anon_sym_class] = ACTIONS(3792),
    [anon_sym_val] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(6625),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6628),
    [anon_sym_new] = ACTIONS(6631),
    [anon_sym_LBRACE_LT] = ACTIONS(6634),
    [anon_sym_begin] = ACTIONS(6637),
    [sym_ocamlyacc_value] = ACTIONS(6640),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6643),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6646),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(6649),
    [anon_sym_SQUOTE] = ACTIONS(6652),
    [anon_sym_DQUOTE] = ACTIONS(6655),
    [sym_prefix_operator] = ACTIONS(6658),
    [sym__uppercase_identifier] = ACTIONS(6661),
    [aux_sym_tag_token1] = ACTIONS(6664),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2588] = {
    [sym__simple_expression] = STATE(7095),
    [sym_typed_expression] = STATE(7057),
    [sym_list_expression] = STATE(7057),
    [sym_array_expression] = STATE(7057),
    [sym_record_expression] = STATE(7057),
    [sym_labeled_argument] = STATE(8121),
    [sym_prefix_expression] = STATE(7057),
    [sym_hash_expression] = STATE(7057),
    [sym_field_get_expression] = STATE(7057),
    [sym_array_get_expression] = STATE(7057),
    [sym_string_get_expression] = STATE(7057),
    [sym_bigarray_get_expression] = STATE(7057),
    [sym_coercion_expression] = STATE(7057),
    [sym_local_open_expression] = STATE(7057),
    [sym_package_expression] = STATE(7057),
    [sym_new_expression] = STATE(7057),
    [sym_object_copy_expression] = STATE(7057),
    [sym_method_invocation] = STATE(7057),
    [sym_object_expression] = STATE(7057),
    [sym_parenthesized_expression] = STATE(7057),
    [sym_attribute] = STATE(2588),
    [sym_extension] = STATE(7057),
    [sym_quoted_extension] = STATE(7057),
    [sym__constant] = STATE(7057),
    [sym_number] = STATE(7338),
    [sym_character] = STATE(7338),
    [sym_string] = STATE(7338),
    [sym_quoted_string] = STATE(7338),
    [sym_boolean] = STATE(7338),
    [sym_unit] = STATE(7338),
    [sym__value_name] = STATE(7093),
    [sym_parenthesized_operator] = STATE(7150),
    [sym_value_path] = STATE(7057),
    [sym_module_path] = STATE(18562),
    [sym_constructor_path] = STATE(7057),
    [sym__constructor_name] = STATE(7340),
    [sym_tag] = STATE(7057),
    [aux_sym_class_application_repeat1] = STATE(2588),
    [sym__lowercase_identifier] = ACTIONS(6667),
    [anon_sym_TILDE] = ACTIONS(6670),
    [anon_sym_QMARK] = ACTIONS(6670),
    [anon_sym_LPAREN] = ACTIONS(6673),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6676),
    [anon_sym_true] = ACTIONS(6679),
    [anon_sym_false] = ACTIONS(6679),
    [anon_sym_LBRACE] = ACTIONS(6682),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_object] = ACTIONS(6685),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6688),
    [anon_sym_done] = ACTIONS(3792),
    [anon_sym_new] = ACTIONS(6691),
    [anon_sym_LBRACE_LT] = ACTIONS(6694),
    [anon_sym_begin] = ACTIONS(6697),
    [sym_ocamlyacc_value] = ACTIONS(6700),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6703),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6706),
    [aux_sym_number_token1] = ACTIONS(6709),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6712),
    [anon_sym_DQUOTE] = ACTIONS(6715),
    [sym_prefix_operator] = ACTIONS(6718),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6721),
    [aux_sym_tag_token1] = ACTIONS(6724),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2589] = {
    [sym__simple_expression] = STATE(7433),
    [sym_typed_expression] = STATE(7511),
    [sym_list_expression] = STATE(7511),
    [sym_array_expression] = STATE(7511),
    [sym_record_expression] = STATE(7511),
    [sym_labeled_argument] = STATE(8135),
    [sym_prefix_expression] = STATE(7511),
    [sym_hash_expression] = STATE(7511),
    [sym_field_get_expression] = STATE(7511),
    [sym_array_get_expression] = STATE(7511),
    [sym_string_get_expression] = STATE(7511),
    [sym_bigarray_get_expression] = STATE(7511),
    [sym_coercion_expression] = STATE(7511),
    [sym_local_open_expression] = STATE(7511),
    [sym_package_expression] = STATE(7511),
    [sym_new_expression] = STATE(7511),
    [sym_object_copy_expression] = STATE(7511),
    [sym_method_invocation] = STATE(7511),
    [sym_object_expression] = STATE(7511),
    [sym_parenthesized_expression] = STATE(7511),
    [sym_attribute] = STATE(2589),
    [sym_extension] = STATE(7511),
    [sym_quoted_extension] = STATE(7511),
    [sym__constant] = STATE(7511),
    [sym_number] = STATE(7279),
    [sym_character] = STATE(7279),
    [sym_string] = STATE(7279),
    [sym_quoted_string] = STATE(7279),
    [sym_boolean] = STATE(7279),
    [sym_unit] = STATE(7279),
    [sym__value_name] = STATE(7516),
    [sym_parenthesized_operator] = STATE(7315),
    [sym_value_path] = STATE(7511),
    [sym_module_path] = STATE(19506),
    [sym_constructor_path] = STATE(7511),
    [sym__constructor_name] = STATE(7502),
    [sym_tag] = STATE(7511),
    [aux_sym_class_application_repeat1] = STATE(2589),
    [sym__lowercase_identifier] = ACTIONS(6727),
    [anon_sym_TILDE] = ACTIONS(6730),
    [anon_sym_QMARK] = ACTIONS(6730),
    [anon_sym_LPAREN] = ACTIONS(6733),
    [anon_sym_COMMA] = ACTIONS(3790),
    [anon_sym_PIPE] = ACTIONS(3792),
    [anon_sym_LBRACK] = ACTIONS(6736),
    [anon_sym_true] = ACTIONS(6739),
    [anon_sym_false] = ACTIONS(6739),
    [anon_sym_LBRACE] = ACTIONS(6742),
    [anon_sym_SEMI] = ACTIONS(3790),
    [anon_sym_with] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(6745),
    [anon_sym_COLON_COLON] = ACTIONS(3790),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6748),
    [anon_sym_new] = ACTIONS(6751),
    [anon_sym_LBRACE_LT] = ACTIONS(6754),
    [anon_sym_begin] = ACTIONS(6757),
    [sym_ocamlyacc_value] = ACTIONS(6760),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6763),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6766),
    [aux_sym_number_token1] = ACTIONS(6769),
    [aux_sym_signed_number_token1] = ACTIONS(3792),
    [anon_sym_SQUOTE] = ACTIONS(6772),
    [anon_sym_DQUOTE] = ACTIONS(6775),
    [sym_prefix_operator] = ACTIONS(6778),
    [aux_sym_sign_operator_token1] = ACTIONS(3792),
    [sym_pow_operator] = ACTIONS(3792),
    [sym_mult_operator] = ACTIONS(3792),
    [aux_sym_add_operator_token1] = ACTIONS(3792),
    [sym_concat_operator] = ACTIONS(3790),
    [sym_rel_operator] = ACTIONS(3792),
    [sym_and_operator] = ACTIONS(3792),
    [sym_or_operator] = ACTIONS(3792),
    [sym_assign_operator] = ACTIONS(3790),
    [sym__uppercase_identifier] = ACTIONS(6781),
    [aux_sym_tag_token1] = ACTIONS(6784),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2590] = {
    [sym__parenthesized_abstract_type] = STATE(3155),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(13888),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2590),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_EQ] = ACTIONS(6787),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(6791),
    [anon_sym_RPAREN] = ACTIONS(6787),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_PIPE] = ACTIONS(6787),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(6787),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_COLON2] = ACTIONS(6793),
    [anon_sym_DASH_GT] = ACTIONS(6787),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_as] = ACTIONS(6793),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(6787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_when] = ACTIONS(6793),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(6797),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2591] = {
    [sym__simple_expression] = STATE(8394),
    [sym_typed_expression] = STATE(8227),
    [sym_list_expression] = STATE(8227),
    [sym_array_expression] = STATE(8227),
    [sym_record_expression] = STATE(8227),
    [sym_labeled_argument] = STATE(8762),
    [sym_prefix_expression] = STATE(8227),
    [sym_hash_expression] = STATE(8227),
    [sym_field_get_expression] = STATE(8227),
    [sym_array_get_expression] = STATE(8227),
    [sym_string_get_expression] = STATE(8227),
    [sym_bigarray_get_expression] = STATE(8227),
    [sym_coercion_expression] = STATE(8227),
    [sym_local_open_expression] = STATE(8227),
    [sym_package_expression] = STATE(8227),
    [sym_new_expression] = STATE(8227),
    [sym_object_copy_expression] = STATE(8227),
    [sym_method_invocation] = STATE(8227),
    [sym_object_expression] = STATE(8227),
    [sym_parenthesized_expression] = STATE(8227),
    [sym_attribute] = STATE(2591),
    [sym_extension] = STATE(8227),
    [sym_quoted_extension] = STATE(8227),
    [sym__constant] = STATE(8227),
    [sym_number] = STATE(8206),
    [sym_character] = STATE(8206),
    [sym_string] = STATE(8206),
    [sym_quoted_string] = STATE(8206),
    [sym_boolean] = STATE(8206),
    [sym_unit] = STATE(8206),
    [sym__value_name] = STATE(8429),
    [sym_parenthesized_operator] = STATE(8203),
    [sym_value_path] = STATE(8227),
    [sym_module_path] = STATE(18431),
    [sym_constructor_path] = STATE(8227),
    [sym__constructor_name] = STATE(8207),
    [sym_tag] = STATE(8227),
    [aux_sym_class_application_repeat1] = STATE(2597),
    [sym__lowercase_identifier] = ACTIONS(6799),
    [anon_sym_TILDE] = ACTIONS(6801),
    [anon_sym_QMARK] = ACTIONS(6801),
    [anon_sym_LPAREN] = ACTIONS(6803),
    [anon_sym_LBRACK] = ACTIONS(6805),
    [anon_sym_true] = ACTIONS(6807),
    [anon_sym_false] = ACTIONS(6807),
    [anon_sym_LBRACE] = ACTIONS(6809),
    [anon_sym_constraint] = ACTIONS(5699),
    [anon_sym_val] = ACTIONS(5699),
    [anon_sym_end] = ACTIONS(5699),
    [anon_sym_object] = ACTIONS(6811),
    [anon_sym_inherit] = ACTIONS(5699),
    [anon_sym_method] = ACTIONS(5699),
    [anon_sym_as] = ACTIONS(5699),
    [anon_sym_initializer] = ACTIONS(5699),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6813),
    [anon_sym_new] = ACTIONS(6815),
    [anon_sym_LBRACE_LT] = ACTIONS(6817),
    [anon_sym_begin] = ACTIONS(6819),
    [sym_ocamlyacc_value] = ACTIONS(6821),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5699),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5697),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6823),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6825),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5697),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5697),
    [aux_sym_number_token1] = ACTIONS(6827),
    [anon_sym_SQUOTE] = ACTIONS(6829),
    [anon_sym_DQUOTE] = ACTIONS(6831),
    [sym_prefix_operator] = ACTIONS(6833),
    [sym__uppercase_identifier] = ACTIONS(6835),
    [aux_sym_tag_token1] = ACTIONS(6837),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2592] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11662),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2592),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(11050),
    [aux_sym_let_binding_repeat1] = STATE(2606),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(6841),
    [anon_sym_let] = ACTIONS(6843),
    [anon_sym_and] = ACTIONS(6843),
    [anon_sym_EQ] = ACTIONS(6845),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(6843),
    [anon_sym_type] = ACTIONS(6843),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(6841),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6843),
    [anon_sym_open] = ACTIONS(6843),
    [anon_sym_include] = ACTIONS(6843),
    [anon_sym_class] = ACTIONS(6843),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6841),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6841),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6841),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(6841),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(6843),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2593] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11742),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2593),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10903),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(6885),
    [anon_sym_let] = ACTIONS(6887),
    [anon_sym_and] = ACTIONS(6887),
    [anon_sym_EQ] = ACTIONS(6889),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(6887),
    [anon_sym_type] = ACTIONS(6887),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(6887),
    [anon_sym_module] = ACTIONS(6887),
    [anon_sym_open] = ACTIONS(6887),
    [anon_sym_include] = ACTIONS(6887),
    [anon_sym_class] = ACTIONS(6887),
    [anon_sym_end] = ACTIONS(6887),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6885),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6885),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6885),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(6885),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(6887),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2594] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11660),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2594),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10879),
    [aux_sym_let_binding_repeat1] = STATE(2596),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(6925),
    [anon_sym_let] = ACTIONS(6927),
    [anon_sym_and] = ACTIONS(6927),
    [anon_sym_EQ] = ACTIONS(6929),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(6927),
    [anon_sym_type] = ACTIONS(6927),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(6925),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(6927),
    [anon_sym_module] = ACTIONS(6927),
    [anon_sym_open] = ACTIONS(6927),
    [anon_sym_include] = ACTIONS(6927),
    [anon_sym_class] = ACTIONS(6927),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6925),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(6925),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(6927),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2595] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11698),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2595),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10936),
    [aux_sym_let_binding_repeat1] = STATE(2602),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(6931),
    [anon_sym_let] = ACTIONS(6933),
    [anon_sym_and] = ACTIONS(6933),
    [anon_sym_EQ] = ACTIONS(6935),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(6933),
    [anon_sym_type] = ACTIONS(6933),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(6933),
    [anon_sym_module] = ACTIONS(6933),
    [anon_sym_open] = ACTIONS(6933),
    [anon_sym_include] = ACTIONS(6933),
    [anon_sym_class] = ACTIONS(6933),
    [anon_sym_end] = ACTIONS(6933),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6931),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6931),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6931),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(6931),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(6933),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2596] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11704),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2596),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10875),
    [aux_sym_let_binding_repeat1] = STATE(2641),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(6937),
    [anon_sym_let] = ACTIONS(6939),
    [anon_sym_and] = ACTIONS(6939),
    [anon_sym_EQ] = ACTIONS(6941),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(6939),
    [anon_sym_type] = ACTIONS(6939),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(6937),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(6939),
    [anon_sym_module] = ACTIONS(6939),
    [anon_sym_open] = ACTIONS(6939),
    [anon_sym_include] = ACTIONS(6939),
    [anon_sym_class] = ACTIONS(6939),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6937),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6937),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6937),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(6937),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(6939),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2597] = {
    [sym__simple_expression] = STATE(8394),
    [sym_typed_expression] = STATE(8227),
    [sym_list_expression] = STATE(8227),
    [sym_array_expression] = STATE(8227),
    [sym_record_expression] = STATE(8227),
    [sym_labeled_argument] = STATE(8762),
    [sym_prefix_expression] = STATE(8227),
    [sym_hash_expression] = STATE(8227),
    [sym_field_get_expression] = STATE(8227),
    [sym_array_get_expression] = STATE(8227),
    [sym_string_get_expression] = STATE(8227),
    [sym_bigarray_get_expression] = STATE(8227),
    [sym_coercion_expression] = STATE(8227),
    [sym_local_open_expression] = STATE(8227),
    [sym_package_expression] = STATE(8227),
    [sym_new_expression] = STATE(8227),
    [sym_object_copy_expression] = STATE(8227),
    [sym_method_invocation] = STATE(8227),
    [sym_object_expression] = STATE(8227),
    [sym_parenthesized_expression] = STATE(8227),
    [sym_attribute] = STATE(2597),
    [sym_extension] = STATE(8227),
    [sym_quoted_extension] = STATE(8227),
    [sym__constant] = STATE(8227),
    [sym_number] = STATE(8206),
    [sym_character] = STATE(8206),
    [sym_string] = STATE(8206),
    [sym_quoted_string] = STATE(8206),
    [sym_boolean] = STATE(8206),
    [sym_unit] = STATE(8206),
    [sym__value_name] = STATE(8429),
    [sym_parenthesized_operator] = STATE(8203),
    [sym_value_path] = STATE(8227),
    [sym_module_path] = STATE(18431),
    [sym_constructor_path] = STATE(8227),
    [sym__constructor_name] = STATE(8207),
    [sym_tag] = STATE(8227),
    [aux_sym_class_application_repeat1] = STATE(2597),
    [sym__lowercase_identifier] = ACTIONS(6943),
    [anon_sym_TILDE] = ACTIONS(6946),
    [anon_sym_QMARK] = ACTIONS(6946),
    [anon_sym_LPAREN] = ACTIONS(6949),
    [anon_sym_LBRACK] = ACTIONS(6952),
    [anon_sym_true] = ACTIONS(6955),
    [anon_sym_false] = ACTIONS(6955),
    [anon_sym_LBRACE] = ACTIONS(6958),
    [anon_sym_constraint] = ACTIONS(3792),
    [anon_sym_val] = ACTIONS(3792),
    [anon_sym_end] = ACTIONS(3792),
    [anon_sym_object] = ACTIONS(6961),
    [anon_sym_inherit] = ACTIONS(3792),
    [anon_sym_method] = ACTIONS(3792),
    [anon_sym_as] = ACTIONS(3792),
    [anon_sym_initializer] = ACTIONS(3792),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6964),
    [anon_sym_new] = ACTIONS(6967),
    [anon_sym_LBRACE_LT] = ACTIONS(6970),
    [anon_sym_begin] = ACTIONS(6973),
    [sym_ocamlyacc_value] = ACTIONS(6976),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(3792),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(3790),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6979),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6982),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(3790),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(3790),
    [aux_sym_number_token1] = ACTIONS(6985),
    [anon_sym_SQUOTE] = ACTIONS(6988),
    [anon_sym_DQUOTE] = ACTIONS(6991),
    [sym_prefix_operator] = ACTIONS(6994),
    [sym__uppercase_identifier] = ACTIONS(6997),
    [aux_sym_tag_token1] = ACTIONS(7000),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2598] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11759),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2598),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10945),
    [aux_sym_let_binding_repeat1] = STATE(2599),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(7003),
    [anon_sym_let] = ACTIONS(7005),
    [anon_sym_and] = ACTIONS(7005),
    [anon_sym_EQ] = ACTIONS(7007),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(7005),
    [anon_sym_type] = ACTIONS(7005),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(7005),
    [anon_sym_module] = ACTIONS(7005),
    [anon_sym_open] = ACTIONS(7005),
    [anon_sym_include] = ACTIONS(7005),
    [anon_sym_class] = ACTIONS(7005),
    [anon_sym_end] = ACTIONS(7005),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7003),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7003),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7003),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(7003),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(7005),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2599] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11764),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2599),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(11100),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(7009),
    [anon_sym_let] = ACTIONS(7011),
    [anon_sym_and] = ACTIONS(7011),
    [anon_sym_EQ] = ACTIONS(7013),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(7011),
    [anon_sym_type] = ACTIONS(7011),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(7011),
    [anon_sym_module] = ACTIONS(7011),
    [anon_sym_open] = ACTIONS(7011),
    [anon_sym_include] = ACTIONS(7011),
    [anon_sym_class] = ACTIONS(7011),
    [anon_sym_end] = ACTIONS(7011),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7009),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7009),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7009),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(7009),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(7011),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2600] = {
    [sym__simple_expression] = STATE(8394),
    [sym_typed_expression] = STATE(8227),
    [sym_list_expression] = STATE(8227),
    [sym_array_expression] = STATE(8227),
    [sym_record_expression] = STATE(8227),
    [sym_labeled_argument] = STATE(8762),
    [sym_prefix_expression] = STATE(8227),
    [sym_hash_expression] = STATE(8227),
    [sym_field_get_expression] = STATE(8227),
    [sym_array_get_expression] = STATE(8227),
    [sym_string_get_expression] = STATE(8227),
    [sym_bigarray_get_expression] = STATE(8227),
    [sym_coercion_expression] = STATE(8227),
    [sym_local_open_expression] = STATE(8227),
    [sym_package_expression] = STATE(8227),
    [sym_new_expression] = STATE(8227),
    [sym_object_copy_expression] = STATE(8227),
    [sym_method_invocation] = STATE(8227),
    [sym_object_expression] = STATE(8227),
    [sym_parenthesized_expression] = STATE(8227),
    [sym_attribute] = STATE(2600),
    [sym_extension] = STATE(8227),
    [sym_quoted_extension] = STATE(8227),
    [sym__constant] = STATE(8227),
    [sym_number] = STATE(8206),
    [sym_character] = STATE(8206),
    [sym_string] = STATE(8206),
    [sym_quoted_string] = STATE(8206),
    [sym_boolean] = STATE(8206),
    [sym_unit] = STATE(8206),
    [sym__value_name] = STATE(8429),
    [sym_parenthesized_operator] = STATE(8203),
    [sym_value_path] = STATE(8227),
    [sym_module_path] = STATE(18431),
    [sym_constructor_path] = STATE(8227),
    [sym__constructor_name] = STATE(8207),
    [sym_tag] = STATE(8227),
    [aux_sym_class_application_repeat1] = STATE(2591),
    [sym__lowercase_identifier] = ACTIONS(6799),
    [anon_sym_TILDE] = ACTIONS(6801),
    [anon_sym_QMARK] = ACTIONS(6801),
    [anon_sym_LPAREN] = ACTIONS(6803),
    [anon_sym_LBRACK] = ACTIONS(6805),
    [anon_sym_true] = ACTIONS(6807),
    [anon_sym_false] = ACTIONS(6807),
    [anon_sym_LBRACE] = ACTIONS(6809),
    [anon_sym_constraint] = ACTIONS(5815),
    [anon_sym_val] = ACTIONS(5815),
    [anon_sym_end] = ACTIONS(5815),
    [anon_sym_object] = ACTIONS(6811),
    [anon_sym_inherit] = ACTIONS(5815),
    [anon_sym_method] = ACTIONS(5815),
    [anon_sym_as] = ACTIONS(5815),
    [anon_sym_initializer] = ACTIONS(5815),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6813),
    [anon_sym_new] = ACTIONS(6815),
    [anon_sym_LBRACE_LT] = ACTIONS(6817),
    [anon_sym_begin] = ACTIONS(6819),
    [sym_ocamlyacc_value] = ACTIONS(6821),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(5815),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(5813),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6823),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6825),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(5813),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(5813),
    [aux_sym_number_token1] = ACTIONS(6827),
    [anon_sym_SQUOTE] = ACTIONS(6829),
    [anon_sym_DQUOTE] = ACTIONS(6831),
    [sym_prefix_operator] = ACTIONS(6833),
    [sym__uppercase_identifier] = ACTIONS(6835),
    [aux_sym_tag_token1] = ACTIONS(6837),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2601] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11635),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2601),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10879),
    [aux_sym_let_binding_repeat1] = STATE(2605),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(6925),
    [anon_sym_let] = ACTIONS(6927),
    [anon_sym_and] = ACTIONS(6927),
    [anon_sym_EQ] = ACTIONS(7015),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(6927),
    [anon_sym_type] = ACTIONS(6927),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(6927),
    [anon_sym_module] = ACTIONS(6927),
    [anon_sym_open] = ACTIONS(6927),
    [anon_sym_include] = ACTIONS(6927),
    [anon_sym_class] = ACTIONS(6927),
    [anon_sym_end] = ACTIONS(6927),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6925),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(6925),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(6927),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2602] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11639),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2602),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(11128),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(7017),
    [anon_sym_let] = ACTIONS(7019),
    [anon_sym_and] = ACTIONS(7019),
    [anon_sym_EQ] = ACTIONS(7021),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(7019),
    [anon_sym_type] = ACTIONS(7019),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(7019),
    [anon_sym_module] = ACTIONS(7019),
    [anon_sym_open] = ACTIONS(7019),
    [anon_sym_include] = ACTIONS(7019),
    [anon_sym_class] = ACTIONS(7019),
    [anon_sym_end] = ACTIONS(7019),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7017),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7017),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7017),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(7017),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(7019),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2603] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11600),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2603),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10936),
    [aux_sym_let_binding_repeat1] = STATE(2608),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(6931),
    [anon_sym_let] = ACTIONS(6933),
    [anon_sym_and] = ACTIONS(6933),
    [anon_sym_EQ] = ACTIONS(7023),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(6933),
    [anon_sym_type] = ACTIONS(6933),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(6931),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(6933),
    [anon_sym_module] = ACTIONS(6933),
    [anon_sym_open] = ACTIONS(6933),
    [anon_sym_include] = ACTIONS(6933),
    [anon_sym_class] = ACTIONS(6933),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6931),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6931),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6931),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(6931),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(6933),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2604] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11653),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2604),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10903),
    [aux_sym_let_binding_repeat1] = STATE(2641),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(6885),
    [anon_sym_let] = ACTIONS(6887),
    [anon_sym_and] = ACTIONS(6887),
    [anon_sym_EQ] = ACTIONS(7025),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(6887),
    [anon_sym_type] = ACTIONS(6887),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(6885),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(6887),
    [anon_sym_module] = ACTIONS(6887),
    [anon_sym_open] = ACTIONS(6887),
    [anon_sym_include] = ACTIONS(6887),
    [anon_sym_class] = ACTIONS(6887),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6885),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6885),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6885),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(6885),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(6887),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2605] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11654),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2605),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10875),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(6937),
    [anon_sym_let] = ACTIONS(6939),
    [anon_sym_and] = ACTIONS(6939),
    [anon_sym_EQ] = ACTIONS(7027),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(6939),
    [anon_sym_type] = ACTIONS(6939),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(6939),
    [anon_sym_module] = ACTIONS(6939),
    [anon_sym_open] = ACTIONS(6939),
    [anon_sym_include] = ACTIONS(6939),
    [anon_sym_class] = ACTIONS(6939),
    [anon_sym_end] = ACTIONS(6939),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6937),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6937),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6937),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(6937),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(6939),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2606] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11680),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2606),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10944),
    [aux_sym_let_binding_repeat1] = STATE(2641),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(7029),
    [anon_sym_let] = ACTIONS(7031),
    [anon_sym_and] = ACTIONS(7031),
    [anon_sym_EQ] = ACTIONS(7033),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(7031),
    [anon_sym_type] = ACTIONS(7031),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(7029),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(7031),
    [anon_sym_module] = ACTIONS(7031),
    [anon_sym_open] = ACTIONS(7031),
    [anon_sym_include] = ACTIONS(7031),
    [anon_sym_class] = ACTIONS(7031),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7029),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7029),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7029),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(7029),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(7031),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2607] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11717),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2607),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10945),
    [aux_sym_let_binding_repeat1] = STATE(2612),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(7003),
    [anon_sym_let] = ACTIONS(7005),
    [anon_sym_and] = ACTIONS(7005),
    [anon_sym_EQ] = ACTIONS(7035),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(7005),
    [anon_sym_type] = ACTIONS(7005),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(7003),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(7005),
    [anon_sym_module] = ACTIONS(7005),
    [anon_sym_open] = ACTIONS(7005),
    [anon_sym_include] = ACTIONS(7005),
    [anon_sym_class] = ACTIONS(7005),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7003),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7003),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7003),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(7003),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(7005),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2608] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11571),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2608),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(11128),
    [aux_sym_let_binding_repeat1] = STATE(2641),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(7017),
    [anon_sym_let] = ACTIONS(7019),
    [anon_sym_and] = ACTIONS(7019),
    [anon_sym_EQ] = ACTIONS(7037),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(7019),
    [anon_sym_type] = ACTIONS(7019),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(7017),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(7019),
    [anon_sym_module] = ACTIONS(7019),
    [anon_sym_open] = ACTIONS(7019),
    [anon_sym_include] = ACTIONS(7019),
    [anon_sym_class] = ACTIONS(7019),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7017),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7017),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7017),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(7017),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(7019),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2609] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11749),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2609),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(11050),
    [aux_sym_let_binding_repeat1] = STATE(2613),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(6841),
    [anon_sym_let] = ACTIONS(6843),
    [anon_sym_and] = ACTIONS(6843),
    [anon_sym_EQ] = ACTIONS(7039),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(6843),
    [anon_sym_type] = ACTIONS(6843),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6843),
    [anon_sym_open] = ACTIONS(6843),
    [anon_sym_include] = ACTIONS(6843),
    [anon_sym_class] = ACTIONS(6843),
    [anon_sym_end] = ACTIONS(6843),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6841),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6841),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6841),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(6841),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(6843),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2610] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11588),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2610),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(10966),
    [aux_sym_let_binding_repeat1] = STATE(2604),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(7041),
    [anon_sym_let] = ACTIONS(7043),
    [anon_sym_and] = ACTIONS(7043),
    [anon_sym_EQ] = ACTIONS(7045),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(7043),
    [anon_sym_type] = ACTIONS(7043),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(7041),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(7043),
    [anon_sym_module] = ACTIONS(7043),
    [anon_sym_open] = ACTIONS(7043),
    [anon_sym_include] = ACTIONS(7043),
    [anon_sym_class] = ACTIONS(7043),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7041),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7041),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7041),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(7041),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(7043),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2611] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11703),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2611),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10966),
    [aux_sym_let_binding_repeat1] = STATE(2593),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(7041),
    [anon_sym_let] = ACTIONS(7043),
    [anon_sym_and] = ACTIONS(7043),
    [anon_sym_EQ] = ACTIONS(7047),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(7043),
    [anon_sym_type] = ACTIONS(7043),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(7043),
    [anon_sym_module] = ACTIONS(7043),
    [anon_sym_open] = ACTIONS(7043),
    [anon_sym_include] = ACTIONS(7043),
    [anon_sym_class] = ACTIONS(7043),
    [anon_sym_end] = ACTIONS(7043),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7041),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7041),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7041),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(7041),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(7043),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2612] = {
    [sym_parameter] = STATE(7770),
    [sym__class_typed] = STATE(11732),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2612),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_expression_item_repeat1] = STATE(11100),
    [aux_sym_let_binding_repeat1] = STATE(2641),
    [sym__lowercase_identifier] = ACTIONS(6839),
    [anon_sym_SEMI_SEMI] = ACTIONS(7009),
    [anon_sym_let] = ACTIONS(7011),
    [anon_sym_and] = ACTIONS(7011),
    [anon_sym_EQ] = ACTIONS(7049),
    [anon_sym_TILDE] = ACTIONS(6847),
    [anon_sym_QMARK] = ACTIONS(6847),
    [anon_sym_LPAREN] = ACTIONS(6849),
    [anon_sym_external] = ACTIONS(7011),
    [anon_sym_type] = ACTIONS(7011),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_RBRACK] = ACTIONS(7009),
    [anon_sym_true] = ACTIONS(6853),
    [anon_sym_false] = ACTIONS(6853),
    [anon_sym_COLON2] = ACTIONS(6855),
    [anon_sym_LBRACE] = ACTIONS(6857),
    [anon_sym_exception] = ACTIONS(7011),
    [anon_sym_module] = ACTIONS(7011),
    [anon_sym_open] = ACTIONS(7011),
    [anon_sym_include] = ACTIONS(7011),
    [anon_sym_class] = ACTIONS(7011),
    [anon_sym_POUND] = ACTIONS(6859),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6861),
    [anon_sym_begin] = ACTIONS(6863),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7009),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6867),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6869),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7009),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7009),
    [aux_sym_number_token1] = ACTIONS(6871),
    [aux_sym_signed_number_token1] = ACTIONS(6873),
    [anon_sym_SQUOTE] = ACTIONS(6875),
    [anon_sym_DQUOTE] = ACTIONS(6877),
    [sym_let_operator] = ACTIONS(7009),
    [sym__uppercase_identifier] = ACTIONS(6879),
    [aux_sym_directive_token1] = ACTIONS(7011),
    [aux_sym_tag_token1] = ACTIONS(6881),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2613] = {
    [sym_parameter] = STATE(7812),
    [sym__class_typed] = STATE(11758),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2613),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_expression_item_repeat1] = STATE(10944),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(6883),
    [anon_sym_SEMI_SEMI] = ACTIONS(7029),
    [anon_sym_let] = ACTIONS(7031),
    [anon_sym_and] = ACTIONS(7031),
    [anon_sym_EQ] = ACTIONS(7051),
    [anon_sym_TILDE] = ACTIONS(6891),
    [anon_sym_QMARK] = ACTIONS(6891),
    [anon_sym_LPAREN] = ACTIONS(6893),
    [anon_sym_external] = ACTIONS(7031),
    [anon_sym_type] = ACTIONS(7031),
    [anon_sym_LBRACK] = ACTIONS(6895),
    [anon_sym_true] = ACTIONS(6897),
    [anon_sym_false] = ACTIONS(6897),
    [anon_sym_COLON2] = ACTIONS(6899),
    [anon_sym_LBRACE] = ACTIONS(6901),
    [anon_sym_exception] = ACTIONS(7031),
    [anon_sym_module] = ACTIONS(7031),
    [anon_sym_open] = ACTIONS(7031),
    [anon_sym_include] = ACTIONS(7031),
    [anon_sym_class] = ACTIONS(7031),
    [anon_sym_end] = ACTIONS(7031),
    [anon_sym_POUND] = ACTIONS(6903),
    [anon_sym_LBRACK_PIPE] = ACTIONS(6905),
    [anon_sym_begin] = ACTIONS(6907),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7029),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(6909),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(6911),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7029),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7029),
    [aux_sym_number_token1] = ACTIONS(6913),
    [aux_sym_signed_number_token1] = ACTIONS(6915),
    [anon_sym_SQUOTE] = ACTIONS(6917),
    [anon_sym_DQUOTE] = ACTIONS(6919),
    [sym_let_operator] = ACTIONS(7029),
    [sym__uppercase_identifier] = ACTIONS(6921),
    [aux_sym_directive_token1] = ACTIONS(7031),
    [aux_sym_tag_token1] = ACTIONS(6923),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2614] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(13890),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2614),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_EQ] = ACTIONS(6787),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(6787),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_PIPE] = ACTIONS(6787),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(6787),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_COLON2] = ACTIONS(6793),
    [anon_sym_DASH_GT] = ACTIONS(6787),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_as] = ACTIONS(6793),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(6787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_when] = ACTIONS(6793),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(6797),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2615] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(11975),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2615),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10944),
    [aux_sym_let_binding_repeat1] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(7029),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(7029),
    [anon_sym_and] = ACTIONS(7031),
    [anon_sym_EQ] = ACTIONS(7055),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(7031),
    [anon_sym_type] = ACTIONS(7031),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(7029),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(7031),
    [anon_sym_module] = ACTIONS(7031),
    [anon_sym_open] = ACTIONS(7031),
    [anon_sym_include] = ACTIONS(7031),
    [anon_sym_class] = ACTIONS(7031),
    [anon_sym_val] = ACTIONS(7031),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7029),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7029),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7029),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2616] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(12375),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2616),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(11128),
    [aux_sym_let_binding_repeat1] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(7017),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(7017),
    [anon_sym_and] = ACTIONS(7019),
    [anon_sym_EQ] = ACTIONS(7091),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(7019),
    [anon_sym_type] = ACTIONS(7019),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(7017),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(7019),
    [anon_sym_module] = ACTIONS(7019),
    [anon_sym_open] = ACTIONS(7019),
    [anon_sym_include] = ACTIONS(7019),
    [anon_sym_class] = ACTIONS(7019),
    [anon_sym_val] = ACTIONS(7019),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7017),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7017),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7017),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2617] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(12081),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2617),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(11100),
    [aux_sym_let_binding_repeat1] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(7009),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(7009),
    [anon_sym_and] = ACTIONS(7011),
    [anon_sym_EQ] = ACTIONS(7093),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(7011),
    [anon_sym_type] = ACTIONS(7011),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(7009),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(7011),
    [anon_sym_module] = ACTIONS(7011),
    [anon_sym_open] = ACTIONS(7011),
    [anon_sym_include] = ACTIONS(7011),
    [anon_sym_class] = ACTIONS(7011),
    [anon_sym_val] = ACTIONS(7011),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7009),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7009),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7009),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2618] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(12381),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2618),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10966),
    [aux_sym_let_binding_repeat1] = STATE(2620),
    [ts_builtin_sym_end] = ACTIONS(7041),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(7041),
    [anon_sym_and] = ACTIONS(7043),
    [anon_sym_EQ] = ACTIONS(7095),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(7043),
    [anon_sym_type] = ACTIONS(7043),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(7041),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(7043),
    [anon_sym_module] = ACTIONS(7043),
    [anon_sym_open] = ACTIONS(7043),
    [anon_sym_include] = ACTIONS(7043),
    [anon_sym_class] = ACTIONS(7043),
    [anon_sym_val] = ACTIONS(7043),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7041),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7041),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7041),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2619] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(12127),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2619),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10875),
    [aux_sym_let_binding_repeat1] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(6937),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(6937),
    [anon_sym_and] = ACTIONS(6939),
    [anon_sym_EQ] = ACTIONS(7097),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(6939),
    [anon_sym_type] = ACTIONS(6939),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(6937),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(6939),
    [anon_sym_module] = ACTIONS(6939),
    [anon_sym_open] = ACTIONS(6939),
    [anon_sym_include] = ACTIONS(6939),
    [anon_sym_class] = ACTIONS(6939),
    [anon_sym_val] = ACTIONS(6939),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6937),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6937),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6937),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2620] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(11837),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2620),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10903),
    [aux_sym_let_binding_repeat1] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(6885),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(6885),
    [anon_sym_and] = ACTIONS(6887),
    [anon_sym_EQ] = ACTIONS(7099),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(6887),
    [anon_sym_type] = ACTIONS(6887),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(6885),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(6887),
    [anon_sym_module] = ACTIONS(6887),
    [anon_sym_open] = ACTIONS(6887),
    [anon_sym_include] = ACTIONS(6887),
    [anon_sym_class] = ACTIONS(6887),
    [anon_sym_val] = ACTIONS(6887),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6885),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6885),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6885),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2621] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(11984),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2621),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10945),
    [aux_sym_let_binding_repeat1] = STATE(2617),
    [ts_builtin_sym_end] = ACTIONS(7003),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(7003),
    [anon_sym_and] = ACTIONS(7005),
    [anon_sym_EQ] = ACTIONS(7101),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(7005),
    [anon_sym_type] = ACTIONS(7005),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(7003),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(7005),
    [anon_sym_module] = ACTIONS(7005),
    [anon_sym_open] = ACTIONS(7005),
    [anon_sym_include] = ACTIONS(7005),
    [anon_sym_class] = ACTIONS(7005),
    [anon_sym_val] = ACTIONS(7005),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7003),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7003),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7003),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2622] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(12308),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2622),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10936),
    [aux_sym_let_binding_repeat1] = STATE(2616),
    [ts_builtin_sym_end] = ACTIONS(6931),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(6931),
    [anon_sym_and] = ACTIONS(6933),
    [anon_sym_EQ] = ACTIONS(7103),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(6933),
    [anon_sym_type] = ACTIONS(6933),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(6931),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(6933),
    [anon_sym_module] = ACTIONS(6933),
    [anon_sym_open] = ACTIONS(6933),
    [anon_sym_include] = ACTIONS(6933),
    [anon_sym_class] = ACTIONS(6933),
    [anon_sym_val] = ACTIONS(6933),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6931),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6931),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6931),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2623] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(11838),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2623),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(11050),
    [aux_sym_let_binding_repeat1] = STATE(2615),
    [ts_builtin_sym_end] = ACTIONS(6841),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(6841),
    [anon_sym_and] = ACTIONS(6843),
    [anon_sym_EQ] = ACTIONS(7105),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(6843),
    [anon_sym_type] = ACTIONS(6843),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(6841),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6843),
    [anon_sym_open] = ACTIONS(6843),
    [anon_sym_include] = ACTIONS(6843),
    [anon_sym_class] = ACTIONS(6843),
    [anon_sym_val] = ACTIONS(6843),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6841),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6841),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6841),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2624] = {
    [sym_parameter] = STATE(8120),
    [sym__class_typed] = STATE(12341),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2624),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_expression_item_repeat1] = STATE(10879),
    [aux_sym_let_binding_repeat1] = STATE(2619),
    [ts_builtin_sym_end] = ACTIONS(6925),
    [sym__lowercase_identifier] = ACTIONS(7053),
    [anon_sym_SEMI_SEMI] = ACTIONS(6925),
    [anon_sym_and] = ACTIONS(6927),
    [anon_sym_EQ] = ACTIONS(7107),
    [anon_sym_TILDE] = ACTIONS(7057),
    [anon_sym_QMARK] = ACTIONS(7057),
    [anon_sym_LPAREN] = ACTIONS(7059),
    [anon_sym_external] = ACTIONS(6927),
    [anon_sym_type] = ACTIONS(6927),
    [anon_sym_LBRACK] = ACTIONS(7061),
    [anon_sym_RBRACK] = ACTIONS(6925),
    [anon_sym_true] = ACTIONS(7063),
    [anon_sym_false] = ACTIONS(7063),
    [anon_sym_COLON2] = ACTIONS(7065),
    [anon_sym_LBRACE] = ACTIONS(7067),
    [anon_sym_exception] = ACTIONS(6927),
    [anon_sym_module] = ACTIONS(6927),
    [anon_sym_open] = ACTIONS(6927),
    [anon_sym_include] = ACTIONS(6927),
    [anon_sym_class] = ACTIONS(6927),
    [anon_sym_val] = ACTIONS(6927),
    [anon_sym_POUND] = ACTIONS(7069),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7071),
    [anon_sym_begin] = ACTIONS(7073),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7075),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7077),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6925),
    [aux_sym_number_token1] = ACTIONS(7079),
    [aux_sym_signed_number_token1] = ACTIONS(7081),
    [anon_sym_SQUOTE] = ACTIONS(7083),
    [anon_sym_DQUOTE] = ACTIONS(7085),
    [sym__uppercase_identifier] = ACTIONS(7087),
    [aux_sym_tag_token1] = ACTIONS(7089),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2625] = {
    [sym__parenthesized_abstract_type] = STATE(4749),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(9208),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2625),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(7111),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_in] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2626] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12474),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2626),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(11100),
    [aux_sym_let_binding_repeat1] = STATE(2687),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(7009),
    [anon_sym_and] = ACTIONS(7011),
    [anon_sym_EQ] = ACTIONS(7145),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(7011),
    [anon_sym_type] = ACTIONS(7011),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(7011),
    [anon_sym_module] = ACTIONS(7011),
    [anon_sym_open] = ACTIONS(7011),
    [anon_sym_include] = ACTIONS(7011),
    [anon_sym_class] = ACTIONS(7011),
    [anon_sym_val] = ACTIONS(7011),
    [anon_sym_end] = ACTIONS(7011),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7009),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7009),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7009),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2627] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12468),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2627),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10966),
    [aux_sym_let_binding_repeat1] = STATE(2631),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(7041),
    [anon_sym_and] = ACTIONS(7043),
    [anon_sym_EQ] = ACTIONS(7181),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(7043),
    [anon_sym_type] = ACTIONS(7043),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(7043),
    [anon_sym_module] = ACTIONS(7043),
    [anon_sym_open] = ACTIONS(7043),
    [anon_sym_include] = ACTIONS(7043),
    [anon_sym_class] = ACTIONS(7043),
    [anon_sym_val] = ACTIONS(7043),
    [anon_sym_end] = ACTIONS(7043),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7041),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7041),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7041),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2628] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12467),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2628),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10875),
    [aux_sym_let_binding_repeat1] = STATE(2687),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(6937),
    [anon_sym_and] = ACTIONS(6939),
    [anon_sym_EQ] = ACTIONS(7183),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(6939),
    [anon_sym_type] = ACTIONS(6939),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(6939),
    [anon_sym_module] = ACTIONS(6939),
    [anon_sym_open] = ACTIONS(6939),
    [anon_sym_include] = ACTIONS(6939),
    [anon_sym_class] = ACTIONS(6939),
    [anon_sym_val] = ACTIONS(6939),
    [anon_sym_end] = ACTIONS(6939),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6937),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6937),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6937),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2629] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12444),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2629),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10936),
    [aux_sym_let_binding_repeat1] = STATE(2635),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(6931),
    [anon_sym_and] = ACTIONS(6933),
    [anon_sym_EQ] = ACTIONS(7185),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(6933),
    [anon_sym_type] = ACTIONS(6933),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(6933),
    [anon_sym_module] = ACTIONS(6933),
    [anon_sym_open] = ACTIONS(6933),
    [anon_sym_include] = ACTIONS(6933),
    [anon_sym_class] = ACTIONS(6933),
    [anon_sym_val] = ACTIONS(6933),
    [anon_sym_end] = ACTIONS(6933),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6931),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6931),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6931),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2630] = {
    [sym__parenthesized_abstract_type] = STATE(3129),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(13888),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2630),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(6791),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_PIPE] = ACTIONS(6787),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(6787),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_SEMI] = ACTIONS(6787),
    [anon_sym_RBRACE] = ACTIONS(6787),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_as] = ACTIONS(6793),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_COLON_COLON] = ACTIONS(6787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2631] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12469),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2631),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10903),
    [aux_sym_let_binding_repeat1] = STATE(2687),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(6885),
    [anon_sym_and] = ACTIONS(6887),
    [anon_sym_EQ] = ACTIONS(7201),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(6887),
    [anon_sym_type] = ACTIONS(6887),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(6887),
    [anon_sym_module] = ACTIONS(6887),
    [anon_sym_open] = ACTIONS(6887),
    [anon_sym_include] = ACTIONS(6887),
    [anon_sym_class] = ACTIONS(6887),
    [anon_sym_val] = ACTIONS(6887),
    [anon_sym_end] = ACTIONS(6887),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6885),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6885),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6885),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2632] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12470),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2632),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(11050),
    [aux_sym_let_binding_repeat1] = STATE(2634),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(6841),
    [anon_sym_and] = ACTIONS(6843),
    [anon_sym_EQ] = ACTIONS(7203),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(6843),
    [anon_sym_type] = ACTIONS(6843),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(6843),
    [anon_sym_module] = ACTIONS(6843),
    [anon_sym_open] = ACTIONS(6843),
    [anon_sym_include] = ACTIONS(6843),
    [anon_sym_class] = ACTIONS(6843),
    [anon_sym_val] = ACTIONS(6843),
    [anon_sym_end] = ACTIONS(6843),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6841),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6841),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6841),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2633] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12452),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2633),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10879),
    [aux_sym_let_binding_repeat1] = STATE(2628),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(6925),
    [anon_sym_and] = ACTIONS(6927),
    [anon_sym_EQ] = ACTIONS(7205),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(6927),
    [anon_sym_type] = ACTIONS(6927),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(6927),
    [anon_sym_module] = ACTIONS(6927),
    [anon_sym_open] = ACTIONS(6927),
    [anon_sym_include] = ACTIONS(6927),
    [anon_sym_class] = ACTIONS(6927),
    [anon_sym_val] = ACTIONS(6927),
    [anon_sym_end] = ACTIONS(6927),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(6925),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(6925),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(6925),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2634] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12471),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2634),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10944),
    [aux_sym_let_binding_repeat1] = STATE(2687),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(7029),
    [anon_sym_and] = ACTIONS(7031),
    [anon_sym_EQ] = ACTIONS(7207),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(7031),
    [anon_sym_type] = ACTIONS(7031),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(7031),
    [anon_sym_module] = ACTIONS(7031),
    [anon_sym_open] = ACTIONS(7031),
    [anon_sym_include] = ACTIONS(7031),
    [anon_sym_class] = ACTIONS(7031),
    [anon_sym_val] = ACTIONS(7031),
    [anon_sym_end] = ACTIONS(7031),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7029),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7029),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7029),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2635] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12453),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2635),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(11128),
    [aux_sym_let_binding_repeat1] = STATE(2687),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(7017),
    [anon_sym_and] = ACTIONS(7019),
    [anon_sym_EQ] = ACTIONS(7209),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(7019),
    [anon_sym_type] = ACTIONS(7019),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(7019),
    [anon_sym_module] = ACTIONS(7019),
    [anon_sym_open] = ACTIONS(7019),
    [anon_sym_include] = ACTIONS(7019),
    [anon_sym_class] = ACTIONS(7019),
    [anon_sym_val] = ACTIONS(7019),
    [anon_sym_end] = ACTIONS(7019),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7017),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7017),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7017),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2636] = {
    [sym_parameter] = STATE(8407),
    [sym__class_typed] = STATE(12473),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2636),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_expression_item_repeat1] = STATE(10945),
    [aux_sym_let_binding_repeat1] = STATE(2626),
    [sym__lowercase_identifier] = ACTIONS(7143),
    [anon_sym_SEMI_SEMI] = ACTIONS(7003),
    [anon_sym_and] = ACTIONS(7005),
    [anon_sym_EQ] = ACTIONS(7211),
    [anon_sym_TILDE] = ACTIONS(7147),
    [anon_sym_QMARK] = ACTIONS(7147),
    [anon_sym_LPAREN] = ACTIONS(7149),
    [anon_sym_external] = ACTIONS(7005),
    [anon_sym_type] = ACTIONS(7005),
    [anon_sym_LBRACK] = ACTIONS(7151),
    [anon_sym_true] = ACTIONS(7153),
    [anon_sym_false] = ACTIONS(7153),
    [anon_sym_COLON2] = ACTIONS(7155),
    [anon_sym_LBRACE] = ACTIONS(7157),
    [anon_sym_exception] = ACTIONS(7005),
    [anon_sym_module] = ACTIONS(7005),
    [anon_sym_open] = ACTIONS(7005),
    [anon_sym_include] = ACTIONS(7005),
    [anon_sym_class] = ACTIONS(7005),
    [anon_sym_val] = ACTIONS(7005),
    [anon_sym_end] = ACTIONS(7005),
    [anon_sym_POUND] = ACTIONS(7159),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7161),
    [anon_sym_begin] = ACTIONS(7163),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7003),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7165),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7167),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7003),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7003),
    [aux_sym_number_token1] = ACTIONS(7169),
    [aux_sym_signed_number_token1] = ACTIONS(7171),
    [anon_sym_SQUOTE] = ACTIONS(7173),
    [anon_sym_DQUOTE] = ACTIONS(7175),
    [sym__uppercase_identifier] = ACTIONS(7177),
    [aux_sym_tag_token1] = ACTIONS(7179),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2637] = {
    [sym_parameter] = STATE(7812),
    [sym__parenthesized_abstract_type] = STATE(7812),
    [sym__simple_pattern] = STATE(7813),
    [sym_typed_pattern] = STATE(7870),
    [sym_polymorphic_variant_pattern] = STATE(7870),
    [sym_record_pattern] = STATE(7870),
    [sym_list_pattern] = STATE(7870),
    [sym_array_pattern] = STATE(7870),
    [sym_local_open_pattern] = STATE(7870),
    [sym_package_pattern] = STATE(7870),
    [sym_parenthesized_pattern] = STATE(7870),
    [sym_attribute] = STATE(2637),
    [sym_extension] = STATE(7870),
    [sym_quoted_extension] = STATE(7870),
    [sym__constant] = STATE(7738),
    [sym__signed_constant] = STATE(7870),
    [sym_number] = STATE(7889),
    [sym_signed_number] = STATE(7738),
    [sym_character] = STATE(7889),
    [sym_string] = STATE(7889),
    [sym_quoted_string] = STATE(7889),
    [sym_boolean] = STATE(7889),
    [sym_unit] = STATE(7889),
    [sym__simple_value_pattern] = STATE(7870),
    [sym_parenthesized_operator] = STATE(7870),
    [sym_module_path] = STATE(19511),
    [sym_constructor_path] = STATE(7870),
    [sym__constructor_name] = STATE(7846),
    [sym_tag] = STATE(7870),
    [aux_sym_let_binding_repeat1] = STATE(2637),
    [sym__lowercase_identifier] = ACTIONS(7213),
    [anon_sym_SEMI_SEMI] = ACTIONS(7216),
    [anon_sym_let] = ACTIONS(7218),
    [anon_sym_and] = ACTIONS(7218),
    [anon_sym_EQ] = ACTIONS(7216),
    [anon_sym_TILDE] = ACTIONS(7220),
    [anon_sym_QMARK] = ACTIONS(7220),
    [anon_sym_LPAREN] = ACTIONS(7223),
    [anon_sym_external] = ACTIONS(7218),
    [anon_sym_type] = ACTIONS(7218),
    [anon_sym_LBRACK] = ACTIONS(7226),
    [anon_sym_true] = ACTIONS(7229),
    [anon_sym_false] = ACTIONS(7229),
    [anon_sym_COLON2] = ACTIONS(7216),
    [anon_sym_LBRACE] = ACTIONS(7232),
    [anon_sym_exception] = ACTIONS(7218),
    [anon_sym_module] = ACTIONS(7218),
    [anon_sym_open] = ACTIONS(7218),
    [anon_sym_include] = ACTIONS(7218),
    [anon_sym_class] = ACTIONS(7218),
    [anon_sym_end] = ACTIONS(7218),
    [anon_sym_POUND] = ACTIONS(7235),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7238),
    [anon_sym_begin] = ACTIONS(7241),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7218),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7216),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7244),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7247),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7216),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7216),
    [aux_sym_number_token1] = ACTIONS(7250),
    [aux_sym_signed_number_token1] = ACTIONS(7253),
    [anon_sym_SQUOTE] = ACTIONS(7256),
    [anon_sym_DQUOTE] = ACTIONS(7259),
    [sym_let_operator] = ACTIONS(7216),
    [sym__uppercase_identifier] = ACTIONS(7262),
    [aux_sym_directive_token1] = ACTIONS(7218),
    [aux_sym_tag_token1] = ACTIONS(7265),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2638] = {
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(9233),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2638),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_and] = ACTIONS(4669),
    [anon_sym_COLON_GT] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4667),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_in] = ACTIONS(4669),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(4667),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym_let_and_operator] = ACTIONS(4667),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2639] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(13890),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2639),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_PIPE] = ACTIONS(6787),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(6787),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_SEMI] = ACTIONS(6787),
    [anon_sym_RBRACE] = ACTIONS(6787),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_as] = ACTIONS(6793),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_COLON_COLON] = ACTIONS(6787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2640] = {
    [sym__parenthesized_abstract_type] = STATE(3121),
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14725),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(2640),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7272),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_PIPE] = ACTIONS(6793),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_SEMI] = ACTIONS(6787),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_as] = ACTIONS(6793),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_COLON_COLON] = ACTIONS(6787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(6787),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2641] = {
    [sym_parameter] = STATE(7770),
    [sym__parenthesized_abstract_type] = STATE(7770),
    [sym__simple_pattern] = STATE(7791),
    [sym_typed_pattern] = STATE(7970),
    [sym_polymorphic_variant_pattern] = STATE(7970),
    [sym_record_pattern] = STATE(7970),
    [sym_list_pattern] = STATE(7970),
    [sym_array_pattern] = STATE(7970),
    [sym_local_open_pattern] = STATE(7970),
    [sym_package_pattern] = STATE(7970),
    [sym_parenthesized_pattern] = STATE(7970),
    [sym_attribute] = STATE(2641),
    [sym_extension] = STATE(7970),
    [sym_quoted_extension] = STATE(7970),
    [sym__constant] = STATE(7786),
    [sym__signed_constant] = STATE(7970),
    [sym_number] = STATE(7761),
    [sym_signed_number] = STATE(7786),
    [sym_character] = STATE(7761),
    [sym_string] = STATE(7761),
    [sym_quoted_string] = STATE(7761),
    [sym_boolean] = STATE(7761),
    [sym_unit] = STATE(7761),
    [sym__simple_value_pattern] = STATE(7970),
    [sym_parenthesized_operator] = STATE(7970),
    [sym_module_path] = STATE(19112),
    [sym_constructor_path] = STATE(7970),
    [sym__constructor_name] = STATE(7979),
    [sym_tag] = STATE(7970),
    [aux_sym_let_binding_repeat1] = STATE(2641),
    [sym__lowercase_identifier] = ACTIONS(7308),
    [anon_sym_SEMI_SEMI] = ACTIONS(7216),
    [anon_sym_let] = ACTIONS(7218),
    [anon_sym_and] = ACTIONS(7218),
    [anon_sym_EQ] = ACTIONS(7216),
    [anon_sym_TILDE] = ACTIONS(7311),
    [anon_sym_QMARK] = ACTIONS(7311),
    [anon_sym_LPAREN] = ACTIONS(7314),
    [anon_sym_external] = ACTIONS(7218),
    [anon_sym_type] = ACTIONS(7218),
    [anon_sym_LBRACK] = ACTIONS(7317),
    [anon_sym_RBRACK] = ACTIONS(7216),
    [anon_sym_true] = ACTIONS(7320),
    [anon_sym_false] = ACTIONS(7320),
    [anon_sym_COLON2] = ACTIONS(7216),
    [anon_sym_LBRACE] = ACTIONS(7323),
    [anon_sym_exception] = ACTIONS(7218),
    [anon_sym_module] = ACTIONS(7218),
    [anon_sym_open] = ACTIONS(7218),
    [anon_sym_include] = ACTIONS(7218),
    [anon_sym_class] = ACTIONS(7218),
    [anon_sym_POUND] = ACTIONS(7326),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7329),
    [anon_sym_begin] = ACTIONS(7332),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7218),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7216),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7335),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7338),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7216),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7216),
    [aux_sym_number_token1] = ACTIONS(7341),
    [aux_sym_signed_number_token1] = ACTIONS(7344),
    [anon_sym_SQUOTE] = ACTIONS(7347),
    [anon_sym_DQUOTE] = ACTIONS(7350),
    [sym_let_operator] = ACTIONS(7216),
    [sym__uppercase_identifier] = ACTIONS(7353),
    [aux_sym_directive_token1] = ACTIONS(7218),
    [aux_sym_tag_token1] = ACTIONS(7356),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2642] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14766),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(2642),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_PIPE] = ACTIONS(6793),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_SEMI] = ACTIONS(6787),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_as] = ACTIONS(6793),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_COLON_COLON] = ACTIONS(6787),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(6787),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2643] = {
    [sym_parameter] = STATE(8120),
    [sym__parenthesized_abstract_type] = STATE(8120),
    [sym__simple_pattern] = STATE(8038),
    [sym_typed_pattern] = STATE(8020),
    [sym_polymorphic_variant_pattern] = STATE(8020),
    [sym_record_pattern] = STATE(8020),
    [sym_list_pattern] = STATE(8020),
    [sym_array_pattern] = STATE(8020),
    [sym_local_open_pattern] = STATE(8020),
    [sym_package_pattern] = STATE(8020),
    [sym_parenthesized_pattern] = STATE(8020),
    [sym_attribute] = STATE(2643),
    [sym_extension] = STATE(8020),
    [sym_quoted_extension] = STATE(8020),
    [sym__constant] = STATE(8163),
    [sym__signed_constant] = STATE(8020),
    [sym_number] = STATE(8116),
    [sym_signed_number] = STATE(8163),
    [sym_character] = STATE(8116),
    [sym_string] = STATE(8116),
    [sym_quoted_string] = STATE(8116),
    [sym_boolean] = STATE(8116),
    [sym_unit] = STATE(8116),
    [sym__simple_value_pattern] = STATE(8020),
    [sym_parenthesized_operator] = STATE(8020),
    [sym_module_path] = STATE(18520),
    [sym_constructor_path] = STATE(8020),
    [sym__constructor_name] = STATE(8074),
    [sym_tag] = STATE(8020),
    [aux_sym_let_binding_repeat1] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(7216),
    [sym__lowercase_identifier] = ACTIONS(7361),
    [anon_sym_SEMI_SEMI] = ACTIONS(7216),
    [anon_sym_and] = ACTIONS(7218),
    [anon_sym_EQ] = ACTIONS(7216),
    [anon_sym_TILDE] = ACTIONS(7364),
    [anon_sym_QMARK] = ACTIONS(7364),
    [anon_sym_LPAREN] = ACTIONS(7367),
    [anon_sym_external] = ACTIONS(7218),
    [anon_sym_type] = ACTIONS(7218),
    [anon_sym_LBRACK] = ACTIONS(7370),
    [anon_sym_RBRACK] = ACTIONS(7216),
    [anon_sym_true] = ACTIONS(7373),
    [anon_sym_false] = ACTIONS(7373),
    [anon_sym_COLON2] = ACTIONS(7216),
    [anon_sym_LBRACE] = ACTIONS(7376),
    [anon_sym_exception] = ACTIONS(7218),
    [anon_sym_module] = ACTIONS(7218),
    [anon_sym_open] = ACTIONS(7218),
    [anon_sym_include] = ACTIONS(7218),
    [anon_sym_class] = ACTIONS(7218),
    [anon_sym_val] = ACTIONS(7218),
    [anon_sym_POUND] = ACTIONS(7379),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7382),
    [anon_sym_begin] = ACTIONS(7385),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7218),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7216),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7388),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7391),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7216),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7216),
    [aux_sym_number_token1] = ACTIONS(7394),
    [aux_sym_signed_number_token1] = ACTIONS(7397),
    [anon_sym_SQUOTE] = ACTIONS(7400),
    [anon_sym_DQUOTE] = ACTIONS(7403),
    [sym__uppercase_identifier] = ACTIONS(7406),
    [aux_sym_tag_token1] = ACTIONS(7409),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2644] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19659),
    [sym_module_definition] = STATE(19667),
    [sym_open_module] = STATE(19677),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2644),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2645] = {
    [sym_let_binding] = STATE(11794),
    [sym_exception_definition] = STATE(19781),
    [sym_module_definition] = STATE(19823),
    [sym_open_module] = STATE(20210),
    [sym__simple_binding_pattern] = STATE(5627),
    [sym__binding_pattern] = STATE(2526),
    [sym_alias_binding_pattern] = STATE(5627),
    [sym_typed_binding_pattern] = STATE(5646),
    [sym__or_binding_pattern_anonymous] = STATE(5649),
    [sym_constructor_binding_pattern] = STATE(5627),
    [sym_tag_binding_pattern] = STATE(5627),
    [sym_polymorphic_variant_pattern] = STATE(5646),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20333),
    [sym__tuple_binding_pattern] = STATE(5652),
    [sym_record_binding_pattern] = STATE(5666),
    [sym_list_binding_pattern] = STATE(5674),
    [sym_cons_binding_pattern] = STATE(5627),
    [sym_array_binding_pattern] = STATE(5618),
    [sym_range_pattern] = STATE(5627),
    [sym_lazy_binding_pattern] = STATE(5627),
    [sym_local_open_binding_pattern] = STATE(5646),
    [sym_package_pattern] = STATE(5646),
    [sym_parenthesized_binding_pattern] = STATE(5646),
    [sym_attribute] = STATE(2645),
    [sym_extension] = STATE(5646),
    [sym_quoted_extension] = STATE(5646),
    [sym__attribute] = STATE(4102),
    [sym__constant] = STATE(5536),
    [sym__signed_constant] = STATE(5488),
    [sym_number] = STATE(5559),
    [sym_signed_number] = STATE(5536),
    [sym_character] = STATE(5559),
    [sym_string] = STATE(5559),
    [sym_quoted_string] = STATE(5559),
    [sym_boolean] = STATE(5559),
    [sym_unit] = STATE(5559),
    [sym__value_name] = STATE(5646),
    [sym_parenthesized_operator] = STATE(5641),
    [sym_module_path] = STATE(20427),
    [sym_constructor_path] = STATE(2480),
    [sym__constructor_name] = STATE(5573),
    [sym_tag] = STATE(2489),
    [sym__lowercase_identifier] = ACTIONS(4775),
    [anon_sym_rec] = ACTIONS(7422),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(4903),
    [anon_sym_LBRACK] = ACTIONS(4779),
    [anon_sym_true] = ACTIONS(4781),
    [anon_sym_false] = ACTIONS(4781),
    [anon_sym_LBRACE] = ACTIONS(4783),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(4785),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4787),
    [anon_sym_lazy] = ACTIONS(4789),
    [anon_sym_begin] = ACTIONS(4791),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7424),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7426),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(4797),
    [aux_sym_signed_number_token1] = ACTIONS(4799),
    [anon_sym_SQUOTE] = ACTIONS(4801),
    [anon_sym_DQUOTE] = ACTIONS(4803),
    [sym__uppercase_identifier] = ACTIONS(4805),
    [aux_sym_tag_token1] = ACTIONS(4807),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2646] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2646),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2932),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2647] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21337),
    [sym_module_definition] = STATE(21339),
    [sym_open_module] = STATE(21343),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2647),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2648] = {
    [sym__match_cases] = STATE(11125),
    [sym_match_case] = STATE(11619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2648),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2907),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7432),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2649] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2649),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2766),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2650] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(9070),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2650),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2869),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7436),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2651] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8786),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2651),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2823),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7438),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2652] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19781),
    [sym_module_definition] = STATE(19823),
    [sym_open_module] = STATE(20210),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2652),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2653] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2653),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2860),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2654] = {
    [sym__match_cases] = STATE(11125),
    [sym_match_case] = STATE(12996),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2654),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2737),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7442),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2655] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2655),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2949),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2656] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18690),
    [sym_module_definition] = STATE(19099),
    [sym_open_module] = STATE(18495),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2656),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2657] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8689),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2657),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2834),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7446),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2658] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2658),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2811),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2659] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21199),
    [sym_module_definition] = STATE(21205),
    [sym_open_module] = STATE(21207),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2659),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2660] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8544),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2660),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2862),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7450),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2661] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2661),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2919),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2662] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21401),
    [sym_module_definition] = STATE(21404),
    [sym_open_module] = STATE(21407),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2662),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2663] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8556),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2663),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2900),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7454),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2664] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2664),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2921),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2665] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2665),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2788),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2666] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18996),
    [sym_module_definition] = STATE(19009),
    [sym_open_module] = STATE(19011),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2666),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2667] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8595),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2667),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2752),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7458),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2668] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2668),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2804),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2669] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20528),
    [sym_module_definition] = STATE(20535),
    [sym_open_module] = STATE(20547),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2669),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2670] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8609),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2670),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2760),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7462),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2671] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2671),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2849),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2672] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19048),
    [sym_module_definition] = STATE(19076),
    [sym_open_module] = STATE(19085),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2672),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2673] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20022),
    [sym_module_definition] = STATE(20207),
    [sym_open_module] = STATE(20215),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2673),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2674] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18565),
    [sym_module_definition] = STATE(18566),
    [sym_open_module] = STATE(18599),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2674),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2675] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20550),
    [sym_module_definition] = STATE(20559),
    [sym_open_module] = STATE(20578),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2675),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2676] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19190),
    [sym_module_definition] = STATE(19191),
    [sym_open_module] = STATE(19192),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2676),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2677] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8618),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2677),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2779),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7464),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2678] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2678),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2913),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2679] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2679),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2863),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2680] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21202),
    [sym_module_definition] = STATE(21203),
    [sym_open_module] = STATE(21208),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2680),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2681] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18901),
    [sym_module_definition] = STATE(19071),
    [sym_open_module] = STATE(19115),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2681),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2682] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19379),
    [sym_module_definition] = STATE(19380),
    [sym_open_module] = STATE(19410),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2682),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2683] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18883),
    [sym_module_definition] = STATE(18892),
    [sym_open_module] = STATE(18895),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2683),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2684] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19956),
    [sym_module_definition] = STATE(19957),
    [sym_open_module] = STATE(19976),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2684),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2685] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18517),
    [sym_module_definition] = STATE(18539),
    [sym_open_module] = STATE(18544),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2685),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2686] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(12639),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2686),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2753),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7466),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2687] = {
    [sym_parameter] = STATE(8407),
    [sym__parenthesized_abstract_type] = STATE(8407),
    [sym__simple_pattern] = STATE(8412),
    [sym_typed_pattern] = STATE(8308),
    [sym_polymorphic_variant_pattern] = STATE(8308),
    [sym_record_pattern] = STATE(8308),
    [sym_list_pattern] = STATE(8308),
    [sym_array_pattern] = STATE(8308),
    [sym_local_open_pattern] = STATE(8308),
    [sym_package_pattern] = STATE(8308),
    [sym_parenthesized_pattern] = STATE(8308),
    [sym_attribute] = STATE(2687),
    [sym_extension] = STATE(8308),
    [sym_quoted_extension] = STATE(8308),
    [sym__constant] = STATE(8242),
    [sym__signed_constant] = STATE(8308),
    [sym_number] = STATE(8386),
    [sym_signed_number] = STATE(8242),
    [sym_character] = STATE(8386),
    [sym_string] = STATE(8386),
    [sym_quoted_string] = STATE(8386),
    [sym_boolean] = STATE(8386),
    [sym_unit] = STATE(8386),
    [sym__simple_value_pattern] = STATE(8308),
    [sym_parenthesized_operator] = STATE(8308),
    [sym_module_path] = STATE(19889),
    [sym_constructor_path] = STATE(8308),
    [sym__constructor_name] = STATE(8349),
    [sym_tag] = STATE(8308),
    [aux_sym_let_binding_repeat1] = STATE(2687),
    [sym__lowercase_identifier] = ACTIONS(7468),
    [anon_sym_SEMI_SEMI] = ACTIONS(7216),
    [anon_sym_and] = ACTIONS(7218),
    [anon_sym_EQ] = ACTIONS(7216),
    [anon_sym_TILDE] = ACTIONS(7471),
    [anon_sym_QMARK] = ACTIONS(7471),
    [anon_sym_LPAREN] = ACTIONS(7474),
    [anon_sym_external] = ACTIONS(7218),
    [anon_sym_type] = ACTIONS(7218),
    [anon_sym_LBRACK] = ACTIONS(7477),
    [anon_sym_true] = ACTIONS(7480),
    [anon_sym_false] = ACTIONS(7480),
    [anon_sym_COLON2] = ACTIONS(7216),
    [anon_sym_LBRACE] = ACTIONS(7483),
    [anon_sym_exception] = ACTIONS(7218),
    [anon_sym_module] = ACTIONS(7218),
    [anon_sym_open] = ACTIONS(7218),
    [anon_sym_include] = ACTIONS(7218),
    [anon_sym_class] = ACTIONS(7218),
    [anon_sym_val] = ACTIONS(7218),
    [anon_sym_end] = ACTIONS(7218),
    [anon_sym_POUND] = ACTIONS(7486),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7489),
    [anon_sym_begin] = ACTIONS(7492),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7218),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7216),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7495),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7498),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7216),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7216),
    [aux_sym_number_token1] = ACTIONS(7501),
    [aux_sym_signed_number_token1] = ACTIONS(7504),
    [anon_sym_SQUOTE] = ACTIONS(7507),
    [anon_sym_DQUOTE] = ACTIONS(7510),
    [sym__uppercase_identifier] = ACTIONS(7513),
    [aux_sym_tag_token1] = ACTIONS(7516),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2688] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18437),
    [sym_module_definition] = STATE(18438),
    [sym_open_module] = STATE(18440),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2688),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2689] = {
    [sym_let_binding] = STATE(12224),
    [sym_exception_definition] = STATE(21202),
    [sym_module_definition] = STATE(21203),
    [sym_open_module] = STATE(21208),
    [sym__simple_binding_pattern] = STATE(5728),
    [sym__binding_pattern] = STATE(2538),
    [sym_alias_binding_pattern] = STATE(5728),
    [sym_typed_binding_pattern] = STATE(5736),
    [sym__or_binding_pattern_anonymous] = STATE(5737),
    [sym_constructor_binding_pattern] = STATE(5728),
    [sym_tag_binding_pattern] = STATE(5728),
    [sym_polymorphic_variant_pattern] = STATE(5736),
    [sym_labeled_tuple_element_binding_pattern] = STATE(20855),
    [sym__tuple_binding_pattern] = STATE(5740),
    [sym_record_binding_pattern] = STATE(5741),
    [sym_list_binding_pattern] = STATE(5585),
    [sym_cons_binding_pattern] = STATE(5728),
    [sym_array_binding_pattern] = STATE(5586),
    [sym_range_pattern] = STATE(5728),
    [sym_lazy_binding_pattern] = STATE(5728),
    [sym_local_open_binding_pattern] = STATE(5736),
    [sym_package_pattern] = STATE(5736),
    [sym_parenthesized_binding_pattern] = STATE(5736),
    [sym_attribute] = STATE(2689),
    [sym_extension] = STATE(5736),
    [sym_quoted_extension] = STATE(5736),
    [sym__attribute] = STATE(3936),
    [sym__constant] = STATE(5513),
    [sym__signed_constant] = STATE(5571),
    [sym_number] = STATE(5558),
    [sym_signed_number] = STATE(5513),
    [sym_character] = STATE(5558),
    [sym_string] = STATE(5558),
    [sym_quoted_string] = STATE(5558),
    [sym_boolean] = STATE(5558),
    [sym_unit] = STATE(5558),
    [sym__value_name] = STATE(5736),
    [sym_parenthesized_operator] = STATE(5708),
    [sym_module_path] = STATE(20857),
    [sym_constructor_path] = STATE(2477),
    [sym__constructor_name] = STATE(5565),
    [sym_tag] = STATE(2482),
    [sym__lowercase_identifier] = ACTIONS(4665),
    [anon_sym_rec] = ACTIONS(7519),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(4809),
    [anon_sym_LBRACK] = ACTIONS(4675),
    [anon_sym_true] = ACTIONS(4677),
    [anon_sym_false] = ACTIONS(4677),
    [anon_sym_LBRACE] = ACTIONS(4679),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(4681),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4683),
    [anon_sym_lazy] = ACTIONS(4685),
    [anon_sym_begin] = ACTIONS(4687),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7521),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7523),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(4693),
    [aux_sym_signed_number_token1] = ACTIONS(4695),
    [anon_sym_SQUOTE] = ACTIONS(4697),
    [anon_sym_DQUOTE] = ACTIONS(4699),
    [sym__uppercase_identifier] = ACTIONS(4701),
    [aux_sym_tag_token1] = ACTIONS(4703),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2690] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18885),
    [sym_module_definition] = STATE(18887),
    [sym_open_module] = STATE(18888),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2690),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2691] = {
    [sym__match_cases] = STATE(11125),
    [sym_match_case] = STATE(12647),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2691),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2880),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7525),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2692] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(9010),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2692),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2922),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7527),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2693] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2693),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2759),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2694] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2694),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2821),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2695] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19258),
    [sym_module_definition] = STATE(19260),
    [sym_open_module] = STATE(19261),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2695),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2696] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18602),
    [sym_module_definition] = STATE(18603),
    [sym_open_module] = STATE(18610),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2696),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2697] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19579),
    [sym_module_definition] = STATE(19591),
    [sym_open_module] = STATE(19593),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2697),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2698] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20099),
    [sym_module_definition] = STATE(20102),
    [sym_open_module] = STATE(20107),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2698),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2699] = {
    [sym__match_cases] = STATE(11125),
    [sym_match_case] = STATE(12281),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2699),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2935),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7533),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2700] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20337),
    [sym_module_definition] = STATE(20338),
    [sym_open_module] = STATE(20341),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2700),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2701] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19803),
    [sym_module_definition] = STATE(19906),
    [sym_open_module] = STATE(19977),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2701),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2702] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20669),
    [sym_module_definition] = STATE(20670),
    [sym_open_module] = STATE(20673),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2702),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2703] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(13277),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2703),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2831),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7535),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2704] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2704),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2936),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2705] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8899),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2705),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2803),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7537),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2706] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21222),
    [sym_module_definition] = STATE(21223),
    [sym_open_module] = STATE(21227),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2706),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2707] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21061),
    [sym_module_definition] = STATE(21075),
    [sym_open_module] = STATE(21149),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2707),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2708] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20974),
    [sym_module_definition] = STATE(20978),
    [sym_open_module] = STATE(20990),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2708),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2709] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2709),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2855),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2710] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19333),
    [sym_module_definition] = STATE(19342),
    [sym_open_module] = STATE(19352),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2710),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2711] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18972),
    [sym_module_definition] = STATE(18976),
    [sym_open_module] = STATE(18984),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2711),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2712] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20711),
    [sym_module_definition] = STATE(20727),
    [sym_open_module] = STATE(20739),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2712),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2713] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21389),
    [sym_module_definition] = STATE(21390),
    [sym_open_module] = STATE(21397),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2713),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2714] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19476),
    [sym_module_definition] = STATE(19478),
    [sym_open_module] = STATE(19576),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2714),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2715] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2715),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2815),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2716] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18799),
    [sym_module_definition] = STATE(18807),
    [sym_open_module] = STATE(18808),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2716),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2717] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19670),
    [sym_module_definition] = STATE(19691),
    [sym_open_module] = STATE(19693),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2717),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2718] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20810),
    [sym_module_definition] = STATE(20812),
    [sym_open_module] = STATE(20825),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2718),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2719] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2719),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2943),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2720] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18581),
    [sym_module_definition] = STATE(18593),
    [sym_open_module] = STATE(18594),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2720),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2721] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2721),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2765),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2722] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2722),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2796),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2723] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(18884),
    [sym_module_definition] = STATE(18886),
    [sym_open_module] = STATE(18890),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2723),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2724] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19286),
    [sym_module_definition] = STATE(19288),
    [sym_open_module] = STATE(19289),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2724),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2725] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19583),
    [sym_module_definition] = STATE(19584),
    [sym_open_module] = STATE(19589),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2725),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2726] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(19851),
    [sym_module_definition] = STATE(19869),
    [sym_open_module] = STATE(19871),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2726),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2727] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(21356),
    [sym_module_definition] = STATE(21392),
    [sym_open_module] = STATE(18442),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2727),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2728] = {
    [sym__match_cases] = STATE(11125),
    [sym_match_case] = STATE(12718),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2728),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2886),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2729] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2729),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2955),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2730] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2730),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2741),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2731] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(8648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2731),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2904),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7545),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2732] = {
    [sym__match_cases] = STATE(8264),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2732),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2830),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2733] = {
    [sym_let_binding] = STATE(15440),
    [sym_exception_definition] = STATE(20567),
    [sym_module_definition] = STATE(20568),
    [sym_open_module] = STATE(20569),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(2733),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_exception] = ACTIONS(7414),
    [anon_sym_module] = ACTIONS(7416),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2734] = {
    [sym__match_cases] = STATE(11125),
    [sym_match_case] = STATE(12476),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2734),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2892),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7547),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2735] = {
    [sym__match_cases] = STATE(8483),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2735),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2747),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2736] = {
    [sym__match_cases] = STATE(8458),
    [sym_match_case] = STATE(9061),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2736),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(2868),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7549),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2737] = {
    [sym__match_cases] = STATE(11119),
    [sym_match_case] = STATE(12996),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2737),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7442),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2738] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2738),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2739] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2739),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2740] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2740),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2741] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2741),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2742] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2742),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2743] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2743),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2744] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2744),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2745] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2745),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2746] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2746),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2747] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2747),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2748] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2748),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2749] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2749),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2750] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2750),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2751] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2751),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2752] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8595),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2752),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7458),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2753] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(12639),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2753),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7466),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2754] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8595),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2754),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7458),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2755] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8595),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2755),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7458),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2756] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8595),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2756),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7458),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2757] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8595),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2757),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7458),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2758] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2758),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2759] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2759),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2760] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8609),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2760),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7462),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2761] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8609),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2761),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7462),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2762] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8609),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2762),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7462),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2763] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8609),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2763),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7462),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2764] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8609),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2764),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7462),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2765] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2765),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2766] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2766),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2767] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2767),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2768] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2768),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2769] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2769),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2770] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2770),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2771] = {
    [sym__parenthesized_abstract_type] = STATE(4611),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14045),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(18535),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2771),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(14597),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2771),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(2968),
    [sym__lowercase_identifier] = ACTIONS(7551),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7553),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_RBRACK] = ACTIONS(4667),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(4667),
    [anon_sym_RBRACE] = ACTIONS(4667),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(7555),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2772] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2772),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2773] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2773),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2774] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12639),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2774),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7466),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2775] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(9061),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2775),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7549),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2776] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(9070),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2776),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7436),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2777] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2777),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2778] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2778),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2779] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8618),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2779),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7464),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2780] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2780),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2781] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8618),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2781),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7464),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2782] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8618),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2782),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7464),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2783] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2783),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2784] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8618),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2784),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7464),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2785] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8618),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2785),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7464),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2786] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2786),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2787] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2787),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2788] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2788),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2789] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(12639),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2789),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7466),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2790] = {
    [sym_parameter] = STATE(9165),
    [sym__polymorphic_typed] = STATE(13667),
    [sym__parenthesized_abstract_type] = STATE(9165),
    [sym__simple_pattern] = STATE(9167),
    [sym_typed_pattern] = STATE(9109),
    [sym_polymorphic_variant_pattern] = STATE(9109),
    [sym_record_pattern] = STATE(9109),
    [sym_list_pattern] = STATE(9109),
    [sym_array_pattern] = STATE(9109),
    [sym_local_open_pattern] = STATE(9109),
    [sym_package_pattern] = STATE(9109),
    [sym_parenthesized_pattern] = STATE(9109),
    [sym_attribute] = STATE(2790),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(9109),
    [sym_quoted_extension] = STATE(9109),
    [sym__constant] = STATE(9176),
    [sym__signed_constant] = STATE(9109),
    [sym_number] = STATE(9113),
    [sym_signed_number] = STATE(9176),
    [sym_character] = STATE(9113),
    [sym_string] = STATE(9113),
    [sym_quoted_string] = STATE(9113),
    [sym_boolean] = STATE(9113),
    [sym_unit] = STATE(9113),
    [sym__simple_value_pattern] = STATE(9109),
    [sym_parenthesized_operator] = STATE(9109),
    [sym_module_path] = STATE(20059),
    [sym_constructor_path] = STATE(9109),
    [sym__constructor_name] = STATE(9114),
    [sym_tag] = STATE(9109),
    [aux_sym_expression_item_repeat1] = STATE(13839),
    [aux_sym_let_binding_repeat1] = STATE(3160),
    [sym__lowercase_identifier] = ACTIONS(7557),
    [anon_sym_EQ] = ACTIONS(7559),
    [anon_sym_TILDE] = ACTIONS(7561),
    [anon_sym_QMARK] = ACTIONS(7561),
    [anon_sym_LPAREN] = ACTIONS(7563),
    [anon_sym_LBRACK] = ACTIONS(7565),
    [anon_sym_true] = ACTIONS(7567),
    [anon_sym_false] = ACTIONS(7567),
    [anon_sym_COLON2] = ACTIONS(7569),
    [anon_sym_LBRACE] = ACTIONS(7571),
    [anon_sym_constraint] = ACTIONS(7573),
    [anon_sym_val] = ACTIONS(7573),
    [anon_sym_end] = ACTIONS(7573),
    [anon_sym_inherit] = ACTIONS(7573),
    [anon_sym_method] = ACTIONS(7573),
    [anon_sym_initializer] = ACTIONS(7573),
    [anon_sym_POUND] = ACTIONS(7575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7577),
    [anon_sym_begin] = ACTIONS(7579),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7581),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7585),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7581),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7581),
    [aux_sym_number_token1] = ACTIONS(7587),
    [aux_sym_signed_number_token1] = ACTIONS(7589),
    [anon_sym_SQUOTE] = ACTIONS(7591),
    [anon_sym_DQUOTE] = ACTIONS(7593),
    [sym__uppercase_identifier] = ACTIONS(7595),
    [aux_sym_tag_token1] = ACTIONS(7597),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2791] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2791),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2792] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2792),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2793] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2793),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2794] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(12804),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2794),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7456),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2795] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(9061),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2795),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7549),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2796] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2796),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2797] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(12639),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2797),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7466),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2798] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2798),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2799] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2799),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2800] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(12639),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2800),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7466),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2801] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2801),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2802] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2802),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2803] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8899),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2803),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7537),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2804] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2804),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2805] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8899),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2805),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7537),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2806] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2806),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2807] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2807),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2808] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2808),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2809] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(12812),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2809),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7460),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2810] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8899),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2810),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7537),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2811] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2811),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2812] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8899),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2812),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7537),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2813] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8899),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2813),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7537),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2814] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2814),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2815] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2815),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2816] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2816),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2817] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2817),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2818] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2818),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2819] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2819),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2820] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2820),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2821] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2821),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2822] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2822),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2823] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8786),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2823),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7438),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2824] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2824),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2825] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8786),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2825),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7438),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2826] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8786),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2826),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7438),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2827] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8786),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2827),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7438),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2828] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8786),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2828),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7438),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2829] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2829),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2830] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2830),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2831] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(13277),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2831),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7535),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2832] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2832),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2833] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2833),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2834] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8689),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2834),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7446),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2835] = {
    [sym_parameter] = STATE(9165),
    [sym__polymorphic_typed] = STATE(13633),
    [sym__parenthesized_abstract_type] = STATE(9165),
    [sym__simple_pattern] = STATE(9167),
    [sym_typed_pattern] = STATE(9109),
    [sym_polymorphic_variant_pattern] = STATE(9109),
    [sym_record_pattern] = STATE(9109),
    [sym_list_pattern] = STATE(9109),
    [sym_array_pattern] = STATE(9109),
    [sym_local_open_pattern] = STATE(9109),
    [sym_package_pattern] = STATE(9109),
    [sym_parenthesized_pattern] = STATE(9109),
    [sym_attribute] = STATE(2835),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(9109),
    [sym_quoted_extension] = STATE(9109),
    [sym__constant] = STATE(9176),
    [sym__signed_constant] = STATE(9109),
    [sym_number] = STATE(9113),
    [sym_signed_number] = STATE(9176),
    [sym_character] = STATE(9113),
    [sym_string] = STATE(9113),
    [sym_quoted_string] = STATE(9113),
    [sym_boolean] = STATE(9113),
    [sym_unit] = STATE(9113),
    [sym__simple_value_pattern] = STATE(9109),
    [sym_parenthesized_operator] = STATE(9109),
    [sym_module_path] = STATE(20059),
    [sym_constructor_path] = STATE(9109),
    [sym__constructor_name] = STATE(9114),
    [sym_tag] = STATE(9109),
    [aux_sym_expression_item_repeat1] = STATE(13713),
    [aux_sym_let_binding_repeat1] = STATE(2947),
    [sym__lowercase_identifier] = ACTIONS(7557),
    [anon_sym_EQ] = ACTIONS(7599),
    [anon_sym_TILDE] = ACTIONS(7561),
    [anon_sym_QMARK] = ACTIONS(7561),
    [anon_sym_LPAREN] = ACTIONS(7563),
    [anon_sym_LBRACK] = ACTIONS(7565),
    [anon_sym_true] = ACTIONS(7567),
    [anon_sym_false] = ACTIONS(7567),
    [anon_sym_COLON2] = ACTIONS(7569),
    [anon_sym_LBRACE] = ACTIONS(7571),
    [anon_sym_constraint] = ACTIONS(7601),
    [anon_sym_val] = ACTIONS(7601),
    [anon_sym_end] = ACTIONS(7601),
    [anon_sym_inherit] = ACTIONS(7601),
    [anon_sym_method] = ACTIONS(7601),
    [anon_sym_initializer] = ACTIONS(7601),
    [anon_sym_POUND] = ACTIONS(7575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7577),
    [anon_sym_begin] = ACTIONS(7579),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7603),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7585),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7603),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7603),
    [aux_sym_number_token1] = ACTIONS(7587),
    [aux_sym_signed_number_token1] = ACTIONS(7589),
    [anon_sym_SQUOTE] = ACTIONS(7591),
    [anon_sym_DQUOTE] = ACTIONS(7593),
    [sym__uppercase_identifier] = ACTIONS(7595),
    [aux_sym_tag_token1] = ACTIONS(7597),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2836] = {
    [sym__match_cases] = STATE(10886),
    [sym_match_case] = STATE(12996),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2836),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7442),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2837] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8689),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2837),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7446),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2838] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8689),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2838),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7446),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2839] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2839),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2840] = {
    [sym__match_cases] = STATE(10963),
    [sym_match_case] = STATE(12996),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2840),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7442),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2841] = {
    [sym_parameter] = STATE(9165),
    [sym__polymorphic_typed] = STATE(13653),
    [sym__parenthesized_abstract_type] = STATE(9165),
    [sym__simple_pattern] = STATE(9167),
    [sym_typed_pattern] = STATE(9109),
    [sym_polymorphic_variant_pattern] = STATE(9109),
    [sym_record_pattern] = STATE(9109),
    [sym_list_pattern] = STATE(9109),
    [sym_array_pattern] = STATE(9109),
    [sym_local_open_pattern] = STATE(9109),
    [sym_package_pattern] = STATE(9109),
    [sym_parenthesized_pattern] = STATE(9109),
    [sym_attribute] = STATE(2841),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(9109),
    [sym_quoted_extension] = STATE(9109),
    [sym__constant] = STATE(9176),
    [sym__signed_constant] = STATE(9109),
    [sym_number] = STATE(9113),
    [sym_signed_number] = STATE(9176),
    [sym_character] = STATE(9113),
    [sym_string] = STATE(9113),
    [sym_quoted_string] = STATE(9113),
    [sym_boolean] = STATE(9113),
    [sym_unit] = STATE(9113),
    [sym__simple_value_pattern] = STATE(9109),
    [sym_parenthesized_operator] = STATE(9109),
    [sym_module_path] = STATE(20059),
    [sym_constructor_path] = STATE(9109),
    [sym__constructor_name] = STATE(9114),
    [sym_tag] = STATE(9109),
    [aux_sym_expression_item_repeat1] = STATE(13745),
    [aux_sym_let_binding_repeat1] = STATE(3160),
    [sym__lowercase_identifier] = ACTIONS(7557),
    [anon_sym_EQ] = ACTIONS(7605),
    [anon_sym_TILDE] = ACTIONS(7561),
    [anon_sym_QMARK] = ACTIONS(7561),
    [anon_sym_LPAREN] = ACTIONS(7563),
    [anon_sym_LBRACK] = ACTIONS(7565),
    [anon_sym_true] = ACTIONS(7567),
    [anon_sym_false] = ACTIONS(7567),
    [anon_sym_COLON2] = ACTIONS(7569),
    [anon_sym_LBRACE] = ACTIONS(7571),
    [anon_sym_constraint] = ACTIONS(7607),
    [anon_sym_val] = ACTIONS(7607),
    [anon_sym_end] = ACTIONS(7607),
    [anon_sym_inherit] = ACTIONS(7607),
    [anon_sym_method] = ACTIONS(7607),
    [anon_sym_initializer] = ACTIONS(7607),
    [anon_sym_POUND] = ACTIONS(7575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7577),
    [anon_sym_begin] = ACTIONS(7579),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7609),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7585),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7609),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7609),
    [aux_sym_number_token1] = ACTIONS(7587),
    [aux_sym_signed_number_token1] = ACTIONS(7589),
    [anon_sym_SQUOTE] = ACTIONS(7591),
    [anon_sym_DQUOTE] = ACTIONS(7593),
    [sym__uppercase_identifier] = ACTIONS(7595),
    [aux_sym_tag_token1] = ACTIONS(7597),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2842] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(13048),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2842),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7539),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2843] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8689),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2843),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7446),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2844] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8689),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2844),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7446),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2845] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(9070),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2845),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7436),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2846] = {
    [sym__match_cases] = STATE(11173),
    [sym_match_case] = STATE(12996),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2846),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7442),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2847] = {
    [sym__match_cases] = STATE(11206),
    [sym_match_case] = STATE(12996),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2847),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7442),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2848] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2848),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2849] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2849),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2850] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2850),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2851] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2851),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2852] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2852),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2853] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2853),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2854] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(9921),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2854),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7434),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2855] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2855),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2856] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2856),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2857] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2857),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2858] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2858),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2859] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2859),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2860] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2860),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2861] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2861),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2862] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8544),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2862),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7450),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2863] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2863),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2864] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2864),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2865] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8544),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2865),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7450),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2866] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(12960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2866),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7531),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2867] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(9070),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2867),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7436),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2868] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(9061),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2868),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7549),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2869] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(9070),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2869),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7436),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2870] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8544),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2870),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7450),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2871] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2871),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2872] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(13277),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2872),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7535),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2873] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2873),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2874] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8544),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2874),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7450),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2875] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(13277),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2875),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7535),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2876] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(9070),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2876),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7436),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2877] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8544),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2877),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7450),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2878] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(13277),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2878),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7535),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2879] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(13277),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2879),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7535),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2880] = {
    [sym__match_cases] = STATE(11119),
    [sym_match_case] = STATE(12647),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2880),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7525),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2881] = {
    [sym__match_cases] = STATE(10886),
    [sym_match_case] = STATE(12647),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2881),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7525),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2882] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2882),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2883] = {
    [sym__match_cases] = STATE(10963),
    [sym_match_case] = STATE(12647),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2883),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7525),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2884] = {
    [sym__match_cases] = STATE(11173),
    [sym_match_case] = STATE(12647),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2884),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7525),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2885] = {
    [sym__match_cases] = STATE(11206),
    [sym_match_case] = STATE(12647),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2885),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7525),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2886] = {
    [sym__match_cases] = STATE(11119),
    [sym_match_case] = STATE(12718),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2886),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2887] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2887),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2888] = {
    [sym__match_cases] = STATE(10886),
    [sym_match_case] = STATE(12718),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2888),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2889] = {
    [sym__match_cases] = STATE(10963),
    [sym_match_case] = STATE(12718),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2889),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2890] = {
    [sym__match_cases] = STATE(11173),
    [sym_match_case] = STATE(12718),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2890),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2891] = {
    [sym__match_cases] = STATE(11206),
    [sym_match_case] = STATE(12718),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2891),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7543),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2892] = {
    [sym__match_cases] = STATE(11119),
    [sym_match_case] = STATE(12476),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2892),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7547),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2893] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(13148),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2893),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7440),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2894] = {
    [sym__match_cases] = STATE(10886),
    [sym_match_case] = STATE(12476),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2894),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7547),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2895] = {
    [sym__match_cases] = STATE(10963),
    [sym_match_case] = STATE(12476),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2895),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7547),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2896] = {
    [sym__match_cases] = STATE(11173),
    [sym_match_case] = STATE(12476),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2896),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7547),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2897] = {
    [sym__match_cases] = STATE(11206),
    [sym_match_case] = STATE(12476),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2897),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7547),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2898] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(9061),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2898),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7549),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2899] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(9061),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2899),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7549),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2900] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8556),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2900),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7454),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2901] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8556),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2901),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7454),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2902] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8556),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2902),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7454),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2903] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8556),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2903),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7454),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2904] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(8648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2904),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7545),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2905] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(8648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2905),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7545),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2906] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8556),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2906),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7454),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2907] = {
    [sym__match_cases] = STATE(11119),
    [sym_match_case] = STATE(11619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2907),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7432),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2908] = {
    [sym__match_cases] = STATE(10886),
    [sym_match_case] = STATE(11619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2908),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7432),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2909] = {
    [sym__match_cases] = STATE(10963),
    [sym_match_case] = STATE(11619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2909),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7432),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2910] = {
    [sym__match_cases] = STATE(11173),
    [sym_match_case] = STATE(11619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2910),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7432),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2911] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(8648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2911),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7545),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2912] = {
    [sym__match_cases] = STATE(11206),
    [sym_match_case] = STATE(11619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2912),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7432),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2913] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2913),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2914] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2914),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2915] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2915),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2916] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2916),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2917] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(8648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2917),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7545),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2918] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2918),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2919] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2919),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2920] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(8648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2920),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7545),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2921] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2921),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2922] = {
    [sym__match_cases] = STATE(8560),
    [sym_match_case] = STATE(9010),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2922),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7527),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2923] = {
    [sym__match_cases] = STATE(8473),
    [sym_match_case] = STATE(9010),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2923),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7527),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2924] = {
    [sym__match_cases] = STATE(8508),
    [sym_match_case] = STATE(9010),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2924),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7527),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2925] = {
    [sym__match_cases] = STATE(8528),
    [sym_match_case] = STATE(9010),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2925),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7527),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2926] = {
    [sym__match_cases] = STATE(8543),
    [sym_match_case] = STATE(9010),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2926),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7527),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2927] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2927),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2928] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2928),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2929] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2929),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2930] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(12783),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2930),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7448),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2931] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2931),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2932] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2932),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2933] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2933),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2934] = {
    [sym_parameter] = STATE(9165),
    [sym__polymorphic_typed] = STATE(13690),
    [sym__parenthesized_abstract_type] = STATE(9165),
    [sym__simple_pattern] = STATE(9167),
    [sym_typed_pattern] = STATE(9109),
    [sym_polymorphic_variant_pattern] = STATE(9109),
    [sym_record_pattern] = STATE(9109),
    [sym_list_pattern] = STATE(9109),
    [sym_array_pattern] = STATE(9109),
    [sym_local_open_pattern] = STATE(9109),
    [sym_package_pattern] = STATE(9109),
    [sym_parenthesized_pattern] = STATE(9109),
    [sym_attribute] = STATE(2934),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(9109),
    [sym_quoted_extension] = STATE(9109),
    [sym__constant] = STATE(9176),
    [sym__signed_constant] = STATE(9109),
    [sym_number] = STATE(9113),
    [sym_signed_number] = STATE(9176),
    [sym_character] = STATE(9113),
    [sym_string] = STATE(9113),
    [sym_quoted_string] = STATE(9113),
    [sym_boolean] = STATE(9113),
    [sym_unit] = STATE(9113),
    [sym__simple_value_pattern] = STATE(9109),
    [sym_parenthesized_operator] = STATE(9109),
    [sym_module_path] = STATE(20059),
    [sym_constructor_path] = STATE(9109),
    [sym__constructor_name] = STATE(9114),
    [sym_tag] = STATE(9109),
    [aux_sym_expression_item_repeat1] = STATE(13923),
    [aux_sym_let_binding_repeat1] = STATE(2841),
    [sym__lowercase_identifier] = ACTIONS(7557),
    [anon_sym_EQ] = ACTIONS(7611),
    [anon_sym_TILDE] = ACTIONS(7561),
    [anon_sym_QMARK] = ACTIONS(7561),
    [anon_sym_LPAREN] = ACTIONS(7563),
    [anon_sym_LBRACK] = ACTIONS(7565),
    [anon_sym_true] = ACTIONS(7567),
    [anon_sym_false] = ACTIONS(7567),
    [anon_sym_COLON2] = ACTIONS(7569),
    [anon_sym_LBRACE] = ACTIONS(7571),
    [anon_sym_constraint] = ACTIONS(7613),
    [anon_sym_val] = ACTIONS(7613),
    [anon_sym_end] = ACTIONS(7613),
    [anon_sym_inherit] = ACTIONS(7613),
    [anon_sym_method] = ACTIONS(7613),
    [anon_sym_initializer] = ACTIONS(7613),
    [anon_sym_POUND] = ACTIONS(7575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7577),
    [anon_sym_begin] = ACTIONS(7579),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7615),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7585),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7615),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7615),
    [aux_sym_number_token1] = ACTIONS(7587),
    [aux_sym_signed_number_token1] = ACTIONS(7589),
    [anon_sym_SQUOTE] = ACTIONS(7591),
    [anon_sym_DQUOTE] = ACTIONS(7593),
    [sym__uppercase_identifier] = ACTIONS(7595),
    [aux_sym_tag_token1] = ACTIONS(7597),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2935] = {
    [sym__match_cases] = STATE(11119),
    [sym_match_case] = STATE(12281),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2935),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7533),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2936] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2936),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2937] = {
    [sym__match_cases] = STATE(10886),
    [sym_match_case] = STATE(12281),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2937),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7533),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2938] = {
    [sym__match_cases] = STATE(10963),
    [sym_match_case] = STATE(12281),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2938),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7533),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2939] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2939),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2940] = {
    [sym__match_cases] = STATE(11173),
    [sym_match_case] = STATE(12281),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2940),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7533),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2941] = {
    [sym__match_cases] = STATE(11206),
    [sym_match_case] = STATE(12281),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2941),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7533),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2942] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2942),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2943] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2943),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2944] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2944),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2945] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2945),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2946] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2946),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2947] = {
    [sym_parameter] = STATE(9165),
    [sym__polymorphic_typed] = STATE(13661),
    [sym__parenthesized_abstract_type] = STATE(9165),
    [sym__simple_pattern] = STATE(9167),
    [sym_typed_pattern] = STATE(9109),
    [sym_polymorphic_variant_pattern] = STATE(9109),
    [sym_record_pattern] = STATE(9109),
    [sym_list_pattern] = STATE(9109),
    [sym_array_pattern] = STATE(9109),
    [sym_local_open_pattern] = STATE(9109),
    [sym_package_pattern] = STATE(9109),
    [sym_parenthesized_pattern] = STATE(9109),
    [sym_attribute] = STATE(2947),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(9109),
    [sym_quoted_extension] = STATE(9109),
    [sym__constant] = STATE(9176),
    [sym__signed_constant] = STATE(9109),
    [sym_number] = STATE(9113),
    [sym_signed_number] = STATE(9176),
    [sym_character] = STATE(9113),
    [sym_string] = STATE(9113),
    [sym_quoted_string] = STATE(9113),
    [sym_boolean] = STATE(9113),
    [sym_unit] = STATE(9113),
    [sym__simple_value_pattern] = STATE(9109),
    [sym_parenthesized_operator] = STATE(9109),
    [sym_module_path] = STATE(20059),
    [sym_constructor_path] = STATE(9109),
    [sym__constructor_name] = STATE(9114),
    [sym_tag] = STATE(9109),
    [aux_sym_expression_item_repeat1] = STATE(13696),
    [aux_sym_let_binding_repeat1] = STATE(3160),
    [sym__lowercase_identifier] = ACTIONS(7557),
    [anon_sym_EQ] = ACTIONS(7617),
    [anon_sym_TILDE] = ACTIONS(7561),
    [anon_sym_QMARK] = ACTIONS(7561),
    [anon_sym_LPAREN] = ACTIONS(7563),
    [anon_sym_LBRACK] = ACTIONS(7565),
    [anon_sym_true] = ACTIONS(7567),
    [anon_sym_false] = ACTIONS(7567),
    [anon_sym_COLON2] = ACTIONS(7569),
    [anon_sym_LBRACE] = ACTIONS(7571),
    [anon_sym_constraint] = ACTIONS(7619),
    [anon_sym_val] = ACTIONS(7619),
    [anon_sym_end] = ACTIONS(7619),
    [anon_sym_inherit] = ACTIONS(7619),
    [anon_sym_method] = ACTIONS(7619),
    [anon_sym_initializer] = ACTIONS(7619),
    [anon_sym_POUND] = ACTIONS(7575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7577),
    [anon_sym_begin] = ACTIONS(7579),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7621),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7585),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7621),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7621),
    [aux_sym_number_token1] = ACTIONS(7587),
    [aux_sym_signed_number_token1] = ACTIONS(7589),
    [anon_sym_SQUOTE] = ACTIONS(7591),
    [anon_sym_DQUOTE] = ACTIONS(7593),
    [sym__uppercase_identifier] = ACTIONS(7595),
    [aux_sym_tag_token1] = ACTIONS(7597),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2948] = {
    [sym_parameter] = STATE(9165),
    [sym__polymorphic_typed] = STATE(13619),
    [sym__parenthesized_abstract_type] = STATE(9165),
    [sym__simple_pattern] = STATE(9167),
    [sym_typed_pattern] = STATE(9109),
    [sym_polymorphic_variant_pattern] = STATE(9109),
    [sym_record_pattern] = STATE(9109),
    [sym_list_pattern] = STATE(9109),
    [sym_array_pattern] = STATE(9109),
    [sym_local_open_pattern] = STATE(9109),
    [sym_package_pattern] = STATE(9109),
    [sym_parenthesized_pattern] = STATE(9109),
    [sym_attribute] = STATE(2948),
    [sym_item_attribute] = STATE(10536),
    [sym_extension] = STATE(9109),
    [sym_quoted_extension] = STATE(9109),
    [sym__constant] = STATE(9176),
    [sym__signed_constant] = STATE(9109),
    [sym_number] = STATE(9113),
    [sym_signed_number] = STATE(9176),
    [sym_character] = STATE(9113),
    [sym_string] = STATE(9113),
    [sym_quoted_string] = STATE(9113),
    [sym_boolean] = STATE(9113),
    [sym_unit] = STATE(9113),
    [sym__simple_value_pattern] = STATE(9109),
    [sym_parenthesized_operator] = STATE(9109),
    [sym_module_path] = STATE(20059),
    [sym_constructor_path] = STATE(9109),
    [sym__constructor_name] = STATE(9114),
    [sym_tag] = STATE(9109),
    [aux_sym_expression_item_repeat1] = STATE(13715),
    [aux_sym_let_binding_repeat1] = STATE(2790),
    [sym__lowercase_identifier] = ACTIONS(7557),
    [anon_sym_EQ] = ACTIONS(7623),
    [anon_sym_TILDE] = ACTIONS(7561),
    [anon_sym_QMARK] = ACTIONS(7561),
    [anon_sym_LPAREN] = ACTIONS(7563),
    [anon_sym_LBRACK] = ACTIONS(7565),
    [anon_sym_true] = ACTIONS(7567),
    [anon_sym_false] = ACTIONS(7567),
    [anon_sym_COLON2] = ACTIONS(7569),
    [anon_sym_LBRACE] = ACTIONS(7571),
    [anon_sym_constraint] = ACTIONS(7625),
    [anon_sym_val] = ACTIONS(7625),
    [anon_sym_end] = ACTIONS(7625),
    [anon_sym_inherit] = ACTIONS(7625),
    [anon_sym_method] = ACTIONS(7625),
    [anon_sym_initializer] = ACTIONS(7625),
    [anon_sym_POUND] = ACTIONS(7575),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7577),
    [anon_sym_begin] = ACTIONS(7579),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(6865),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(7627),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7583),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7585),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(7627),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(7627),
    [aux_sym_number_token1] = ACTIONS(7587),
    [aux_sym_signed_number_token1] = ACTIONS(7589),
    [anon_sym_SQUOTE] = ACTIONS(7591),
    [anon_sym_DQUOTE] = ACTIONS(7593),
    [sym__uppercase_identifier] = ACTIONS(7595),
    [aux_sym_tag_token1] = ACTIONS(7597),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2949] = {
    [sym__match_cases] = STATE(8182),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2949),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2950] = {
    [sym__match_cases] = STATE(8228),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2950),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2951] = {
    [sym__match_cases] = STATE(8224),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2951),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2952] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2952),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2953] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2953),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2954] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(10774),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2954),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7444),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2955] = {
    [sym__match_cases] = STATE(8472),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2955),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2956] = {
    [sym__match_cases] = STATE(8515),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2956),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2957] = {
    [sym__match_cases] = STATE(8521),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2957),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2958] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2958),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2959] = {
    [sym__match_cases] = STATE(8531),
    [sym_match_case] = STATE(11247),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2959),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7529),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2960] = {
    [sym__match_cases] = STATE(8233),
    [sym_match_case] = STATE(9960),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2960),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7428),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2961] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(13006),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2961),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7541),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2962] = {
    [sym__match_cases] = STATE(8518),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2962),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2963] = {
    [sym__match_cases] = STATE(8218),
    [sym_match_case] = STATE(12791),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2963),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PIPE] = ACTIONS(7452),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2964] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15073),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2964),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7629),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4835),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2965] = {
    [sym__signature] = STATE(19324),
    [sym_external] = STATE(13539),
    [sym_type_definition] = STATE(13539),
    [sym_exception_definition] = STATE(13539),
    [sym_module_definition] = STATE(13539),
    [sym_module_type_definition] = STATE(13539),
    [sym_open_module] = STATE(13539),
    [sym_class_definition] = STATE(13539),
    [sym_class_type_definition] = STATE(13539),
    [sym__signature_item] = STATE(13542),
    [sym_value_specification] = STATE(13539),
    [sym_include_module_type] = STATE(13539),
    [sym__simple_type] = STATE(13023),
    [sym__type] = STATE(17487),
    [sym_function_type] = STATE(8550),
    [sym_labeled_argument_type] = STATE(19510),
    [sym__proper_tuple_type] = STATE(13994),
    [sym__labeled_tuple_type] = STATE(8550),
    [sym_labeled_tuple_element_type] = STATE(18959),
    [sym_constructed_type] = STATE(13276),
    [sym_aliased_type] = STATE(8550),
    [sym_local_open_type] = STATE(13276),
    [sym_polymorphic_variant_type] = STATE(13276),
    [sym_package_type] = STATE(13276),
    [sym_object_type] = STATE(13276),
    [sym_hash_type] = STATE(13276),
    [sym_parenthesized_type] = STATE(13276),
    [sym_attribute] = STATE(2965),
    [sym_floating_attribute] = STATE(13539),
    [sym_extension] = STATE(13276),
    [sym_quoted_extension] = STATE(13276),
    [sym_item_extension] = STATE(13539),
    [sym_quoted_item_extension] = STATE(13539),
    [sym_extended_module_path] = STATE(18040),
    [sym_type_constructor_path] = STATE(13276),
    [sym_type_variable] = STATE(13276),
    [aux_sym__structure_repeat1] = STATE(9319),
    [aux_sym__signature_repeat1] = STATE(9283),
    [sym__lowercase_identifier] = ACTIONS(7631),
    [anon_sym_SEMI_SEMI] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(7633),
    [anon_sym_LPAREN] = ACTIONS(7635),
    [anon_sym_external] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(7637),
    [anon_sym_LBRACK] = ACTIONS(7639),
    [anon_sym_RBRACK] = ACTIONS(7641),
    [anon_sym_exception] = ACTIONS(7643),
    [anon_sym_module] = ACTIONS(7645),
    [anon_sym_open] = ACTIONS(7647),
    [anon_sym_include] = ACTIONS(7649),
    [anon_sym_class] = ACTIONS(7651),
    [anon_sym_val] = ACTIONS(7653),
    [anon_sym_LBRACK_GT] = ACTIONS(7655),
    [anon_sym_LBRACK_LT] = ACTIONS(7657),
    [anon_sym_LT] = ACTIONS(7659),
    [anon_sym_POUND] = ACTIONS(7661),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT_AT] = ACTIONS(27),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7663),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7665),
    [anon_sym_LBRACK_PERCENT_PERCENT] = ACTIONS(29),
    [anon_sym_LBRACE_PERCENT_PERCENT] = ACTIONS(31),
    [sym__uppercase_identifier] = ACTIONS(7667),
    [aux_sym_type_variable_token1] = ACTIONS(7669),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2966] = {
    [sym__parenthesized_abstract_type] = STATE(4512),
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14045),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2966),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7553),
    [anon_sym_RPAREN] = ACTIONS(4667),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2967] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15171),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2967),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7671),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4869),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2968] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14063),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(18535),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(2968),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(14597),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2771),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(2968),
    [sym__lowercase_identifier] = ACTIONS(7551),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_RBRACK] = ACTIONS(4667),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(4667),
    [anon_sym_RBRACE] = ACTIONS(4667),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(7555),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2969] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14986),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(2969),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__attribute] = STATE(3116),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2970] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15076),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2970),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7673),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4889),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2971] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15035),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2971),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7675),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(5005),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2972] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15174),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2972),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(5253),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2973] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15039),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2973),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7679),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2974] = {
    [sym_parameter] = STATE(10790),
    [sym__polymorphic_typed] = STATE(17196),
    [sym__parenthesized_abstract_type] = STATE(10790),
    [sym__simple_pattern] = STATE(10586),
    [sym_typed_pattern] = STATE(10736),
    [sym_polymorphic_variant_pattern] = STATE(10736),
    [sym_record_pattern] = STATE(10736),
    [sym_list_pattern] = STATE(10736),
    [sym_array_pattern] = STATE(10736),
    [sym_local_open_pattern] = STATE(10736),
    [sym_package_pattern] = STATE(10736),
    [sym_parenthesized_pattern] = STATE(10736),
    [sym_attribute] = STATE(2974),
    [sym_item_attribute] = STATE(15472),
    [sym_extension] = STATE(10736),
    [sym_quoted_extension] = STATE(10736),
    [sym__constant] = STATE(10744),
    [sym__signed_constant] = STATE(10736),
    [sym_number] = STATE(10787),
    [sym_signed_number] = STATE(10744),
    [sym_character] = STATE(10787),
    [sym_string] = STATE(10787),
    [sym_quoted_string] = STATE(10787),
    [sym_boolean] = STATE(10787),
    [sym_unit] = STATE(10787),
    [sym__simple_value_pattern] = STATE(10736),
    [sym_parenthesized_operator] = STATE(10736),
    [sym_module_path] = STATE(19549),
    [sym_constructor_path] = STATE(10736),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(10736),
    [aux_sym_expression_item_repeat1] = STATE(14970),
    [aux_sym_let_binding_repeat1] = STATE(4787),
    [sym__lowercase_identifier] = ACTIONS(5395),
    [anon_sym_and] = ACTIONS(5399),
    [anon_sym_COLON_GT] = ACTIONS(7681),
    [anon_sym_EQ] = ACTIONS(7683),
    [anon_sym_TILDE] = ACTIONS(5405),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_LPAREN] = ACTIONS(5407),
    [anon_sym_COMMA] = ACTIONS(7685),
    [anon_sym_PIPE] = ACTIONS(7687),
    [anon_sym_LBRACK] = ACTIONS(5413),
    [anon_sym_true] = ACTIONS(5415),
    [anon_sym_false] = ACTIONS(5415),
    [anon_sym_COLON2] = ACTIONS(5417),
    [anon_sym_LBRACE] = ACTIONS(5419),
    [anon_sym_in] = ACTIONS(5399),
    [anon_sym_as] = ACTIONS(7689),
    [anon_sym_POUND] = ACTIONS(5423),
    [anon_sym_COLON_COLON] = ACTIONS(7691),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5427),
    [anon_sym_begin] = ACTIONS(5429),
    [aux_sym_attribute_token1] = ACTIONS(3),
    [anon_sym_LBRACK_AT_AT] = ACTIONS(7693),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7695),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7697),
    [aux_sym_number_token1] = ACTIONS(5437),
    [aux_sym_signed_number_token1] = ACTIONS(5439),
    [anon_sym_SQUOTE] = ACTIONS(5441),
    [anon_sym_DQUOTE] = ACTIONS(5443),
    [sym_let_and_operator] = ACTIONS(5397),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2975] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2975),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(3151),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2976] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15090),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2976),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7699),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4879),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2977] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15171),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2977),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7671),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(5251),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2978] = {
    [sym__parenthesized_abstract_type] = STATE(4690),
    [sym__simple_binding_pattern] = STATE(14873),
    [sym__binding_pattern] = STATE(14933),
    [sym_alias_binding_pattern] = STATE(14873),
    [sym_typed_binding_pattern] = STATE(14943),
    [sym__or_binding_pattern_anonymous] = STATE(14637),
    [sym_constructor_binding_pattern] = STATE(14873),
    [sym_tag_binding_pattern] = STATE(14873),
    [sym_polymorphic_variant_pattern] = STATE(14943),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19116),
    [sym__tuple_binding_pattern] = STATE(14741),
    [sym_record_binding_pattern] = STATE(14749),
    [sym_list_binding_pattern] = STATE(14839),
    [sym_cons_binding_pattern] = STATE(14873),
    [sym_array_binding_pattern] = STATE(14885),
    [sym_range_pattern] = STATE(14873),
    [sym_lazy_binding_pattern] = STATE(14873),
    [sym_local_open_binding_pattern] = STATE(14943),
    [sym_package_pattern] = STATE(14943),
    [sym_parenthesized_binding_pattern] = STATE(14943),
    [sym_attribute] = STATE(2978),
    [sym_extension] = STATE(14943),
    [sym_quoted_extension] = STATE(14943),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14358),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__value_name] = STATE(14943),
    [sym_parenthesized_operator] = STATE(14939),
    [sym_module_path] = STATE(18536),
    [sym_constructor_path] = STATE(2978),
    [sym__constructor_name] = STATE(8492),
    [sym_tag] = STATE(3026),
    [sym__lowercase_identifier] = ACTIONS(7701),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7703),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4669),
    [anon_sym_LBRACK] = ACTIONS(7705),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7707),
    [anon_sym_SEMI] = ACTIONS(4667),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7709),
    [anon_sym_PIPE_RBRACK] = ACTIONS(4667),
    [anon_sym_lazy] = ACTIONS(7711),
    [anon_sym_begin] = ACTIONS(7288),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7713),
    [aux_sym_tag_token1] = ACTIONS(7715),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2979] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14517),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2979),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(3124),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2980] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14640),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(2980),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__attribute] = STATE(3117),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2981] = {
    [sym__parenthesized_abstract_type] = STATE(3152),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15561),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2981),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(6791),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2982] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(13878),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2982),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(3125),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2983] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15174),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2983),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2984] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14023),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2984),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(3141),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2985] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15174),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2985),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7677),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(1427),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2986] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(13878),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2986),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__attribute] = STATE(3143),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [anon_sym_PERCENT] = ACTIONS(7430),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2987] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15190),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2987),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_RPAREN] = ACTIONS(7717),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4899),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2988] = {
    [sym_match_case] = STATE(8790),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2988),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2989] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2989),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2990] = {
    [sym_match_case] = STATE(12282),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2990),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2991] = {
    [sym_match_case] = STATE(10888),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2991),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2992] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14427),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(2992),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7719),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2993] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2993),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7721),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2994] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2994),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2995] = {
    [sym_match_case] = STATE(8910),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2995),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2996] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(2996),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7723),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2997] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2997),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2998] = {
    [sym_match_case] = STATE(11124),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14328),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2998),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [2999] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(2999),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7725),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3000] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3000),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7727),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3001] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14457),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3001),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3002] = {
    [sym_match_case] = STATE(13007),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3002),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3003] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3003),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3004] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3004),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7729),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3005] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3005),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7731),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3006] = {
    [sym_match_case] = STATE(12719),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3006),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3007] = {
    [sym__simple_expression] = STATE(9543),
    [sym_typed_expression] = STATE(9642),
    [sym_list_expression] = STATE(9642),
    [sym_array_expression] = STATE(9642),
    [sym_record_expression] = STATE(9642),
    [sym_labeled_argument] = STATE(10439),
    [sym_prefix_expression] = STATE(9642),
    [sym_hash_expression] = STATE(9642),
    [sym_field_get_expression] = STATE(9642),
    [sym_array_get_expression] = STATE(9642),
    [sym_string_get_expression] = STATE(9642),
    [sym_bigarray_get_expression] = STATE(9642),
    [sym_coercion_expression] = STATE(9642),
    [sym_local_open_expression] = STATE(9642),
    [sym_package_expression] = STATE(9642),
    [sym_new_expression] = STATE(9642),
    [sym_object_copy_expression] = STATE(9642),
    [sym_method_invocation] = STATE(9642),
    [sym_object_expression] = STATE(9642),
    [sym_parenthesized_expression] = STATE(9642),
    [sym_attribute] = STATE(3007),
    [sym_extension] = STATE(9642),
    [sym_quoted_extension] = STATE(9642),
    [sym__constant] = STATE(9642),
    [sym_number] = STATE(9639),
    [sym_character] = STATE(9639),
    [sym_string] = STATE(9639),
    [sym_quoted_string] = STATE(9639),
    [sym_boolean] = STATE(9639),
    [sym_unit] = STATE(9639),
    [sym__value_name] = STATE(9709),
    [sym_parenthesized_operator] = STATE(9491),
    [sym_value_path] = STATE(9642),
    [sym_module_path] = STATE(18781),
    [sym_constructor_path] = STATE(9642),
    [sym__constructor_name] = STATE(8492),
    [sym_tag] = STATE(9642),
    [aux_sym_class_application_repeat1] = STATE(3007),
    [sym__lowercase_identifier] = ACTIONS(7733),
    [anon_sym_TILDE] = ACTIONS(7736),
    [anon_sym_QMARK] = ACTIONS(7736),
    [anon_sym_LPAREN] = ACTIONS(7739),
    [anon_sym_RPAREN] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(7742),
    [anon_sym_true] = ACTIONS(7745),
    [anon_sym_false] = ACTIONS(7745),
    [anon_sym_COLON2] = ACTIONS(3790),
    [anon_sym_LBRACE] = ACTIONS(7748),
    [anon_sym_object] = ACTIONS(7751),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7754),
    [anon_sym_new] = ACTIONS(7757),
    [anon_sym_LBRACE_LT] = ACTIONS(7760),
    [anon_sym_begin] = ACTIONS(7763),
    [sym_ocamlyacc_value] = ACTIONS(7766),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7769),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7772),
    [aux_sym_number_token1] = ACTIONS(7775),
    [anon_sym_SQUOTE] = ACTIONS(7778),
    [anon_sym_DQUOTE] = ACTIONS(7781),
    [sym_prefix_operator] = ACTIONS(7784),
    [sym__uppercase_identifier] = ACTIONS(7787),
    [aux_sym_tag_token1] = ACTIONS(7790),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3008] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3008),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7793),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3009] = {
    [sym_match_case] = STATE(8649),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3009),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3010] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3010),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7795),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3011] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3011),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7797),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3012] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3012),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7799),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3013] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14483),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3013),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7801),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3014] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3014),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7803),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3015] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3015),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3016] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3016),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7805),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3017] = {
    [sym_match_case] = STATE(13049),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14589),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3017),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3018] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3018),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7807),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3019] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14305),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3019),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3020] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3020),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7809),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3021] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3021),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3022] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14460),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3022),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7811),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3023] = {
    [sym_match_case] = STATE(12477),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3023),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3024] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14477),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3024),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7813),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3025] = {
    [sym_match_case] = STATE(13156),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3025),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3026] = {
    [sym__simple_binding_pattern] = STATE(14873),
    [sym__binding_pattern] = STATE(14936),
    [sym_alias_binding_pattern] = STATE(14873),
    [sym_typed_binding_pattern] = STATE(14943),
    [sym__or_binding_pattern_anonymous] = STATE(14637),
    [sym_constructor_binding_pattern] = STATE(14873),
    [sym_tag_binding_pattern] = STATE(14873),
    [sym_polymorphic_variant_pattern] = STATE(14943),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19116),
    [sym__tuple_binding_pattern] = STATE(14741),
    [sym_record_binding_pattern] = STATE(14749),
    [sym_list_binding_pattern] = STATE(14839),
    [sym_cons_binding_pattern] = STATE(14873),
    [sym_array_binding_pattern] = STATE(14885),
    [sym_range_pattern] = STATE(14873),
    [sym_lazy_binding_pattern] = STATE(14873),
    [sym_local_open_binding_pattern] = STATE(14943),
    [sym_package_pattern] = STATE(14943),
    [sym_parenthesized_binding_pattern] = STATE(14943),
    [sym_attribute] = STATE(3026),
    [sym_extension] = STATE(14943),
    [sym_quoted_extension] = STATE(14943),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14358),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__value_name] = STATE(14943),
    [sym_parenthesized_operator] = STATE(14939),
    [sym_module_path] = STATE(18536),
    [sym_constructor_path] = STATE(2978),
    [sym__constructor_name] = STATE(8492),
    [sym_tag] = STATE(3026),
    [sym__lowercase_identifier] = ACTIONS(7701),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7815),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4669),
    [anon_sym_LBRACK] = ACTIONS(7705),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7707),
    [anon_sym_SEMI] = ACTIONS(4667),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7709),
    [anon_sym_PIPE_RBRACK] = ACTIONS(4667),
    [anon_sym_lazy] = ACTIONS(7711),
    [anon_sym_begin] = ACTIONS(7288),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7713),
    [aux_sym_tag_token1] = ACTIONS(7715),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3027] = {
    [sym_match_case] = STATE(9013),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3027),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3028] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14317),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3028),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3029] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3029),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7817),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3030] = {
    [sym__simple_expression] = STATE(9543),
    [sym_typed_expression] = STATE(9642),
    [sym_list_expression] = STATE(9642),
    [sym_array_expression] = STATE(9642),
    [sym_record_expression] = STATE(9642),
    [sym_labeled_argument] = STATE(10439),
    [sym_prefix_expression] = STATE(9642),
    [sym_hash_expression] = STATE(9642),
    [sym_field_get_expression] = STATE(9642),
    [sym_array_get_expression] = STATE(9642),
    [sym_string_get_expression] = STATE(9642),
    [sym_bigarray_get_expression] = STATE(9642),
    [sym_coercion_expression] = STATE(9642),
    [sym_local_open_expression] = STATE(9642),
    [sym_package_expression] = STATE(9642),
    [sym_new_expression] = STATE(9642),
    [sym_object_copy_expression] = STATE(9642),
    [sym_method_invocation] = STATE(9642),
    [sym_object_expression] = STATE(9642),
    [sym_parenthesized_expression] = STATE(9642),
    [sym_attribute] = STATE(3030),
    [sym_extension] = STATE(9642),
    [sym_quoted_extension] = STATE(9642),
    [sym__constant] = STATE(9642),
    [sym_number] = STATE(9639),
    [sym_character] = STATE(9639),
    [sym_string] = STATE(9639),
    [sym_quoted_string] = STATE(9639),
    [sym_boolean] = STATE(9639),
    [sym_unit] = STATE(9639),
    [sym__value_name] = STATE(9709),
    [sym_parenthesized_operator] = STATE(9491),
    [sym_value_path] = STATE(9642),
    [sym_module_path] = STATE(18781),
    [sym_constructor_path] = STATE(9642),
    [sym__constructor_name] = STATE(8492),
    [sym_tag] = STATE(9642),
    [aux_sym_class_application_repeat1] = STATE(3080),
    [sym__lowercase_identifier] = ACTIONS(7819),
    [anon_sym_TILDE] = ACTIONS(7821),
    [anon_sym_QMARK] = ACTIONS(7821),
    [anon_sym_LPAREN] = ACTIONS(7823),
    [anon_sym_RPAREN] = ACTIONS(5813),
    [anon_sym_LBRACK] = ACTIONS(7825),
    [anon_sym_true] = ACTIONS(7827),
    [anon_sym_false] = ACTIONS(7827),
    [anon_sym_COLON2] = ACTIONS(5813),
    [anon_sym_LBRACE] = ACTIONS(7829),
    [anon_sym_object] = ACTIONS(7831),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7833),
    [anon_sym_new] = ACTIONS(7835),
    [anon_sym_LBRACE_LT] = ACTIONS(7837),
    [anon_sym_begin] = ACTIONS(7839),
    [sym_ocamlyacc_value] = ACTIONS(7841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7845),
    [aux_sym_number_token1] = ACTIONS(7847),
    [anon_sym_SQUOTE] = ACTIONS(7849),
    [anon_sym_DQUOTE] = ACTIONS(7851),
    [sym_prefix_operator] = ACTIONS(7853),
    [sym__uppercase_identifier] = ACTIONS(7713),
    [aux_sym_tag_token1] = ACTIONS(7715),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3031] = {
    [sym_match_case] = STATE(10888),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3031),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3032] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3032),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7855),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3033] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3033),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3034] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3034),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3035] = {
    [sym_match_case] = STATE(9961),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3035),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3036] = {
    [sym_match_case] = STATE(12641),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3036),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3037] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3037),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3038] = {
    [sym_match_case] = STATE(11620),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3038),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3039] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3039),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7857),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3040] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14450),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3040),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7859),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3041] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3041),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7861),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3042] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14525),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3042),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7863),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3043] = {
    [sym_match_case] = STATE(9069),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14611),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3043),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3044] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3044),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7865),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3045] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14346),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3045),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7867),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3046] = {
    [sym_match_case] = STATE(12648),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14364),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3046),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3047] = {
    [sym_match_case] = STATE(8619),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14357),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3047),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3048] = {
    [sym_match_case] = STATE(13278),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14522),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3048),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3049] = {
    [sym_match_case] = STATE(13072),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3049),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3050] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14452),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3050),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3051] = {
    [sym__simple_binding_pattern] = STATE(14219),
    [sym__binding_pattern] = STATE(14063),
    [sym_alias_binding_pattern] = STATE(14219),
    [sym_typed_binding_pattern] = STATE(14134),
    [sym__or_binding_pattern_anonymous] = STATE(14170),
    [sym_constructor_binding_pattern] = STATE(14219),
    [sym_tag_binding_pattern] = STATE(14219),
    [sym_polymorphic_variant_pattern] = STATE(14134),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19588),
    [sym__tuple_binding_pattern] = STATE(14039),
    [sym_record_binding_pattern] = STATE(14065),
    [sym_list_binding_pattern] = STATE(14097),
    [sym_cons_binding_pattern] = STATE(14219),
    [sym_array_binding_pattern] = STATE(14126),
    [sym_range_pattern] = STATE(14219),
    [sym_lazy_binding_pattern] = STATE(14219),
    [sym_local_open_binding_pattern] = STATE(14134),
    [sym_package_pattern] = STATE(14134),
    [sym_parenthesized_binding_pattern] = STATE(14134),
    [sym_attribute] = STATE(3051),
    [sym_extension] = STATE(14134),
    [sym_quoted_extension] = STATE(14134),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(14007),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__value_name] = STATE(14134),
    [sym_parenthesized_operator] = STATE(10894),
    [sym_module_path] = STATE(19608),
    [sym_constructor_path] = STATE(2966),
    [sym__constructor_name] = STATE(8963),
    [sym_tag] = STATE(3051),
    [sym__lowercase_identifier] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(4667),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_PIPE] = ACTIONS(4667),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_COLON2] = ACTIONS(4669),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_as] = ACTIONS(4669),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_LBRACK_PIPE] = ACTIONS(5467),
    [anon_sym_lazy] = ACTIONS(5469),
    [anon_sym_begin] = ACTIONS(4841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(5445),
    [aux_sym_tag_token1] = ACTIONS(5447),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3052] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3052),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7869),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3053] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3053),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3054] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14360),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3054),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7871),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3055] = {
    [sym_match_case] = STATE(10888),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14349),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3055),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3056] = {
    [sym_match_case] = STATE(10775),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3056),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3057] = {
    [sym_match_case] = STATE(10888),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14510),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3057),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3058] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3058),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7873),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3059] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14581),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3059),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7875),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3060] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3060),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7877),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3061] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3061),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7879),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3062] = {
    [sym_let_binding] = STATE(15440),
    [sym_open_module] = STATE(21161),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(3062),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3063] = {
    [sym_match_case] = STATE(8698),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3063),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3064] = {
    [sym_let_binding] = STATE(15440),
    [sym_open_module] = STATE(18685),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(3064),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3065] = {
    [sym_let_binding] = STATE(15440),
    [sym_open_module] = STATE(20093),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(3065),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3066] = {
    [sym_let_binding] = STATE(15440),
    [sym_open_module] = STATE(18745),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(3066),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3067] = {
    [sym_match_case] = STATE(12784),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14311),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3067),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3068] = {
    [sym_let_binding] = STATE(15440),
    [sym_open_module] = STATE(19262),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(3068),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3069] = {
    [sym_let_binding] = STATE(15440),
    [sym_open_module] = STATE(19664),
    [sym__simple_binding_pattern] = STATE(9220),
    [sym__binding_pattern] = STATE(2974),
    [sym_alias_binding_pattern] = STATE(9220),
    [sym_typed_binding_pattern] = STATE(9226),
    [sym__or_binding_pattern_anonymous] = STATE(9227),
    [sym_constructor_binding_pattern] = STATE(9220),
    [sym_tag_binding_pattern] = STATE(9220),
    [sym_polymorphic_variant_pattern] = STATE(9226),
    [sym_labeled_tuple_element_binding_pattern] = STATE(19515),
    [sym__tuple_binding_pattern] = STATE(9228),
    [sym_record_binding_pattern] = STATE(9231),
    [sym_list_binding_pattern] = STATE(9234),
    [sym_cons_binding_pattern] = STATE(9220),
    [sym_array_binding_pattern] = STATE(9239),
    [sym_range_pattern] = STATE(9220),
    [sym_lazy_binding_pattern] = STATE(9220),
    [sym_local_open_binding_pattern] = STATE(9226),
    [sym_package_pattern] = STATE(9226),
    [sym_parenthesized_binding_pattern] = STATE(9226),
    [sym_attribute] = STATE(3069),
    [sym_extension] = STATE(9226),
    [sym_quoted_extension] = STATE(9226),
    [sym__attribute] = STATE(4023),
    [sym__constant] = STATE(9071),
    [sym__signed_constant] = STATE(9161),
    [sym_number] = STATE(9062),
    [sym_signed_number] = STATE(9071),
    [sym_character] = STATE(9062),
    [sym_string] = STATE(9062),
    [sym_quoted_string] = STATE(9062),
    [sym_boolean] = STATE(9062),
    [sym_unit] = STATE(9062),
    [sym__value_name] = STATE(9226),
    [sym_parenthesized_operator] = STATE(9221),
    [sym_module_path] = STATE(19117),
    [sym_constructor_path] = STATE(2625),
    [sym__constructor_name] = STATE(9064),
    [sym_tag] = STATE(2638),
    [sym__lowercase_identifier] = ACTIONS(7109),
    [anon_sym_rec] = ACTIONS(7412),
    [anon_sym_TILDE] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(7268),
    [anon_sym_LBRACK] = ACTIONS(7113),
    [anon_sym_true] = ACTIONS(7115),
    [anon_sym_false] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7117),
    [anon_sym_open] = ACTIONS(7418),
    [anon_sym_POUND] = ACTIONS(7119),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7121),
    [anon_sym_lazy] = ACTIONS(7123),
    [anon_sym_begin] = ACTIONS(7125),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7127),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7129),
    [anon_sym_PERCENT] = ACTIONS(7420),
    [aux_sym_number_token1] = ACTIONS(7131),
    [aux_sym_signed_number_token1] = ACTIONS(7133),
    [anon_sym_SQUOTE] = ACTIONS(7135),
    [anon_sym_DQUOTE] = ACTIONS(7137),
    [sym__uppercase_identifier] = ACTIONS(7139),
    [aux_sym_tag_token1] = ACTIONS(7141),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3070] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3070),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3071] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3071),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7881),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3072] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14519),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3072),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3073] = {
    [sym_match_case] = STATE(10888),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14534),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3073),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3074] = {
    [sym_match_case] = STATE(8548),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14614),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3074),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3075] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14582),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3075),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7883),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3076] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14504),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3076),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7885),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3077] = {
    [sym_match_case] = STATE(12792),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14542),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3077),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3078] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3078),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7887),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3079] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3079),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3080] = {
    [sym__simple_expression] = STATE(9543),
    [sym_typed_expression] = STATE(9642),
    [sym_list_expression] = STATE(9642),
    [sym_array_expression] = STATE(9642),
    [sym_record_expression] = STATE(9642),
    [sym_labeled_argument] = STATE(10439),
    [sym_prefix_expression] = STATE(9642),
    [sym_hash_expression] = STATE(9642),
    [sym_field_get_expression] = STATE(9642),
    [sym_array_get_expression] = STATE(9642),
    [sym_string_get_expression] = STATE(9642),
    [sym_bigarray_get_expression] = STATE(9642),
    [sym_coercion_expression] = STATE(9642),
    [sym_local_open_expression] = STATE(9642),
    [sym_package_expression] = STATE(9642),
    [sym_new_expression] = STATE(9642),
    [sym_object_copy_expression] = STATE(9642),
    [sym_method_invocation] = STATE(9642),
    [sym_object_expression] = STATE(9642),
    [sym_parenthesized_expression] = STATE(9642),
    [sym_attribute] = STATE(3080),
    [sym_extension] = STATE(9642),
    [sym_quoted_extension] = STATE(9642),
    [sym__constant] = STATE(9642),
    [sym_number] = STATE(9639),
    [sym_character] = STATE(9639),
    [sym_string] = STATE(9639),
    [sym_quoted_string] = STATE(9639),
    [sym_boolean] = STATE(9639),
    [sym_unit] = STATE(9639),
    [sym__value_name] = STATE(9709),
    [sym_parenthesized_operator] = STATE(9491),
    [sym_value_path] = STATE(9642),
    [sym_module_path] = STATE(18781),
    [sym_constructor_path] = STATE(9642),
    [sym__constructor_name] = STATE(8492),
    [sym_tag] = STATE(9642),
    [aux_sym_class_application_repeat1] = STATE(3007),
    [sym__lowercase_identifier] = ACTIONS(7819),
    [anon_sym_TILDE] = ACTIONS(7821),
    [anon_sym_QMARK] = ACTIONS(7821),
    [anon_sym_LPAREN] = ACTIONS(7823),
    [anon_sym_RPAREN] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(7825),
    [anon_sym_true] = ACTIONS(7827),
    [anon_sym_false] = ACTIONS(7827),
    [anon_sym_COLON2] = ACTIONS(5697),
    [anon_sym_LBRACE] = ACTIONS(7829),
    [anon_sym_object] = ACTIONS(7831),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7833),
    [anon_sym_new] = ACTIONS(7835),
    [anon_sym_LBRACE_LT] = ACTIONS(7837),
    [anon_sym_begin] = ACTIONS(7839),
    [sym_ocamlyacc_value] = ACTIONS(7841),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7843),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7845),
    [aux_sym_number_token1] = ACTIONS(7847),
    [anon_sym_SQUOTE] = ACTIONS(7849),
    [anon_sym_DQUOTE] = ACTIONS(7851),
    [sym_prefix_operator] = ACTIONS(7853),
    [sym__uppercase_identifier] = ACTIONS(7713),
    [aux_sym_tag_token1] = ACTIONS(7715),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3081] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3081),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7889),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3082] = {
    [sym_match_case] = STATE(12983),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14505),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3082),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3083] = {
    [sym_match_case] = STATE(8565),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14310),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3083),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3084] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14579),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3084),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3085] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(15564),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3085),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_COMMA] = ACTIONS(6787),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3086] = {
    [sym_match_case] = STATE(12805),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14316),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3086),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3087] = {
    [sym_match_case] = STATE(10888),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14529),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3087),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3088] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14338),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3088),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7891),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3089] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3089),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7893),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3090] = {
    [sym_match_case] = STATE(8599),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14409),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3090),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3091] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3091),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7895),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3092] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3092),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7897),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3093] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3093),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7899),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3094] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14331),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3094),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3095] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14587),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3095),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3096] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14426),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3096),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7901),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3097] = {
    [sym_match_case] = STATE(12961),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3097),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3098] = {
    [sym_match_case] = STATE(9162),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3098),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3099] = {
    [sym_match_case] = STATE(12813),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14391),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3099),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3100] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14613),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3100),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3101] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14340),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3101),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7903),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3102] = {
    [sym_match_case] = STATE(8611),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3102),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3103] = {
    [sym_match_case] = STATE(13072),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14540),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3103),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3104] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14476),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3104),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7905),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3105] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14459),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3105),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3106] = {
    [sym_match_case] = STATE(9922),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14548),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3106),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3107] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14478),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3107),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7907),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3108] = {
    [sym_match_case] = STATE(8454),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14521),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3108),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3109] = {
    [sym__simple_pattern] = STATE(14748),
    [sym__effect_pattern] = STATE(14761),
    [sym__pattern] = STATE(14801),
    [sym_alias_pattern] = STATE(14761),
    [sym_typed_pattern] = STATE(14731),
    [sym__or_pattern_anonymous] = STATE(14762),
    [sym_constructor_pattern] = STATE(14748),
    [sym_tag_pattern] = STATE(14748),
    [sym_polymorphic_variant_pattern] = STATE(14731),
    [sym_labeled_tuple_element_pattern] = STATE(20865),
    [sym__tuple_pattern] = STATE(14765),
    [sym_record_pattern] = STATE(14731),
    [sym_list_pattern] = STATE(14731),
    [sym_cons_pattern] = STATE(14761),
    [sym_array_pattern] = STATE(14731),
    [sym_range_pattern] = STATE(14761),
    [sym_lazy_pattern] = STATE(14748),
    [sym_local_open_pattern] = STATE(14731),
    [sym_package_pattern] = STATE(14731),
    [sym_parenthesized_pattern] = STATE(14731),
    [sym_exception_pattern] = STATE(14761),
    [sym_effect_pattern] = STATE(14761),
    [sym_attribute] = STATE(3109),
    [sym_extension] = STATE(14731),
    [sym_quoted_extension] = STATE(14731),
    [sym__constant] = STATE(14412),
    [sym__signed_constant] = STATE(14523),
    [sym_number] = STATE(14575),
    [sym_signed_number] = STATE(14412),
    [sym_character] = STATE(14575),
    [sym_string] = STATE(14575),
    [sym_quoted_string] = STATE(14575),
    [sym_boolean] = STATE(14575),
    [sym_unit] = STATE(14575),
    [sym__simple_value_pattern] = STATE(14731),
    [sym_parenthesized_operator] = STATE(14731),
    [sym_module_path] = STATE(18530),
    [sym_constructor_path] = STATE(2640),
    [sym__constructor_name] = STATE(9503),
    [sym_tag] = STATE(2642),
    [sym__lowercase_identifier] = ACTIONS(7270),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(7359),
    [anon_sym_LBRACK] = ACTIONS(7274),
    [anon_sym_true] = ACTIONS(7276),
    [anon_sym_false] = ACTIONS(7276),
    [anon_sym_LBRACE] = ACTIONS(7278),
    [anon_sym_exception] = ACTIONS(7280),
    [anon_sym_POUND] = ACTIONS(7282),
    [anon_sym_LBRACK_PIPE] = ACTIONS(7284),
    [anon_sym_PIPE_RBRACK] = ACTIONS(7909),
    [anon_sym_lazy] = ACTIONS(7286),
    [anon_sym_begin] = ACTIONS(7288),
    [anon_sym_effect] = ACTIONS(7290),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7292),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7294),
    [aux_sym_number_token1] = ACTIONS(7296),
    [aux_sym_signed_number_token1] = ACTIONS(7298),
    [anon_sym_SQUOTE] = ACTIONS(7300),
    [anon_sym_DQUOTE] = ACTIONS(7302),
    [sym__uppercase_identifier] = ACTIONS(7304),
    [aux_sym_tag_token1] = ACTIONS(7306),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3110] = {
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14872),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20112),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3110),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2630),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2639),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_RBRACK] = ACTIONS(7911),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(7187),
    [anon_sym_POUND] = ACTIONS(7189),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(7191),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(7193),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(7195),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(7197),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
  [3111] = {
    [sym_match_case] = STATE(8474),
    [sym__simple_pattern] = STATE(13851),
    [sym__effect_pattern] = STATE(13853),
    [sym__pattern] = STATE(14468),
    [sym_alias_pattern] = STATE(13853),
    [sym_typed_pattern] = STATE(13858),
    [sym__or_pattern_anonymous] = STATE(13861),
    [sym_constructor_pattern] = STATE(13851),
    [sym_tag_pattern] = STATE(13851),
    [sym_polymorphic_variant_pattern] = STATE(13858),
    [sym_labeled_tuple_element_pattern] = STATE(20737),
    [sym__tuple_pattern] = STATE(13866),
    [sym_record_pattern] = STATE(13858),
    [sym_list_pattern] = STATE(13858),
    [sym_cons_pattern] = STATE(13853),
    [sym_array_pattern] = STATE(13858),
    [sym_range_pattern] = STATE(13853),
    [sym_lazy_pattern] = STATE(13851),
    [sym_local_open_pattern] = STATE(13858),
    [sym_package_pattern] = STATE(13858),
    [sym_parenthesized_pattern] = STATE(13858),
    [sym_exception_pattern] = STATE(13853),
    [sym_effect_pattern] = STATE(13853),
    [sym_attribute] = STATE(3111),
    [sym_extension] = STATE(13858),
    [sym_quoted_extension] = STATE(13858),
    [sym__constant] = STATE(13682),
    [sym__signed_constant] = STATE(13672),
    [sym_number] = STATE(12638),
    [sym_signed_number] = STATE(13682),
    [sym_character] = STATE(12638),
    [sym_string] = STATE(12638),
    [sym_quoted_string] = STATE(12638),
    [sym_boolean] = STATE(12638),
    [sym_unit] = STATE(12638),
    [sym__simple_value_pattern] = STATE(13858),
    [sym_parenthesized_operator] = STATE(13858),
    [sym_module_path] = STATE(20846),
    [sym_constructor_path] = STATE(2590),
    [sym__constructor_name] = STATE(8763),
    [sym_tag] = STATE(2614),
    [sym__lowercase_identifier] = ACTIONS(4811),
    [anon_sym_TILDE] = ACTIONS(6789),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_LBRACK] = ACTIONS(4821),
    [anon_sym_true] = ACTIONS(4823),
    [anon_sym_false] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_exception] = ACTIONS(4829),
    [anon_sym_POUND] = ACTIONS(6795),
    [anon_sym_LBRACK_PIPE] = ACTIONS(4837),
    [anon_sym_lazy] = ACTIONS(4839),
    [anon_sym_begin] = ACTIONS(4841),
    [anon_sym_effect] = ACTIONS(4843),
    [aux_sym_attribute_token1] = ACTIONS(1097),
    [anon_sym_LBRACK_PERCENT] = ACTIONS(4845),
    [anon_sym_LBRACE_PERCENT] = ACTIONS(4847),
    [aux_sym_number_token1] = ACTIONS(4849),
    [aux_sym_signed_number_token1] = ACTIONS(7199),
    [anon_sym_SQUOTE] = ACTIONS(4853),
    [anon_sym_DQUOTE] = ACTIONS(4855),
    [sym__uppercase_identifier] = ACTIONS(4859),
    [aux_sym_tag_token1] = ACTIONS(4861),
    [sym_comment] = ACTIONS(5),
    [sym_line_number_directive] = ACTIONS(5),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3112), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14442), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [139] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3113), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14903), 1,
      sym__pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [278] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [355] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7923), 1,
      anon_sym_LT_DASH,
    STATE(3115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [432] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3116), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14639), 1,
      sym__pattern,
    STATE(14762), 1,
      sym__or_pattern_anonymous,
    STATE(14765), 1,
      sym__tuple_pattern,
    STATE(18530), 1,
      sym_module_path,
    STATE(20865), 1,
      sym_labeled_tuple_element_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [571] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3117), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14762), 1,
      sym__or_pattern_anonymous,
    STATE(14765), 1,
      sym__tuple_pattern,
    STATE(14993), 1,
      sym__pattern,
    STATE(18530), 1,
      sym_module_path,
    STATE(20865), 1,
      sym_labeled_tuple_element_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [710] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    ACTIONS(7925), 1,
      anon_sym_TILDE,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3118), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14641), 1,
      sym__pattern,
    STATE(14643), 1,
      sym_labeled_tuple_element_pattern,
    STATE(14644), 1,
      sym__tuple_pattern,
    STATE(14762), 1,
      sym__or_pattern_anonymous,
    STATE(18530), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [849] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3119), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14645), 1,
      sym__pattern,
    STATE(14646), 1,
      sym__or_pattern_anonymous,
    STATE(14765), 1,
      sym__tuple_pattern,
    STATE(18530), 1,
      sym_module_path,
    STATE(20865), 1,
      sym_labeled_tuple_element_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [988] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3120), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14648), 1,
      sym__pattern,
    STATE(14762), 1,
      sym__or_pattern_anonymous,
    STATE(14765), 1,
      sym__tuple_pattern,
    STATE(18530), 1,
      sym_module_path,
    STATE(20865), 1,
      sym_labeled_tuple_element_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1127] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3121), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14653), 1,
      sym__pattern,
    STATE(14762), 1,
      sym__or_pattern_anonymous,
    STATE(14765), 1,
      sym__tuple_pattern,
    STATE(18530), 1,
      sym_module_path,
    STATE(20865), 1,
      sym_labeled_tuple_element_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1266] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7280), 1,
      anon_sym_exception,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7286), 1,
      anon_sym_lazy,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7290), 1,
      anon_sym_effect,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7304), 1,
      sym__uppercase_identifier,
    ACTIONS(7306), 1,
      aux_sym_tag_token1,
    ACTIONS(7359), 1,
      anon_sym_LPAREN,
    STATE(2640), 1,
      sym_constructor_path,
    STATE(2642), 1,
      sym_tag,
    STATE(3122), 1,
      sym_attribute,
    STATE(9503), 1,
      sym__constructor_name,
    STATE(14523), 1,
      sym__signed_constant,
    STATE(14762), 1,
      sym__or_pattern_anonymous,
    STATE(14765), 1,
      sym__tuple_pattern,
    STATE(14801), 1,
      sym__pattern,
    STATE(18530), 1,
      sym_module_path,
    STATE(20865), 1,
      sym_labeled_tuple_element_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14748), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14761), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(14731), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1405] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [1482] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3124), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14394), 1,
      sym__pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1621] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3125), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13846), 1,
      sym__pattern,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1760] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7927), 1,
      anon_sym_TILDE,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3126), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13915), 1,
      sym__tuple_pattern,
    STATE(14396), 1,
      sym__pattern,
    STATE(14397), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [1899] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3127), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13829), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14398), 1,
      sym__pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2038] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3128), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14399), 1,
      sym__pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2177] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3129), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13695), 1,
      sym__pattern,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [2316] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7929), 1,
      anon_sym_LT_DASH,
    STATE(3130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2543] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2618] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [2918] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3138), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14872), 1,
      sym__pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3207] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3141), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14022), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3421] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3143), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13846), 1,
      sym__pattern,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3560] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7967), 1,
      anon_sym_TILDE,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3144), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13915), 1,
      sym__tuple_pattern,
    STATE(13980), 1,
      sym__pattern,
    STATE(13990), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [3699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [3999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [4074] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [4149] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3151), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(15418), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4288] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3152), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(15427), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4427] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3153), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13829), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(13982), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4566] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3154), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14020), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4705] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3155), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13695), 1,
      sym__pattern,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [4844] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [4919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 38,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [4994] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3158), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14572), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5133] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3159), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14323), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5272] = 29,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7969), 1,
      sym__lowercase_identifier,
    ACTIONS(7975), 1,
      anon_sym_LPAREN,
    ACTIONS(7978), 1,
      anon_sym_LBRACK,
    ACTIONS(7984), 1,
      anon_sym_LBRACE,
    ACTIONS(7987), 1,
      anon_sym_POUND,
    ACTIONS(7990), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7993), 1,
      anon_sym_begin,
    ACTIONS(7996), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7999), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8002), 1,
      aux_sym_number_token1,
    ACTIONS(8005), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8008), 1,
      anon_sym_SQUOTE,
    ACTIONS(8011), 1,
      anon_sym_DQUOTE,
    ACTIONS(8014), 1,
      sym__uppercase_identifier,
    ACTIONS(8017), 1,
      aux_sym_tag_token1,
    STATE(9114), 1,
      sym__constructor_name,
    STATE(9167), 1,
      sym__simple_pattern,
    STATE(20059), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7972), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(7981), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3160), 2,
      sym_attribute,
      aux_sym_let_binding_repeat1,
    STATE(9165), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(9176), 2,
      sym__constant,
      sym_signed_number,
    ACTIONS(7216), 5,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    STATE(9113), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    ACTIONS(7218), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
    STATE(9109), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [5395] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3161), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14532), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5534] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(7187), 1,
      anon_sym_exception,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7191), 1,
      anon_sym_lazy,
    ACTIONS(7193), 1,
      anon_sym_effect,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2630), 1,
      sym_constructor_path,
    STATE(2639), 1,
      sym_tag,
    STATE(3162), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14782), 1,
      sym__pattern,
    STATE(20112), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5673] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3163), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14382), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5812] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3164), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14401), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [5951] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3165), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14574), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6090] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3166), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14578), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6229] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3167), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14632), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6368] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3168), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14421), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6507] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3169), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14327), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6646] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3170), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14332), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6785] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3171), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14418), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [6924] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3172), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14436), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7063] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3173), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14472), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7202] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3174), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14488), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7341] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3175), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14514), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7480] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3176), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14516), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7619] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3177), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14535), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7758] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3178), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14539), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [7897] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3179), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14599), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8036] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3180), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14610), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8175] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3181), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14297), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8314] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3182), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14300), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8453] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3183), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14313), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8592] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3184), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14500), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8731] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3185), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14318), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [8870] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3186), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14319), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9009] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3187), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14324), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9148] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3188), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14326), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9287] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3189), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14329), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9426] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3190), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14330), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9565] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3191), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14335), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9704] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3192), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14336), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9843] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3193), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14345), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [9982] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3194), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14348), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10121] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3195), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14354), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10260] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3196), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14356), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10399] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3197), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14359), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10538] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3198), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14361), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10677] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3199), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14365), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10816] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3200), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14366), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [10955] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3201), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14371), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11094] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3202), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14372), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11233] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3203), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14379), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11372] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3204), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14381), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11511] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3205), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14385), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11650] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3206), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14387), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11789] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3207), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14389), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [11928] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3208), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14390), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12067] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3209), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14392), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12206] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3210), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14393), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12345] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3211), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14400), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12484] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3212), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14402), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12623] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3213), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14406), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12762] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3214), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14407), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [12901] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3215), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14411), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13040] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3216), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14414), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13179] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3217), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14419), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13318] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3218), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14422), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13457] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3219), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14424), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13596] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3220), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14425), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13735] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3221), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14430), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [13874] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3222), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14431), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14013] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3223), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14437), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14152] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3224), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14438), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14291] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3225), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14501), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14430] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3226), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14443), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14569] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3227), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14445), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14708] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3228), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14446), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14847] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3229), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14449), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [14986] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3230), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14451), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15125] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3231), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14454), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15264] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3232), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14455), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15403] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3233), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14463), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15542] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3234), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14464), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15681] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3235), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14469), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15820] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3236), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14470), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [15959] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3237), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14473), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16098] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3238), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14474), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16237] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3239), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14481), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16376] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3240), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14484), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16515] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3241), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14490), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16654] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3242), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14491), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16793] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3243), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14494), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [16932] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3244), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14495), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [17071] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3245), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14498), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [17210] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3246), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14499), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [17349] = 37,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4829), 1,
      anon_sym_exception,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4839), 1,
      anon_sym_lazy,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4843), 1,
      anon_sym_effect,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6789), 1,
      anon_sym_TILDE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2590), 1,
      sym_constructor_path,
    STATE(2614), 1,
      sym_tag,
    STATE(3247), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(13672), 1,
      sym__signed_constant,
    STATE(13861), 1,
      sym__or_pattern_anonymous,
    STATE(13866), 1,
      sym__tuple_pattern,
    STATE(14314), 1,
      sym__pattern,
    STATE(20737), 1,
      sym_labeled_tuple_element_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13853), 6,
      sym__effect_pattern,
      sym_alias_pattern,
      sym_cons_pattern,
      sym_range_pattern,
      sym_exception_pattern,
      sym_effect_pattern,
    STATE(13858), 12,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [17488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17562] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3249), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15733), 1,
      sym__simple_expression,
    STATE(17017), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    STATE(20790), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [17692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17766] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17914] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [17988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18284] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18432] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18506] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3197), 1,
      anon_sym_DOT,
    ACTIONS(3199), 1,
      anon_sym_POUND,
    ACTIONS(3201), 1,
      sym_hash_operator,
    STATE(3261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18734] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [18956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19030] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19104] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3197), 1,
      anon_sym_DOT,
    STATE(3269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19698] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19772] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19920] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [19994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20068] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20142] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20438] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20512] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20660] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3197), 1,
      anon_sym_DOT,
    ACTIONS(3199), 1,
      anon_sym_POUND,
    ACTIONS(3201), 1,
      sym_hash_operator,
    STATE(3290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20814] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [20962] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21258] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21776] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [21998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22368] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22442] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22516] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3315), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15758), 1,
      sym__simple_expression,
    STATE(15960), 1,
      sym_field_expression,
    STATE(19631), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [22646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22794] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [22868] = 42,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(8272), 1,
      anon_sym_rec,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(2544), 1,
      sym__binding_pattern,
    STATE(3319), 1,
      sym_attribute,
    STATE(4071), 1,
      sym__attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(12497), 1,
      sym_let_binding,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [23016] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3207), 1,
      anon_sym_DOT,
    ACTIONS(3209), 1,
      anon_sym_POUND,
    ACTIONS(3211), 1,
      sym_hash_operator,
    STATE(3320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23614] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3207), 1,
      anon_sym_DOT,
    STATE(3328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [23986] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3333), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15777), 1,
      sym__simple_expression,
    STATE(15954), 1,
      sym_field_expression,
    STATE(18642), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [24116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24264] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24412] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24708] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [24856] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3344), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15784), 1,
      sym__simple_expression,
    STATE(16280), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    STATE(21377), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [24986] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25134] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25284] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8278), 1,
      anon_sym_LT_DASH,
    STATE(3349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25360] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3207), 1,
      anon_sym_DOT,
    ACTIONS(3209), 1,
      anon_sym_POUND,
    ACTIONS(3211), 1,
      sym_hash_operator,
    STATE(3350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25588] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25736] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3355), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15790), 1,
      sym__simple_expression,
    STATE(16535), 1,
      sym_field_expression,
    STATE(18618), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [25866] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [25940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26014] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26088] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26162] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26236] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3361), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15792), 1,
      sym__simple_expression,
    STATE(16856), 1,
      sym_field_expression,
    STATE(19738), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [26366] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26588] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3365), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15777), 1,
      sym__simple_expression,
    STATE(15954), 1,
      sym_field_expression,
    STATE(19780), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [26718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [26866] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3368), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15794), 1,
      sym__simple_expression,
    STATE(17159), 1,
      sym_field_expression,
    STATE(19155), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [26996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [27070] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3370), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15797), 1,
      sym__simple_expression,
    STATE(16035), 1,
      sym_field_expression,
    STATE(20753), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [27200] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [27274] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3372), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15800), 1,
      sym__simple_expression,
    STATE(17059), 1,
      sym_field_expression,
    STATE(19655), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [27404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [27478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [27552] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3375), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15803), 1,
      sym__simple_expression,
    STATE(16858), 1,
      sym_field_expression,
    STATE(19278), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [27682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [27756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [27830] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3378), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15806), 1,
      sym__simple_expression,
    STATE(16425), 1,
      sym_field_expression,
    STATE(19614), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [27960] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3379), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15808), 1,
      sym__simple_expression,
    STATE(16893), 1,
      sym_field_expression,
    STATE(20127), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28164] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3381), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15809), 1,
      sym__simple_expression,
    STATE(16445), 1,
      sym_field_expression,
    STATE(20700), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28294] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3382), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15812), 1,
      sym__simple_expression,
    STATE(16619), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    STATE(21235), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28646] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3386), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15814), 1,
      sym__simple_expression,
    STATE(16066), 1,
      sym_field_expression,
    STATE(19013), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [28776] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [28998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29146] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29220] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3393), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15816), 1,
      sym__simple_expression,
    STATE(16452), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    STATE(21120), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [29350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29572] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3397), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15819), 1,
      sym__simple_expression,
    STATE(16817), 1,
      sym_field_expression,
    STATE(19554), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [29702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29776] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [29850] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3400), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15821), 1,
      sym__simple_expression,
    STATE(17118), 1,
      sym_field_expression,
    STATE(19042), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [29980] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3401), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15823), 1,
      sym__simple_expression,
    STATE(15982), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    STATE(20794), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [30184] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3403), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15824), 1,
      sym__simple_expression,
    STATE(16110), 1,
      sym_field_expression,
    STATE(19204), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [30388] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3405), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15825), 1,
      sym__simple_expression,
    STATE(16225), 1,
      sym_field_expression,
    STATE(19875), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30518] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3406), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15827), 1,
      sym__simple_expression,
    STATE(16368), 1,
      sym_field_expression,
    STATE(18918), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30648] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3407), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15829), 1,
      sym__simple_expression,
    STATE(16453), 1,
      sym_field_expression,
    STATE(19764), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30778] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3408), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15830), 1,
      sym__simple_expression,
    STATE(16532), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    STATE(20979), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [30908] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3409), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15831), 1,
      sym__simple_expression,
    STATE(16701), 1,
      sym_field_expression,
    STATE(18614), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [31038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31112] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3411), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15832), 1,
      sym__simple_expression,
    STATE(16772), 1,
      sym_field_expression,
    STATE(18920), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [31242] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31540] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3416), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15835), 1,
      sym__simple_expression,
    STATE(16888), 1,
      sym_field_expression,
    STATE(19332), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [31670] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [31818] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3419), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15836), 1,
      sym__simple_expression,
    STATE(17123), 1,
      sym_field_expression,
    STATE(19690), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [31948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [32022] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [32096] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3422), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15838), 1,
      sym__simple_expression,
    STATE(16578), 1,
      sym_field_expression,
    STATE(19873), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [32226] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3423), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15839), 1,
      sym__simple_expression,
    STATE(17176), 1,
      sym_field_expression,
    STATE(20000), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [32356] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3424), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15841), 1,
      sym__simple_expression,
    STATE(16415), 1,
      sym_field_expression,
    STATE(20023), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [32486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [32560] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3426), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15842), 1,
      sym__simple_expression,
    STATE(17186), 1,
      sym_field_expression,
    STATE(20045), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [32690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [32764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [32838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [32912] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3430), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15845), 1,
      sym__simple_expression,
    STATE(16124), 1,
      sym_field_expression,
    STATE(20067), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [33042] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [33116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [33190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [33264] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3434), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15847), 1,
      sym__simple_expression,
    STATE(16443), 1,
      sym_field_expression,
    STATE(20101), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [33394] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3435), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15848), 1,
      sym__simple_expression,
    STATE(16695), 1,
      sym_field_expression,
    STATE(20141), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [33524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [33598] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3437), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15850), 1,
      sym__simple_expression,
    STATE(16857), 1,
      sym_field_expression,
    STATE(20174), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [33728] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3438), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15853), 1,
      sym__simple_expression,
    STATE(17139), 1,
      sym_field_expression,
    STATE(20227), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [33858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [33932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [34006] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3441), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15856), 1,
      sym__simple_expression,
    STATE(15972), 1,
      sym_field_expression,
    STATE(20261), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [34210] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3443), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15857), 1,
      sym__simple_expression,
    STATE(16048), 1,
      sym_field_expression,
    STATE(20314), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34340] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3444), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15858), 1,
      sym__simple_expression,
    STATE(16121), 1,
      sym_field_expression,
    STATE(20367), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34470] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3445), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15861), 1,
      sym__simple_expression,
    STATE(16217), 1,
      sym_field_expression,
    STATE(20415), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [34674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [34748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [34822] = 33,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(3449), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15381), 1,
      sym__simple_expression,
    STATE(16436), 1,
      sym_field_expression,
    STATE(20624), 1,
      sym__quoted_string,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [34952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35248] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35618] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35766] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [35990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36064] = 42,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(8346), 1,
      anon_sym_rec,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(2548), 1,
      sym__binding_pattern,
    STATE(3465), 1,
      sym_attribute,
    STATE(4097), 1,
      sym__attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(12445), 1,
      sym_let_binding,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [36212] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36286] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36434] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36582] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36806] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [36956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37030] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37178] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37474] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37548] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37624] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37700] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8366), 1,
      anon_sym_LT_DASH,
    STATE(3486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37776] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8368), 1,
      anon_sym_LT_DASH,
    STATE(3487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37852] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [37928] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8370), 1,
      anon_sym_LT_DASH,
    STATE(3489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 37,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38299] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38664] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3409), 1,
      anon_sym_DOT,
    ACTIONS(3411), 1,
      anon_sym_POUND,
    ACTIONS(3413), 1,
      sym_hash_operator,
    STATE(3499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38889] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [38962] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39108] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39181] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39327] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39473] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39546] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39765] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39838] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3705), 1,
      anon_sym_DOT,
    ACTIONS(3707), 1,
      anon_sym_POUND,
    ACTIONS(3709), 1,
      sym_hash_operator,
    STATE(3515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39917] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [39990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40063] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8372), 1,
      anon_sym_LT_DASH,
    STATE(3518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40211] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40286] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40359] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40432] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40505] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [40943] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41016] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3431), 1,
      anon_sym_DOT,
    ACTIONS(3433), 1,
      anon_sym_POUND,
    ACTIONS(3435), 1,
      sym_hash_operator,
    STATE(3531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41095] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41241] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41387] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41533] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41825] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3431), 1,
      anon_sym_DOT,
    STATE(3542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [41973] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42046] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42119] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42192] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42265] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42411] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42484] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42630] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42776] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [42995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43068] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43287] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43506] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43652] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43725] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43871] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [43944] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44309] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44382] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3431), 1,
      anon_sym_DOT,
    ACTIONS(3433), 1,
      anon_sym_POUND,
    ACTIONS(3435), 1,
      sym_hash_operator,
    STATE(3577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44461] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44607] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [44972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45045] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45264] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45775] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45848] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3479), 1,
      anon_sym_DOT,
    STATE(3597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45923] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8374), 1,
      anon_sym_LT_DASH,
    STATE(3598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [45998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46071] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46363] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46582] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46801] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [46947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47020] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47093] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47166] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47239] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47312] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47385] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47677] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47898] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [47971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48263] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48701] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48847] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48920] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [48993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49212] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49577] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3479), 1,
      anon_sym_DOT,
    ACTIONS(3481), 1,
      anon_sym_POUND,
    ACTIONS(3483), 1,
      sym_hash_operator,
    STATE(3648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49875] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [49948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50021] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50313] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50386] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50605] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3409), 1,
      anon_sym_DOT,
    ACTIONS(3411), 1,
      anon_sym_POUND,
    ACTIONS(3413), 1,
      sym_hash_operator,
    STATE(3662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50684] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [50976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51049] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51487] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3705), 1,
      anon_sym_DOT,
    ACTIONS(3707), 1,
      anon_sym_POUND,
    ACTIONS(3709), 1,
      sym_hash_operator,
    STATE(3674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51712] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3705), 1,
      anon_sym_DOT,
    STATE(3677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [51933] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52079] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52225] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52371] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3479), 1,
      anon_sym_DOT,
    ACTIONS(3481), 1,
      anon_sym_POUND,
    ACTIONS(3483), 1,
      sym_hash_operator,
    STATE(3686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52669] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [52961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53253] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53545] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53618] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53691] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [53983] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54348] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54421] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54713] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3409), 1,
      anon_sym_DOT,
    STATE(3718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54788] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54863] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [54936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55082] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55155] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55447] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55593] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55666] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [55958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56542] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56907] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [56980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57345] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57420] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57493] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57639] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57860] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [57935] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58008] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58519] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58594] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58667] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58742] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58890] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [58963] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59109] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59182] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59474] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59547] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59620] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59766] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [59985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60131] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60423] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [60934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61007] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61153] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61447] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61593] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61666] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [61958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62542] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 36,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [62832] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(3829), 1,
      sym_attribute,
    STATE(4644), 1,
      sym__attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5810), 1,
      sym__binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [62974] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3181), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3830), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [63116] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63260] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3833), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15792), 1,
      sym__simple_expression,
    STATE(16856), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [63384] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63456] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8376), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(3835), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15077), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [63598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63670] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [63960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64032] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64104] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64178] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(3844), 1,
      sym_attribute,
    STATE(4585), 1,
      sym__attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5820), 1,
      sym__binding_pattern,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [64320] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3119), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3845), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [64462] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [64534] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3847), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15794), 1,
      sym__simple_expression,
    STATE(17159), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [64658] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8378), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(3848), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15181), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [64800] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3165), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3849), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [64942] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3850), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15797), 1,
      sym__simple_expression,
    STATE(16035), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [65066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65426] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(3856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65572] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3133), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3858), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [65714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [65858] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3861), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15800), 1,
      sym__simple_expression,
    STATE(17059), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [65982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66198] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(3865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66560] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3105), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3870), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [66702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66774] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3872), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15803), 1,
      sym__simple_expression,
    STATE(16858), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [66898] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [66970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67042] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3173), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3875), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [67184] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3876), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15806), 1,
      sym__simple_expression,
    STATE(16425), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [67308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67380] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3147), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3878), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [67522] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3879), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15808), 1,
      sym__simple_expression,
    STATE(16893), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [67646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67862] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [67934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68078] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3183), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3886), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [68220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68292] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68436] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3890), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15809), 1,
      sym__simple_expression,
    STATE(16445), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [68560] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3111), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3891), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [68702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [68846] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3894), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15812), 1,
      sym__simple_expression,
    STATE(16619), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [68970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69042] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3149), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3896), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [69184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69400] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3900), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15814), 1,
      sym__simple_expression,
    STATE(16066), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [69524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [69596] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3163), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3902), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [69738] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3903), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15816), 1,
      sym__simple_expression,
    STATE(16452), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [69862] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3101), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3904), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [70004] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3905), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15819), 1,
      sym__simple_expression,
    STATE(16817), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [70128] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3137), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3906), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [70270] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70414] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3909), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15821), 1,
      sym__simple_expression,
    STATE(17118), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [70538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70682] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3113), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3912), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [70824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [70968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71040] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3916), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15823), 1,
      sym__simple_expression,
    STATE(15982), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [71164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71236] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3169), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3918), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [71378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71594] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3922), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15824), 1,
      sym__simple_expression,
    STATE(16110), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [71718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [71862] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3109), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3925), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [72004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72076] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3927), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15825), 1,
      sym__simple_expression,
    STATE(16225), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [72200] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3155), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3928), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [72342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72414] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3930), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15827), 1,
      sym__simple_expression,
    STATE(16368), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [72538] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3095), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3931), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [72680] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3761), 1,
      anon_sym_DOT,
    STATE(3932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [72754] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3933), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15829), 1,
      sym__simple_expression,
    STATE(16453), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [72878] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3934), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [73020] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(3935), 1,
      sym_attribute,
    STATE(4574), 1,
      sym__attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5673), 1,
      sym__binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [73162] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8380), 1,
      anon_sym_rec,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(2538), 1,
      sym__binding_pattern,
    STATE(3936), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(12228), 1,
      sym_let_binding,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [73304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [73376] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3938), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15830), 1,
      sym__simple_expression,
    STATE(16532), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [73500] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3145), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3939), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [73642] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3121), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3940), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [73784] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(3941), 1,
      sym_attribute,
    STATE(4613), 1,
      sym__attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(8015), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [73908] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3942), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15831), 1,
      sym__simple_expression,
    STATE(16701), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [74032] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3177), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3943), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [74174] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(3944), 1,
      sym_attribute,
    STATE(4618), 1,
      sym__attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7896), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [74298] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3945), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15832), 1,
      sym__simple_expression,
    STATE(16772), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [74422] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3097), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3946), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [74564] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3947), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15835), 1,
      sym__simple_expression,
    STATE(16888), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [74688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [74832] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3141), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3950), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [74974] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3951), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15836), 1,
      sym__simple_expression,
    STATE(17123), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [75098] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3952), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15733), 1,
      sym__simple_expression,
    STATE(17017), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [75222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75294] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3954), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [75436] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(5569), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8406), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(3955), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15140), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [75578] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3956), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15381), 1,
      sym__simple_expression,
    STATE(16436), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [75702] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3957), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15838), 1,
      sym__simple_expression,
    STATE(16578), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [75826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [75898] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3129), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3959), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [76040] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3960), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15839), 1,
      sym__simple_expression,
    STATE(17176), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [76164] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [76236] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(3962), 1,
      sym_attribute,
    STATE(4692), 1,
      sym__attribute,
    STATE(9944), 1,
      sym__simple_expression,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [76360] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3103), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3963), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [76502] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(3964), 1,
      sym_attribute,
    STATE(4693), 1,
      sym__attribute,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(10237), 1,
      sym__simple_expression,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [76626] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8450), 1,
      anon_sym_COLON,
    STATE(3965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [76700] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(3966), 1,
      sym_attribute,
    STATE(4440), 1,
      sym__attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9229), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [76824] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3967), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15841), 1,
      sym__simple_expression,
    STATE(16415), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [76948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77020] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(3969), 1,
      sym_attribute,
    STATE(4441), 1,
      sym__attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9269), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [77144] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3123), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3970), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [77286] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3971), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15842), 1,
      sym__simple_expression,
    STATE(17186), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [77410] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77626] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3161), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3975), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [77768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [77840] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3977), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15845), 1,
      sym__simple_expression,
    STATE(16124), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [77964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78108] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3099), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3980), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [78250] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3981), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15847), 1,
      sym__simple_expression,
    STATE(16443), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [78374] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3115), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3982), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [78516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78588] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3984), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15848), 1,
      sym__simple_expression,
    STATE(16695), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [78712] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [78856] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3131), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3987), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [78998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79142] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3990), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15850), 1,
      sym__simple_expression,
    STATE(16857), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [79266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79338] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(3992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79412] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3143), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3993), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [79554] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8490), 1,
      anon_sym_LT_DASH,
    STATE(3994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [79700] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3996), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15853), 1,
      sym__simple_expression,
    STATE(17139), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [79824] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3157), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(3997), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [79966] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(3998), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15856), 1,
      sym__simple_expression,
    STATE(15972), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [80090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(3999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80162] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80234] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3187), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4001), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [80376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80520] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3171), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4004), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [80662] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4005), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15857), 1,
      sym__simple_expression,
    STATE(16048), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [80786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [80858] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4007), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [81000] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4008), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15858), 1,
      sym__simple_expression,
    STATE(16121), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [81124] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4009), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [81266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81338] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4011), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15861), 1,
      sym__simple_expression,
    STATE(16217), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [81462] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4012), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [81604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81676] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [81820] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(5609), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8492), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4016), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15136), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [81962] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82106] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82178] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5253), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8378), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4020), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15181), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [82320] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5251), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8494), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4021), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15031), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [82462] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4022), 1,
      sym_attribute,
    STATE(4506), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14192), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [82604] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    ACTIONS(8496), 1,
      anon_sym_rec,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4023), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15576), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [82746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82818] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3761), 1,
      anon_sym_DOT,
    ACTIONS(3763), 1,
      anon_sym_POUND,
    ACTIONS(3765), 1,
      sym_hash_operator,
    STATE(4025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [82896] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3175), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4026), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [83038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83182] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83326] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4031), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15758), 1,
      sym__simple_expression,
    STATE(15960), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83450] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5015), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8378), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4032), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15181), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [83592] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [83736] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4035), 1,
      sym_attribute,
    STATE(4531), 1,
      sym__attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7860), 1,
      sym__simple_expression,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83860] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4036), 1,
      sym_attribute,
    STATE(4533), 1,
      sym__attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7871), 1,
      sym__simple_expression,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [83984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84056] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3771), 1,
      anon_sym_DOT,
    STATE(4038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [84994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85426] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3761), 1,
      anon_sym_DOT,
    ACTIONS(3763), 1,
      anon_sym_POUND,
    ACTIONS(3765), 1,
      sym_hash_operator,
    STATE(4057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85576] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(4059), 1,
      sym_attribute,
    STATE(4764), 1,
      sym__attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(5711), 1,
      sym__binding_pattern,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [85718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85862] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [85934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86366] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4069), 1,
      sym_attribute,
    STATE(4606), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14192), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [86508] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(4070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86582] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8536), 1,
      anon_sym_rec,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(2544), 1,
      sym__binding_pattern,
    STATE(4071), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(12417), 1,
      sym_let_binding,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [86724] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8538), 1,
      anon_sym_LT_DASH,
    STATE(4072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [86798] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3127), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4073), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [86940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87156] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4077), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15777), 1,
      sym__simple_expression,
    STATE(15954), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [87280] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3771), 1,
      anon_sym_DOT,
    ACTIONS(3773), 1,
      anon_sym_POUND,
    ACTIONS(3775), 1,
      sym_hash_operator,
    STATE(4078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87358] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1709), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8494), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4079), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15031), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [87500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87860] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [87932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88076] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3771), 1,
      anon_sym_DOT,
    ACTIONS(3773), 1,
      anon_sym_POUND,
    ACTIONS(3775), 1,
      sym_hash_operator,
    STATE(4088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88442] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [88658] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4096), 1,
      sym_attribute,
    STATE(4684), 1,
      sym__attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14848), 1,
      sym__binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [88800] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8540), 1,
      anon_sym_rec,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(2548), 1,
      sym__binding_pattern,
    STATE(4097), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(12460), 1,
      sym_let_binding,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [88942] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3153), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4098), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [89084] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4099), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15784), 1,
      sym__simple_expression,
    STATE(16280), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [89208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89280] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(5549), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8542), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4101), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15125), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [89422] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8544), 1,
      anon_sym_rec,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(2526), 1,
      sym__binding_pattern,
    STATE(4102), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(12380), 1,
      sym_let_binding,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [89564] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89636] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [89708] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4105), 1,
      sym_attribute,
    STATE(4721), 1,
      sym__attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9713), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [89832] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8396), 1,
      anon_sym_PERCENT,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4106), 1,
      sym_attribute,
    STATE(4722), 1,
      sym__attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9714), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [89956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90172] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [90532] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8548), 1,
      anon_sym_COLON,
    STATE(4115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [90606] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(4116), 1,
      sym_attribute,
    STATE(4745), 1,
      sym__attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9238), 1,
      sym__binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [90748] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3159), 1,
      anon_sym_RPAREN,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4117), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [90890] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8024), 1,
      sym__lowercase_identifier,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(4118), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15175), 1,
      sym_field_path,
    STATE(15790), 1,
      sym__simple_expression,
    STATE(16535), 1,
      sym_field_expression,
    STATE(20787), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [91014] = 40,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(5589), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8550), 1,
      anon_sym_RPAREN,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4119), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(15197), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [91156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 36,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91587] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3097), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4126), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [91708] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3149), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4127), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [91829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [91900] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(2538), 1,
      sym__binding_pattern,
    STATE(4129), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(11914), 1,
      sym_let_binding,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [92039] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8552), 1,
      anon_sym_COLON,
    STATE(4130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [92112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92254] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92396] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4135), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15440), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [92535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [92606] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4137), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15576), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [92745] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8554), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4138), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14512), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [92884] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8556), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4139), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14520), 1,
      sym__binding_pattern,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [93023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93094] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3141), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4141), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [93215] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93286] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3165), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4143), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [93407] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3175), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4144), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [93528] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(4145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93601] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4146), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(16461), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [93740] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(2974), 1,
      sym__binding_pattern,
    STATE(4147), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(15677), 1,
      sym_let_binding,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [93879] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [93950] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3163), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4149), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94071] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8558), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4150), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [94210] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8560), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4151), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [94349] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4152), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [94470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94541] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8562), 1,
      anon_sym_COLON,
    STATE(4154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [94614] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [94685] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8564), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4156), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [94824] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8566), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4157), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [94963] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(2526), 1,
      sym__binding_pattern,
    STATE(4158), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(12380), 1,
      sym_let_binding,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [95102] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3173), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4159), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [95223] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3101), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4160), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [95344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [95415] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [95557] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8572), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4164), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [95696] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8574), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4165), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [95835] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [95906] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3187), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4167), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [96027] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [96524] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8576), 1,
      anon_sym_COLON,
    STATE(4175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [96597] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3129), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4176), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [96718] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3137), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4177), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [96839] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8578), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4178), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [96978] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8580), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4179), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [97117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [97472] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3103), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4185), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [97593] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3181), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4186), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [97714] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8582), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4187), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14555), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [97853] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8584), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4188), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14558), 1,
      sym__binding_pattern,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [97992] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98063] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98347] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3113), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4194), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [98468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98539] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98823] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98894] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [98965] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99036] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3869), 1,
      anon_sym_DOT,
    STATE(4203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99109] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3123), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4204), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [99230] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(4205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99658] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(4211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99731] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [99944] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3169), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4215), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [100065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100278] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3161), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4219), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [100399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100612] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [100967] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101109] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101251] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3147), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4232), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [101372] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8586), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4233), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [101511] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101582] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [101795] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(2544), 1,
      sym__binding_pattern,
    STATE(4238), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(12497), 1,
      sym_let_binding,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [101934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102005] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102076] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8588), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4241), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [102215] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3119), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4242), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [102336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 35,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [102407] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3099), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4244), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [102528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102670] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(2544), 1,
      sym__binding_pattern,
    STATE(4247), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(12417), 1,
      sym_let_binding,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [102809] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [102880] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8590), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4249), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14308), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [103019] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8592), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4250), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14309), 1,
      sym__binding_pattern,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [103158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103229] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8594), 1,
      anon_sym_LT_DASH,
    STATE(4252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103302] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3109), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4253), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [103423] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3115), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4254), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [103544] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3127), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4255), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [103665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103807] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3869), 1,
      anon_sym_DOT,
    ACTIONS(3871), 1,
      anon_sym_POUND,
    ACTIONS(3873), 1,
      sym_hash_operator,
    STATE(4258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [103884] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(2544), 1,
      sym__binding_pattern,
    STATE(4259), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(12251), 1,
      sym_let_binding,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [104023] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(2544), 1,
      sym__binding_pattern,
    STATE(4260), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(12546), 1,
      sym_let_binding,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [104162] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104304] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3155), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4263), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [104425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104567] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3869), 1,
      anon_sym_DOT,
    ACTIONS(3871), 1,
      anon_sym_POUND,
    ACTIONS(3873), 1,
      sym_hash_operator,
    STATE(4266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104644] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8596), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4267), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [104783] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3131), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4268), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [104904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [104975] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8598), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4270), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [105114] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8600), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4271), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [105253] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105395] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8602), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4274), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [105534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [105676] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8604), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4277), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [105815] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8606), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4278), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [105954] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106025] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8608), 1,
      anon_sym_LT_DASH,
    STATE(4280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106240] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3095), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4283), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [106361] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8610), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4284), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14584), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [106500] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(4285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106857] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [106999] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3105), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4292), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107120] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(2526), 1,
      sym__binding_pattern,
    STATE(4293), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(11794), 1,
      sym_let_binding,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [107259] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3133), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4294), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107380] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107451] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3143), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4296), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107572] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(2538), 1,
      sym__binding_pattern,
    STATE(4297), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(12224), 1,
      sym_let_binding,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [107711] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [107782] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3183), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4299), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [107903] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(2538), 1,
      sym__binding_pattern,
    STATE(4300), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(12228), 1,
      sym_let_binding,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [108042] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [108326] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3157), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4305), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [108447] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4306), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [108568] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(2526), 1,
      sym__binding_pattern,
    STATE(4307), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(12256), 1,
      sym_let_binding,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [108707] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8612), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4308), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14415), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [108846] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8614), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4309), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14416), 1,
      sym__binding_pattern,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [108985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109056] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8616), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4311), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [109195] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(2548), 1,
      sym__binding_pattern,
    STATE(4312), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(12445), 1,
      sym_let_binding,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [109334] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(2548), 1,
      sym__binding_pattern,
    STATE(4313), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(12460), 1,
      sym_let_binding,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [109473] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8618), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4314), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14342), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [109612] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8620), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4315), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14344), 1,
      sym__binding_pattern,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [109751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [109822] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8622), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4317), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14585), 1,
      sym__binding_pattern,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [109961] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3153), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4318), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [110082] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8624), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4319), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [110221] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(2548), 1,
      sym__binding_pattern,
    STATE(4320), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(12251), 1,
      sym_let_binding,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [110360] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(2548), 1,
      sym__binding_pattern,
    STATE(4321), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(12544), 1,
      sym_let_binding,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [110499] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110641] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3171), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4324), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [110762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [110833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [110975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111046] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [111330] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8626), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4333), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [111469] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8628), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4334), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [111608] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8630), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4335), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [111747] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8632), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4336), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [111886] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8634), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4337), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [112025] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8636), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4338), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [112164] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3145), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4339), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [112285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112427] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112711] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8638), 1,
      anon_sym_COLON,
    STATE(4346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [112784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112855] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112926] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3859), 1,
      anon_sym_DOT,
    STATE(4349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [112999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113070] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4351), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [113191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113333] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113404] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113475] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3121), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4356), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [113596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113809] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [113951] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3111), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4362), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [114072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114427] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114711] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114782] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(4373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [114855] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4374), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [114976] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(2526), 1,
      sym__binding_pattern,
    STATE(4375), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(12251), 1,
      sym_let_binding,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [115115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115186] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115612] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [115825] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3177), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4386), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [115946] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8640), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4387), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14482), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [116085] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8642), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4388), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14635), 1,
      sym__binding_pattern,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [116224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [116295] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3159), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4390), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [116487] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4392), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [116608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [116679] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8644), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4394), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [116818] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8646), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4395), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [116957] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117028] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3859), 1,
      anon_sym_DOT,
    ACTIONS(3861), 1,
      anon_sym_POUND,
    ACTIONS(3863), 1,
      sym_hash_operator,
    STATE(4397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117105] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8648), 1,
      anon_sym_RBRACK,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4398), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [117244] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8650), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4399), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [117383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117454] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117667] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(4404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117811] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3859), 1,
      anon_sym_DOT,
    ACTIONS(3861), 1,
      anon_sym_POUND,
    ACTIONS(3863), 1,
      sym_hash_operator,
    STATE(4406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [117888] = 39,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(2538), 1,
      sym__binding_pattern,
    STATE(4407), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(12251), 1,
      sym_let_binding,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [118027] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 35,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118665] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(4417), 1,
      sym_attribute,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(10128), 1,
      sym__simple_expression,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [118783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118853] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [118923] = 29,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    ACTIONS(1007), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      anon_sym_object,
    ACTIONS(1013), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1023), 1,
      anon_sym_new,
    ACTIONS(1025), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1027), 1,
      anon_sym_begin,
    ACTIONS(1029), 1,
      sym_ocamlyacc_value,
    ACTIONS(1035), 1,
      aux_sym_number_token1,
    ACTIONS(1037), 1,
      anon_sym_SQUOTE,
    ACTIONS(1039), 1,
      anon_sym_DQUOTE,
    ACTIONS(1041), 1,
      sym_prefix_operator,
    ACTIONS(1045), 1,
      sym__uppercase_identifier,
    ACTIONS(1047), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3071), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3073), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4565), 1,
      sym__lowercase_identifier,
    STATE(4420), 1,
      sym_attribute,
    STATE(5041), 1,
      sym_parenthesized_operator,
    STATE(5064), 1,
      sym__constructor_name,
    STATE(5079), 1,
      sym__value_name,
    STATE(5104), 1,
      sym__simple_expression,
    STATE(20345), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1005), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5036), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5054), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [119111] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [119181] = 29,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    ACTIONS(1007), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      anon_sym_object,
    ACTIONS(1013), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1023), 1,
      anon_sym_new,
    ACTIONS(1025), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1027), 1,
      anon_sym_begin,
    ACTIONS(1029), 1,
      sym_ocamlyacc_value,
    ACTIONS(1035), 1,
      aux_sym_number_token1,
    ACTIONS(1037), 1,
      anon_sym_SQUOTE,
    ACTIONS(1039), 1,
      anon_sym_DQUOTE,
    ACTIONS(1041), 1,
      sym_prefix_operator,
    ACTIONS(1045), 1,
      sym__uppercase_identifier,
    ACTIONS(1047), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3071), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3073), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4565), 1,
      sym__lowercase_identifier,
    STATE(4423), 1,
      sym_attribute,
    STATE(5041), 1,
      sym_parenthesized_operator,
    STATE(5064), 1,
      sym__constructor_name,
    STATE(5079), 1,
      sym__value_name,
    STATE(5093), 1,
      sym__simple_expression,
    STATE(20345), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1005), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5036), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5054), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119299] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1349), 1,
      anon_sym_LPAREN,
    ACTIONS(1351), 1,
      anon_sym_LBRACK,
    ACTIONS(1355), 1,
      anon_sym_LBRACE,
    ACTIONS(1357), 1,
      anon_sym_object,
    ACTIONS(1361), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1371), 1,
      anon_sym_new,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1375), 1,
      anon_sym_begin,
    ACTIONS(1377), 1,
      sym_ocamlyacc_value,
    ACTIONS(1379), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1381), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1383), 1,
      aux_sym_number_token1,
    ACTIONS(1385), 1,
      anon_sym_SQUOTE,
    ACTIONS(1387), 1,
      anon_sym_DQUOTE,
    ACTIONS(1389), 1,
      sym_prefix_operator,
    ACTIONS(1393), 1,
      sym__uppercase_identifier,
    ACTIONS(1395), 1,
      aux_sym_tag_token1,
    ACTIONS(5255), 1,
      sym__lowercase_identifier,
    STATE(4424), 1,
      sym_attribute,
    STATE(5989), 1,
      sym__simple_expression,
    STATE(6002), 1,
      sym__value_name,
    STATE(6018), 1,
      sym__constructor_name,
    STATE(6069), 1,
      sym_parenthesized_operator,
    STATE(18835), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1353), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6016), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6059), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119417] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2511), 1,
      anon_sym_LPAREN,
    ACTIONS(2513), 1,
      anon_sym_LBRACK,
    ACTIONS(2517), 1,
      anon_sym_LBRACE,
    ACTIONS(2519), 1,
      anon_sym_object,
    ACTIONS(2523), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2533), 1,
      anon_sym_new,
    ACTIONS(2535), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2537), 1,
      anon_sym_begin,
    ACTIONS(2539), 1,
      sym_ocamlyacc_value,
    ACTIONS(2541), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2543), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2545), 1,
      aux_sym_number_token1,
    ACTIONS(2547), 1,
      anon_sym_SQUOTE,
    ACTIONS(2549), 1,
      anon_sym_DQUOTE,
    ACTIONS(2551), 1,
      sym_prefix_operator,
    ACTIONS(2555), 1,
      sym__uppercase_identifier,
    ACTIONS(2557), 1,
      aux_sym_tag_token1,
    ACTIONS(5385), 1,
      sym__lowercase_identifier,
    STATE(4425), 1,
      sym_attribute,
    STATE(6743), 1,
      sym__simple_expression,
    STATE(6792), 1,
      sym__value_name,
    STATE(6882), 1,
      sym__constructor_name,
    STATE(6922), 1,
      sym_parenthesized_operator,
    STATE(19171), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2515), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6880), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6736), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119535] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2511), 1,
      anon_sym_LPAREN,
    ACTIONS(2513), 1,
      anon_sym_LBRACK,
    ACTIONS(2517), 1,
      anon_sym_LBRACE,
    ACTIONS(2519), 1,
      anon_sym_object,
    ACTIONS(2523), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2533), 1,
      anon_sym_new,
    ACTIONS(2535), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2537), 1,
      anon_sym_begin,
    ACTIONS(2539), 1,
      sym_ocamlyacc_value,
    ACTIONS(2541), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2543), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2545), 1,
      aux_sym_number_token1,
    ACTIONS(2547), 1,
      anon_sym_SQUOTE,
    ACTIONS(2549), 1,
      anon_sym_DQUOTE,
    ACTIONS(2551), 1,
      sym_prefix_operator,
    ACTIONS(2555), 1,
      sym__uppercase_identifier,
    ACTIONS(2557), 1,
      aux_sym_tag_token1,
    ACTIONS(5385), 1,
      sym__lowercase_identifier,
    STATE(4426), 1,
      sym_attribute,
    STATE(6753), 1,
      sym__simple_expression,
    STATE(6792), 1,
      sym__value_name,
    STATE(6882), 1,
      sym__constructor_name,
    STATE(6922), 1,
      sym_parenthesized_operator,
    STATE(19171), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2515), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6880), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6736), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119653] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(4427), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(5692), 1,
      sym__binding_pattern,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [119789] = 29,
    ACTIONS(811), 1,
      anon_sym_LPAREN,
    ACTIONS(813), 1,
      anon_sym_LBRACK,
    ACTIONS(817), 1,
      anon_sym_LBRACE,
    ACTIONS(819), 1,
      anon_sym_object,
    ACTIONS(823), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(833), 1,
      anon_sym_new,
    ACTIONS(835), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(837), 1,
      anon_sym_begin,
    ACTIONS(839), 1,
      sym_ocamlyacc_value,
    ACTIONS(845), 1,
      aux_sym_number_token1,
    ACTIONS(847), 1,
      anon_sym_SQUOTE,
    ACTIONS(849), 1,
      anon_sym_DQUOTE,
    ACTIONS(851), 1,
      sym_prefix_operator,
    ACTIONS(855), 1,
      sym__uppercase_identifier,
    ACTIONS(857), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3079), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3081), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3865), 1,
      sym__lowercase_identifier,
    STATE(4257), 1,
      sym__value_name,
    STATE(4266), 1,
      sym__simple_expression,
    STATE(4382), 1,
      sym__constructor_name,
    STATE(4384), 1,
      sym_parenthesized_operator,
    STATE(4428), 1,
      sym_attribute,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(815), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4380), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4163), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [119907] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4429), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14935), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [120043] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1349), 1,
      anon_sym_LPAREN,
    ACTIONS(1351), 1,
      anon_sym_LBRACK,
    ACTIONS(1355), 1,
      anon_sym_LBRACE,
    ACTIONS(1357), 1,
      anon_sym_object,
    ACTIONS(1361), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1371), 1,
      anon_sym_new,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1375), 1,
      anon_sym_begin,
    ACTIONS(1377), 1,
      sym_ocamlyacc_value,
    ACTIONS(1379), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1381), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1383), 1,
      aux_sym_number_token1,
    ACTIONS(1385), 1,
      anon_sym_SQUOTE,
    ACTIONS(1387), 1,
      anon_sym_DQUOTE,
    ACTIONS(1389), 1,
      sym_prefix_operator,
    ACTIONS(1393), 1,
      sym__uppercase_identifier,
    ACTIONS(1395), 1,
      aux_sym_tag_token1,
    ACTIONS(5255), 1,
      sym__lowercase_identifier,
    STATE(4430), 1,
      sym_attribute,
    STATE(5987), 1,
      sym__simple_expression,
    STATE(6002), 1,
      sym__value_name,
    STATE(6018), 1,
      sym__constructor_name,
    STATE(6069), 1,
      sym_parenthesized_operator,
    STATE(18835), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1353), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6016), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6059), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120161] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1173), 1,
      anon_sym_LPAREN,
    ACTIONS(1175), 1,
      anon_sym_LBRACK,
    ACTIONS(1179), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      anon_sym_object,
    ACTIONS(1185), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1199), 1,
      anon_sym_new,
    ACTIONS(1201), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1203), 1,
      anon_sym_begin,
    ACTIONS(1205), 1,
      sym_ocamlyacc_value,
    ACTIONS(1207), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1209), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1211), 1,
      aux_sym_number_token1,
    ACTIONS(1213), 1,
      anon_sym_SQUOTE,
    ACTIONS(1215), 1,
      anon_sym_DQUOTE,
    ACTIONS(1217), 1,
      sym_prefix_operator,
    ACTIONS(1221), 1,
      sym__uppercase_identifier,
    ACTIONS(1223), 1,
      aux_sym_tag_token1,
    ACTIONS(4575), 1,
      sym__lowercase_identifier,
    STATE(4431), 1,
      sym_attribute,
    STATE(5154), 1,
      sym__value_name,
    STATE(5188), 1,
      sym__constructor_name,
    STATE(5231), 1,
      sym__simple_expression,
    STATE(5253), 1,
      sym_parenthesized_operator,
    STATE(18889), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1177), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5187), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5255), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120279] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2303), 1,
      anon_sym_LPAREN,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_LBRACE,
    ACTIONS(2311), 1,
      anon_sym_object,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2325), 1,
      anon_sym_new,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2329), 1,
      anon_sym_begin,
    ACTIONS(2331), 1,
      sym_ocamlyacc_value,
    ACTIONS(2333), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2335), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2337), 1,
      aux_sym_number_token1,
    ACTIONS(2339), 1,
      anon_sym_SQUOTE,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      sym_prefix_operator,
    ACTIONS(2347), 1,
      sym__uppercase_identifier,
    ACTIONS(2349), 1,
      aux_sym_tag_token1,
    ACTIONS(5345), 1,
      sym__lowercase_identifier,
    STATE(4432), 1,
      sym_attribute,
    STATE(6799), 1,
      sym__simple_expression,
    STATE(6848), 1,
      sym__value_name,
    STATE(6936), 1,
      sym_parenthesized_operator,
    STATE(7002), 1,
      sym__constructor_name,
    STATE(19211), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7001), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6791), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120397] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2303), 1,
      anon_sym_LPAREN,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_LBRACE,
    ACTIONS(2311), 1,
      anon_sym_object,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2325), 1,
      anon_sym_new,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2329), 1,
      anon_sym_begin,
    ACTIONS(2331), 1,
      sym_ocamlyacc_value,
    ACTIONS(2333), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2335), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2337), 1,
      aux_sym_number_token1,
    ACTIONS(2339), 1,
      anon_sym_SQUOTE,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      sym_prefix_operator,
    ACTIONS(2347), 1,
      sym__uppercase_identifier,
    ACTIONS(2349), 1,
      aux_sym_tag_token1,
    ACTIONS(5345), 1,
      sym__lowercase_identifier,
    STATE(4433), 1,
      sym_attribute,
    STATE(6810), 1,
      sym__simple_expression,
    STATE(6848), 1,
      sym__value_name,
    STATE(6936), 1,
      sym_parenthesized_operator,
    STATE(7002), 1,
      sym__constructor_name,
    STATE(19211), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7001), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6791), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120515] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1349), 1,
      anon_sym_LPAREN,
    ACTIONS(1351), 1,
      anon_sym_LBRACK,
    ACTIONS(1355), 1,
      anon_sym_LBRACE,
    ACTIONS(1357), 1,
      anon_sym_object,
    ACTIONS(1361), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1371), 1,
      anon_sym_new,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1375), 1,
      anon_sym_begin,
    ACTIONS(1377), 1,
      sym_ocamlyacc_value,
    ACTIONS(1379), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1381), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1383), 1,
      aux_sym_number_token1,
    ACTIONS(1385), 1,
      anon_sym_SQUOTE,
    ACTIONS(1387), 1,
      anon_sym_DQUOTE,
    ACTIONS(1389), 1,
      sym_prefix_operator,
    ACTIONS(1393), 1,
      sym__uppercase_identifier,
    ACTIONS(1395), 1,
      aux_sym_tag_token1,
    ACTIONS(5255), 1,
      sym__lowercase_identifier,
    STATE(4434), 1,
      sym_attribute,
    STATE(6002), 1,
      sym__value_name,
    STATE(6018), 1,
      sym__constructor_name,
    STATE(6048), 1,
      sym__simple_expression,
    STATE(6069), 1,
      sym_parenthesized_operator,
    STATE(18835), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1353), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6016), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6059), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [120633] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(4435), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5813), 1,
      sym__binding_pattern,
    STATE(5815), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [120769] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120909] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [120979] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121049] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(4440), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9248), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121167] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(4441), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9245), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121355] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121565] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121635] = 29,
    ACTIONS(487), 1,
      anon_sym_LPAREN,
    ACTIONS(489), 1,
      anon_sym_LBRACK,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(495), 1,
      anon_sym_object,
    ACTIONS(499), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(509), 1,
      anon_sym_new,
    ACTIONS(511), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(513), 1,
      anon_sym_begin,
    ACTIONS(515), 1,
      sym_ocamlyacc_value,
    ACTIONS(521), 1,
      aux_sym_number_token1,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(527), 1,
      sym_prefix_operator,
    ACTIONS(531), 1,
      sym__uppercase_identifier,
    ACTIONS(533), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3059), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3061), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3701), 1,
      sym__lowercase_identifier,
    STATE(3515), 1,
      sym__simple_expression,
    STATE(3554), 1,
      sym_parenthesized_operator,
    STATE(3640), 1,
      sym__value_name,
    STATE(3721), 1,
      sym__constructor_name,
    STATE(4447), 1,
      sym_attribute,
    STATE(21100), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(491), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3574), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3757), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [121753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121823] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121893] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [121963] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122033] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122103] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122243] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122313] = 29,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(307), 1,
      anon_sym_LBRACK,
    ACTIONS(311), 1,
      anon_sym_LBRACE,
    ACTIONS(321), 1,
      anon_sym_object,
    ACTIONS(325), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(335), 1,
      anon_sym_new,
    ACTIONS(337), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(339), 1,
      anon_sym_begin,
    ACTIONS(341), 1,
      sym_ocamlyacc_value,
    ACTIONS(347), 1,
      aux_sym_number_token1,
    ACTIONS(349), 1,
      anon_sym_SQUOTE,
    ACTIONS(351), 1,
      anon_sym_DQUOTE,
    ACTIONS(353), 1,
      sym_prefix_operator,
    ACTIONS(359), 1,
      sym__uppercase_identifier,
    ACTIONS(363), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3039), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3041), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4185), 1,
      sym__lowercase_identifier,
    STATE(4456), 1,
      sym_attribute,
    STATE(4488), 1,
      sym__simple_expression,
    STATE(4691), 1,
      sym_parenthesized_operator,
    STATE(4737), 1,
      sym__value_name,
    STATE(4743), 1,
      sym__constructor_name,
    STATE(20799), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(309), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4735), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4695), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122431] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1121), 1,
      anon_sym_LPAREN,
    ACTIONS(1123), 1,
      anon_sym_LBRACK,
    ACTIONS(1127), 1,
      anon_sym_LBRACE,
    ACTIONS(1129), 1,
      anon_sym_object,
    ACTIONS(1133), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1143), 1,
      anon_sym_new,
    ACTIONS(1145), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1147), 1,
      anon_sym_begin,
    ACTIONS(1149), 1,
      sym_ocamlyacc_value,
    ACTIONS(1151), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1153), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1155), 1,
      aux_sym_number_token1,
    ACTIONS(1157), 1,
      anon_sym_SQUOTE,
    ACTIONS(1159), 1,
      anon_sym_DQUOTE,
    ACTIONS(1161), 1,
      sym_prefix_operator,
    ACTIONS(1165), 1,
      sym__uppercase_identifier,
    ACTIONS(1167), 1,
      aux_sym_tag_token1,
    ACTIONS(4705), 1,
      sym__lowercase_identifier,
    STATE(4457), 1,
      sym_attribute,
    STATE(5478), 1,
      sym__simple_expression,
    STATE(5522), 1,
      sym_parenthesized_operator,
    STATE(5526), 1,
      sym__constructor_name,
    STATE(5532), 1,
      sym__value_name,
    STATE(18943), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1125), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5554), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122549] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4189), 1,
      anon_sym_DOT,
    ACTIONS(4191), 1,
      anon_sym_POUND,
    ACTIONS(4193), 1,
      sym_hash_operator,
    STATE(4458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [122625] = 29,
    ACTIONS(759), 1,
      anon_sym_LPAREN,
    ACTIONS(761), 1,
      anon_sym_LBRACK,
    ACTIONS(765), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_object,
    ACTIONS(771), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(781), 1,
      anon_sym_new,
    ACTIONS(783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(785), 1,
      anon_sym_begin,
    ACTIONS(787), 1,
      sym_ocamlyacc_value,
    ACTIONS(793), 1,
      aux_sym_number_token1,
    ACTIONS(795), 1,
      anon_sym_SQUOTE,
    ACTIONS(797), 1,
      anon_sym_DQUOTE,
    ACTIONS(799), 1,
      sym_prefix_operator,
    ACTIONS(803), 1,
      sym__uppercase_identifier,
    ACTIONS(805), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3043), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3045), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3757), 1,
      sym__lowercase_identifier,
    STATE(3839), 1,
      sym__constructor_name,
    STATE(3867), 1,
      sym_parenthesized_operator,
    STATE(3889), 1,
      sym__simple_expression,
    STATE(4010), 1,
      sym__value_name,
    STATE(4459), 1,
      sym_attribute,
    STATE(19251), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(763), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3838), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3882), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122743] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8652), 1,
      anon_sym_COLON,
    STATE(4460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 32,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [122815] = 29,
    ACTIONS(759), 1,
      anon_sym_LPAREN,
    ACTIONS(761), 1,
      anon_sym_LBRACK,
    ACTIONS(765), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_object,
    ACTIONS(771), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(781), 1,
      anon_sym_new,
    ACTIONS(783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(785), 1,
      anon_sym_begin,
    ACTIONS(787), 1,
      sym_ocamlyacc_value,
    ACTIONS(793), 1,
      aux_sym_number_token1,
    ACTIONS(795), 1,
      anon_sym_SQUOTE,
    ACTIONS(797), 1,
      anon_sym_DQUOTE,
    ACTIONS(799), 1,
      sym_prefix_operator,
    ACTIONS(803), 1,
      sym__uppercase_identifier,
    ACTIONS(805), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3043), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3045), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3757), 1,
      sym__lowercase_identifier,
    STATE(3839), 1,
      sym__constructor_name,
    STATE(3867), 1,
      sym_parenthesized_operator,
    STATE(3932), 1,
      sym__simple_expression,
    STATE(4010), 1,
      sym__value_name,
    STATE(4461), 1,
      sym_attribute,
    STATE(19251), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(763), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3838), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3882), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [122933] = 29,
    ACTIONS(863), 1,
      anon_sym_LPAREN,
    ACTIONS(865), 1,
      anon_sym_LBRACK,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_object,
    ACTIONS(875), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(885), 1,
      anon_sym_new,
    ACTIONS(887), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(889), 1,
      anon_sym_begin,
    ACTIONS(891), 1,
      sym_ocamlyacc_value,
    ACTIONS(897), 1,
      aux_sym_number_token1,
    ACTIONS(899), 1,
      anon_sym_SQUOTE,
    ACTIONS(901), 1,
      anon_sym_DQUOTE,
    ACTIONS(903), 1,
      sym_prefix_operator,
    ACTIONS(907), 1,
      sym__uppercase_identifier,
    ACTIONS(909), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3067), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3069), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3855), 1,
      sym__lowercase_identifier,
    STATE(4140), 1,
      sym__constructor_name,
    STATE(4251), 1,
      sym_parenthesized_operator,
    STATE(4331), 1,
      sym__simple_expression,
    STATE(4385), 1,
      sym__value_name,
    STATE(4462), 1,
      sym_attribute,
    STATE(18727), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(867), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4134), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4323), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123121] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6167), 1,
      sym__lowercase_identifier,
    ACTIONS(6171), 1,
      anon_sym_LPAREN,
    ACTIONS(6173), 1,
      anon_sym_LBRACK,
    ACTIONS(6177), 1,
      anon_sym_LBRACE,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(6181), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6183), 1,
      anon_sym_new,
    ACTIONS(6185), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6187), 1,
      anon_sym_begin,
    ACTIONS(6189), 1,
      sym_ocamlyacc_value,
    ACTIONS(6195), 1,
      aux_sym_number_token1,
    ACTIONS(6197), 1,
      anon_sym_SQUOTE,
    ACTIONS(6199), 1,
      anon_sym_DQUOTE,
    ACTIONS(6201), 1,
      sym_prefix_operator,
    ACTIONS(6203), 1,
      sym__uppercase_identifier,
    ACTIONS(6205), 1,
      aux_sym_tag_token1,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4464), 1,
      sym_attribute,
    STATE(6482), 1,
      sym__simple_expression,
    STATE(6525), 1,
      sym__value_name,
    STATE(6548), 1,
      sym_parenthesized_operator,
    STATE(6640), 1,
      sym__constructor_name,
    STATE(20775), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6175), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6688), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6477), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123239] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6167), 1,
      sym__lowercase_identifier,
    ACTIONS(6171), 1,
      anon_sym_LPAREN,
    ACTIONS(6173), 1,
      anon_sym_LBRACK,
    ACTIONS(6177), 1,
      anon_sym_LBRACE,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(6181), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6183), 1,
      anon_sym_new,
    ACTIONS(6185), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6187), 1,
      anon_sym_begin,
    ACTIONS(6189), 1,
      sym_ocamlyacc_value,
    ACTIONS(6195), 1,
      aux_sym_number_token1,
    ACTIONS(6197), 1,
      anon_sym_SQUOTE,
    ACTIONS(6199), 1,
      anon_sym_DQUOTE,
    ACTIONS(6201), 1,
      sym_prefix_operator,
    ACTIONS(6203), 1,
      sym__uppercase_identifier,
    ACTIONS(6205), 1,
      aux_sym_tag_token1,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4465), 1,
      sym_attribute,
    STATE(6493), 1,
      sym__simple_expression,
    STATE(6525), 1,
      sym__value_name,
    STATE(6548), 1,
      sym_parenthesized_operator,
    STATE(6640), 1,
      sym__constructor_name,
    STATE(20775), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6175), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6688), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6477), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123357] = 29,
    ACTIONS(863), 1,
      anon_sym_LPAREN,
    ACTIONS(865), 1,
      anon_sym_LBRACK,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_object,
    ACTIONS(875), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(885), 1,
      anon_sym_new,
    ACTIONS(887), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(889), 1,
      anon_sym_begin,
    ACTIONS(891), 1,
      sym_ocamlyacc_value,
    ACTIONS(897), 1,
      aux_sym_number_token1,
    ACTIONS(899), 1,
      anon_sym_SQUOTE,
    ACTIONS(901), 1,
      anon_sym_DQUOTE,
    ACTIONS(903), 1,
      sym_prefix_operator,
    ACTIONS(907), 1,
      sym__uppercase_identifier,
    ACTIONS(909), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3067), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3069), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3855), 1,
      sym__lowercase_identifier,
    STATE(4140), 1,
      sym__constructor_name,
    STATE(4251), 1,
      sym_parenthesized_operator,
    STATE(4349), 1,
      sym__simple_expression,
    STATE(4385), 1,
      sym__value_name,
    STATE(4466), 1,
      sym_attribute,
    STATE(18727), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(867), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4134), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4323), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [123475] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123545] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123685] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [123755] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [123895] = 29,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      anon_sym_LBRACK,
    ACTIONS(57), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_object,
    ACTIONS(73), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(91), 1,
      anon_sym_new,
    ACTIONS(93), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(95), 1,
      anon_sym_begin,
    ACTIONS(97), 1,
      sym_ocamlyacc_value,
    ACTIONS(103), 1,
      aux_sym_number_token1,
    ACTIONS(107), 1,
      anon_sym_SQUOTE,
    ACTIONS(109), 1,
      anon_sym_DQUOTE,
    ACTIONS(111), 1,
      sym_prefix_operator,
    ACTIONS(119), 1,
      sym__uppercase_identifier,
    ACTIONS(123), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3087), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3089), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3935), 1,
      sym__lowercase_identifier,
    STATE(4446), 1,
      sym__value_name,
    STATE(4448), 1,
      sym__constructor_name,
    STATE(4473), 1,
      sym_attribute,
    STATE(4628), 1,
      sym__simple_expression,
    STATE(4662), 1,
      sym_parenthesized_operator,
    STATE(21079), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(53), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4421), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4471), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124013] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    STATE(4474), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15479), 1,
      sym__simple_expression,
    STATE(20850), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124131] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2657), 1,
      anon_sym_LPAREN,
    ACTIONS(2659), 1,
      anon_sym_LBRACK,
    ACTIONS(2663), 1,
      anon_sym_LBRACE,
    ACTIONS(2665), 1,
      anon_sym_object,
    ACTIONS(2669), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2679), 1,
      anon_sym_new,
    ACTIONS(2681), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2683), 1,
      anon_sym_begin,
    ACTIONS(2685), 1,
      sym_ocamlyacc_value,
    ACTIONS(2687), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2689), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2691), 1,
      aux_sym_number_token1,
    ACTIONS(2693), 1,
      anon_sym_SQUOTE,
    ACTIONS(2695), 1,
      anon_sym_DQUOTE,
    ACTIONS(2697), 1,
      sym_prefix_operator,
    ACTIONS(2701), 1,
      sym__uppercase_identifier,
    ACTIONS(2703), 1,
      aux_sym_tag_token1,
    ACTIONS(5573), 1,
      sym__lowercase_identifier,
    STATE(4475), 1,
      sym_attribute,
    STATE(7153), 1,
      sym__simple_expression,
    STATE(7160), 1,
      sym__constructor_name,
    STATE(7189), 1,
      sym__value_name,
    STATE(7418), 1,
      sym_parenthesized_operator,
    STATE(18498), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7324), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7186), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124249] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(4476), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9252), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [124367] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124507] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124577] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124647] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124717] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3939), 1,
      anon_sym_DOT,
    ACTIONS(3941), 1,
      anon_sym_POUND,
    ACTIONS(3943), 1,
      sym_hash_operator,
    STATE(4482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124863] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [124933] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125003] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125143] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4189), 1,
      anon_sym_DOT,
    STATE(4488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125215] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(4489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125287] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125357] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125427] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125497] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2355), 1,
      anon_sym_LPAREN,
    ACTIONS(2357), 1,
      anon_sym_LBRACK,
    ACTIONS(2361), 1,
      anon_sym_LBRACE,
    ACTIONS(2363), 1,
      anon_sym_object,
    ACTIONS(2367), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2377), 1,
      anon_sym_new,
    ACTIONS(2379), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2381), 1,
      anon_sym_begin,
    ACTIONS(2383), 1,
      sym_ocamlyacc_value,
    ACTIONS(2385), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2387), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2389), 1,
      aux_sym_number_token1,
    ACTIONS(2391), 1,
      anon_sym_SQUOTE,
    ACTIONS(2393), 1,
      anon_sym_DQUOTE,
    ACTIONS(2395), 1,
      sym_prefix_operator,
    ACTIONS(2399), 1,
      sym__uppercase_identifier,
    ACTIONS(2401), 1,
      aux_sym_tag_token1,
    ACTIONS(5355), 1,
      sym__lowercase_identifier,
    STATE(4493), 1,
      sym_attribute,
    STATE(6587), 1,
      sym__constructor_name,
    STATE(6689), 1,
      sym__value_name,
    STATE(6779), 1,
      sym__simple_expression,
    STATE(6871), 1,
      sym_parenthesized_operator,
    STATE(19050), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2359), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6582), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6638), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [125685] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125755] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5695), 1,
      sym__lowercase_identifier,
    ACTIONS(5703), 1,
      anon_sym_LPAREN,
    ACTIONS(5705), 1,
      anon_sym_LBRACK,
    ACTIONS(5709), 1,
      anon_sym_LBRACE,
    ACTIONS(5711), 1,
      anon_sym_object,
    ACTIONS(5713), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5715), 1,
      anon_sym_new,
    ACTIONS(5717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5719), 1,
      anon_sym_begin,
    ACTIONS(5721), 1,
      sym_ocamlyacc_value,
    ACTIONS(5727), 1,
      aux_sym_number_token1,
    ACTIONS(5729), 1,
      anon_sym_SQUOTE,
    ACTIONS(5731), 1,
      anon_sym_DQUOTE,
    ACTIONS(5733), 1,
      sym_prefix_operator,
    ACTIONS(5735), 1,
      sym__uppercase_identifier,
    ACTIONS(5737), 1,
      aux_sym_tag_token1,
    ACTIONS(8658), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8660), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4496), 1,
      sym_attribute,
    STATE(6110), 1,
      sym__constructor_name,
    STATE(6283), 1,
      sym__simple_expression,
    STATE(6323), 1,
      sym__value_name,
    STATE(6342), 1,
      sym_parenthesized_operator,
    STATE(19291), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5707), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6109), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6278), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [125873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [125943] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5695), 1,
      sym__lowercase_identifier,
    ACTIONS(5703), 1,
      anon_sym_LPAREN,
    ACTIONS(5705), 1,
      anon_sym_LBRACK,
    ACTIONS(5709), 1,
      anon_sym_LBRACE,
    ACTIONS(5711), 1,
      anon_sym_object,
    ACTIONS(5713), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5715), 1,
      anon_sym_new,
    ACTIONS(5717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5719), 1,
      anon_sym_begin,
    ACTIONS(5721), 1,
      sym_ocamlyacc_value,
    ACTIONS(5727), 1,
      aux_sym_number_token1,
    ACTIONS(5729), 1,
      anon_sym_SQUOTE,
    ACTIONS(5731), 1,
      anon_sym_DQUOTE,
    ACTIONS(5733), 1,
      sym_prefix_operator,
    ACTIONS(5735), 1,
      sym__uppercase_identifier,
    ACTIONS(5737), 1,
      aux_sym_tag_token1,
    ACTIONS(8658), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8660), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4498), 1,
      sym_attribute,
    STATE(6110), 1,
      sym__constructor_name,
    STATE(6293), 1,
      sym__simple_expression,
    STATE(6323), 1,
      sym__value_name,
    STATE(6342), 1,
      sym_parenthesized_operator,
    STATE(19291), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5707), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6109), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6278), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126061] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2709), 1,
      anon_sym_LPAREN,
    ACTIONS(2711), 1,
      anon_sym_LBRACK,
    ACTIONS(2715), 1,
      anon_sym_LBRACE,
    ACTIONS(2717), 1,
      anon_sym_object,
    ACTIONS(2721), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2731), 1,
      anon_sym_new,
    ACTIONS(2733), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2735), 1,
      anon_sym_begin,
    ACTIONS(2737), 1,
      sym_ocamlyacc_value,
    ACTIONS(2739), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2741), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2743), 1,
      aux_sym_number_token1,
    ACTIONS(2745), 1,
      anon_sym_SQUOTE,
    ACTIONS(2747), 1,
      anon_sym_DQUOTE,
    ACTIONS(2749), 1,
      sym_prefix_operator,
    ACTIONS(2753), 1,
      sym__uppercase_identifier,
    ACTIONS(2755), 1,
      aux_sym_tag_token1,
    ACTIONS(5593), 1,
      sym__lowercase_identifier,
    STATE(4499), 1,
      sym_attribute,
    STATE(7315), 1,
      sym_parenthesized_operator,
    STATE(7481), 1,
      sym__simple_expression,
    STATE(7502), 1,
      sym__constructor_name,
    STATE(7516), 1,
      sym__value_name,
    STATE(19506), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7279), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7511), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126179] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(4500), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5828), 1,
      sym__binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [126315] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126385] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2251), 1,
      anon_sym_LPAREN,
    ACTIONS(2253), 1,
      anon_sym_LBRACK,
    ACTIONS(2257), 1,
      anon_sym_LBRACE,
    ACTIONS(2259), 1,
      anon_sym_object,
    ACTIONS(2263), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2273), 1,
      anon_sym_new,
    ACTIONS(2275), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2277), 1,
      anon_sym_begin,
    ACTIONS(2279), 1,
      sym_ocamlyacc_value,
    ACTIONS(2281), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2283), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2285), 1,
      aux_sym_number_token1,
    ACTIONS(2287), 1,
      anon_sym_SQUOTE,
    ACTIONS(2289), 1,
      anon_sym_DQUOTE,
    ACTIONS(2291), 1,
      sym_prefix_operator,
    ACTIONS(2295), 1,
      sym__uppercase_identifier,
    ACTIONS(2297), 1,
      aux_sym_tag_token1,
    ACTIONS(5365), 1,
      sym__lowercase_identifier,
    STATE(4502), 1,
      sym_attribute,
    STATE(6727), 1,
      sym__constructor_name,
    STATE(6737), 1,
      sym__value_name,
    STATE(6832), 1,
      sym__simple_expression,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(19091), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6726), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6686), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126503] = 29,
    ACTIONS(707), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_LBRACK,
    ACTIONS(713), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      anon_sym_object,
    ACTIONS(719), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(729), 1,
      anon_sym_new,
    ACTIONS(731), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(733), 1,
      anon_sym_begin,
    ACTIONS(735), 1,
      sym_ocamlyacc_value,
    ACTIONS(741), 1,
      aux_sym_number_token1,
    ACTIONS(743), 1,
      anon_sym_SQUOTE,
    ACTIONS(745), 1,
      anon_sym_DQUOTE,
    ACTIONS(747), 1,
      sym_prefix_operator,
    ACTIONS(751), 1,
      sym__uppercase_identifier,
    ACTIONS(753), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3075), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3077), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3767), 1,
      sym__lowercase_identifier,
    STATE(3859), 1,
      sym__constructor_name,
    STATE(3949), 1,
      sym_parenthesized_operator,
    STATE(4024), 1,
      sym__simple_expression,
    STATE(4074), 1,
      sym__value_name,
    STATE(4503), 1,
      sym_attribute,
    STATE(19331), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(711), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3857), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4014), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [126621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [126691] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [126761] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4506), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14216), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [126897] = 29,
    ACTIONS(707), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_LBRACK,
    ACTIONS(713), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      anon_sym_object,
    ACTIONS(719), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(729), 1,
      anon_sym_new,
    ACTIONS(731), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(733), 1,
      anon_sym_begin,
    ACTIONS(735), 1,
      sym_ocamlyacc_value,
    ACTIONS(741), 1,
      aux_sym_number_token1,
    ACTIONS(743), 1,
      anon_sym_SQUOTE,
    ACTIONS(745), 1,
      anon_sym_DQUOTE,
    ACTIONS(747), 1,
      sym_prefix_operator,
    ACTIONS(751), 1,
      sym__uppercase_identifier,
    ACTIONS(753), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3075), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3077), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3767), 1,
      sym__lowercase_identifier,
    STATE(3859), 1,
      sym__constructor_name,
    STATE(3949), 1,
      sym_parenthesized_operator,
    STATE(4038), 1,
      sym__simple_expression,
    STATE(4074), 1,
      sym__value_name,
    STATE(4507), 1,
      sym_attribute,
    STATE(19331), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(711), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3857), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4014), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127015] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8662), 1,
      anon_sym_TILDE,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4508), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14129), 1,
      sym__tuple_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14982), 1,
      sym__binding_pattern,
    STATE(14989), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [127151] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4509), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14028), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14992), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [127287] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4510), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14726), 1,
      sym__binding_pattern,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [127423] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127493] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5469), 1,
      anon_sym_lazy,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    STATE(2966), 1,
      sym_constructor_path,
    STATE(3051), 1,
      sym_tag,
    STATE(4512), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14034), 1,
      sym__binding_pattern,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19588), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [127629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [127699] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2709), 1,
      anon_sym_LPAREN,
    ACTIONS(2711), 1,
      anon_sym_LBRACK,
    ACTIONS(2715), 1,
      anon_sym_LBRACE,
    ACTIONS(2717), 1,
      anon_sym_object,
    ACTIONS(2721), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2731), 1,
      anon_sym_new,
    ACTIONS(2733), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2735), 1,
      anon_sym_begin,
    ACTIONS(2737), 1,
      sym_ocamlyacc_value,
    ACTIONS(2739), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2741), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2743), 1,
      aux_sym_number_token1,
    ACTIONS(2745), 1,
      anon_sym_SQUOTE,
    ACTIONS(2747), 1,
      anon_sym_DQUOTE,
    ACTIONS(2749), 1,
      sym_prefix_operator,
    ACTIONS(2753), 1,
      sym__uppercase_identifier,
    ACTIONS(2755), 1,
      aux_sym_tag_token1,
    ACTIONS(5593), 1,
      sym__lowercase_identifier,
    STATE(4514), 1,
      sym_attribute,
    STATE(7136), 1,
      sym__simple_expression,
    STATE(7315), 1,
      sym_parenthesized_operator,
    STATE(7502), 1,
      sym__constructor_name,
    STATE(7516), 1,
      sym__value_name,
    STATE(19506), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7279), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7511), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [127817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [127957] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128027] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128097] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2657), 1,
      anon_sym_LPAREN,
    ACTIONS(2659), 1,
      anon_sym_LBRACK,
    ACTIONS(2663), 1,
      anon_sym_LBRACE,
    ACTIONS(2665), 1,
      anon_sym_object,
    ACTIONS(2669), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2679), 1,
      anon_sym_new,
    ACTIONS(2681), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2683), 1,
      anon_sym_begin,
    ACTIONS(2685), 1,
      sym_ocamlyacc_value,
    ACTIONS(2687), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2689), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2691), 1,
      aux_sym_number_token1,
    ACTIONS(2693), 1,
      anon_sym_SQUOTE,
    ACTIONS(2695), 1,
      anon_sym_DQUOTE,
    ACTIONS(2697), 1,
      sym_prefix_operator,
    ACTIONS(2701), 1,
      sym__uppercase_identifier,
    ACTIONS(2703), 1,
      aux_sym_tag_token1,
    ACTIONS(5573), 1,
      sym__lowercase_identifier,
    STATE(4519), 1,
      sym_attribute,
    STATE(7160), 1,
      sym__constructor_name,
    STATE(7189), 1,
      sym__value_name,
    STATE(7214), 1,
      sym__simple_expression,
    STATE(7418), 1,
      sym_parenthesized_operator,
    STATE(18498), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7324), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7186), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128215] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128285] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4521), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5390), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128403] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2511), 1,
      anon_sym_LPAREN,
    ACTIONS(2513), 1,
      anon_sym_LBRACK,
    ACTIONS(2517), 1,
      anon_sym_LBRACE,
    ACTIONS(2519), 1,
      anon_sym_object,
    ACTIONS(2523), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2533), 1,
      anon_sym_new,
    ACTIONS(2535), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2537), 1,
      anon_sym_begin,
    ACTIONS(2539), 1,
      sym_ocamlyacc_value,
    ACTIONS(2541), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2543), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2545), 1,
      aux_sym_number_token1,
    ACTIONS(2547), 1,
      anon_sym_SQUOTE,
    ACTIONS(2549), 1,
      anon_sym_DQUOTE,
    ACTIONS(2551), 1,
      sym_prefix_operator,
    ACTIONS(2555), 1,
      sym__uppercase_identifier,
    ACTIONS(2557), 1,
      aux_sym_tag_token1,
    ACTIONS(5385), 1,
      sym__lowercase_identifier,
    STATE(4522), 1,
      sym_attribute,
    STATE(6792), 1,
      sym__value_name,
    STATE(6859), 1,
      sym__simple_expression,
    STATE(6882), 1,
      sym__constructor_name,
    STATE(6922), 1,
      sym_parenthesized_operator,
    STATE(19171), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2515), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6880), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6736), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128521] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [128591] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6387), 1,
      sym__lowercase_identifier,
    ACTIONS(6391), 1,
      anon_sym_LPAREN,
    ACTIONS(6393), 1,
      anon_sym_LBRACK,
    ACTIONS(6397), 1,
      anon_sym_LBRACE,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(6401), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6403), 1,
      anon_sym_new,
    ACTIONS(6405), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6407), 1,
      anon_sym_begin,
    ACTIONS(6409), 1,
      sym_ocamlyacc_value,
    ACTIONS(6415), 1,
      aux_sym_number_token1,
    ACTIONS(6417), 1,
      anon_sym_SQUOTE,
    ACTIONS(6419), 1,
      anon_sym_DQUOTE,
    ACTIONS(6421), 1,
      sym_prefix_operator,
    ACTIONS(6423), 1,
      sym__uppercase_identifier,
    ACTIONS(6425), 1,
      aux_sym_tag_token1,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4524), 1,
      sym_attribute,
    STATE(7134), 1,
      sym__constructor_name,
    STATE(7373), 1,
      sym__simple_expression,
    STATE(7422), 1,
      sym__value_name,
    STATE(7501), 1,
      sym_parenthesized_operator,
    STATE(19371), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6395), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7133), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7367), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128709] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6387), 1,
      sym__lowercase_identifier,
    ACTIONS(6391), 1,
      anon_sym_LPAREN,
    ACTIONS(6393), 1,
      anon_sym_LBRACK,
    ACTIONS(6397), 1,
      anon_sym_LBRACE,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(6401), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6403), 1,
      anon_sym_new,
    ACTIONS(6405), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6407), 1,
      anon_sym_begin,
    ACTIONS(6409), 1,
      sym_ocamlyacc_value,
    ACTIONS(6415), 1,
      aux_sym_number_token1,
    ACTIONS(6417), 1,
      anon_sym_SQUOTE,
    ACTIONS(6419), 1,
      anon_sym_DQUOTE,
    ACTIONS(6421), 1,
      sym_prefix_operator,
    ACTIONS(6423), 1,
      sym__uppercase_identifier,
    ACTIONS(6425), 1,
      aux_sym_tag_token1,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4525), 1,
      sym_attribute,
    STATE(7134), 1,
      sym__constructor_name,
    STATE(7386), 1,
      sym__simple_expression,
    STATE(7422), 1,
      sym__value_name,
    STATE(7501), 1,
      sym_parenthesized_operator,
    STATE(19371), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6395), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7133), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7367), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [128827] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [128897] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8668), 1,
      anon_sym_COLON,
    STATE(4527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [128969] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129039] = 29,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      anon_sym_LBRACK,
    ACTIONS(57), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_object,
    ACTIONS(73), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(91), 1,
      anon_sym_new,
    ACTIONS(93), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(95), 1,
      anon_sym_begin,
    ACTIONS(97), 1,
      sym_ocamlyacc_value,
    ACTIONS(103), 1,
      aux_sym_number_token1,
    ACTIONS(107), 1,
      anon_sym_SQUOTE,
    ACTIONS(109), 1,
      anon_sym_DQUOTE,
    ACTIONS(111), 1,
      sym_prefix_operator,
    ACTIONS(119), 1,
      sym__uppercase_identifier,
    ACTIONS(123), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3087), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3089), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3935), 1,
      sym__lowercase_identifier,
    STATE(4446), 1,
      sym__value_name,
    STATE(4448), 1,
      sym__constructor_name,
    STATE(4455), 1,
      sym__simple_expression,
    STATE(4529), 1,
      sym_attribute,
    STATE(4662), 1,
      sym_parenthesized_operator,
    STATE(21079), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(53), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4421), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4471), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129157] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129227] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4531), 1,
      sym_attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7879), 1,
      sym__simple_expression,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129415] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4533), 1,
      sym_attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7942), 1,
      sym__simple_expression,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129533] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4534), 1,
      sym_attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(7998), 1,
      sym__simple_expression,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129721] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129791] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2577), 1,
      anon_sym_LPAREN,
    ACTIONS(2579), 1,
      anon_sym_LBRACK,
    ACTIONS(2583), 1,
      anon_sym_LBRACE,
    ACTIONS(2585), 1,
      anon_sym_object,
    ACTIONS(2589), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2599), 1,
      anon_sym_new,
    ACTIONS(2601), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2603), 1,
      anon_sym_begin,
    ACTIONS(2605), 1,
      sym_ocamlyacc_value,
    ACTIONS(2607), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2609), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2611), 1,
      aux_sym_number_token1,
    ACTIONS(2613), 1,
      anon_sym_SQUOTE,
    ACTIONS(2615), 1,
      anon_sym_DQUOTE,
    ACTIONS(2617), 1,
      sym_prefix_operator,
    ACTIONS(2621), 1,
      sym__uppercase_identifier,
    ACTIONS(2623), 1,
      aux_sym_tag_token1,
    ACTIONS(5473), 1,
      sym__lowercase_identifier,
    STATE(4537), 1,
      sym_attribute,
    STATE(7093), 1,
      sym__value_name,
    STATE(7105), 1,
      sym__simple_expression,
    STATE(7150), 1,
      sym_parenthesized_operator,
    STATE(7340), 1,
      sym__constructor_name,
    STATE(18562), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2581), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7338), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7057), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [129909] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [129979] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2709), 1,
      anon_sym_LPAREN,
    ACTIONS(2711), 1,
      anon_sym_LBRACK,
    ACTIONS(2715), 1,
      anon_sym_LBRACE,
    ACTIONS(2717), 1,
      anon_sym_object,
    ACTIONS(2721), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2731), 1,
      anon_sym_new,
    ACTIONS(2733), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2735), 1,
      anon_sym_begin,
    ACTIONS(2737), 1,
      sym_ocamlyacc_value,
    ACTIONS(2739), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2741), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2743), 1,
      aux_sym_number_token1,
    ACTIONS(2745), 1,
      anon_sym_SQUOTE,
    ACTIONS(2747), 1,
      anon_sym_DQUOTE,
    ACTIONS(2749), 1,
      sym_prefix_operator,
    ACTIONS(2753), 1,
      sym__uppercase_identifier,
    ACTIONS(2755), 1,
      aux_sym_tag_token1,
    ACTIONS(5593), 1,
      sym__lowercase_identifier,
    STATE(4539), 1,
      sym_attribute,
    STATE(7315), 1,
      sym_parenthesized_operator,
    STATE(7478), 1,
      sym__simple_expression,
    STATE(7502), 1,
      sym__constructor_name,
    STATE(7516), 1,
      sym__value_name,
    STATE(19506), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7279), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7511), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130097] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130237] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130307] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130377] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1173), 1,
      anon_sym_LPAREN,
    ACTIONS(1175), 1,
      anon_sym_LBRACK,
    ACTIONS(1179), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      anon_sym_object,
    ACTIONS(1185), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1199), 1,
      anon_sym_new,
    ACTIONS(1201), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1203), 1,
      anon_sym_begin,
    ACTIONS(1205), 1,
      sym_ocamlyacc_value,
    ACTIONS(1207), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1209), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1211), 1,
      aux_sym_number_token1,
    ACTIONS(1213), 1,
      anon_sym_SQUOTE,
    ACTIONS(1215), 1,
      anon_sym_DQUOTE,
    ACTIONS(1217), 1,
      sym_prefix_operator,
    ACTIONS(1221), 1,
      sym__uppercase_identifier,
    ACTIONS(1223), 1,
      aux_sym_tag_token1,
    ACTIONS(4575), 1,
      sym__lowercase_identifier,
    STATE(4544), 1,
      sym_attribute,
    STATE(5154), 1,
      sym__value_name,
    STATE(5188), 1,
      sym__constructor_name,
    STATE(5253), 1,
      sym_parenthesized_operator,
    STATE(5260), 1,
      sym__simple_expression,
    STATE(18889), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1177), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5187), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5255), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [130565] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2303), 1,
      anon_sym_LPAREN,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_LBRACE,
    ACTIONS(2311), 1,
      anon_sym_object,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2325), 1,
      anon_sym_new,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2329), 1,
      anon_sym_begin,
    ACTIONS(2331), 1,
      sym_ocamlyacc_value,
    ACTIONS(2333), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2335), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2337), 1,
      aux_sym_number_token1,
    ACTIONS(2339), 1,
      anon_sym_SQUOTE,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE,
    ACTIONS(2343), 1,
      sym_prefix_operator,
    ACTIONS(2347), 1,
      sym__uppercase_identifier,
    ACTIONS(2349), 1,
      aux_sym_tag_token1,
    ACTIONS(5345), 1,
      sym__lowercase_identifier,
    STATE(4546), 1,
      sym_attribute,
    STATE(6848), 1,
      sym__value_name,
    STATE(6888), 1,
      sym__simple_expression,
    STATE(6936), 1,
      sym_parenthesized_operator,
    STATE(7002), 1,
      sym__constructor_name,
    STATE(19211), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2307), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7001), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6791), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130683] = 29,
    ACTIONS(487), 1,
      anon_sym_LPAREN,
    ACTIONS(489), 1,
      anon_sym_LBRACK,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(495), 1,
      anon_sym_object,
    ACTIONS(499), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(509), 1,
      anon_sym_new,
    ACTIONS(511), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(513), 1,
      anon_sym_begin,
    ACTIONS(515), 1,
      sym_ocamlyacc_value,
    ACTIONS(521), 1,
      aux_sym_number_token1,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(527), 1,
      sym_prefix_operator,
    ACTIONS(531), 1,
      sym__uppercase_identifier,
    ACTIONS(533), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3059), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3061), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3701), 1,
      sym__lowercase_identifier,
    STATE(3554), 1,
      sym_parenthesized_operator,
    STATE(3640), 1,
      sym__value_name,
    STATE(3721), 1,
      sym__constructor_name,
    STATE(3782), 1,
      sym__simple_expression,
    STATE(4547), 1,
      sym_attribute,
    STATE(21100), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(491), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3574), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3757), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130801] = 29,
    ACTIONS(487), 1,
      anon_sym_LPAREN,
    ACTIONS(489), 1,
      anon_sym_LBRACK,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(495), 1,
      anon_sym_object,
    ACTIONS(499), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(509), 1,
      anon_sym_new,
    ACTIONS(511), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(513), 1,
      anon_sym_begin,
    ACTIONS(515), 1,
      sym_ocamlyacc_value,
    ACTIONS(521), 1,
      aux_sym_number_token1,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(527), 1,
      sym_prefix_operator,
    ACTIONS(531), 1,
      sym__uppercase_identifier,
    ACTIONS(533), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3059), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3061), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3701), 1,
      sym__lowercase_identifier,
    STATE(3554), 1,
      sym_parenthesized_operator,
    STATE(3640), 1,
      sym__value_name,
    STATE(3677), 1,
      sym__simple_expression,
    STATE(3721), 1,
      sym__constructor_name,
    STATE(4548), 1,
      sym_attribute,
    STATE(21100), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(491), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3574), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3757), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [130919] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4549), 1,
      sym_attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7931), 1,
      sym__simple_expression,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131107] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8498), 1,
      sym__lowercase_identifier,
    ACTIONS(8500), 1,
      anon_sym_LPAREN,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8506), 1,
      anon_sym_LBRACE,
    ACTIONS(8508), 1,
      anon_sym_object,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8512), 1,
      anon_sym_new,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8516), 1,
      anon_sym_begin,
    ACTIONS(8518), 1,
      sym_ocamlyacc_value,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8524), 1,
      aux_sym_number_token1,
    ACTIONS(8526), 1,
      anon_sym_SQUOTE,
    ACTIONS(8528), 1,
      anon_sym_DQUOTE,
    ACTIONS(8530), 1,
      sym_prefix_operator,
    ACTIONS(8532), 1,
      sym__uppercase_identifier,
    ACTIONS(8534), 1,
      aux_sym_tag_token1,
    STATE(4551), 1,
      sym_attribute,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7848), 1,
      sym__value_name,
    STATE(7960), 1,
      sym__simple_expression,
    STATE(7982), 1,
      sym__constructor_name,
    STATE(19411), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8504), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7912), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7824), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131225] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131295] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131365] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131435] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1173), 1,
      anon_sym_LPAREN,
    ACTIONS(1175), 1,
      anon_sym_LBRACK,
    ACTIONS(1179), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      anon_sym_object,
    ACTIONS(1185), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1199), 1,
      anon_sym_new,
    ACTIONS(1201), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1203), 1,
      anon_sym_begin,
    ACTIONS(1205), 1,
      sym_ocamlyacc_value,
    ACTIONS(1207), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1209), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1211), 1,
      aux_sym_number_token1,
    ACTIONS(1213), 1,
      anon_sym_SQUOTE,
    ACTIONS(1215), 1,
      anon_sym_DQUOTE,
    ACTIONS(1217), 1,
      sym_prefix_operator,
    ACTIONS(1221), 1,
      sym__uppercase_identifier,
    ACTIONS(1223), 1,
      aux_sym_tag_token1,
    ACTIONS(4575), 1,
      sym__lowercase_identifier,
    STATE(4555), 1,
      sym_attribute,
    STATE(5154), 1,
      sym__value_name,
    STATE(5188), 1,
      sym__constructor_name,
    STATE(5253), 1,
      sym_parenthesized_operator,
    STATE(5269), 1,
      sym__simple_expression,
    STATE(18889), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1177), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5187), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5255), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131553] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2657), 1,
      anon_sym_LPAREN,
    ACTIONS(2659), 1,
      anon_sym_LBRACK,
    ACTIONS(2663), 1,
      anon_sym_LBRACE,
    ACTIONS(2665), 1,
      anon_sym_object,
    ACTIONS(2669), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2679), 1,
      anon_sym_new,
    ACTIONS(2681), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2683), 1,
      anon_sym_begin,
    ACTIONS(2685), 1,
      sym_ocamlyacc_value,
    ACTIONS(2687), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2689), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2691), 1,
      aux_sym_number_token1,
    ACTIONS(2693), 1,
      anon_sym_SQUOTE,
    ACTIONS(2695), 1,
      anon_sym_DQUOTE,
    ACTIONS(2697), 1,
      sym_prefix_operator,
    ACTIONS(2701), 1,
      sym__uppercase_identifier,
    ACTIONS(2703), 1,
      aux_sym_tag_token1,
    ACTIONS(5573), 1,
      sym__lowercase_identifier,
    STATE(4556), 1,
      sym_attribute,
    STATE(7160), 1,
      sym__constructor_name,
    STATE(7189), 1,
      sym__value_name,
    STATE(7292), 1,
      sym__simple_expression,
    STATE(7418), 1,
      sym_parenthesized_operator,
    STATE(18498), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7324), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7186), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131671] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    STATE(4557), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7613), 1,
      sym__simple_expression,
    STATE(20850), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [131789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131929] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [131999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132069] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132139] = 29,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(307), 1,
      anon_sym_LBRACK,
    ACTIONS(311), 1,
      anon_sym_LBRACE,
    ACTIONS(321), 1,
      anon_sym_object,
    ACTIONS(325), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(335), 1,
      anon_sym_new,
    ACTIONS(337), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(339), 1,
      anon_sym_begin,
    ACTIONS(341), 1,
      sym_ocamlyacc_value,
    ACTIONS(347), 1,
      aux_sym_number_token1,
    ACTIONS(349), 1,
      anon_sym_SQUOTE,
    ACTIONS(351), 1,
      anon_sym_DQUOTE,
    ACTIONS(353), 1,
      sym_prefix_operator,
    ACTIONS(359), 1,
      sym__uppercase_identifier,
    ACTIONS(363), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3039), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3041), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4185), 1,
      sym__lowercase_identifier,
    STATE(4563), 1,
      sym_attribute,
    STATE(4622), 1,
      sym__simple_expression,
    STATE(4691), 1,
      sym_parenthesized_operator,
    STATE(4737), 1,
      sym__value_name,
    STATE(4743), 1,
      sym__constructor_name,
    STATE(20799), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(309), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4735), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4695), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132327] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132397] = 29,
    ACTIONS(759), 1,
      anon_sym_LPAREN,
    ACTIONS(761), 1,
      anon_sym_LBRACK,
    ACTIONS(765), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_object,
    ACTIONS(771), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(781), 1,
      anon_sym_new,
    ACTIONS(783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(785), 1,
      anon_sym_begin,
    ACTIONS(787), 1,
      sym_ocamlyacc_value,
    ACTIONS(793), 1,
      aux_sym_number_token1,
    ACTIONS(795), 1,
      anon_sym_SQUOTE,
    ACTIONS(797), 1,
      anon_sym_DQUOTE,
    ACTIONS(799), 1,
      sym_prefix_operator,
    ACTIONS(803), 1,
      sym__uppercase_identifier,
    ACTIONS(805), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3043), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3045), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3757), 1,
      sym__lowercase_identifier,
    STATE(3839), 1,
      sym__constructor_name,
    STATE(3867), 1,
      sym_parenthesized_operator,
    STATE(4010), 1,
      sym__value_name,
    STATE(4057), 1,
      sym__simple_expression,
    STATE(4566), 1,
      sym_attribute,
    STATE(19251), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(763), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3838), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3882), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132515] = 29,
    ACTIONS(919), 1,
      anon_sym_LPAREN,
    ACTIONS(921), 1,
      anon_sym_LBRACK,
    ACTIONS(925), 1,
      anon_sym_LBRACE,
    ACTIONS(927), 1,
      anon_sym_object,
    ACTIONS(931), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(949), 1,
      anon_sym_new,
    ACTIONS(951), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(953), 1,
      anon_sym_begin,
    ACTIONS(955), 1,
      sym_ocamlyacc_value,
    ACTIONS(961), 1,
      aux_sym_number_token1,
    ACTIONS(963), 1,
      anon_sym_SQUOTE,
    ACTIONS(965), 1,
      anon_sym_DQUOTE,
    ACTIONS(967), 1,
      sym_prefix_operator,
    ACTIONS(971), 1,
      sym__uppercase_identifier,
    ACTIONS(973), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3055), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3057), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4555), 1,
      sym__lowercase_identifier,
    STATE(4567), 1,
      sym_attribute,
    STATE(4913), 1,
      sym__value_name,
    STATE(4925), 1,
      sym__constructor_name,
    STATE(4967), 1,
      sym_parenthesized_operator,
    STATE(5024), 1,
      sym__simple_expression,
    STATE(19451), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4904), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4942), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132633] = 29,
    ACTIONS(919), 1,
      anon_sym_LPAREN,
    ACTIONS(921), 1,
      anon_sym_LBRACK,
    ACTIONS(925), 1,
      anon_sym_LBRACE,
    ACTIONS(927), 1,
      anon_sym_object,
    ACTIONS(931), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(949), 1,
      anon_sym_new,
    ACTIONS(951), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(953), 1,
      anon_sym_begin,
    ACTIONS(955), 1,
      sym_ocamlyacc_value,
    ACTIONS(961), 1,
      aux_sym_number_token1,
    ACTIONS(963), 1,
      anon_sym_SQUOTE,
    ACTIONS(965), 1,
      anon_sym_DQUOTE,
    ACTIONS(967), 1,
      sym_prefix_operator,
    ACTIONS(971), 1,
      sym__uppercase_identifier,
    ACTIONS(973), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3055), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3057), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4555), 1,
      sym__lowercase_identifier,
    STATE(4568), 1,
      sym_attribute,
    STATE(4913), 1,
      sym__value_name,
    STATE(4925), 1,
      sym__constructor_name,
    STATE(4967), 1,
      sym_parenthesized_operator,
    STATE(4975), 1,
      sym__simple_expression,
    STATE(19451), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4904), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4942), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [132751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [132821] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(4570), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5846), 1,
      sym__binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [132957] = 29,
    ACTIONS(707), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_LBRACK,
    ACTIONS(713), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      anon_sym_object,
    ACTIONS(719), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(729), 1,
      anon_sym_new,
    ACTIONS(731), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(733), 1,
      anon_sym_begin,
    ACTIONS(735), 1,
      sym_ocamlyacc_value,
    ACTIONS(741), 1,
      aux_sym_number_token1,
    ACTIONS(743), 1,
      anon_sym_SQUOTE,
    ACTIONS(745), 1,
      anon_sym_DQUOTE,
    ACTIONS(747), 1,
      sym_prefix_operator,
    ACTIONS(751), 1,
      sym__uppercase_identifier,
    ACTIONS(753), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3075), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3077), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3767), 1,
      sym__lowercase_identifier,
    STATE(3859), 1,
      sym__constructor_name,
    STATE(3949), 1,
      sym_parenthesized_operator,
    STATE(4074), 1,
      sym__value_name,
    STATE(4088), 1,
      sym__simple_expression,
    STATE(4571), 1,
      sym_attribute,
    STATE(19331), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(711), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3857), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4014), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133075] = 29,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(377), 1,
      anon_sym_LBRACK,
    ACTIONS(381), 1,
      anon_sym_LBRACE,
    ACTIONS(383), 1,
      anon_sym_object,
    ACTIONS(387), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(397), 1,
      anon_sym_new,
    ACTIONS(399), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(401), 1,
      anon_sym_begin,
    ACTIONS(403), 1,
      sym_ocamlyacc_value,
    ACTIONS(411), 1,
      aux_sym_number_token1,
    ACTIONS(413), 1,
      anon_sym_SQUOTE,
    ACTIONS(415), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym_prefix_operator,
    ACTIONS(423), 1,
      sym__uppercase_identifier,
    ACTIONS(425), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3189), 1,
      sym__lowercase_identifier,
    STATE(3260), 1,
      sym__simple_expression,
    STATE(3297), 1,
      sym__value_name,
    STATE(3362), 1,
      sym_parenthesized_operator,
    STATE(3463), 1,
      sym__constructor_name,
    STATE(4572), 1,
      sym_attribute,
    STATE(19490), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(379), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3462), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3250), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133193] = 29,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(377), 1,
      anon_sym_LBRACK,
    ACTIONS(381), 1,
      anon_sym_LBRACE,
    ACTIONS(383), 1,
      anon_sym_object,
    ACTIONS(387), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(397), 1,
      anon_sym_new,
    ACTIONS(399), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(401), 1,
      anon_sym_begin,
    ACTIONS(403), 1,
      sym_ocamlyacc_value,
    ACTIONS(411), 1,
      aux_sym_number_token1,
    ACTIONS(413), 1,
      anon_sym_SQUOTE,
    ACTIONS(415), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym_prefix_operator,
    ACTIONS(423), 1,
      sym__uppercase_identifier,
    ACTIONS(425), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3189), 1,
      sym__lowercase_identifier,
    STATE(3269), 1,
      sym__simple_expression,
    STATE(3297), 1,
      sym__value_name,
    STATE(3362), 1,
      sym_parenthesized_operator,
    STATE(3463), 1,
      sym__constructor_name,
    STATE(4573), 1,
      sym_attribute,
    STATE(19490), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(379), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3462), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3250), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133311] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(4574), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5650), 1,
      sym__binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [133447] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8670), 1,
      anon_sym_TILDE,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(4575), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5653), 1,
      sym__binding_pattern,
    STATE(5689), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(5690), 1,
      sym__tuple_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [133583] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(4576), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5725), 1,
      sym__binding_pattern,
    STATE(5738), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [133719] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(4577), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(5743), 1,
      sym__binding_pattern,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [133855] = 29,
    ACTIONS(919), 1,
      anon_sym_LPAREN,
    ACTIONS(921), 1,
      anon_sym_LBRACK,
    ACTIONS(925), 1,
      anon_sym_LBRACE,
    ACTIONS(927), 1,
      anon_sym_object,
    ACTIONS(931), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(949), 1,
      anon_sym_new,
    ACTIONS(951), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(953), 1,
      anon_sym_begin,
    ACTIONS(955), 1,
      sym_ocamlyacc_value,
    ACTIONS(961), 1,
      aux_sym_number_token1,
    ACTIONS(963), 1,
      anon_sym_SQUOTE,
    ACTIONS(965), 1,
      anon_sym_DQUOTE,
    ACTIONS(967), 1,
      sym_prefix_operator,
    ACTIONS(971), 1,
      sym__uppercase_identifier,
    ACTIONS(973), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3055), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3057), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4555), 1,
      sym__lowercase_identifier,
    STATE(4578), 1,
      sym_attribute,
    STATE(4913), 1,
      sym__value_name,
    STATE(4925), 1,
      sym__constructor_name,
    STATE(4967), 1,
      sym_parenthesized_operator,
    STATE(5023), 1,
      sym__simple_expression,
    STATE(19451), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4904), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4942), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [133973] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134043] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2407), 1,
      anon_sym_LPAREN,
    ACTIONS(2409), 1,
      anon_sym_LBRACK,
    ACTIONS(2413), 1,
      anon_sym_LBRACE,
    ACTIONS(2415), 1,
      anon_sym_object,
    ACTIONS(2419), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2429), 1,
      anon_sym_new,
    ACTIONS(2431), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2433), 1,
      anon_sym_begin,
    ACTIONS(2435), 1,
      sym_ocamlyacc_value,
    ACTIONS(2437), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2439), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2441), 1,
      aux_sym_number_token1,
    ACTIONS(2443), 1,
      anon_sym_SQUOTE,
    ACTIONS(2445), 1,
      anon_sym_DQUOTE,
    ACTIONS(2447), 1,
      sym_prefix_operator,
    ACTIONS(2451), 1,
      sym__uppercase_identifier,
    ACTIONS(2453), 1,
      aux_sym_tag_token1,
    ACTIONS(5375), 1,
      sym__lowercase_identifier,
    STATE(4580), 1,
      sym_attribute,
    STATE(6431), 1,
      sym__constructor_name,
    STATE(6682), 1,
      sym_parenthesized_operator,
    STATE(6956), 1,
      sym__simple_expression,
    STATE(6991), 1,
      sym__value_name,
    STATE(19529), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2411), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6430), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6951), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134161] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2407), 1,
      anon_sym_LPAREN,
    ACTIONS(2409), 1,
      anon_sym_LBRACK,
    ACTIONS(2413), 1,
      anon_sym_LBRACE,
    ACTIONS(2415), 1,
      anon_sym_object,
    ACTIONS(2419), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2429), 1,
      anon_sym_new,
    ACTIONS(2431), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2433), 1,
      anon_sym_begin,
    ACTIONS(2435), 1,
      sym_ocamlyacc_value,
    ACTIONS(2437), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2439), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2441), 1,
      aux_sym_number_token1,
    ACTIONS(2443), 1,
      anon_sym_SQUOTE,
    ACTIONS(2445), 1,
      anon_sym_DQUOTE,
    ACTIONS(2447), 1,
      sym_prefix_operator,
    ACTIONS(2451), 1,
      sym__uppercase_identifier,
    ACTIONS(2453), 1,
      aux_sym_tag_token1,
    ACTIONS(5375), 1,
      sym__lowercase_identifier,
    STATE(4581), 1,
      sym_attribute,
    STATE(6431), 1,
      sym__constructor_name,
    STATE(6682), 1,
      sym_parenthesized_operator,
    STATE(6966), 1,
      sym__simple_expression,
    STATE(6991), 1,
      sym__value_name,
    STATE(19529), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2411), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6430), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6951), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134279] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2813), 1,
      anon_sym_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2819), 1,
      anon_sym_LBRACE,
    ACTIONS(2821), 1,
      anon_sym_object,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2835), 1,
      anon_sym_new,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2839), 1,
      anon_sym_begin,
    ACTIONS(2841), 1,
      sym_ocamlyacc_value,
    ACTIONS(2843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2847), 1,
      aux_sym_number_token1,
    ACTIONS(2849), 1,
      anon_sym_SQUOTE,
    ACTIONS(2851), 1,
      anon_sym_DQUOTE,
    ACTIONS(2853), 1,
      sym_prefix_operator,
    ACTIONS(2857), 1,
      sym__uppercase_identifier,
    ACTIONS(2859), 1,
      aux_sym_tag_token1,
    ACTIONS(5553), 1,
      sym__lowercase_identifier,
    STATE(4582), 1,
      sym_attribute,
    STATE(7040), 1,
      sym__constructor_name,
    STATE(7116), 1,
      sym_parenthesized_operator,
    STATE(7325), 1,
      sym__value_name,
    STATE(7374), 1,
      sym__simple_expression,
    STATE(19882), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2817), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7039), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7319), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134397] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(8026), 1,
      anon_sym_LPAREN,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8030), 1,
      anon_sym_LBRACE,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8040), 1,
      anon_sym_begin,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8044), 1,
      sym_prefix_operator,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    STATE(4583), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(15093), 1,
      sym__simple_expression,
    STATE(20850), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [134515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134585] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(4585), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(5932), 1,
      sym__binding_pattern,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [134721] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [134791] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4685), 1,
      anon_sym_lazy,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2477), 1,
      sym_constructor_path,
    STATE(2482), 1,
      sym_tag,
    STATE(4587), 1,
      sym_attribute,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5571), 1,
      sym__signed_constant,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5610), 1,
      sym__binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5737), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5740), 1,
      sym__tuple_binding_pattern,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(20855), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5728), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5736), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [134927] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(4588), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7866), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135045] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2459), 1,
      anon_sym_LPAREN,
    ACTIONS(2461), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_LBRACE,
    ACTIONS(2467), 1,
      anon_sym_object,
    ACTIONS(2471), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2481), 1,
      anon_sym_new,
    ACTIONS(2483), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2485), 1,
      anon_sym_begin,
    ACTIONS(2487), 1,
      sym_ocamlyacc_value,
    ACTIONS(2489), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2491), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2493), 1,
      aux_sym_number_token1,
    ACTIONS(2495), 1,
      anon_sym_SQUOTE,
    ACTIONS(2497), 1,
      anon_sym_DQUOTE,
    ACTIONS(2499), 1,
      sym_prefix_operator,
    ACTIONS(2503), 1,
      sym__uppercase_identifier,
    ACTIONS(2505), 1,
      aux_sym_tag_token1,
    ACTIONS(5275), 1,
      sym__lowercase_identifier,
    STATE(4589), 1,
      sym_attribute,
    STATE(6590), 1,
      sym__value_name,
    STATE(6596), 1,
      sym__simple_expression,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(6929), 1,
      sym__constructor_name,
    STATE(18617), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2463), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6928), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6549), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135163] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1121), 1,
      anon_sym_LPAREN,
    ACTIONS(1123), 1,
      anon_sym_LBRACK,
    ACTIONS(1127), 1,
      anon_sym_LBRACE,
    ACTIONS(1129), 1,
      anon_sym_object,
    ACTIONS(1133), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1143), 1,
      anon_sym_new,
    ACTIONS(1145), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1147), 1,
      anon_sym_begin,
    ACTIONS(1149), 1,
      sym_ocamlyacc_value,
    ACTIONS(1151), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1153), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1155), 1,
      aux_sym_number_token1,
    ACTIONS(1157), 1,
      anon_sym_SQUOTE,
    ACTIONS(1159), 1,
      anon_sym_DQUOTE,
    ACTIONS(1161), 1,
      sym_prefix_operator,
    ACTIONS(1165), 1,
      sym__uppercase_identifier,
    ACTIONS(1167), 1,
      aux_sym_tag_token1,
    ACTIONS(4705), 1,
      sym__lowercase_identifier,
    STATE(4590), 1,
      sym_attribute,
    STATE(5466), 1,
      sym__simple_expression,
    STATE(5522), 1,
      sym_parenthesized_operator,
    STATE(5526), 1,
      sym__constructor_name,
    STATE(5532), 1,
      sym__value_name,
    STATE(18943), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1125), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5554), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135281] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2813), 1,
      anon_sym_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2819), 1,
      anon_sym_LBRACE,
    ACTIONS(2821), 1,
      anon_sym_object,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2835), 1,
      anon_sym_new,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2839), 1,
      anon_sym_begin,
    ACTIONS(2841), 1,
      sym_ocamlyacc_value,
    ACTIONS(2843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2847), 1,
      aux_sym_number_token1,
    ACTIONS(2849), 1,
      anon_sym_SQUOTE,
    ACTIONS(2851), 1,
      anon_sym_DQUOTE,
    ACTIONS(2853), 1,
      sym_prefix_operator,
    ACTIONS(2857), 1,
      sym__uppercase_identifier,
    ACTIONS(2859), 1,
      aux_sym_tag_token1,
    ACTIONS(5553), 1,
      sym__lowercase_identifier,
    STATE(4591), 1,
      sym_attribute,
    STATE(7040), 1,
      sym__constructor_name,
    STATE(7116), 1,
      sym_parenthesized_operator,
    STATE(7241), 1,
      sym__simple_expression,
    STATE(7325), 1,
      sym__value_name,
    STATE(19882), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2817), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7039), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7319), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135399] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1121), 1,
      anon_sym_LPAREN,
    ACTIONS(1123), 1,
      anon_sym_LBRACK,
    ACTIONS(1127), 1,
      anon_sym_LBRACE,
    ACTIONS(1129), 1,
      anon_sym_object,
    ACTIONS(1133), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1143), 1,
      anon_sym_new,
    ACTIONS(1145), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1147), 1,
      anon_sym_begin,
    ACTIONS(1149), 1,
      sym_ocamlyacc_value,
    ACTIONS(1151), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1153), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1155), 1,
      aux_sym_number_token1,
    ACTIONS(1157), 1,
      anon_sym_SQUOTE,
    ACTIONS(1159), 1,
      anon_sym_DQUOTE,
    ACTIONS(1161), 1,
      sym_prefix_operator,
    ACTIONS(1165), 1,
      sym__uppercase_identifier,
    ACTIONS(1167), 1,
      aux_sym_tag_token1,
    ACTIONS(4705), 1,
      sym__lowercase_identifier,
    STATE(4592), 1,
      sym_attribute,
    STATE(5482), 1,
      sym__simple_expression,
    STATE(5522), 1,
      sym_parenthesized_operator,
    STATE(5526), 1,
      sym__constructor_name,
    STATE(5532), 1,
      sym__value_name,
    STATE(18943), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1125), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5523), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5554), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135517] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8672), 1,
      anon_sym_TILDE,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(4593), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(5935), 1,
      sym__binding_pattern,
    STATE(5938), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(5946), 1,
      sym__tuple_binding_pattern,
    STATE(19898), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [135653] = 29,
    ACTIONS(375), 1,
      anon_sym_LPAREN,
    ACTIONS(377), 1,
      anon_sym_LBRACK,
    ACTIONS(381), 1,
      anon_sym_LBRACE,
    ACTIONS(383), 1,
      anon_sym_object,
    ACTIONS(387), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(397), 1,
      anon_sym_new,
    ACTIONS(399), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(401), 1,
      anon_sym_begin,
    ACTIONS(403), 1,
      sym_ocamlyacc_value,
    ACTIONS(411), 1,
      aux_sym_number_token1,
    ACTIONS(413), 1,
      anon_sym_SQUOTE,
    ACTIONS(415), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym_prefix_operator,
    ACTIONS(423), 1,
      sym__uppercase_identifier,
    ACTIONS(425), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3189), 1,
      sym__lowercase_identifier,
    STATE(3290), 1,
      sym__simple_expression,
    STATE(3297), 1,
      sym__value_name,
    STATE(3362), 1,
      sym_parenthesized_operator,
    STATE(3463), 1,
      sym__constructor_name,
    STATE(4594), 1,
      sym_attribute,
    STATE(19490), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(379), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3462), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3250), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135771] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1981), 1,
      anon_sym_LPAREN,
    ACTIONS(1983), 1,
      anon_sym_LBRACK,
    ACTIONS(1987), 1,
      anon_sym_LBRACE,
    ACTIONS(1989), 1,
      anon_sym_object,
    ACTIONS(1993), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2003), 1,
      anon_sym_new,
    ACTIONS(2005), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2007), 1,
      anon_sym_begin,
    ACTIONS(2009), 1,
      sym_ocamlyacc_value,
    ACTIONS(2011), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2013), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2015), 1,
      aux_sym_number_token1,
    ACTIONS(2017), 1,
      anon_sym_SQUOTE,
    ACTIONS(2019), 1,
      anon_sym_DQUOTE,
    ACTIONS(2021), 1,
      sym_prefix_operator,
    ACTIONS(2025), 1,
      sym__uppercase_identifier,
    ACTIONS(2027), 1,
      aux_sym_tag_token1,
    ACTIONS(5265), 1,
      sym__lowercase_identifier,
    STATE(4595), 1,
      sym_attribute,
    STATE(6099), 1,
      sym_parenthesized_operator,
    STATE(6129), 1,
      sym__constructor_name,
    STATE(6360), 1,
      sym__simple_expression,
    STATE(6393), 1,
      sym__value_name,
    STATE(19567), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1985), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6128), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6355), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [135889] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1981), 1,
      anon_sym_LPAREN,
    ACTIONS(1983), 1,
      anon_sym_LBRACK,
    ACTIONS(1987), 1,
      anon_sym_LBRACE,
    ACTIONS(1989), 1,
      anon_sym_object,
    ACTIONS(1993), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2003), 1,
      anon_sym_new,
    ACTIONS(2005), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2007), 1,
      anon_sym_begin,
    ACTIONS(2009), 1,
      sym_ocamlyacc_value,
    ACTIONS(2011), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2013), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2015), 1,
      aux_sym_number_token1,
    ACTIONS(2017), 1,
      anon_sym_SQUOTE,
    ACTIONS(2019), 1,
      anon_sym_DQUOTE,
    ACTIONS(2021), 1,
      sym_prefix_operator,
    ACTIONS(2025), 1,
      sym__uppercase_identifier,
    ACTIONS(2027), 1,
      aux_sym_tag_token1,
    ACTIONS(5265), 1,
      sym__lowercase_identifier,
    STATE(4596), 1,
      sym_attribute,
    STATE(6099), 1,
      sym_parenthesized_operator,
    STATE(6129), 1,
      sym__constructor_name,
    STATE(6369), 1,
      sym__simple_expression,
    STATE(6393), 1,
      sym__value_name,
    STATE(19567), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1985), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6128), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6355), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [136007] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136077] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136147] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136287] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(4601), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(5954), 1,
      sym__binding_pattern,
    STATE(5955), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [136423] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4602), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14925), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [136559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [136699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [136769] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4606), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14216), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [136905] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6387), 1,
      sym__lowercase_identifier,
    ACTIONS(6391), 1,
      anon_sym_LPAREN,
    ACTIONS(6393), 1,
      anon_sym_LBRACK,
    ACTIONS(6397), 1,
      anon_sym_LBRACE,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(6401), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6403), 1,
      anon_sym_new,
    ACTIONS(6405), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6407), 1,
      anon_sym_begin,
    ACTIONS(6409), 1,
      sym_ocamlyacc_value,
    ACTIONS(6415), 1,
      aux_sym_number_token1,
    ACTIONS(6417), 1,
      anon_sym_SQUOTE,
    ACTIONS(6419), 1,
      anon_sym_DQUOTE,
    ACTIONS(6421), 1,
      sym_prefix_operator,
    ACTIONS(6423), 1,
      sym__uppercase_identifier,
    ACTIONS(6425), 1,
      aux_sym_tag_token1,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4607), 1,
      sym_attribute,
    STATE(7134), 1,
      sym__constructor_name,
    STATE(7154), 1,
      sym__simple_expression,
    STATE(7422), 1,
      sym__value_name,
    STATE(7501), 1,
      sym_parenthesized_operator,
    STATE(19371), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6395), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7133), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7367), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137023] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    ACTIONS(8674), 1,
      anon_sym_TILDE,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4608), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14129), 1,
      sym__tuple_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14428), 1,
      sym__binding_pattern,
    STATE(14429), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [137159] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4609), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14028), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14432), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [137295] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4610), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14434), 1,
      sym__binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [137431] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4611), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14034), 1,
      sym__binding_pattern,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [137567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137637] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(4613), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7818), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [137755] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [137965] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [138035] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(4618), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7873), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [138223] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8676), 1,
      anon_sym_TILDE,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(4620), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5606), 1,
      sym__binding_pattern,
    STATE(5607), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(5617), 1,
      sym__tuple_binding_pattern,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [138359] = 29,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(49), 1,
      anon_sym_LBRACK,
    ACTIONS(57), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_object,
    ACTIONS(73), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(91), 1,
      anon_sym_new,
    ACTIONS(93), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(95), 1,
      anon_sym_begin,
    ACTIONS(97), 1,
      sym_ocamlyacc_value,
    ACTIONS(103), 1,
      aux_sym_number_token1,
    ACTIONS(107), 1,
      anon_sym_SQUOTE,
    ACTIONS(109), 1,
      anon_sym_DQUOTE,
    ACTIONS(111), 1,
      sym_prefix_operator,
    ACTIONS(119), 1,
      sym__uppercase_identifier,
    ACTIONS(123), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3087), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3089), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3935), 1,
      sym__lowercase_identifier,
    STATE(4446), 1,
      sym__value_name,
    STATE(4448), 1,
      sym__constructor_name,
    STATE(4621), 1,
      sym_attribute,
    STATE(4662), 1,
      sym_parenthesized_operator,
    STATE(4760), 1,
      sym__simple_expression,
    STATE(21079), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(53), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4421), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4471), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138477] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4189), 1,
      anon_sym_DOT,
    ACTIONS(4191), 1,
      anon_sym_POUND,
    ACTIONS(4193), 1,
      sym_hash_operator,
    STATE(4622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [138553] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(4623), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(5880), 1,
      sym__binding_pattern,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [138689] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5811), 1,
      sym__lowercase_identifier,
    ACTIONS(5819), 1,
      anon_sym_LPAREN,
    ACTIONS(5821), 1,
      anon_sym_LBRACK,
    ACTIONS(5825), 1,
      anon_sym_LBRACE,
    ACTIONS(5827), 1,
      anon_sym_object,
    ACTIONS(5829), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5831), 1,
      anon_sym_new,
    ACTIONS(5833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5835), 1,
      anon_sym_begin,
    ACTIONS(5837), 1,
      sym_ocamlyacc_value,
    ACTIONS(5843), 1,
      aux_sym_number_token1,
    ACTIONS(5845), 1,
      anon_sym_SQUOTE,
    ACTIONS(5847), 1,
      anon_sym_DQUOTE,
    ACTIONS(5849), 1,
      sym_prefix_operator,
    ACTIONS(5851), 1,
      sym__uppercase_identifier,
    ACTIONS(5853), 1,
      aux_sym_tag_token1,
    ACTIONS(8678), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8680), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4624), 1,
      sym_attribute,
    STATE(6076), 1,
      sym__constructor_name,
    STATE(6159), 1,
      sym__simple_expression,
    STATE(6219), 1,
      sym__value_name,
    STATE(6275), 1,
      sym_parenthesized_operator,
    STATE(18997), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6075), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6176), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138807] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2407), 1,
      anon_sym_LPAREN,
    ACTIONS(2409), 1,
      anon_sym_LBRACK,
    ACTIONS(2413), 1,
      anon_sym_LBRACE,
    ACTIONS(2415), 1,
      anon_sym_object,
    ACTIONS(2419), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2429), 1,
      anon_sym_new,
    ACTIONS(2431), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2433), 1,
      anon_sym_begin,
    ACTIONS(2435), 1,
      sym_ocamlyacc_value,
    ACTIONS(2437), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2439), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2441), 1,
      aux_sym_number_token1,
    ACTIONS(2443), 1,
      anon_sym_SQUOTE,
    ACTIONS(2445), 1,
      anon_sym_DQUOTE,
    ACTIONS(2447), 1,
      sym_prefix_operator,
    ACTIONS(2451), 1,
      sym__uppercase_identifier,
    ACTIONS(2453), 1,
      aux_sym_tag_token1,
    ACTIONS(5375), 1,
      sym__lowercase_identifier,
    STATE(4625), 1,
      sym_attribute,
    STATE(6431), 1,
      sym__constructor_name,
    STATE(6682), 1,
      sym_parenthesized_operator,
    STATE(6984), 1,
      sym__simple_expression,
    STATE(6991), 1,
      sym__value_name,
    STATE(19529), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2411), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6430), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6951), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [138925] = 29,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(433), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_LBRACE,
    ACTIONS(439), 1,
      anon_sym_object,
    ACTIONS(443), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(453), 1,
      anon_sym_new,
    ACTIONS(455), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(457), 1,
      anon_sym_begin,
    ACTIONS(459), 1,
      sym_ocamlyacc_value,
    ACTIONS(465), 1,
      aux_sym_number_token1,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(471), 1,
      sym_prefix_operator,
    ACTIONS(475), 1,
      sym__uppercase_identifier,
    ACTIONS(477), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3051), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3053), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3203), 1,
      sym__lowercase_identifier,
    STATE(3318), 1,
      sym__simple_expression,
    STATE(3358), 1,
      sym__value_name,
    STATE(3440), 1,
      sym_parenthesized_operator,
    STATE(3458), 1,
      sym__constructor_name,
    STATE(4626), 1,
      sym_attribute,
    STATE(19605), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(435), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3351), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3312), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139043] = 29,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(433), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_LBRACE,
    ACTIONS(439), 1,
      anon_sym_object,
    ACTIONS(443), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(453), 1,
      anon_sym_new,
    ACTIONS(455), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(457), 1,
      anon_sym_begin,
    ACTIONS(459), 1,
      sym_ocamlyacc_value,
    ACTIONS(465), 1,
      aux_sym_number_token1,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(471), 1,
      sym_prefix_operator,
    ACTIONS(475), 1,
      sym__uppercase_identifier,
    ACTIONS(477), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3051), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3053), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3203), 1,
      sym__lowercase_identifier,
    STATE(3328), 1,
      sym__simple_expression,
    STATE(3358), 1,
      sym__value_name,
    STATE(3440), 1,
      sym_parenthesized_operator,
    STATE(3458), 1,
      sym__constructor_name,
    STATE(4627), 1,
      sym_attribute,
    STATE(19605), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(435), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3351), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3312), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139161] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3939), 1,
      anon_sym_DOT,
    STATE(4628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139233] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4979), 1,
      anon_sym_lazy,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2491), 1,
      sym_constructor_path,
    STATE(2500), 1,
      sym_tag,
    STATE(4629), 1,
      sym_attribute,
    STATE(5624), 1,
      sym__signed_constant,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5837), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5838), 1,
      sym__tuple_binding_pattern,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(5873), 1,
      sym__binding_pattern,
    STATE(19898), 1,
      sym_module_path,
    STATE(20060), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5801), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5803), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [139369] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7819), 1,
      sym__lowercase_identifier,
    ACTIONS(7823), 1,
      anon_sym_LPAREN,
    ACTIONS(7825), 1,
      anon_sym_LBRACK,
    ACTIONS(7829), 1,
      anon_sym_LBRACE,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7835), 1,
      anon_sym_new,
    ACTIONS(7837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(7839), 1,
      anon_sym_begin,
    ACTIONS(7841), 1,
      sym_ocamlyacc_value,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7847), 1,
      aux_sym_number_token1,
    ACTIONS(7849), 1,
      anon_sym_SQUOTE,
    ACTIONS(7851), 1,
      anon_sym_DQUOTE,
    ACTIONS(7853), 1,
      sym_prefix_operator,
    STATE(4630), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(9491), 1,
      sym_parenthesized_operator,
    STATE(9652), 1,
      sym__simple_expression,
    STATE(9709), 1,
      sym__value_name,
    STATE(18781), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7827), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9639), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9642), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139487] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139627] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139697] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(4634), 1,
      sym_attribute,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10079), 1,
      sym__simple_expression,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [139815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [139955] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7819), 1,
      sym__lowercase_identifier,
    ACTIONS(7823), 1,
      anon_sym_LPAREN,
    ACTIONS(7825), 1,
      anon_sym_LBRACK,
    ACTIONS(7829), 1,
      anon_sym_LBRACE,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7835), 1,
      anon_sym_new,
    ACTIONS(7837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(7839), 1,
      anon_sym_begin,
    ACTIONS(7841), 1,
      sym_ocamlyacc_value,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7847), 1,
      aux_sym_number_token1,
    ACTIONS(7849), 1,
      anon_sym_SQUOTE,
    ACTIONS(7851), 1,
      anon_sym_DQUOTE,
    ACTIONS(7853), 1,
      sym_prefix_operator,
    STATE(4637), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(9491), 1,
      sym_parenthesized_operator,
    STATE(9668), 1,
      sym__simple_expression,
    STATE(9709), 1,
      sym__value_name,
    STATE(18781), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7827), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9639), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9642), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140213] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(4640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140355] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140495] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(4644), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5759), 1,
      sym__tuple_binding_pattern,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5784), 1,
      sym__binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19526), 1,
      sym_module_path,
    STATE(19897), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [140631] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2813), 1,
      anon_sym_LPAREN,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2819), 1,
      anon_sym_LBRACE,
    ACTIONS(2821), 1,
      anon_sym_object,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2835), 1,
      anon_sym_new,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2839), 1,
      anon_sym_begin,
    ACTIONS(2841), 1,
      sym_ocamlyacc_value,
    ACTIONS(2843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2847), 1,
      aux_sym_number_token1,
    ACTIONS(2849), 1,
      anon_sym_SQUOTE,
    ACTIONS(2851), 1,
      anon_sym_DQUOTE,
    ACTIONS(2853), 1,
      sym_prefix_operator,
    ACTIONS(2857), 1,
      sym__uppercase_identifier,
    ACTIONS(2859), 1,
      aux_sym_tag_token1,
    ACTIONS(5553), 1,
      sym__lowercase_identifier,
    STATE(4645), 1,
      sym_attribute,
    STATE(7040), 1,
      sym__constructor_name,
    STATE(7116), 1,
      sym_parenthesized_operator,
    STATE(7233), 1,
      sym__simple_expression,
    STATE(7325), 1,
      sym__value_name,
    STATE(19882), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2817), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7039), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7319), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140749] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(4646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [140821] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1981), 1,
      anon_sym_LPAREN,
    ACTIONS(1983), 1,
      anon_sym_LBRACK,
    ACTIONS(1987), 1,
      anon_sym_LBRACE,
    ACTIONS(1989), 1,
      anon_sym_object,
    ACTIONS(1993), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2003), 1,
      anon_sym_new,
    ACTIONS(2005), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2007), 1,
      anon_sym_begin,
    ACTIONS(2009), 1,
      sym_ocamlyacc_value,
    ACTIONS(2011), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2013), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2015), 1,
      aux_sym_number_token1,
    ACTIONS(2017), 1,
      anon_sym_SQUOTE,
    ACTIONS(2019), 1,
      anon_sym_DQUOTE,
    ACTIONS(2021), 1,
      sym_prefix_operator,
    ACTIONS(2025), 1,
      sym__uppercase_identifier,
    ACTIONS(2027), 1,
      aux_sym_tag_token1,
    ACTIONS(5265), 1,
      sym__lowercase_identifier,
    STATE(4647), 1,
      sym_attribute,
    STATE(6099), 1,
      sym_parenthesized_operator,
    STATE(6129), 1,
      sym__constructor_name,
    STATE(6387), 1,
      sym__simple_expression,
    STATE(6393), 1,
      sym__value_name,
    STATE(19567), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1985), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6128), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6355), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [140939] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1283), 1,
      anon_sym_LPAREN,
    ACTIONS(1285), 1,
      anon_sym_LBRACK,
    ACTIONS(1289), 1,
      anon_sym_LBRACE,
    ACTIONS(1291), 1,
      anon_sym_object,
    ACTIONS(1295), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1313), 1,
      anon_sym_new,
    ACTIONS(1315), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1317), 1,
      anon_sym_begin,
    ACTIONS(1319), 1,
      sym_ocamlyacc_value,
    ACTIONS(1321), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1323), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1325), 1,
      aux_sym_number_token1,
    ACTIONS(1327), 1,
      anon_sym_SQUOTE,
    ACTIONS(1329), 1,
      anon_sym_DQUOTE,
    ACTIONS(1331), 1,
      sym_prefix_operator,
    ACTIONS(1335), 1,
      sym__uppercase_identifier,
    ACTIONS(1337), 1,
      aux_sym_tag_token1,
    ACTIONS(5179), 1,
      sym__lowercase_identifier,
    STATE(4648), 1,
      sym_attribute,
    STATE(5769), 1,
      sym__value_name,
    STATE(5777), 1,
      sym__simple_expression,
    STATE(5915), 1,
      sym__constructor_name,
    STATE(5953), 1,
      sym_parenthesized_operator,
    STATE(19643), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1287), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5901), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5762), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141057] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1283), 1,
      anon_sym_LPAREN,
    ACTIONS(1285), 1,
      anon_sym_LBRACK,
    ACTIONS(1289), 1,
      anon_sym_LBRACE,
    ACTIONS(1291), 1,
      anon_sym_object,
    ACTIONS(1295), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1313), 1,
      anon_sym_new,
    ACTIONS(1315), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1317), 1,
      anon_sym_begin,
    ACTIONS(1319), 1,
      sym_ocamlyacc_value,
    ACTIONS(1321), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1323), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1325), 1,
      aux_sym_number_token1,
    ACTIONS(1327), 1,
      anon_sym_SQUOTE,
    ACTIONS(1329), 1,
      anon_sym_DQUOTE,
    ACTIONS(1331), 1,
      sym_prefix_operator,
    ACTIONS(1335), 1,
      sym__uppercase_identifier,
    ACTIONS(1337), 1,
      aux_sym_tag_token1,
    ACTIONS(5179), 1,
      sym__lowercase_identifier,
    STATE(4649), 1,
      sym_attribute,
    STATE(5769), 1,
      sym__value_name,
    STATE(5831), 1,
      sym__simple_expression,
    STATE(5915), 1,
      sym__constructor_name,
    STATE(5953), 1,
      sym_parenthesized_operator,
    STATE(19643), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1287), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5901), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5762), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141175] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(4650), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(7701), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141293] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6799), 1,
      sym__lowercase_identifier,
    ACTIONS(6803), 1,
      anon_sym_LPAREN,
    ACTIONS(6805), 1,
      anon_sym_LBRACK,
    ACTIONS(6809), 1,
      anon_sym_LBRACE,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(6813), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6815), 1,
      anon_sym_new,
    ACTIONS(6817), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6819), 1,
      anon_sym_begin,
    ACTIONS(6821), 1,
      sym_ocamlyacc_value,
    ACTIONS(6827), 1,
      aux_sym_number_token1,
    ACTIONS(6829), 1,
      anon_sym_SQUOTE,
    ACTIONS(6831), 1,
      anon_sym_DQUOTE,
    ACTIONS(6833), 1,
      sym_prefix_operator,
    ACTIONS(6835), 1,
      sym__uppercase_identifier,
    ACTIONS(6837), 1,
      aux_sym_tag_token1,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4651), 1,
      sym_attribute,
    STATE(8203), 1,
      sym_parenthesized_operator,
    STATE(8207), 1,
      sym__constructor_name,
    STATE(8270), 1,
      sym__simple_expression,
    STATE(8429), 1,
      sym__value_name,
    STATE(18431), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6807), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8206), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8227), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141411] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6799), 1,
      sym__lowercase_identifier,
    ACTIONS(6803), 1,
      anon_sym_LPAREN,
    ACTIONS(6805), 1,
      anon_sym_LBRACK,
    ACTIONS(6809), 1,
      anon_sym_LBRACE,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(6813), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6815), 1,
      anon_sym_new,
    ACTIONS(6817), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6819), 1,
      anon_sym_begin,
    ACTIONS(6821), 1,
      sym_ocamlyacc_value,
    ACTIONS(6827), 1,
      aux_sym_number_token1,
    ACTIONS(6829), 1,
      anon_sym_SQUOTE,
    ACTIONS(6831), 1,
      anon_sym_DQUOTE,
    ACTIONS(6833), 1,
      sym_prefix_operator,
    ACTIONS(6835), 1,
      sym__uppercase_identifier,
    ACTIONS(6837), 1,
      aux_sym_tag_token1,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4652), 1,
      sym_attribute,
    STATE(8203), 1,
      sym_parenthesized_operator,
    STATE(8207), 1,
      sym__constructor_name,
    STATE(8340), 1,
      sym__simple_expression,
    STATE(8429), 1,
      sym__value_name,
    STATE(18431), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6807), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8206), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8227), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141529] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141669] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141809] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [141879] = 29,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    ACTIONS(1007), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      anon_sym_object,
    ACTIONS(1013), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1023), 1,
      anon_sym_new,
    ACTIONS(1025), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1027), 1,
      anon_sym_begin,
    ACTIONS(1029), 1,
      sym_ocamlyacc_value,
    ACTIONS(1035), 1,
      aux_sym_number_token1,
    ACTIONS(1037), 1,
      anon_sym_SQUOTE,
    ACTIONS(1039), 1,
      anon_sym_DQUOTE,
    ACTIONS(1041), 1,
      sym_prefix_operator,
    ACTIONS(1045), 1,
      sym__uppercase_identifier,
    ACTIONS(1047), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3071), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3073), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4565), 1,
      sym__lowercase_identifier,
    STATE(4658), 1,
      sym_attribute,
    STATE(5041), 1,
      sym_parenthesized_operator,
    STATE(5057), 1,
      sym__simple_expression,
    STATE(5064), 1,
      sym__constructor_name,
    STATE(5079), 1,
      sym__value_name,
    STATE(20345), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1005), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5036), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5054), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [141997] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142067] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142347] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5033), 1,
      anon_sym_lazy,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8686), 1,
      anon_sym_TILDE,
    STATE(2494), 1,
      sym_constructor_path,
    STATE(2496), 1,
      sym_tag,
    STATE(4664), 1,
      sym_attribute,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5661), 1,
      sym__signed_constant,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5804), 1,
      sym__binding_pattern,
    STATE(5808), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(5811), 1,
      sym__tuple_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5942), 1,
      sym__or_binding_pattern_anonymous,
    STATE(19526), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5928), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5931), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142553] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4666), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14807), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [142689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [142969] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [143039] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [143109] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(5453), 1,
      anon_sym_LPAREN,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(7555), 1,
      anon_sym_lazy,
    STATE(2771), 1,
      sym_constructor_path,
    STATE(2968), 1,
      sym_tag,
    STATE(4673), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(14007), 1,
      sym__signed_constant,
    STATE(14039), 1,
      sym__tuple_binding_pattern,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14170), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(14877), 1,
      sym__binding_pattern,
    STATE(18535), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(19608), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14219), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14134), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [143245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [143315] = 29,
    ACTIONS(431), 1,
      anon_sym_LPAREN,
    ACTIONS(433), 1,
      anon_sym_LBRACK,
    ACTIONS(437), 1,
      anon_sym_LBRACE,
    ACTIONS(439), 1,
      anon_sym_object,
    ACTIONS(443), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(453), 1,
      anon_sym_new,
    ACTIONS(455), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(457), 1,
      anon_sym_begin,
    ACTIONS(459), 1,
      sym_ocamlyacc_value,
    ACTIONS(465), 1,
      aux_sym_number_token1,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(471), 1,
      sym_prefix_operator,
    ACTIONS(475), 1,
      sym__uppercase_identifier,
    ACTIONS(477), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3051), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3053), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3203), 1,
      sym__lowercase_identifier,
    STATE(3350), 1,
      sym__simple_expression,
    STATE(3358), 1,
      sym__value_name,
    STATE(3440), 1,
      sym_parenthesized_operator,
    STATE(3458), 1,
      sym__constructor_name,
    STATE(4675), 1,
      sym_attribute,
    STATE(19605), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(435), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3351), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3312), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [143433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [143503] = 29,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_LBRACE,
    ACTIONS(1075), 1,
      anon_sym_object,
    ACTIONS(1079), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1089), 1,
      anon_sym_new,
    ACTIONS(1091), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1093), 1,
      anon_sym_begin,
    ACTIONS(1095), 1,
      sym_ocamlyacc_value,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1099), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1103), 1,
      aux_sym_number_token1,
    ACTIONS(1105), 1,
      anon_sym_SQUOTE,
    ACTIONS(1107), 1,
      anon_sym_DQUOTE,
    ACTIONS(1109), 1,
      sym_prefix_operator,
    ACTIONS(1113), 1,
      sym__uppercase_identifier,
    ACTIONS(1115), 1,
      aux_sym_tag_token1,
    ACTIONS(4655), 1,
      sym__lowercase_identifier,
    STATE(4677), 1,
      sym_attribute,
    STATE(5306), 1,
      sym__simple_expression,
    STATE(5409), 1,
      sym__value_name,
    STATE(5460), 1,
      sym__constructor_name,
    STATE(5461), 1,
      sym_parenthesized_operator,
    STATE(19681), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1071), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5434), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5398), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [143621] = 29,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_LBRACE,
    ACTIONS(1075), 1,
      anon_sym_object,
    ACTIONS(1079), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1089), 1,
      anon_sym_new,
    ACTIONS(1091), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1093), 1,
      anon_sym_begin,
    ACTIONS(1095), 1,
      sym_ocamlyacc_value,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1099), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1103), 1,
      aux_sym_number_token1,
    ACTIONS(1105), 1,
      anon_sym_SQUOTE,
    ACTIONS(1107), 1,
      anon_sym_DQUOTE,
    ACTIONS(1109), 1,
      sym_prefix_operator,
    ACTIONS(1113), 1,
      sym__uppercase_identifier,
    ACTIONS(1115), 1,
      aux_sym_tag_token1,
    ACTIONS(4655), 1,
      sym__lowercase_identifier,
    STATE(4678), 1,
      sym_attribute,
    STATE(5409), 1,
      sym__value_name,
    STATE(5424), 1,
      sym__simple_expression,
    STATE(5460), 1,
      sym__constructor_name,
    STATE(5461), 1,
      sym_parenthesized_operator,
    STATE(19681), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1071), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5434), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5398), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [143739] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8484), 1,
      sym_prefix_operator,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    STATE(4679), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(7586), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [143857] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [143927] = 29,
    ACTIONS(539), 1,
      anon_sym_LPAREN,
    ACTIONS(541), 1,
      anon_sym_LBRACK,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      anon_sym_object,
    ACTIONS(551), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(561), 1,
      anon_sym_new,
    ACTIONS(563), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(565), 1,
      anon_sym_begin,
    ACTIONS(567), 1,
      sym_ocamlyacc_value,
    ACTIONS(573), 1,
      aux_sym_number_token1,
    ACTIONS(575), 1,
      anon_sym_SQUOTE,
    ACTIONS(577), 1,
      anon_sym_DQUOTE,
    ACTIONS(579), 1,
      sym_prefix_operator,
    ACTIONS(583), 1,
      sym__uppercase_identifier,
    ACTIONS(585), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3091), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3093), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3475), 1,
      sym__lowercase_identifier,
    STATE(3643), 1,
      sym__value_name,
    STATE(3686), 1,
      sym__simple_expression,
    STATE(3769), 1,
      sym_parenthesized_operator,
    STATE(3811), 1,
      sym__constructor_name,
    STATE(4681), 1,
      sym_attribute,
    STATE(18672), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(543), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3809), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3557), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [144045] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5811), 1,
      sym__lowercase_identifier,
    ACTIONS(5819), 1,
      anon_sym_LPAREN,
    ACTIONS(5821), 1,
      anon_sym_LBRACK,
    ACTIONS(5825), 1,
      anon_sym_LBRACE,
    ACTIONS(5827), 1,
      anon_sym_object,
    ACTIONS(5829), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5831), 1,
      anon_sym_new,
    ACTIONS(5833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5835), 1,
      anon_sym_begin,
    ACTIONS(5837), 1,
      sym_ocamlyacc_value,
    ACTIONS(5843), 1,
      aux_sym_number_token1,
    ACTIONS(5845), 1,
      anon_sym_SQUOTE,
    ACTIONS(5847), 1,
      anon_sym_DQUOTE,
    ACTIONS(5849), 1,
      sym_prefix_operator,
    ACTIONS(5851), 1,
      sym__uppercase_identifier,
    ACTIONS(5853), 1,
      aux_sym_tag_token1,
    ACTIONS(8678), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8680), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4682), 1,
      sym_attribute,
    STATE(6076), 1,
      sym__constructor_name,
    STATE(6181), 1,
      sym__simple_expression,
    STATE(6219), 1,
      sym__value_name,
    STATE(6275), 1,
      sym_parenthesized_operator,
    STATE(18997), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6075), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6176), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [144163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [144233] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4684), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14689), 1,
      sym__binding_pattern,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144369] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5811), 1,
      sym__lowercase_identifier,
    ACTIONS(5819), 1,
      anon_sym_LPAREN,
    ACTIONS(5821), 1,
      anon_sym_LBRACK,
    ACTIONS(5825), 1,
      anon_sym_LBRACE,
    ACTIONS(5827), 1,
      anon_sym_object,
    ACTIONS(5829), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5831), 1,
      anon_sym_new,
    ACTIONS(5833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5835), 1,
      anon_sym_begin,
    ACTIONS(5837), 1,
      sym_ocamlyacc_value,
    ACTIONS(5843), 1,
      aux_sym_number_token1,
    ACTIONS(5845), 1,
      anon_sym_SQUOTE,
    ACTIONS(5847), 1,
      anon_sym_DQUOTE,
    ACTIONS(5849), 1,
      sym_prefix_operator,
    ACTIONS(5851), 1,
      sym__uppercase_identifier,
    ACTIONS(5853), 1,
      aux_sym_tag_token1,
    ACTIONS(8678), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8680), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4685), 1,
      sym_attribute,
    STATE(6076), 1,
      sym__constructor_name,
    STATE(6190), 1,
      sym__simple_expression,
    STATE(6219), 1,
      sym__value_name,
    STATE(6275), 1,
      sym_parenthesized_operator,
    STATE(18997), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6075), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6176), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [144487] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    ACTIONS(8688), 1,
      anon_sym_TILDE,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4686), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14804), 1,
      sym__binding_pattern,
    STATE(14813), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(14814), 1,
      sym__tuple_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144623] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4687), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14837), 1,
      sym__binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14853), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144759] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4688), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14874), 1,
      sym__binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [144895] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2761), 1,
      anon_sym_LPAREN,
    ACTIONS(2763), 1,
      anon_sym_LBRACK,
    ACTIONS(2767), 1,
      anon_sym_LBRACE,
    ACTIONS(2769), 1,
      anon_sym_object,
    ACTIONS(2773), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2783), 1,
      anon_sym_new,
    ACTIONS(2785), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2787), 1,
      anon_sym_begin,
    ACTIONS(2789), 1,
      sym_ocamlyacc_value,
    ACTIONS(2791), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2793), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2795), 1,
      aux_sym_number_token1,
    ACTIONS(2797), 1,
      anon_sym_SQUOTE,
    ACTIONS(2799), 1,
      anon_sym_DQUOTE,
    ACTIONS(2801), 1,
      sym_prefix_operator,
    ACTIONS(2805), 1,
      sym__uppercase_identifier,
    ACTIONS(2807), 1,
      aux_sym_tag_token1,
    ACTIONS(5625), 1,
      sym__lowercase_identifier,
    STATE(4689), 1,
      sym_attribute,
    STATE(7282), 1,
      sym__constructor_name,
    STATE(7423), 1,
      sym__value_name,
    STATE(7432), 1,
      sym__simple_expression,
    STATE(7510), 1,
      sym_parenthesized_operator,
    STATE(19106), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2765), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7138), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7419), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [145013] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7711), 1,
      anon_sym_lazy,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7815), 1,
      anon_sym_LPAREN,
    STATE(2978), 1,
      sym_constructor_path,
    STATE(3026), 1,
      sym_tag,
    STATE(4690), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(14358), 1,
      sym__signed_constant,
    STATE(14637), 1,
      sym__or_binding_pattern_anonymous,
    STATE(14741), 1,
      sym__tuple_binding_pattern,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14887), 1,
      sym__binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(18536), 1,
      sym_module_path,
    STATE(19116), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14873), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(14943), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [145149] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [145219] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(4692), 1,
      sym_attribute,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(10296), 1,
      sym__simple_expression,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [145337] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(4693), 1,
      sym_attribute,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(10287), 1,
      sym__simple_expression,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [145455] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8408), 1,
      sym__lowercase_identifier,
    ACTIONS(8410), 1,
      anon_sym_LPAREN,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8416), 1,
      anon_sym_LBRACE,
    ACTIONS(8418), 1,
      anon_sym_object,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8422), 1,
      anon_sym_new,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8426), 1,
      anon_sym_begin,
    ACTIONS(8428), 1,
      sym_ocamlyacc_value,
    ACTIONS(8430), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8432), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8434), 1,
      aux_sym_number_token1,
    ACTIONS(8436), 1,
      anon_sym_SQUOTE,
    ACTIONS(8438), 1,
      anon_sym_DQUOTE,
    ACTIONS(8440), 1,
      sym_prefix_operator,
    ACTIONS(8442), 1,
      sym__uppercase_identifier,
    ACTIONS(8444), 1,
      aux_sym_tag_token1,
    STATE(4694), 1,
      sym_attribute,
    STATE(9966), 1,
      sym__value_name,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10087), 1,
      sym__constructor_name,
    STATE(10139), 1,
      sym__simple_expression,
    STATE(19131), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8414), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10215), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10043), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [145573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [145643] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [145713] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1283), 1,
      anon_sym_LPAREN,
    ACTIONS(1285), 1,
      anon_sym_LBRACK,
    ACTIONS(1289), 1,
      anon_sym_LBRACE,
    ACTIONS(1291), 1,
      anon_sym_object,
    ACTIONS(1295), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1313), 1,
      anon_sym_new,
    ACTIONS(1315), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1317), 1,
      anon_sym_begin,
    ACTIONS(1319), 1,
      sym_ocamlyacc_value,
    ACTIONS(1321), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1323), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1325), 1,
      aux_sym_number_token1,
    ACTIONS(1327), 1,
      anon_sym_SQUOTE,
    ACTIONS(1329), 1,
      anon_sym_DQUOTE,
    ACTIONS(1331), 1,
      sym_prefix_operator,
    ACTIONS(1335), 1,
      sym__uppercase_identifier,
    ACTIONS(1337), 1,
      aux_sym_tag_token1,
    ACTIONS(5179), 1,
      sym__lowercase_identifier,
    STATE(4697), 1,
      sym_attribute,
    STATE(5769), 1,
      sym__value_name,
    STATE(5890), 1,
      sym__simple_expression,
    STATE(5915), 1,
      sym__constructor_name,
    STATE(5953), 1,
      sym_parenthesized_operator,
    STATE(19643), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1287), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5901), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5762), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [145831] = 29,
    ACTIONS(593), 1,
      anon_sym_LPAREN,
    ACTIONS(595), 1,
      anon_sym_LBRACK,
    ACTIONS(599), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_object,
    ACTIONS(605), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(615), 1,
      anon_sym_new,
    ACTIONS(617), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(619), 1,
      anon_sym_begin,
    ACTIONS(621), 1,
      sym_ocamlyacc_value,
    ACTIONS(627), 1,
      aux_sym_number_token1,
    ACTIONS(629), 1,
      anon_sym_SQUOTE,
    ACTIONS(631), 1,
      anon_sym_DQUOTE,
    ACTIONS(633), 1,
      sym_prefix_operator,
    ACTIONS(637), 1,
      sym__uppercase_identifier,
    ACTIONS(639), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3083), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3085), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3405), 1,
      sym__lowercase_identifier,
    STATE(3523), 1,
      sym__value_name,
    STATE(3647), 1,
      sym__simple_expression,
    STATE(3706), 1,
      sym_parenthesized_operator,
    STATE(3764), 1,
      sym__constructor_name,
    STATE(4698), 1,
      sym_attribute,
    STATE(19718), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(597), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3524), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3632), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [145949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [146019] = 29,
    ACTIONS(593), 1,
      anon_sym_LPAREN,
    ACTIONS(595), 1,
      anon_sym_LBRACK,
    ACTIONS(599), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_object,
    ACTIONS(605), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(615), 1,
      anon_sym_new,
    ACTIONS(617), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(619), 1,
      anon_sym_begin,
    ACTIONS(621), 1,
      sym_ocamlyacc_value,
    ACTIONS(627), 1,
      aux_sym_number_token1,
    ACTIONS(629), 1,
      anon_sym_SQUOTE,
    ACTIONS(631), 1,
      anon_sym_DQUOTE,
    ACTIONS(633), 1,
      sym_prefix_operator,
    ACTIONS(637), 1,
      sym__uppercase_identifier,
    ACTIONS(639), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3083), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3085), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3405), 1,
      sym__lowercase_identifier,
    STATE(3523), 1,
      sym__value_name,
    STATE(3706), 1,
      sym_parenthesized_operator,
    STATE(3718), 1,
      sym__simple_expression,
    STATE(3764), 1,
      sym__constructor_name,
    STATE(4700), 1,
      sym_attribute,
    STATE(19718), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(597), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3524), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3632), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [146137] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4701), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5399), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [146255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [146325] = 29,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(307), 1,
      anon_sym_LBRACK,
    ACTIONS(311), 1,
      anon_sym_LBRACE,
    ACTIONS(321), 1,
      anon_sym_object,
    ACTIONS(325), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(335), 1,
      anon_sym_new,
    ACTIONS(337), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(339), 1,
      anon_sym_begin,
    ACTIONS(341), 1,
      sym_ocamlyacc_value,
    ACTIONS(347), 1,
      aux_sym_number_token1,
    ACTIONS(349), 1,
      anon_sym_SQUOTE,
    ACTIONS(351), 1,
      anon_sym_DQUOTE,
    ACTIONS(353), 1,
      sym_prefix_operator,
    ACTIONS(359), 1,
      sym__uppercase_identifier,
    ACTIONS(363), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3039), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3041), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4185), 1,
      sym__lowercase_identifier,
    STATE(4452), 1,
      sym__simple_expression,
    STATE(4691), 1,
      sym_parenthesized_operator,
    STATE(4703), 1,
      sym_attribute,
    STATE(4737), 1,
      sym__value_name,
    STATE(4743), 1,
      sym__constructor_name,
    STATE(20799), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(309), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4735), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4695), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [146443] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(4704), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7613), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [146561] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6167), 1,
      sym__lowercase_identifier,
    ACTIONS(6171), 1,
      anon_sym_LPAREN,
    ACTIONS(6173), 1,
      anon_sym_LBRACK,
    ACTIONS(6177), 1,
      anon_sym_LBRACE,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(6181), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6183), 1,
      anon_sym_new,
    ACTIONS(6185), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6187), 1,
      anon_sym_begin,
    ACTIONS(6189), 1,
      sym_ocamlyacc_value,
    ACTIONS(6195), 1,
      aux_sym_number_token1,
    ACTIONS(6197), 1,
      anon_sym_SQUOTE,
    ACTIONS(6199), 1,
      anon_sym_DQUOTE,
    ACTIONS(6201), 1,
      sym_prefix_operator,
    ACTIONS(6203), 1,
      sym__uppercase_identifier,
    ACTIONS(6205), 1,
      aux_sym_tag_token1,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4705), 1,
      sym_attribute,
    STATE(6405), 1,
      sym__simple_expression,
    STATE(6525), 1,
      sym__value_name,
    STATE(6548), 1,
      sym_parenthesized_operator,
    STATE(6640), 1,
      sym__constructor_name,
    STATE(20775), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6175), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6688), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6477), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [146679] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(4706), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5620), 1,
      sym__binding_pattern,
    STATE(5633), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [146815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [146885] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(4708), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5635), 1,
      sym__binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [147021] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [147091] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8032), 1,
      anon_sym_object,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8036), 1,
      anon_sym_new,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8042), 1,
      sym_ocamlyacc_value,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(8384), 1,
      anon_sym_LPAREN,
    ACTIONS(8388), 1,
      anon_sym_LBRACE,
    ACTIONS(8390), 1,
      anon_sym_begin,
    ACTIONS(8392), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8394), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8398), 1,
      aux_sym_number_token1,
    ACTIONS(8400), 1,
      anon_sym_SQUOTE,
    ACTIONS(8402), 1,
      anon_sym_DQUOTE,
    ACTIONS(8404), 1,
      sym_prefix_operator,
    STATE(4710), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7599), 1,
      sym__value_name,
    STATE(7892), 1,
      sym__simple_expression,
    STATE(20321), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8386), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7996), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7597), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147209] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5695), 1,
      sym__lowercase_identifier,
    ACTIONS(5703), 1,
      anon_sym_LPAREN,
    ACTIONS(5705), 1,
      anon_sym_LBRACK,
    ACTIONS(5709), 1,
      anon_sym_LBRACE,
    ACTIONS(5711), 1,
      anon_sym_object,
    ACTIONS(5713), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5715), 1,
      anon_sym_new,
    ACTIONS(5717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(5719), 1,
      anon_sym_begin,
    ACTIONS(5721), 1,
      sym_ocamlyacc_value,
    ACTIONS(5727), 1,
      aux_sym_number_token1,
    ACTIONS(5729), 1,
      anon_sym_SQUOTE,
    ACTIONS(5731), 1,
      anon_sym_DQUOTE,
    ACTIONS(5733), 1,
      sym_prefix_operator,
    ACTIONS(5735), 1,
      sym__uppercase_identifier,
    ACTIONS(5737), 1,
      aux_sym_tag_token1,
    ACTIONS(8658), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8660), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4711), 1,
      sym_attribute,
    STATE(6110), 1,
      sym__constructor_name,
    STATE(6172), 1,
      sym__simple_expression,
    STATE(6323), 1,
      sym__value_name,
    STATE(6342), 1,
      sym_parenthesized_operator,
    STATE(19291), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5707), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6109), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6278), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147327] = 29,
    ACTIONS(811), 1,
      anon_sym_LPAREN,
    ACTIONS(813), 1,
      anon_sym_LBRACK,
    ACTIONS(817), 1,
      anon_sym_LBRACE,
    ACTIONS(819), 1,
      anon_sym_object,
    ACTIONS(823), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(833), 1,
      anon_sym_new,
    ACTIONS(835), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(837), 1,
      anon_sym_begin,
    ACTIONS(839), 1,
      sym_ocamlyacc_value,
    ACTIONS(845), 1,
      aux_sym_number_token1,
    ACTIONS(847), 1,
      anon_sym_SQUOTE,
    ACTIONS(849), 1,
      anon_sym_DQUOTE,
    ACTIONS(851), 1,
      sym_prefix_operator,
    ACTIONS(855), 1,
      sym__uppercase_identifier,
    ACTIONS(857), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3079), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3081), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3865), 1,
      sym__lowercase_identifier,
    STATE(4173), 1,
      sym__simple_expression,
    STATE(4257), 1,
      sym__value_name,
    STATE(4382), 1,
      sym__constructor_name,
    STATE(4384), 1,
      sym_parenthesized_operator,
    STATE(4712), 1,
      sym_attribute,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(815), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4380), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4163), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147445] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2355), 1,
      anon_sym_LPAREN,
    ACTIONS(2357), 1,
      anon_sym_LBRACK,
    ACTIONS(2361), 1,
      anon_sym_LBRACE,
    ACTIONS(2363), 1,
      anon_sym_object,
    ACTIONS(2367), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2377), 1,
      anon_sym_new,
    ACTIONS(2379), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2381), 1,
      anon_sym_begin,
    ACTIONS(2383), 1,
      sym_ocamlyacc_value,
    ACTIONS(2385), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2387), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2389), 1,
      aux_sym_number_token1,
    ACTIONS(2391), 1,
      anon_sym_SQUOTE,
    ACTIONS(2393), 1,
      anon_sym_DQUOTE,
    ACTIONS(2395), 1,
      sym_prefix_operator,
    ACTIONS(2399), 1,
      sym__uppercase_identifier,
    ACTIONS(2401), 1,
      aux_sym_tag_token1,
    ACTIONS(5355), 1,
      sym__lowercase_identifier,
    STATE(4713), 1,
      sym_attribute,
    STATE(6587), 1,
      sym__constructor_name,
    STATE(6645), 1,
      sym__simple_expression,
    STATE(6689), 1,
      sym__value_name,
    STATE(6871), 1,
      sym_parenthesized_operator,
    STATE(19050), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2359), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6582), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6638), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147563] = 29,
    ACTIONS(811), 1,
      anon_sym_LPAREN,
    ACTIONS(813), 1,
      anon_sym_LBRACK,
    ACTIONS(817), 1,
      anon_sym_LBRACE,
    ACTIONS(819), 1,
      anon_sym_object,
    ACTIONS(823), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(833), 1,
      anon_sym_new,
    ACTIONS(835), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(837), 1,
      anon_sym_begin,
    ACTIONS(839), 1,
      sym_ocamlyacc_value,
    ACTIONS(845), 1,
      aux_sym_number_token1,
    ACTIONS(847), 1,
      anon_sym_SQUOTE,
    ACTIONS(849), 1,
      anon_sym_DQUOTE,
    ACTIONS(851), 1,
      sym_prefix_operator,
    ACTIONS(855), 1,
      sym__uppercase_identifier,
    ACTIONS(857), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3079), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3081), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3865), 1,
      sym__lowercase_identifier,
    STATE(4203), 1,
      sym__simple_expression,
    STATE(4257), 1,
      sym__value_name,
    STATE(4382), 1,
      sym__constructor_name,
    STATE(4384), 1,
      sym_parenthesized_operator,
    STATE(4714), 1,
      sym_attribute,
    STATE(18504), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(815), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4380), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4163), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147681] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2355), 1,
      anon_sym_LPAREN,
    ACTIONS(2357), 1,
      anon_sym_LBRACK,
    ACTIONS(2361), 1,
      anon_sym_LBRACE,
    ACTIONS(2363), 1,
      anon_sym_object,
    ACTIONS(2367), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2377), 1,
      anon_sym_new,
    ACTIONS(2379), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2381), 1,
      anon_sym_begin,
    ACTIONS(2383), 1,
      sym_ocamlyacc_value,
    ACTIONS(2385), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2387), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2389), 1,
      aux_sym_number_token1,
    ACTIONS(2391), 1,
      anon_sym_SQUOTE,
    ACTIONS(2393), 1,
      anon_sym_DQUOTE,
    ACTIONS(2395), 1,
      sym_prefix_operator,
    ACTIONS(2399), 1,
      sym__uppercase_identifier,
    ACTIONS(2401), 1,
      aux_sym_tag_token1,
    ACTIONS(5355), 1,
      sym__lowercase_identifier,
    STATE(4715), 1,
      sym_attribute,
    STATE(6587), 1,
      sym__constructor_name,
    STATE(6655), 1,
      sym__simple_expression,
    STATE(6689), 1,
      sym__value_name,
    STATE(6871), 1,
      sym_parenthesized_operator,
    STATE(19050), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2359), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6582), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6638), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147799] = 29,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_LBRACE,
    ACTIONS(1075), 1,
      anon_sym_object,
    ACTIONS(1079), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1089), 1,
      anon_sym_new,
    ACTIONS(1091), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1093), 1,
      anon_sym_begin,
    ACTIONS(1095), 1,
      sym_ocamlyacc_value,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1099), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1103), 1,
      aux_sym_number_token1,
    ACTIONS(1105), 1,
      anon_sym_SQUOTE,
    ACTIONS(1107), 1,
      anon_sym_DQUOTE,
    ACTIONS(1109), 1,
      sym_prefix_operator,
    ACTIONS(1113), 1,
      sym__uppercase_identifier,
    ACTIONS(1115), 1,
      aux_sym_tag_token1,
    ACTIONS(4655), 1,
      sym__lowercase_identifier,
    STATE(4716), 1,
      sym_attribute,
    STATE(5409), 1,
      sym__value_name,
    STATE(5410), 1,
      sym__simple_expression,
    STATE(5460), 1,
      sym__constructor_name,
    STATE(5461), 1,
      sym_parenthesized_operator,
    STATE(19681), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1071), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5434), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5398), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [147917] = 29,
    ACTIONS(645), 1,
      anon_sym_LPAREN,
    ACTIONS(647), 1,
      anon_sym_LBRACK,
    ACTIONS(651), 1,
      anon_sym_LBRACE,
    ACTIONS(653), 1,
      anon_sym_object,
    ACTIONS(657), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(667), 1,
      anon_sym_new,
    ACTIONS(669), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(671), 1,
      anon_sym_begin,
    ACTIONS(673), 1,
      sym_ocamlyacc_value,
    ACTIONS(679), 1,
      aux_sym_number_token1,
    ACTIONS(681), 1,
      anon_sym_SQUOTE,
    ACTIONS(683), 1,
      anon_sym_DQUOTE,
    ACTIONS(685), 1,
      sym_prefix_operator,
    ACTIONS(689), 1,
      sym__uppercase_identifier,
    ACTIONS(691), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3035), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3037), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3427), 1,
      sym__lowercase_identifier,
    STATE(3521), 1,
      sym__constructor_name,
    STATE(3529), 1,
      sym__simple_expression,
    STATE(3606), 1,
      sym__value_name,
    STATE(3709), 1,
      sym_parenthesized_operator,
    STATE(4717), 1,
      sym_attribute,
    STATE(19755), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(649), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3810), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3522), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148035] = 29,
    ACTIONS(645), 1,
      anon_sym_LPAREN,
    ACTIONS(647), 1,
      anon_sym_LBRACK,
    ACTIONS(651), 1,
      anon_sym_LBRACE,
    ACTIONS(653), 1,
      anon_sym_object,
    ACTIONS(657), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(667), 1,
      anon_sym_new,
    ACTIONS(669), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(671), 1,
      anon_sym_begin,
    ACTIONS(673), 1,
      sym_ocamlyacc_value,
    ACTIONS(679), 1,
      aux_sym_number_token1,
    ACTIONS(681), 1,
      anon_sym_SQUOTE,
    ACTIONS(683), 1,
      anon_sym_DQUOTE,
    ACTIONS(685), 1,
      sym_prefix_operator,
    ACTIONS(689), 1,
      sym__uppercase_identifier,
    ACTIONS(691), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3035), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3037), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3427), 1,
      sym__lowercase_identifier,
    STATE(3521), 1,
      sym__constructor_name,
    STATE(3542), 1,
      sym__simple_expression,
    STATE(3606), 1,
      sym__value_name,
    STATE(3709), 1,
      sym_parenthesized_operator,
    STATE(4718), 1,
      sym_attribute,
    STATE(19755), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(649), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3810), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3522), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [148223] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [148293] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4721), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9715), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148411] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4722), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9716), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148529] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4723), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(9717), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148647] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4724), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(7701), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148765] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8452), 1,
      sym__lowercase_identifier,
    ACTIONS(8454), 1,
      anon_sym_LPAREN,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8460), 1,
      anon_sym_LBRACE,
    ACTIONS(8462), 1,
      anon_sym_object,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8466), 1,
      anon_sym_new,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(8470), 1,
      anon_sym_begin,
    ACTIONS(8472), 1,
      sym_ocamlyacc_value,
    ACTIONS(8478), 1,
      aux_sym_number_token1,
    ACTIONS(8480), 1,
      anon_sym_SQUOTE,
    ACTIONS(8482), 1,
      anon_sym_DQUOTE,
    ACTIONS(8486), 1,
      sym__uppercase_identifier,
    ACTIONS(8488), 1,
      aux_sym_tag_token1,
    ACTIONS(8520), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8522), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8546), 1,
      sym_prefix_operator,
    STATE(4725), 1,
      sym_attribute,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7537), 1,
      sym__value_name,
    STATE(7562), 1,
      sym__constructor_name,
    STATE(7586), 1,
      sym__simple_expression,
    STATE(20053), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8458), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7572), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7693), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [148883] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7713), 1,
      sym__uppercase_identifier,
    ACTIONS(7715), 1,
      aux_sym_tag_token1,
    ACTIONS(7819), 1,
      sym__lowercase_identifier,
    ACTIONS(7823), 1,
      anon_sym_LPAREN,
    ACTIONS(7825), 1,
      anon_sym_LBRACK,
    ACTIONS(7829), 1,
      anon_sym_LBRACE,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7835), 1,
      anon_sym_new,
    ACTIONS(7837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(7839), 1,
      anon_sym_begin,
    ACTIONS(7841), 1,
      sym_ocamlyacc_value,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7847), 1,
      aux_sym_number_token1,
    ACTIONS(7849), 1,
      anon_sym_SQUOTE,
    ACTIONS(7851), 1,
      anon_sym_DQUOTE,
    ACTIONS(7853), 1,
      sym_prefix_operator,
    STATE(4726), 1,
      sym_attribute,
    STATE(8492), 1,
      sym__constructor_name,
    STATE(9491), 1,
      sym_parenthesized_operator,
    STATE(9578), 1,
      sym__simple_expression,
    STATE(9709), 1,
      sym__value_name,
    STATE(18781), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7827), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9639), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9642), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149001] = 29,
    ACTIONS(539), 1,
      anon_sym_LPAREN,
    ACTIONS(541), 1,
      anon_sym_LBRACK,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      anon_sym_object,
    ACTIONS(551), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(561), 1,
      anon_sym_new,
    ACTIONS(563), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(565), 1,
      anon_sym_begin,
    ACTIONS(567), 1,
      sym_ocamlyacc_value,
    ACTIONS(573), 1,
      aux_sym_number_token1,
    ACTIONS(575), 1,
      anon_sym_SQUOTE,
    ACTIONS(577), 1,
      anon_sym_DQUOTE,
    ACTIONS(579), 1,
      sym_prefix_operator,
    ACTIONS(583), 1,
      sym__uppercase_identifier,
    ACTIONS(585), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3091), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3093), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3475), 1,
      sym__lowercase_identifier,
    STATE(3567), 1,
      sym__simple_expression,
    STATE(3643), 1,
      sym__value_name,
    STATE(3769), 1,
      sym_parenthesized_operator,
    STATE(3811), 1,
      sym__constructor_name,
    STATE(4727), 1,
      sym_attribute,
    STATE(18672), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(543), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3809), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3557), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149119] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2761), 1,
      anon_sym_LPAREN,
    ACTIONS(2763), 1,
      anon_sym_LBRACK,
    ACTIONS(2767), 1,
      anon_sym_LBRACE,
    ACTIONS(2769), 1,
      anon_sym_object,
    ACTIONS(2773), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2783), 1,
      anon_sym_new,
    ACTIONS(2785), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2787), 1,
      anon_sym_begin,
    ACTIONS(2789), 1,
      sym_ocamlyacc_value,
    ACTIONS(2791), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2793), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2795), 1,
      aux_sym_number_token1,
    ACTIONS(2797), 1,
      anon_sym_SQUOTE,
    ACTIONS(2799), 1,
      anon_sym_DQUOTE,
    ACTIONS(2801), 1,
      sym_prefix_operator,
    ACTIONS(2805), 1,
      sym__uppercase_identifier,
    ACTIONS(2807), 1,
      aux_sym_tag_token1,
    ACTIONS(5625), 1,
      sym__lowercase_identifier,
    STATE(4728), 1,
      sym_attribute,
    STATE(7282), 1,
      sym__constructor_name,
    STATE(7423), 1,
      sym__value_name,
    STATE(7447), 1,
      sym__simple_expression,
    STATE(7510), 1,
      sym_parenthesized_operator,
    STATE(19106), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2765), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7138), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7419), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149237] = 29,
    ACTIONS(539), 1,
      anon_sym_LPAREN,
    ACTIONS(541), 1,
      anon_sym_LBRACK,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      anon_sym_object,
    ACTIONS(551), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(561), 1,
      anon_sym_new,
    ACTIONS(563), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(565), 1,
      anon_sym_begin,
    ACTIONS(567), 1,
      sym_ocamlyacc_value,
    ACTIONS(573), 1,
      aux_sym_number_token1,
    ACTIONS(575), 1,
      anon_sym_SQUOTE,
    ACTIONS(577), 1,
      anon_sym_DQUOTE,
    ACTIONS(579), 1,
      sym_prefix_operator,
    ACTIONS(583), 1,
      sym__uppercase_identifier,
    ACTIONS(585), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3091), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3093), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3475), 1,
      sym__lowercase_identifier,
    STATE(3597), 1,
      sym__simple_expression,
    STATE(3643), 1,
      sym__value_name,
    STATE(3769), 1,
      sym_parenthesized_operator,
    STATE(3811), 1,
      sym__constructor_name,
    STATE(4729), 1,
      sym_attribute,
    STATE(18672), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(543), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3809), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3557), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149355] = 29,
    ACTIONS(593), 1,
      anon_sym_LPAREN,
    ACTIONS(595), 1,
      anon_sym_LBRACK,
    ACTIONS(599), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_object,
    ACTIONS(605), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(615), 1,
      anon_sym_new,
    ACTIONS(617), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(619), 1,
      anon_sym_begin,
    ACTIONS(621), 1,
      sym_ocamlyacc_value,
    ACTIONS(627), 1,
      aux_sym_number_token1,
    ACTIONS(629), 1,
      anon_sym_SQUOTE,
    ACTIONS(631), 1,
      anon_sym_DQUOTE,
    ACTIONS(633), 1,
      sym_prefix_operator,
    ACTIONS(637), 1,
      sym__uppercase_identifier,
    ACTIONS(639), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3083), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3085), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3405), 1,
      sym__lowercase_identifier,
    STATE(3499), 1,
      sym__simple_expression,
    STATE(3523), 1,
      sym__value_name,
    STATE(3706), 1,
      sym_parenthesized_operator,
    STATE(3764), 1,
      sym__constructor_name,
    STATE(4730), 1,
      sym_attribute,
    STATE(19718), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(597), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3524), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3632), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149473] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(4731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [149545] = 29,
    ACTIONS(863), 1,
      anon_sym_LPAREN,
    ACTIONS(865), 1,
      anon_sym_LBRACK,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_object,
    ACTIONS(875), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(885), 1,
      anon_sym_new,
    ACTIONS(887), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(889), 1,
      anon_sym_begin,
    ACTIONS(891), 1,
      sym_ocamlyacc_value,
    ACTIONS(897), 1,
      aux_sym_number_token1,
    ACTIONS(899), 1,
      anon_sym_SQUOTE,
    ACTIONS(901), 1,
      anon_sym_DQUOTE,
    ACTIONS(903), 1,
      sym_prefix_operator,
    ACTIONS(907), 1,
      sym__uppercase_identifier,
    ACTIONS(909), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3067), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3069), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3855), 1,
      sym__lowercase_identifier,
    STATE(4140), 1,
      sym__constructor_name,
    STATE(4251), 1,
      sym_parenthesized_operator,
    STATE(4385), 1,
      sym__value_name,
    STATE(4406), 1,
      sym__simple_expression,
    STATE(4732), 1,
      sym_attribute,
    STATE(18727), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(867), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4134), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(4323), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 34,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [149733] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2251), 1,
      anon_sym_LPAREN,
    ACTIONS(2253), 1,
      anon_sym_LBRACK,
    ACTIONS(2257), 1,
      anon_sym_LBRACE,
    ACTIONS(2259), 1,
      anon_sym_object,
    ACTIONS(2263), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2273), 1,
      anon_sym_new,
    ACTIONS(2275), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2277), 1,
      anon_sym_begin,
    ACTIONS(2279), 1,
      sym_ocamlyacc_value,
    ACTIONS(2281), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2283), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2285), 1,
      aux_sym_number_token1,
    ACTIONS(2287), 1,
      anon_sym_SQUOTE,
    ACTIONS(2289), 1,
      anon_sym_DQUOTE,
    ACTIONS(2291), 1,
      sym_prefix_operator,
    ACTIONS(2295), 1,
      sym__uppercase_identifier,
    ACTIONS(2297), 1,
      aux_sym_tag_token1,
    ACTIONS(5365), 1,
      sym__lowercase_identifier,
    STATE(4734), 1,
      sym_attribute,
    STATE(6695), 1,
      sym__simple_expression,
    STATE(6727), 1,
      sym__constructor_name,
    STATE(6737), 1,
      sym__value_name,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(19091), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6726), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6686), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [149851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [149921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [149991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [150061] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [150131] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [150201] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1229), 1,
      anon_sym_LPAREN,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1235), 1,
      anon_sym_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_object,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1251), 1,
      anon_sym_new,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1255), 1,
      anon_sym_begin,
    ACTIONS(1257), 1,
      sym_ocamlyacc_value,
    ACTIONS(1259), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(1261), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(1263), 1,
      aux_sym_number_token1,
    ACTIONS(1265), 1,
      anon_sym_SQUOTE,
    ACTIONS(1267), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      sym_prefix_operator,
    ACTIONS(1273), 1,
      sym__uppercase_identifier,
    ACTIONS(1275), 1,
      aux_sym_tag_token1,
    ACTIONS(4645), 1,
      sym__lowercase_identifier,
    STATE(4740), 1,
      sym_attribute,
    STATE(5328), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5375), 1,
      sym__value_name,
    STATE(5447), 1,
      sym__simple_expression,
    STATE(19433), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1233), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5322), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5371), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [150319] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [150389] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2251), 1,
      anon_sym_LPAREN,
    ACTIONS(2253), 1,
      anon_sym_LBRACK,
    ACTIONS(2257), 1,
      anon_sym_LBRACE,
    ACTIONS(2259), 1,
      anon_sym_object,
    ACTIONS(2263), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2273), 1,
      anon_sym_new,
    ACTIONS(2275), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2277), 1,
      anon_sym_begin,
    ACTIONS(2279), 1,
      sym_ocamlyacc_value,
    ACTIONS(2281), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2283), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2285), 1,
      aux_sym_number_token1,
    ACTIONS(2287), 1,
      anon_sym_SQUOTE,
    ACTIONS(2289), 1,
      anon_sym_DQUOTE,
    ACTIONS(2291), 1,
      sym_prefix_operator,
    ACTIONS(2295), 1,
      sym__uppercase_identifier,
    ACTIONS(2297), 1,
      aux_sym_tag_token1,
    ACTIONS(5365), 1,
      sym__lowercase_identifier,
    STATE(4742), 1,
      sym_attribute,
    STATE(6706), 1,
      sym__simple_expression,
    STATE(6727), 1,
      sym__constructor_name,
    STATE(6737), 1,
      sym__value_name,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(19091), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6726), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6686), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [150507] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [150577] = 29,
    ACTIONS(645), 1,
      anon_sym_LPAREN,
    ACTIONS(647), 1,
      anon_sym_LBRACK,
    ACTIONS(651), 1,
      anon_sym_LBRACE,
    ACTIONS(653), 1,
      anon_sym_object,
    ACTIONS(657), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(667), 1,
      anon_sym_new,
    ACTIONS(669), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(671), 1,
      anon_sym_begin,
    ACTIONS(673), 1,
      sym_ocamlyacc_value,
    ACTIONS(679), 1,
      aux_sym_number_token1,
    ACTIONS(681), 1,
      anon_sym_SQUOTE,
    ACTIONS(683), 1,
      anon_sym_DQUOTE,
    ACTIONS(685), 1,
      sym_prefix_operator,
    ACTIONS(689), 1,
      sym__uppercase_identifier,
    ACTIONS(691), 1,
      aux_sym_tag_token1,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3035), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(3037), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(3427), 1,
      sym__lowercase_identifier,
    STATE(3521), 1,
      sym__constructor_name,
    STATE(3577), 1,
      sym__simple_expression,
    STATE(3606), 1,
      sym__value_name,
    STATE(3709), 1,
      sym_parenthesized_operator,
    STATE(4744), 1,
      sym_attribute,
    STATE(19755), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(649), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3810), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(3522), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [150695] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(4745), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(9257), 1,
      sym__binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150831] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    ACTIONS(8690), 1,
      anon_sym_TILDE,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(4746), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9205), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9222), 1,
      sym__binding_pattern,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(9266), 1,
      sym__tuple_binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [150967] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(4747), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(9267), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9278), 1,
      sym__binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151103] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(4748), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(9268), 1,
      sym__binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151239] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7123), 1,
      anon_sym_lazy,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(2625), 1,
      sym_constructor_path,
    STATE(2638), 1,
      sym_tag,
    STATE(4749), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9161), 1,
      sym__signed_constant,
    STATE(9219), 1,
      sym__binding_pattern,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9227), 1,
      sym__or_binding_pattern_anonymous,
    STATE(9228), 1,
      sym__tuple_binding_pattern,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    STATE(19515), 1,
      sym_labeled_tuple_element_binding_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9220), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(9226), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [151375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [151445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [151515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [151585] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [151655] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6799), 1,
      sym__lowercase_identifier,
    ACTIONS(6803), 1,
      anon_sym_LPAREN,
    ACTIONS(6805), 1,
      anon_sym_LBRACK,
    ACTIONS(6809), 1,
      anon_sym_LBRACE,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(6813), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6815), 1,
      anon_sym_new,
    ACTIONS(6817), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(6819), 1,
      anon_sym_begin,
    ACTIONS(6821), 1,
      sym_ocamlyacc_value,
    ACTIONS(6827), 1,
      aux_sym_number_token1,
    ACTIONS(6829), 1,
      anon_sym_SQUOTE,
    ACTIONS(6831), 1,
      anon_sym_DQUOTE,
    ACTIONS(6833), 1,
      sym_prefix_operator,
    ACTIONS(6835), 1,
      sym__uppercase_identifier,
    ACTIONS(6837), 1,
      aux_sym_tag_token1,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4754), 1,
      sym_attribute,
    STATE(8194), 1,
      sym__simple_expression,
    STATE(8203), 1,
      sym_parenthesized_operator,
    STATE(8207), 1,
      sym__constructor_name,
    STATE(8429), 1,
      sym__value_name,
    STATE(18431), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6807), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8206), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8227), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [151773] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2577), 1,
      anon_sym_LPAREN,
    ACTIONS(2579), 1,
      anon_sym_LBRACK,
    ACTIONS(2583), 1,
      anon_sym_LBRACE,
    ACTIONS(2585), 1,
      anon_sym_object,
    ACTIONS(2589), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2599), 1,
      anon_sym_new,
    ACTIONS(2601), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2603), 1,
      anon_sym_begin,
    ACTIONS(2605), 1,
      sym_ocamlyacc_value,
    ACTIONS(2607), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2609), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2611), 1,
      aux_sym_number_token1,
    ACTIONS(2613), 1,
      anon_sym_SQUOTE,
    ACTIONS(2615), 1,
      anon_sym_DQUOTE,
    ACTIONS(2617), 1,
      sym_prefix_operator,
    ACTIONS(2621), 1,
      sym__uppercase_identifier,
    ACTIONS(2623), 1,
      aux_sym_tag_token1,
    ACTIONS(5473), 1,
      sym__lowercase_identifier,
    STATE(4755), 1,
      sym_attribute,
    STATE(7062), 1,
      sym__simple_expression,
    STATE(7093), 1,
      sym__value_name,
    STATE(7150), 1,
      sym_parenthesized_operator,
    STATE(7340), 1,
      sym__constructor_name,
    STATE(18562), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2581), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7338), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7057), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [151891] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2577), 1,
      anon_sym_LPAREN,
    ACTIONS(2579), 1,
      anon_sym_LBRACK,
    ACTIONS(2583), 1,
      anon_sym_LBRACE,
    ACTIONS(2585), 1,
      anon_sym_object,
    ACTIONS(2589), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2599), 1,
      anon_sym_new,
    ACTIONS(2601), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2603), 1,
      anon_sym_begin,
    ACTIONS(2605), 1,
      sym_ocamlyacc_value,
    ACTIONS(2607), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2609), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2611), 1,
      aux_sym_number_token1,
    ACTIONS(2613), 1,
      anon_sym_SQUOTE,
    ACTIONS(2615), 1,
      anon_sym_DQUOTE,
    ACTIONS(2617), 1,
      sym_prefix_operator,
    ACTIONS(2621), 1,
      sym__uppercase_identifier,
    ACTIONS(2623), 1,
      aux_sym_tag_token1,
    ACTIONS(5473), 1,
      sym__lowercase_identifier,
    STATE(4756), 1,
      sym_attribute,
    STATE(7070), 1,
      sym__simple_expression,
    STATE(7093), 1,
      sym__value_name,
    STATE(7150), 1,
      sym_parenthesized_operator,
    STATE(7340), 1,
      sym__constructor_name,
    STATE(18562), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2581), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7338), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7057), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [152009] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2761), 1,
      anon_sym_LPAREN,
    ACTIONS(2763), 1,
      anon_sym_LBRACK,
    ACTIONS(2767), 1,
      anon_sym_LBRACE,
    ACTIONS(2769), 1,
      anon_sym_object,
    ACTIONS(2773), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2783), 1,
      anon_sym_new,
    ACTIONS(2785), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2787), 1,
      anon_sym_begin,
    ACTIONS(2789), 1,
      sym_ocamlyacc_value,
    ACTIONS(2791), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2793), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2795), 1,
      aux_sym_number_token1,
    ACTIONS(2797), 1,
      anon_sym_SQUOTE,
    ACTIONS(2799), 1,
      anon_sym_DQUOTE,
    ACTIONS(2801), 1,
      sym_prefix_operator,
    ACTIONS(2805), 1,
      sym__uppercase_identifier,
    ACTIONS(2807), 1,
      aux_sym_tag_token1,
    ACTIONS(5625), 1,
      sym__lowercase_identifier,
    STATE(4757), 1,
      sym_attribute,
    STATE(7282), 1,
      sym__constructor_name,
    STATE(7355), 1,
      sym__simple_expression,
    STATE(7423), 1,
      sym__value_name,
    STATE(7510), 1,
      sym_parenthesized_operator,
    STATE(19106), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2765), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7138), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7419), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [152127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152267] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(3939), 1,
      anon_sym_DOT,
    ACTIONS(3941), 1,
      anon_sym_POUND,
    ACTIONS(3943), 1,
      sym_hash_operator,
    STATE(4760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152343] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2459), 1,
      anon_sym_LPAREN,
    ACTIONS(2461), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_LBRACE,
    ACTIONS(2467), 1,
      anon_sym_object,
    ACTIONS(2471), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2481), 1,
      anon_sym_new,
    ACTIONS(2483), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2485), 1,
      anon_sym_begin,
    ACTIONS(2487), 1,
      sym_ocamlyacc_value,
    ACTIONS(2489), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2491), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2493), 1,
      aux_sym_number_token1,
    ACTIONS(2495), 1,
      anon_sym_SQUOTE,
    ACTIONS(2497), 1,
      anon_sym_DQUOTE,
    ACTIONS(2499), 1,
      sym_prefix_operator,
    ACTIONS(2503), 1,
      sym__uppercase_identifier,
    ACTIONS(2505), 1,
      aux_sym_tag_token1,
    ACTIONS(5275), 1,
      sym__lowercase_identifier,
    STATE(4761), 1,
      sym_attribute,
    STATE(6554), 1,
      sym__simple_expression,
    STATE(6590), 1,
      sym__value_name,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(6929), 1,
      sym__constructor_name,
    STATE(18617), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2463), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6928), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6549), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [152461] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2459), 1,
      anon_sym_LPAREN,
    ACTIONS(2461), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_LBRACE,
    ACTIONS(2467), 1,
      anon_sym_object,
    ACTIONS(2471), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2481), 1,
      anon_sym_new,
    ACTIONS(2483), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(2485), 1,
      anon_sym_begin,
    ACTIONS(2487), 1,
      sym_ocamlyacc_value,
    ACTIONS(2489), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(2491), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(2493), 1,
      aux_sym_number_token1,
    ACTIONS(2495), 1,
      anon_sym_SQUOTE,
    ACTIONS(2497), 1,
      anon_sym_DQUOTE,
    ACTIONS(2499), 1,
      sym_prefix_operator,
    ACTIONS(2503), 1,
      sym__uppercase_identifier,
    ACTIONS(2505), 1,
      aux_sym_tag_token1,
    ACTIONS(5275), 1,
      sym__lowercase_identifier,
    STATE(4762), 1,
      sym_attribute,
    STATE(6563), 1,
      sym__simple_expression,
    STATE(6590), 1,
      sym__value_name,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(6929), 1,
      sym__constructor_name,
    STATE(18617), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(2463), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(6928), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(6549), 24,
      sym_typed_expression,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_prefix_expression,
      sym_hash_expression,
      sym_field_get_expression,
      sym_array_get_expression,
      sym_string_get_expression,
      sym_bigarray_get_expression,
      sym_coercion_expression,
      sym_local_open_expression,
      sym_package_expression,
      sym_new_expression,
      sym_object_copy_expression,
      sym_method_invocation,
      sym_object_expression,
      sym_parenthesized_expression,
      sym_extension,
      sym_quoted_extension,
      sym__constant,
      sym_value_path,
      sym_constructor_path,
      sym_tag,
  [152579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152649] = 38,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4671), 1,
      anon_sym_TILDE,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4789), 1,
      anon_sym_lazy,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2480), 1,
      sym_constructor_path,
    STATE(2489), 1,
      sym_tag,
    STATE(4764), 1,
      sym_attribute,
    STATE(5488), 1,
      sym__signed_constant,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5605), 1,
      sym__binding_pattern,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5649), 1,
      sym__or_binding_pattern_anonymous,
    STATE(5652), 1,
      sym__tuple_binding_pattern,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(20333), 1,
      sym_labeled_tuple_element_binding_pattern,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5627), 7,
      sym__simple_binding_pattern,
      sym_alias_binding_pattern,
      sym_constructor_binding_pattern,
      sym_tag_binding_pattern,
      sym_cons_binding_pattern,
      sym_range_pattern,
      sym_lazy_binding_pattern,
    STATE(5646), 8,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__value_name,
  [152785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152855] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152925] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 34,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [152995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 32,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153202] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8692), 1,
      anon_sym_COLON,
    STATE(4771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153273] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8694), 1,
      anon_sym_COLON,
    STATE(4772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 32,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153481] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8696), 1,
      anon_sym_COLON,
    STATE(4775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 31,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153687] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8698), 1,
      anon_sym_COLON,
    STATE(4778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 33,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 31,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153892] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [153959] = 32,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5417), 1,
      anon_sym_COLON2,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8700), 1,
      anon_sym_COLON_GT,
    ACTIONS(8702), 1,
      anon_sym_EQ,
    STATE(4782), 1,
      sym_attribute,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(17362), 1,
      sym__polymorphic_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [154080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 31,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [154147] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7218), 1,
      anon_sym_COLON2,
    ACTIONS(8704), 1,
      sym__lowercase_identifier,
    ACTIONS(8710), 1,
      anon_sym_LPAREN,
    ACTIONS(8713), 1,
      anon_sym_LBRACK,
    ACTIONS(8719), 1,
      anon_sym_LBRACE,
    ACTIONS(8722), 1,
      anon_sym_POUND,
    ACTIONS(8725), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8728), 1,
      anon_sym_begin,
    ACTIONS(8731), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8734), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8737), 1,
      aux_sym_number_token1,
    ACTIONS(8740), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8743), 1,
      anon_sym_SQUOTE,
    ACTIONS(8746), 1,
      anon_sym_DQUOTE,
    ACTIONS(8749), 1,
      sym__uppercase_identifier,
    ACTIONS(8752), 1,
      aux_sym_tag_token1,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8707), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(8716), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4784), 2,
      sym_attribute,
      aux_sym_let_binding_repeat1,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    ACTIONS(7216), 3,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [154262] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8759), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4785), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8757), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8755), 30,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [154331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 32,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [154398] = 32,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5417), 1,
      anon_sym_COLON2,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8762), 1,
      anon_sym_COLON_GT,
    ACTIONS(8764), 1,
      anon_sym_EQ,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4787), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18358), 1,
      sym__polymorphic_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [154519] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8770), 1,
      aux_sym_attribute_id_token1,
    STATE(4785), 1,
      aux_sym_attribute_id_repeat1,
    STATE(4788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8768), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8766), 30,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [154590] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8770), 1,
      aux_sym_attribute_id_token1,
    STATE(4788), 1,
      aux_sym_attribute_id_repeat1,
    STATE(4789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8774), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8772), 30,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [154661] = 32,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5417), 1,
      anon_sym_COLON2,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8776), 1,
      anon_sym_COLON_GT,
    ACTIONS(8778), 1,
      anon_sym_EQ,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4790), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(17280), 1,
      sym__polymorphic_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [154782] = 32,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5417), 1,
      anon_sym_COLON2,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8780), 1,
      anon_sym_COLON_GT,
    ACTIONS(8782), 1,
      anon_sym_EQ,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4791), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(17294), 1,
      sym__polymorphic_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [154903] = 32,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5417), 1,
      anon_sym_COLON2,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8784), 1,
      anon_sym_COLON_GT,
    ACTIONS(8786), 1,
      anon_sym_EQ,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4792), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18365), 1,
      sym__polymorphic_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155024] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8790), 1,
      anon_sym_DASH_GT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4793), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20129), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155142] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8794), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4794), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19727), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155260] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8796), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4795), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19383), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155378] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8798), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4796), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21402), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155496] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8800), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4797), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18464), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155614] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8802), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4798), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19358), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155732] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8804), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4799), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19412), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155850] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8806), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4800), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19502), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [155968] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8808), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4801), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19408), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156086] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8810), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4802), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18555), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [156270] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8812), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4804), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20858), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156388] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8814), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4805), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21346), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156506] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8816), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4806), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18758), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156624] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8818), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4807), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21042), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156742] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8820), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4808), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19725), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156860] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8822), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4809), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19001), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [156978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [157044] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8824), 1,
      anon_sym_LT_DASH,
    STATE(4811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [157112] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8826), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4812), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19325), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157230] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8828), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4813), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19752), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157348] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8830), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4814), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19945), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157466] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8832), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4815), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19239), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157584] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8834), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4816), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19720), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157702] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8836), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4817), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18687), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157820] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8838), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4818), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20509), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [157938] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8840), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4819), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18749), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158056] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8842), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4820), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19779), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158174] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8844), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4821), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18478), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158292] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8846), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4822), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18589), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158410] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8848), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4823), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19896), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158528] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8850), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4824), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19914), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158646] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8852), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4825), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20448), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158764] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8854), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4826), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19943), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [158882] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8856), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4827), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20750), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159000] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8858), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4828), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19979), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159118] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8860), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4829), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20180), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [159302] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8862), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4831), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18811), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159420] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8864), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4832), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20237), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159538] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8866), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4833), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20871), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [159722] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8868), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4835), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21186), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159840] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8870), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4836), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18953), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [159958] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8872), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4837), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20323), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160076] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8874), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4838), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18576), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160194] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8876), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4839), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20070), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160312] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8878), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4840), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21206), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160430] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(4841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [160498] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8880), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4842), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18644), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160616] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8882), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4843), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19414), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160734] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8884), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4844), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18686), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160852] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8886), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4845), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21197), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [160970] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8888), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4846), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20407), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161088] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8890), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4847), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20447), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161206] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8892), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4848), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19272), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161324] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8894), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4849), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19348), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161442] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8896), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4850), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21211), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161560] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8898), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4851), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19574), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161678] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8900), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4852), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18456), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161796] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8902), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4853), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19633), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [161914] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8904), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4854), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19213), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162032] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8906), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4855), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19227), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162150] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8908), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4856), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18990), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162268] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8910), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4857), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19317), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162386] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8912), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4858), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19049), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162504] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8914), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4859), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20856), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8757), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
    ACTIONS(8755), 30,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [162688] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8916), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4861), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19007), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162806] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8918), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4862), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20963), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [162924] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8920), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4863), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20474), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163042] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8922), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4864), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21064), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163160] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8924), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4865), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19367), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163278] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8926), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4866), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19129), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163396] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8928), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4867), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18496), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163514] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8930), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4868), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20996), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163632] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8932), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4869), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19303), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163750] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8934), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4870), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20203), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163868] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8936), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4871), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20025), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [163986] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [164052] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8938), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4873), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19015), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164170] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8940), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4874), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20862), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164288] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8942), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4875), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19444), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164406] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8944), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4876), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19816), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164524] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8946), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4877), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19102), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164642] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8948), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4878), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19110), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164760] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8950), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4879), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20172), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164878] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8952), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4880), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19407), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [164996] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8954), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4881), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19236), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165114] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8956), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4882), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20786), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165232] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8958), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4883), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20847), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165350] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8960), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4884), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20832), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165468] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8962), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4885), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19937), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165586] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8964), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4886), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(18597), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165704] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8966), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4887), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21250), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165822] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8968), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4888), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(20952), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [165940] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8970), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4889), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21119), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166124] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8972), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4891), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(21358), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166242] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 31,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166440] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8974), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4895), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    STATE(19874), 1,
      sym__simple_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166558] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8788), 1,
      anon_sym_COLON2,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8976), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(4896), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19395), 1,
      sym__simple_typed,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166676] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166741] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4869), 1,
      aux_sym_let_binding_repeat1,
    STATE(4898), 1,
      sym_attribute,
    STATE(5212), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [166856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [166986] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(4901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167053] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4829), 1,
      aux_sym_let_binding_repeat1,
    STATE(4902), 1,
      sym_attribute,
    STATE(5189), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167298] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4831), 1,
      aux_sym_let_binding_repeat1,
    STATE(4905), 1,
      sym_attribute,
    STATE(5137), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167413] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4896), 1,
      aux_sym_let_binding_repeat1,
    STATE(4906), 1,
      sym_attribute,
    STATE(5152), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167528] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4883), 1,
      aux_sym_let_binding_repeat1,
    STATE(4907), 1,
      sym_attribute,
    STATE(5216), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [167643] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167708] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167773] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [167968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [168033] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4878), 1,
      aux_sym_let_binding_repeat1,
    STATE(4914), 1,
      sym_attribute,
    STATE(5220), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [168213] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4828), 1,
      aux_sym_let_binding_repeat1,
    STATE(4916), 1,
      sym_attribute,
    STATE(5223), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168328] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4863), 1,
      aux_sym_let_binding_repeat1,
    STATE(4917), 1,
      sym_attribute,
    STATE(5175), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168443] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [168508] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4823), 1,
      aux_sym_let_binding_repeat1,
    STATE(4919), 1,
      sym_attribute,
    STATE(5168), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168623] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4867), 1,
      aux_sym_let_binding_repeat1,
    STATE(4920), 1,
      sym_attribute,
    STATE(5153), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [168803] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4845), 1,
      aux_sym_let_binding_repeat1,
    STATE(4922), 1,
      sym_attribute,
    STATE(5224), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [168918] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [168983] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4846), 1,
      aux_sym_let_binding_repeat1,
    STATE(4924), 1,
      sym_attribute,
    STATE(5191), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169423] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4817), 1,
      aux_sym_let_binding_repeat1,
    STATE(4930), 1,
      sym_attribute,
    STATE(5226), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [169733] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4856), 1,
      aux_sym_let_binding_repeat1,
    STATE(4934), 1,
      sym_attribute,
    STATE(5228), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169848] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4799), 1,
      aux_sym_let_binding_repeat1,
    STATE(4935), 1,
      sym_attribute,
    STATE(5230), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [169963] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4808), 1,
      aux_sym_let_binding_repeat1,
    STATE(4936), 1,
      sym_attribute,
    STATE(5232), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170078] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4824), 1,
      aux_sym_let_binding_repeat1,
    STATE(4937), 1,
      sym_attribute,
    STATE(5233), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170193] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4859), 1,
      aux_sym_let_binding_repeat1,
    STATE(4938), 1,
      sym_attribute,
    STATE(5192), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170308] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8978), 1,
      anon_sym_LT_DASH,
    STATE(4939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [170375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [170440] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4875), 1,
      aux_sym_let_binding_repeat1,
    STATE(4941), 1,
      sym_attribute,
    STATE(5157), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [170620] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4853), 1,
      aux_sym_let_binding_repeat1,
    STATE(4943), 1,
      sym_attribute,
    STATE(5131), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170735] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4891), 1,
      aux_sym_let_binding_repeat1,
    STATE(4944), 1,
      sym_attribute,
    STATE(5194), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [170850] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(4945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [170917] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(4946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [170984] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4857), 1,
      aux_sym_let_binding_repeat1,
    STATE(4947), 1,
      sym_attribute,
    STATE(5146), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171164] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4838), 1,
      aux_sym_let_binding_repeat1,
    STATE(4949), 1,
      sym_attribute,
    STATE(5176), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171344] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171409] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4793), 1,
      aux_sym_let_binding_repeat1,
    STATE(4952), 1,
      sym_attribute,
    STATE(5196), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [171524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171589] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [171914] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4850), 1,
      aux_sym_let_binding_repeat1,
    STATE(4959), 1,
      sym_attribute,
    STATE(5158), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172029] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4876), 1,
      aux_sym_let_binding_repeat1,
    STATE(4960), 1,
      sym_attribute,
    STATE(5139), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172209] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172339] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172404] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4815), 1,
      aux_sym_let_binding_repeat1,
    STATE(4965), 1,
      sym_attribute,
    STATE(5200), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172519] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172649] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4873), 1,
      aux_sym_let_binding_repeat1,
    STATE(4968), 1,
      sym_attribute,
    STATE(5177), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [172764] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [172894] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4809), 1,
      aux_sym_let_binding_repeat1,
    STATE(4971), 1,
      sym_attribute,
    STATE(5162), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173074] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173204] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4559), 1,
      anon_sym_DOT,
    STATE(4975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173336] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4880), 1,
      aux_sym_let_binding_repeat1,
    STATE(4977), 1,
      sym_attribute,
    STATE(5135), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173451] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4837), 1,
      aux_sym_let_binding_repeat1,
    STATE(4978), 1,
      sym_attribute,
    STATE(5204), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173631] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4882), 1,
      aux_sym_let_binding_repeat1,
    STATE(4980), 1,
      sym_attribute,
    STATE(5136), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173746] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4870), 1,
      aux_sym_let_binding_repeat1,
    STATE(4981), 1,
      sym_attribute,
    STATE(5151), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [173861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [173991] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4821), 1,
      aux_sym_let_binding_repeat1,
    STATE(4984), 1,
      sym_attribute,
    STATE(5133), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174106] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4798), 1,
      aux_sym_let_binding_repeat1,
    STATE(4985), 1,
      sym_attribute,
    STATE(5180), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174221] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174286] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4842), 1,
      aux_sym_let_binding_repeat1,
    STATE(4987), 1,
      sym_attribute,
    STATE(5163), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174466] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4835), 1,
      aux_sym_let_binding_repeat1,
    STATE(4989), 1,
      sym_attribute,
    STATE(5245), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174581] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4804), 1,
      aux_sym_let_binding_repeat1,
    STATE(4990), 1,
      sym_attribute,
    STATE(5171), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [174696] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8980), 1,
      anon_sym_LT_DASH,
    STATE(4991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174763] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174893] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [174958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175088] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(4998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175218] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4861), 1,
      aux_sym_let_binding_repeat1,
    STATE(4999), 1,
      sym_attribute,
    STATE(5165), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175333] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4816), 1,
      aux_sym_let_binding_repeat1,
    STATE(5000), 1,
      sym_attribute,
    STATE(5185), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175448] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4849), 1,
      aux_sym_let_binding_repeat1,
    STATE(5001), 1,
      sym_attribute,
    STATE(5206), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [175563] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175758] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175823] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [175953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176018] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4854), 1,
      aux_sym_let_binding_repeat1,
    STATE(5009), 1,
      sym_attribute,
    STATE(5167), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [176133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176263] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176588] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [176978] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4559), 1,
      anon_sym_DOT,
    ACTIONS(4561), 1,
      anon_sym_POUND,
    ACTIONS(4563), 1,
      sym_hash_operator,
    STATE(5023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177049] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177114] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4827), 1,
      aux_sym_let_binding_repeat1,
    STATE(5025), 1,
      sym_attribute,
    STATE(5142), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177229] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177294] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4862), 1,
      aux_sym_let_binding_repeat1,
    STATE(5027), 1,
      sym_attribute,
    STATE(5208), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177409] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4866), 1,
      aux_sym_let_binding_repeat1,
    STATE(5028), 1,
      sym_attribute,
    STATE(5173), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177524] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4559), 1,
      anon_sym_DOT,
    ACTIONS(4561), 1,
      anon_sym_POUND,
    ACTIONS(4563), 1,
      sym_hash_operator,
    STATE(5029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177595] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7420), 1,
      anon_sym_PERCENT,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4888), 1,
      aux_sym_let_binding_repeat1,
    STATE(5030), 1,
      sym_attribute,
    STATE(5166), 1,
      sym__attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [177710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177775] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 30,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [177968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178032] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178288] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8982), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(5040), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [178400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178464] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178592] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178656] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7965), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [178720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [178976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179232] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179296] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179426] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4569), 1,
      anon_sym_DOT,
    ACTIONS(4571), 1,
      anon_sym_POUND,
    ACTIONS(4573), 1,
      sym_hash_operator,
    STATE(5057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179560] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179624] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179754] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8986), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5062), 2,
      sym_attribute,
      aux_sym__structure_repeat1,
    ACTIONS(8989), 17,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8984), 30,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [179820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [179948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180140] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180460] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8991), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(5073), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [180572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180636] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180700] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8993), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(5076), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [180812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [180940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181004] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7957), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [181068] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181132] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4569), 1,
      anon_sym_DOT,
    ACTIONS(4571), 1,
      anon_sym_POUND,
    ACTIONS(4573), 1,
      sym_hash_operator,
    STATE(5082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181458] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8995), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5087), 2,
      sym_attribute,
      aux_sym__structure_repeat1,
    ACTIONS(8989), 18,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8984), 29,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [181524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181588] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181652] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181780] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181844] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(4569), 1,
      anon_sym_DOT,
    STATE(5093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [181974] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182166] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182294] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8998), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(5100), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [182406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182662] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9000), 1,
      anon_sym_LT_DASH,
    STATE(5105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182920] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [182984] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(5110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [183050] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183178] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9002), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(5113), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [183290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183354] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7949), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [183418] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7933), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [183482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183546] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183610] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7961), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [183674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183802] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7953), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [183866] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [183994] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8792), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9004), 1,
      anon_sym_DASH_GT,
    STATE(4784), 1,
      aux_sym_let_binding_repeat1,
    STATE(5125), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7937), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [184170] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7941), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [184234] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7945), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [184298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [184362] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8190), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [184425] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4874), 1,
      aux_sym_let_binding_repeat1,
    STATE(5131), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184534] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8194), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [184597] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4822), 1,
      aux_sym_let_binding_repeat1,
    STATE(5133), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184706] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8206), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [184769] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4895), 1,
      aux_sym_let_binding_repeat1,
    STATE(5135), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184878] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4886), 1,
      aux_sym_let_binding_repeat1,
    STATE(5136), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [184987] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4836), 1,
      aux_sym_let_binding_repeat1,
    STATE(5137), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185096] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7961), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185159] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4879), 1,
      aux_sym_let_binding_repeat1,
    STATE(5139), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185268] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185331] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8290), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185394] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4833), 1,
      aux_sym_let_binding_repeat1,
    STATE(5142), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185503] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8312), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185566] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8202), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9008), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9006), 29,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [185692] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4802), 1,
      aux_sym_let_binding_repeat1,
    STATE(5146), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [185801] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8294), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185864] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8022), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185927] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7965), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [185990] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8298), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186053] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4807), 1,
      aux_sym_let_binding_repeat1,
    STATE(5151), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186162] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4848), 1,
      aux_sym_let_binding_repeat1,
    STATE(5152), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186271] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4881), 1,
      aux_sym_let_binding_repeat1,
    STATE(5153), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186380] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186443] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8222), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186506] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7937), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186569] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4794), 1,
      aux_sym_let_binding_repeat1,
    STATE(5157), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186678] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4852), 1,
      aux_sym_let_binding_repeat1,
    STATE(5158), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [186787] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7941), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186850] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7961), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186913] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7945), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [186976] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4814), 1,
      aux_sym_let_binding_repeat1,
    STATE(5162), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187085] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4843), 1,
      aux_sym_let_binding_repeat1,
    STATE(5163), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187194] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8226), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [187257] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4865), 1,
      aux_sym_let_binding_repeat1,
    STATE(5165), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187366] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4889), 1,
      aux_sym_let_binding_repeat1,
    STATE(5166), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187475] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4855), 1,
      aux_sym_let_binding_repeat1,
    STATE(5167), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187584] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4825), 1,
      aux_sym_let_binding_repeat1,
    STATE(5168), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187693] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7937), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [187756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7941), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [187819] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4805), 1,
      aux_sym_let_binding_repeat1,
    STATE(5171), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [187928] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7945), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [187991] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4795), 1,
      aux_sym_let_binding_repeat1,
    STATE(5173), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [188100] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9010), 1,
      anon_sym_COLON,
    STATE(5174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [188165] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4884), 1,
      aux_sym_let_binding_repeat1,
    STATE(5175), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [188274] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4844), 1,
      aux_sym_let_binding_repeat1,
    STATE(5176), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [188383] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4877), 1,
      aux_sym_let_binding_repeat1,
    STATE(5177), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [188492] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8332), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [188555] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7949), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [188618] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4801), 1,
      aux_sym_let_binding_repeat1,
    STATE(5180), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [188727] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7953), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [188790] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [188853] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7957), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [188916] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8230), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [188979] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4820), 1,
      aux_sym_let_binding_repeat1,
    STATE(5185), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189088] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189153] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8282), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189216] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189279] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4832), 1,
      aux_sym_let_binding_repeat1,
    STATE(5189), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189388] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8344), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189451] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4847), 1,
      aux_sym_let_binding_repeat1,
    STATE(5191), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189560] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4868), 1,
      aux_sym_let_binding_repeat1,
    STATE(5192), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189669] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8234), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189732] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4796), 1,
      aux_sym_let_binding_repeat1,
    STATE(5194), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [189841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8316), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [189904] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4806), 1,
      aux_sym_let_binding_repeat1,
    STATE(5196), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [190013] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8238), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190076] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7965), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190139] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8242), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190202] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4818), 1,
      aux_sym_let_binding_repeat1,
    STATE(5200), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [190311] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8218), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190374] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8354), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9008), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9006), 30,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [190500] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4840), 1,
      aux_sym_let_binding_repeat1,
    STATE(5204), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [190609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8358), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190672] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4851), 1,
      aux_sym_let_binding_repeat1,
    STATE(5206), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [190781] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7949), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [190844] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4864), 1,
      aux_sym_let_binding_repeat1,
    STATE(5208), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [190953] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8320), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191016] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7953), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191079] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8246), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191142] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4871), 1,
      aux_sym_let_binding_repeat1,
    STATE(5212), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [191251] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191316] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8182), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191379] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191442] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4887), 1,
      aux_sym_let_binding_repeat1,
    STATE(5216), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [191551] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(5217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191616] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8198), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191679] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7957), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191742] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4812), 1,
      aux_sym_let_binding_repeat1,
    STATE(5220), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [191851] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8250), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191914] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(5222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [191979] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4839), 1,
      aux_sym_let_binding_repeat1,
    STATE(5223), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192088] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4797), 1,
      aux_sym_let_binding_repeat1,
    STATE(5224), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192197] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9012), 1,
      anon_sym_LT_DASH,
    STATE(5225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192262] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4819), 1,
      aux_sym_let_binding_repeat1,
    STATE(5226), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192371] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8308), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192434] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4858), 1,
      aux_sym_let_binding_repeat1,
    STATE(5228), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192543] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8254), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192606] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4800), 1,
      aux_sym_let_binding_repeat1,
    STATE(5230), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192715] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4579), 1,
      anon_sym_DOT,
    ACTIONS(4581), 1,
      anon_sym_POUND,
    ACTIONS(4583), 1,
      sym_hash_operator,
    STATE(5231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8186), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [192784] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4813), 1,
      aux_sym_let_binding_repeat1,
    STATE(5232), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [192893] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4826), 1,
      aux_sym_let_binding_repeat1,
    STATE(5233), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193002] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9014), 1,
      anon_sym_lazy,
    STATE(2981), 1,
      sym_constructor_path,
    STATE(3085), 1,
      sym_tag,
    STATE(5234), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(20846), 1,
      sym_module_path,
    STATE(21048), 1,
      sym__effect_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 13,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [193113] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5125), 1,
      aux_sym_let_binding_repeat1,
    STATE(5235), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193222] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193285] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9014), 1,
      anon_sym_lazy,
    STATE(2981), 1,
      sym_constructor_path,
    STATE(3085), 1,
      sym_tag,
    STATE(5237), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(19966), 1,
      sym__effect_pattern,
    STATE(20846), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 13,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [193396] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5040), 1,
      aux_sym_let_binding_repeat1,
    STATE(5238), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193505] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5100), 1,
      aux_sym_let_binding_repeat1,
    STATE(5239), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193614] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193677] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5073), 1,
      aux_sym_let_binding_repeat1,
    STATE(5241), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193786] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4579), 1,
      anon_sym_DOT,
    ACTIONS(4581), 1,
      anon_sym_POUND,
    ACTIONS(4583), 1,
      sym_hash_operator,
    STATE(5242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [193855] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5076), 1,
      aux_sym_let_binding_repeat1,
    STATE(5243), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [193964] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194027] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(4885), 1,
      aux_sym_let_binding_repeat1,
    STATE(5245), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194136] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8258), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194199] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5407), 1,
      anon_sym_LPAREN,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5113), 1,
      aux_sym_let_binding_repeat1,
    STATE(5247), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10586), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5405), 2,
      anon_sym_TILDE,
      anon_sym_QMARK,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10790), 2,
      sym_parameter,
      sym__parenthesized_abstract_type,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [194308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8262), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194371] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194434] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8266), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194497] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8270), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194560] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7933), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8286), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194686] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(4859), 1,
      sym__uppercase_identifier,
    ACTIONS(4861), 1,
      aux_sym_tag_token1,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9014), 1,
      anon_sym_lazy,
    STATE(2981), 1,
      sym_constructor_path,
    STATE(3085), 1,
      sym_tag,
    STATE(5254), 1,
      sym_attribute,
    STATE(8763), 1,
      sym__constructor_name,
    STATE(20846), 1,
      sym_module_path,
    STATE(21056), 1,
      sym__effect_pattern,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(13851), 4,
      sym__simple_pattern,
      sym_constructor_pattern,
      sym_tag_pattern,
      sym_lazy_pattern,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 13,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [194797] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194860] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194923] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [194986] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195112] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195238] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195301] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195364] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195427] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195490] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195553] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7933), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195616] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195679] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4579), 1,
      anon_sym_DOT,
    STATE(5269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195744] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195807] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195870] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195933] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [195996] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196122] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196248] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196311] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8154), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196374] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8158), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196437] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8162), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196500] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8166), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196563] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8170), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196626] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8174), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196689] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8178), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196752] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8324), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196815] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8320), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196877] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8170), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [196939] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8174), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197001] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197125] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197187] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197251] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197313] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8294), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197375] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197437] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8022), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197499] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8178), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197561] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8182), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197749] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [197873] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8206), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197935] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [197997] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198059] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198123] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8190), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8332), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198247] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8194), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198309] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198371] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8198), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198495] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8202), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198557] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8246), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198619] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8194), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198681] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8250), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8230), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198805] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8254), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198867] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(5320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198931] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [198995] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8282), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199057] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9016), 1,
      anon_sym_LT_DASH,
    STATE(5323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199121] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8198), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199183] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9018), 1,
      anon_sym_LT_DASH,
    STATE(5325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199247] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199309] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199371] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199495] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199557] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199619] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8298), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199681] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7961), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199805] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199867] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8202), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199929] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8226), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [199991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 29,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [200053] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8238), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200115] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200177] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8178), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200239] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8182), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200301] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8312), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200363] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8234), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200425] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200487] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8166), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200549] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8238), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200611] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8258), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200673] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8242), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200735] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8174), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200797] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9020), 1,
      anon_sym_COLON,
    STATE(5351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [200861] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8316), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200923] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8344), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [200985] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8262), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201111] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8324), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201173] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201235] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8286), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201359] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [201423] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201485] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8246), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201547] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8266), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8250), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201733] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8254), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201795] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201857] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8258), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201919] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8262), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [201981] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202043] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202105] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8266), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202167] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202229] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202291] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202353] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8290), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8270), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202477] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8270), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202539] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202601] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202663] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8242), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202787] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202849] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8294), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202911] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8022), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [202973] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8298), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203035] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203097] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203159] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8222), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203221] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4649), 1,
      anon_sym_DOT,
    ACTIONS(4651), 1,
      anon_sym_POUND,
    ACTIONS(4653), 1,
      sym_hash_operator,
    STATE(5390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8186), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203289] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203351] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8222), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203413] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8226), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203475] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203537] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203599] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8206), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203661] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203723] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203785] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203847] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4659), 1,
      anon_sym_DOT,
    ACTIONS(4661), 1,
      anon_sym_POUND,
    ACTIONS(4663), 1,
      sym_hash_operator,
    STATE(5400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203915] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8308), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [203977] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4649), 1,
      anon_sym_DOT,
    ACTIONS(4651), 1,
      anon_sym_POUND,
    ACTIONS(4653), 1,
      sym_hash_operator,
    STATE(5402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7933), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204107] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204169] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8308), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8154), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204293] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8312), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204355] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8234), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204417] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204479] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4659), 1,
      anon_sym_DOT,
    ACTIONS(4661), 1,
      anon_sym_POUND,
    ACTIONS(4663), 1,
      sym_hash_operator,
    STATE(5410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8186), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204547] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8158), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7937), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7941), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204733] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7945), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204795] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8162), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204857] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8316), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204919] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8320), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [204981] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8170), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205043] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7949), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205105] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205167] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8290), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205229] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7953), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205291] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7957), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205353] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4659), 1,
      anon_sym_DOT,
    STATE(5424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205417] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205479] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8230), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205665] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205727] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8218), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8324), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205851] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8332), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205913] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [205975] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8282), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206037] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206099] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206223] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [206287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206349] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206411] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206473] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206535] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8190), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206597] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7965), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206659] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8154), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206783] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4649), 1,
      anon_sym_DOT,
    STATE(5447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206847] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8344), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8158), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [206971] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8354), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207033] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207095] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207157] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8218), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207219] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8354), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207281] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8358), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8162), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207405] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8166), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207467] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8358), 25,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207529] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207593] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207655] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8286), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207717] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8258), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207778] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8066), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8332), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207900] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8234), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [207961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8078), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208022] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8070), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9024), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9022), 34,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [208144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9028), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208205] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9030), 34,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [208329] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8086), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208390] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8090), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208451] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8094), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208512] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8098), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208573] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8102), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208634] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8106), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208695] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4709), 1,
      anon_sym_DOT,
    ACTIONS(4711), 1,
      anon_sym_POUND,
    ACTIONS(4713), 1,
      sym_hash_operator,
    STATE(5478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8186), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8070), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208823] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8110), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208884] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8074), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [208945] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4709), 1,
      anon_sym_DOT,
    STATE(5482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8114), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209008] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8118), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209069] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8122), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209130] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8126), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209191] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8130), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209252] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8134), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209313] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9034), 1,
      anon_sym_DOT_DOT,
    STATE(5488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4669), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(4667), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209437] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8138), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209498] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8270), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8354), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209620] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8142), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209681] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9040), 1,
      anon_sym_COLON,
    STATE(5494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9036), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9038), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209744] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8358), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209868] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209931] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8146), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [209992] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8150), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210114] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8364), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8154), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210236] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8158), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8162), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210358] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8166), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210419] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8170), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210480] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8174), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8332), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210602] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8178), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210663] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8182), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210724] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9042), 1,
      anon_sym_LT_DASH,
    STATE(5511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210787] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8238), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9046), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8340), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [210970] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8250), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211031] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8190), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211092] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8194), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211153] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8198), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211214] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8254), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211275] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8202), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211336] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7915), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211397] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8286), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211458] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8282), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211519] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9048), 1,
      anon_sym_COLON,
    STATE(5524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9038), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9036), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [211582] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211643] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8336), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211704] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8344), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211765] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8294), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211826] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8022), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211887] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8210), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [211948] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8298), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212009] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8214), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9050), 34,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [212131] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [212192] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8308), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212253] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9046), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [212375] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8302), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212438] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212499] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [212562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8074), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8218), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212684] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8242), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8206), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8354), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212928] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8358), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [212989] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8312), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213050] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8230), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213111] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8226), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213172] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 28,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [213233] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8316), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213294] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8320), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213355] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213416] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8246), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213477] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8354), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213538] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8262), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8282), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8282), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8054), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9028), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213843] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [213906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8358), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [213967] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8058), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [214089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8344), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214150] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8062), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214211] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214272] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8206), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214333] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8332), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214394] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9054), 1,
      anon_sym_DOT_DOT,
    STATE(5571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(4669), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [214457] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8344), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [214640] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8324), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214701] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4709), 1,
      anon_sym_DOT,
    ACTIONS(4711), 1,
      anon_sym_POUND,
    ACTIONS(4713), 1,
      sym_hash_operator,
    STATE(5576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214768] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8266), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214829] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8222), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214890] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8328), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [214951] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9056), 1,
      anon_sym_COLON,
    STATE(5580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8446), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8448), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215014] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215075] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8290), 24,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9060), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9058), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9064), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9062), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9068), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9066), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215376] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8312), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [215616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9072), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9070), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215676] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8354), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9074), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9076), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9078), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9080), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9084), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9082), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [215916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8358), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [215976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9086), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9088), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9092), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9090), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9096), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9094), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9100), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8074), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216336] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9028), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9106), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9108), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216516] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5409), 1,
      anon_sym_COMMA,
    ACTIONS(5425), 1,
      anon_sym_COLON_COLON,
    STATE(5606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9110), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216580] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5409), 1,
      anon_sym_COMMA,
    STATE(5607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9112), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9070), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9072), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9114), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9118), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [216822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8316), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9046), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [216942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9124), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9122), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217002] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9126), 1,
      anon_sym_COLON,
    STATE(5614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9036), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9038), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217064] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8320), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217124] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8324), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9112), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9066), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9068), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9128), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217364] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5409), 1,
      anon_sym_COMMA,
    ACTIONS(5411), 1,
      anon_sym_PIPE,
    ACTIONS(5425), 1,
      anon_sym_COLON_COLON,
    STATE(5620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9132), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9136), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9082), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9084), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217610] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9144), 1,
      anon_sym_DOT_DOT,
    STATE(5624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(4669), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8070), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9148), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9088), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9086), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [217912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8344), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [217972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9152), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9150), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [218032] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9102), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [218092] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9028), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218212] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218272] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5425), 1,
      anon_sym_COLON_COLON,
    STATE(5635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218334] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9162), 1,
      anon_sym_LT_DASH,
    STATE(5636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [218396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218456] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(5638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [218518] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8568), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8570), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [218638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8286), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218698] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9168), 1,
      anon_sym_COLON,
    STATE(5642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9036), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9038), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9170), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [218820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8294), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9152), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [218940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4669), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(4667), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219000] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8022), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [219120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9106), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9060), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219300] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219360] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5617), 1,
      anon_sym_COMMA,
    ACTIONS(5623), 1,
      anon_sym_COLON_COLON,
    STATE(5653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9110), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219484] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9182), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9188), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8328), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219784] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9190), 1,
      anon_sym_COLON,
    STATE(5660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8446), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8448), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219846] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9192), 1,
      anon_sym_DOT_DOT,
    STATE(5661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4669), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(4667), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [219908] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9194), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [219968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9046), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220088] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9092), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9096), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9116), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9164), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9206), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9212), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9210), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220628] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9062), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9064), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9194), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9196), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [220808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9214), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220868] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [220928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [220988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [221048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9218), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [221108] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9080), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9078), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [221168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8332), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8282), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221348] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8344), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9224), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8070), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221528] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5617), 1,
      anon_sym_COMMA,
    STATE(5689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9110), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [221590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9110), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [221650] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9220), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9118), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9120), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9226), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [221830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9228), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221890] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [221950] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222010] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9140), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [222130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8298), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9188), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9186), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8354), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8282), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9202), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8358), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222490] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8308), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8074), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9232), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222670] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [222730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [222850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9212), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [222910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [222970] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9222), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223030] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [223090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [223150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223210] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223270] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8290), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8206), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223510] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9234), 1,
      anon_sym_COLON,
    STATE(5722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8448), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9236), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223632] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9240), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223692] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5617), 1,
      anon_sym_COMMA,
    ACTIONS(5619), 1,
      anon_sym_PIPE,
    ACTIONS(5623), 1,
      anon_sym_COLON_COLON,
    STATE(5725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9132), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223758] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [223818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9076), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9074), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223878] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9148), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9146), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223938] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9100), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9098), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [223998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224058] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224178] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224238] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8332), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(4669), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9174), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9132), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224538] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9154), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224598] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9178), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9198), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9214), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9216), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224778] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5623), 1,
      anon_sym_COLON_COLON,
    STATE(5743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9158), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9124), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [224900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9230), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [224960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9092), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225019] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9188), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225078] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9244), 1,
      anon_sym_LT_DASH,
    STATE(5748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9078), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9080), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9116), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9070), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9072), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8316), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225434] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9166), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225493] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9246), 1,
      anon_sym_LT_DASH,
    STATE(5755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8320), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225613] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9070), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9072), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8290), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225731] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9180), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9200), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8324), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [225908] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [225967] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9062), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9064), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9130), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226203] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226262] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(5768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8294), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9082), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9084), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226618] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9138), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226677] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8022), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226795] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [226913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9086), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9088), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [226972] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5183), 1,
      anon_sym_DOT,
    ACTIONS(5185), 1,
      anon_sym_POUND,
    ACTIONS(5187), 1,
      sym_hash_operator,
    STATE(5780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227096] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227155] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9232), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9106), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9108), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8298), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227391] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227627] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9066), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9068), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227804] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227863] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [227922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9232), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [227981] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [228099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [228217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9148), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [228335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(4669), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [228394] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(5749), 1,
      anon_sym_COLON_COLON,
    STATE(5804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9112), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228457] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8308), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8286), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228575] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [228634] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    STATE(5808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9112), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9212), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9112), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9194), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9196), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [228931] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(5745), 1,
      anon_sym_PIPE,
    ACTIONS(5749), 1,
      anon_sym_COLON_COLON,
    STATE(5813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9132), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [228996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9134), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9208), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9092), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229232] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [229291] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9156), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229350] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9212), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [229468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9096), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229527] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8022), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [229645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8312), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [229763] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [229822] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5749), 1,
      anon_sym_COLON_COLON,
    STATE(5828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9160), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229883] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8316), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [229942] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9156), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230001] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5183), 1,
      anon_sym_DOT,
    STATE(5831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9096), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8320), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230239] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9152), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8324), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230357] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9180), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230475] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9116), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230593] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230652] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230711] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9220), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [230888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9118), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9120), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [230947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9200), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9062), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9064), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231124] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9194), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9196), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231242] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9220), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9066), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9068), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231360] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8570), 23,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231419] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9228), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9188), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231537] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9228), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(7915), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [231773] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231891] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(5863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [231952] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9060), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9238), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9124), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8286), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9214), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9216), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232365] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9224), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9118), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9120), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [232542] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232601] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [232896] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5865), 1,
      anon_sym_COLON_COLON,
    STATE(5880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9158), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [232957] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233016] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233075] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9152), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9224), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233429] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233488] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5183), 1,
      anon_sym_DOT,
    ACTIONS(5185), 1,
      anon_sym_POUND,
    ACTIONS(5187), 1,
      sym_hash_operator,
    STATE(5890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233553] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8312), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233612] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233671] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9242), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9214), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9216), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [233907] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [233966] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234084] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8294), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9130), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234261] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9138), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234320] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8298), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234379] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234438] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234497] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234556] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9124), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9172), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9238), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9172), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234792] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9248), 1,
      anon_sym_COLON,
    STATE(5912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8448), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234853] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9078), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9080), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [234912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [234971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235030] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9086), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9088), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9242), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9074), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9076), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235266] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(7915), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235384] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9166), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235443] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9100), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9100), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235620] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9104), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9148), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235797] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [235858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235917] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4669), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(4667), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [235976] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9106), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9108), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8308), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9142), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236153] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5859), 1,
      anon_sym_COMMA,
    ACTIONS(5865), 1,
      anon_sym_COLON_COLON,
    STATE(5935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9110), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [236216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9060), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9074), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9076), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236334] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5859), 1,
      anon_sym_COMMA,
    STATE(5938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9110), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [236395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236454] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9176), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236749] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9082), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9084), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9112), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [236926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8290), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [236985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237103] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237162] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237221] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237280] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5859), 1,
      anon_sym_COMMA,
    ACTIONS(5861), 1,
      anon_sym_PIPE,
    ACTIONS(5865), 1,
      anon_sym_COLON_COLON,
    STATE(5954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9132), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [237345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9134), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237404] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8568), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8570), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237521] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237579] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8082), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [237637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237811] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7557), 1,
      sym__lowercase_identifier,
    ACTIONS(7565), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_LBRACE,
    ACTIONS(7575), 1,
      anon_sym_POUND,
    ACTIONS(7577), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7579), 1,
      anon_sym_begin,
    ACTIONS(7587), 1,
      aux_sym_number_token1,
    ACTIONS(7589), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7591), 1,
      anon_sym_SQUOTE,
    ACTIONS(7593), 1,
      anon_sym_DQUOTE,
    ACTIONS(7595), 1,
      sym__uppercase_identifier,
    ACTIONS(7597), 1,
      aux_sym_tag_token1,
    ACTIONS(9250), 1,
      anon_sym_LPAREN,
    ACTIONS(9252), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9254), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5963), 1,
      sym_attribute,
    STATE(9108), 1,
      sym__simple_pattern,
    STATE(9114), 1,
      sym__constructor_name,
    STATE(20059), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7567), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9176), 2,
      sym__constant,
      sym_signed_number,
    STATE(9113), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9109), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [237909] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(5964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [237969] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238027] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238201] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238317] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238433] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7109), 1,
      sym__lowercase_identifier,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7117), 1,
      anon_sym_LBRACE,
    ACTIONS(7119), 1,
      anon_sym_POUND,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7125), 1,
      anon_sym_begin,
    ACTIONS(7127), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7129), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(7139), 1,
      sym__uppercase_identifier,
    ACTIONS(7141), 1,
      aux_sym_tag_token1,
    ACTIONS(7268), 1,
      anon_sym_LPAREN,
    STATE(5973), 1,
      sym_attribute,
    STATE(9064), 1,
      sym__constructor_name,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9231), 1,
      sym_record_binding_pattern,
    STATE(9232), 1,
      sym__simple_binding_pattern,
    STATE(9234), 1,
      sym_list_binding_pattern,
    STATE(9239), 1,
      sym_array_binding_pattern,
    STATE(19117), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7115), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(9226), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [238539] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238713] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238829] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6883), 1,
      sym__lowercase_identifier,
    ACTIONS(6895), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_LBRACE,
    ACTIONS(6903), 1,
      anon_sym_POUND,
    ACTIONS(6905), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6907), 1,
      anon_sym_begin,
    ACTIONS(6913), 1,
      aux_sym_number_token1,
    ACTIONS(6915), 1,
      aux_sym_signed_number_token1,
    ACTIONS(6917), 1,
      anon_sym_SQUOTE,
    ACTIONS(6919), 1,
      anon_sym_DQUOTE,
    ACTIONS(6921), 1,
      sym__uppercase_identifier,
    ACTIONS(6923), 1,
      aux_sym_tag_token1,
    ACTIONS(9256), 1,
      anon_sym_LPAREN,
    ACTIONS(9258), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9260), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5979), 1,
      sym_attribute,
    STATE(7846), 1,
      sym__constructor_name,
    STATE(7895), 1,
      sym__simple_pattern,
    STATE(19511), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6897), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7738), 2,
      sym__constant,
      sym_signed_number,
    STATE(7889), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7870), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [238927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [238985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239043] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239159] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239333] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239391] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239449] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5259), 1,
      anon_sym_DOT,
    ACTIONS(5261), 1,
      anon_sym_POUND,
    ACTIONS(5263), 1,
      sym_hash_operator,
    STATE(5989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239513] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(8570), 22,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      anon_sym_GT_RBRACE,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [239571] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239687] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4665), 1,
      sym__lowercase_identifier,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4679), 1,
      anon_sym_LBRACE,
    ACTIONS(4681), 1,
      anon_sym_POUND,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4687), 1,
      anon_sym_begin,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(4701), 1,
      sym__uppercase_identifier,
    ACTIONS(4703), 1,
      aux_sym_tag_token1,
    ACTIONS(4809), 1,
      anon_sym_LPAREN,
    ACTIONS(7521), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7523), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5565), 1,
      sym__constructor_name,
    STATE(5585), 1,
      sym_list_binding_pattern,
    STATE(5586), 1,
      sym_array_binding_pattern,
    STATE(5643), 1,
      sym__simple_binding_pattern,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5741), 1,
      sym_record_binding_pattern,
    STATE(5993), 1,
      sym_attribute,
    STATE(20857), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4677), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5736), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [239793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [239967] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240025] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(5999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240141] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240315] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7143), 1,
      sym__lowercase_identifier,
    ACTIONS(7151), 1,
      anon_sym_LBRACK,
    ACTIONS(7157), 1,
      anon_sym_LBRACE,
    ACTIONS(7159), 1,
      anon_sym_POUND,
    ACTIONS(7161), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7163), 1,
      anon_sym_begin,
    ACTIONS(7169), 1,
      aux_sym_number_token1,
    ACTIONS(7171), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7173), 1,
      anon_sym_SQUOTE,
    ACTIONS(7175), 1,
      anon_sym_DQUOTE,
    ACTIONS(7177), 1,
      sym__uppercase_identifier,
    ACTIONS(7179), 1,
      aux_sym_tag_token1,
    ACTIONS(9262), 1,
      anon_sym_LPAREN,
    ACTIONS(9264), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9266), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(6003), 1,
      sym_attribute,
    STATE(8293), 1,
      sym__simple_pattern,
    STATE(8349), 1,
      sym__constructor_name,
    STATE(19889), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7153), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8242), 2,
      sym__constant,
      sym_signed_number,
    STATE(8386), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8308), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [240413] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4775), 1,
      sym__lowercase_identifier,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4783), 1,
      anon_sym_LBRACE,
    ACTIONS(4785), 1,
      anon_sym_POUND,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4791), 1,
      anon_sym_begin,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(4805), 1,
      sym__uppercase_identifier,
    ACTIONS(4807), 1,
      aux_sym_tag_token1,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7426), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5573), 1,
      sym__constructor_name,
    STATE(5618), 1,
      sym_array_binding_pattern,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(5666), 1,
      sym_record_binding_pattern,
    STATE(5674), 1,
      sym_list_binding_pattern,
    STATE(5720), 1,
      sym__simple_binding_pattern,
    STATE(6004), 1,
      sym_attribute,
    STATE(20427), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4781), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5646), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [240519] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240577] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240635] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5019), 1,
      sym__lowercase_identifier,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5027), 1,
      anon_sym_LBRACE,
    ACTIONS(5029), 1,
      anon_sym_POUND,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5035), 1,
      anon_sym_begin,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(5049), 1,
      sym__uppercase_identifier,
    ACTIONS(5051), 1,
      aux_sym_tag_token1,
    ACTIONS(5057), 1,
      anon_sym_LPAREN,
    ACTIONS(8274), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8276), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5657), 1,
      sym__constructor_name,
    STATE(5760), 1,
      sym_record_binding_pattern,
    STATE(5763), 1,
      sym_list_binding_pattern,
    STATE(5792), 1,
      sym_array_binding_pattern,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(5911), 1,
      sym__simple_binding_pattern,
    STATE(6007), 1,
      sym_attribute,
    STATE(19526), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5025), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5931), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [240741] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9268), 1,
      anon_sym_LPAREN,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    STATE(6008), 1,
      sym_attribute,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14207), 1,
      sym__simple_binding_pattern,
    STATE(20357), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14134), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [240847] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [240963] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241021] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241079] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(9274), 1,
      anon_sym_LPAREN,
    STATE(6013), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(13895), 1,
      sym__simple_pattern,
    STATE(20354), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [241177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241235] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241351] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241583] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7053), 1,
      sym__lowercase_identifier,
    ACTIONS(7061), 1,
      anon_sym_LBRACK,
    ACTIONS(7067), 1,
      anon_sym_LBRACE,
    ACTIONS(7069), 1,
      anon_sym_POUND,
    ACTIONS(7071), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7073), 1,
      anon_sym_begin,
    ACTIONS(7079), 1,
      aux_sym_number_token1,
    ACTIONS(7081), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7083), 1,
      anon_sym_SQUOTE,
    ACTIONS(7085), 1,
      anon_sym_DQUOTE,
    ACTIONS(7087), 1,
      sym__uppercase_identifier,
    ACTIONS(7089), 1,
      aux_sym_tag_token1,
    ACTIONS(9276), 1,
      anon_sym_LPAREN,
    ACTIONS(9278), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9280), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(6021), 1,
      sym_attribute,
    STATE(8030), 1,
      sym__simple_pattern,
    STATE(8074), 1,
      sym__constructor_name,
    STATE(18520), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7063), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8163), 2,
      sym__constant,
      sym_signed_number,
    STATE(8116), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(8020), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [241681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [241855] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5395), 1,
      sym__lowercase_identifier,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5419), 1,
      anon_sym_LBRACE,
    ACTIONS(5423), 1,
      anon_sym_POUND,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5429), 1,
      anon_sym_begin,
    ACTIONS(5437), 1,
      aux_sym_number_token1,
    ACTIONS(5439), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5441), 1,
      anon_sym_SQUOTE,
    ACTIONS(5443), 1,
      anon_sym_DQUOTE,
    ACTIONS(5445), 1,
      sym__uppercase_identifier,
    ACTIONS(5447), 1,
      aux_sym_tag_token1,
    ACTIONS(7695), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7697), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9282), 1,
      anon_sym_LPAREN,
    STATE(6025), 1,
      sym_attribute,
    STATE(8963), 1,
      sym__constructor_name,
    STATE(10615), 1,
      sym__simple_pattern,
    STATE(19549), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5415), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10744), 2,
      sym__constant,
      sym_signed_number,
    STATE(10787), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(10736), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [241953] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(8382), 1,
      sym__lowercase_identifier,
    ACTIONS(9268), 1,
      anon_sym_LPAREN,
    STATE(6026), 1,
      sym_attribute,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14207), 1,
      sym__simple_binding_pattern,
    STATE(20061), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14134), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [242059] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(7701), 1,
      sym__lowercase_identifier,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(9284), 1,
      anon_sym_LPAREN,
    ACTIONS(9286), 1,
      sym__uppercase_identifier,
    ACTIONS(9288), 1,
      aux_sym_tag_token1,
    STATE(6027), 1,
      sym_attribute,
    STATE(14749), 1,
      sym_record_binding_pattern,
    STATE(14754), 1,
      sym__constructor_name,
    STATE(14783), 1,
      sym__simple_binding_pattern,
    STATE(14839), 1,
      sym_list_binding_pattern,
    STATE(14885), 1,
      sym_array_binding_pattern,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(21140), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14943), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [242165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242223] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242281] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(9286), 1,
      sym__uppercase_identifier,
    ACTIONS(9288), 1,
      aux_sym_tag_token1,
    ACTIONS(9290), 1,
      anon_sym_LPAREN,
    STATE(6030), 1,
      sym_attribute,
    STATE(14754), 1,
      sym__constructor_name,
    STATE(14820), 1,
      sym__simple_pattern,
    STATE(18434), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14731), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242379] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242553] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9292), 1,
      anon_sym_LPAREN,
    ACTIONS(9294), 1,
      sym__uppercase_identifier,
    STATE(6034), 1,
      sym_attribute,
    STATE(13895), 1,
      sym__simple_pattern,
    STATE(14103), 1,
      sym__constructor_name,
    STATE(21134), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242651] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9274), 1,
      anon_sym_LPAREN,
    STATE(6035), 1,
      sym_attribute,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(13896), 1,
      sym__simple_pattern,
    STATE(20783), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [242749] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242865] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [242923] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4965), 1,
      sym__lowercase_identifier,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_LBRACE,
    ACTIONS(4975), 1,
      anon_sym_POUND,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4981), 1,
      anon_sym_begin,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(4995), 1,
      sym__uppercase_identifier,
    ACTIONS(4997), 1,
      aux_sym_tag_token1,
    ACTIONS(5189), 1,
      anon_sym_LPAREN,
    ACTIONS(8348), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8350), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(5716), 1,
      sym__constructor_name,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5848), 1,
      sym_record_binding_pattern,
    STATE(5849), 1,
      sym_list_binding_pattern,
    STATE(5853), 1,
      sym_array_binding_pattern,
    STATE(5909), 1,
      sym__simple_binding_pattern,
    STATE(6039), 1,
      sym_attribute,
    STATE(19898), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4971), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(5803), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [243029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243087] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9296), 1,
      anon_sym_LT_DASH,
    STATE(6041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [243147] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243205] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243263] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243321] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6839), 1,
      sym__lowercase_identifier,
    ACTIONS(6851), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_LBRACE,
    ACTIONS(6859), 1,
      anon_sym_POUND,
    ACTIONS(6861), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6863), 1,
      anon_sym_begin,
    ACTIONS(6871), 1,
      aux_sym_number_token1,
    ACTIONS(6873), 1,
      aux_sym_signed_number_token1,
    ACTIONS(6875), 1,
      anon_sym_SQUOTE,
    ACTIONS(6877), 1,
      anon_sym_DQUOTE,
    ACTIONS(6879), 1,
      sym__uppercase_identifier,
    ACTIONS(6881), 1,
      aux_sym_tag_token1,
    ACTIONS(9298), 1,
      anon_sym_LPAREN,
    ACTIONS(9300), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9302), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(6045), 1,
      sym_attribute,
    STATE(7737), 1,
      sym__simple_pattern,
    STATE(7979), 1,
      sym__constructor_name,
    STATE(19112), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6853), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(7786), 2,
      sym__constant,
      sym_signed_number,
    STATE(7761), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(7970), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [243419] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 24,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243477] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243535] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5259), 1,
      anon_sym_DOT,
    STATE(6048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243595] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243713] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5259), 1,
      anon_sym_DOT,
    ACTIONS(5261), 1,
      anon_sym_POUND,
    ACTIONS(5263), 1,
      sym_hash_operator,
    STATE(6051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243777] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [243953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244069] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244243] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(6795), 1,
      anon_sym_POUND,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9274), 1,
      anon_sym_LPAREN,
    STATE(6060), 1,
      sym_attribute,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(13895), 1,
      sym__simple_pattern,
    STATE(20783), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [244341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244457] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7270), 1,
      sym__lowercase_identifier,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7278), 1,
      anon_sym_LBRACE,
    ACTIONS(7282), 1,
      anon_sym_POUND,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7288), 1,
      anon_sym_begin,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(9286), 1,
      sym__uppercase_identifier,
    ACTIONS(9288), 1,
      aux_sym_tag_token1,
    ACTIONS(9290), 1,
      anon_sym_LPAREN,
    STATE(6063), 1,
      sym_attribute,
    STATE(14754), 1,
      sym__constructor_name,
    STATE(14821), 1,
      sym__simple_pattern,
    STATE(18434), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7276), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14731), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [244555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244613] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244671] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4811), 1,
      sym__lowercase_identifier,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4827), 1,
      anon_sym_LBRACE,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9292), 1,
      anon_sym_LPAREN,
    ACTIONS(9294), 1,
      sym__uppercase_identifier,
    STATE(6066), 1,
      sym_attribute,
    STATE(13896), 1,
      sym__simple_pattern,
    STATE(14103), 1,
      sym__constructor_name,
    STATE(21134), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(13858), 15,
      sym_typed_pattern,
      sym_polymorphic_variant_pattern,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
      sym_local_open_pattern,
      sym_package_pattern,
      sym_parenthesized_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
      sym_constructor_path,
      sym_tag,
  [244769] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9304), 1,
      anon_sym_LT_DASH,
    STATE(6067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 21,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [244945] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4841), 1,
      anon_sym_begin,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5461), 1,
      anon_sym_LBRACE,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7189), 1,
      anon_sym_POUND,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7551), 1,
      sym__lowercase_identifier,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9294), 1,
      sym__uppercase_identifier,
    ACTIONS(9306), 1,
      anon_sym_LPAREN,
    STATE(6070), 1,
      sym_attribute,
    STATE(14065), 1,
      sym_record_binding_pattern,
    STATE(14097), 1,
      sym_list_binding_pattern,
    STATE(14103), 1,
      sym__constructor_name,
    STATE(14126), 1,
      sym_array_binding_pattern,
    STATE(14207), 1,
      sym__simple_binding_pattern,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(20801), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4823), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    STATE(14134), 11,
      sym_typed_binding_pattern,
      sym_polymorphic_variant_pattern,
      sym_local_open_binding_pattern,
      sym_package_pattern,
      sym_parenthesized_binding_pattern,
      sym_extension,
      sym_quoted_extension,
      sym__signed_constant,
      sym__value_name,
      sym_constructor_path,
      sym_tag,
  [245051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245108] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245222] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245281] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245452] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245509] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245737] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [245853] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245910] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [245967] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246024] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246081] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246138] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246195] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246252] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246309] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246366] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246423] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246480] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246537] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246594] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246651] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [246708] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246765] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246879] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [246993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247050] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247164] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247223] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247508] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247738] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [247795] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247852] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [247966] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248023] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248080] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248137] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248194] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248251] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248310] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248367] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248424] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248481] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248538] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248595] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248711] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248768] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248825] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [248882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [248996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249053] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [249281] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249395] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249452] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249509] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9308), 1,
      sym__lowercase_identifier,
    ACTIONS(9310), 1,
      anon_sym_LPAREN,
    ACTIONS(9312), 1,
      anon_sym_private,
    ACTIONS(9314), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(9318), 1,
      anon_sym_LBRACK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    STATE(6149), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9320), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10985), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [249618] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9308), 1,
      sym__lowercase_identifier,
    ACTIONS(9310), 1,
      anon_sym_LPAREN,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(9318), 1,
      anon_sym_LBRACK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9340), 1,
      anon_sym_private,
    ACTIONS(9342), 1,
      anon_sym_DOT_DOT,
    STATE(6150), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9320), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10996), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [249727] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9344), 1,
      sym__lowercase_identifier,
    ACTIONS(9346), 1,
      anon_sym_LPAREN,
    ACTIONS(9348), 1,
      anon_sym_private,
    ACTIONS(9350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(9354), 1,
      anon_sym_LBRACK,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    STATE(6151), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9356), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11033), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [249836] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249895] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9372), 1,
      anon_sym_LT_DASH,
    STATE(6153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [249954] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9344), 1,
      sym__lowercase_identifier,
    ACTIONS(9346), 1,
      anon_sym_LPAREN,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(9354), 1,
      anon_sym_LBRACK,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9374), 1,
      anon_sym_private,
    ACTIONS(9376), 1,
      anon_sym_DOT_DOT,
    STATE(6154), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9356), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11042), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [250063] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9378), 1,
      sym__lowercase_identifier,
    ACTIONS(9380), 1,
      anon_sym_LPAREN,
    ACTIONS(9382), 1,
      anon_sym_private,
    ACTIONS(9384), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(9388), 1,
      anon_sym_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    STATE(6155), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9390), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11421), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [250172] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      sym__lowercase_identifier,
    ACTIONS(9408), 1,
      anon_sym_LPAREN,
    ACTIONS(9410), 1,
      anon_sym_private,
    ACTIONS(9412), 1,
      anon_sym_DOT_DOT,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(9416), 1,
      anon_sym_LBRACK,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    STATE(6156), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9418), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11694), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [250281] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      sym__lowercase_identifier,
    ACTIONS(9408), 1,
      anon_sym_LPAREN,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(9416), 1,
      anon_sym_LBRACK,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9434), 1,
      anon_sym_private,
    ACTIONS(9436), 1,
      anon_sym_DOT_DOT,
    STATE(6157), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9418), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11748), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [250390] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9438), 1,
      anon_sym_DOT,
    ACTIONS(9440), 1,
      anon_sym_POUND,
    ACTIONS(9442), 1,
      sym_hash_operator,
    STATE(6158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250453] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9438), 1,
      anon_sym_DOT,
    ACTIONS(9440), 1,
      anon_sym_POUND,
    ACTIONS(9442), 1,
      sym_hash_operator,
    STATE(6159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [250516] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250573] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250630] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250744] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250801] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250858] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250915] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [250974] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251031] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251088] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251147] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9444), 1,
      anon_sym_DOT,
    ACTIONS(9446), 1,
      anon_sym_POUND,
    ACTIONS(9448), 1,
      sym_hash_operator,
    STATE(6171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251210] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9444), 1,
      anon_sym_DOT,
    ACTIONS(9446), 1,
      anon_sym_POUND,
    ACTIONS(9448), 1,
      sym_hash_operator,
    STATE(6172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251330] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251389] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [251448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251505] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251676] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251847] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [251961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252075] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252189] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252246] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9438), 1,
      anon_sym_DOT,
    STATE(6190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252419] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252533] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252647] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252818] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252875] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [252989] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253046] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253103] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253160] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253616] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253673] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253844] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253901] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [253958] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254015] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254072] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254186] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254243] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254300] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254357] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254471] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254585] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254642] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254699] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254813] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254870] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [254927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [254984] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255098] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255155] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255212] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255269] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255383] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255497] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255554] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255611] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [255839] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255896] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [255953] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256010] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9450), 1,
      anon_sym_LT_DASH,
    STATE(6256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256069] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9452), 1,
      anon_sym_LT_DASH,
    STATE(6257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256128] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9454), 1,
      anon_sym_LT_DASH,
    STATE(6258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256187] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9456), 1,
      anon_sym_LT_DASH,
    STATE(6259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256246] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [256474] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256533] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9458), 1,
      anon_sym_LT_DASH,
    STATE(6265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256592] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256649] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256706] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256763] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256820] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256877] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256934] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [256991] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257048] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257105] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257162] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257219] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257333] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257447] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257618] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [257675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [257960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258074] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258131] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9444), 1,
      anon_sym_DOT,
    STATE(6293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258361] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258475] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258589] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258703] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [258760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258931] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [258988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259045] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259159] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259330] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259387] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259615] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259672] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259786] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [259957] = 31,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9378), 1,
      sym__lowercase_identifier,
    ACTIONS(9380), 1,
      anon_sym_LPAREN,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(9388), 1,
      anon_sym_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9460), 1,
      anon_sym_private,
    ACTIONS(9462), 1,
      anon_sym_DOT_DOT,
    STATE(6325), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9390), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11431), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [260066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260237] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260351] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260465] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260636] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260750] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260864] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [260921] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9464), 1,
      anon_sym_LT_DASH,
    STATE(6341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [260980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 25,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261094] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261151] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261208] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261265] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261379] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261436] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261493] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261607] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [261721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261778] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261835] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261892] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [261949] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262063] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5269), 1,
      anon_sym_DOT,
    ACTIONS(5271), 1,
      anon_sym_POUND,
    ACTIONS(5273), 1,
      sym_hash_operator,
    STATE(6361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262126] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262183] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262354] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262411] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262468] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262525] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5269), 1,
      anon_sym_DOT,
    STATE(6369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262584] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262641] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262698] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262755] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262812] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262869] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262926] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [262983] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263040] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263097] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263154] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263211] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263268] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263325] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263382] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263439] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263496] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263553] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5269), 1,
      anon_sym_DOT,
    ACTIONS(5271), 1,
      anon_sym_POUND,
    ACTIONS(5273), 1,
      sym_hash_operator,
    STATE(6387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263616] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263673] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263730] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263787] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263844] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263901] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [263958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264015] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264072] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9466), 1,
      anon_sym_COLON,
    STATE(6396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264131] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 23,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 24,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [264245] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264301] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264359] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264471] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264527] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264583] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9468), 1,
      anon_sym_DOT,
    ACTIONS(9470), 1,
      anon_sym_POUND,
    ACTIONS(9472), 1,
      sym_hash_operator,
    STATE(6405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [264645] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264701] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264757] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264813] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264869] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264925] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [264981] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265037] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265093] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265149] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265205] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265261] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265317] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265373] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265429] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265485] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265597] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [265709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265765] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9378), 1,
      sym__lowercase_identifier,
    ACTIONS(9380), 1,
      anon_sym_LPAREN,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(9388), 1,
      anon_sym_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9474), 1,
      anon_sym_DOT_DOT,
    STATE(6426), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9390), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11420), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [265871] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265927] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [265983] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266041] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266097] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266153] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266209] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266265] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266321] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266377] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266435] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266491] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266547] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266659] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266715] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [266827] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266883] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [266939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [266995] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [267107] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267163] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267219] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267275] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267331] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267387] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267443] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267499] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267555] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267611] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [267667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [267723] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [267779] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267835] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267891] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [267947] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268003] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268115] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268171] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268283] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268339] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268395] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268451] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268507] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268563] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [268619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268731] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268899] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [268955] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269011] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [269067] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9308), 1,
      sym__lowercase_identifier,
    ACTIONS(9310), 1,
      anon_sym_LPAREN,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(9318), 1,
      anon_sym_LBRACK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9476), 1,
      anon_sym_DOT_DOT,
    STATE(6484), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9320), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(10991), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [269173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269229] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269397] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269565] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269621] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9468), 1,
      anon_sym_DOT,
    STATE(6493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269679] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9308), 1,
      sym__lowercase_identifier,
    ACTIONS(9310), 1,
      anon_sym_LPAREN,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(9318), 1,
      anon_sym_LBRACK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9478), 1,
      anon_sym_DOT_DOT,
    STATE(6494), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9320), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11004), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [269785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269897] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [269953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270457] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270569] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270625] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [270961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271129] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271241] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271353] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271411] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9480), 1,
      anon_sym_LT_DASH,
    STATE(6524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [271581] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9378), 1,
      sym__lowercase_identifier,
    ACTIONS(9380), 1,
      anon_sym_LPAREN,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(9388), 1,
      anon_sym_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9482), 1,
      anon_sym_DOT_DOT,
    STATE(6527), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9390), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11345), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [271687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271799] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9344), 1,
      sym__lowercase_identifier,
    ACTIONS(9346), 1,
      anon_sym_LPAREN,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(9354), 1,
      anon_sym_LBRACK,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9484), 1,
      anon_sym_DOT_DOT,
    STATE(6530), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9356), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11037), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [271905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [271961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272017] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9344), 1,
      sym__lowercase_identifier,
    ACTIONS(9346), 1,
      anon_sym_LPAREN,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(9354), 1,
      anon_sym_LBRACK,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9486), 1,
      anon_sym_DOT_DOT,
    STATE(6533), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9356), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11051), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [272123] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [272179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [272235] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      sym__lowercase_identifier,
    ACTIONS(9408), 1,
      anon_sym_LPAREN,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(9416), 1,
      anon_sym_LBRACK,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9488), 1,
      anon_sym_DOT_DOT,
    STATE(6536), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9418), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11728), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [272341] = 30,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9336), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      sym__lowercase_identifier,
    ACTIONS(9408), 1,
      anon_sym_LPAREN,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(9416), 1,
      anon_sym_LBRACK,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9490), 1,
      anon_sym_DOT_DOT,
    STATE(6537), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9418), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(11775), 2,
      sym_variant_declaration,
      sym_record_declaration,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [272447] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272503] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [272559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [272615] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272727] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272783] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272839] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272895] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [272951] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273007] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [273063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273119] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273455] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273511] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273567] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273679] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273735] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273791] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273847] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_DOT,
    STATE(6563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [273961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274017] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274073] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274241] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274353] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274409] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274465] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274521] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274577] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274633] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274689] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274745] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274801] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274857] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274915] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [274971] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275027] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275083] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275139] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275195] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275251] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275307] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275363] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275419] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_DOT,
    ACTIONS(5281), 1,
      anon_sym_POUND,
    ACTIONS(5283), 1,
      sym_hash_operator,
    STATE(6591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275481] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275537] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [275593] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275649] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275705] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5279), 1,
      anon_sym_DOT,
    ACTIONS(5281), 1,
      anon_sym_POUND,
    ACTIONS(5283), 1,
      sym_hash_operator,
    STATE(6596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275767] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275823] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9492), 1,
      anon_sym_LT_DASH,
    STATE(6598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275881] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [275937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [275993] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276049] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [276105] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [276161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276217] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [276273] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276329] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276387] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276443] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276499] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276555] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276611] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276667] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276723] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276779] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9494), 1,
      anon_sym_LT_DASH,
    STATE(6615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276837] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276893] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [276949] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9496), 1,
      anon_sym_LT_DASH,
    STATE(6618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277007] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277119] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277175] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9498), 1,
      anon_sym_LT_DASH,
    STATE(6622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277401] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277457] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [277513] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277681] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277739] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9500), 1,
      anon_sym_COLON,
    STATE(6632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277797] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277853] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [277965] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278021] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278077] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278133] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [278191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [278247] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278303] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278359] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278471] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278527] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [278583] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278641] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278697] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278753] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278865] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278921] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [278977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279033] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5359), 1,
      anon_sym_DOT,
    STATE(6655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279091] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [279149] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [279261] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279317] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279373] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279429] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279485] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279597] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279653] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279765] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279821] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279877] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279933] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [279989] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280101] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280157] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280213] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280269] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280325] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280437] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280493] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280549] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280605] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280661] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280717] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [280773] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [280885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [280941] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [280997] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [281053] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281109] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281165] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281221] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281277] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281333] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281389] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281445] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [281557] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281613] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281669] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281725] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [281781] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281837] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281893] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5369), 1,
      anon_sym_DOT,
    STATE(6706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [281951] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282007] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282119] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282455] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282511] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282681] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282737] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282793] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282849] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [282961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283017] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283073] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283241] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283353] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283409] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283465] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283521] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283577] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283633] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283689] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283745] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283801] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283857] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [283913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [283969] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284025] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5359), 1,
      anon_sym_DOT,
    ACTIONS(5361), 1,
      anon_sym_POUND,
    ACTIONS(5363), 1,
      sym_hash_operator,
    STATE(6744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284087] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284143] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284199] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284255] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284311] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284367] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284423] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284479] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284535] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5389), 1,
      anon_sym_DOT,
    STATE(6753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284593] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284649] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284761] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284817] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284873] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284929] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9502), 1,
      anon_sym_LT_DASH,
    STATE(6760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [284987] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9504), 1,
      anon_sym_LT_DASH,
    STATE(6761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285045] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9506), 1,
      anon_sym_LT_DASH,
    STATE(6762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285103] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9508), 1,
      anon_sym_LT_DASH,
    STATE(6763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285217] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285273] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285329] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285385] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285497] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285553] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285665] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285777] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285833] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285889] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [285945] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286001] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5359), 1,
      anon_sym_DOT,
    ACTIONS(5361), 1,
      anon_sym_POUND,
    ACTIONS(5363), 1,
      sym_hash_operator,
    STATE(6779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286119] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286455] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286511] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286681] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286737] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286793] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286849] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [286961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287017] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287073] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287185] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5369), 1,
      anon_sym_DOT,
    ACTIONS(5371), 1,
      anon_sym_POUND,
    ACTIONS(5373), 1,
      sym_hash_operator,
    STATE(6800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(6801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [287303] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287359] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287471] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287527] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287583] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287639] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287695] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287751] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5349), 1,
      anon_sym_DOT,
    STATE(6810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287865] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287921] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [287977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288033] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288089] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288145] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288201] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288257] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288313] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288369] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288425] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288481] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288537] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288593] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288649] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288761] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288817] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288873] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288929] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [288985] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5369), 1,
      anon_sym_DOT,
    ACTIONS(5371), 1,
      anon_sym_POUND,
    ACTIONS(5373), 1,
      sym_hash_operator,
    STATE(6832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289047] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289103] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289159] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289215] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289271] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289327] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289383] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289439] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289495] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289551] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289607] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289663] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289719] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289775] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289831] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289887] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289943] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [289999] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290055] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5389), 1,
      anon_sym_DOT,
    ACTIONS(5391), 1,
      anon_sym_POUND,
    ACTIONS(5393), 1,
      sym_hash_operator,
    STATE(6851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290117] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290173] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290229] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290285] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290341] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290397] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290453] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290509] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5389), 1,
      anon_sym_DOT,
    ACTIONS(5391), 1,
      anon_sym_POUND,
    ACTIONS(5393), 1,
      sym_hash_operator,
    STATE(6859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290571] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290627] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290683] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290795] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290851] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290907] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [290963] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291019] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291075] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291131] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291187] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291243] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291299] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291355] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5349), 1,
      anon_sym_DOT,
    ACTIONS(5351), 1,
      anon_sym_POUND,
    ACTIONS(5353), 1,
      sym_hash_operator,
    STATE(6874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291417] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291473] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291529] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291585] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291641] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291699] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291755] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291811] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291867] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291923] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [291979] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292035] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292091] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292147] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5349), 1,
      anon_sym_DOT,
    ACTIONS(5351), 1,
      anon_sym_POUND,
    ACTIONS(5353), 1,
      sym_hash_operator,
    STATE(6888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292209] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292265] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292321] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292377] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292489] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292545] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292601] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292657] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292713] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292769] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292825] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292881] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292937] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [292993] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293105] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293217] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293273] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293329] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293385] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293497] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293553] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293665] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293777] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293833] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293889] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [293945] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294001] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294057] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294113] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294169] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294225] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294281] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(6926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294339] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294395] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294451] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294507] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294563] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294619] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294675] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294733] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294845] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294901] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(6937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [294959] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(6938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295017] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295073] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295241] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295297] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9468), 1,
      anon_sym_DOT,
    ACTIONS(9470), 1,
      anon_sym_POUND,
    ACTIONS(9472), 1,
      sym_hash_operator,
    STATE(6944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [295359] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295471] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295527] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9510), 1,
      anon_sym_LT_DASH,
    STATE(6948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
    ACTIONS(7921), 20,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [295585] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295641] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295697] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295753] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295865] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295921] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [295977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296033] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5379), 1,
      anon_sym_DOT,
    ACTIONS(5381), 1,
      anon_sym_POUND,
    ACTIONS(5383), 1,
      sym_hash_operator,
    STATE(6957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296095] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296151] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296207] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296263] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296319] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296375] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296431] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296487] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296543] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5379), 1,
      anon_sym_DOT,
    STATE(6966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296601] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296657] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296713] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296769] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296825] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296881] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296937] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [296993] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297105] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297217] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297273] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297329] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297385] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297497] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297553] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5379), 1,
      anon_sym_DOT,
    ACTIONS(5381), 1,
      anon_sym_POUND,
    ACTIONS(5383), 1,
      sym_hash_operator,
    STATE(6984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297615] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297727] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297783] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297839] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297895] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [297951] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298007] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298119] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298455] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298513] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298681] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298737] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298793] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298849] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [298961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299017] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299073] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299241] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_LT_DASH,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299353] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299465] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299521] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299577] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299633] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7917), 1,
      anon_sym_LT_DASH,
    STATE(7021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299691] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299747] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [299859] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299914] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [299969] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300026] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300081] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300136] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300191] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300246] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300301] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300356] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300411] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300466] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300521] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300576] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300633] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300688] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300798] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300853] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300908] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [300963] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301018] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301073] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301130] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301185] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301295] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301350] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9512), 1,
      anon_sym_COLON,
    STATE(7052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [301407] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301462] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301517] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301572] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301627] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301682] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301737] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301792] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301847] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301902] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [301957] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302012] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302067] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302122] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302177] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302232] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302342] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5477), 1,
      anon_sym_DOT,
    STATE(7070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302454] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302509] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302564] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302619] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302729] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302784] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302839] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302894] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [302949] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303004] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303114] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303169] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303224] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303279] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303334] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303389] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303444] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303499] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303554] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [303719] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5477), 1,
      anon_sym_DOT,
    ACTIONS(5479), 1,
      anon_sym_POUND,
    ACTIONS(5481), 1,
      sym_hash_operator,
    STATE(7095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303780] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303835] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303890] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [303945] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304000] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304110] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [304220] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304275] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5477), 1,
      anon_sym_DOT,
    ACTIONS(5479), 1,
      anon_sym_POUND,
    ACTIONS(5481), 1,
      sym_hash_operator,
    STATE(7105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304336] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304391] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304446] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304501] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304556] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304611] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304666] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304776] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304831] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304886] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304941] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [304996] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305051] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305216] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305271] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305326] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305436] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305491] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305546] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305713] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [305768] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305935] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [305990] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5597), 1,
      anon_sym_DOT,
    STATE(7136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306047] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9514), 1,
      anon_sym_LT_DASH,
    STATE(7137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306104] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306159] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306269] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306324] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306491] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5577), 1,
      anon_sym_DOT,
    ACTIONS(5579), 1,
      anon_sym_POUND,
    ACTIONS(5581), 1,
      sym_hash_operator,
    STATE(7145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306552] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9516), 1,
      anon_sym_COLON,
    STATE(7146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8446), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306664] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8302), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [306721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306776] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306831] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [306886] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9518), 1,
      anon_sym_DOT,
    ACTIONS(9520), 1,
      anon_sym_POUND,
    ACTIONS(9522), 1,
      sym_hash_operator,
    STATE(7152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [306947] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5577), 1,
      anon_sym_DOT,
    ACTIONS(5579), 1,
      anon_sym_POUND,
    ACTIONS(5581), 1,
      sym_hash_operator,
    STATE(7153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307008] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9518), 1,
      anon_sym_DOT,
    ACTIONS(9520), 1,
      anon_sym_POUND,
    ACTIONS(9522), 1,
      sym_hash_operator,
    STATE(7154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307069] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307124] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8364), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [307179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307344] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307454] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307509] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307564] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [307674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307729] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307784] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307839] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307894] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [307949] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308004] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308279] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308334] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_in,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308389] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308499] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308609] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [308664] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308719] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308774] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308829] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308884] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9524), 1,
      anon_sym_LT_DASH,
    STATE(7188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308941] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [308996] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309051] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309216] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309271] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309326] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309436] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309491] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309546] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309601] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309656] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309711] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [309766] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309821] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309876] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309931] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [309986] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310041] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310096] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310151] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310206] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310261] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310316] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310371] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310426] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5629), 1,
      anon_sym_DOT,
    ACTIONS(5631), 1,
      anon_sym_POUND,
    ACTIONS(5633), 1,
      sym_hash_operator,
    STATE(7216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310487] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310544] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310599] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310764] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310819] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7915), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [310874] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310929] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [310984] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311039] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311094] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311149] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311204] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [311314] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311369] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5557), 1,
      anon_sym_DOT,
    ACTIONS(5559), 1,
      anon_sym_POUND,
    ACTIONS(5561), 1,
      sym_hash_operator,
    STATE(7233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311430] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311485] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311540] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8336), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [311650] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311760] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311815] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5557), 1,
      anon_sym_DOT,
    STATE(7241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311872] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311927] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [311982] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312037] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312092] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312147] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8286), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [312257] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312312] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312367] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312477] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312532] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312587] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312642] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312697] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312752] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312807] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312862] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312917] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [312972] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313027] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313082] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [313137] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313192] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313247] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313302] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313357] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313412] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313467] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313522] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313577] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313632] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313742] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313797] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313854] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [313964] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314019] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [314074] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314184] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314239] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314294] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314349] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314404] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314459] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314514] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314624] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5577), 1,
      anon_sym_DOT,
    STATE(7292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314681] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314736] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314791] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314846] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314901] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [314956] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315011] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315066] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315121] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [315231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315286] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315341] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315396] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315451] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315506] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315561] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315616] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315726] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315781] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315836] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315891] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [315946] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316001] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316056] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316111] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316166] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316221] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316276] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316331] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316386] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316496] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316551] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316606] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316661] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316716] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316771] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316826] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [316881] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [316936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [316991] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317046] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317101] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317158] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317213] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317268] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317323] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317378] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317488] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317543] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317598] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317653] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317708] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317763] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317818] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317873] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317928] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [317983] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318038] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318093] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5629), 1,
      anon_sym_DOT,
    ACTIONS(5631), 1,
      anon_sym_POUND,
    ACTIONS(5633), 1,
      sym_hash_operator,
    STATE(7355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318154] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318211] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318266] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318321] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318376] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318431] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318486] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318596] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318651] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318706] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [318761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318871] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [318981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319036] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319091] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319146] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319201] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319366] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319421] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319586] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319641] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319751] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319806] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9518), 1,
      anon_sym_DOT,
    STATE(7386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319863] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [319918] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [319973] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320248] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320303] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320633] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320743] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320853] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [320908] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [320963] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321128] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321238] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321348] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321568] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321678] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321735] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9526), 1,
      anon_sym_LT_DASH,
    STATE(7421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [321847] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321902] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5557), 1,
      anon_sym_DOT,
    ACTIONS(5559), 1,
      anon_sym_POUND,
    ACTIONS(5561), 1,
      sym_hash_operator,
    STATE(7424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [321963] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322018] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322073] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322128] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322183] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322238] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [322348] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322403] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5597), 1,
      anon_sym_DOT,
    ACTIONS(5599), 1,
      anon_sym_POUND,
    ACTIONS(5601), 1,
      sym_hash_operator,
    STATE(7433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322464] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322519] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322574] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322629] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322684] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322794] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322849] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322904] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [322959] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323014] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323069] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323124] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323179] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5629), 1,
      anon_sym_DOT,
    STATE(7447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323236] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323291] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [323401] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323456] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323511] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323566] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323621] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323676] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323731] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323786] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323896] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [323951] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324006] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9528), 1,
      anon_sym_COLON,
    STATE(7462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324118] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324173] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324228] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324283] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324393] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324448] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324503] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324558] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324613] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324668] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324723] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324778] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324833] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324888] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5597), 1,
      anon_sym_DOT,
    ACTIONS(5599), 1,
      anon_sym_POUND,
    ACTIONS(5601), 1,
      sym_hash_operator,
    STATE(7478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [324949] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325004] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325114] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8328), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_tag_token1,
  [325224] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325279] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325334] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325389] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325444] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325499] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325554] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325664] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325719] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325774] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325829] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325886] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325941] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [325996] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326051] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326161] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 24,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [326216] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326271] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326326] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326436] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326491] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326546] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326601] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326656] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326711] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326766] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8302), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [326823] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326878] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9530), 1,
      anon_sym_LT_DASH,
    STATE(7514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326935] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [326990] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 19,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [327100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8110), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [327154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8260), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [327208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7941), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8270), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [327316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8264), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [327370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8268), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [327424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7945), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8190), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8246), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8194), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7915), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8286), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8198), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8202), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327856] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7949), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7953), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [327964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7957), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8210), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8250), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328126] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8214), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328180] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8254), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8248), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [328288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8258), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328342] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8262), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8226), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [328450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8266), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8270), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328558] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9532), 1,
      anon_sym_COLON,
    STATE(7545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [328614] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8154), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8158), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328722] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8162), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328776] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8110), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328830] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8308), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8166), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328938] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8312), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [328992] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8316), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329046] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9536), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9534), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8288), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8320), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8324), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329262] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8328), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329316] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9538), 1,
      anon_sym_COLON,
    STATE(7559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [329372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8234), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329426] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329482] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8336), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329536] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329592] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8364), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8118), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329754] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8292), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8020), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [329862] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8332), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8340), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [329970] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [330026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8282), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8296), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8218), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330188] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9540), 1,
      anon_sym_COLON,
    STATE(7575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [330244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8344), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8070), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330352] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8224), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330406] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8220), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8354), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8224), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [330568] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8358), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330622] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8074), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330676] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9542), 1,
      anon_sym_COLON,
    STATE(7584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [330732] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8302), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [330788] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    STATE(7586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8114), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330844] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8238), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330898] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8122), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [330952] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9550), 1,
      anon_sym_COLON,
    STATE(7589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [331008] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8126), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331062] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9552), 1,
      anon_sym_COLON,
    STATE(7591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [331118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8130), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331172] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8228), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8238), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [331280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7961), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331334] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9556), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9554), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7921), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [331442] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8170), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8214), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [331550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8236), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8232), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7933), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331712] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8054), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [331766] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8236), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8134), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [331928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9560), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9558), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [331982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9564), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9562), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8222), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8058), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8062), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332198] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8066), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8078), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8206), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [332360] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9568), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9566), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332414] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8568), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332468] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9536), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9534), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332522] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9570), 1,
      anon_sym_COLON,
    STATE(7618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 21,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [332578] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [332634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8086), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8090), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8220), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [332796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8094), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8230), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8098), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [332958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8102), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8106), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7933), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8252), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8256), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8118), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8218), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333336] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [333392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8122), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8126), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8232), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8130), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8174), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [333662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8134), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8234), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8138), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [333824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8240), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333878] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8244), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8248), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [333986] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8252), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8142), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8146), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8150), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8256), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8260), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8264), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8268), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8138), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [334472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334526] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8142), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [334580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9556), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9554), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [334634] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9572), 1,
      anon_sym_COLON,
    STATE(7657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [334690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8154), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8158), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8162), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8166), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8170), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [334960] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8174), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335014] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8242), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335068] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8222), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335122] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [335176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8288), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8226), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335284] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8178), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7965), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8182), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8240), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8292), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8020), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8146), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8296), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [335716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8230), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7937), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8150), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [335878] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7941), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7945), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [335986] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8190), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336040] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 22,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [336094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9560), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9558), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [336148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9564), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9562), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [336202] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8178), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8194), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336310] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8198), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8202), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336418] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8246), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336472] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8250), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336526] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8254), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7921), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7949), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336688] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7953), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8054), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7957), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [336850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8058), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8062), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [336958] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8066), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8078), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9568), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(9566), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337120] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9574), 1,
      anon_sym_COLON,
    STATE(7703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8086), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8090), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337284] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8094), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8182), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8242), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8210), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337500] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8258), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8262), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7937), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8098), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8266), 25,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [337770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8102), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8106), 27,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [337878] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8244), 22,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
      aux_sym_tag_token1,
    ACTIONS(8228), 23,
      anon_sym_let,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [337986] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9576), 1,
      anon_sym_COLON,
    STATE(7719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [338041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9556), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9554), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338094] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9580), 1,
      anon_sym_PIPE,
    ACTIONS(9582), 1,
      anon_sym_RBRACK,
    STATE(7721), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16613), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [338195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9560), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9558), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338248] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9584), 1,
      anon_sym_PIPE,
    ACTIONS(9586), 1,
      anon_sym_RBRACK,
    STATE(7723), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18316), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20556), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [338349] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9564), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9562), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [338402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8358), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [338455] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7949), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338508] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9588), 1,
      anon_sym_PIPE,
    ACTIONS(9590), 1,
      anon_sym_RBRACK,
    STATE(7727), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17122), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [338609] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7953), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7957), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9030), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [338768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8210), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [338821] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8074), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [338874] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [338927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8364), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [338980] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9592), 1,
      anon_sym_PIPE,
    ACTIONS(9594), 1,
      anon_sym_RBRACK,
    STATE(7735), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17178), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [339081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9596), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9598), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9602), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339187] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9046), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9044), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [339293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9606), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9604), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339346] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [339399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9608), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9610), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8308), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339505] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [339558] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9612), 1,
      anon_sym_COLON,
    STATE(7745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [339613] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9614), 1,
      anon_sym_PIPE,
    ACTIONS(9616), 1,
      anon_sym_RBRACK,
    STATE(7746), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16577), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [339714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9182), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339767] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8142), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [339820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8206), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [339873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8332), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [339926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9620), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9618), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [339979] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9624), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340032] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9628), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9632), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9630), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [340138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9636), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9640), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340244] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9644), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8340), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340350] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9646), 1,
      anon_sym_PIPE,
    ACTIONS(9648), 1,
      anon_sym_RBRACK,
    STATE(7759), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16476), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [340451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8290), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [340504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8282), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340557] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [340610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8344), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8070), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9652), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340769] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [340822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8146), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [340875] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9536), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9534), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [340928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8354), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [340981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9654), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9656), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341034] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9658), 1,
      anon_sym_PIPE,
    ACTIONS(9660), 1,
      anon_sym_RBRACK,
    STATE(7771), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17109), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [341135] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8358), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8074), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341241] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9662), 1,
      anon_sym_COLON,
    STATE(7774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [341296] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9666), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341349] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8166), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8130), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341455] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8122), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341508] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9668), 1,
      anon_sym_PIPE,
    ACTIONS(9670), 1,
      anon_sym_RBRACK,
    STATE(7779), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16852), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [341609] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9184), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341662] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9674), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341715] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9092), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [341768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8222), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341821] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9676), 1,
      anon_sym_PIPE,
    ACTIONS(9678), 1,
      anon_sym_RBRACK,
    STATE(7784), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17048), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [341922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8190), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [341975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9046), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342028] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8354), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [342081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9060), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9058), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342134] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9028), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9026), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342187] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9604), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9606), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9682), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342293] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9632), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342346] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9096), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8226), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [342452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9686), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342505] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9690), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9694), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342611] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [342664] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8294), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [342717] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9698), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9702), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [342823] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8022), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [342876] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9704), 1,
      anon_sym_PIPE,
    ACTIONS(9706), 1,
      anon_sym_RBRACK,
    STATE(7803), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16331), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [342977] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9708), 1,
      anon_sym_PIPE,
    ACTIONS(9710), 1,
      anon_sym_RBRACK,
    STATE(7804), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16769), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [343078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8194), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [343131] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343184] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7915), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [343237] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8230), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [343290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8298), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [343343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9656), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9654), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9682), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9680), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [343555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8286), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [343608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [343661] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9712), 1,
      anon_sym_PIPE,
    ACTIONS(9714), 1,
      anon_sym_RBRACK,
    STATE(7816), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16122), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [343762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8308), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [343815] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9720), 1,
      anon_sym_DOT,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(9724), 1,
      sym_hash_operator,
    STATE(7818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9716), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [343874] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9726), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9728), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [343927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9730), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9732), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [343980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9736), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [344033] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9740), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [344086] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8312), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7921), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [344192] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8316), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8320), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8324), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [344351] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9742), 1,
      anon_sym_PIPE,
    ACTIONS(9744), 1,
      anon_sym_RBRACK,
    STATE(7828), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16510), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [344452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8290), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [344505] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9746), 1,
      anon_sym_PIPE,
    ACTIONS(9748), 1,
      anon_sym_RBRACK,
    STATE(7830), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17353), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20147), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [344606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8294), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [344659] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9750), 1,
      anon_sym_PIPE,
    ACTIONS(9752), 1,
      anon_sym_RBRACK,
    STATE(7832), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16020), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [344760] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9754), 1,
      anon_sym_PIPE,
    ACTIONS(9756), 1,
      anon_sym_RBRACK,
    STATE(7833), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16859), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [344861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9760), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [344914] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8150), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [344967] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9762), 1,
      anon_sym_PIPE,
    ACTIONS(9764), 1,
      anon_sym_RBRACK,
    STATE(7836), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17170), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [345068] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8126), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8022), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345174] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9224), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [345227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9610), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9608), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [345280] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7965), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345333] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9766), 1,
      anon_sym_PIPE,
    ACTIONS(9768), 1,
      anon_sym_RBRACK,
    STATE(7842), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15998), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [345434] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8154), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345487] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8234), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8238), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345593] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [345646] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [345699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8214), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9770), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9772), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [345805] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8242), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [345858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [345911] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9774), 1,
      anon_sym_PIPE,
    ACTIONS(9776), 1,
      anon_sym_RBRACK,
    STATE(7852), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16139), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [346012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9124), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8206), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346118] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9778), 1,
      anon_sym_COLON,
    STATE(7855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [346173] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9780), 1,
      anon_sym_PIPE,
    ACTIONS(9782), 1,
      anon_sym_RBRACK,
    STATE(7856), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17415), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20382), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [346274] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9784), 1,
      anon_sym_PIPE,
    ACTIONS(9786), 1,
      anon_sym_RBRACK,
    STATE(7857), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16251), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [346375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8198), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8202), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346481] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9792), 1,
      anon_sym_DOT,
    ACTIONS(9794), 1,
      anon_sym_POUND,
    ACTIONS(9796), 1,
      sym_hash_operator,
    STATE(7860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9790), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9788), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [346540] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9620), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346593] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [346699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8316), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [346752] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [346805] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9720), 1,
      anon_sym_DOT,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(9724), 1,
      sym_hash_operator,
    STATE(7866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9800), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9798), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [346864] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9802), 1,
      anon_sym_PIPE,
    ACTIONS(9804), 1,
      anon_sym_RBRACK,
    STATE(7867), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16232), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [346965] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347018] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9806), 1,
      anon_sym_PIPE,
    ACTIONS(9808), 1,
      anon_sym_RBRACK,
    STATE(7869), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16901), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [347119] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(6793), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347172] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9792), 1,
      anon_sym_DOT,
    ACTIONS(9794), 1,
      anon_sym_POUND,
    ACTIONS(9796), 1,
      sym_hash_operator,
    STATE(7871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9812), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9810), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347231] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8178), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347284] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9720), 1,
      anon_sym_DOT,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(9724), 1,
      sym_hash_operator,
    STATE(7873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9816), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9814), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [347343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8298), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347396] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8158), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9674), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9672), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9818), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9820), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [347555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9568), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9566), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [347608] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9792), 1,
      anon_sym_DOT,
    ACTIONS(9794), 1,
      anon_sym_POUND,
    ACTIONS(9796), 1,
      sym_hash_operator,
    STATE(7879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9716), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 22,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [347720] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9820), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9818), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347773] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8246), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [347826] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [347879] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 5,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8294), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [347932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [347985] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8250), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [348091] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [348144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 5,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8022), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [348250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348303] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9720), 1,
      anon_sym_DOT,
    STATE(7892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8114), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [348358] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9822), 1,
      anon_sym_COLON,
    STATE(7893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [348413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9596), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9602), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9600), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348519] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9720), 1,
      anon_sym_DOT,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(9724), 1,
      sym_hash_operator,
    STATE(7896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9812), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9810), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [348578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9622), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9626), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348684] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9634), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9640), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9638), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9642), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [348843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8254), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [348896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8320), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [348949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8182), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349002] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8218), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349055] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [349108] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8332), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349161] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349267] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9824), 1,
      anon_sym_COLON,
    STATE(7910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [349322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8340), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8282), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349428] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8054), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349481] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9826), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9828), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [349534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8344), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7937), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9684), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9688), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8354), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9692), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [349852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8058), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8358), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [349958] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9830), 1,
      anon_sym_PIPE,
    ACTIONS(9832), 1,
      anon_sym_RBRACK,
    STATE(7923), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16553), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [350059] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9202), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8162), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8062), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9696), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350271] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8302), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [350326] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8066), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350379] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9702), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9700), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [350432] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8078), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350485] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9834), 1,
      anon_sym_PIPE,
    ACTIONS(9836), 1,
      anon_sym_RBRACK,
    STATE(7932), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16055), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [350586] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8070), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8308), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7961), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8086), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8090), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8094), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8074), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [350957] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_else,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [351010] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8098), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351063] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9792), 1,
      anon_sym_DOT,
    ACTIONS(9794), 1,
      anon_sym_POUND,
    ACTIONS(9796), 1,
      sym_hash_operator,
    STATE(7942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9816), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9814), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9092), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9090), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [351175] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9096), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9094), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [351228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8102), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351281] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8106), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351334] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9546), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9548), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [351387] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9838), 1,
      anon_sym_COLON,
    STATE(7948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [351442] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7933), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8312), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 5,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8290), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [351601] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7961), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [351654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8110), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351707] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8316), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9222), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [351813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9060), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [351866] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9028), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [351919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8134), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [351972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9652), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9650), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352025] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9792), 1,
      anon_sym_DOT,
    STATE(7960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8114), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352080] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8320), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8324), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352186] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8258), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352239] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8328), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352292] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9124), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9122), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 5,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8298), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [352398] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9050), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [352451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8262), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8266), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(6793), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9728), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9726), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352663] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9732), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9730), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(9204), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [352769] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9734), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [352822] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8170), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [352875] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_else,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [352928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8332), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [352981] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9740), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9738), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [353034] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8336), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353087] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [353140] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(7981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8336), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353248] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8206), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8174), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8340), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [353407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(7965), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [353460] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9666), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9664), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [353513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [353566] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(7989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353621] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9840), 1,
      anon_sym_PIPE,
    ACTIONS(9842), 1,
      anon_sym_RBRACK,
    STATE(7990), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18263), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20516), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [353722] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8324), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [353775] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7941), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8118), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8364), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8138), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [353987] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8282), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [354040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8290), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354093] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9792), 1,
      anon_sym_DOT,
    ACTIONS(9794), 1,
      anon_sym_POUND,
    ACTIONS(9796), 1,
      sym_hash_operator,
    STATE(7998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9800), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9798), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [354152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(7999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8270), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [354205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [354258] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8344), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [354311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9760), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9758), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [354364] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [354417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8298), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [354470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8312), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(8070), 24,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [354576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8328), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [354682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 12,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7945), 26,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [354735] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8302), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354790] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9772), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9770), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [354843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [354896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8294), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [354949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 19,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8022), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355002] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9720), 1,
      anon_sym_DOT,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(9724), 1,
      sym_hash_operator,
    STATE(8015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9790), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
      aux_sym_directive_token1,
    ACTIONS(9788), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
  [355061] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9024), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9022), 26,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [355114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9828), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9826), 20,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [355167] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [355219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9092), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6793), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(6787), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [355375] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9844), 1,
      anon_sym_PIPE,
    STATE(8022), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18215), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20381), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355473] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9846), 1,
      anon_sym_PIPE,
    STATE(8023), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17632), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20772), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355571] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9848), 1,
      anon_sym_PIPE,
    STATE(8024), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15611), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [355669] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9698), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355721] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9096), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355773] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_type,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    STATE(8027), 1,
      sym_attribute,
    STATE(10803), 1,
      sym__polymorphic_type,
    STATE(10805), 1,
      sym_polymorphic_type,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13636), 1,
      sym_type_variable,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15234), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(16100), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(19993), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [355873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9608), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9610), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355925] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9818), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9820), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [355977] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9602), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356029] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9844), 1,
      anon_sym_PIPE,
    STATE(8031), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15074), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18215), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20381), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356127] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9850), 1,
      anon_sym_PIPE,
    STATE(8032), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18351), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20628), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356225] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9852), 1,
      anon_sym_PIPE,
    STATE(8033), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15868), 1,
      sym__tag_spec,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356323] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_type,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9854), 1,
      sym__lowercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    STATE(8034), 1,
      sym_attribute,
    STATE(10803), 1,
      sym__polymorphic_type,
    STATE(10804), 1,
      sym__type,
    STATE(10805), 1,
      sym_polymorphic_type,
    STATE(12692), 1,
      sym__simple_type,
    STATE(12788), 1,
      sym_type_variable,
    STATE(13932), 1,
      sym__proper_tuple_type,
    STATE(15624), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17202), 1,
      sym_extended_module_path,
    STATE(18439), 1,
      sym_labeled_tuple_element_type,
    STATE(18688), 1,
      sym__abstract_type,
    STATE(18937), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13511), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [356423] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9686), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356475] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9874), 1,
      anon_sym_PIPE,
    STATE(8036), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18401), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20536), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9726), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9728), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356625] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9682), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356677] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9876), 1,
      anon_sym_PIPE,
    STATE(8039), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17686), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20644), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [356775] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9674), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [356827] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9556), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9554), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [356879] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [356931] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9878), 1,
      anon_sym_PIPE,
    STATE(8043), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15244), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357029] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9880), 1,
      anon_sym_PIPE,
    STATE(8044), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15493), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357127] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [357179] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9882), 1,
      anon_sym_RBRACK,
    STATE(8046), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16624), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9702), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357329] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9584), 1,
      anon_sym_PIPE,
    STATE(8048), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18316), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20556), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357427] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9884), 1,
      anon_sym_PIPE,
    STATE(8049), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15402), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357525] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    STATE(8050), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16913), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357623] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8308), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9604), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9606), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357727] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9888), 1,
      anon_sym_PIPE,
    STATE(8053), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17321), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20660), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8206), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [357877] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9890), 1,
      anon_sym_PIPE,
    STATE(8055), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15287), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [357975] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9892), 1,
      anon_sym_RBRACK,
    STATE(8056), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16082), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358073] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9894), 1,
      anon_sym_RBRACK,
    STATE(8057), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15914), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358171] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9896), 1,
      anon_sym_RBRACK,
    STATE(8058), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16045), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358269] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8290), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358321] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9898), 1,
      anon_sym_RBRACK,
    STATE(8060), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16367), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358419] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9900), 1,
      anon_sym_RBRACK,
    STATE(8061), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16708), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358517] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9902), 1,
      anon_sym_PIPE,
    STATE(8062), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18004), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20493), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358615] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9904), 1,
      anon_sym_PIPE,
    STATE(8063), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15715), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [358713] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [358765] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [358817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8324), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358869] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9770), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9772), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [358921] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9906), 1,
      anon_sym_RBRACK,
    STATE(8068), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15966), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359019] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9908), 1,
      anon_sym_RBRACK,
    STATE(8069), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16025), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359117] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9620), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359169] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9910), 1,
      anon_sym_PIPE,
    STATE(8071), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15302), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359267] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9730), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9732), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359319] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9912), 1,
      anon_sym_RBRACK,
    STATE(8073), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16537), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8336), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359469] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9914), 1,
      anon_sym_PIPE,
    STATE(8075), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17747), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20676), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359567] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9916), 1,
      anon_sym_PIPE,
    STATE(8076), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15345), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9736), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359717] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9918), 1,
      anon_sym_PIPE,
    STATE(8078), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17457), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20575), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [359815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9060), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359867] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8344), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359919] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9636), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [359971] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9740), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [360023] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9920), 1,
      anon_sym_RBRACK,
    STATE(8083), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16372), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8364), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [360173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9826), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9828), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [360225] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9624), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [360277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8312), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [360329] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9922), 1,
      anon_sym_RBRACK,
    STATE(8088), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16160), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360427] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9746), 1,
      anon_sym_PIPE,
    STATE(8089), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17353), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20147), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360525] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9924), 1,
      anon_sym_PIPE,
    STATE(8090), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15294), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360623] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9926), 1,
      anon_sym_PIPE,
    STATE(8091), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18299), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20692), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360721] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9928), 1,
      anon_sym_PIPE,
    STATE(8092), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15393), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360819] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9930), 1,
      anon_sym_PIPE,
    STATE(8093), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15239), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [360917] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9844), 1,
      anon_sym_PIPE,
    STATE(8094), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15178), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18215), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20381), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361015] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_type,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9932), 1,
      sym__lowercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    STATE(8095), 1,
      sym_attribute,
    STATE(10582), 1,
      sym_type_variable,
    STATE(10755), 1,
      sym__simple_type,
    STATE(10803), 1,
      sym__polymorphic_type,
    STATE(10804), 1,
      sym__type,
    STATE(10805), 1,
      sym_polymorphic_type,
    STATE(12610), 1,
      sym__proper_tuple_type,
    STATE(15225), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19663), 1,
      sym_labeled_tuple_element_type,
    STATE(19928), 1,
      sym__abstract_type,
    STATE(20689), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11401), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [361115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8358), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9224), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9028), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [361323] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9952), 1,
      anon_sym_RBRACK,
    STATE(8100), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16284), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361421] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_type,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9954), 1,
      sym__lowercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    STATE(8101), 1,
      sym_attribute,
    STATE(10803), 1,
      sym__polymorphic_type,
    STATE(10804), 1,
      sym__type,
    STATE(10805), 1,
      sym_polymorphic_type,
    STATE(11707), 1,
      sym__simple_type,
    STATE(11996), 1,
      sym_type_variable,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(15511), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(18926), 1,
      sym__abstract_type,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [361521] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9974), 1,
      anon_sym_PIPE,
    STATE(8102), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15526), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8294), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361671] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8022), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361723] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9596), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9598), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361775] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9632), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361827] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9976), 1,
      anon_sym_RBRACK,
    STATE(8107), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16800), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [361925] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8332), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [361977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_then,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [362029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9560), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9558), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9564), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9562), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362133] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8354), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [362185] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9694), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [362237] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9978), 1,
      anon_sym_PIPE,
    STATE(8114), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17190), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20462), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362335] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9980), 1,
      anon_sym_PIPE,
    STATE(8115), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17297), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20593), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8282), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [362485] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9982), 1,
      anon_sym_PIPE,
    STATE(8117), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17215), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20708), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362583] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9984), 1,
      anon_sym_PIPE,
    STATE(8118), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15442), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362681] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9986), 1,
      anon_sym_PIPE,
    STATE(8119), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15481), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [362779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9654), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9656), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [362831] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_done,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [362883] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9988), 1,
      anon_sym_COLON,
    STATE(8122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 20,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [362937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9628), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [362989] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [363043] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9990), 1,
      anon_sym_PIPE,
    STATE(8125), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15635), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363141] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9992), 1,
      anon_sym_PIPE,
    STATE(8126), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17871), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20288), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363239] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9994), 1,
      anon_sym_PIPE,
    STATE(8127), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15360), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8316), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [363389] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9996), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8129), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8757), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8755), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [363443] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9999), 1,
      anon_sym_PIPE,
    STATE(8130), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17302), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20724), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363541] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10001), 1,
      anon_sym_PIPE,
    STATE(8131), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15480), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363639] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10003), 1,
      anon_sym_RBRACK,
    STATE(8132), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16992), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363737] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_type,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10005), 1,
      sym__lowercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    STATE(8133), 1,
      sym_attribute,
    STATE(10803), 1,
      sym__polymorphic_type,
    STATE(10804), 1,
      sym__type,
    STATE(10805), 1,
      sym_polymorphic_type,
    STATE(10965), 1,
      sym__simple_type,
    STATE(11220), 1,
      sym_type_variable,
    STATE(13317), 1,
      sym__proper_tuple_type,
    STATE(15333), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(18579), 1,
      sym__abstract_type,
    STATE(20077), 1,
      sym_labeled_tuple_element_type,
    STATE(20590), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11726), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [363837] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10025), 1,
      anon_sym_RBRACK,
    STATE(8134), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16508), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [363935] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [363987] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8070), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [364039] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10027), 1,
      anon_sym_RBRACK,
    STATE(8137), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16955), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364137] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9690), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [364189] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9666), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [364241] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10029), 1,
      anon_sym_PIPE,
    STATE(8140), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17388), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20740), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364339] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9780), 1,
      anon_sym_PIPE,
    STATE(8141), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17415), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20382), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364437] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10031), 1,
      anon_sym_PIPE,
    STATE(8142), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15519), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9124), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [364587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9640), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [364639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9536), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9534), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [364691] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10033), 1,
      anon_sym_RBRACK,
    STATE(8146), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17168), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [364841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9184), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [364893] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10035), 1,
      anon_sym_PIPE,
    STATE(8149), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17877), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20611), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [364991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8340), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365043] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9568), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9566), 23,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [365095] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10037), 1,
      anon_sym_PIPE,
    STATE(8152), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15679), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9644), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9760), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9204), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365349] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(9840), 1,
      anon_sym_PIPE,
    STATE(8156), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18263), 1,
      sym_tag_specification,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20516), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365447] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8328), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365499] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10039), 1,
      anon_sym_PIPE,
    STATE(8158), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15822), 1,
      sym__tag_spec,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365597] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10041), 1,
      anon_sym_RBRACK,
    STATE(8159), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15990), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365695] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 17,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_do,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_pow_operator,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
      sym__lowercase_identifier,
  [365747] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10043), 1,
      anon_sym_PIPE,
    STATE(8161), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(17521), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    STATE(20756), 1,
      sym__tag_spec,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [365845] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8298), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365897] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9046), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [365949] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10045), 1,
      anon_sym_PIPE,
    STATE(8164), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15567), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366047] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10047), 1,
      aux_sym_attribute_id_token1,
    STATE(8165), 1,
      sym_attribute,
    STATE(8167), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8774), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8772), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [366103] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(8166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366157] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10047), 1,
      aux_sym_attribute_id_token1,
    STATE(8129), 1,
      aux_sym_attribute_id_repeat1,
    STATE(8167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8768), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8766), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [366213] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9546), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9548), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [366265] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8320), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [366317] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10049), 1,
      anon_sym_RBRACK,
    STATE(8170), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16195), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366415] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10051), 1,
      anon_sym_RBRACK,
    STATE(8171), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16180), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366513] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9652), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [366565] = 29,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4819), 1,
      anon_sym_type,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    STATE(8173), 1,
      sym_attribute,
    STATE(13636), 1,
      sym_type_variable,
    STATE(13785), 1,
      sym__simple_type,
    STATE(14773), 1,
      sym__proper_tuple_type,
    STATE(15395), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15487), 1,
      sym__type,
    STATE(15919), 1,
      sym__polymorphic_type,
    STATE(15920), 1,
      sym_polymorphic_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(19147), 1,
      sym_labeled_tuple_element_type,
    STATE(20887), 1,
      sym_labeled_argument_type,
    STATE(20922), 1,
      sym__abstract_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [366665] = 28,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10053), 1,
      anon_sym_RBRACK,
    STATE(8174), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16472), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [366763] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 18,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8074), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [366815] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8154), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8152), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [366866] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10055), 1,
      sym__lowercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8177), 1,
      sym_attribute,
    STATE(10839), 1,
      sym__class_type,
    STATE(14465), 1,
      sym__simple_type,
    STATE(17277), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10639), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(18848), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [366957] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10069), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10067), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367008] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10073), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10071), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367059] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10077), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10075), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367110] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10083), 1,
      anon_sym_COLON,
    STATE(8181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10081), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10079), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [367163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10087), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10085), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10091), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10089), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367265] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8184), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16800), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367360] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8185), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15431), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367455] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367506] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8187), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15978), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [367601] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367652] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10095), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10093), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9610), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9608), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367754] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(10101), 1,
      anon_sym_LPAREN,
    ACTIONS(10105), 1,
      anon_sym_LBRACE,
    ACTIONS(10107), 1,
      anon_sym_begin,
    ACTIONS(10109), 1,
      aux_sym_number_token1,
    ACTIONS(10111), 1,
      anon_sym_SQUOTE,
    ACTIONS(10113), 1,
      anon_sym_DQUOTE,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    STATE(8191), 1,
      sym_attribute,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(12576), 1,
      sym_module_path,
    STATE(12975), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10103), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13323), 2,
      sym__constant,
      sym_value_path,
    ACTIONS(10097), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
    STATE(13355), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    ACTIONS(10099), 9,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
  [367833] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10119), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10117), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10123), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10121), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [367935] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10125), 1,
      anon_sym_DOT,
    ACTIONS(10127), 1,
      anon_sym_POUND,
    ACTIONS(10129), 1,
      sym_hash_operator,
    STATE(8194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8186), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8184), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [367992] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368043] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9728), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9726), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9732), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9730), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368145] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9734), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368196] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9740), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9738), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10137), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10135), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368349] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8284), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368451] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 14,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8216), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368606] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368657] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368708] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10141), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10139), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [368759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368810] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [368861] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8212), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16472), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [368956] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8213), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15390), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369051] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8214), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16692), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369146] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(8215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 14,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8300), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9182), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [369301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10145), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10143), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [369352] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8219), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16082), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369447] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8220), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15545), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369542] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8757), 16,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
    ACTIONS(8755), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [369593] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10055), 1,
      sym__lowercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8222), 1,
      sym_attribute,
    STATE(11023), 1,
      sym__class_type,
    STATE(14465), 1,
      sym__simple_type,
    STATE(17277), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10639), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(18848), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [369684] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8223), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16117), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [369779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10149), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10147), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [369830] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10151), 1,
      sym__lowercase_identifier,
    ACTIONS(10153), 1,
      anon_sym_let,
    ACTIONS(10155), 1,
      anon_sym_LBRACK,
    STATE(8225), 1,
      sym_attribute,
    STATE(11023), 1,
      sym__class_type,
    STATE(14339), 1,
      sym__simple_type,
    STATE(17403), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(14852), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(18725), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [369921] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10157), 1,
      anon_sym_COLON,
    STATE(8226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10081), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10079), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [369974] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7921), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7919), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10161), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10159), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [370076] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8229), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16372), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370171] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8230), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15645), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370266] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8231), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16406), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370361] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370412] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10165), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10163), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [370463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8222), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8220), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370514] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8235), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16708), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370609] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8236), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15738), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370704] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8237), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16738), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [370850] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8239), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16955), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [370945] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8240), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15833), 1,
      sym__tag_spec,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371040] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8241), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16994), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371135] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9046), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9044), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371186] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10151), 1,
      sym__lowercase_identifier,
    ACTIONS(10153), 1,
      anon_sym_let,
    ACTIONS(10155), 1,
      anon_sym_LBRACK,
    STATE(8243), 1,
      sym_attribute,
    STATE(10839), 1,
      sym__class_type,
    STATE(14339), 1,
      sym__simple_type,
    STATE(17403), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(14852), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(18725), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [371277] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9760), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9758), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371328] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8245), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16508), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371423] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8246), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15221), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371518] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8247), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16839), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371613] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8248), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16045), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371708] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8249), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15556), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8054), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8052), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [371854] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8251), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16254), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [371949] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8252), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16367), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372044] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8253), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15272), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372139] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8254), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16830), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8058), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8056), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372285] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10167), 1,
      sym__lowercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8256), 1,
      sym_attribute,
    STATE(11023), 1,
      sym__class_type,
    STATE(14355), 1,
      sym__simple_type,
    STATE(18328), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10561), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(19578), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [372376] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8257), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15990), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372471] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8258), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15516), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9772), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9770), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372617] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8260), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16095), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [372712] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10167), 1,
      sym__lowercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8261), 1,
      sym_attribute,
    STATE(10839), 1,
      sym__class_type,
    STATE(14355), 1,
      sym__simple_type,
    STATE(18328), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10561), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(19578), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [372803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8204), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [372905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10175), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10173), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [372956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8062), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8060), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373007] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8266), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16537), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373102] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8267), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15702), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373197] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8268), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16606), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373292] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8066), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8064), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8078), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8076), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10179), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10177), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [373445] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8272), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17168), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373540] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8273), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15900), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373635] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373686] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373737] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8276), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16764), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373832] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7959), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [373883] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8278), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15966), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [373978] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8279), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15248), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374124] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8281), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16089), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374219] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8282), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16399), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374314] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8283), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16992), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374409] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8284), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15299), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374504] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8285), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(17154), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [374650] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8290), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [374701] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8288), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16500), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374796] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8289), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16195), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374891] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8290), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15354), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [374986] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9598), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9596), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375037] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8292), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16287), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9602), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9600), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8230), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8228), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [375234] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10181), 1,
      sym__lowercase_identifier,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8295), 1,
      sym_attribute,
    STATE(10839), 1,
      sym__class_type,
    STATE(14591), 1,
      sym__simple_type,
    STATE(17345), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(11486), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(19061), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [375325] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8296), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16624), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375420] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8297), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15405), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375515] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8298), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16727), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375610] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8299), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16913), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375705] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8300), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15449), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375800] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8294), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [375851] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8302), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(16983), 1,
      sym__tag_spec,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [375946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8022), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [375997] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8304), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15914), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376092] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8305), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15484), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376187] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8306), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(15934), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8298), 25,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [376333] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(6793), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376384] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8309), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15527), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376479] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8310), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16047), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376574] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5449), 1,
      sym__lowercase_identifier,
    ACTIONS(10101), 1,
      anon_sym_LPAREN,
    ACTIONS(10105), 1,
      anon_sym_LBRACE,
    ACTIONS(10107), 1,
      anon_sym_begin,
    ACTIONS(10109), 1,
      aux_sym_number_token1,
    ACTIONS(10111), 1,
      anon_sym_SQUOTE,
    ACTIONS(10113), 1,
      anon_sym_DQUOTE,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    STATE(8311), 1,
      sym_attribute,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(12576), 1,
      sym_module_path,
    STATE(12975), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10103), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13323), 2,
      sym__constant,
      sym_value_path,
    STATE(13355), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
    ACTIONS(10097), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
    ACTIONS(10099), 8,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
  [376653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [376704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10191), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10189), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [376755] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8314), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16160), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376850] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8315), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15574), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [376945] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8316), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16187), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377040] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377091] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9060), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9058), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377142] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9028), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9026), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377193] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8320), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16284), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377288] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8321), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15622), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9652), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9650), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377434] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8323), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16312), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [377529] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7963), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377682] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8086), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8084), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8090), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8088), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8094), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8092), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377835] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10195), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10193), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [377886] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8098), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8096), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8102), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8100), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [377988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10199), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10197), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [378039] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10205), 1,
      anon_sym_RPAREN,
    STATE(8334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10203), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10201), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [378092] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9666), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9664), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378143] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8106), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8104), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7933), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7931), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9674), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9672), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378296] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8110), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8108), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378347] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10125), 1,
      anon_sym_DOT,
    STATE(8340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 14,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8112), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378400] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8118), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8116), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8122), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8120), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8126), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8124), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378553] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8130), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8128), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8134), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8132), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378655] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8138), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8136), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9606), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9604), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9632), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9630), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8334), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8142), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8140), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9622), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [378961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8146), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8144), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9626), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379063] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9634), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379114] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7913), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8150), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8148), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8326), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379267] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9640), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9638), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379318] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9642), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379369] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8226), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8224), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379420] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9202), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8158), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8156), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379522] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8162), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8160), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8166), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8164), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8362), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8170), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8168), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379726] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8174), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8172), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8178), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8176), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8182), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8180), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [379879] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8370), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16180), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [379974] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8234), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8232), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7937), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7935), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7941), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7939), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380127] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8374), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15588), 1,
      sym__tag_spec,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [380222] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7945), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7943), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380273] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8190), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8188), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9620), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9618), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380375] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9684), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380426] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9688), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380477] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9692), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9696), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380579] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9702), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9700), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380630] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8238), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8236), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8330), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380732] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8338), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8280), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8342), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9092), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9090), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9096), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9094), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [380987] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8242), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8240), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8306), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8288), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381140] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(10207), 1,
      sym__lowercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8393), 1,
      sym_attribute,
    STATE(10839), 1,
      sym__class_type,
    STATE(14466), 1,
      sym__simple_type,
    STATE(17990), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(11026), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(19646), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [381231] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10125), 1,
      anon_sym_DOT,
    ACTIONS(10127), 1,
      anon_sym_POUND,
    ACTIONS(10129), 1,
      sym_hash_operator,
    STATE(8394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381288] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8352), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381339] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8194), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8192), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381390] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8356), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8246), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8244), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381492] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8250), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8248), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381543] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8254), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8252), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381594] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8198), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8196), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8202), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8200), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8292), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381747] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8020), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7949), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7947), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381849] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7953), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7951), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381900] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9656), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9654), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [381951] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7957), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(7955), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382002] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10181), 1,
      sym__lowercase_identifier,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8409), 1,
      sym_attribute,
    STATE(11023), 1,
      sym__class_type,
    STATE(14591), 1,
      sym__simple_type,
    STATE(17345), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(11486), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(19061), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [382093] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9124), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9122), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8296), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9682), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9680), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382246] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8258), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8256), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8262), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8260), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382348] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8210), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8208), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10215), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10213), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [382450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8266), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8264), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9820), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9818), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382552] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8310), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382603] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8270), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8268), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9828), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9826), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382705] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8314), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8318), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8322), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [382858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3193), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3191), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [382909] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10219), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10217), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [382960] = 25,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10059), 1,
      anon_sym_LBRACK,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(10207), 1,
      sym__lowercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8427), 1,
      sym_attribute,
    STATE(11023), 1,
      sym__class_type,
    STATE(14466), 1,
      sym__simple_type,
    STATE(17990), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10990), 2,
      sym__simple_class_type,
      sym_class_function_type,
    STATE(11026), 2,
      sym_extension,
      sym_quoted_extension,
    STATE(19646), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(10177), 4,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_class_type_path,
    STATE(13276), 9,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_type_constructor_path,
      sym_type_variable,
  [383051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8068), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [383102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 15,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8212), 21,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [383153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10223), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10221), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [383204] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10227), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10225), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [383255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8072), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [383306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10231), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10229), 25,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [383357] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9222), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [383408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 19,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [383459] = 27,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9272), 1,
      aux_sym_tag_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8436), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15772), 1,
      sym__type,
    STATE(15872), 1,
      sym_tag,
    STATE(16025), 1,
      sym__tag_spec,
    STATE(16315), 1,
      sym_tag_specification,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [383554] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8364), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [383604] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383676] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10215), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10213), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [383778] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383834] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [383906] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3193), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3191), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [383956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10219), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10217), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384006] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10269), 1,
      anon_sym_else,
    STATE(8445), 1,
      sym_attribute,
    STATE(8510), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384060] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384132] = 26,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9586), 1,
      anon_sym_RPAREN,
    ACTIONS(10275), 1,
      anon_sym_module,
    STATE(8447), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15396), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10227), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10225), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10279), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10277), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384324] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10179), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10177), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10223), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10221), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10069), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10067), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384474] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10283), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10281), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384524] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10287), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384574] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384624] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10073), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10071), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [384674] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10291), 1,
      anon_sym_SEMI,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10175), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10173), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384798] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10309), 1,
      anon_sym_else,
    STATE(8459), 1,
      sym_attribute,
    STATE(8510), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384852] = 26,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9782), 1,
      anon_sym_RPAREN,
    ACTIONS(10311), 1,
      anon_sym_module,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    STATE(8460), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15525), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [384944] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10269), 1,
      anon_sym_else,
    STATE(8461), 1,
      sym_attribute,
    STATE(8462), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [384998] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10231), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10229), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10091), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10089), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10119), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10117), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385148] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10095), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10093), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385198] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10319), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385252] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8328), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [385302] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10191), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10189), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385352] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10077), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10075), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385402] = 26,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9842), 1,
      anon_sym_RPAREN,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10321), 1,
      anon_sym_module,
    STATE(8470), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15820), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [385494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10223), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10221), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385544] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10087), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10085), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385594] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10161), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10159), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10287), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10069), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10067), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9050), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385794] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10309), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10119), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10117), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [385898] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [385968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386018] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10073), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10071), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386128] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10175), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10173), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386178] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10137), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10135), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10231), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10229), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [386278] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10191), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10189), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386328] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10295), 1,
      sym_pow_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386382] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10291), 1,
      anon_sym_SEMI,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386456] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10123), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10121), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386506] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10195), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10193), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386556] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [386608] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8336), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [386658] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10295), 1,
      sym_pow_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386712] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386774] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386836] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386902] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10319), 1,
      anon_sym_else,
    STATE(8497), 1,
      sym_attribute,
    STATE(8510), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [386956] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    ACTIONS(10331), 1,
      anon_sym_SEMI,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387030] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10333), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387102] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10339), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10337), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [387220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9024), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9022), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [387270] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    ACTIONS(10331), 1,
      anon_sym_SEMI,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387344] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387416] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387472] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(8506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8302), 19,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [387524] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10149), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10147), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10141), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10139), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387696] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10095), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10093), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387746] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10199), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10197), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10215), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10213), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10141), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10139), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [387896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10137), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10135), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [387946] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10161), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10159), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [387996] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10203), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10201), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [388046] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10341), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388100] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10145), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10143), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [388150] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3193), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3191), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388200] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10345), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10343), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [388250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10149), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10147), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [388300] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10333), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388372] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10351), 1,
      anon_sym_PIPE,
    STATE(8523), 1,
      sym_attribute,
    STATE(8526), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388426] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388498] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10351), 1,
      anon_sym_PIPE,
    STATE(8525), 1,
      sym_attribute,
    STATE(8526), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388552] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10357), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8526), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388604] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388674] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10145), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10143), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10283), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10281), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9030), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [388824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10165), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10163), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [388874] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388934] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10243), 1,
      sym_pow_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [388988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10362), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10360), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [389038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10195), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10193), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [389088] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_PIPE,
    STATE(8536), 1,
      sym_attribute,
    STATE(8540), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389142] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    ACTIONS(10291), 1,
      anon_sym_SEMI,
    ACTIONS(10293), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10295), 1,
      sym_pow_operator,
    ACTIONS(10297), 1,
      sym_mult_operator,
    ACTIONS(10299), 1,
      sym_concat_operator,
    ACTIONS(10301), 1,
      sym_rel_operator,
    ACTIONS(10303), 1,
      sym_and_operator,
    ACTIONS(10305), 1,
      sym_or_operator,
    ACTIONS(10307), 1,
      sym_assign_operator,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389216] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10368), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10366), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [389266] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_PIPE,
    STATE(8539), 1,
      sym_attribute,
    STATE(8540), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389320] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10370), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8540), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389372] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10219), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10217), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389422] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    ACTIONS(10255), 1,
      sym_assign_operator,
    ACTIONS(10331), 1,
      anon_sym_SEMI,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10165), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10163), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389546] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10351), 1,
      anon_sym_PIPE,
    STATE(8523), 1,
      aux_sym__match_cases_repeat1,
    STATE(8544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10379), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10377), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [389650] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10243), 1,
      sym_pow_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389704] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389766] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10351), 1,
      anon_sym_PIPE,
    STATE(8525), 1,
      aux_sym__match_cases_repeat1,
    STATE(8548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389820] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [389882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10383), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10381), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [389932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10387), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10385), 33,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [389982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10091), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10089), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390032] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10389), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390082] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10205), 15,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      aux_sym_sign_operator_token1,
      sym_let_operator,
      sym_match_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(10393), 20,
      anon_sym_let,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_fun,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_function,
      anon_sym_try,
      anon_sym_assert,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
  [390132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10389), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390182] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_PIPE,
    STATE(8536), 1,
      aux_sym__match_cases_repeat1,
    STATE(8556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10077), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10075), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390286] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1967), 1,
      sym_add_operator,
    STATE(8558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390338] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10227), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10225), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390388] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10087), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10085), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390438] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10341), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390492] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390558] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10199), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10197), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [390608] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 15,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_as,
      anon_sym_POUND,
      anon_sym_lazy,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8206), 20,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [390658] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10364), 1,
      anon_sym_PIPE,
    STATE(8539), 1,
      aux_sym__match_cases_repeat1,
    STATE(8565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390712] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10279), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10277), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390762] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10239), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10243), 1,
      sym_pow_operator,
    ACTIONS(10245), 1,
      sym_mult_operator,
    ACTIONS(10247), 1,
      sym_concat_operator,
    ACTIONS(10249), 1,
      sym_rel_operator,
    ACTIONS(10251), 1,
      sym_and_operator,
    ACTIONS(10253), 1,
      sym_or_operator,
    STATE(1999), 1,
      sym_add_operator,
    STATE(8567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390830] = 26,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9748), 1,
      anon_sym_RPAREN,
    ACTIONS(10395), 1,
      anon_sym_module,
    STATE(8568), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15289), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [390922] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10179), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10177), 23,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [390972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10123), 11,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10121), 24,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [391022] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391093] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391152] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10417), 1,
      sym_pow_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391205] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10417), 1,
      sym_pow_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391258] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391319] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391380] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391445] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391512] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391563] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391634] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_PIPE,
    STATE(8581), 1,
      sym_attribute,
    STATE(8583), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391687] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_PIPE,
    STATE(8582), 1,
      sym_attribute,
    STATE(8583), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391740] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10431), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8583), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391791] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10436), 1,
      anon_sym_SEMI,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391864] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391925] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [391996] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10458), 1,
      anon_sym_PIPE,
    STATE(8587), 1,
      sym_attribute,
    STATE(8589), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392049] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10458), 1,
      anon_sym_PIPE,
    STATE(8588), 1,
      sym_attribute,
    STATE(8589), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392102] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10460), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8589), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392153] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392222] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392281] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10440), 1,
      sym_pow_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392334] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10465), 1,
      anon_sym_SEMI,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392407] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392462] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_PIPE,
    STATE(8581), 1,
      aux_sym__match_cases_repeat1,
    STATE(8595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392515] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10440), 1,
      sym_pow_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392568] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392639] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392700] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10429), 1,
      anon_sym_PIPE,
    STATE(8582), 1,
      aux_sym__match_cases_repeat1,
    STATE(8599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392753] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392814] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392875] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [392940] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393007] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393078] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393133] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393204] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393257] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393328] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10458), 1,
      anon_sym_PIPE,
    STATE(8587), 1,
      aux_sym__match_cases_repeat1,
    STATE(8609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393381] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10401), 1,
      sym_pow_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393434] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10458), 1,
      anon_sym_PIPE,
    STATE(8588), 1,
      aux_sym__match_cases_repeat1,
    STATE(8611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393487] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_PIPE,
    STATE(8612), 1,
      sym_attribute,
    STATE(8621), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393540] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393605] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    STATE(8614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393656] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393707] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10487), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393760] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10489), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393813] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_PIPE,
    STATE(8612), 1,
      aux_sym__match_cases_repeat1,
    STATE(8618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393866] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_PIPE,
    STATE(8619), 1,
      sym_attribute,
    STATE(8620), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393919] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10485), 1,
      anon_sym_PIPE,
    STATE(8620), 1,
      sym_attribute,
    STATE(8621), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [393972] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10491), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8621), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394023] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    ACTIONS(10494), 1,
      anon_sym_SEMI,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394096] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10483), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394149] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10333), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394220] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10496), 1,
      anon_sym_PIPE,
    STATE(8625), 1,
      sym_attribute,
    STATE(8626), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394273] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10498), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8626), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394324] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394393] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394452] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    ACTIONS(10494), 1,
      anon_sym_SEMI,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394525] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10469), 1,
      sym_pow_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394578] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10469), 1,
      sym_pow_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394631] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394692] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394753] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394818] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394885] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [394956] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395011] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395082] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10487), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395135] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395206] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    ACTIONS(10501), 1,
      anon_sym_SEMI,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395279] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    ACTIONS(10501), 1,
      anon_sym_SEMI,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395352] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10489), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395405] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395472] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10333), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395543] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395594] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    STATE(8647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395645] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10496), 1,
      anon_sym_PIPE,
    STATE(8648), 1,
      sym_attribute,
    STATE(8669), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395698] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10496), 1,
      anon_sym_PIPE,
    STATE(8625), 1,
      aux_sym__match_cases_repeat1,
    STATE(8649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395751] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395822] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8302), 20,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [395873] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10503), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395926] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    ACTIONS(10501), 1,
      anon_sym_SEMI,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [395999] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10503), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396052] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396107] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396178] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10436), 1,
      anon_sym_SEMI,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396251] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    ACTIONS(10436), 1,
      anon_sym_SEMI,
    ACTIONS(10438), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_pow_operator,
    ACTIONS(10442), 1,
      sym_mult_operator,
    ACTIONS(10444), 1,
      sym_concat_operator,
    ACTIONS(10446), 1,
      sym_rel_operator,
    ACTIONS(10448), 1,
      sym_and_operator,
    ACTIONS(10450), 1,
      sym_or_operator,
    ACTIONS(10452), 1,
      sym_assign_operator,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396324] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(8659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8302), 20,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [396375] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10465), 1,
      anon_sym_SEMI,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396448] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    ACTIONS(10494), 1,
      anon_sym_SEMI,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396521] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396590] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    ACTIONS(10465), 1,
      anon_sym_SEMI,
    ACTIONS(10467), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10469), 1,
      sym_pow_operator,
    ACTIONS(10471), 1,
      sym_mult_operator,
    ACTIONS(10473), 1,
      sym_concat_operator,
    ACTIONS(10475), 1,
      sym_rel_operator,
    ACTIONS(10477), 1,
      sym_and_operator,
    ACTIONS(10479), 1,
      sym_or_operator,
    ACTIONS(10481), 1,
      sym_assign_operator,
    STATE(2067), 1,
      sym_add_operator,
    STATE(8663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396663] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10505), 1,
      anon_sym_COLON,
    STATE(8664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8448), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8446), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [396714] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2028), 1,
      sym_add_operator,
    STATE(8665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 22,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396765] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396834] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10401), 1,
      sym_pow_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396887] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 8,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396946] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10496), 1,
      anon_sym_PIPE,
    STATE(8626), 1,
      aux_sym__match_cases_repeat1,
    STATE(8669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [396999] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10507), 1,
      sym__lowercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10511), 1,
      anon_sym_private,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    STATE(8670), 1,
      sym_attribute,
    STATE(9297), 1,
      sym__simple_type,
    STATE(9313), 1,
      sym__type,
    STATE(10726), 1,
      sym__proper_tuple_type,
    STATE(17493), 1,
      sym_extended_module_path,
    STATE(18623), 1,
      sym_labeled_tuple_element_type,
    STATE(19404), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397085] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10529), 1,
      anon_sym_module,
    STATE(8671), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17430), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397171] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10531), 1,
      anon_sym_module,
    STATE(8672), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17235), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397257] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10533), 1,
      anon_sym_module,
    STATE(8673), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15478), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397343] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10537), 1,
      anon_sym_SEMI,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397415] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10555), 1,
      anon_sym_module,
    STATE(8675), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17501), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397501] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10533), 1,
      anon_sym_module,
    STATE(8676), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17334), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397587] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10557), 1,
      anon_sym_module,
    STATE(8677), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15518), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397673] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    ACTIONS(10559), 1,
      anon_sym_SEMI,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397745] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10557), 1,
      anon_sym_module,
    STATE(8679), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17434), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397831] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [397901] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10275), 1,
      anon_sym_module,
    STATE(8681), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17668), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [397987] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10561), 1,
      anon_sym_module,
    STATE(8682), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15566), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398073] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398141] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10579), 1,
      anon_sym_module,
    STATE(8684), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15389), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398227] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10275), 1,
      anon_sym_module,
    STATE(8685), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15396), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398313] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10561), 1,
      anon_sym_module,
    STATE(8686), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17564), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398399] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10581), 1,
      anon_sym_module,
    STATE(8687), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15609), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398485] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10583), 1,
      anon_sym_module,
    STATE(8688), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18360), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398571] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10585), 1,
      anon_sym_PIPE,
    STATE(8689), 1,
      sym_attribute,
    STATE(8775), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398623] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10581), 1,
      anon_sym_module,
    STATE(8690), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17688), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8570), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8568), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [398757] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10587), 1,
      anon_sym_module,
    STATE(8692), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15678), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [398843] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    STATE(8693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398893] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    STATE(8694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [398943] = 22,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10589), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(10592), 1,
      anon_sym_let,
    ACTIONS(10595), 1,
      anon_sym_external,
    ACTIONS(10598), 1,
      anon_sym_type,
    ACTIONS(10601), 1,
      anon_sym_exception,
    ACTIONS(10604), 1,
      anon_sym_module,
    ACTIONS(10607), 1,
      anon_sym_open,
    ACTIONS(10610), 1,
      anon_sym_include,
    ACTIONS(10613), 1,
      anon_sym_class,
    ACTIONS(10616), 1,
      anon_sym_end,
    ACTIONS(10618), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(10621), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(10624), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10627), 1,
      sym_let_operator,
    ACTIONS(10630), 1,
      aux_sym_directive_token1,
    STATE(105), 1,
      aux_sym__structure_repeat1,
    STATE(8191), 1,
      sym_directive,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8695), 2,
      sym_attribute,
      aux_sym__structure_repeat2,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [399025] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10555), 1,
      anon_sym_module,
    STATE(8696), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15476), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [399111] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(299), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(361), 1,
      aux_sym_directive_token1,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(10633), 1,
      anon_sym_let,
    ACTIONS(10635), 1,
      anon_sym_type,
    ACTIONS(10637), 1,
      anon_sym_exception,
    ACTIONS(10639), 1,
      anon_sym_module,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10645), 1,
      anon_sym_class,
    ACTIONS(10647), 1,
      sym_let_operator,
    STATE(97), 1,
      aux_sym__structure_repeat1,
    STATE(8191), 1,
      sym_directive,
    STATE(8695), 1,
      aux_sym__structure_repeat2,
    STATE(8697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [399195] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10585), 1,
      anon_sym_PIPE,
    STATE(8698), 1,
      sym_attribute,
    STATE(8776), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399247] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    STATE(8699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399297] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    ACTIONS(10559), 1,
      anon_sym_SEMI,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [399369] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(299), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(361), 1,
      aux_sym_directive_token1,
    ACTIONS(479), 1,
      anon_sym_end,
    ACTIONS(10633), 1,
      anon_sym_let,
    ACTIONS(10635), 1,
      anon_sym_type,
    ACTIONS(10637), 1,
      anon_sym_exception,
    ACTIONS(10639), 1,
      anon_sym_module,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10645), 1,
      anon_sym_class,
    ACTIONS(10647), 1,
      sym_let_operator,
    STATE(104), 1,
      aux_sym__structure_repeat1,
    STATE(8191), 1,
      sym_directive,
    STATE(8701), 1,
      sym_attribute,
    STATE(8711), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [399453] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10529), 1,
      anon_sym_module,
    STATE(8702), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15233), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [399539] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(121), 1,
      aux_sym_directive_token1,
    ACTIONS(693), 1,
      anon_sym_RBRACK,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10649), 1,
      anon_sym_let,
    ACTIONS(10651), 1,
      anon_sym_type,
    ACTIONS(10653), 1,
      anon_sym_exception,
    ACTIONS(10655), 1,
      anon_sym_module,
    ACTIONS(10657), 1,
      anon_sym_class,
    ACTIONS(10659), 1,
      sym_let_operator,
    STATE(101), 1,
      aux_sym__structure_repeat1,
    STATE(8311), 1,
      sym_directive,
    STATE(8703), 1,
      sym_attribute,
    STATE(8773), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [399623] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10661), 1,
      sym__lowercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10665), 1,
      anon_sym_private,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    STATE(8704), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(13673), 1,
      sym__simple_type,
    STATE(14320), 1,
      sym__proper_tuple_type,
    STATE(17664), 1,
      sym_extended_module_path,
    STATE(21166), 1,
      sym_labeled_tuple_element_type,
    STATE(21321), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [399709] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10587), 1,
      anon_sym_module,
    STATE(8705), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18123), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [399795] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9378), 1,
      sym__lowercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10685), 1,
      anon_sym_private,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    STATE(8706), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [399881] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10689), 1,
      anon_sym_module,
    STATE(8707), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15866), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [399967] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(121), 1,
      aux_sym_directive_token1,
    ACTIONS(479), 1,
      anon_sym_RBRACK,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10649), 1,
      anon_sym_let,
    ACTIONS(10651), 1,
      anon_sym_type,
    ACTIONS(10653), 1,
      anon_sym_exception,
    ACTIONS(10655), 1,
      anon_sym_module,
    ACTIONS(10657), 1,
      anon_sym_class,
    ACTIONS(10659), 1,
      sym_let_operator,
    STATE(100), 1,
      aux_sym__structure_repeat1,
    STATE(8311), 1,
      sym_directive,
    STATE(8708), 1,
      sym_attribute,
    STATE(8765), 1,
      aux_sym__structure_repeat2,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [400051] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10689), 1,
      anon_sym_module,
    STATE(8709), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17315), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400137] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8302), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [400187] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(299), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(361), 1,
      aux_sym_directive_token1,
    ACTIONS(693), 1,
      anon_sym_end,
    ACTIONS(10633), 1,
      anon_sym_let,
    ACTIONS(10635), 1,
      anon_sym_type,
    ACTIONS(10637), 1,
      anon_sym_exception,
    ACTIONS(10639), 1,
      anon_sym_module,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10645), 1,
      anon_sym_class,
    ACTIONS(10647), 1,
      sym_let_operator,
    STATE(94), 1,
      aux_sym__structure_repeat1,
    STATE(8191), 1,
      sym_directive,
    STATE(8695), 1,
      aux_sym__structure_repeat2,
    STATE(8711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [400271] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10395), 1,
      anon_sym_module,
    STATE(8712), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17389), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400357] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [400415] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(299), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(361), 1,
      aux_sym_directive_token1,
    ACTIONS(693), 1,
      anon_sym_end,
    ACTIONS(10633), 1,
      anon_sym_let,
    ACTIONS(10635), 1,
      anon_sym_type,
    ACTIONS(10637), 1,
      anon_sym_exception,
    ACTIONS(10639), 1,
      anon_sym_module,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10645), 1,
      anon_sym_class,
    ACTIONS(10647), 1,
      sym_let_operator,
    STATE(94), 1,
      aux_sym__structure_repeat1,
    STATE(8191), 1,
      sym_directive,
    STATE(8697), 1,
      aux_sym__structure_repeat2,
    STATE(8714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [400499] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10567), 1,
      sym_pow_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [400551] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10691), 1,
      anon_sym_module,
    STATE(8716), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15242), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400637] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10691), 1,
      anon_sym_module,
    STATE(8717), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18282), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400723] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10693), 1,
      anon_sym_module,
    STATE(8718), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18137), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400809] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10537), 1,
      anon_sym_SEMI,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [400881] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10695), 1,
      sym__lowercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10699), 1,
      anon_sym_private,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    STATE(8720), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9619), 1,
      sym__simple_type,
    STATE(11261), 1,
      sym__proper_tuple_type,
    STATE(17263), 1,
      sym_extended_module_path,
    STATE(18511), 1,
      sym_labeled_tuple_element_type,
    STATE(19100), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [400967] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10311), 1,
      anon_sym_module,
    STATE(8721), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15525), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401053] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10717), 1,
      anon_sym_module,
    STATE(8722), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15286), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401139] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10567), 1,
      sym_pow_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401191] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401251] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401311] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401375] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401425] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401491] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    ACTIONS(10719), 1,
      anon_sym_SEMI,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401563] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    ACTIONS(10719), 1,
      anon_sym_SEMI,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401635] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10721), 1,
      anon_sym_SEMI,
    ACTIONS(10723), 1,
      sym_assign_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401707] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    ACTIONS(10725), 1,
      anon_sym_AMP,
    STATE(8732), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(14941), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401793] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10723), 1,
      sym_assign_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [401863] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10311), 1,
      anon_sym_module,
    STATE(8734), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17502), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [401949] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10727), 1,
      sym__lowercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10731), 1,
      anon_sym_private,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    STATE(8735), 1,
      sym_attribute,
    STATE(9308), 1,
      sym__simple_type,
    STATE(9313), 1,
      sym__type,
    STATE(10924), 1,
      sym__proper_tuple_type,
    STATE(18259), 1,
      sym_extended_module_path,
    STATE(20815), 1,
      sym_labeled_tuple_element_type,
    STATE(21196), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402035] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [402089] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8206), 20,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [402137] = 22,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10589), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(10595), 1,
      anon_sym_external,
    ACTIONS(10607), 1,
      anon_sym_open,
    ACTIONS(10610), 1,
      anon_sym_include,
    ACTIONS(10616), 1,
      anon_sym_RBRACK,
    ACTIONS(10618), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(10621), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(10624), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10749), 1,
      anon_sym_let,
    ACTIONS(10752), 1,
      anon_sym_type,
    ACTIONS(10755), 1,
      anon_sym_exception,
    ACTIONS(10758), 1,
      anon_sym_module,
    ACTIONS(10761), 1,
      anon_sym_class,
    ACTIONS(10764), 1,
      sym_let_operator,
    ACTIONS(10767), 1,
      aux_sym_directive_token1,
    STATE(107), 1,
      aux_sym__structure_repeat1,
    STATE(8311), 1,
      sym_directive,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8738), 2,
      sym_attribute,
      aux_sym__structure_repeat2,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [402219] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    ACTIONS(10399), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10401), 1,
      sym_pow_operator,
    ACTIONS(10403), 1,
      sym_mult_operator,
    ACTIONS(10405), 1,
      sym_concat_operator,
    ACTIONS(10407), 1,
      sym_rel_operator,
    ACTIONS(10409), 1,
      sym_and_operator,
    ACTIONS(10411), 1,
      sym_or_operator,
    ACTIONS(10413), 1,
      sym_assign_operator,
    ACTIONS(10719), 1,
      anon_sym_SEMI,
    STATE(2250), 1,
      sym_add_operator,
    STATE(8739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [402291] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10693), 1,
      anon_sym_module,
    STATE(8740), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15743), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402377] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9308), 1,
      sym__lowercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10772), 1,
      anon_sym_private,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    STATE(8741), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402463] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10583), 1,
      anon_sym_module,
    STATE(8742), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15358), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402549] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(8743), 1,
      sym_attribute,
    STATE(9275), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10780), 2,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10776), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [402607] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10786), 1,
      anon_sym_module,
    STATE(8744), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15633), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402693] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10717), 1,
      anon_sym_module,
    STATE(8745), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17483), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9560), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9558), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [402827] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10579), 1,
      anon_sym_module,
    STATE(8747), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17261), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [402913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9564), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9562), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [402961] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10788), 1,
      sym__lowercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10792), 1,
      anon_sym_private,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    STATE(8749), 1,
      sym_attribute,
    STATE(9289), 1,
      sym__simple_type,
    STATE(9313), 1,
      sym__type,
    STATE(10690), 1,
      sym__proper_tuple_type,
    STATE(17378), 1,
      sym_extended_module_path,
    STATE(18568), 1,
      sym_labeled_tuple_element_type,
    STATE(20677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403047] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10810), 1,
      anon_sym_module,
    STATE(8750), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15344), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403133] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10812), 1,
      sym__lowercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10816), 1,
      anon_sym_private,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    STATE(8751), 1,
      sym_attribute,
    STATE(13384), 1,
      sym__simple_type,
    STATE(14035), 1,
      sym__proper_tuple_type,
    STATE(14210), 1,
      sym__type,
    STATE(17607), 1,
      sym_extended_module_path,
    STATE(18678), 1,
      sym_labeled_tuple_element_type,
    STATE(18862), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403219] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10786), 1,
      anon_sym_module,
    STATE(8752), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17782), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403305] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [403355] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10721), 1,
      anon_sym_SEMI,
    ACTIONS(10723), 1,
      sym_assign_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [403427] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10834), 1,
      anon_sym_PIPE,
    STATE(8755), 1,
      sym_attribute,
    STATE(8757), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [403479] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10834), 1,
      anon_sym_PIPE,
    STATE(8756), 1,
      sym_attribute,
    STATE(8757), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [403531] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10836), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8757), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [403581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9536), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9534), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [403629] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10810), 1,
      anon_sym_module,
    STATE(8759), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17960), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403715] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10839), 1,
      anon_sym_module,
    STATE(8760), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15714), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [403801] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10537), 1,
      anon_sym_SEMI,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9032), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [403873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8082), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(8080), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [403921] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8336), 20,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [403969] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10841), 1,
      anon_sym_module,
    STATE(8764), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15392), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404055] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(121), 1,
      aux_sym_directive_token1,
    ACTIONS(693), 1,
      anon_sym_RBRACK,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10649), 1,
      anon_sym_let,
    ACTIONS(10651), 1,
      anon_sym_type,
    ACTIONS(10653), 1,
      anon_sym_exception,
    ACTIONS(10655), 1,
      anon_sym_module,
    ACTIONS(10657), 1,
      anon_sym_class,
    ACTIONS(10659), 1,
      sym_let_operator,
    STATE(101), 1,
      aux_sym__structure_repeat1,
    STATE(8311), 1,
      sym_directive,
    STATE(8738), 1,
      aux_sym__structure_repeat2,
    STATE(8765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [404139] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10723), 1,
      sym_assign_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [404209] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [404277] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10395), 1,
      anon_sym_module,
    STATE(8768), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15289), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404363] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10839), 1,
      anon_sym_module,
    STATE(8769), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18175), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404449] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9406), 1,
      sym__lowercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10845), 1,
      anon_sym_private,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    STATE(8770), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404535] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(8771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8302), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [404585] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10415), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10417), 1,
      sym_pow_operator,
    ACTIONS(10419), 1,
      sym_mult_operator,
    ACTIONS(10421), 1,
      sym_concat_operator,
    ACTIONS(10423), 1,
      sym_rel_operator,
    ACTIONS(10425), 1,
      sym_and_operator,
    ACTIONS(10427), 1,
      sym_or_operator,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    ACTIONS(10456), 1,
      sym_assign_operator,
    ACTIONS(10559), 1,
      anon_sym_SEMI,
    STATE(2359), 1,
      sym_add_operator,
    STATE(8772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9052), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [404657] = 23,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(35), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(121), 1,
      aux_sym_directive_token1,
    ACTIONS(695), 1,
      anon_sym_RBRACK,
    ACTIONS(10641), 1,
      anon_sym_open,
    ACTIONS(10643), 1,
      anon_sym_include,
    ACTIONS(10649), 1,
      anon_sym_let,
    ACTIONS(10651), 1,
      anon_sym_type,
    ACTIONS(10653), 1,
      anon_sym_exception,
    ACTIONS(10655), 1,
      anon_sym_module,
    ACTIONS(10657), 1,
      anon_sym_class,
    ACTIONS(10659), 1,
      sym_let_operator,
    STATE(102), 1,
      aux_sym__structure_repeat1,
    STATE(8311), 1,
      sym_directive,
    STATE(8738), 1,
      aux_sym__structure_repeat2,
    STATE(8773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13241), 2,
      sym_toplevel_directive,
      sym__structure_item,
    STATE(13305), 13,
      sym_value_definition,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_include_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [404741] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [404799] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10585), 1,
      anon_sym_PIPE,
    STATE(8775), 1,
      sym_attribute,
    STATE(8778), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [404851] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10585), 1,
      anon_sym_PIPE,
    STATE(8776), 1,
      sym_attribute,
    STATE(8778), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [404903] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10841), 1,
      anon_sym_module,
    STATE(8777), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18396), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [404989] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10849), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8778), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405039] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10723), 1,
      sym_assign_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405109] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9344), 1,
      sym__lowercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10854), 1,
      anon_sym_private,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    STATE(8780), 1,
      sym_attribute,
    STATE(9313), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405195] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10541), 1,
      sym_pow_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9556), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9554), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [405295] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10321), 1,
      anon_sym_module,
    STATE(8783), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15820), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405381] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10541), 1,
      sym_pow_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8364), 20,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [405481] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10834), 1,
      anon_sym_PIPE,
    STATE(8755), 1,
      aux_sym__match_cases_repeat1,
    STATE(8786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405533] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405593] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 7,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405653] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405717] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10834), 1,
      anon_sym_PIPE,
    STATE(8756), 1,
      aux_sym__match_cases_repeat1,
    STATE(8790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405769] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10321), 1,
      anon_sym_module,
    STATE(8791), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18317), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [405855] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(8792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9568), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9566), 20,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_object,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_new,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [405903] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [405969] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [406039] = 24,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7631), 1,
      sym__lowercase_identifier,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10531), 1,
      anon_sym_module,
    STATE(8795), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15438), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406125] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [406179] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    STATE(8797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [406229] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 13,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_when,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8328), 20,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [406277] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 5,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [406347] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10721), 1,
      anon_sym_SEMI,
    ACTIONS(10723), 1,
      sym_assign_operator,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [406419] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10858), 1,
      sym__lowercase_identifier,
    STATE(8801), 1,
      sym_attribute,
    STATE(9297), 1,
      sym__simple_type,
    STATE(9368), 1,
      sym__type,
    STATE(10726), 1,
      sym__proper_tuple_type,
    STATE(17493), 1,
      sym_extended_module_path,
    STATE(18623), 1,
      sym_labeled_tuple_element_type,
    STATE(19404), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406502] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8802), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18368), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406585] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(10860), 1,
      sym__lowercase_identifier,
    STATE(8803), 1,
      sym_attribute,
    STATE(9368), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406668] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406731] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [406796] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8806), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17224), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406879] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8807), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17381), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [406962] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8808), 1,
      sym_attribute,
    STATE(13729), 1,
      sym__type,
    STATE(13785), 1,
      sym__simple_type,
    STATE(14773), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(19147), 1,
      sym_labeled_tuple_element_type,
    STATE(20887), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407045] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8809), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17233), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407128] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8810), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17397), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407211] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [407280] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [407333] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [407402] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8814), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17318), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407485] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10880), 1,
      sym__lowercase_identifier,
    STATE(8815), 1,
      sym_attribute,
    STATE(10820), 1,
      sym__type,
    STATE(12692), 1,
      sym__simple_type,
    STATE(13932), 1,
      sym__proper_tuple_type,
    STATE(17202), 1,
      sym_extended_module_path,
    STATE(18439), 1,
      sym_labeled_tuple_element_type,
    STATE(18937), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407568] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8816), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17328), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407651] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8817), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17463), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407734] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8818), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17246), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407817] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8819), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17407), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407900] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8820), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18194), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [407983] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8821), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17429), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408066] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8822), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18277), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408149] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8823), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17289), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408232] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10882), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [408283] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8825), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17602), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408366] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8826), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17541), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408449] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8827), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15292), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408532] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10884), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [408583] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8829), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17561), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408666] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8830), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18349), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408749] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8831), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15468), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408832] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10886), 1,
      sym__lowercase_identifier,
    STATE(8832), 1,
      sym_attribute,
    STATE(13384), 1,
      sym__simple_type,
    STATE(14035), 1,
      sym__proper_tuple_type,
    STATE(14140), 1,
      sym__type,
    STATE(17607), 1,
      sym_extended_module_path,
    STATE(18678), 1,
      sym_labeled_tuple_element_type,
    STATE(18862), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408915] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8833), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17654), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [408998] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8834), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17358), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409081] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8835), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17364), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409164] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8836), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17683), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409247] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8837), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17375), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409330] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10888), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(8838), 1,
      sym_attribute,
    STATE(9619), 1,
      sym__simple_type,
    STATE(11261), 1,
      sym__proper_tuple_type,
    STATE(17263), 1,
      sym_extended_module_path,
    STATE(18511), 1,
      sym_labeled_tuple_element_type,
    STATE(19100), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409413] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8839), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17786), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409496] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8840), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17808), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409579] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10890), 1,
      sym__lowercase_identifier,
    STATE(8841), 1,
      sym_attribute,
    STATE(10755), 1,
      sym__simple_type,
    STATE(10820), 1,
      sym__type,
    STATE(12610), 1,
      sym__proper_tuple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19663), 1,
      sym_labeled_tuple_element_type,
    STATE(20689), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409662] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    STATE(8842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [409711] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8843), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17955), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409794] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8844), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17888), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [409877] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [409944] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8846), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17902), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410027] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10908), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(8847), 1,
      sym_attribute,
    STATE(10965), 1,
      sym__simple_type,
    STATE(13317), 1,
      sym__proper_tuple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20077), 1,
      sym_labeled_tuple_element_type,
    STATE(20590), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410110] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [410179] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8849), 1,
      sym_attribute,
    STATE(13785), 1,
      sym__simple_type,
    STATE(14773), 1,
      sym__proper_tuple_type,
    STATE(15704), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(19147), 1,
      sym_labeled_tuple_element_type,
    STATE(20887), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410262] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8850), 1,
      sym_attribute,
    STATE(13785), 1,
      sym__simple_type,
    STATE(14773), 1,
      sym__proper_tuple_type,
    STATE(15705), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(19147), 1,
      sym_labeled_tuple_element_type,
    STATE(20887), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410345] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8851), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17996), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410428] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(10910), 1,
      sym__lowercase_identifier,
    STATE(8852), 1,
      sym_attribute,
    STATE(9368), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410511] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8853), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18013), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410594] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8854), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18289), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [410677] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [410734] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10896), 1,
      sym_pow_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [410785] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10896), 1,
      sym_pow_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [410836] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [410895] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [410954] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8860), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18161), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411037] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [411100] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [411165] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8863), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18171), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411248] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8864), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18024), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411331] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10886), 1,
      sym__lowercase_identifier,
    STATE(8865), 1,
      sym_attribute,
    STATE(13384), 1,
      sym__simple_type,
    STATE(14035), 1,
      sym__proper_tuple_type,
    STATE(14082), 1,
      sym__type,
    STATE(17607), 1,
      sym_extended_module_path,
    STATE(18678), 1,
      sym_labeled_tuple_element_type,
    STATE(18862), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411414] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10890), 1,
      sym__lowercase_identifier,
    STATE(8866), 1,
      sym_attribute,
    STATE(10755), 1,
      sym__simple_type,
    STATE(10821), 1,
      sym__type,
    STATE(12610), 1,
      sym__proper_tuple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19663), 1,
      sym_labeled_tuple_element_type,
    STATE(20689), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411497] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8867), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18221), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411580] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8868), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18233), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411663] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10912), 1,
      anon_sym_PIPE,
    STATE(8869), 1,
      sym_attribute,
    STATE(8879), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [411714] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [411783] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10890), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(8871), 1,
      sym_attribute,
    STATE(10755), 1,
      sym__simple_type,
    STATE(12610), 1,
      sym__proper_tuple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19663), 1,
      sym_labeled_tuple_element_type,
    STATE(20689), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411866] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8872), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18318), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [411949] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8873), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18335), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412032] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [412085] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8875), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18350), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412168] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8876), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18405), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412251] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10912), 1,
      anon_sym_PIPE,
    STATE(8877), 1,
      sym_attribute,
    STATE(8879), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [412302] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8878), 1,
      sym_attribute,
    STATE(10820), 1,
      sym__type,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412385] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10918), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8879), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [412434] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10880), 1,
      sym__lowercase_identifier,
    STATE(8880), 1,
      sym_attribute,
    STATE(12692), 1,
      sym__simple_type,
    STATE(13676), 1,
      sym__type,
    STATE(13932), 1,
      sym__proper_tuple_type,
    STATE(17202), 1,
      sym_extended_module_path,
    STATE(18439), 1,
      sym_labeled_tuple_element_type,
    STATE(18937), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412517] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8881), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18413), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412600] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8882), 1,
      sym_attribute,
    STATE(10821), 1,
      sym__type,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412683] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [412752] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8884), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17496), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412835] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8885), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17986), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [412918] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8886), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18342), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413001] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    ACTIONS(10921), 1,
      anon_sym_SEMI,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [413072] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8888), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18379), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413155] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8889), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17677), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413238] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8890), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17855), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413321] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8328), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [413368] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(10923), 1,
      sym__lowercase_identifier,
    STATE(8892), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413451] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8893), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(13676), 1,
      sym__type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413534] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    ACTIONS(10925), 1,
      anon_sym_SEMI,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [413605] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [413654] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8896), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17264), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413737] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8897), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17325), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413820] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10888), 1,
      sym__lowercase_identifier,
    STATE(8898), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9619), 1,
      sym__simple_type,
    STATE(11261), 1,
      sym__proper_tuple_type,
    STATE(17263), 1,
      sym_extended_module_path,
    STATE(18511), 1,
      sym_labeled_tuple_element_type,
    STATE(19100), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [413903] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10912), 1,
      anon_sym_PIPE,
    STATE(8869), 1,
      aux_sym__match_cases_repeat1,
    STATE(8899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [413954] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8900), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13600), 1,
      sym__type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414037] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8901), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(14729), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414120] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8902), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17562), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414203] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8903), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17635), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414286] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8904), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17459), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414369] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10333), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [414438] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8906), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17491), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414521] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8907), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17927), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414604] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8908), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17992), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414687] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10333), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [414756] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10912), 1,
      anon_sym_PIPE,
    STATE(8877), 1,
      aux_sym__match_cases_repeat1,
    STATE(8910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [414807] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8911), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18330), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [414890] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    ACTIONS(10921), 1,
      anon_sym_SEMI,
    STATE(2439), 1,
      sym_add_operator,
    STATE(8912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [414961] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8913), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18359), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415044] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10927), 1,
      sym__lowercase_identifier,
    STATE(8914), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(13673), 1,
      sym__simple_type,
    STATE(14320), 1,
      sym__proper_tuple_type,
    STATE(17664), 1,
      sym_extended_module_path,
    STATE(21166), 1,
      sym_labeled_tuple_element_type,
    STATE(21321), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415127] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8915), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17497), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415210] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8916), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17219), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415293] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10888), 1,
      sym__lowercase_identifier,
    STATE(8917), 1,
      sym_attribute,
    STATE(9368), 1,
      sym__type,
    STATE(9619), 1,
      sym__simple_type,
    STATE(11261), 1,
      sym__proper_tuple_type,
    STATE(17263), 1,
      sym_extended_module_path,
    STATE(18511), 1,
      sym_labeled_tuple_element_type,
    STATE(19100), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415376] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8918), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17230), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415459] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8919), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17320), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415542] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8920), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17331), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415625] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8921), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18352), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415708] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8922), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17414), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415791] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8923), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17889), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415874] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8924), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17423), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [415957] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8302), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [416006] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    ACTIONS(10925), 1,
      anon_sym_SEMI,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [416077] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8927), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17498), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416160] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8928), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17516), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416243] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    ACTIONS(10878), 1,
      sym_assign_operator,
    ACTIONS(10925), 1,
      anon_sym_SEMI,
    STATE(2373), 1,
      sym_add_operator,
    STATE(8929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [416314] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8930), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17597), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416397] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8931), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17610), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416480] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8932), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17519), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416563] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8933), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17684), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416646] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10880), 1,
      sym__lowercase_identifier,
    STATE(8934), 1,
      sym_attribute,
    STATE(10821), 1,
      sym__type,
    STATE(12692), 1,
      sym__simple_type,
    STATE(13932), 1,
      sym__proper_tuple_type,
    STATE(17202), 1,
      sym_extended_module_path,
    STATE(18439), 1,
      sym_labeled_tuple_element_type,
    STATE(18937), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416729] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8935), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17700), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416812] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8936), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17778), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416895] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8937), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13596), 1,
      sym__type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [416978] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(10910), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(8938), 1,
      sym_attribute,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417061] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8939), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17803), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417144] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10929), 1,
      anon_sym_COLON,
    STATE(8940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 15,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
    ACTIONS(9546), 16,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
  [417193] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8941), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17914), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417276] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8942), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17934), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417359] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8943), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13606), 1,
      sym__type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417442] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8944), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15568), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417525] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    STATE(8945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [417574] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8946), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18314), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417657] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8947), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18348), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417740] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10931), 1,
      anon_sym_PIPE,
    STATE(8948), 1,
      sym_attribute,
    STATE(8952), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [417791] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8949), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18241), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [417874] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10931), 1,
      anon_sym_PIPE,
    STATE(8950), 1,
      sym_attribute,
    STATE(8952), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [417925] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8951), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15412), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418008] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10933), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8952), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [418057] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8953), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18364), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418140] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8954), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18392), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418223] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8955), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18394), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418306] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8956), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18402), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418389] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8957), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13609), 1,
      sym__type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418472] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    ACTIONS(10936), 1,
      anon_sym_SEMI,
    STATE(2263), 1,
      sym_add_operator,
    STATE(8958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [418543] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8959), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15201), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418626] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8960), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17270), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418709] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(8961), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418792] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8962), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15477), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [418875] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8336), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [418922] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8964), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17293), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419005] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8965), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17304), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419088] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8966), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17305), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419171] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8967), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17308), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419254] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8968), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15782), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419337] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10938), 1,
      sym__lowercase_identifier,
    STATE(8969), 1,
      sym_attribute,
    STATE(9308), 1,
      sym__simple_type,
    STATE(9311), 1,
      sym__type,
    STATE(10924), 1,
      sym__proper_tuple_type,
    STATE(18259), 1,
      sym_extended_module_path,
    STATE(20815), 1,
      sym_labeled_tuple_element_type,
    STATE(21196), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419420] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8970), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17340), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419503] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8971), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15504), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419586] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8972), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17361), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419669] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(10910), 1,
      sym__lowercase_identifier,
    STATE(8973), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9653), 1,
      sym__simple_type,
    STATE(11565), 1,
      sym__proper_tuple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18548), 1,
      sym_labeled_tuple_element_type,
    STATE(18677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419752] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8974), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17368), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419835] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8975), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17369), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [419918] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8976), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17371), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420001] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8977), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17746), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420084] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8978), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17399), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420167] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8979), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15524), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420250] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8980), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17438), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420333] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8981), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15541), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420416] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8982), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17472), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420499] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10723), 1,
      sym_assign_operator,
    ACTIONS(10940), 1,
      anon_sym_SEMI,
    STATE(1931), 1,
      sym_add_operator,
    STATE(8983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [420570] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8984), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17504), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420653] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8985), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17525), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420736] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8986), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18249), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420819] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10880), 1,
      sym__lowercase_identifier,
    STATE(8987), 1,
      sym_attribute,
    STATE(12692), 1,
      sym__simple_type,
    STATE(13622), 1,
      sym__type,
    STATE(13932), 1,
      sym__proper_tuple_type,
    STATE(17202), 1,
      sym_extended_module_path,
    STATE(18439), 1,
      sym_labeled_tuple_element_type,
    STATE(18937), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420902] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10858), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(8988), 1,
      sym_attribute,
    STATE(9297), 1,
      sym__simple_type,
    STATE(10726), 1,
      sym__proper_tuple_type,
    STATE(17493), 1,
      sym_extended_module_path,
    STATE(18623), 1,
      sym_labeled_tuple_element_type,
    STATE(19404), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [420985] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8989), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17548), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421068] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10886), 1,
      sym__lowercase_identifier,
    STATE(8990), 1,
      sym_attribute,
    STATE(13384), 1,
      sym__simple_type,
    STATE(13729), 1,
      sym__type,
    STATE(14035), 1,
      sym__proper_tuple_type,
    STATE(17607), 1,
      sym_extended_module_path,
    STATE(18678), 1,
      sym_labeled_tuple_element_type,
    STATE(18862), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421151] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10908), 1,
      sym__lowercase_identifier,
    STATE(8991), 1,
      sym_attribute,
    STATE(10820), 1,
      sym__type,
    STATE(10965), 1,
      sym__simple_type,
    STATE(13317), 1,
      sym__proper_tuple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20077), 1,
      sym_labeled_tuple_element_type,
    STATE(20590), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421234] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10908), 1,
      sym__lowercase_identifier,
    STATE(8992), 1,
      sym_attribute,
    STATE(10821), 1,
      sym__type,
    STATE(10965), 1,
      sym__simple_type,
    STATE(13317), 1,
      sym__proper_tuple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20077), 1,
      sym_labeled_tuple_element_type,
    STATE(20590), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421317] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(8993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [421368] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8994), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17776), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421451] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10884), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(8995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [421502] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(8996), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18375), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421585] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10944), 1,
      sym__lowercase_identifier,
    STATE(8997), 1,
      sym_attribute,
    STATE(9289), 1,
      sym__simple_type,
    STATE(9311), 1,
      sym__type,
    STATE(10690), 1,
      sym__proper_tuple_type,
    STATE(17378), 1,
      sym_extended_module_path,
    STATE(18568), 1,
      sym_labeled_tuple_element_type,
    STATE(20677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421668] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(8998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8302), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [421717] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(10946), 1,
      sym__lowercase_identifier,
    STATE(8999), 1,
      sym_attribute,
    STATE(9368), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421800] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9000), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17394), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [421883] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10723), 1,
      sym_assign_operator,
    ACTIONS(10940), 1,
      anon_sym_SEMI,
    STATE(1931), 1,
      sym_add_operator,
    STATE(9001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [421954] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(10923), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9002), 1,
      sym_attribute,
    STATE(9493), 1,
      sym__simple_type,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422037] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10944), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9003), 1,
      sym_attribute,
    STATE(9289), 1,
      sym__simple_type,
    STATE(10690), 1,
      sym__proper_tuple_type,
    STATE(17378), 1,
      sym_extended_module_path,
    STATE(18568), 1,
      sym_labeled_tuple_element_type,
    STATE(20677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422120] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10948), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(9004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [422171] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    STATE(2263), 1,
      sym_add_operator,
    STATE(9005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [422240] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10927), 1,
      sym__lowercase_identifier,
    STATE(9006), 1,
      sym_attribute,
    STATE(9368), 1,
      sym__type,
    STATE(13673), 1,
      sym__simple_type,
    STATE(14320), 1,
      sym__proper_tuple_type,
    STATE(17664), 1,
      sym_extended_module_path,
    STATE(21166), 1,
      sym_labeled_tuple_element_type,
    STATE(21321), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422323] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9007), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17453), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422406] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(9008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8302), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422455] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9009), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17722), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422538] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10931), 1,
      anon_sym_PIPE,
    STATE(8948), 1,
      aux_sym__match_cases_repeat1,
    STATE(9010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [422589] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9011), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18138), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422672] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10944), 1,
      sym__lowercase_identifier,
    STATE(9012), 1,
      sym_attribute,
    STATE(9289), 1,
      sym__simple_type,
    STATE(9368), 1,
      sym__type,
    STATE(10690), 1,
      sym__proper_tuple_type,
    STATE(17378), 1,
      sym_extended_module_path,
    STATE(18568), 1,
      sym_labeled_tuple_element_type,
    STATE(20677), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422755] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10931), 1,
      anon_sym_PIPE,
    STATE(8950), 1,
      aux_sym__match_cases_repeat1,
    STATE(9013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [422806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8206), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [422853] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9015), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18163), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [422936] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(10923), 1,
      sym__lowercase_identifier,
    STATE(9016), 1,
      sym_attribute,
    STATE(9368), 1,
      sym__type,
    STATE(9493), 1,
      sym__simple_type,
    STATE(11387), 1,
      sym__proper_tuple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18633), 1,
      sym_labeled_argument_type,
    STATE(19546), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423019] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10880), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9017), 1,
      sym_attribute,
    STATE(12692), 1,
      sym__simple_type,
    STATE(13932), 1,
      sym__proper_tuple_type,
    STATE(17202), 1,
      sym_extended_module_path,
    STATE(18439), 1,
      sym_labeled_tuple_element_type,
    STATE(18937), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423102] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9018), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17332), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423185] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10938), 1,
      sym__lowercase_identifier,
    STATE(9019), 1,
      sym_attribute,
    STATE(9308), 1,
      sym__simple_type,
    STATE(9368), 1,
      sym__type,
    STATE(10924), 1,
      sym__proper_tuple_type,
    STATE(18259), 1,
      sym_extended_module_path,
    STATE(20815), 1,
      sym_labeled_tuple_element_type,
    STATE(21196), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423268] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10882), 1,
      anon_sym_else,
    STATE(8510), 1,
      sym_else_clause,
    STATE(9020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [423319] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9021), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(15079), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423402] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9022), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18391), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423485] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9023), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(16511), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423568] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9024), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(16516), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423651] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10952), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9025), 1,
      sym_attribute,
    STATE(9275), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10950), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [423708] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    ACTIONS(10870), 1,
      sym_rel_operator,
    ACTIONS(10872), 1,
      sym_and_operator,
    ACTIONS(10874), 1,
      sym_or_operator,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    STATE(2373), 1,
      sym_add_operator,
    STATE(9026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [423775] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 10,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8364), 22,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [423822] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10927), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9028), 1,
      sym_attribute,
    STATE(13673), 1,
      sym__simple_type,
    STATE(14320), 1,
      sym__proper_tuple_type,
    STATE(17664), 1,
      sym_extended_module_path,
    STATE(21166), 1,
      sym_labeled_tuple_element_type,
    STATE(21321), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423905] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9029), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [423988] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9030), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17824), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424071] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9031), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17194), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424154] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2263), 1,
      sym_add_operator,
    STATE(9032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [424203] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(10860), 1,
      sym__lowercase_identifier,
    STATE(9033), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424286] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(10946), 1,
      sym__lowercase_identifier,
    STATE(9034), 1,
      sym_attribute,
    STATE(9311), 1,
      sym__type,
    STATE(10143), 1,
      sym__simple_type,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424369] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(9035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [424426] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9036), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(17941), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424509] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    ACTIONS(10936), 1,
      anon_sym_SEMI,
    STATE(2263), 1,
      sym_add_operator,
    STATE(9037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [424580] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10948), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(9038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [424631] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(9039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8302), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [424680] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10864), 1,
      sym_pow_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(9040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [424731] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9041), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18292), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [424814] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    ACTIONS(10894), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10896), 1,
      sym_pow_operator,
    ACTIONS(10898), 1,
      sym_mult_operator,
    ACTIONS(10900), 1,
      sym_concat_operator,
    ACTIONS(10902), 1,
      sym_rel_operator,
    ACTIONS(10904), 1,
      sym_and_operator,
    ACTIONS(10906), 1,
      sym_or_operator,
    ACTIONS(10914), 1,
      sym_assign_operator,
    ACTIONS(10936), 1,
      anon_sym_SEMI,
    STATE(2263), 1,
      sym_add_operator,
    STATE(9042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [424885] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10864), 1,
      sym_pow_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(9043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [424936] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10938), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9044), 1,
      sym_attribute,
    STATE(9308), 1,
      sym__simple_type,
    STATE(10924), 1,
      sym__proper_tuple_type,
    STATE(18259), 1,
      sym_extended_module_path,
    STATE(20815), 1,
      sym_labeled_tuple_element_type,
    STATE(21196), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425019] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(9045), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(13622), 1,
      sym__type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425102] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8206), 29,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [425149] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(9047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [425208] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10858), 1,
      sym__lowercase_identifier,
    STATE(9048), 1,
      sym_attribute,
    STATE(9297), 1,
      sym__simple_type,
    STATE(9311), 1,
      sym__type,
    STATE(10726), 1,
      sym__proper_tuple_type,
    STATE(17493), 1,
      sym_extended_module_path,
    STATE(18623), 1,
      sym_labeled_tuple_element_type,
    STATE(19404), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425291] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9049), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18311), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425374] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10567), 1,
      sym_pow_operator,
    ACTIONS(10569), 1,
      sym_mult_operator,
    ACTIONS(10571), 1,
      sym_concat_operator,
    ACTIONS(10573), 1,
      sym_rel_operator,
    ACTIONS(10575), 1,
      sym_and_operator,
    ACTIONS(10577), 1,
      sym_or_operator,
    ACTIONS(10723), 1,
      sym_assign_operator,
    ACTIONS(10940), 1,
      anon_sym_SEMI,
    STATE(1931), 1,
      sym_add_operator,
    STATE(9050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [425445] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(9051), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13587), 1,
      sym__type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425528] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10862), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10864), 1,
      sym_pow_operator,
    ACTIONS(10866), 1,
      sym_mult_operator,
    ACTIONS(10868), 1,
      sym_concat_operator,
    STATE(2373), 1,
      sym_add_operator,
    STATE(9052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [425587] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(10860), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9053), 1,
      sym_attribute,
    STATE(9832), 1,
      sym__simple_type,
    STATE(11719), 1,
      sym__proper_tuple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20015), 1,
      sym_labeled_argument_type,
    STATE(20888), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425670] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9054), 1,
      sym_attribute,
    STATE(13785), 1,
      sym__simple_type,
    STATE(14773), 1,
      sym__proper_tuple_type,
    STATE(15428), 1,
      sym__type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(19147), 1,
      sym_labeled_tuple_element_type,
    STATE(20887), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13799), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425753] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10916), 1,
      sym__lowercase_identifier,
    STATE(9055), 1,
      sym_attribute,
    STATE(11707), 1,
      sym__simple_type,
    STATE(13588), 1,
      sym__type,
    STATE(13616), 1,
      sym__proper_tuple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    STATE(20385), 1,
      sym_labeled_tuple_element_type,
    STATE(21370), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425836] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10942), 1,
      anon_sym_else,
    STATE(8462), 1,
      sym_else_clause,
    STATE(9056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [425887] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(9578), 1,
      sym__lowercase_identifier,
    STATE(9057), 1,
      sym_attribute,
    STATE(13023), 1,
      sym__simple_type,
    STATE(13994), 1,
      sym__proper_tuple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    STATE(18340), 1,
      sym__type,
    STATE(18959), 1,
      sym_labeled_tuple_element_type,
    STATE(19510), 1,
      sym_labeled_argument_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [425970] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    ACTIONS(10539), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10541), 1,
      sym_pow_operator,
    ACTIONS(10543), 1,
      sym_mult_operator,
    ACTIONS(10545), 1,
      sym_concat_operator,
    ACTIONS(10547), 1,
      sym_rel_operator,
    ACTIONS(10549), 1,
      sym_and_operator,
    ACTIONS(10551), 1,
      sym_or_operator,
    ACTIONS(10553), 1,
      sym_assign_operator,
    ACTIONS(10921), 1,
      anon_sym_SEMI,
    STATE(2439), 1,
      sym_add_operator,
    STATE(9058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [426041] = 23,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(10946), 1,
      sym__lowercase_identifier,
    STATE(8534), 1,
      sym__type,
    STATE(9059), 1,
      sym_attribute,
    STATE(10143), 1,
      sym__simple_type,
    STATE(12352), 1,
      sym__proper_tuple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19620), 1,
      sym_labeled_argument_type,
    STATE(19907), 1,
      sym_labeled_tuple_element_type,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8550), 3,
      sym_function_type,
      sym__labeled_tuple_type,
      sym_aliased_type,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [426124] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 11,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9030), 20,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [426170] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10954), 1,
      anon_sym_PIPE,
    STATE(9061), 1,
      sym_attribute,
    STATE(9103), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8282), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426266] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8336), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8344), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426408] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10960), 1,
      anon_sym_SEMI,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [426478] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10980), 1,
      anon_sym_SEMI,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [426548] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426610] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10954), 1,
      anon_sym_PIPE,
    STATE(9069), 1,
      sym_attribute,
    STATE(9150), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426660] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10996), 1,
      anon_sym_PIPE,
    STATE(9070), 1,
      sym_attribute,
    STATE(9120), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9046), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9608), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9610), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [426802] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426860] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426918] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [426980] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8070), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427090] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [427158] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8328), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9184), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427306] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8074), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427416] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10964), 1,
      sym_pow_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427466] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427532] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10233), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [427600] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427652] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [427720] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10998), 1,
      anon_sym_COLON,
    STATE(9089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9036), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9038), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9060), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427814] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9091), 1,
      sym_attribute,
    STATE(9275), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10780), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10776), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [427870] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [427926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9698), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [427972] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9736), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428018] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9095), 1,
      sym_attribute,
    STATE(9275), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10952), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10950), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [428074] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9740), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9028), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428166] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11004), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8304), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [428212] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8316), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428258] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9546), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9548), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428304] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9204), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428350] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10984), 1,
      sym_mult_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428402] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10954), 1,
      anon_sym_PIPE,
    STATE(9103), 1,
      sym_attribute,
    STATE(9164), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428452] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8332), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428498] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10133), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10131), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [428564] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8354), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428610] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9596), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9598), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428656] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9602), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6793), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(6787), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428748] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8340), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428794] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9702), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428840] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10960), 1,
      anon_sym_SEMI,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [428910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8282), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [428956] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8336), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429002] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8358), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8344), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429094] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10261), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [429162] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8074), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9124), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429254] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10996), 1,
      anon_sym_PIPE,
    STATE(9120), 1,
      sym_attribute,
    STATE(9123), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429304] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(9121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8302), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [429352] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8206), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429398] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11006), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9123), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429446] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10980), 1,
      anon_sym_SEMI,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [429516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8312), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429562] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429610] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8320), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9224), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429750] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(9130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8302), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [429798] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8328), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [429844] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10964), 1,
      sym_pow_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [429894] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [429962] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [430020] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10960), 1,
      anon_sym_SEMI,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10327), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9818), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9820), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430136] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [430194] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9826), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9828), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11009), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8360), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [430286] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8354), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9620), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9760), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430424] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9726), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9728), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430470] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9624), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9628), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8324), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430608] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9636), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9652), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430700] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8358), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430746] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10954), 1,
      anon_sym_PIPE,
    STATE(9150), 1,
      sym_attribute,
    STATE(9164), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [430796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9686), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430842] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    STATE(9152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [430890] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9640), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9028), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [430982] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9644), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431028] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11015), 1,
      anon_sym_DOT,
    STATE(9156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11013), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11011), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431076] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9092), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9096), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431168] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 4,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10271), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431236] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9024), 11,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9022), 20,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [431282] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11017), 1,
      anon_sym_DOT_DOT,
    STATE(9161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4669), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(4667), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431330] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10996), 1,
      anon_sym_PIPE,
    STATE(9162), 1,
      sym_attribute,
    STATE(9184), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [431380] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11019), 29,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [431426] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11023), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9164), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [431474] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9654), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9656), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431520] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9690), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9682), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431612] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8070), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8332), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9666), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431750] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8308), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431796] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8364), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8206), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9730), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9732), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8290), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [431980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9046), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432026] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9674), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432072] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [432122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9694), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9604), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9606), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8340), 21,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432260] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9632), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9770), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(9772), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432352] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10996), 1,
      anon_sym_PIPE,
    STATE(9123), 1,
      aux_sym__match_cases_repeat1,
    STATE(9184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 9,
      anon_sym_let,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [432402] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8294), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432448] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8022), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432494] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 11,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9050), 20,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [432540] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    STATE(9188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [432588] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10980), 1,
      anon_sym_SEMI,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 15,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_begin,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__lowercase_identifier,
    ACTIONS(8298), 16,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 11,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8364), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432750] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8308), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432795] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9096), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9124), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11013), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11011), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [432930] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7915), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [432975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9136), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9138), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433020] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    STATE(9198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [433067] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11028), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11026), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433112] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11032), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11030), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433157] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9214), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9216), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433202] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    ACTIONS(11034), 1,
      anon_sym_SEMI,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433271] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9092), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9114), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9116), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433361] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7685), 1,
      anon_sym_COMMA,
    STATE(9205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9112), 19,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9078), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9080), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9140), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9142), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433498] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9218), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9220), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433543] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9186), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9188), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433588] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9082), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9084), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433633] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11038), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11036), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9194), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9196), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433723] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    ACTIONS(11040), 1,
      anon_sym_SEMI,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433792] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8320), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [433837] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11044), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11042), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [433882] = 21,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11046), 1,
      anon_sym_type,
    ACTIONS(11048), 1,
      anon_sym_exception,
    ACTIONS(11050), 1,
      anon_sym_module,
    ACTIONS(11052), 1,
      anon_sym_include,
    ACTIONS(11054), 1,
      anon_sym_class,
    ACTIONS(11056), 1,
      anon_sym_val,
    ACTIONS(11058), 1,
      anon_sym_end,
    STATE(9216), 1,
      sym_attribute,
    STATE(9293), 1,
      aux_sym__signature_repeat1,
    STATE(9367), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    STATE(19986), 1,
      sym__signature,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [433959] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9060), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434004] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11062), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11060), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [434049] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9118), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9120), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9146), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9148), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8286), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434184] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7685), 1,
      anon_sym_COMMA,
    ACTIONS(7691), 1,
      anon_sym_COLON_COLON,
    STATE(9222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9112), 18,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9070), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9072), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434278] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8312), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11066), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11064), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [434368] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4669), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(4667), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9174), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9176), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9178), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9180), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434503] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11070), 1,
      sym_hash_operator,
    STATE(9229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9790), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9788), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [434554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9128), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9130), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9198), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9200), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434644] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9170), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9172), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9226), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9228), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434734] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9062), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9064), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434779] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9086), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9088), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8324), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434869] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    STATE(9237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 10,
      anon_sym_let,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_operator,
      aux_sym_directive_token1,
  [434916] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9210), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9212), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [434961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9066), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9068), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435006] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8336), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435051] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9102), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9104), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8294), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8022), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435186] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    ACTIONS(11034), 1,
      anon_sym_SEMI,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435255] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11070), 1,
      sym_hash_operator,
    STATE(9245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9816), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9814), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [435306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9236), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9238), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435351] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8316), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435396] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11070), 1,
      sym_hash_operator,
    STATE(9248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9716), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [435447] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9204), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435492] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11074), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11072), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435537] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9240), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9242), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435582] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11070), 1,
      sym_hash_operator,
    STATE(9252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9800), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9798), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [435633] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8364), 27,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435678] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9150), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9152), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435723] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8290), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11078), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11076), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435813] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9106), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9108), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9230), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9232), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [435903] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    ACTIONS(11040), 1,
      anon_sym_SEMI,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [435972] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10956), 1,
      sym_pow_operator,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10984), 1,
      sym_mult_operator,
    ACTIONS(10986), 1,
      sym_concat_operator,
    ACTIONS(10988), 1,
      sym_rel_operator,
    ACTIONS(10990), 1,
      sym_and_operator,
    ACTIONS(10992), 1,
      sym_or_operator,
    ACTIONS(10994), 1,
      sym_assign_operator,
    ACTIONS(11034), 1,
      anon_sym_SEMI,
    STATE(1972), 1,
      sym_add_operator,
    STATE(9260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436041] = 21,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11046), 1,
      anon_sym_type,
    ACTIONS(11048), 1,
      anon_sym_exception,
    ACTIONS(11050), 1,
      anon_sym_module,
    ACTIONS(11052), 1,
      anon_sym_include,
    ACTIONS(11054), 1,
      anon_sym_class,
    ACTIONS(11056), 1,
      anon_sym_val,
    ACTIONS(11080), 1,
      anon_sym_end,
    STATE(9261), 1,
      sym_attribute,
    STATE(9293), 1,
      aux_sym__signature_repeat1,
    STATE(9367), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    STATE(20438), 1,
      sym__signature,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [436118] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9224), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9154), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9156), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8298), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436253] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9074), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9076), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436298] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9110), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9112), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9134), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436388] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7691), 1,
      anon_sym_COLON_COLON,
    STATE(9268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9158), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9160), 19,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436435] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11070), 1,
      sym_hash_operator,
    STATE(9269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9812), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9810), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [436486] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9164), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9166), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11084), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11082), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436576] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9098), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9100), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9184), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436666] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9206), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9208), 20,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436711] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11088), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11086), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11092), 5,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11090), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436801] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    ACTIONS(10962), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10964), 1,
      sym_pow_operator,
    ACTIONS(10966), 1,
      sym_mult_operator,
    ACTIONS(10968), 1,
      sym_concat_operator,
    ACTIONS(10970), 1,
      sym_rel_operator,
    ACTIONS(10972), 1,
      sym_and_operator,
    ACTIONS(10974), 1,
      sym_or_operator,
    ACTIONS(10976), 1,
      sym_assign_operator,
    ACTIONS(11040), 1,
      anon_sym_SEMI,
    STATE(1893), 1,
      sym_add_operator,
    STATE(9277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436870] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7685), 1,
      anon_sym_COMMA,
    ACTIONS(7687), 1,
      anon_sym_PIPE,
    ACTIONS(7691), 1,
      anon_sym_COLON_COLON,
    STATE(9278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9132), 10,
      anon_sym_and,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9134), 17,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_and_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [436921] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11096), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9279), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10811), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11094), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [436981] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11100), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9280), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11155), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11098), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437041] = 20,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11102), 1,
      ts_builtin_sym_end,
    STATE(9281), 1,
      sym_attribute,
    STATE(9287), 1,
      aux_sym__signature_repeat1,
    STATE(9344), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437115] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11104), 1,
      sym__lowercase_identifier,
    ACTIONS(11110), 1,
      anon_sym_POUND,
    STATE(9282), 1,
      sym_attribute,
    STATE(9455), 1,
      sym_type_constructor_path,
    STATE(18423), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [437169] = 20,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11102), 1,
      anon_sym_RBRACK,
    ACTIONS(11112), 1,
      anon_sym_exception,
    STATE(9283), 1,
      sym_attribute,
    STATE(9284), 1,
      aux_sym__signature_repeat1,
    STATE(9379), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437243] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11114), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11117), 1,
      anon_sym_external,
    ACTIONS(11120), 1,
      anon_sym_type,
    ACTIONS(11123), 1,
      anon_sym_RBRACK,
    ACTIONS(11125), 1,
      anon_sym_exception,
    ACTIONS(11128), 1,
      anon_sym_module,
    ACTIONS(11131), 1,
      anon_sym_open,
    ACTIONS(11134), 1,
      anon_sym_include,
    ACTIONS(11137), 1,
      anon_sym_class,
    ACTIONS(11140), 1,
      anon_sym_val,
    ACTIONS(11143), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(11146), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(11149), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    STATE(9625), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9284), 2,
      sym_attribute,
      aux_sym__signature_repeat1,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437315] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11154), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9285), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11161), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11152), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437375] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11156), 1,
      sym__lowercase_identifier,
    ACTIONS(11162), 1,
      anon_sym_STAR,
    ACTIONS(11164), 1,
      anon_sym_POUND,
    STATE(9286), 1,
      sym_attribute,
    STATE(9405), 1,
      sym_type_constructor_path,
    STATE(17878), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11160), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [437431] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11114), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11117), 1,
      anon_sym_external,
    ACTIONS(11120), 1,
      anon_sym_type,
    ACTIONS(11123), 1,
      ts_builtin_sym_end,
    ACTIONS(11128), 1,
      anon_sym_module,
    ACTIONS(11131), 1,
      anon_sym_open,
    ACTIONS(11134), 1,
      anon_sym_include,
    ACTIONS(11137), 1,
      anon_sym_class,
    ACTIONS(11140), 1,
      anon_sym_val,
    ACTIONS(11143), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(11146), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(11149), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11166), 1,
      anon_sym_exception,
    STATE(9602), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9287), 2,
      sym_attribute,
      aux_sym__signature_repeat1,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437503] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11096), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9288), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10898), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11094), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437563] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11156), 1,
      sym__lowercase_identifier,
    ACTIONS(11164), 1,
      anon_sym_POUND,
    ACTIONS(11169), 1,
      anon_sym_DASH_GT,
    ACTIONS(11171), 1,
      anon_sym_STAR,
    STATE(9289), 1,
      sym_attribute,
    STATE(9405), 1,
      sym_type_constructor_path,
    STATE(17878), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10383), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [437621] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11114), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11117), 1,
      anon_sym_external,
    ACTIONS(11123), 1,
      anon_sym_end,
    ACTIONS(11131), 1,
      anon_sym_open,
    ACTIONS(11143), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(11146), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(11149), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11173), 1,
      anon_sym_type,
    ACTIONS(11176), 1,
      anon_sym_exception,
    ACTIONS(11179), 1,
      anon_sym_module,
    ACTIONS(11182), 1,
      anon_sym_include,
    ACTIONS(11185), 1,
      anon_sym_class,
    ACTIONS(11188), 1,
      anon_sym_val,
    STATE(9478), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9290), 2,
      sym_attribute,
      aux_sym__signature_repeat1,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437693] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11104), 1,
      sym__lowercase_identifier,
    ACTIONS(11191), 1,
      anon_sym_STAR,
    ACTIONS(11193), 1,
      anon_sym_POUND,
    STATE(9291), 1,
      sym_attribute,
    STATE(9447), 1,
      sym_type_constructor_path,
    STATE(18423), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11160), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [437749] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11100), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9292), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11152), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11098), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437809] = 20,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11046), 1,
      anon_sym_type,
    ACTIONS(11048), 1,
      anon_sym_exception,
    ACTIONS(11050), 1,
      anon_sym_module,
    ACTIONS(11052), 1,
      anon_sym_include,
    ACTIONS(11054), 1,
      anon_sym_class,
    ACTIONS(11056), 1,
      anon_sym_val,
    ACTIONS(11102), 1,
      anon_sym_end,
    STATE(9290), 1,
      aux_sym__signature_repeat1,
    STATE(9293), 1,
      sym_attribute,
    STATE(9356), 1,
      aux_sym__structure_repeat1,
    STATE(13542), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [437883] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 13,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON2,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9184), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [437927] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11197), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9295), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10871), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11195), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [437987] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11104), 1,
      sym__lowercase_identifier,
    ACTIONS(11193), 1,
      anon_sym_POUND,
    STATE(9296), 1,
      sym_attribute,
    STATE(9447), 1,
      sym_type_constructor_path,
    STATE(18423), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11201), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [438041] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11104), 1,
      sym__lowercase_identifier,
    ACTIONS(11193), 1,
      anon_sym_POUND,
    ACTIONS(11203), 1,
      anon_sym_DASH_GT,
    ACTIONS(11205), 1,
      anon_sym_STAR,
    STATE(9297), 1,
      sym_attribute,
    STATE(9447), 1,
      sym_type_constructor_path,
    STATE(18423), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10383), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [438099] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11156), 1,
      sym__lowercase_identifier,
    ACTIONS(11207), 1,
      anon_sym_POUND,
    STATE(9298), 1,
      sym_attribute,
    STATE(9417), 1,
      sym_type_constructor_path,
    STATE(17878), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [438153] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11156), 1,
      sym__lowercase_identifier,
    ACTIONS(11164), 1,
      anon_sym_POUND,
    STATE(9299), 1,
      sym_attribute,
    STATE(9405), 1,
      sym_type_constructor_path,
    STATE(17878), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11201), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [438207] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9300), 1,
      sym_attribute,
    STATE(9965), 1,
      sym__simple_type,
    STATE(10541), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15694), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19540), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438284] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9301), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11155), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11098), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [438341] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9302), 1,
      sym_attribute,
    STATE(10209), 1,
      sym__simple_type,
    STATE(10541), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15674), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19287), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438418] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(9303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8302), 16,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [438463] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9304), 1,
      sym_attribute,
    STATE(9565), 1,
      sym__simple_type,
    STATE(9870), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15313), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(21000), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438540] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9305), 1,
      sym_attribute,
    STATE(9572), 1,
      sym__simple_type,
    STATE(9870), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15520), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(19963), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438617] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9306), 1,
      sym_attribute,
    STATE(10389), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10707), 1,
      sym_type_variable,
    STATE(15626), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18409), 1,
      sym_extended_module_path,
    STATE(18702), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [438694] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11233), 1,
      anon_sym_COLON,
    STATE(9307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10081), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10079), 17,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_then,
      anon_sym_else,
      anon_sym_do,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [438739] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11235), 1,
      sym__lowercase_identifier,
    ACTIONS(11237), 1,
      anon_sym_DASH_GT,
    ACTIONS(11239), 1,
      anon_sym_STAR,
    ACTIONS(11241), 1,
      anon_sym_POUND,
    STATE(9308), 1,
      sym_attribute,
    STATE(9819), 1,
      sym_type_constructor_path,
    STATE(17792), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [438796] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11245), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9309), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11275), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11243), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [438855] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11249), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9310), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11371), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11247), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [438914] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    STATE(9311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11253), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11251), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [438959] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(9312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [439004] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    STATE(9313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11259), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [439049] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(9314), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(14018), 1,
      sym__simple_type,
    STATE(14122), 1,
      sym_type_variable,
    STATE(15828), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(20785), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [439126] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9315), 1,
      sym_attribute,
    STATE(10582), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10754), 1,
      sym__simple_type,
    STATE(15471), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19072), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [439203] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11235), 1,
      sym__lowercase_identifier,
    ACTIONS(11241), 1,
      anon_sym_POUND,
    STATE(9316), 1,
      sym_attribute,
    STATE(9819), 1,
      sym_type_constructor_path,
    STATE(17792), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [439256] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11283), 1,
      anon_sym_POUND,
    STATE(9317), 1,
      sym_attribute,
    STATE(9907), 1,
      sym_type_constructor_path,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [439309] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11287), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11285), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [439352] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11102), 1,
      anon_sym_RBRACK,
    ACTIONS(11112), 1,
      anon_sym_exception,
    STATE(9319), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [439423] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9320), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10898), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11094), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [439480] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9321), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10871), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11195), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [439537] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11291), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11289), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [439580] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(9323), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(13999), 1,
      sym__simple_type,
    STATE(14122), 1,
      sym_type_variable,
    STATE(15811), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(20653), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [439657] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9324), 1,
      sym_attribute,
    STATE(10459), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10707), 1,
      sym_type_variable,
    STATE(15627), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18409), 1,
      sym_extended_module_path,
    STATE(18705), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [439734] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9325), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(11070), 1,
      sym__simple_type,
    STATE(11220), 1,
      sym_type_variable,
    STATE(15728), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20075), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [439811] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11235), 1,
      sym__lowercase_identifier,
    ACTIONS(11295), 1,
      anon_sym_POUND,
    STATE(9326), 1,
      sym_attribute,
    STATE(9927), 1,
      sym_type_constructor_path,
    STATE(17792), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [439864] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11102), 1,
      ts_builtin_sym_end,
    STATE(9327), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [439935] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(9328), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(14002), 1,
      sym__simple_type,
    STATE(14122), 1,
      sym_type_variable,
    STATE(15813), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(20656), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440012] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9329), 1,
      sym_attribute,
    STATE(9804), 1,
      sym__simple_type,
    STATE(9989), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15384), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17454), 1,
      sym_extended_module_path,
    STATE(20206), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440089] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9330), 1,
      sym_attribute,
    STATE(9902), 1,
      sym__simple_type,
    STATE(10266), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15462), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17243), 1,
      sym_extended_module_path,
    STATE(18840), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440166] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11331), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9331), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11823), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11329), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [440225] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9332), 1,
      sym_attribute,
    STATE(9805), 1,
      sym__simple_type,
    STATE(9989), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15386), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17454), 1,
      sym_extended_module_path,
    STATE(20683), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440302] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9333), 1,
      sym_attribute,
    STATE(9772), 1,
      sym__simple_type,
    STATE(10264), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15338), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(18689), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440379] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9334), 1,
      sym_attribute,
    STATE(10295), 1,
      sym__simple_type,
    STATE(10383), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15537), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17956), 1,
      sym_extended_module_path,
    STATE(19501), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440456] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9335), 1,
      sym_attribute,
    STATE(9774), 1,
      sym__simple_type,
    STATE(10264), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15340), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(18704), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440533] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9336), 1,
      sym_attribute,
    STATE(10582), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10729), 1,
      sym__simple_type,
    STATE(15698), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19409), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440610] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9337), 1,
      sym_attribute,
    STATE(9910), 1,
      sym__simple_type,
    STATE(10266), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15466), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17243), 1,
      sym_extended_module_path,
    STATE(19197), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440687] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [440730] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11353), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9339), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11307), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11351), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [440789] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9340), 1,
      sym_attribute,
    STATE(9484), 1,
      sym__simple_type,
    STATE(9845), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15224), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(18775), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440866] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9341), 1,
      sym_attribute,
    STATE(10448), 1,
      sym__simple_type,
    STATE(10599), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15236), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17655), 1,
      sym_extended_module_path,
    STATE(19949), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [440943] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9342), 1,
      sym_attribute,
    STATE(9485), 1,
      sym__simple_type,
    STATE(9845), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15226), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(19766), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441020] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9343), 1,
      sym_attribute,
    STATE(9916), 1,
      sym__simple_type,
    STATE(9989), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15506), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17454), 1,
      sym_extended_module_path,
    STATE(18592), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441097] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11377), 1,
      ts_builtin_sym_end,
    STATE(9344), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [441168] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9345), 1,
      sym_attribute,
    STATE(10411), 1,
      sym__simple_type,
    STATE(10599), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15241), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17655), 1,
      sym_extended_module_path,
    STATE(20640), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441245] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(11000), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11002), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11381), 1,
      anon_sym_let,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9346), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12309), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11379), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [441304] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9347), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11161), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11152), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [441361] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9348), 1,
      sym_attribute,
    STATE(10208), 1,
      sym__simple_type,
    STATE(10541), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15673), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19279), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441438] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11385), 1,
      anon_sym_POUND,
    STATE(9349), 1,
      sym_attribute,
    STATE(9736), 1,
      sym_type_constructor_path,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [441491] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9350), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10955), 1,
      sym__simple_type,
    STATE(11220), 1,
      sym_type_variable,
    STATE(15706), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(19696), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441568] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9351), 1,
      sym_attribute,
    STATE(10513), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10786), 1,
      sym_type_variable,
    STATE(15882), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18267), 1,
      sym_extended_module_path,
    STATE(21323), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441645] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9352), 1,
      sym_attribute,
    STATE(10275), 1,
      sym__simple_type,
    STATE(10383), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15513), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17956), 1,
      sym_extended_module_path,
    STATE(18961), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441722] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9353), 1,
      sym_attribute,
    STATE(10282), 1,
      sym__simple_type,
    STATE(10383), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15514), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17956), 1,
      sym_extended_module_path,
    STATE(18970), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441799] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9354), 1,
      sym_attribute,
    STATE(10468), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10707), 1,
      sym_type_variable,
    STATE(15640), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18409), 1,
      sym_extended_module_path,
    STATE(18850), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [441876] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11403), 1,
      anon_sym_COLON2,
    STATE(9355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [441921] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11046), 1,
      anon_sym_type,
    ACTIONS(11048), 1,
      anon_sym_exception,
    ACTIONS(11050), 1,
      anon_sym_module,
    ACTIONS(11052), 1,
      anon_sym_include,
    ACTIONS(11054), 1,
      anon_sym_class,
    ACTIONS(11056), 1,
      anon_sym_val,
    ACTIONS(11377), 1,
      anon_sym_end,
    STATE(9356), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [441992] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11289), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11407), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11405), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [442037] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9358), 1,
      sym_attribute,
    STATE(10540), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10786), 1,
      sym_type_variable,
    STATE(15854), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18267), 1,
      sym_extended_module_path,
    STATE(20995), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442114] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9359), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10956), 1,
      sym__simple_type,
    STATE(11220), 1,
      sym_type_variable,
    STATE(15707), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(19698), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442191] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9360), 1,
      sym_attribute,
    STATE(10582), 1,
      sym_type_variable,
    STATE(10647), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15473), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(19726), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11411), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11409), 26,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [442311] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11409), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11415), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11413), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [442356] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9363), 1,
      sym_attribute,
    STATE(9937), 1,
      sym__simple_type,
    STATE(10264), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15375), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(19923), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442433] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9364), 1,
      sym_attribute,
    STATE(10538), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10786), 1,
      sym_type_variable,
    STATE(15851), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18267), 1,
      sym_extended_module_path,
    STATE(20961), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442510] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9365), 1,
      sym_attribute,
    STATE(9510), 1,
      sym__simple_type,
    STATE(9845), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15262), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(21057), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442587] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(9366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8302), 16,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [442632] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11046), 1,
      anon_sym_type,
    ACTIONS(11048), 1,
      anon_sym_exception,
    ACTIONS(11050), 1,
      anon_sym_module,
    ACTIONS(11052), 1,
      anon_sym_include,
    ACTIONS(11054), 1,
      anon_sym_class,
    ACTIONS(11056), 1,
      anon_sym_val,
    ACTIONS(11102), 1,
      anon_sym_end,
    STATE(9367), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [442703] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    STATE(9368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11419), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11417), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [442748] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9369), 1,
      sym_attribute,
    STATE(10430), 1,
      sym__simple_type,
    STATE(10599), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15352), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17655), 1,
      sym_extended_module_path,
    STATE(19133), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442825] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9370), 1,
      sym_attribute,
    STATE(9552), 1,
      sym__simple_type,
    STATE(9870), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15767), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(20250), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [442902] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [442945] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(11427), 1,
      anon_sym_DOT,
    STATE(9372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11423), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11421), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [442992] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11235), 1,
      sym__lowercase_identifier,
    ACTIONS(11241), 1,
      anon_sym_POUND,
    ACTIONS(11429), 1,
      anon_sym_STAR,
    STATE(9373), 1,
      sym_attribute,
    STATE(9819), 1,
      sym_type_constructor_path,
    STATE(17792), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 9,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [443047] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9374), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11152), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11098), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [443104] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11431), 1,
      anon_sym_COLON2,
    STATE(9375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [443149] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(9376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [443194] = 22,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9377), 1,
      sym_attribute,
    STATE(9942), 1,
      sym__simple_type,
    STATE(10266), 1,
      sym_type_variable,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(15507), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17243), 1,
      sym_extended_module_path,
    STATE(18834), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 10,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
  [443271] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9378), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10811), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11094), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [443328] = 19,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11112), 1,
      anon_sym_exception,
    ACTIONS(11377), 1,
      anon_sym_RBRACK,
    STATE(9379), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [443399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8146), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443441] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11435), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11437), 1,
      anon_sym_GT,
    STATE(9381), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443513] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11439), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11441), 1,
      anon_sym_GT,
    STATE(9382), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443585] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11443), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11445), 1,
      anon_sym_GT,
    STATE(9383), 1,
      sym_attribute,
    STATE(14256), 1,
      sym__simple_type,
    STATE(16255), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443657] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9384), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [443715] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11457), 1,
      sym__lowercase_identifier,
    ACTIONS(11459), 1,
      anon_sym_STAR,
    ACTIONS(11461), 1,
      anon_sym_POUND,
    STATE(9385), 1,
      sym_attribute,
    STATE(10245), 1,
      sym_type_constructor_path,
    STATE(17862), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [443769] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8234), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443811] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11463), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11465), 1,
      anon_sym_GT,
    STATE(9387), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443883] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11467), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11469), 1,
      anon_sym_GT,
    STATE(9388), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [443955] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8218), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [443997] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11457), 1,
      sym__lowercase_identifier,
    ACTIONS(11471), 1,
      anon_sym_POUND,
    STATE(9390), 1,
      sym_attribute,
    STATE(9945), 1,
      sym_type_constructor_path,
    STATE(17862), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [444049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8242), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444091] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    ACTIONS(11473), 1,
      anon_sym_STAR,
    STATE(9392), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11160), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [444145] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9393), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [444203] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11457), 1,
      sym__lowercase_identifier,
    ACTIONS(11461), 1,
      anon_sym_POUND,
    STATE(9394), 1,
      sym_attribute,
    STATE(10245), 1,
      sym_type_constructor_path,
    STATE(17862), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [444255] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8246), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444339] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8250), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8254), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444423] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9399), 1,
      sym_attribute,
    STATE(10485), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444495] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7961), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444537] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9401), 1,
      sym_attribute,
    STATE(10485), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [444609] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444693] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444735] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444819] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444903] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [444945] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8258), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [444987] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8262), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445029] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8266), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445071] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7965), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445155] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11515), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11517), 1,
      anon_sym_GT,
    STATE(9415), 1,
      sym_attribute,
    STATE(14277), 1,
      sym__simple_type,
    STATE(16027), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445269] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445395] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8270), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [445437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445479] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9422), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(10983), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [445551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445593] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445635] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445677] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445761] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445803] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445845] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445929] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [445971] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9433), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11201), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [446023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446107] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446149] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446191] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9438), 1,
      sym_attribute,
    STATE(10485), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446263] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446347] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11021), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446389] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446473] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446641] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11579), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11581), 1,
      anon_sym_GT,
    STATE(9448), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446713] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446755] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446881] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11583), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11585), 1,
      anon_sym_GT,
    STATE(9453), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [446953] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [446995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447079] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447373] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447415] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9465), 1,
      sym_attribute,
    STATE(10324), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18409), 1,
      sym_extended_module_path,
    STATE(18977), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447487] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9466), 1,
      sym_attribute,
    STATE(10337), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18409), 1,
      sym_extended_module_path,
    STATE(18981), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447559] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447601] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447643] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447685] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9470), 1,
      sym_attribute,
    STATE(10334), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18409), 1,
      sym_extended_module_path,
    STATE(19088), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447757] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447799] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11021), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447841] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9473), 1,
      sym_attribute,
    STATE(10602), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [447913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [447955] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9475), 1,
      sym_attribute,
    STATE(10602), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448027] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(9476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [448071] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9477), 1,
      sym_attribute,
    STATE(10413), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17655), 1,
      sym_extended_module_path,
    STATE(19139), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448143] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11046), 1,
      anon_sym_type,
    ACTIONS(11048), 1,
      anon_sym_exception,
    ACTIONS(11050), 1,
      anon_sym_module,
    ACTIONS(11052), 1,
      anon_sym_include,
    ACTIONS(11054), 1,
      anon_sym_class,
    ACTIONS(11056), 1,
      anon_sym_val,
    STATE(9478), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [448211] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9479), 1,
      sym_attribute,
    STATE(10415), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17655), 1,
      sym_extended_module_path,
    STATE(19248), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448283] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11595), 1,
      anon_sym_LPAREN,
    STATE(10239), 1,
      sym_module_parameter,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9480), 2,
      sym_attribute,
      aux_sym_module_binding_repeat1,
    ACTIONS(11593), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11591), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [448329] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9481), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11275), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11243), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [448385] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11600), 1,
      anon_sym_GT,
    STATE(9482), 1,
      sym_attribute,
    STATE(14251), 1,
      sym__simple_type,
    STATE(16926), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448457] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [448499] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9484), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11604), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [448557] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9485), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11610), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [448615] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9486), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [448673] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11618), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11616), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [448715] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9488), 1,
      sym_attribute,
    STATE(10602), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448787] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9489), 1,
      sym_attribute,
    STATE(10571), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448859] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9490), 1,
      sym_attribute,
    STATE(10571), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [448931] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8286), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [448973] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9492), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11307), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11351), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [449029] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    ACTIONS(11620), 1,
      anon_sym_DASH_GT,
    ACTIONS(11622), 1,
      anon_sym_STAR,
    STATE(9493), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10383), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [449085] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11624), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11626), 1,
      anon_sym_GT,
    STATE(9494), 1,
      sym_attribute,
    STATE(14283), 1,
      sym__simple_type,
    STATE(16333), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449157] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(9495), 1,
      sym_attribute,
    STATE(10571), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449229] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11630), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11628), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [449271] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9497), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(10983), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449343] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11634), 1,
      anon_sym_GT,
    STATE(9498), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449415] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11636), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11638), 1,
      anon_sym_GT,
    STATE(9499), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449487] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9500), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(11108), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20192), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449559] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9501), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(11110), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20193), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449631] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9502), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(11164), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    STATE(20279), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449703] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8336), 16,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [449745] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8328), 16,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [449787] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11640), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11642), 1,
      anon_sym_GT,
    STATE(9505), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449859] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9506), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(11457), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [449931] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9507), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(11457), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450003] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11644), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11646), 1,
      anon_sym_GT,
    STATE(9508), 1,
      sym_attribute,
    STATE(14254), 1,
      sym__simple_type,
    STATE(16581), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450075] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(9509), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(11457), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450147] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9510), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11650), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [450205] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9511), 1,
      sym_attribute,
    STATE(10611), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(20298), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450277] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11652), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11654), 1,
      anon_sym_GT,
    STATE(9512), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450349] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11658), 1,
      anon_sym_GT,
    STATE(9513), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450421] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11660), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11662), 1,
      anon_sym_GT,
    STATE(9514), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450493] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(9515), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(13998), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(20891), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450565] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(9516), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(13986), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(20893), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450637] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(9517), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(14011), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(20975), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8364), 16,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [450751] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(10782), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10784), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(9519), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11371), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(11247), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [450807] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9520), 1,
      sym_attribute,
    STATE(9750), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20934), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450879] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9521), 1,
      sym_attribute,
    STATE(9751), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(20935), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [450951] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9522), 1,
      sym_attribute,
    STATE(9788), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18272), 1,
      sym_extended_module_path,
    STATE(21190), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451023] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9523), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [451081] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9524), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [451139] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9525), 1,
      sym_attribute,
    STATE(10662), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(20343), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451211] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11664), 1,
      sym__lowercase_identifier,
    STATE(9526), 1,
      sym_attribute,
    STATE(14588), 1,
      sym__simple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(18428), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451281] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11666), 1,
      anon_sym_LBRACE,
    STATE(9527), 1,
      sym_attribute,
    STATE(14215), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(17406), 1,
      sym__constructor_argument,
    STATE(17418), 1,
      sym_record_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451353] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11666), 1,
      anon_sym_LBRACE,
    STATE(9528), 1,
      sym_attribute,
    STATE(14215), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(17418), 1,
      sym_record_declaration,
    STATE(17424), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451425] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9529), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [451483] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11668), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11670), 1,
      anon_sym_GT,
    STATE(9530), 1,
      sym_attribute,
    STATE(14270), 1,
      sym__simple_type,
    STATE(16906), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451555] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11666), 1,
      anon_sym_LBRACE,
    STATE(9531), 1,
      sym_attribute,
    STATE(14215), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    STATE(17418), 1,
      sym_record_declaration,
    STATE(17651), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451627] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11019), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [451669] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9533), 1,
      sym_attribute,
    STATE(10663), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17544), 1,
      sym_extended_module_path,
    STATE(20365), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451741] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11672), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11674), 1,
      anon_sym_GT,
    STATE(9534), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451813] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9384), 1,
      sym__simple_type,
    STATE(9535), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18923), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451885] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9393), 1,
      sym__simple_type,
    STATE(9536), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(18945), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [451957] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9486), 1,
      sym__simple_type,
    STATE(9537), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17350), 1,
      sym_extended_module_path,
    STATE(21225), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452029] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 11,
      anon_sym_PIPE,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_as,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8206), 16,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452071] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8226), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452113] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11678), 1,
      anon_sym_POUND,
    STATE(9540), 1,
      sym_attribute,
    STATE(10069), 1,
      sym_type_constructor_path,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [452165] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9541), 1,
      sym_attribute,
    STATE(9840), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452237] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9542), 1,
      sym_attribute,
    STATE(9840), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452309] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11680), 1,
      anon_sym_DOT,
    ACTIONS(11682), 1,
      anon_sym_POUND,
    ACTIONS(11684), 1,
      sym_hash_operator,
    STATE(9543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8082), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [452357] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11688), 1,
      anon_sym_GT,
    STATE(9544), 1,
      sym_attribute,
    STATE(14247), 1,
      sym__simple_type,
    STATE(16382), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452429] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9545), 1,
      sym_attribute,
    STATE(9840), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452501] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11690), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11692), 1,
      anon_sym_GT,
    STATE(9546), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452573] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11694), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11696), 1,
      anon_sym_GT,
    STATE(9547), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452645] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9548), 1,
      sym_attribute,
    STATE(9737), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17454), 1,
      sym_extended_module_path,
    STATE(21413), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452717] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9549), 1,
      sym_attribute,
    STATE(9743), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17454), 1,
      sym_extended_module_path,
    STATE(21416), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452789] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    ACTIONS(11698), 1,
      anon_sym_STAR,
    STATE(9550), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11160), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [452843] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9551), 1,
      sym_attribute,
    STATE(9813), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17454), 1,
      sym_extended_module_path,
    STATE(18831), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [452915] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9552), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11650), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [452973] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9553), 1,
      sym_attribute,
    STATE(10172), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453045] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9554), 1,
      sym_attribute,
    STATE(10172), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453117] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11700), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11702), 1,
      anon_sym_GT,
    STATE(9555), 1,
      sym_attribute,
    STATE(14260), 1,
      sym__simple_type,
    STATE(16760), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453189] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(9556), 1,
      sym_attribute,
    STATE(10172), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453261] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11704), 1,
      anon_sym_COLON2,
    STATE(9557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [453305] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11706), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11708), 1,
      anon_sym_GT,
    STATE(9558), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453377] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(9559), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(10983), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453449] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11710), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11712), 1,
      anon_sym_GT,
    STATE(9560), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453521] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9523), 1,
      sym__simple_type,
    STATE(9561), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(19622), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453593] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9524), 1,
      sym__simple_type,
    STATE(9562), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(20364), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453665] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9529), 1,
      sym__simple_type,
    STATE(9563), 1,
      sym_attribute,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18252), 1,
      sym_extended_module_path,
    STATE(20612), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453737] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(9564), 1,
      sym_attribute,
    STATE(10345), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17655), 1,
      sym_extended_module_path,
    STATE(19392), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453809] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9565), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11604), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [453867] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8238), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [453909] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9567), 1,
      sym_attribute,
    STATE(9885), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [453981] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9568), 1,
      sym_attribute,
    STATE(9885), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454053] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11714), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11716), 1,
      anon_sym_GT,
    STATE(9569), 1,
      sym_attribute,
    STATE(14272), 1,
      sym__simple_type,
    STATE(17041), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11720), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11718), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [454167] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9571), 1,
      sym_attribute,
    STATE(9885), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454239] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9572), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11610), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [454297] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11722), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11724), 1,
      anon_sym_GT,
    STATE(9573), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454369] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11726), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11728), 1,
      anon_sym_GT,
    STATE(9574), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454441] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9575), 1,
      sym_attribute,
    STATE(9724), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17243), 1,
      sym_extended_module_path,
    STATE(19692), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454513] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9576), 1,
      sym_attribute,
    STATE(9726), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17243), 1,
      sym_extended_module_path,
    STATE(19733), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454585] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9577), 1,
      sym_attribute,
    STATE(9745), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17243), 1,
      sym_extended_module_path,
    STATE(20533), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454657] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11680), 1,
      anon_sym_DOT,
    ACTIONS(11682), 1,
      anon_sym_POUND,
    ACTIONS(11684), 1,
      sym_hash_operator,
    STATE(9578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8184), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8186), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [454705] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11409), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(8302), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [454749] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8290), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [454791] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9581), 1,
      sym_attribute,
    STATE(9992), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454863] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9582), 1,
      sym_attribute,
    STATE(9992), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [454935] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8294), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [454977] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11730), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11732), 1,
      anon_sym_GT,
    STATE(9584), 1,
      sym_attribute,
    STATE(14288), 1,
      sym__simple_type,
    STATE(15911), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8022), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [455091] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(9586), 1,
      sym_attribute,
    STATE(9992), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455163] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8298), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [455205] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11734), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11736), 1,
      anon_sym_GT,
    STATE(9588), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455277] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11738), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11740), 1,
      anon_sym_GT,
    STATE(9589), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455349] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9590), 1,
      sym_attribute,
    STATE(10075), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19793), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455421] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9591), 1,
      sym_attribute,
    STATE(10080), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(19817), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455493] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9592), 1,
      sym_attribute,
    STATE(10020), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17616), 1,
      sym_extended_module_path,
    STATE(21417), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455565] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9593), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11201), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [455617] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7915), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [455659] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9595), 1,
      sym_attribute,
    STATE(10379), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455731] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9596), 1,
      sym_attribute,
    STATE(10379), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455803] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8308), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [455845] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11742), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11744), 1,
      anon_sym_GT,
    STATE(9598), 1,
      sym_attribute,
    STATE(14239), 1,
      sym__simple_type,
    STATE(16482), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455917] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9599), 1,
      sym_attribute,
    STATE(10147), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [455989] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(9600), 1,
      sym_attribute,
    STATE(10379), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456061] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9601), 1,
      sym_attribute,
    STATE(10147), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456133] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(15), 1,
      anon_sym_exception,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    STATE(9602), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [456201] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11746), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11748), 1,
      anon_sym_GT,
    STATE(9603), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456273] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11750), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11752), 1,
      anon_sym_GT,
    STATE(9604), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456345] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9605), 1,
      sym_attribute,
    STATE(10395), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18267), 1,
      sym_extended_module_path,
    STATE(19439), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456417] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9606), 1,
      sym_attribute,
    STATE(10403), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18267), 1,
      sym_extended_module_path,
    STATE(19607), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456489] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9607), 1,
      sym_attribute,
    STATE(10512), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(18267), 1,
      sym_extended_module_path,
    STATE(21344), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456561] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8312), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [456603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8316), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [456645] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8320), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [456687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8324), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [456729] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9612), 1,
      sym_attribute,
    STATE(10603), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10855), 1,
      sym__constructor_argument,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456801] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9613), 1,
      sym_attribute,
    STATE(10603), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10819), 1,
      sym__constructor_argument,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456873] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11754), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11756), 1,
      anon_sym_GT,
    STATE(9614), 1,
      sym_attribute,
    STATE(14240), 1,
      sym__simple_type,
    STATE(16247), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [456945] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11758), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11760), 1,
      anon_sym_GT,
    STATE(9615), 1,
      sym_attribute,
    STATE(14242), 1,
      sym__simple_type,
    STATE(17116), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457017] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(5815), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(5813), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [457059] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11762), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11764), 1,
      anon_sym_GT,
    STATE(9617), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457131] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(9618), 1,
      sym_attribute,
    STATE(10603), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457203] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11457), 1,
      sym__lowercase_identifier,
    ACTIONS(11461), 1,
      anon_sym_POUND,
    ACTIONS(11766), 1,
      anon_sym_DASH_GT,
    ACTIONS(11768), 1,
      anon_sym_STAR,
    STATE(9619), 1,
      sym_attribute,
    STATE(10245), 1,
      sym_type_constructor_path,
    STATE(17862), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [457259] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11772), 1,
      anon_sym_GT,
    STATE(9620), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457331] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11774), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11776), 1,
      anon_sym_GT,
    STATE(9621), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457403] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9622), 1,
      sym_attribute,
    STATE(10147), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(10906), 1,
      sym__constructor_argument,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457475] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8222), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [457517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11780), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11778), 25,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [457559] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(11), 1,
      anon_sym_external,
    ACTIONS(13), 1,
      anon_sym_type,
    ACTIONS(17), 1,
      anon_sym_module,
    ACTIONS(19), 1,
      anon_sym_open,
    ACTIONS(21), 1,
      anon_sym_include,
    ACTIONS(23), 1,
      anon_sym_class,
    ACTIONS(25), 1,
      anon_sym_val,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11112), 1,
      anon_sym_exception,
    STATE(9625), 1,
      sym_attribute,
    STATE(13106), 1,
      aux_sym__structure_repeat1,
    STATE(13421), 1,
      sym__signature_item,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13539), 13,
      sym_external,
      sym_type_definition,
      sym_exception_definition,
      sym_module_definition,
      sym_module_type_definition,
      sym_open_module,
      sym_class_definition,
      sym_class_type_definition,
      sym_value_specification,
      sym_include_module_type,
      sym_floating_attribute,
      sym_item_extension,
      sym_quoted_item_extension,
  [457627] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11782), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11784), 1,
      anon_sym_GT,
    STATE(9626), 1,
      sym_attribute,
    STATE(14250), 1,
      sym__simple_type,
    STATE(17124), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457699] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11664), 1,
      sym__lowercase_identifier,
    STATE(9627), 1,
      sym_attribute,
    STATE(14622), 1,
      sym__simple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21318), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457769] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [457853] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11786), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11788), 1,
      anon_sym_GT,
    STATE(9630), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457925] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11792), 1,
      anon_sym_GT,
    STATE(9631), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [457997] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7633), 1,
      anon_sym_QMARK,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11664), 1,
      sym__lowercase_identifier,
    STATE(9632), 1,
      sym_attribute,
    STATE(14307), 1,
      sym__simple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(18428), 2,
      sym_labeled_argument_type,
      sym__proper_tuple_type,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458067] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11794), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11796), 1,
      anon_sym_GT,
    STATE(9633), 1,
      sym_attribute,
    STATE(14237), 1,
      sym__simple_type,
    STATE(16778), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458139] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11798), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11800), 1,
      anon_sym_GT,
    STATE(9634), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458211] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11802), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11804), 1,
      anon_sym_GT,
    STATE(9635), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458283] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8332), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458325] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8340), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458367] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11806), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11808), 1,
      anon_sym_GT,
    STATE(9638), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458439] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8282), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458481] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8344), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458523] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11810), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11812), 1,
      anon_sym_GT,
    STATE(9641), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458595] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7921), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 16,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [458721] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11814), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11816), 1,
      anon_sym_GT,
    STATE(9645), 1,
      sym_attribute,
    STATE(14241), 1,
      sym__simple_type,
    STATE(16136), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [458793] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8054), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458835] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8354), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458877] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8058), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458919] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8358), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [458961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8062), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459003] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8066), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8078), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459087] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    ACTIONS(11818), 1,
      anon_sym_DASH_GT,
    ACTIONS(11820), 1,
      anon_sym_STAR,
    STATE(9653), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(10383), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [459143] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11822), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11824), 1,
      anon_sym_GT,
    STATE(9654), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459215] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11826), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11828), 1,
      anon_sym_GT,
    STATE(9655), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459287] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11830), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11832), 1,
      anon_sym_GT,
    STATE(9656), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459359] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11834), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11836), 1,
      anon_sym_GT,
    STATE(9657), 1,
      sym_attribute,
    STATE(14271), 1,
      sym__simple_type,
    STATE(16528), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459431] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8086), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459473] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8090), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459515] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8094), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459557] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11840), 1,
      anon_sym_GT,
    STATE(9661), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459629] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8098), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459671] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11842), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11844), 1,
      anon_sym_GT,
    STATE(9663), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [459743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8102), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459785] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8106), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459827] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7933), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459869] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8110), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459911] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11680), 1,
      anon_sym_DOT,
    STATE(9668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8114), 15,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459955] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8118), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [459997] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8070), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460039] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11846), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11848), 1,
      anon_sym_GT,
    STATE(9671), 1,
      sym_attribute,
    STATE(14238), 1,
      sym__simple_type,
    STATE(16875), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [460111] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8122), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460153] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8126), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460195] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8130), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460237] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8134), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460279] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8230), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460321] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8138), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460363] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8074), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460405] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11850), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11852), 1,
      anon_sym_GT,
    STATE(9679), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [460477] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8142), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460519] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11854), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11856), 1,
      anon_sym_GT,
    STATE(9681), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [460591] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8150), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460633] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8154), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460675] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8158), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460717] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8162), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460759] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8166), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460801] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8170), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460843] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8174), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [460885] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11858), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11860), 1,
      anon_sym_GT,
    STATE(9689), 1,
      sym_attribute,
    STATE(14233), 1,
      sym__simple_type,
    STATE(16289), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [460957] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11862), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11864), 1,
      anon_sym_GT,
    STATE(9690), 1,
      sym_attribute,
    STATE(14221), 1,
      sym__simple_type,
    STATE(17177), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461029] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8178), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461071] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8182), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461113] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7937), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461155] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7941), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461197] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7945), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461239] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8190), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461281] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8194), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461323] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8198), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461365] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8202), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461407] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11866), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11868), 1,
      anon_sym_GT,
    STATE(9700), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461479] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11870), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11872), 1,
      anon_sym_GT,
    STATE(9701), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461551] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7949), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461593] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7953), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461635] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(7957), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461677] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8210), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461719] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11874), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11876), 1,
      anon_sym_GT,
    STATE(9706), 1,
      sym_attribute,
    STATE(14225), 1,
      sym__simple_type,
    STATE(16001), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461791] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9707), 1,
      sym_attribute,
    STATE(10050), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17956), 1,
      sym_extended_module_path,
    STATE(19938), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461863] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9708), 1,
      sym_attribute,
    STATE(10057), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17956), 1,
      sym_extended_module_path,
    STATE(19939), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [461935] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_POUND,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8214), 16,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym_hash_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [461977] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11878), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11880), 1,
      anon_sym_GT,
    STATE(9710), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462049] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9322), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(9711), 1,
      sym_attribute,
    STATE(9950), 1,
      sym__simple_type,
    STATE(10669), 1,
      sym_record_declaration,
    STATE(17956), 1,
      sym_extended_module_path,
    STATE(20216), 1,
      sym__constructor_argument,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462121] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11884), 1,
      anon_sym_GT,
    STATE(9712), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462193] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11886), 1,
      sym_hash_operator,
    STATE(9713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9790), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9788), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462241] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11886), 1,
      sym_hash_operator,
    STATE(9714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9812), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9810), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462289] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11886), 1,
      sym_hash_operator,
    STATE(9715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9716), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462337] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11886), 1,
      sym_hash_operator,
    STATE(9716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9816), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9814), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462385] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9544), 1,
      anon_sym_DOT,
    ACTIONS(11068), 1,
      anon_sym_POUND,
    ACTIONS(11886), 1,
      sym_hash_operator,
    STATE(9717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9800), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9798), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [462433] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11888), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11890), 1,
      anon_sym_GT,
    STATE(9718), 1,
      sym_attribute,
    STATE(14231), 1,
      sym__simple_type,
    STATE(16145), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462505] = 20,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    ACTIONS(11892), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11894), 1,
      anon_sym_GT,
    STATE(9719), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462577] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11896), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9291), 1,
      sym__simple_type,
    STATE(9720), 1,
      sym_attribute,
    STATE(10339), 1,
      sym_labeled_tuple_element_type,
    STATE(17493), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462646] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11898), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9721), 1,
      sym_attribute,
    STATE(9898), 1,
      sym__simple_type,
    STATE(11383), 1,
      sym_labeled_tuple_element_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462715] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11898), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9722), 1,
      sym_attribute,
    STATE(9898), 1,
      sym__simple_type,
    STATE(11383), 1,
      sym_labeled_tuple_element_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [462784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462825] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(9724), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [462882] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [462923] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(9726), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [462980] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463021] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463062] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463103] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8308), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [463185] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11904), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9373), 1,
      sym__simple_type,
    STATE(9732), 1,
      sym_attribute,
    STATE(10598), 1,
      sym_labeled_tuple_element_type,
    STATE(18259), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [463254] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11904), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9373), 1,
      sym__simple_type,
    STATE(9733), 1,
      sym_attribute,
    STATE(10598), 1,
      sym_labeled_tuple_element_type,
    STATE(18259), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [463323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11908), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11906), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [463364] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11910), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9735), 1,
      sym_attribute,
    STATE(12764), 1,
      sym__simple_type,
    STATE(13806), 1,
      sym_labeled_tuple_element_type,
    STATE(17202), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [463433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463474] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(9737), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [463531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463613] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463654] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [463736] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(9743), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [463793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [463834] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(9745), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [463891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11918), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11916), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [463932] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11922), 1,
      anon_sym_let,
    ACTIONS(11924), 1,
      anon_sym_EQ,
    ACTIONS(11926), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(9747), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10723), 1,
      sym__type_equation,
    STATE(10981), 1,
      aux_sym_type_binding_repeat1,
    STATE(11101), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [463993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464034] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11930), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9550), 1,
      sym__simple_type,
    STATE(9749), 1,
      sym_attribute,
    STATE(11177), 1,
      sym_labeled_tuple_element_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [464103] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9750), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [464160] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9751), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [464217] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11936), 1,
      anon_sym_let,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(11942), 1,
      anon_sym_COLON2,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(9752), 1,
      sym_attribute,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10925), 1,
      aux_sym_expression_item_repeat1,
    STATE(10988), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11938), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11934), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [464276] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [464317] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [464358] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [464399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [464440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464481] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11944), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9758), 1,
      sym_attribute,
    STATE(13666), 1,
      sym__simple_type,
    STATE(14224), 1,
      sym_labeled_tuple_element_type,
    STATE(17664), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [464550] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11944), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9759), 1,
      sym_attribute,
    STATE(13666), 1,
      sym__simple_type,
    STATE(14224), 1,
      sym_labeled_tuple_element_type,
    STATE(17664), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [464619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11021), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [464660] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11898), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9761), 1,
      sym_attribute,
    STATE(9898), 1,
      sym__simple_type,
    STATE(11383), 1,
      sym_labeled_tuple_element_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [464729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [464770] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464811] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464893] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [464975] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11946), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9768), 1,
      sym_attribute,
    STATE(10620), 1,
      sym__simple_type,
    STATE(12420), 1,
      sym_labeled_tuple_element_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [465044] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11407), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11405), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [465085] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11950), 1,
      anon_sym_SEMI,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [465150] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11950), 1,
      anon_sym_SEMI,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [465215] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9772), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11604), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [465272] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11970), 1,
      anon_sym_let,
    ACTIONS(11972), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9773), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
    ACTIONS(11968), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [465317] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9774), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11610), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [465374] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465415] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465456] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11904), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9373), 1,
      sym__simple_type,
    STATE(9777), 1,
      sym_attribute,
    STATE(10598), 1,
      sym_labeled_tuple_element_type,
    STATE(18259), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [465525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465607] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(11979), 1,
      anon_sym_EQ,
    ACTIONS(11981), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(9780), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10733), 1,
      sym__type_equation,
    STATE(11036), 1,
      aux_sym_type_binding_repeat1,
    STATE(11116), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11975), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [465668] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11985), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9385), 1,
      sym__simple_type,
    STATE(9781), 1,
      sym_attribute,
    STATE(10884), 1,
      sym_labeled_tuple_element_type,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [465737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [465778] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [465819] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11910), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9784), 1,
      sym_attribute,
    STATE(12764), 1,
      sym__simple_type,
    STATE(13806), 1,
      sym_labeled_tuple_element_type,
    STATE(17202), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [465888] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11910), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9785), 1,
      sym_attribute,
    STATE(12764), 1,
      sym__simple_type,
    STATE(13806), 1,
      sym_labeled_tuple_element_type,
    STATE(17202), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [465957] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11930), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9550), 1,
      sym__simple_type,
    STATE(9786), 1,
      sym_attribute,
    STATE(11177), 1,
      sym_labeled_tuple_element_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [466026] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11930), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9550), 1,
      sym__simple_type,
    STATE(9787), 1,
      sym_attribute,
    STATE(11177), 1,
      sym_labeled_tuple_element_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [466095] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9788), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [466152] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [466193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466234] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [466275] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11987), 1,
      sym__lowercase_identifier,
    STATE(9792), 1,
      sym_attribute,
    STATE(13810), 1,
      sym__simple_type,
    STATE(13855), 1,
      sym__tuple_type_rhs,
    STATE(14441), 1,
      sym_labeled_tuple_element_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [466344] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9793), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 9,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [466395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [466436] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [466477] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8316), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [466518] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11950), 1,
      anon_sym_SEMI,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [466583] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [466624] = 20,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(11989), 1,
      sym__lowercase_identifier,
    ACTIONS(11991), 1,
      anon_sym_let,
    ACTIONS(11993), 1,
      anon_sym_LPAREN,
    ACTIONS(11995), 1,
      anon_sym_BANG,
    ACTIONS(11997), 1,
      anon_sym_LBRACK,
    ACTIONS(11999), 1,
      anon_sym_fun,
    STATE(2600), 1,
      sym__simple_class_expression,
    STATE(9799), 1,
      sym_attribute,
    STATE(13626), 1,
      sym__class_expression,
    STATE(19557), 1,
      sym_module_path,
    STATE(21009), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8758), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [466695] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [466736] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11415), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11413), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [466777] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11922), 1,
      anon_sym_let,
    ACTIONS(11981), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12001), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(9802), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10730), 1,
      sym__type_equation,
    STATE(11030), 1,
      aux_sym_type_binding_repeat1,
    STATE(11101), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [466838] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12003), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(9803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [466883] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(9804), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11604), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [466940] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(9805), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11610), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [466997] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [467038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467079] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(9808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467204] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11985), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9385), 1,
      sym__simple_type,
    STATE(9811), 1,
      sym_attribute,
    STATE(10884), 1,
      sym_labeled_tuple_element_type,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [467273] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11985), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9385), 1,
      sym__simple_type,
    STATE(9812), 1,
      sym_attribute,
    STATE(10884), 1,
      sym_labeled_tuple_element_type,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [467342] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(9813), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [467399] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [467440] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11987), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9815), 1,
      sym_attribute,
    STATE(13146), 1,
      sym__simple_type,
    STATE(13957), 1,
      sym_labeled_tuple_element_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [467509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12007), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12005), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [467550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [467591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [467632] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467673] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [467714] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [467755] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11896), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9291), 1,
      sym__simple_type,
    STATE(9822), 1,
      sym_attribute,
    STATE(10339), 1,
      sym_labeled_tuple_element_type,
    STATE(17493), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [467824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [467865] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(11926), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(11977), 1,
      anon_sym_let,
    ACTIONS(12009), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(9824), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10728), 1,
      sym__type_equation,
    STATE(10987), 1,
      aux_sym_type_binding_repeat1,
    STATE(11116), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11975), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [467926] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(11942), 1,
      anon_sym_COLON2,
    ACTIONS(12013), 1,
      anon_sym_let,
    STATE(9752), 1,
      aux_sym_module_binding_repeat1,
    STATE(9825), 1,
      sym_attribute,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10982), 1,
      sym__module_typed,
    STATE(11162), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12015), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(12011), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [467985] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(12017), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9392), 1,
      sym__simple_type,
    STATE(9826), 1,
      sym_attribute,
    STATE(11137), 1,
      sym_labeled_tuple_element_type,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468054] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [468095] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [468136] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12019), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9286), 1,
      sym__simple_type,
    STATE(9829), 1,
      sym_attribute,
    STATE(10534), 1,
      sym_labeled_tuple_element_type,
    STATE(17378), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468205] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12019), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9286), 1,
      sym__simple_type,
    STATE(9830), 1,
      sym_attribute,
    STATE(10534), 1,
      sym_labeled_tuple_element_type,
    STATE(17378), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468274] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11946), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9831), 1,
      sym_attribute,
    STATE(10620), 1,
      sym__simple_type,
    STATE(12420), 1,
      sym_labeled_tuple_element_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468343] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    ACTIONS(12021), 1,
      anon_sym_DASH_GT,
    ACTIONS(12023), 1,
      anon_sym_STAR,
    STATE(9832), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [468398] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11944), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9833), 1,
      sym_attribute,
    STATE(13666), 1,
      sym__simple_type,
    STATE(14224), 1,
      sym_labeled_tuple_element_type,
    STATE(17664), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468467] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11946), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9834), 1,
      sym_attribute,
    STATE(10620), 1,
      sym__simple_type,
    STATE(12420), 1,
      sym_labeled_tuple_element_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468536] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(12017), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9392), 1,
      sym__simple_type,
    STATE(9835), 1,
      sym_attribute,
    STATE(11137), 1,
      sym_labeled_tuple_element_type,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [468646] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [468687] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11987), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9838), 1,
      sym_attribute,
    STATE(13146), 1,
      sym__simple_type,
    STATE(13957), 1,
      sym_labeled_tuple_element_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468756] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11987), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9839), 1,
      sym_attribute,
    STATE(13146), 1,
      sym__simple_type,
    STATE(13957), 1,
      sym_labeled_tuple_element_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468825] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    ACTIONS(12027), 1,
      anon_sym_STAR,
    STATE(9840), 1,
      sym_attribute,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(11452), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12025), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [468880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [468921] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11896), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9291), 1,
      sym__simple_type,
    STATE(9842), 1,
      sym_attribute,
    STATE(10339), 1,
      sym_labeled_tuple_element_type,
    STATE(17493), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [468990] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [469031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [469072] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [469115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [469156] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [469197] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10335), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [469260] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12031), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9849), 1,
      sym_attribute,
    STATE(10854), 1,
      sym__simple_type,
    STATE(12901), 1,
      sym_labeled_tuple_element_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [469329] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [469370] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 12,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [469431] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [469482] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11954), 1,
      sym_pow_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [469527] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11954), 1,
      sym_pow_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [469572] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [469625] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [469678] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [469735] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [469794] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [469857] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12033), 1,
      sym__lowercase_identifier,
    STATE(9860), 1,
      sym_attribute,
    STATE(13498), 1,
      sym__simple_type,
    STATE(13731), 1,
      sym__tuple_type_rhs,
    STATE(13989), 1,
      sym_labeled_tuple_element_type,
    STATE(17607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [469926] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [469973] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12033), 1,
      sym__lowercase_identifier,
    STATE(9862), 1,
      sym_attribute,
    STATE(13498), 1,
      sym__simple_type,
    STATE(13734), 1,
      sym__tuple_type_rhs,
    STATE(13989), 1,
      sym_labeled_tuple_element_type,
    STATE(17607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [470042] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [470105] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12035), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(9864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [470150] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(9865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470193] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    ACTIONS(11952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11954), 1,
      sym_pow_operator,
    ACTIONS(11956), 1,
      sym_mult_operator,
    ACTIONS(11958), 1,
      sym_concat_operator,
    ACTIONS(11960), 1,
      sym_rel_operator,
    ACTIONS(11962), 1,
      sym_and_operator,
    ACTIONS(11964), 1,
      sym_or_operator,
    ACTIONS(11966), 1,
      sym_assign_operator,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10273), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [470256] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(12039), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9867), 1,
      sym_attribute,
    STATE(10197), 1,
      sym__simple_type,
    STATE(11690), 1,
      sym_labeled_tuple_element_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [470325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470366] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(12039), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9869), 1,
      sym_attribute,
    STATE(10197), 1,
      sym__simple_type,
    STATE(11690), 1,
      sym_labeled_tuple_element_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [470435] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470478] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(12013), 1,
      anon_sym_let,
    ACTIONS(12041), 1,
      anon_sym_COLON2,
    STATE(9871), 1,
      sym_attribute,
    STATE(9882), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10982), 1,
      sym__module_typed,
    STATE(11162), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12015), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(12011), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [470537] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470578] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8312), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [470619] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470660] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470701] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470742] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470824] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [470865] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2190), 1,
      sym_add_operator,
    STATE(9880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [470908] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12035), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(9881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [470953] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11936), 1,
      anon_sym_let,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(12041), 1,
      anon_sym_COLON2,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(9882), 1,
      sym_attribute,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10925), 1,
      aux_sym_expression_item_repeat1,
    STATE(10988), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11938), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11934), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [471012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471053] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(12039), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9884), 1,
      sym_attribute,
    STATE(10197), 1,
      sym__simple_type,
    STATE(11690), 1,
      sym_labeled_tuple_element_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [471122] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    ACTIONS(12043), 1,
      anon_sym_STAR,
    STATE(9885), 1,
      sym_attribute,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(11426), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12025), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [471177] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12045), 1,
      anon_sym_COLON2,
    STATE(9886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471261] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12049), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12047), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [471302] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471343] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471384] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471425] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471466] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [471507] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471548] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471589] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12051), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9896), 1,
      sym_attribute,
    STATE(11611), 1,
      sym__simple_type,
    STATE(13414), 1,
      sym_labeled_tuple_element_type,
    STATE(17801), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [471658] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471699] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    ACTIONS(12053), 1,
      anon_sym_STAR,
    STATE(9898), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [471752] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [471793] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12031), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9900), 1,
      sym_attribute,
    STATE(10854), 1,
      sym__simple_type,
    STATE(12901), 1,
      sym_labeled_tuple_element_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [471862] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12031), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9901), 1,
      sym_attribute,
    STATE(10854), 1,
      sym__simple_type,
    STATE(12901), 1,
      sym_labeled_tuple_element_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [471931] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(9902), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11604), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [471988] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472029] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472070] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12055), 1,
      anon_sym_COLON2,
    STATE(9905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472195] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472236] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(9909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472279] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(9910), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11610), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [472336] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12033), 1,
      sym__lowercase_identifier,
    STATE(9911), 1,
      sym_attribute,
    STATE(13498), 1,
      sym__simple_type,
    STATE(13855), 1,
      sym__tuple_type_rhs,
    STATE(13989), 1,
      sym_labeled_tuple_element_type,
    STATE(17607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [472405] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472446] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12003), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(9913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [472491] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8324), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [472532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [472573] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(9916), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11650), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [472630] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(12017), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9392), 1,
      sym__simple_type,
    STATE(9917), 1,
      sym_attribute,
    STATE(11137), 1,
      sym_labeled_tuple_element_type,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [472699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 15,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [472740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12059), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12057), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [472781] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [472822] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12061), 1,
      anon_sym_PIPE,
    STATE(9921), 1,
      sym_attribute,
    STATE(9923), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [472867] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12061), 1,
      anon_sym_PIPE,
    STATE(9922), 1,
      sym_attribute,
    STATE(9924), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [472912] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12061), 1,
      anon_sym_PIPE,
    STATE(9923), 1,
      sym_attribute,
    STATE(9925), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [472957] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12061), 1,
      anon_sym_PIPE,
    STATE(9924), 1,
      sym_attribute,
    STATE(9925), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [473002] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12063), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9925), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [473045] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12068), 1,
      anon_sym_POUND,
    STATE(9926), 1,
      sym_attribute,
    STATE(10335), 1,
      sym_type_constructor_path,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [473096] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [473137] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11987), 1,
      sym__lowercase_identifier,
    STATE(9928), 1,
      sym_attribute,
    STATE(13731), 1,
      sym__tuple_type_rhs,
    STATE(13810), 1,
      sym__simple_type,
    STATE(14441), 1,
      sym_labeled_tuple_element_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [473206] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12051), 1,
      sym__lowercase_identifier,
    STATE(8538), 1,
      sym__tuple_type_rhs,
    STATE(9929), 1,
      sym_attribute,
    STATE(11611), 1,
      sym__simple_type,
    STATE(13414), 1,
      sym_labeled_tuple_element_type,
    STATE(17801), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [473275] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12051), 1,
      sym__lowercase_identifier,
    STATE(8551), 1,
      sym__tuple_type_rhs,
    STATE(9930), 1,
      sym_attribute,
    STATE(11611), 1,
      sym__simple_type,
    STATE(13414), 1,
      sym_labeled_tuple_element_type,
    STATE(17801), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [473344] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11987), 1,
      sym__lowercase_identifier,
    STATE(9931), 1,
      sym_attribute,
    STATE(13734), 1,
      sym__tuple_type_rhs,
    STATE(13810), 1,
      sym__simple_type,
    STATE(14441), 1,
      sym_labeled_tuple_element_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [473413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [473454] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [473495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [473536] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [473577] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 14,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [473618] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9937), 1,
      sym_attribute,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11650), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [473675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [473716] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12019), 1,
      sym__lowercase_identifier,
    STATE(8501), 1,
      sym__tuple_type_rhs,
    STATE(9286), 1,
      sym__simple_type,
    STATE(9939), 1,
      sym_attribute,
    STATE(10534), 1,
      sym_labeled_tuple_element_type,
    STATE(17378), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [473785] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12070), 1,
      anon_sym_COLON2,
    STATE(9940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [473828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12074), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12072), 24,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [473869] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(9942), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11650), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [473926] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 3,
      anon_sym_COLON2,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8320), 23,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_hash_operator,
  [473967] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12076), 1,
      anon_sym_DOT,
    ACTIONS(12078), 1,
      anon_sym_POUND,
    ACTIONS(12080), 1,
      sym_hash_operator,
    STATE(9944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9790), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9788), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [474013] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474053] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12084), 1,
      anon_sym_let,
    STATE(9946), 1,
      sym_attribute,
    STATE(9987), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12082), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [474099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474219] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(9950), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [474275] = 18,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11433), 1,
      sym__lowercase_identifier,
    STATE(9951), 1,
      sym_attribute,
    STATE(14353), 1,
      sym__simple_type,
    STATE(17730), 1,
      sym_method_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [474341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474381] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474421] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9954), 1,
      sym_attribute,
    STATE(10937), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [474489] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(9955), 1,
      sym_attribute,
    STATE(16684), 1,
      sym__class_expression,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [474557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8208), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8210), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [474637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(11019), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [474677] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [474717] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12110), 1,
      anon_sym_PIPE,
    STATE(9960), 1,
      sym_attribute,
    STATE(9962), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [474761] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12110), 1,
      anon_sym_PIPE,
    STATE(9961), 1,
      sym_attribute,
    STATE(9963), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [474805] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12110), 1,
      anon_sym_PIPE,
    STATE(9962), 1,
      sym_attribute,
    STATE(9964), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [474849] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12110), 1,
      anon_sym_PIPE,
    STATE(9963), 1,
      sym_attribute,
    STATE(9964), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [474893] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12112), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9964), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [474935] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(9965), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11650), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [474991] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8212), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8214), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [475031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475071] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(9968), 1,
      sym_attribute,
    STATE(10909), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475139] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12135), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(12133), 14,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_begin,
      sym__lowercase_identifier,
  [475219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475259] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475299] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475339] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9974), 1,
      sym_attribute,
    STATE(11117), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475407] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9975), 1,
      sym_attribute,
    STATE(11160), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475475] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475555] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475595] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12137), 1,
      anon_sym_COLON2,
    STATE(9979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475677] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9570), 1,
      sym__class_expression,
    STATE(9981), 1,
      sym_attribute,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [475825] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9984), 1,
      sym_attribute,
    STATE(10863), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [475893] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12141), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(9985), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12139), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [475939] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12145), 1,
      anon_sym_let,
    STATE(9986), 1,
      sym_attribute,
    STATE(10091), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12143), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [475985] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12145), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(9987), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12143), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [476031] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476071] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [476113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12135), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(12133), 13,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_begin,
      sym__lowercase_identifier,
  [476153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12149), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12147), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [476193] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    ACTIONS(12151), 1,
      anon_sym_STAR,
    STATE(9992), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(11652), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12025), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [476247] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(9993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [476307] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(9994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [476357] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(12169), 1,
      anon_sym_POUND,
    STATE(9995), 1,
      sym_attribute,
    STATE(10576), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [476407] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12157), 1,
      sym_pow_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(9996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [476451] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8228), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8230), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [476491] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(9999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476571] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [476611] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12171), 1,
      anon_sym_EQ,
    ACTIONS(12173), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10001), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10960), 1,
      sym__type_equation,
    STATE(11101), 1,
      aux_sym_expression_item_repeat1,
    STATE(11407), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [476669] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12157), 1,
      sym_pow_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [476713] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [476765] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [476817] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [476873] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [476931] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    ACTIONS(12177), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [476993] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [477039] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    ACTIONS(12177), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [477101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477141] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(10011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477183] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7915), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477223] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12181), 1,
      anon_sym_SEMI,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [477287] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8302), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [477327] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8286), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477367] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    ACTIONS(12177), 1,
      sym_assign_operator,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10273), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [477429] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8232), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8234), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477509] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8236), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8238), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477549] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10020), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [477605] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7959), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7961), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [477645] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477685] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10023), 1,
      sym_attribute,
    STATE(11143), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [477793] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10025), 1,
      sym_attribute,
    STATE(11215), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477861] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10026), 1,
      sym_attribute,
    STATE(11236), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477929] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10027), 1,
      sym_attribute,
    STATE(11143), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [477997] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10028), 1,
      sym_attribute,
    STATE(10812), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478065] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8240), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8242), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478105] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10030), 1,
      sym_attribute,
    STATE(10909), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478173] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8244), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8246), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478213] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12209), 1,
      anon_sym_COLON,
    STATE(10032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8446), 11,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8448), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [478255] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10033), 1,
      sym_attribute,
    STATE(11215), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8248), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8250), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478363] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8252), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8254), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478403] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10036), 1,
      sym_attribute,
    STATE(11236), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478471] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [478511] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 4,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8290), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [478551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [478591] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 4,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8294), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [478631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8256), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8258), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478671] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10042), 1,
      sym_attribute,
    STATE(10919), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7919), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7921), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [478779] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9487), 1,
      sym__class_expression,
    STATE(10044), 1,
      sym_attribute,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [478847] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10045), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12213), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [478897] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 4,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8022), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [478937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 4,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(8298), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [478977] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8260), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8262), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479017] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(12217), 1,
      anon_sym_COLON2,
    STATE(10049), 1,
      sym_attribute,
    STATE(10146), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11162), 1,
      aux_sym_expression_item_repeat1,
    STATE(11358), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12215), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(12011), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [479073] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10050), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [479129] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(9496), 1,
      sym__class_expression,
    STATE(10051), 1,
      sym_attribute,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479197] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10052), 1,
      sym_attribute,
    STATE(10941), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479265] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [479305] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8264), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8266), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8206), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479385] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8268), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8270), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479425] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10057), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [479481] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12173), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    ACTIONS(12219), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10058), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10989), 1,
      sym__type_equation,
    STATE(11116), 1,
      aux_sym_expression_item_repeat1,
    STATE(11309), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11975), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [479539] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10059), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12213), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [479589] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(9570), 1,
      sym__class_expression,
    STATE(10060), 1,
      sym_attribute,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479657] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [479697] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7963), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7965), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8290), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8294), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8022), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [479857] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(9487), 1,
      sym__class_expression,
    STATE(10066), 1,
      sym_attribute,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479925] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(9496), 1,
      sym__class_expression,
    STATE(10067), 1,
      sym_attribute,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [479993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480033] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11021), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480153] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12239), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12237), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [480193] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8052), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8054), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480233] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8056), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8058), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480273] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10075), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [480329] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8060), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8062), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480369] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8064), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8066), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8298), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8076), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8078), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480489] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10080), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [480545] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12243), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12241), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [480585] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12247), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12245), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [480625] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480705] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10085), 1,
      sym_attribute,
    STATE(10934), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480773] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10086), 1,
      sym_attribute,
    STATE(11117), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [480841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8334), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8336), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [480881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [480921] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    ACTIONS(12177), 1,
      sym_assign_operator,
    ACTIONS(12249), 1,
      anon_sym_SEMI,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [480985] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    ACTIONS(12177), 1,
      sym_assign_operator,
    ACTIONS(12249), 1,
      anon_sym_SEMI,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [481049] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12253), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10091), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12251), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [481095] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12257), 1,
      anon_sym_let,
    STATE(10092), 1,
      sym_attribute,
    STATE(10241), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12255), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [481141] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8216), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8218), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [481181] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10094), 1,
      sym_attribute,
    STATE(11160), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481249] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(9570), 1,
      sym__class_expression,
    STATE(10095), 1,
      sym_attribute,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481317] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12263), 1,
      anon_sym_LPAREN,
    ACTIONS(12265), 1,
      anon_sym_LBRACK,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    STATE(10096), 1,
      sym_attribute,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11755), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12267), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [481369] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(10097), 1,
      sym_attribute,
    STATE(16393), 1,
      sym__class_expression,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481437] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8084), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8086), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [481477] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8088), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8090), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [481517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8092), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8094), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [481557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [481597] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 12,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [481657] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12273), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12271), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [481697] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [481747] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12185), 1,
      sym_pow_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [481791] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10106), 1,
      sym_attribute,
    STATE(11143), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [481859] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12185), 1,
      sym_pow_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [481903] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [481955] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [482007] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8096), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8098), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482047] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10111), 1,
      sym_attribute,
    STATE(10909), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8100), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8102), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482155] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8104), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8106), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482195] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [482251] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [482309] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [482371] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [482417] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [482459] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12275), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(10119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [482503] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [482565] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12275), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(10121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [482609] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [482671] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [482711] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10124), 1,
      sym_attribute,
    STATE(10863), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482779] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(10125), 1,
      sym_attribute,
    STATE(16816), 1,
      sym__class_expression,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [482847] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7931), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7933), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8108), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8110), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482927] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12076), 1,
      anon_sym_DOT,
    STATE(10128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8112), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8114), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [482969] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8116), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8118), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483009] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [483049] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10131), 1,
      sym_attribute,
    STATE(11117), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [483117] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12277), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(10132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [483161] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10133), 1,
      sym_attribute,
    STATE(11160), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [483229] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(11989), 1,
      sym__lowercase_identifier,
    ACTIONS(11991), 1,
      anon_sym_let,
    ACTIONS(11993), 1,
      anon_sym_LPAREN,
    ACTIONS(11997), 1,
      anon_sym_LBRACK,
    ACTIONS(11999), 1,
      anon_sym_fun,
    STATE(2600), 1,
      sym__simple_class_expression,
    STATE(9570), 1,
      sym__class_expression,
    STATE(10134), 1,
      sym_attribute,
    STATE(19557), 1,
      sym_module_path,
    STATE(21009), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8758), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [483297] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8120), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8122), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483337] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8124), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8126), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483377] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8128), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8130), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [483457] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12076), 1,
      anon_sym_DOT,
    ACTIONS(12078), 1,
      anon_sym_POUND,
    ACTIONS(12080), 1,
      sym_hash_operator,
    STATE(10139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9800), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9798), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483503] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [483543] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10141), 1,
      sym_attribute,
    STATE(10863), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [483611] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10142), 1,
      sym_attribute,
    STATE(10812), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [483679] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    ACTIONS(12279), 1,
      anon_sym_DASH_GT,
    ACTIONS(12281), 1,
      anon_sym_STAR,
    STATE(10143), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [483733] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8224), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8226), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483773] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8132), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8134), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [483813] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(12217), 1,
      anon_sym_COLON2,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10146), 1,
      sym_attribute,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10925), 1,
      aux_sym_expression_item_repeat1,
    STATE(11267), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12283), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11934), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [483869] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    ACTIONS(12285), 1,
      anon_sym_STAR,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10147), 1,
      sym_attribute,
    STATE(11569), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12025), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [483923] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(9487), 1,
      sym__class_expression,
    STATE(10148), 1,
      sym_attribute,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [483991] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(9496), 1,
      sym__class_expression,
    STATE(10149), 1,
      sym_attribute,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484059] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [484099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [484139] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10152), 1,
      sym_attribute,
    STATE(11085), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484207] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10153), 1,
      sym_attribute,
    STATE(10812), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484275] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10154), 1,
      sym_attribute,
    STATE(11087), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484343] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10155), 1,
      sym_attribute,
    STATE(11088), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484411] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10156), 1,
      sym_attribute,
    STATE(11090), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484479] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [484519] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10158), 1,
      sym_attribute,
    STATE(10919), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8136), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8138), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [484627] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10160), 1,
      sym_attribute,
    STATE(11143), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484695] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10161), 1,
      sym_attribute,
    STATE(11215), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484763] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10162), 1,
      sym_attribute,
    STATE(11236), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [484831] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [484871] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12289), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12287), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [484911] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12293), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12291), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [484951] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(11989), 1,
      sym__lowercase_identifier,
    ACTIONS(11991), 1,
      anon_sym_let,
    ACTIONS(11993), 1,
      anon_sym_LPAREN,
    ACTIONS(11997), 1,
      anon_sym_LBRACK,
    ACTIONS(11999), 1,
      anon_sym_fun,
    STATE(2600), 1,
      sym__simple_class_expression,
    STATE(9487), 1,
      sym__class_expression,
    STATE(10166), 1,
      sym_attribute,
    STATE(19557), 1,
      sym_module_path,
    STATE(21009), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8758), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485019] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8140), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8142), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [485059] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [485099] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8144), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8146), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [485139] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(11989), 1,
      sym__lowercase_identifier,
    ACTIONS(11991), 1,
      anon_sym_let,
    ACTIONS(11993), 1,
      anon_sym_LPAREN,
    ACTIONS(11997), 1,
      anon_sym_LBRACK,
    ACTIONS(11999), 1,
      anon_sym_fun,
    STATE(2600), 1,
      sym__simple_class_expression,
    STATE(9496), 1,
      sym__class_expression,
    STATE(10170), 1,
      sym_attribute,
    STATE(19557), 1,
      sym_module_path,
    STATE(21009), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8758), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8148), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8150), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [485247] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    ACTIONS(12295), 1,
      anon_sym_STAR,
    STATE(10172), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(11721), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12025), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [485301] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [485341] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [485381] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10175), 1,
      sym_attribute,
    STATE(10887), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [485489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12299), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12297), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [485529] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10178), 1,
      sym_attribute,
    STATE(10934), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485597] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10179), 1,
      sym_attribute,
    STATE(10937), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485665] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10180), 1,
      sym_attribute,
    STATE(10941), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485733] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      anon_sym_LBRACK,
    STATE(10181), 1,
      sym_attribute,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11733), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12305), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [485785] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10182), 1,
      sym_attribute,
    STATE(10934), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485853] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10183), 1,
      sym_attribute,
    STATE(10937), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [485921] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8152), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8154), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [485961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8156), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8158), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [486001] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8160), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8162), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [486041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8164), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8166), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [486081] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8168), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8170), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [486121] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10189), 1,
      sym_attribute,
    STATE(11117), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486189] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10190), 1,
      sym_attribute,
    STATE(11160), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486257] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(9570), 1,
      sym__class_expression,
    STATE(10191), 1,
      sym_attribute,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486325] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(9570), 1,
      sym__class_expression,
    STATE(10192), 1,
      sym_attribute,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486393] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10193), 1,
      sym_attribute,
    STATE(11221), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486461] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8172), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8174), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [486501] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8332), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [486541] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10196), 1,
      sym_attribute,
    STATE(10863), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486609] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    ACTIONS(12307), 1,
      anon_sym_STAR,
    STATE(10197), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [486661] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10198), 1,
      sym_attribute,
    STATE(10941), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486729] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [486769] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10200), 1,
      sym_attribute,
    STATE(11227), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486837] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10201), 1,
      sym_attribute,
    STATE(11085), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486905] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10202), 1,
      sym_attribute,
    STATE(11231), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [486973] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10203), 1,
      sym_attribute,
    STATE(11087), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8340), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [487081] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10205), 1,
      sym_attribute,
    STATE(11088), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487149] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(9487), 1,
      sym__class_expression,
    STATE(10206), 1,
      sym_attribute,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487217] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(9496), 1,
      sym__class_expression,
    STATE(10207), 1,
      sym_attribute,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487285] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10208), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11604), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [487341] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10209), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11610), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [487397] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10210), 1,
      sym_attribute,
    STATE(11090), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487465] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10211), 1,
      sym_attribute,
    STATE(11221), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487533] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10212), 1,
      sym_attribute,
    STATE(11215), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487601] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10213), 1,
      sym_attribute,
    STATE(11227), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487669] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10214), 1,
      sym_attribute,
    STATE(11231), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [487737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8282), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [487777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8344), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [487817] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8176), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8178), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [487857] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8180), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8182), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [487897] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8308), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [487937] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10220), 1,
      sym_attribute,
    STATE(10812), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488005] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10221), 1,
      sym_attribute,
    STATE(10919), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488073] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6179), 1,
      anon_sym_object,
    ACTIONS(8654), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8656), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12090), 1,
      sym__lowercase_identifier,
    ACTIONS(12092), 1,
      anon_sym_let,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      anon_sym_LBRACK,
    ACTIONS(12098), 1,
      anon_sym_fun,
    STATE(2567), 1,
      sym__simple_class_expression,
    STATE(10222), 1,
      sym_attribute,
    STATE(11236), 1,
      sym__class_expression,
    STATE(19347), 1,
      sym_value_definition,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7768), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488141] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12117), 1,
      sym__lowercase_identifier,
    ACTIONS(12119), 1,
      anon_sym_let,
    ACTIONS(12121), 1,
      anon_sym_LPAREN,
    ACTIONS(12123), 1,
      anon_sym_LBRACK,
    ACTIONS(12125), 1,
      anon_sym_object,
    ACTIONS(12127), 1,
      anon_sym_fun,
    ACTIONS(12129), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12131), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2546), 1,
      sym__simple_class_expression,
    STATE(10223), 1,
      sym_attribute,
    STATE(10887), 1,
      sym__class_expression,
    STATE(18515), 1,
      sym_module_path,
    STATE(18645), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7617), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488209] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12277), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(10224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [488253] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(9487), 1,
      sym__class_expression,
    STATE(10225), 1,
      sym_attribute,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488321] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(9496), 1,
      sym__class_expression,
    STATE(10226), 1,
      sym_attribute,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488389] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7935), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7937), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488429] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [488491] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [488531] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10230), 1,
      sym_attribute,
    STATE(11085), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [488599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8354), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8358), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488679] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7939), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7941), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7943), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7945), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488759] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12311), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12309), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [488799] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [488841] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12076), 1,
      anon_sym_DOT,
    ACTIONS(12078), 1,
      anon_sym_POUND,
    ACTIONS(12080), 1,
      sym_hash_operator,
    STATE(10237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9812), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9810), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488887] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8188), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8190), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [488927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12315), 3,
      anon_sym_let,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12313), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [488967] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10240), 1,
      sym_attribute,
    STATE(11087), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489035] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12319), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10241), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12317), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [489081] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10242), 1,
      sym_attribute,
    STATE(10934), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489149] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10243), 1,
      sym_attribute,
    STATE(10937), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489217] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10244), 1,
      sym_attribute,
    STATE(11088), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489285] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489325] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10246), 1,
      sym_attribute,
    STATE(10941), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489393] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8192), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8194), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [489433] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8196), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8198), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [489473] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10249), 1,
      sym_attribute,
    STATE(11090), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [489621] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(10252), 1,
      sym_attribute,
    STATE(16409), 1,
      sym__class_expression,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489689] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12323), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12321), 23,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [489729] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(12325), 1,
      anon_sym_POUND,
    STATE(10254), 1,
      sym_attribute,
    STATE(10715), 1,
      sym_type_constructor_path,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [489779] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10255), 1,
      sym_attribute,
    STATE(11085), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489847] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10256), 1,
      sym_attribute,
    STATE(11221), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489915] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10257), 1,
      sym_attribute,
    STATE(11227), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [489983] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10258), 1,
      sym_attribute,
    STATE(11087), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490051] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10259), 1,
      sym_attribute,
    STATE(11231), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490119] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10260), 1,
      sym_attribute,
    STATE(11088), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490187] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [490227] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10262), 1,
      sym_attribute,
    STATE(11090), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490295] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(10263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [490337] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [490379] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10265), 1,
      sym_attribute,
    STATE(10887), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490447] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [490489] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(10267), 1,
      sym_attribute,
    STATE(16057), 1,
      sym__class_expression,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490557] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10268), 1,
      sym_attribute,
    STATE(11221), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490625] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10269), 1,
      sym_attribute,
    STATE(10909), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490693] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12181), 1,
      anon_sym_SEMI,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [490757] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10271), 1,
      sym_attribute,
    STATE(11227), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7951), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7953), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [490865] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6811), 1,
      anon_sym_object,
    ACTIONS(8682), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8684), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(11989), 1,
      sym__lowercase_identifier,
    ACTIONS(11991), 1,
      anon_sym_let,
    ACTIONS(11993), 1,
      anon_sym_LPAREN,
    ACTIONS(11997), 1,
      anon_sym_LBRACK,
    ACTIONS(11999), 1,
      anon_sym_fun,
    STATE(2600), 1,
      sym__simple_class_expression,
    STATE(10273), 1,
      sym_attribute,
    STATE(13686), 1,
      sym__class_expression,
    STATE(19557), 1,
      sym_module_path,
    STATE(21009), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8758), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [490933] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [490973] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10275), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11604), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [491029] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10276), 1,
      sym_attribute,
    STATE(11231), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [491097] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7955), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7957), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491137] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12221), 1,
      sym__lowercase_identifier,
    ACTIONS(12223), 1,
      anon_sym_let,
    ACTIONS(12225), 1,
      anon_sym_LPAREN,
    ACTIONS(12227), 1,
      anon_sym_LBRACK,
    ACTIONS(12229), 1,
      anon_sym_object,
    ACTIONS(12231), 1,
      anon_sym_fun,
    ACTIONS(12233), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(12235), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(2550), 1,
      sym__simple_class_expression,
    STATE(10278), 1,
      sym_attribute,
    STATE(10887), 1,
      sym__class_expression,
    STATE(18627), 1,
      sym_module_path,
    STATE(19196), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(7554), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [491205] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8312), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491285] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(10281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8300), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8302), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491327] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10282), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11610), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [491383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8316), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491423] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10284), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [491473] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7831), 1,
      anon_sym_object,
    ACTIONS(7843), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7845), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12100), 1,
      sym__lowercase_identifier,
    ACTIONS(12102), 1,
      anon_sym_let,
    ACTIONS(12104), 1,
      anon_sym_LPAREN,
    ACTIONS(12106), 1,
      anon_sym_LBRACK,
    ACTIONS(12108), 1,
      anon_sym_fun,
    STATE(3030), 1,
      sym__simple_class_expression,
    STATE(10285), 1,
      sym_attribute,
    STATE(16350), 1,
      sym__class_expression,
    STATE(19899), 1,
      sym_value_definition,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(10520), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [491541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8320), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491581] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12076), 1,
      anon_sym_DOT,
    ACTIONS(12078), 1,
      anon_sym_POUND,
    ACTIONS(12080), 1,
      sym_hash_operator,
    STATE(10287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9816), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9814), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491627] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8324), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491667] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491707] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8200), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8202), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491747] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8070), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491787] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8326), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8328), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [491827] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    ACTIONS(12155), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12157), 1,
      sym_pow_operator,
    ACTIONS(12159), 1,
      sym_mult_operator,
    ACTIONS(12161), 1,
      sym_concat_operator,
    ACTIONS(12163), 1,
      sym_rel_operator,
    ACTIONS(12165), 1,
      sym_and_operator,
    ACTIONS(12167), 1,
      sym_or_operator,
    ACTIONS(12177), 1,
      sym_assign_operator,
    ACTIONS(12249), 1,
      anon_sym_SEMI,
    STATE(1881), 1,
      sym_add_operator,
    STATE(10293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [491891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [491931] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10295), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11650), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [491987] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12076), 1,
      anon_sym_DOT,
    ACTIONS(12078), 1,
      anon_sym_POUND,
    ACTIONS(12080), 1,
      sym_hash_operator,
    STATE(10296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9718), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9716), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [492033] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492073] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    STATE(10298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 16,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [492115] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8362), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8364), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [492155] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    ACTIONS(12181), 1,
      anon_sym_SEMI,
    ACTIONS(12183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12185), 1,
      sym_pow_operator,
    ACTIONS(12187), 1,
      sym_mult_operator,
    ACTIONS(12189), 1,
      sym_concat_operator,
    ACTIONS(12191), 1,
      sym_rel_operator,
    ACTIONS(12193), 1,
      sym_and_operator,
    ACTIONS(12195), 1,
      sym_or_operator,
    ACTIONS(12197), 1,
      sym_assign_operator,
    STATE(2015), 1,
      sym_add_operator,
    STATE(10300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 10,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [492219] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8074), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [492259] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12327), 1,
      anon_sym_COLON,
    STATE(10302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10081), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10079), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [492301] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12319), 1,
      anon_sym_let,
    STATE(9985), 1,
      aux_sym_expression_item_repeat1,
    STATE(10303), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12317), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [492347] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492387] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7947), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(7949), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [492427] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 15,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [492467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8220), 9,
      anon_sym_and,
      anon_sym_PIPE,
      anon_sym_POUND,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(8222), 16,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_hash_operator,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [492507] = 19,
    ACTIONS(419), 1,
      sym_let_operator,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6399), 1,
      anon_sym_object,
    ACTIONS(8664), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8666), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(12199), 1,
      sym__lowercase_identifier,
    ACTIONS(12201), 1,
      anon_sym_let,
    ACTIONS(12203), 1,
      anon_sym_LPAREN,
    ACTIONS(12205), 1,
      anon_sym_LBRACK,
    ACTIONS(12207), 1,
      anon_sym_fun,
    STATE(2583), 1,
      sym__simple_class_expression,
    STATE(10308), 1,
      sym_attribute,
    STATE(10919), 1,
      sym__class_expression,
    STATE(18682), 1,
      sym_module_path,
    STATE(19587), 1,
      sym_value_definition,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9616), 4,
      sym_class_function,
      sym_class_application,
      sym_let_class_expression,
      sym_let_open_class_expression,
    STATE(8145), 7,
      sym_instantiated_class,
      sym_typed_class_expression,
      sym_parenthesized_class_expression,
      sym_object_expression,
      sym_extension,
      sym_quoted_extension,
      sym_class_path,
  [492575] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10309), 1,
      sym_attribute,
    STATE(10961), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [492638] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10310), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492687] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10284), 1,
      sym__simple_type,
    STATE(10311), 1,
      sym_attribute,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [492750] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10312), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12213), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492799] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_LBRACK_AT_AT,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [492854] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10314), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12343), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492903] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10315), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12347), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [492952] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10316), 1,
      sym_attribute,
    STATE(11107), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493015] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10317), 1,
      sym_attribute,
    STATE(12378), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493117] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    STATE(10319), 1,
      sym_attribute,
    STATE(14793), 1,
      sym__simple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493180] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    STATE(10320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 8,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 15,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [493221] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493260] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10322), 1,
      sym_attribute,
    STATE(12379), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493323] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493362] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(10324), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [493417] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493456] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9554), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9556), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [493495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493573] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493612] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12331), 1,
      sym_pow_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [493655] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [493716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493755] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12363), 1,
      anon_sym_let,
    ACTIONS(12365), 1,
      anon_sym_DQUOTE,
    STATE(10333), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11169), 1,
      aux_sym_external_repeat1,
    STATE(11434), 1,
      aux_sym_expression_item_repeat1,
    STATE(11648), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12361), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [493806] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(10334), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [493861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [493900] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(9593), 1,
      sym__simple_type,
    STATE(10336), 1,
      sym_attribute,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [493963] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(10337), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [494018] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12367), 1,
      anon_sym_LPAREN,
    ACTIONS(12369), 1,
      anon_sym_LBRACK,
    STATE(10338), 1,
      sym_attribute,
    STATE(11303), 1,
      sym__constructor_name,
    STATE(12370), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12371), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [494069] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11191), 1,
      anon_sym_STAR,
    STATE(10339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11160), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11158), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [494110] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494149] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10341), 1,
      sym_attribute,
    STATE(11450), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494212] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(9793), 1,
      sym__simple_type,
    STATE(10342), 1,
      sym_attribute,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494275] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10814), 1,
      anon_sym_LPAREN,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10824), 1,
      anon_sym_LT,
    ACTIONS(10826), 1,
      anon_sym_POUND,
    ACTIONS(10828), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10830), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10832), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12373), 1,
      sym__lowercase_identifier,
    STATE(10343), 1,
      sym_attribute,
    STATE(13456), 1,
      sym__simple_type,
    STATE(17607), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13684), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494338] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    ACTIONS(12375), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [494401] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10345), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [494456] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10346), 1,
      sym_attribute,
    STATE(11492), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494519] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10347), 1,
      sym_attribute,
    STATE(11499), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494582] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10348), 1,
      sym_attribute,
    STATE(12388), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494645] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12357), 1,
      sym_or_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [494702] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10350), 1,
      sym_attribute,
    STATE(10681), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494765] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10351), 1,
      sym_attribute,
    STATE(12391), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [494867] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10353), 1,
      sym_attribute,
    STATE(12392), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [494930] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12381), 1,
      anon_sym_LPAREN,
    ACTIONS(12383), 1,
      anon_sym_LBRACK,
    STATE(10354), 1,
      sym_attribute,
    STATE(11528), 1,
      sym__constructor_name,
    STATE(12389), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12385), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [494981] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10355), 1,
      sym_attribute,
    STATE(12394), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495044] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10356), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [495093] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10697), 1,
      anon_sym_LPAREN,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10707), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_POUND,
    ACTIONS(10711), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10713), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10715), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12387), 1,
      sym__lowercase_identifier,
    STATE(9394), 1,
      sym__simple_type,
    STATE(10357), 1,
      sym_attribute,
    STATE(17263), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10297), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495156] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10312), 1,
      sym__simple_type,
    STATE(10358), 1,
      sym_attribute,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495219] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10359), 1,
      sym_attribute,
    STATE(11233), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495321] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10361), 1,
      sym_attribute,
    STATE(10836), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495384] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12389), 1,
      aux_sym_attribute_id_token1,
    STATE(10362), 1,
      sym_attribute,
    STATE(10475), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8772), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8774), 13,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [495427] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10363), 1,
      sym_attribute,
    STATE(11163), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495490] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12391), 1,
      anon_sym_POUND,
    STATE(10364), 1,
      sym_attribute,
    STATE(11148), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 9,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [495539] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495578] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12393), 1,
      anon_sym_COLON2,
    STATE(10366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495619] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10367), 1,
      sym_attribute,
    STATE(11120), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495682] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10368), 1,
      sym_attribute,
    STATE(11136), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495745] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10369), 1,
      sym_attribute,
    STATE(11235), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495808] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [495847] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12399), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12397), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10371), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [495890] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10729), 1,
      anon_sym_LPAREN,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10739), 1,
      anon_sym_LT,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(10743), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10745), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10747), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12402), 1,
      sym__lowercase_identifier,
    STATE(9316), 1,
      sym__simple_type,
    STATE(10372), 1,
      sym_attribute,
    STATE(18259), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9836), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [495953] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10059), 1,
      sym__simple_type,
    STATE(10373), 1,
      sym_attribute,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [496016] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9182), 1,
      sym__lowercase_identifier,
    ACTIONS(12404), 1,
      anon_sym_COLON2,
    STATE(10374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11577), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11575), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [496061] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10375), 1,
      sym_attribute,
    STATE(10629), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [496124] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8568), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8570), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [496163] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12406), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12397), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(10377), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [496206] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    ACTIONS(12375), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [496269] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    ACTIONS(12409), 1,
      anon_sym_STAR,
    STATE(10379), 1,
      sym_attribute,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(12287), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12025), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [496322] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [496361] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12413), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12411), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [496400] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10663), 1,
      anon_sym_LPAREN,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10673), 1,
      anon_sym_LT,
    ACTIONS(10675), 1,
      anon_sym_POUND,
    ACTIONS(10677), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10679), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10681), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12415), 1,
      sym__lowercase_identifier,
    STATE(10382), 1,
      sym_attribute,
    STATE(13670), 1,
      sym__simple_type,
    STATE(17664), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13965), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [496463] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11479), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11481), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [496504] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [496543] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10385), 1,
      sym_attribute,
    STATE(10472), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [496606] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10386), 1,
      sym_attribute,
    STATE(10476), 1,
      sym__simple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [496669] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12417), 1,
      anon_sym_EQ,
    ACTIONS(12419), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10387), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11116), 1,
      aux_sym_expression_item_repeat1,
    STATE(11325), 1,
      sym__type_equation,
    STATE(11700), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11975), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [496726] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [496765] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(10389), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11604), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [496820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [496859] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [496898] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10392), 1,
      sym_attribute,
    STATE(10478), 1,
      sym__simple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [496961] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10393), 1,
      sym_attribute,
    STATE(10634), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497024] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10394), 1,
      sym_attribute,
    STATE(10507), 1,
      sym__simple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497087] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10395), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [497142] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10396), 1,
      sym_attribute,
    STATE(11183), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497205] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    ACTIONS(12427), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [497268] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10398), 1,
      sym_attribute,
    STATE(10537), 1,
      sym__simple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497331] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [497372] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10400), 1,
      sym_attribute,
    STATE(10471), 1,
      sym__simple_type,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497435] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    STATE(10401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 16,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [497476] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10315), 1,
      sym__simple_type,
    STATE(10402), 1,
      sym_attribute,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497539] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10403), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [497594] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10007), 1,
      anon_sym_LPAREN,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10015), 1,
      anon_sym_LT,
    ACTIONS(10017), 1,
      anon_sym_POUND,
    ACTIONS(10019), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10021), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10023), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    STATE(10404), 1,
      sym_attribute,
    STATE(11661), 1,
      sym__simple_type,
    STATE(17393), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11726), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497657] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10405), 1,
      sym_attribute,
    STATE(11291), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497720] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10406), 1,
      sym_attribute,
    STATE(14444), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [497822] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10408), 1,
      sym_attribute,
    STATE(14627), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [497885] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [497924] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [497963] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10411), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11610), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [498018] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10412), 1,
      sym_attribute,
    STATE(14334), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498081] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10413), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [498136] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10414), 1,
      sym_attribute,
    STATE(14556), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498199] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10415), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [498254] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10416), 1,
      sym_attribute,
    STATE(10693), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498317] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10417), 1,
      sym_attribute,
    STATE(14562), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498380] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9956), 1,
      anon_sym_LPAREN,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9964), 1,
      anon_sym_LT,
    ACTIONS(9966), 1,
      anon_sym_POUND,
    ACTIONS(9968), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9970), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9972), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12429), 1,
      sym__lowercase_identifier,
    STATE(10418), 1,
      sym_attribute,
    STATE(11750), 1,
      sym__simple_type,
    STATE(17801), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12545), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498443] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10419), 1,
      sym_attribute,
    STATE(14273), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498506] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10420), 1,
      sym_attribute,
    STATE(10660), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498569] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7292), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7294), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(11265), 1,
      anon_sym_LPAREN,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11273), 1,
      anon_sym_LT,
    ACTIONS(11275), 1,
      anon_sym_POUND,
    ACTIONS(11277), 1,
      aux_sym_type_variable_token1,
    STATE(10421), 1,
      sym_attribute,
    STATE(14606), 1,
      sym__simple_type,
    STATE(17210), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14544), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498632] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12365), 1,
      anon_sym_DQUOTE,
    ACTIONS(12433), 1,
      anon_sym_let,
    STATE(10422), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11169), 1,
      aux_sym_external_repeat1,
    STATE(11405), 1,
      aux_sym_expression_item_repeat1,
    STATE(11648), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12431), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [498683] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10423), 1,
      sym_attribute,
    STATE(10712), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498746] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10169), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10171), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(11299), 1,
      anon_sym_LPAREN,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11307), 1,
      anon_sym_LT,
    ACTIONS(11309), 1,
      anon_sym_POUND,
    ACTIONS(11311), 1,
      aux_sym_type_variable_token1,
    STATE(10424), 1,
      sym_attribute,
    STATE(10763), 1,
      sym__simple_type,
    STATE(17454), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10604), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498809] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10425), 1,
      sym_attribute,
    STATE(10442), 1,
      sym__simple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498872] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    ACTIONS(12427), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [498935] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10790), 1,
      anon_sym_LPAREN,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10800), 1,
      anon_sym_LT,
    ACTIONS(10802), 1,
      anon_sym_POUND,
    ACTIONS(10804), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10806), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10808), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12435), 1,
      sym__lowercase_identifier,
    STATE(9299), 1,
      sym__simple_type,
    STATE(10427), 1,
      sym_attribute,
    STATE(17378), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9395), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [498998] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    ACTIONS(12375), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [499061] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(9433), 1,
      sym__simple_type,
    STATE(10429), 1,
      sym_attribute,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499124] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10430), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11650), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [499179] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 11,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_assign_operator,
  [499238] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10310), 1,
      sym__simple_type,
    STATE(10432), 1,
      sym_attribute,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499301] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9424), 1,
      anon_sym_LT,
    ACTIONS(9426), 1,
      anon_sym_POUND,
    ACTIONS(9428), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9430), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9432), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10843), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    STATE(10433), 1,
      sym_attribute,
    STATE(10746), 1,
      sym__simple_type,
    STATE(17616), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10467), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499364] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10434), 1,
      sym_attribute,
    STATE(11382), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499427] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9620), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [499466] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10436), 1,
      sym_attribute,
    STATE(11390), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499529] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10437), 1,
      sym_attribute,
    STATE(11409), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499592] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10438), 1,
      sym_attribute,
    STATE(11460), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499655] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8080), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8082), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [499694] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10440), 1,
      sym_attribute,
    STATE(11456), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499757] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10441), 1,
      sym_attribute,
    STATE(11488), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499820] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10442), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [499869] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10443), 1,
      sym_attribute,
    STATE(11288), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [499932] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9558), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9560), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [499971] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [500022] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10446), 1,
      sym_attribute,
    STATE(10837), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500085] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10447), 1,
      sym_attribute,
    STATE(10642), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500148] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10448), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11604), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [500203] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10356), 1,
      sym__simple_type,
    STATE(10449), 1,
      sym_attribute,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500266] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10450), 1,
      sym_attribute,
    STATE(10643), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500329] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    STATE(10451), 1,
      sym_attribute,
    STATE(14486), 1,
      sym__simple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [500431] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10453), 1,
      sym_attribute,
    STATE(10673), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500494] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10454), 1,
      sym_attribute,
    STATE(10519), 1,
      sym__simple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500557] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [500596] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9184), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(12419), 1,
      anon_sym_COLON_EQ,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    ACTIONS(12437), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10456), 1,
      sym_attribute,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11101), 1,
      aux_sym_expression_item_repeat1,
    STATE(11321), 1,
      sym__type_equation,
    STATE(11681), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11920), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [500653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8290), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [500692] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10314), 1,
      sym__simple_type,
    STATE(10458), 1,
      sym_attribute,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500755] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(10459), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11610), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [500810] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10460), 1,
      sym_attribute,
    STATE(10699), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500873] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10461), 1,
      sym_attribute,
    STATE(10700), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500936] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10462), 1,
      sym_attribute,
    STATE(10717), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [500999] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12441), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12439), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [501038] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [501077] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [501116] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9328), 1,
      anon_sym_LT,
    ACTIONS(9330), 1,
      anon_sym_POUND,
    ACTIONS(9332), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9334), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9338), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    STATE(10466), 1,
      sym_attribute,
    STATE(10524), 1,
      sym__simple_type,
    STATE(17350), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9868), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [501179] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [501218] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(10468), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11650), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501273] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [501334] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    ACTIONS(12427), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [501397] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10471), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12343), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501446] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10472), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12213), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8294), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [501534] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8022), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [501573] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12389), 1,
      aux_sym_attribute_id_token1,
    STATE(10475), 1,
      sym_attribute,
    STATE(10498), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8766), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8768), 13,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [501616] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10476), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11589), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [501704] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10478), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [501753] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12443), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      anon_sym_LBRACK,
    STATE(10479), 1,
      sym_attribute,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11971), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12447), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [501804] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12331), 1,
      sym_pow_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [501847] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9864), 1,
      anon_sym_LT,
    ACTIONS(9866), 1,
      anon_sym_POUND,
    ACTIONS(9868), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9870), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9872), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12449), 1,
      sym__lowercase_identifier,
    STATE(10481), 1,
      sym_attribute,
    STATE(12796), 1,
      sym__simple_type,
    STATE(17202), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13511), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [501910] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10482), 1,
      sym_attribute,
    STATE(11340), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [501973] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(8298), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
  [502012] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10484), 1,
      sym_attribute,
    STATE(11617), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502075] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    ACTIONS(12451), 1,
      anon_sym_STAR,
    STATE(10485), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(12302), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12025), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [502128] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9362), 1,
      anon_sym_LT,
    ACTIONS(9364), 1,
      anon_sym_POUND,
    ACTIONS(9366), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9368), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9370), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10852), 1,
      anon_sym_LPAREN,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    STATE(10045), 1,
      sym__simple_type,
    STATE(10486), 1,
      sym_attribute,
    STATE(18252), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9766), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502191] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10487), 1,
      sym_attribute,
    STATE(10617), 1,
      sym__simple_type,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502254] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10488), 1,
      sym_attribute,
    STATE(11731), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502317] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [502356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [502395] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10491), 1,
      sym_attribute,
    STATE(10619), 1,
      sym__simple_type,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502458] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10492), 1,
      sym_attribute,
    STATE(10592), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502521] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10493), 1,
      sym_attribute,
    STATE(11604), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502584] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [502623] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10495), 1,
      sym_attribute,
    STATE(11568), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502686] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [502735] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [502780] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12453), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10498), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8755), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8757), 13,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [502821] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10499), 1,
      sym_attribute,
    STATE(11411), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502884] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10500), 1,
      sym_attribute,
    STATE(11633), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [502947] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [502986] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(10502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [503027] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10503), 1,
      sym_attribute,
    STATE(10637), 1,
      sym__simple_type,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503090] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    ACTIONS(12337), 1,
      sym_rel_operator,
    ACTIONS(12339), 1,
      sym_and_operator,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    ACTIONS(12357), 1,
      sym_or_operator,
    ACTIONS(12359), 1,
      sym_assign_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 10,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [503151] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10505), 1,
      sym_attribute,
    STATE(10664), 1,
      sym__simple_type,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503214] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [503253] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10507), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [503302] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7195), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(7197), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(7659), 1,
      anon_sym_LT,
    ACTIONS(7661), 1,
      anon_sym_POUND,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    STATE(10508), 1,
      sym_attribute,
    STATE(12485), 1,
      sym__simple_type,
    STATE(18040), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13276), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503365] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [503404] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10510), 1,
      sym_attribute,
    STATE(10665), 1,
      sym__simple_type,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503467] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10063), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10065), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(11315), 1,
      anon_sym_LPAREN,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11323), 1,
      anon_sym_LT,
    ACTIONS(11325), 1,
      anon_sym_POUND,
    ACTIONS(11327), 1,
      aux_sym_type_variable_token1,
    STATE(10511), 1,
      sym_attribute,
    STATE(10668), 1,
      sym__simple_type,
    STATE(17243), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10767), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503530] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10512), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [503585] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10513), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11650), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [503640] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(11359), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11367), 1,
      anon_sym_LT,
    ACTIONS(11369), 1,
      anon_sym_POUND,
    ACTIONS(11371), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11373), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11375), 1,
      aux_sym_type_variable_token1,
    STATE(10514), 1,
      sym_attribute,
    STATE(11442), 1,
      sym__simple_type,
    STATE(17655), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11388), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [503742] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9396), 1,
      anon_sym_LT,
    ACTIONS(9398), 1,
      anon_sym_POUND,
    ACTIONS(9400), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9402), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9404), 1,
      aux_sym_type_variable_token1,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    STATE(10516), 1,
      sym_attribute,
    STATE(10542), 1,
      sym__simple_type,
    STATE(18272), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10280), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503805] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10517), 1,
      sym_attribute,
    STATE(10904), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503868] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10518), 1,
      sym_attribute,
    STATE(11736), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [503931] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10519), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12458), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [503980] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9534), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9536), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [504019] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9182), 1,
      sym__lowercase_identifier,
    ACTIONS(12404), 1,
      anon_sym_COLON2,
    STATE(10521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11577), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11575), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [504064] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10522), 1,
      sym_attribute,
    STATE(11339), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504127] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10523), 1,
      sym_attribute,
    STATE(10897), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504190] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11281), 1,
      sym__lowercase_identifier,
    ACTIONS(11455), 1,
      anon_sym_POUND,
    STATE(9936), 1,
      sym_type_constructor_path,
    STATE(10524), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12347), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [504239] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9566), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9568), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [504278] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10526), 1,
      sym_attribute,
    STATE(11506), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504341] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(9934), 1,
      anon_sym_LPAREN,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(9942), 1,
      anon_sym_LT,
    ACTIONS(9944), 1,
      anon_sym_POUND,
    ACTIONS(9946), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(9948), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(9950), 1,
      aux_sym_type_variable_token1,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(10527), 1,
      sym_attribute,
    STATE(11678), 1,
      sym__simple_type,
    STATE(17544), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11401), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504404] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10528), 1,
      sym_attribute,
    STATE(10869), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504467] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10529), 1,
      sym_attribute,
    STATE(11517), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504530] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11577), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [504569] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(11215), 1,
      anon_sym_LPAREN,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11223), 1,
      anon_sym_LT,
    ACTIONS(11225), 1,
      anon_sym_POUND,
    ACTIONS(11227), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(11229), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11231), 1,
      aux_sym_type_variable_token1,
    STATE(10531), 1,
      sym_attribute,
    STATE(11286), 1,
      sym__simple_type,
    STATE(18409), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11349), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504632] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10532), 1,
      sym_attribute,
    STATE(10873), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504695] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10209), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10211), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(11337), 1,
      anon_sym_LPAREN,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11345), 1,
      anon_sym_LT,
    ACTIONS(11347), 1,
      anon_sym_POUND,
    ACTIONS(11349), 1,
      aux_sym_type_variable_token1,
    STATE(10533), 1,
      sym_attribute,
    STATE(11175), 1,
      sym__simple_type,
    STATE(17956), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10928), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [504758] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11162), 1,
      anon_sym_STAR,
    STATE(10534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11160), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11158), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [504799] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12460), 1,
      anon_sym_COLON,
    STATE(10535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9546), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9548), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [504840] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12464), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12462), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [504879] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11383), 1,
      sym__lowercase_identifier,
    ACTIONS(11606), 1,
      anon_sym_POUND,
    STATE(9893), 1,
      sym_type_constructor_path,
    STATE(10537), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12458), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [504928] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10538), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11604), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [504983] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 14,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [505022] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10540), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11610), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [505077] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 13,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [505118] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10542), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12213), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [505167] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11019), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [505206] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12329), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12331), 1,
      sym_pow_operator,
    ACTIONS(12333), 1,
      sym_mult_operator,
    ACTIONS(12335), 1,
      sym_concat_operator,
    STATE(2237), 1,
      sym_add_operator,
    STATE(10544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_LBRACK_AT_AT,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_rel_operator,
      sym_assign_operator,
  [505257] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10509), 1,
      anon_sym_LPAREN,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10519), 1,
      anon_sym_LT,
    ACTIONS(10521), 1,
      anon_sym_POUND,
    ACTIONS(10523), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10525), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10527), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12466), 1,
      sym__lowercase_identifier,
    STATE(9296), 1,
      sym__simple_type,
    STATE(10545), 1,
      sym_attribute,
    STATE(17493), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9442), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [505320] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12472), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10546), 1,
      sym_attribute,
    STATE(10548), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12470), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12468), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505365] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12472), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10547), 1,
      sym_attribute,
    STATE(10549), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12476), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12474), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505410] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12472), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10371), 1,
      aux_sym_type_binding_repeat1,
    STATE(10548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12480), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12478), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505455] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12472), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10371), 1,
      aux_sym_type_binding_repeat1,
    STATE(10549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12484), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12482), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505500] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12486), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10550), 1,
      sym_attribute,
    STATE(10552), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12470), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12468), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505545] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12486), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10551), 1,
      sym_attribute,
    STATE(10553), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12476), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12474), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505590] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12486), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10377), 1,
      aux_sym_type_binding_repeat1,
    STATE(10552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12480), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12478), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505635] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12486), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10377), 1,
      aux_sym_type_binding_repeat1,
    STATE(10553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12484), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12482), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [505680] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(12488), 1,
      anon_sym_COLON2,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10554), 1,
      sym_attribute,
    STATE(10925), 1,
      aux_sym_expression_item_repeat1,
    STATE(11267), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12283), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(11934), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [505735] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(12488), 1,
      anon_sym_COLON2,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10554), 1,
      aux_sym_module_binding_repeat1,
    STATE(10555), 1,
      sym_attribute,
    STATE(11162), 1,
      aux_sym_expression_item_repeat1,
    STATE(11358), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12215), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(12011), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [505790] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10185), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(10187), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(11389), 1,
      anon_sym_LPAREN,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(11397), 1,
      anon_sym_LT,
    ACTIONS(11399), 1,
      anon_sym_POUND,
    ACTIONS(11401), 1,
      aux_sym_type_variable_token1,
    STATE(10556), 1,
      sym_attribute,
    STATE(10949), 1,
      sym__simple_type,
    STATE(18267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11274), 11,
      sym_constructed_type,
      sym_local_open_type,
      sym_polymorphic_variant_type,
      sym_package_type,
      sym_object_type,
      sym_hash_type,
      sym_parenthesized_type,
      sym_extension,
      sym_quoted_extension,
      sym_type_constructor_path,
      sym_type_variable,
  [505853] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9562), 10,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(9564), 14,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON2,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [505892] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9642), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9644), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [505930] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10559), 1,
      sym_attribute,
    STATE(11526), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16034), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [505996] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12506), 1,
      anon_sym_RPAREN,
    ACTIONS(12508), 1,
      anon_sym__,
    ACTIONS(12510), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10560), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16795), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [506062] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11479), 1,
      sym__lowercase_identifier,
    STATE(10561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12297), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12299), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [506104] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8354), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506142] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10563), 1,
      sym_attribute,
    STATE(11510), 1,
      sym__attribute,
    STATE(11849), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [506208] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12516), 1,
      anon_sym_POUND,
    STATE(10564), 1,
      sym_attribute,
    STATE(11462), 1,
      sym_type_constructor_path,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [506256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506332] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506370] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506408] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10569), 1,
      sym_attribute,
    STATE(11531), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16351), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [506474] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9184), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506512] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    ACTIONS(12518), 1,
      anon_sym_STAR,
    STATE(10571), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(12441), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12025), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [506564] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9090), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9092), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506602] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9094), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9096), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506640] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10574), 1,
      sym_attribute,
    STATE(11373), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(15988), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [506706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506782] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506820] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506858] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506896] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [506934] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8294), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [506972] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [507012] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507050] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8022), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [507088] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10585), 1,
      sym_attribute,
    STATE(11335), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16536), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [507154] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9680), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9682), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [507192] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507230] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507268] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507306] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507344] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10591), 1,
      sym_attribute,
    STATE(11292), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16791), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [507410] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10592), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12213), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [507458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507496] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10594), 1,
      sym_attribute,
    STATE(11497), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(17167), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [507562] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507600] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507638] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507676] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11429), 1,
      anon_sym_STAR,
    STATE(10598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [507716] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [507756] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10600), 1,
      sym_attribute,
    STATE(11366), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(15963), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [507822] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8314), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8316), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [507860] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    ACTIONS(12520), 1,
      anon_sym_STAR,
    STATE(10602), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(12438), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12025), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [507912] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    ACTIONS(12522), 1,
      anon_sym_STAR,
    STATE(10603), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(12517), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12025), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [507964] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [508002] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [508040] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9622), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9624), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508078] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9626), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9628), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508116] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9634), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9636), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508154] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10609), 1,
      sym_attribute,
    STATE(11441), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16987), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [508220] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9638), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9640), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508258] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10611), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [508312] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12528), 1,
      anon_sym_POUND,
    STATE(10612), 1,
      sym_attribute,
    STATE(11341), 1,
      sym_type_constructor_path,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11108), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [508360] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9596), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9598), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508398] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10614), 1,
      sym_attribute,
    STATE(11513), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16188), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [508464] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9600), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9602), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508502] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12530), 1,
      anon_sym_POUND,
    STATE(10616), 1,
      sym_attribute,
    STATE(11468), 1,
      sym_type_constructor_path,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [508550] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10617), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [508598] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12532), 1,
      aux_sym_attribute_id_token1,
    STATE(10618), 1,
      sym_attribute,
    STATE(10635), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8772), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8774), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508640] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10619), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [508688] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    ACTIONS(12534), 1,
      anon_sym_STAR,
    STATE(10620), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [508738] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8755), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(8757), 14,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
  [508776] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8310), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8312), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508814] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10623), 1,
      sym_attribute,
    STATE(11258), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16616), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [508880] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9222), 1,
      sym__lowercase_identifier,
    STATE(10624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11589), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11587), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [508922] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8358), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508960] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8074), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [508998] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12538), 1,
      anon_sym_SEMI,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [509060] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10335), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10333), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [509120] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10629), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [509168] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10630), 1,
      sym_attribute,
    STATE(11264), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16907), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [509234] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [509274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [509312] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12556), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(10633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [509354] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10634), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [509402] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12532), 1,
      aux_sym_attribute_id_token1,
    STATE(10635), 1,
      sym_attribute,
    STATE(10720), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8766), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8768), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [509444] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10636), 1,
      sym_attribute,
    STATE(11422), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(15913), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [509510] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10637), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [509558] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9818), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9820), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [509596] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11479), 1,
      sym__lowercase_identifier,
    STATE(10639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12297), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12299), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [509638] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10640), 1,
      sym_attribute,
    STATE(11269), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16019), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [509704] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9826), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9828), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [509742] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10642), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [509790] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10643), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [509838] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9202), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9204), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [509876] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8290), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [509914] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10646), 1,
      sym_attribute,
    STATE(11317), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16158), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [509980] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10647), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11610), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [510034] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9684), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9686), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510072] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [510110] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10650), 1,
      sym_attribute,
    STATE(11378), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16282), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [510176] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [510214] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9688), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9690), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510252] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9222), 1,
      sym__lowercase_identifier,
    STATE(10653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11589), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11587), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [510294] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9692), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9694), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510332] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9696), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9698), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510370] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9700), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9702), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510408] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8322), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8324), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510446] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [510484] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [510522] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10660), 1,
      sym_attribute,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12458), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [510570] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [510608] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10662), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [510662] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10663), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [510716] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10664), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12458), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [510764] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10665), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12343), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [510812] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8298), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [510850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
    ACTIONS(11019), 12,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [510888] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11900), 1,
      sym__lowercase_identifier,
    ACTIONS(11902), 1,
      anon_sym_POUND,
    STATE(10668), 1,
      sym_attribute,
    STATE(10686), 1,
      sym_type_constructor_path,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12347), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [510936] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12025), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11451), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [510974] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12476), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12558), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10670), 1,
      sym_attribute,
    STATE(10691), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12474), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [511018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511094] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10673), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [511142] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9664), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9666), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [511180] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9122), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9124), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [511218] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12480), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12558), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10676), 1,
      sym_attribute,
    STATE(10734), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12478), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [511262] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9726), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9728), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [511300] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9730), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9732), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [511338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9734), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9736), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [511376] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9738), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9740), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [511414] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10681), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [511462] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10682), 1,
      sym_attribute,
    STATE(11360), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16471), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [511528] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511604] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12562), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12560), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511680] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511718] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [511756] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11019), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [511794] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11169), 1,
      anon_sym_DASH_GT,
    STATE(10690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10383), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10381), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [511834] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12484), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12558), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10691), 1,
      sym_attribute,
    STATE(10734), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12482), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [511878] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [511936] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(10693), 1,
      sym_attribute,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [511984] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [512032] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12542), 1,
      sym_pow_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [512074] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12542), 1,
      sym_pow_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [512116] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [512166] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [512216] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10699), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12458), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [512264] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10700), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12343), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [512312] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [512366] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [512422] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [512482] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [512526] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10261), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [512586] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9546), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9548), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [512624] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [512664] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12556), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(10708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [512706] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9758), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9760), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [512744] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10271), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [512804] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12564), 1,
      anon_sym_POUND,
    STATE(10711), 1,
      sym_attribute,
    STATE(11279), 1,
      sym_type_constructor_path,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [512852] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(10712), 1,
      sym_attribute,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12343), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [512900] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    STATE(10713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_LBRACK_AT_AT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 15,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [512940] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [512978] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [513016] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [513054] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11676), 1,
      sym__lowercase_identifier,
    ACTIONS(11932), 1,
      anon_sym_POUND,
    STATE(9969), 1,
      sym_type_constructor_path,
    STATE(10717), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12347), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [513102] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12566), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(10718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [513144] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [513182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12568), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10720), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8755), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8757), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [513222] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9770), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9772), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [513260] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9182), 1,
      sym__lowercase_identifier,
    ACTIONS(12404), 1,
      anon_sym_COLON2,
    STATE(10722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11577), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11575), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [513304] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12573), 1,
      anon_sym_let,
    ACTIONS(12575), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10723), 1,
      sym_attribute,
    STATE(10864), 1,
      aux_sym_expression_item_repeat1,
    STATE(10986), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12571), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513356] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10724), 1,
      sym_attribute,
    STATE(11250), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16173), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [513422] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10725), 1,
      sym_attribute,
    STATE(11282), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16081), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [513488] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11203), 1,
      anon_sym_DASH_GT,
    STATE(10726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10383), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10381), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513528] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12577), 1,
      anon_sym_LPAREN,
    ACTIONS(12579), 1,
      anon_sym_LBRACK,
    STATE(10727), 1,
      sym_attribute,
    STATE(11612), 1,
      sym__constructor_name,
    STATE(12555), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [513578] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12585), 1,
      anon_sym_let,
    ACTIONS(12587), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10728), 1,
      sym_attribute,
    STATE(10798), 1,
      aux_sym_type_binding_repeat1,
    STATE(10942), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12583), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513630] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10729), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11650), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [513684] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12573), 1,
      anon_sym_let,
    ACTIONS(12589), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10730), 1,
      sym_attribute,
    STATE(10864), 1,
      aux_sym_expression_item_repeat1,
    STATE(11034), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12571), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513736] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12538), 1,
      anon_sym_SEMI,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [513798] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12591), 1,
      anon_sym_LPAREN,
    ACTIONS(12593), 1,
      anon_sym_LBRACK,
    STATE(10732), 1,
      sym_attribute,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(12563), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [513848] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12585), 1,
      anon_sym_let,
    ACTIONS(12597), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10733), 1,
      sym_attribute,
    STATE(10942), 1,
      aux_sym_expression_item_repeat1,
    STATE(11043), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12583), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [513900] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12397), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12599), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10734), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [513942] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9650), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9652), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [513980] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6793), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(6787), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [514018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514094] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514132] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514246] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10743), 1,
      sym_attribute,
    STATE(11379), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16371), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [514312] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9044), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9046), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [514350] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8344), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [514388] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(10746), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12213), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [514436] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12602), 1,
      anon_sym_COLON,
    STATE(10747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10081), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10079), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [514476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [514514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514552] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514628] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    ACTIONS(12538), 1,
      anon_sym_SEMI,
    ACTIONS(12540), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12542), 1,
      sym_pow_operator,
    ACTIONS(12544), 1,
      sym_mult_operator,
    ACTIONS(12546), 1,
      sym_concat_operator,
    ACTIONS(12548), 1,
      sym_rel_operator,
    ACTIONS(12550), 1,
      sym_and_operator,
    ACTIONS(12552), 1,
      sym_or_operator,
    ACTIONS(12554), 1,
      sym_assign_operator,
    STATE(2110), 1,
      sym_add_operator,
    STATE(10752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10327), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [514690] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514728] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(10754), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11604), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [514782] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    ACTIONS(12604), 1,
      anon_sym_DASH_GT,
    ACTIONS(12606), 1,
      anon_sym_STAR,
    STATE(10755), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [514834] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [514872] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8290), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [514910] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12610), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12608), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [514948] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10759), 1,
      sym_attribute,
    STATE(11425), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16707), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [515014] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [515052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8294), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [515090] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8022), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [515128] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11912), 1,
      sym__lowercase_identifier,
    ACTIONS(11914), 1,
      anon_sym_POUND,
    STATE(10661), 1,
      sym_type_constructor_path,
    STATE(10763), 1,
      sym_attribute,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12347), 11,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [515176] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9224), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515214] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9672), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9674), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515252] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8298), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [515290] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [515328] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8070), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515366] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10769), 1,
      sym_attribute,
    STATE(11475), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16954), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [515432] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9604), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9606), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515470] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12566), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(10771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515512] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9608), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9610), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515550] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12614), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12612), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [515588] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12616), 1,
      anon_sym_PIPE,
    STATE(10774), 1,
      sym_attribute,
    STATE(10777), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515630] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12616), 1,
      anon_sym_PIPE,
    STATE(10775), 1,
      sym_attribute,
    STATE(10778), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515672] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9058), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9060), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515710] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12616), 1,
      anon_sym_PIPE,
    STATE(10777), 1,
      sym_attribute,
    STATE(10779), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515752] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12616), 1,
      anon_sym_PIPE,
    STATE(10778), 1,
      sym_attribute,
    STATE(10779), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515794] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12618), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10779), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [515834] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9026), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9028), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515872] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8306), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8308), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515910] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8318), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8320), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [515948] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12470), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12558), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10676), 1,
      aux_sym_type_binding_repeat1,
    STATE(10783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12468), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [515992] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8332), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [516030] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8340), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [516068] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [516108] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(8282), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [516146] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12506), 1,
      anon_sym_RPAREN,
    ACTIONS(12508), 1,
      anon_sym__,
    ACTIONS(12510), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10788), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16449), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [516212] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10789), 1,
      sym_attribute,
    STATE(11530), 1,
      sym__attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16402), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [516278] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9654), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9656), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [516316] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [516354] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [516392] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 11,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 12,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [516430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 13,
      anon_sym_let,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [516468] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9630), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON2,
      anon_sym_LBRACE,
      anon_sym_begin,
      aux_sym_signed_number_token1,
      sym__lowercase_identifier,
    ACTIONS(9632), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [516506] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12502), 1,
      anon_sym_PERCENT,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(10796), 1,
      sym_attribute,
    STATE(11536), 1,
      sym__attribute,
    STATE(12567), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [516572] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8204), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8206), 21,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516610] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12627), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10798), 1,
      sym_attribute,
    STATE(10807), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12625), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516659] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12631), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12629), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516702] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10800), 1,
      sym_attribute,
    STATE(10882), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12635), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12633), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [516745] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12637), 1,
      anon_sym_LPAREN,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12643), 1,
      anon_sym_end,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    STATE(10801), 1,
      sym_attribute,
    STATE(11778), 1,
      sym__attribute,
    STATE(12272), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [516808] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [516851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12659), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516888] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(12663), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12661), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516927] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12663), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12661), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [516964] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12665), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(10806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [517005] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12669), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12667), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517048] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12671), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10808), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8755), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8757), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [517087] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12676), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12674), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517130] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10191), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10189), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [517167] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12680), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12678), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517210] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12684), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10812), 1,
      sym_attribute,
    STATE(10933), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12682), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517253] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12686), 1,
      anon_sym_LPAREN,
    ACTIONS(12688), 1,
      anon_sym_end,
    STATE(10813), 1,
      sym_attribute,
    STATE(11605), 1,
      sym__attribute,
    STATE(12354), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [517316] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12692), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10814), 1,
      sym_attribute,
    STATE(11029), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12690), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517359] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12696), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12694), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517402] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12700), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12698), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517445] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517488] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12702), 1,
      anon_sym_LPAREN,
    ACTIONS(12704), 1,
      anon_sym_end,
    STATE(10818), 1,
      sym_attribute,
    STATE(11599), 1,
      sym__attribute,
    STATE(12136), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [517551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11610), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11608), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517588] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(12708), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12706), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [517627] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(12712), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12710), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [517666] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12716), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12714), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [517709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10227), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10225), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [517746] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [517803] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [517850] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12722), 1,
      sym_pow_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [517891] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12722), 1,
      sym_pow_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [517932] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [517981] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518030] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518083] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12734), 1,
      aux_sym_attribute_id_token1,
    STATE(10808), 1,
      aux_sym_attribute_id_repeat1,
    STATE(10831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8766), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8768), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [518124] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [518179] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [518238] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [518281] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [518340] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(10836), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [518387] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(10837), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 7,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12213), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [518434] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12738), 1,
      anon_sym_LPAREN,
    ACTIONS(12740), 1,
      anon_sym_end,
    STATE(10838), 1,
      sym_attribute,
    STATE(11594), 1,
      sym__attribute,
    STATE(11834), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [518497] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12744), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12742), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [518534] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9222), 1,
      sym__lowercase_identifier,
    STATE(10840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11589), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11587), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [518575] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12748), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12746), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [518618] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12750), 1,
      anon_sym_LPAREN,
    ACTIONS(12752), 1,
      anon_sym_end,
    STATE(10842), 1,
      sym_attribute,
    STATE(11607), 1,
      sym__attribute,
    STATE(12028), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [518681] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10843), 1,
      sym_attribute,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12756), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12754), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [518724] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12760), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12758), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [518761] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12762), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(10845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [518802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10219), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10217), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [518839] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12766), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12764), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [518882] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10335), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [518941] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12768), 1,
      anon_sym_LPAREN,
    ACTIONS(12770), 1,
      anon_sym_end,
    STATE(10849), 1,
      sym_attribute,
    STATE(11787), 1,
      sym__attribute,
    STATE(11873), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519004] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12774), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12772), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519047] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10851), 1,
      sym_attribute,
    STATE(10971), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12778), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12776), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [519090] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12780), 1,
      anon_sym_LPAREN,
    ACTIONS(12782), 1,
      anon_sym_end,
    STATE(10852), 1,
      sym_attribute,
    STATE(11632), 1,
      sym__attribute,
    STATE(12113), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519153] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12786), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12784), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519196] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12790), 1,
      anon_sym_STAR,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(10854), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [519245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11604), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11602), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519282] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12794), 1,
      anon_sym_LPAREN,
    ACTIONS(12796), 1,
      anon_sym_end,
    STATE(10856), 1,
      sym_attribute,
    STATE(11645), 1,
      sym__attribute,
    STATE(12071), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519345] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12798), 1,
      anon_sym_LPAREN,
    ACTIONS(12800), 1,
      anon_sym_end,
    STATE(10857), 1,
      sym_attribute,
    STATE(11718), 1,
      sym__attribute,
    STATE(12147), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519408] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10179), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10177), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [519445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10195), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10193), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [519482] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12802), 1,
      anon_sym_POUND,
    STATE(10860), 1,
      sym_attribute,
    STATE(11673), 1,
      sym_type_constructor_path,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [519529] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12806), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12804), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519572] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10273), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [519631] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12810), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10799), 1,
      aux_sym_expression_item_repeat1,
    STATE(10863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12808), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519674] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12814), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12812), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519717] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12818), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12816), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [519760] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11589), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [519797] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12820), 1,
      anon_sym_PIPE,
    STATE(10867), 1,
      sym_attribute,
    STATE(10872), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [519838] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12822), 1,
      anon_sym_LPAREN,
    ACTIONS(12824), 1,
      anon_sym_end,
    STATE(10868), 1,
      sym_attribute,
    STATE(11647), 1,
      sym__attribute,
    STATE(11850), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [519901] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10869), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12458), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [519948] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12826), 1,
      anon_sym_LPAREN,
    ACTIONS(12828), 1,
      anon_sym_end,
    STATE(10870), 1,
      sym_attribute,
    STATE(11670), 1,
      sym__attribute,
    STATE(12157), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520011] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12832), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12830), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520054] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12834), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10872), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [520093] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10873), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12343), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [520140] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12839), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12837), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520183] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12843), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12841), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520226] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10231), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10229), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520263] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10123), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10121), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520300] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12845), 1,
      anon_sym_LPAREN,
    ACTIONS(12847), 1,
      anon_sym_end,
    STATE(10878), 1,
      sym_attribute,
    STATE(11643), 1,
      sym__attribute,
    STATE(12158), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520363] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(6939), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6937), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520406] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12849), 1,
      anon_sym_LPAREN,
    ACTIONS(12851), 1,
      anon_sym_end,
    STATE(10880), 1,
      sym_attribute,
    STATE(11709), 1,
      sym__attribute,
    STATE(11806), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520469] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10141), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10139), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520506] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10882), 1,
      sym_attribute,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12855), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12853), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [520549] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10883), 1,
      sym_attribute,
    STATE(11104), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12859), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12857), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [520592] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11459), 1,
      anon_sym_STAR,
    STATE(10884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [520631] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12861), 1,
      anon_sym_LPAREN,
    ACTIONS(12863), 1,
      anon_sym_end,
    STATE(10885), 1,
      sym_attribute,
    STATE(11630), 1,
      sym__attribute,
    STATE(11997), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520694] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10161), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10159), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520731] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12867), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10887), 1,
      sym_attribute,
    STATE(11099), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12865), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [520774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10287), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520811] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10843), 1,
      aux_sym_expression_item_repeat1,
    STATE(10889), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12871), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(12869), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [520854] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10389), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520891] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10279), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10277), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [520928] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12873), 1,
      anon_sym_LPAREN,
    ACTIONS(12875), 1,
      anon_sym_end,
    STATE(10892), 1,
      sym_attribute,
    STATE(11610), 1,
      sym__attribute,
    STATE(12007), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [520991] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12879), 1,
      anon_sym_SEMI,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    ACTIONS(12895), 1,
      sym_assign_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10329), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10327), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [521052] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8284), 2,
      anon_sym_let,
      anon_sym_COLON2,
    ACTIONS(8286), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521089] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12897), 1,
      anon_sym_LPAREN,
    ACTIONS(12899), 1,
      anon_sym_end,
    STATE(10895), 1,
      sym_attribute,
    STATE(11663), 1,
      sym__attribute,
    STATE(11847), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [521152] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521195] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10897), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [521242] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12680), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12678), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521285] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12905), 1,
      anon_sym_LPAREN,
    ACTIONS(12907), 1,
      anon_sym_end,
    STATE(10899), 1,
      sym_attribute,
    STATE(11642), 1,
      sym__attribute,
    STATE(12082), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [521348] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12909), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10900), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
    ACTIONS(11970), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(11968), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [521389] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9224), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [521426] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12914), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12912), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521469] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12918), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12916), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521512] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10904), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [521559] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12922), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12920), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521602] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11650), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11648), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521639] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12926), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12924), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521682] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12926), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12924), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521725] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12930), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10909), 1,
      sym_attribute,
    STATE(11103), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12928), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521768] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12926), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12924), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521811] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12934), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12932), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521854] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12938), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12936), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521897] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9024), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9022), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [521934] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [521977] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12944), 1,
      anon_sym_LPAREN,
    ACTIONS(12946), 1,
      anon_sym_end,
    STATE(10915), 1,
      sym_attribute,
    STATE(11740), 1,
      sym__attribute,
    STATE(11862), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [522040] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522083] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10343), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(10345), 13,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [522120] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12950), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12948), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522163] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12954), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10919), 1,
      sym_attribute,
    STATE(10947), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12952), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522206] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522249] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12956), 1,
      anon_sym_LPAREN,
    ACTIONS(12958), 1,
      anon_sym_end,
    STATE(10921), 1,
      sym_attribute,
    STATE(11659), 1,
      sym__attribute,
    STATE(12169), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [522312] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12962), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12960), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522355] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12962), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12960), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522398] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11237), 1,
      anon_sym_DASH_GT,
    STATE(10924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [522437] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12966), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12964), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522480] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12962), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12960), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522523] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12970), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12968), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522566] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11481), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [522603] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    STATE(10929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [522642] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10091), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10089), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [522679] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(12972), 1,
      anon_sym_LPAREN,
    ACTIONS(12974), 1,
      anon_sym_end,
    STATE(10931), 1,
      sym_attribute,
    STATE(11637), 1,
      sym__attribute,
    STATE(12061), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [522742] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12978), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10932), 1,
      sym_attribute,
    STATE(11079), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12976), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522785] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12982), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12980), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522828] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12986), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10934), 1,
      sym_attribute,
    STATE(11083), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12984), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522871] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [522928] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7019), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7017), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [522971] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12990), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10937), 1,
      sym_attribute,
    STATE(11084), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12988), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523014] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [523061] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12994), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12992), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523104] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12883), 1,
      sym_pow_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(10235), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
  [523145] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12998), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10941), 1,
      sym_attribute,
    STATE(11086), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12996), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523188] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12627), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12625), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523231] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13002), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13000), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523274] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13006), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13004), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523317] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7011), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7009), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523360] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    ACTIONS(13008), 1,
      anon_sym_SEMI,
    STATE(2399), 1,
      sym_add_operator,
    STATE(10946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [523421] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13012), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13010), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523464] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12883), 1,
      sym_pow_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(10235), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
  [523505] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(10949), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12213), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [523552] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [523601] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13016), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13014), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [523644] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [523693] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [523746] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [523801] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(10955), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11604), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [523854] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(10956), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11610), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [523907] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    ACTIONS(12895), 1,
      sym_assign_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [523966] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [524009] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    ACTIONS(12895), 1,
      sym_assign_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10263), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10261), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [524068] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    ACTIONS(13018), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10864), 1,
      aux_sym_expression_item_repeat1,
    STATE(10960), 1,
      sym_attribute,
    STATE(11524), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12571), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [524117] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10961), 1,
      sym_attribute,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [524164] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13024), 1,
      anon_sym_EQ,
    ACTIONS(13026), 1,
      anon_sym_of,
    ACTIONS(13028), 1,
      anon_sym_COLON2,
    STATE(10962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13022), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13020), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10149), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10147), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [524244] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8755), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8757), 14,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
  [524281] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    ACTIONS(13030), 1,
      anon_sym_DASH_GT,
    ACTIONS(13032), 1,
      anon_sym_STAR,
    STATE(10965), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [524332] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(6887), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6885), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524375] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(10967), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13036), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13034), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [524418] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10968), 1,
      sym_attribute,
    STATE(11135), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13040), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13038), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [524461] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10969), 1,
      sym_attribute,
    STATE(11141), 1,
      aux_sym_expression_item_repeat1,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13044), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13042), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [524504] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13046), 1,
      anon_sym_LPAREN,
    ACTIONS(13048), 1,
      anon_sym_end,
    STATE(10970), 1,
      sym_attribute,
    STATE(11601), 1,
      sym__attribute,
    STATE(12125), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [524567] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(10971), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13052), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13050), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [524610] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13054), 1,
      anon_sym_LPAREN,
    ACTIONS(13056), 1,
      anon_sym_end,
    STATE(10972), 1,
      sym_attribute,
    STATE(11754), 1,
      sym__attribute,
    STATE(11874), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [524673] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11483), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11485), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [524710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11487), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11489), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [524747] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13060), 1,
      anon_sym_let,
    STATE(10975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13058), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524784] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13062), 1,
      anon_sym_LPAREN,
    ACTIONS(13064), 1,
      anon_sym_end,
    STATE(10976), 1,
      sym_attribute,
    STATE(11745), 1,
      sym__attribute,
    STATE(12317), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [524847] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11491), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11493), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [524884] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11495), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11497), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [524921] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      anon_sym_EQ,
    ACTIONS(13072), 1,
      anon_sym_of,
    ACTIONS(13074), 1,
      anon_sym_COLON2,
    STATE(10979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13066), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [524964] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12665), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(10980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [525005] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13078), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10912), 1,
      aux_sym_expression_item_repeat1,
    STATE(10981), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13076), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525054] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13082), 1,
      anon_sym_let,
    ACTIONS(13084), 1,
      anon_sym_EQ,
    ACTIONS(13086), 1,
      anon_sym_COLON_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10865), 1,
      aux_sym_expression_item_repeat1,
    STATE(10982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13080), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525101] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    ACTIONS(13088), 1,
      anon_sym_STAR,
    STATE(10983), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(12864), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12025), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [525152] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2412), 1,
      sym_add_operator,
    STATE(10984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [525191] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13092), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10902), 1,
      aux_sym_expression_item_repeat1,
    STATE(10985), 1,
      sym_attribute,
    STATE(10992), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13090), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525240] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12814), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10822), 1,
      aux_sym_expression_item_repeat1,
    STATE(10986), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12812), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525289] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13096), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10987), 1,
      sym_attribute,
    STATE(11167), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13094), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525338] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13100), 1,
      anon_sym_let,
    ACTIONS(13102), 1,
      anon_sym_EQ,
    ACTIONS(13104), 1,
      anon_sym_COLON_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10988), 1,
      sym_attribute,
    STATE(11138), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13098), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525385] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    ACTIONS(13106), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10942), 1,
      aux_sym_expression_item_repeat1,
    STATE(10989), 1,
      sym_attribute,
    STATE(11476), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12583), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [525434] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(10990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13110), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13108), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525471] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13114), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10991), 1,
      sym_attribute,
    STATE(10997), 1,
      aux_sym_type_binding_repeat1,
    STATE(11174), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13112), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525520] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12914), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10992), 1,
      sym_attribute,
    STATE(11194), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12912), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525569] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13118), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10993), 1,
      sym_attribute,
    STATE(11001), 1,
      aux_sym_type_binding_repeat1,
    STATE(11098), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525618] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13118), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10802), 1,
      aux_sym_expression_item_repeat1,
    STATE(10994), 1,
      sym_attribute,
    STATE(11002), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525667] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13118), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10817), 1,
      aux_sym_expression_item_repeat1,
    STATE(10995), 1,
      sym_attribute,
    STATE(11003), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525716] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13122), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10951), 1,
      aux_sym_expression_item_repeat1,
    STATE(10996), 1,
      sym_attribute,
    STATE(11005), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13120), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525765] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13126), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10997), 1,
      sym_attribute,
    STATE(11140), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13124), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525814] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13130), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10998), 1,
      sym_attribute,
    STATE(11010), 1,
      aux_sym_type_binding_repeat1,
    STATE(11142), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525863] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13130), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10999), 1,
      sym_attribute,
    STATE(11011), 1,
      aux_sym_type_binding_repeat1,
    STATE(11144), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525912] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13130), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11000), 1,
      sym_attribute,
    STATE(11012), 1,
      aux_sym_type_binding_repeat1,
    STATE(11151), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [525961] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11001), 1,
      sym_attribute,
    STATE(11156), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526010] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11002), 1,
      sym_attribute,
    STATE(11158), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526059] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11003), 1,
      sym_attribute,
    STATE(11159), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526108] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13134), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11004), 1,
      sym_attribute,
    STATE(11013), 1,
      aux_sym_type_binding_repeat1,
    STATE(11165), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13132), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526157] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13016), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11005), 1,
      sym_attribute,
    STATE(11192), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13014), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526206] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13138), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11006), 1,
      sym_attribute,
    STATE(11017), 1,
      aux_sym_type_binding_repeat1,
    STATE(11212), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526255] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13138), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11007), 1,
      sym_attribute,
    STATE(11018), 1,
      aux_sym_type_binding_repeat1,
    STATE(11232), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526304] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13138), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10896), 1,
      aux_sym_expression_item_repeat1,
    STATE(11008), 1,
      sym_attribute,
    STATE(11019), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526353] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10199), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10197), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [526390] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10907), 1,
      aux_sym_expression_item_repeat1,
    STATE(11010), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526439] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10908), 1,
      aux_sym_expression_item_repeat1,
    STATE(11011), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526488] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10910), 1,
      aux_sym_expression_item_repeat1,
    STATE(11012), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526537] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13146), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10911), 1,
      aux_sym_expression_item_repeat1,
    STATE(11013), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13144), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526586] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13150), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10914), 1,
      aux_sym_expression_item_repeat1,
    STATE(11014), 1,
      sym_attribute,
    STATE(11020), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526635] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13150), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10916), 1,
      aux_sym_expression_item_repeat1,
    STATE(11015), 1,
      sym_attribute,
    STATE(11021), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526684] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(13150), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10920), 1,
      aux_sym_expression_item_repeat1,
    STATE(11016), 1,
      sym_attribute,
    STATE(11022), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526733] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10922), 1,
      aux_sym_expression_item_repeat1,
    STATE(11017), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526782] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10923), 1,
      aux_sym_expression_item_repeat1,
    STATE(11018), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526831] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10926), 1,
      aux_sym_expression_item_repeat1,
    STATE(11019), 1,
      sym_attribute,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526880] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11020), 1,
      sym_attribute,
    STATE(11076), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526929] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11021), 1,
      sym_attribute,
    STATE(11077), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [526978] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11928), 1,
      anon_sym_constraint,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11022), 1,
      sym_attribute,
    STATE(11078), 1,
      aux_sym_expression_item_repeat1,
    STATE(11743), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527027] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13154), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13152), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527064] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13158), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10847), 1,
      aux_sym_expression_item_repeat1,
    STATE(11024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13156), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527107] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13160), 1,
      anon_sym_LPAREN,
    ACTIONS(13162), 1,
      anon_sym_end,
    STATE(11025), 1,
      sym_attribute,
    STATE(11640), 1,
      sym__attribute,
    STATE(12179), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [527170] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11479), 1,
      sym__lowercase_identifier,
    STATE(11026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12297), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12299), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [527211] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13164), 1,
      anon_sym_LPAREN,
    ACTIONS(13166), 1,
      anon_sym_end,
    STATE(11027), 1,
      sym_attribute,
    STATE(11691), 1,
      sym__attribute,
    STATE(12041), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [527274] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    ACTIONS(12895), 1,
      sym_assign_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(11028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10273), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10271), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [527333] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13170), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13168), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527376] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13078), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10912), 1,
      aux_sym_expression_item_repeat1,
    STATE(11030), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13076), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527425] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13172), 1,
      anon_sym_LPAREN,
    ACTIONS(13174), 1,
      anon_sym_end,
    STATE(11031), 1,
      sym_attribute,
    STATE(11622), 1,
      sym__attribute,
    STATE(11986), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [527488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9050), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [527525] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13092), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10902), 1,
      aux_sym_expression_item_repeat1,
    STATE(11033), 1,
      sym_attribute,
    STATE(11038), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13090), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527574] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12814), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10822), 1,
      aux_sym_expression_item_repeat1,
    STATE(11034), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12812), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527623] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13180), 1,
      anon_sym_EQ,
    ACTIONS(13182), 1,
      anon_sym_of,
    ACTIONS(13184), 1,
      anon_sym_COLON2,
    STATE(11035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527666] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13096), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11036), 1,
      sym_attribute,
    STATE(11167), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13094), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527715] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13114), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11037), 1,
      sym_attribute,
    STATE(11044), 1,
      aux_sym_type_binding_repeat1,
    STATE(11174), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13112), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527764] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12914), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11038), 1,
      sym_attribute,
    STATE(11194), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12912), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527813] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13118), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11039), 1,
      sym_attribute,
    STATE(11048), 1,
      aux_sym_type_binding_repeat1,
    STATE(11098), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527862] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13118), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10802), 1,
      aux_sym_expression_item_repeat1,
    STATE(11040), 1,
      sym_attribute,
    STATE(11049), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527911] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13118), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10817), 1,
      aux_sym_expression_item_repeat1,
    STATE(11041), 1,
      sym_attribute,
    STATE(11248), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [527960] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13122), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10951), 1,
      aux_sym_expression_item_repeat1,
    STATE(11042), 1,
      sym_attribute,
    STATE(11052), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13120), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528009] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12627), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10807), 1,
      aux_sym_expression_item_repeat1,
    STATE(11043), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12625), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528058] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13126), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11044), 1,
      sym_attribute,
    STATE(11140), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13124), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528107] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13130), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11045), 1,
      sym_attribute,
    STATE(11057), 1,
      aux_sym_type_binding_repeat1,
    STATE(11142), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528156] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13130), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11046), 1,
      sym_attribute,
    STATE(11058), 1,
      aux_sym_type_binding_repeat1,
    STATE(11144), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528205] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13130), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11047), 1,
      sym_attribute,
    STATE(11059), 1,
      aux_sym_type_binding_repeat1,
    STATE(11151), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528254] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11048), 1,
      sym_attribute,
    STATE(11156), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528303] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11049), 1,
      sym_attribute,
    STATE(11158), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528352] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(7031), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7029), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528395] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13134), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11051), 1,
      sym_attribute,
    STATE(11060), 1,
      aux_sym_type_binding_repeat1,
    STATE(11165), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13132), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528444] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13016), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11052), 1,
      sym_attribute,
    STATE(11192), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13014), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528493] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13138), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11053), 1,
      sym_attribute,
    STATE(11064), 1,
      aux_sym_type_binding_repeat1,
    STATE(11212), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528542] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13138), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11054), 1,
      sym_attribute,
    STATE(11065), 1,
      aux_sym_type_binding_repeat1,
    STATE(11232), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528591] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13138), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10896), 1,
      aux_sym_expression_item_repeat1,
    STATE(11055), 1,
      sym_attribute,
    STATE(11066), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528640] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10215), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10213), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [528677] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10907), 1,
      aux_sym_expression_item_repeat1,
    STATE(11057), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528726] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10908), 1,
      aux_sym_expression_item_repeat1,
    STATE(11058), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528775] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10910), 1,
      aux_sym_expression_item_repeat1,
    STATE(11059), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528824] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13146), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10911), 1,
      aux_sym_expression_item_repeat1,
    STATE(11060), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13144), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528873] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13150), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10914), 1,
      aux_sym_expression_item_repeat1,
    STATE(11061), 1,
      sym_attribute,
    STATE(11067), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528922] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13150), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10916), 1,
      aux_sym_expression_item_repeat1,
    STATE(11062), 1,
      sym_attribute,
    STATE(11068), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [528971] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(13150), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10920), 1,
      aux_sym_expression_item_repeat1,
    STATE(11063), 1,
      sym_attribute,
    STATE(11069), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529020] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10922), 1,
      aux_sym_expression_item_repeat1,
    STATE(11064), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529069] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10923), 1,
      aux_sym_expression_item_repeat1,
    STATE(11065), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529118] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10926), 1,
      aux_sym_expression_item_repeat1,
    STATE(11066), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529167] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11067), 1,
      sym_attribute,
    STATE(11076), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529216] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11068), 1,
      sym_attribute,
    STATE(11077), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529265] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12942), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11069), 1,
      sym_attribute,
    STATE(11078), 1,
      aux_sym_expression_item_repeat1,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529314] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11070), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11650), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [529367] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(3193), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(3191), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [529404] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_LBRACK,
    STATE(11072), 1,
      sym_attribute,
    STATE(12312), 1,
      sym__constructor_name,
    STATE(12908), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13190), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(12259), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [529453] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13192), 1,
      anon_sym_LPAREN,
    ACTIONS(13194), 1,
      anon_sym_end,
    STATE(11073), 1,
      sym_attribute,
    STATE(11614), 1,
      sym__attribute,
    STATE(11886), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [529516] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13200), 1,
      anon_sym_and,
    STATE(11074), 1,
      sym_attribute,
    STATE(11075), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13198), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13196), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529557] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13202), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12049), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11075), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(12047), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529596] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13207), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13205), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529639] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13207), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13205), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529682] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13207), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13205), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529725] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13211), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13209), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529768] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13213), 1,
      anon_sym_and,
    STATE(11080), 1,
      sym_attribute,
    STATE(11081), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13198), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13196), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529809] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13215), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12049), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11081), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(12047), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529848] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13220), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11082), 1,
      sym_attribute,
    STATE(11199), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13218), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529891] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13224), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13222), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529934] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13228), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13226), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [529977] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13232), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11085), 1,
      sym_attribute,
    STATE(11210), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13230), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530020] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13236), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13234), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530063] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13240), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11087), 1,
      sym_attribute,
    STATE(11213), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13238), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530106] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13244), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11088), 1,
      sym_attribute,
    STATE(11216), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13242), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530149] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13248), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13246), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530192] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13252), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11090), 1,
      sym_attribute,
    STATE(11224), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13250), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530235] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11499), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11501), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [530272] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11503), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11505), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [530309] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12397), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13254), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11093), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [530350] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13257), 1,
      anon_sym_LPAREN,
    ACTIONS(13259), 1,
      anon_sym_end,
    STATE(11094), 1,
      sym_attribute,
    STATE(11701), 1,
      sym__attribute,
    STATE(12390), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [530413] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11507), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11509), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [530450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11511), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11513), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [530487] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13263), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13261), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530530] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530573] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13267), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13265), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530616] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13271), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13269), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530659] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13078), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13076), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9184), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [530739] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13275), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13273), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [530782] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11104), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13279), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13277), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [530825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(9030), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [530862] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13281), 1,
      anon_sym_LPAREN,
    ACTIONS(13283), 1,
      anon_sym_end,
    STATE(11106), 1,
      sym_attribute,
    STATE(11777), 1,
      sym__attribute,
    STATE(11973), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [530925] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11107), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12213), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [530972] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11108), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [531025] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10223), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10221), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [531062] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11110), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [531115] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13287), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13285), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531158] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13289), 1,
      anon_sym_LPAREN,
    ACTIONS(13291), 1,
      anon_sym_end,
    STATE(11112), 1,
      sym_attribute,
    STATE(11714), 1,
      sym__attribute,
    STATE(11897), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [531221] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13295), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13293), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531264] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11577), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [531301] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13299), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13297), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531344] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13096), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13094), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531387] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13303), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10841), 1,
      aux_sym_expression_item_repeat1,
    STATE(11117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13301), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531430] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10069), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10067), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [531467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10087), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10085), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [531504] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(11120), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12458), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [531551] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    ACTIONS(13008), 1,
      anon_sym_SEMI,
    STATE(2399), 1,
      sym_add_operator,
    STATE(11121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [531612] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13305), 1,
      anon_sym_LPAREN,
    ACTIONS(13307), 1,
      anon_sym_end,
    STATE(11122), 1,
      sym_attribute,
    STATE(11752), 1,
      sym__attribute,
    STATE(12189), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [531675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10073), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10071), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [531712] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12820), 1,
      anon_sym_PIPE,
    STATE(10867), 1,
      aux_sym__match_cases_repeat1,
    STATE(11124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [531753] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10175), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10173), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [531790] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13309), 1,
      anon_sym_LPAREN,
    ACTIONS(13311), 1,
      anon_sym_end,
    STATE(11126), 1,
      sym_attribute,
    STATE(11788), 1,
      sym__attribute,
    STATE(12092), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [531853] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12879), 1,
      anon_sym_SEMI,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    ACTIONS(12895), 1,
      sym_assign_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(11127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [531914] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13315), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13313), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [531957] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    ACTIONS(12720), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12722), 1,
      sym_pow_operator,
    ACTIONS(12724), 1,
      sym_mult_operator,
    ACTIONS(12726), 1,
      sym_concat_operator,
    ACTIONS(12728), 1,
      sym_rel_operator,
    ACTIONS(12730), 1,
      sym_and_operator,
    ACTIONS(12732), 1,
      sym_or_operator,
    ACTIONS(12736), 1,
      sym_assign_operator,
    ACTIONS(13008), 1,
      anon_sym_SEMI,
    STATE(2399), 1,
      sym_add_operator,
    STATE(11129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_GT_RBRACE,
  [532018] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13317), 1,
      anon_sym_LPAREN,
    ACTIONS(13319), 1,
      anon_sym_end,
    STATE(11130), 1,
      sym_attribute,
    STATE(11776), 1,
      sym__attribute,
    STATE(11909), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [532081] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11131), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13323), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13321), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [532124] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12820), 1,
      anon_sym_PIPE,
    STATE(10872), 1,
      aux_sym__match_cases_repeat1,
    STATE(11132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [532165] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13327), 1,
      anon_sym_let,
    STATE(11133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13325), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532202] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(11134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532241] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11135), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13331), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13329), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [532284] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(11136), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12343), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [532331] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11473), 1,
      anon_sym_STAR,
    STATE(11137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11160), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11158), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532370] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13335), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13333), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532413] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13337), 1,
      anon_sym_LPAREN,
    ACTIONS(13339), 1,
      anon_sym_end,
    STATE(11139), 1,
      sym_attribute,
    STATE(11589), 1,
      sym__attribute,
    STATE(12200), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [532476] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13343), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13341), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532519] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11141), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13347), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13345), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [532562] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532605] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13351), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11113), 1,
      aux_sym_expression_item_repeat1,
    STATE(11143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13349), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532648] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532691] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10095), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10093), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [532728] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11519), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11521), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [532765] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [532802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11523), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11525), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [532839] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11527), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11529), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [532876] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11531), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11533), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [532913] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13142), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532956] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13355), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13353), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [532999] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13357), 1,
      anon_sym_LPAREN,
    ACTIONS(13359), 1,
      anon_sym_end,
    STATE(11153), 1,
      sym_attribute,
    STATE(11598), 1,
      sym__attribute,
    STATE(11922), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [533062] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11131), 1,
      aux_sym_expression_item_repeat1,
    STATE(11154), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13363), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13361), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [533105] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13355), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13353), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533148] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13367), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13365), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10137), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10135), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [533228] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13367), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13365), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533271] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13367), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13365), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533314] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13371), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10850), 1,
      aux_sym_expression_item_repeat1,
    STATE(11160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13369), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533357] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13375), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13373), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533400] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11936), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11934), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533443] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(11163), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [533490] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11164), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [533543] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13146), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13144), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533586] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13377), 1,
      anon_sym_LPAREN,
    ACTIONS(13379), 1,
      anon_sym_end,
    STATE(11166), 1,
      sym_attribute,
    STATE(11615), 1,
      sym__attribute,
    STATE(12210), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [533649] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13383), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13381), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533692] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7913), 2,
      anon_sym_let,
      anon_sym_COLON2,
    ACTIONS(7915), 20,
      anon_sym_SEMI_SEMI,
      anon_sym_RPAREN,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533729] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13389), 1,
      anon_sym_DQUOTE,
    STATE(11648), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13387), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11169), 2,
      sym_attribute,
      aux_sym_external_repeat1,
    ACTIONS(13385), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533770] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2399), 1,
      sym_add_operator,
    STATE(11170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 12,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [533809] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13392), 1,
      anon_sym_LPAREN,
    ACTIONS(13394), 1,
      anon_sym_end,
    STATE(11171), 1,
      sym_attribute,
    STATE(11641), 1,
      sym__attribute,
    STATE(11933), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [533872] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12762), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(11172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [533913] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10145), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10143), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [533950] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13126), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13124), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [533993] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12086), 1,
      sym__lowercase_identifier,
    ACTIONS(12088), 1,
      anon_sym_POUND,
    STATE(10978), 1,
      sym_type_constructor_path,
    STATE(11175), 1,
      sym_attribute,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12347), 10,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [534040] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13398), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13396), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534083] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11698), 1,
      anon_sym_STAR,
    STATE(11177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11160), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11158), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534122] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10283), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10281), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [534159] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    ACTIONS(12879), 1,
      anon_sym_SEMI,
    ACTIONS(12881), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12883), 1,
      sym_pow_operator,
    ACTIONS(12885), 1,
      sym_mult_operator,
    ACTIONS(12887), 1,
      sym_concat_operator,
    ACTIONS(12889), 1,
      sym_rel_operator,
    ACTIONS(12891), 1,
      sym_and_operator,
    ACTIONS(12893), 1,
      sym_or_operator,
    ACTIONS(12895), 1,
      sym_assign_operator,
    STATE(2412), 1,
      sym_add_operator,
    STATE(11179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 3,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [534220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [534257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [534294] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [534331] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11183), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [534378] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13400), 1,
      anon_sym_LPAREN,
    ACTIONS(13402), 1,
      anon_sym_end,
    STATE(11184), 1,
      sym_attribute,
    STATE(11739), 1,
      sym__attribute,
    STATE(12102), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [534441] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11535), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11537), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [534478] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11539), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11541), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [534515] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11543), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11545), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [534552] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11547), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11549), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [534589] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11551), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11553), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [534626] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10900), 1,
      aux_sym_expression_item_repeat1,
    STATE(11190), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13406), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13404), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [534669] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11555), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11557), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [534706] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13410), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13408), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534749] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13414), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13412), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534792] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13418), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13416), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534835] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13422), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10815), 1,
      aux_sym_expression_item_repeat1,
    STATE(11195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13420), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534878] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13426), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13424), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [534921] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13428), 1,
      anon_sym_LPAREN,
    ACTIONS(13430), 1,
      anon_sym_end,
    STATE(11197), 1,
      sym_attribute,
    STATE(11688), 1,
      sym__attribute,
    STATE(11944), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [534984] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12734), 1,
      aux_sym_attribute_id_token1,
    STATE(10831), 1,
      aux_sym_attribute_id_repeat1,
    STATE(11198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8772), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8774), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [535025] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13434), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13432), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535068] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9182), 1,
      sym__lowercase_identifier,
    ACTIONS(12404), 1,
      anon_sym_COLON2,
    STATE(11200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11577), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11575), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [535111] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13438), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10927), 1,
      aux_sym_expression_item_repeat1,
    STATE(11201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13436), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11559), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11561), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [535191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11563), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11565), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [535228] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11567), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11569), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [535265] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(5431), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10967), 1,
      aux_sym_expression_item_repeat1,
    STATE(11205), 1,
      sym_attribute,
    STATE(11669), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13442), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(13440), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [535308] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10165), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10163), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [535345] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10077), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10075), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [535382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [535419] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13444), 1,
      anon_sym_LPAREN,
    ACTIONS(13446), 1,
      anon_sym_end,
    STATE(11209), 1,
      sym_attribute,
    STATE(11650), 1,
      sym__attribute,
    STATE(11818), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [535482] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13450), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13448), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(11021), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [535562] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535605] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13454), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13452), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535648] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11571), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11573), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [535685] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13458), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10853), 1,
      aux_sym_expression_item_repeat1,
    STATE(11215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13456), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535728] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13462), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13460), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535771] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13464), 1,
      anon_sym_LPAREN,
    ACTIONS(13466), 1,
      anon_sym_end,
    STATE(11217), 1,
      sym_attribute,
    STATE(11768), 1,
      sym__attribute,
    STATE(12017), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [535834] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13024), 1,
      anon_sym_EQ,
    ACTIONS(13468), 1,
      anon_sym_of,
    ACTIONS(13470), 1,
      anon_sym_COLON2,
    STATE(11218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13022), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13020), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535877] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      anon_sym_EQ,
    ACTIONS(13472), 1,
      anon_sym_of,
    ACTIONS(13474), 1,
      anon_sym_COLON2,
    STATE(11219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13066), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [535920] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [535959] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13478), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10918), 1,
      aux_sym_expression_item_repeat1,
    STATE(11221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13476), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536002] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13482), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13480), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536045] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13180), 1,
      anon_sym_EQ,
    ACTIONS(13484), 1,
      anon_sym_of,
    ACTIONS(13486), 1,
      anon_sym_COLON2,
    STATE(11223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536088] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13490), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13488), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536131] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9546), 2,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(9548), 20,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536168] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13492), 1,
      anon_sym_LPAREN,
    ACTIONS(13494), 1,
      anon_sym_end,
    STATE(11226), 1,
      sym_attribute,
    STATE(11573), 1,
      sym__attribute,
    STATE(11957), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536231] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13498), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11193), 1,
      aux_sym_expression_item_repeat1,
    STATE(11227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13496), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536274] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10119), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10117), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      anon_sym_to,
      anon_sym_downto,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [536311] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13502), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10809), 1,
      aux_sym_expression_item_repeat1,
    STATE(11229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13500), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536354] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13506), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10905), 1,
      aux_sym_expression_item_repeat1,
    STATE(11230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13504), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536397] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13510), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11222), 1,
      aux_sym_expression_item_repeat1,
    STATE(11231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13508), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536440] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12903), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536483] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(11233), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [536530] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13512), 1,
      anon_sym_LPAREN,
    ACTIONS(13514), 1,
      anon_sym_end,
    STATE(11234), 1,
      sym_attribute,
    STATE(11657), 1,
      sym__attribute,
    STATE(12206), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536593] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12066), 1,
      sym__lowercase_identifier,
    ACTIONS(12115), 1,
      anon_sym_POUND,
    STATE(10515), 1,
      sym_type_constructor_path,
    STATE(11235), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12347), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [536640] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13518), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10861), 1,
      aux_sym_expression_item_repeat1,
    STATE(11236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13516), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536683] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12470), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13520), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(11237), 1,
      sym_attribute,
    STATE(11239), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12468), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536726] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12476), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13520), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(11238), 1,
      sym_attribute,
    STATE(11240), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12474), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536769] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12480), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13520), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(11093), 1,
      aux_sym_type_binding_repeat1,
    STATE(11239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12478), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536812] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12484), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13520), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(11093), 1,
      aux_sym_type_binding_repeat1,
    STATE(11240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12482), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [536855] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13200), 1,
      anon_sym_and,
    STATE(11074), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13524), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13522), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [536896] = 18,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(12651), 1,
      anon_sym_PERCENT,
    ACTIONS(13526), 1,
      anon_sym_LPAREN,
    ACTIONS(13528), 1,
      anon_sym_end,
    STATE(11242), 1,
      sym_attribute,
    STATE(11699), 1,
      sym__attribute,
    STATE(12051), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [536959] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13213), 1,
      anon_sym_and,
    STATE(11080), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13524), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13522), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [537000] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13530), 1,
      anon_sym_COLON2,
    STATE(11244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537039] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13534), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13532), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [537082] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13538), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10816), 1,
      aux_sym_expression_item_repeat1,
    STATE(11246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13536), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [537125] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12820), 1,
      anon_sym_PIPE,
    STATE(11132), 1,
      aux_sym__match_cases_repeat1,
    STATE(11247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [537166] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11983), 1,
      anon_sym_constraint,
    ACTIONS(12655), 1,
      anon_sym_let,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11159), 1,
      aux_sym_expression_item_repeat1,
    STATE(11248), 1,
      sym_attribute,
    STATE(11649), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [537215] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11249), 1,
      sym_attribute,
    STATE(11297), 1,
      sym__module_type,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [537275] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11250), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(17138), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [537335] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537371] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537407] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10923), 1,
      aux_sym_expression_item_repeat1,
    STATE(11253), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537453] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537489] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [537525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11567), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537597] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11258), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16718), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [537657] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11158), 1,
      aux_sym_expression_item_repeat1,
    STATE(11259), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537739] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11766), 1,
      anon_sym_DASH_GT,
    STATE(11261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 19,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [537777] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537813] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [537871] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11264), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16971), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [537931] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [537967] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10926), 1,
      aux_sym_expression_item_repeat1,
    STATE(11266), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538013] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13568), 1,
      anon_sym_EQ,
    ACTIONS(13570), 1,
      anon_sym_COLON_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11138), 1,
      aux_sym_expression_item_repeat1,
    STATE(11267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13098), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538057] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13572), 1,
      sym__lowercase_identifier,
    ACTIONS(13574), 1,
      anon_sym_LPAREN,
    ACTIONS(13576), 1,
      anon_sym_DASH_GT,
    ACTIONS(13578), 1,
      anon_sym_module,
    ACTIONS(13580), 1,
      anon_sym_sig,
    ACTIONS(13582), 1,
      anon_sym_functor,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13588), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11268), 1,
      sym_attribute,
    STATE(14485), 1,
      sym__module_type,
    STATE(15723), 1,
      aux_sym_module_binding_repeat1,
    STATE(18278), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14302), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [538117] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11269), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16044), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [538177] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [538213] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11156), 1,
      aux_sym_expression_item_repeat1,
    STATE(11271), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538259] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10343), 8,
      anon_sym_rec,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_lazy,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(10345), 13,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [538295] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [538331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538367] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13592), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13590), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538409] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538445] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10802), 1,
      aux_sym_expression_item_repeat1,
    STATE(11259), 1,
      aux_sym_type_binding_repeat1,
    STATE(11277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538491] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [538527] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538563] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538599] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538635] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11282), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16113), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [538695] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13024), 1,
      anon_sym_EQ,
    ACTIONS(13594), 1,
      anon_sym_of,
    ACTIONS(13596), 1,
      anon_sym_COLON2,
    STATE(11283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13022), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13020), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [538737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [538773] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [538827] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11286), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12347), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [538873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [538909] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(11288), 1,
      sym_attribute,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12347), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [538955] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13598), 1,
      anon_sym_EQ,
    ACTIONS(13600), 1,
      anon_sym_of,
    ACTIONS(13602), 1,
      anon_sym_COLON2,
    STATE(11289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [538997] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13604), 1,
      anon_sym_EQ,
    ACTIONS(13606), 1,
      anon_sym_of,
    ACTIONS(13608), 1,
      anon_sym_COLON2,
    STATE(11290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539039] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(11291), 1,
      sym_attribute,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [539085] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11292), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(15974), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [539145] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    STATE(11293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13612), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13610), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539185] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11294), 1,
      sym_attribute,
    STATE(11483), 1,
      sym__module_type,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [539245] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [539281] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13572), 1,
      sym__lowercase_identifier,
    ACTIONS(13574), 1,
      anon_sym_LPAREN,
    ACTIONS(13576), 1,
      anon_sym_DASH_GT,
    ACTIONS(13578), 1,
      anon_sym_module,
    ACTIONS(13580), 1,
      anon_sym_sig,
    ACTIONS(13582), 1,
      anon_sym_functor,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13588), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11296), 1,
      sym_attribute,
    STATE(14502), 1,
      sym__module_type,
    STATE(15723), 1,
      aux_sym_module_binding_repeat1,
    STATE(18278), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14302), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [539341] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    STATE(11297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13620), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13618), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539381] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13622), 1,
      anon_sym_EQ,
    ACTIONS(13624), 1,
      anon_sym_of,
    ACTIONS(13626), 1,
      anon_sym_COLON2,
    STATE(11298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539423] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13572), 1,
      sym__lowercase_identifier,
    ACTIONS(13574), 1,
      anon_sym_LPAREN,
    ACTIONS(13576), 1,
      anon_sym_DASH_GT,
    ACTIONS(13578), 1,
      anon_sym_module,
    ACTIONS(13580), 1,
      anon_sym_sig,
    ACTIONS(13582), 1,
      anon_sym_functor,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13588), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11299), 1,
      sym_attribute,
    STATE(14592), 1,
      sym__module_type,
    STATE(15723), 1,
      aux_sym_module_binding_repeat1,
    STATE(18278), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14302), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [539483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [539519] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13630), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13628), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11571), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [539597] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      anon_sym_EQ,
    ACTIONS(13632), 1,
      anon_sym_of,
    ACTIONS(13634), 1,
      anon_sym_COLON2,
    STATE(11303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13066), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539639] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9222), 1,
      sym__lowercase_identifier,
    STATE(11304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(11589), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11587), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [539679] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13554), 1,
      sym_pow_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [539719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [539755] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13638), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13636), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [539797] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [539833] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11167), 1,
      aux_sym_expression_item_repeat1,
    STATE(11309), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13094), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [539879] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11310), 1,
      sym_attribute,
    STATE(11629), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [539939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [539975] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540011] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540047] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540083] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540119] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8288), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [540155] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11317), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16185), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [540215] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11318), 1,
      sym_attribute,
    STATE(11461), 1,
      sym__module_type,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [540275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540347] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    ACTIONS(13640), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10864), 1,
      aux_sym_expression_item_repeat1,
    STATE(11321), 1,
      sym_attribute,
    STATE(11697), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12571), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [540395] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [540431] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [540467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [540503] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    ACTIONS(13642), 1,
      anon_sym_EQ,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10942), 1,
      aux_sym_expression_item_repeat1,
    STATE(11325), 1,
      sym_attribute,
    STATE(11753), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12583), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [540551] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540587] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540623] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540659] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540695] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13180), 1,
      anon_sym_EQ,
    ACTIONS(13644), 1,
      anon_sym_of,
    ACTIONS(13646), 1,
      anon_sym_COLON2,
    STATE(11330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [540737] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [540789] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [540825] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(11333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540863] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [540899] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11335), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16593), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [540959] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [540995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541031] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11194), 1,
      aux_sym_expression_item_repeat1,
    STATE(11338), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12912), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541077] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11339), 1,
      sym_attribute,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11614), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [541123] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11340), 1,
      sym_attribute,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12213), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [541169] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [541205] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11342), 1,
      sym_attribute,
    STATE(11687), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [541265] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11343), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16789), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [541325] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541361] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11174), 1,
      aux_sym_expression_item_repeat1,
    STATE(11345), 1,
      sym_attribute,
    STATE(11454), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13112), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541407] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541443] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [541479] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11076), 1,
      aux_sym_expression_item_repeat1,
    STATE(11348), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541525] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [541561] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541597] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541633] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13180), 1,
      anon_sym_EQ,
    ACTIONS(13648), 1,
      anon_sym_of,
    ACTIONS(13650), 1,
      anon_sym_COLON2,
    STATE(11352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [541675] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8292), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [541711] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11354), 1,
      sym_attribute,
    STATE(11516), 1,
      sym__module_type,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [541771] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8020), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [541807] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541843] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [541879] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13652), 1,
      anon_sym_EQ,
    ACTIONS(13654), 1,
      anon_sym_COLON_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10865), 1,
      aux_sym_expression_item_repeat1,
    STATE(11358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13080), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [541923] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9222), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [541959] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11360), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16683), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542019] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542091] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(9182), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [542127] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542163] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542199] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11366), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16080), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542259] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11077), 1,
      aux_sym_expression_item_repeat1,
    STATE(11367), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [542305] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [542353] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11369), 1,
      sym_attribute,
    STATE(12030), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542413] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11078), 1,
      aux_sym_expression_item_repeat1,
    STATE(11370), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [542459] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13658), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13656), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [542501] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11372), 1,
      sym_attribute,
    STATE(11786), 1,
      sym__module_type,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542561] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11373), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16090), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542621] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [542657] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [542703] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542739] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [542775] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11378), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16310), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542835] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11379), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16404), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [542895] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [542931] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [542967] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(11382), 1,
      sym_attribute,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [543013] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12053), 1,
      anon_sym_STAR,
    STATE(11383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [543051] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9618), 9,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_exception,
      anon_sym_lazy,
      anon_sym_begin,
      anon_sym_effect,
      sym__lowercase_identifier,
    ACTIONS(9620), 12,
      anon_sym_TILDE,
      anon_sym_LPAREN,
      anon_sym_POUND,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      aux_sym_signed_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [543087] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [543123] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13660), 1,
      anon_sym_COLON2,
    STATE(11386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [543161] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11620), 1,
      anon_sym_DASH_GT,
    STATE(11387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10383), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10381), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543199] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11479), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [543235] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [543273] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(11390), 1,
      sym_attribute,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [543319] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11144), 1,
      aux_sym_expression_item_repeat1,
    STATE(11391), 1,
      sym_attribute,
    STATE(11417), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [543365] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11098), 1,
      aux_sym_expression_item_repeat1,
    STATE(11271), 1,
      aux_sym_type_binding_repeat1,
    STATE(11392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [543411] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [543447] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11394), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16051), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [543507] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [543565] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13664), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13662), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [543607] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [543649] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [543685] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11503), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [543721] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13572), 1,
      sym__lowercase_identifier,
    ACTIONS(13574), 1,
      anon_sym_LPAREN,
    ACTIONS(13576), 1,
      anon_sym_DASH_GT,
    ACTIONS(13578), 1,
      anon_sym_module,
    ACTIONS(13580), 1,
      anon_sym_sig,
    ACTIONS(13582), 1,
      anon_sym_functor,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13588), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11400), 1,
      sym_attribute,
    STATE(14408), 1,
      sym__module_type,
    STATE(15723), 1,
      aux_sym_module_binding_repeat1,
    STATE(18278), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14302), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [543781] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [543817] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(13666), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [543877] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13572), 1,
      sym__lowercase_identifier,
    ACTIONS(13574), 1,
      anon_sym_LPAREN,
    ACTIONS(13576), 1,
      anon_sym_DASH_GT,
    ACTIONS(13578), 1,
      anon_sym_module,
    ACTIONS(13580), 1,
      anon_sym_sig,
    ACTIONS(13582), 1,
      anon_sym_functor,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13588), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11403), 1,
      sym_attribute,
    STATE(14435), 1,
      sym__module_type,
    STATE(15723), 1,
      aux_sym_module_binding_repeat1,
    STATE(18278), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14302), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [543937] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(13666), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [543997] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13670), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13668), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [544039] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11495), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [544075] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10912), 1,
      aux_sym_expression_item_repeat1,
    STATE(11407), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13076), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544121] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [544157] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(11409), 1,
      sym_attribute,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12347), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [544203] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11410), 1,
      sym_attribute,
    STATE(11685), 1,
      sym__module_type,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [544263] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(11411), 1,
      sym_attribute,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [544309] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10907), 1,
      aux_sym_expression_item_repeat1,
    STATE(11412), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544355] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11413), 1,
      sym_attribute,
    STATE(11609), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [544415] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11159), 1,
      aux_sym_expression_item_repeat1,
    STATE(11414), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544461] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11519), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [544497] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [544533] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10908), 1,
      aux_sym_expression_item_repeat1,
    STATE(11417), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544579] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    STATE(11418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(10133), 10,
      anon_sym_PIPE,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
  [544617] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11232), 1,
      aux_sym_expression_item_repeat1,
    STATE(11253), 1,
      aux_sym_type_binding_repeat1,
    STATE(11419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544663] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11165), 1,
      aux_sym_expression_item_repeat1,
    STATE(11420), 1,
      sym_attribute,
    STATE(11473), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13132), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544709] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10951), 1,
      aux_sym_expression_item_repeat1,
    STATE(11421), 1,
      sym_attribute,
    STATE(11504), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13120), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544755] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11422), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(15931), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [544815] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10910), 1,
      aux_sym_expression_item_repeat1,
    STATE(11423), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [544861] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 5,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [544909] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11425), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16735), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [544969] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12043), 1,
      anon_sym_STAR,
    STATE(11426), 1,
      sym_attribute,
    STATE(11430), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13674), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13672), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [545009] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11142), 1,
      aux_sym_expression_item_repeat1,
    STATE(11412), 1,
      aux_sym_type_binding_repeat1,
    STATE(11427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [545055] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545091] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [545127] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13676), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12213), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11430), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [545165] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10902), 1,
      aux_sym_expression_item_repeat1,
    STATE(11338), 1,
      aux_sym_type_binding_repeat1,
    STATE(11431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13090), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [545211] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11535), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(8296), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545283] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13681), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13679), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [545325] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(9816), 1,
      sym__module_type,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11435), 1,
      sym_attribute,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [545385] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13572), 1,
      sym__lowercase_identifier,
    ACTIONS(13574), 1,
      anon_sym_LPAREN,
    ACTIONS(13576), 1,
      anon_sym_DASH_GT,
    ACTIONS(13578), 1,
      anon_sym_module,
    ACTIONS(13580), 1,
      anon_sym_sig,
    ACTIONS(13582), 1,
      anon_sym_functor,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13588), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11436), 1,
      sym_attribute,
    STATE(14378), 1,
      sym__module_type,
    STATE(15723), 1,
      aux_sym_module_binding_repeat1,
    STATE(18278), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14302), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [545445] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11539), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545481] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11543), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545517] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11487), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545553] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13685), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11440), 1,
      sym_attribute,
    STATE(11446), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13683), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [545595] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11441), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(17121), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [545655] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(11442), 1,
      sym_attribute,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [545701] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10817), 1,
      aux_sym_expression_item_repeat1,
    STATE(11414), 1,
      aux_sym_type_binding_repeat1,
    STATE(11443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [545747] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545783] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11551), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [545819] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13689), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13687), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [545861] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [545897] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(13666), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 5,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [545957] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10896), 1,
      aux_sym_expression_item_repeat1,
    STATE(11266), 1,
      aux_sym_type_binding_repeat1,
    STATE(11449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [546003] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(11450), 1,
      sym_attribute,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11477), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [546049] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546085] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12027), 1,
      anon_sym_STAR,
    STATE(11452), 1,
      sym_attribute,
    STATE(11458), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13674), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13672), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [546125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11555), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [546161] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11140), 1,
      aux_sym_expression_item_repeat1,
    STATE(11454), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13124), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [546207] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13685), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13683), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [546249] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(11456), 1,
      sym_attribute,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12458), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [546295] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    ACTIONS(13691), 1,
      anon_sym_STAR,
    STATE(11457), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(13289), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12025), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [546345] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13693), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12213), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11458), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [546383] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11559), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [546419] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(11460), 1,
      sym_attribute,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [546465] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    STATE(11461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13698), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13696), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [546505] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11523), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [546541] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11527), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [546577] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(9816), 1,
      sym__module_type,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11464), 1,
      sym_attribute,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [546637] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546673] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11466), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(17050), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [546733] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11467), 1,
      sym_attribute,
    STATE(12377), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [546793] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546829] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546865] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546901] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546937] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [546973] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10911), 1,
      aux_sym_expression_item_repeat1,
    STATE(11473), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13144), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [547019] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547055] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11475), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16991), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [547115] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10807), 1,
      aux_sym_expression_item_repeat1,
    STATE(11476), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12625), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [547161] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547197] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547233] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13702), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13700), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547275] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547311] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13554), 1,
      sym_pow_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_concat_operator,
      sym_assign_operator,
  [547351] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 12,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547387] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    STATE(11483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13706), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13704), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547427] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13198), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13708), 1,
      anon_sym_and,
    STATE(11484), 1,
      sym_attribute,
    STATE(11512), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13196), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [547467] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [547503] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11479), 1,
      sym__lowercase_identifier,
    STATE(11486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 4,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
    ACTIONS(12297), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12299), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [547543] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10914), 1,
      aux_sym_expression_item_repeat1,
    STATE(11348), 1,
      aux_sym_type_binding_repeat1,
    STATE(11487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [547589] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12423), 1,
      sym__lowercase_identifier,
    ACTIONS(12425), 1,
      anon_sym_POUND,
    STATE(11361), 1,
      sym_type_constructor_path,
    STATE(11488), 1,
      sym_attribute,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_PIPE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12343), 11,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [547635] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13712), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11455), 1,
      aux_sym_expression_item_repeat1,
    STATE(11489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13710), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [547677] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [547713] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11531), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [547749] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(11492), 1,
      sym_attribute,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12458), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [547795] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10916), 1,
      aux_sym_expression_item_repeat1,
    STATE(11367), 1,
      aux_sym_type_binding_repeat1,
    STATE(11493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [547841] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11494), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16780), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [547901] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11495), 1,
      sym_attribute,
    STATE(11627), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [547961] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10920), 1,
      aux_sym_expression_item_repeat1,
    STATE(11370), 1,
      aux_sym_type_binding_repeat1,
    STATE(11496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [548007] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11497), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16317), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [548067] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11563), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [548103] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12377), 1,
      sym__lowercase_identifier,
    ACTIONS(12379), 1,
      anon_sym_POUND,
    STATE(11398), 1,
      sym_type_constructor_path,
    STATE(11499), 1,
      sym_attribute,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 6,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12343), 10,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [548149] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10922), 1,
      aux_sym_expression_item_repeat1,
    STATE(11500), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [548195] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13524), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13708), 1,
      anon_sym_and,
    STATE(11484), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13522), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [548235] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11502), 1,
      sym_attribute,
    STATE(11706), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [548295] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11507), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [548331] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11192), 1,
      aux_sym_expression_item_repeat1,
    STATE(11504), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13014), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [548377] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11575), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [548413] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(11506), 1,
      sym_attribute,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12458), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [548459] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [548495] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [548531] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [548567] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12512), 1,
      anon_sym_DASH_GT,
    ACTIONS(12514), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11510), 1,
      sym_attribute,
    STATE(12250), 1,
      sym__module_type,
    STATE(15768), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [548627] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10273), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
  [548685] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12049), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13714), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11512), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(12047), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [548723] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11513), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16276), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [548783] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    STATE(11514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 11,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [548821] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13024), 1,
      anon_sym_EQ,
    ACTIONS(13717), 1,
      anon_sym_of,
    ACTIONS(13719), 1,
      anon_sym_COLON2,
    STATE(11515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13022), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13020), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [548863] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    STATE(11516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13723), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13721), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [548903] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(11517), 1,
      sym_attribute,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(12343), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [548949] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [548985] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 2,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 7,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT_RBRACE,
      sym_assign_operator,
  [549041] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11499), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [549077] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11547), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [549113] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11151), 1,
      aux_sym_expression_item_repeat1,
    STATE(11423), 1,
      aux_sym_type_binding_repeat1,
    STATE(11522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [549159] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 4,
      anon_sym_COLON2,
      anon_sym_as,
      anon_sym_when,
      sym__lowercase_identifier,
    ACTIONS(9224), 17,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [549195] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10822), 1,
      aux_sym_expression_item_repeat1,
    STATE(11524), 1,
      sym_attribute,
    STATE(12227), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12812), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [549241] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13540), 1,
      anon_sym_DASH_GT,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13544), 1,
      anon_sym_functor,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11293), 1,
      sym__module_type,
    STATE(11525), 1,
      sym_attribute,
    STATE(15726), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549301] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11526), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16228), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549361] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12175), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11212), 1,
      aux_sym_expression_item_repeat1,
    STATE(11500), 1,
      aux_sym_type_binding_repeat1,
    STATE(11527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [549407] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      anon_sym_EQ,
    ACTIONS(13725), 1,
      anon_sym_of,
    ACTIONS(13727), 1,
      anon_sym_COLON2,
    STATE(11528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13066), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [549449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11491), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [549485] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11530), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16504), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549545] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11531), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(16779), 1,
      sym__module_type,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549605] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13731), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13729), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [549647] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11483), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [549683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 9,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11587), 12,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [549719] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [549755] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11536), 1,
      sym_attribute,
    STATE(12552), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549815] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11537), 1,
      sym_attribute,
    STATE(15870), 1,
      sym__module_type,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549875] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 10,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym__uppercase_identifier,
    ACTIONS(11511), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
      aux_sym_directive_token1,
  [549911] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11539), 1,
      sym_attribute,
    STATE(15120), 1,
      sym__module_type,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [549971] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11540), 1,
      sym_attribute,
    STATE(15121), 1,
      sym__module_type,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550031] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11541), 1,
      sym_attribute,
    STATE(12556), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550091] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11542), 1,
      sym_attribute,
    STATE(15126), 1,
      sym__module_type,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550151] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11543), 1,
      sym_attribute,
    STATE(12557), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550211] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    STATE(11544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13698), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13696), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550251] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    STATE(11545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13612), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13610), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550291] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    STATE(11546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13620), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13618), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550331] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    STATE(11547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13706), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13704), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550371] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    STATE(11548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13723), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13721), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [550411] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11549), 1,
      sym_attribute,
    STATE(12405), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550471] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11550), 1,
      sym_attribute,
    STATE(12406), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550531] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11551), 1,
      sym_attribute,
    STATE(12407), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550591] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11552), 1,
      sym_attribute,
    STATE(12408), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550651] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 10,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 11,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [550687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8755), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(8757), 13,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
      aux_sym_attribute_id_token1,
  [550723] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11555), 1,
      sym_attribute,
    STATE(15158), 1,
      sym__module_type,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550783] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      anon_sym_DASH_GT,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12500), 1,
      anon_sym_functor,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    STATE(9816), 1,
      sym__module_type,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11556), 1,
      sym_attribute,
    STATE(15885), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550843] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11548), 1,
      sym__module_type,
    STATE(11557), 1,
      sym_attribute,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550903] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11544), 1,
      sym__module_type,
    STATE(11558), 1,
      sym_attribute,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [550963] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11545), 1,
      sym__module_type,
    STATE(11559), 1,
      sym_attribute,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551023] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11546), 1,
      sym__module_type,
    STATE(11560), 1,
      sym_attribute,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551083] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11561), 1,
      sym_attribute,
    STATE(11767), 1,
      sym__module_type,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551143] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11547), 1,
      sym__module_type,
    STATE(11562), 1,
      sym_attribute,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551203] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11563), 1,
      sym_attribute,
    STATE(11769), 1,
      sym__module_type,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551263] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(13542), 1,
      anon_sym_module,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13737), 1,
      anon_sym_DASH_GT,
    ACTIONS(13739), 1,
      anon_sym_functor,
    STATE(9816), 1,
      sym__module_type,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11564), 1,
      sym_attribute,
    STATE(15895), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551323] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11818), 1,
      anon_sym_DASH_GT,
    STATE(11565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10383), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10381), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [551361] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11566), 1,
      sym_attribute,
    STATE(12411), 1,
      sym__module_type,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551421] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(12490), 1,
      sym__lowercase_identifier,
    ACTIONS(12492), 1,
      anon_sym_LPAREN,
    ACTIONS(12496), 1,
      anon_sym_module,
    ACTIONS(12498), 1,
      anon_sym_sig,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(12621), 1,
      anon_sym_DASH_GT,
    ACTIONS(12623), 1,
      anon_sym_functor,
    STATE(9816), 1,
      sym__module_type,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(11567), 1,
      sym_attribute,
    STATE(15899), 1,
      aux_sym_module_binding_repeat1,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9941), 8,
      sym_signature,
      sym_module_type_constraint,
      sym_module_type_of,
      sym_functor_type,
      sym_parenthesized_module_type,
      sym_extension,
      sym_quoted_extension,
      sym_module_type_path,
  [551481] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12351), 1,
      sym__lowercase_identifier,
    ACTIONS(12353), 1,
      anon_sym_POUND,
    STATE(11406), 1,
      sym_type_constructor_path,
    STATE(11568), 1,
      sym_attribute,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
    ACTIONS(11449), 11,
      anon_sym_let,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
      aux_sym_directive_token1,
  [551527] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12285), 1,
      anon_sym_STAR,
    ACTIONS(13674), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(11569), 1,
      sym_attribute,
    STATE(11713), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [551566] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10911), 1,
      aux_sym_expression_item_repeat1,
    STATE(11570), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13144), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [551611] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13743), 1,
      anon_sym_let,
    ACTIONS(13745), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11245), 1,
      aux_sym_expression_item_repeat1,
    STATE(11571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13741), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [551654] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10914), 1,
      aux_sym_expression_item_repeat1,
    STATE(11572), 1,
      sym_attribute,
    STATE(11584), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [551699] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13747), 1,
      anon_sym_LPAREN,
    ACTIONS(13749), 1,
      anon_sym_end,
    STATE(11573), 1,
      sym_attribute,
    STATE(11960), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [551756] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10916), 1,
      aux_sym_expression_item_repeat1,
    STATE(11574), 1,
      sym_attribute,
    STATE(11586), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [551801] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [551838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [551873] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [551908] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13751), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(11578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [551947] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10920), 1,
      aux_sym_expression_item_repeat1,
    STATE(11579), 1,
      sym_attribute,
    STATE(11587), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13148), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [551992] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10922), 1,
      aux_sym_expression_item_repeat1,
    STATE(11580), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552037] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10923), 1,
      aux_sym_expression_item_repeat1,
    STATE(11581), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552082] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [552117] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10926), 1,
      aux_sym_expression_item_repeat1,
    STATE(11583), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12901), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552162] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11076), 1,
      aux_sym_expression_item_repeat1,
    STATE(11584), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552207] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [552242] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11077), 1,
      aux_sym_expression_item_repeat1,
    STATE(11586), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552287] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11078), 1,
      aux_sym_expression_item_repeat1,
    STATE(11587), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12940), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [552332] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13755), 1,
      anon_sym_let,
    ACTIONS(13757), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11111), 1,
      aux_sym_expression_item_repeat1,
    STATE(11588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13753), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [552375] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13759), 1,
      anon_sym_LPAREN,
    ACTIONS(13761), 1,
      anon_sym_end,
    STATE(11589), 1,
      sym_attribute,
    STATE(12201), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552432] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_and,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [552483] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [552536] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [552593] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [552634] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13781), 1,
      anon_sym_LPAREN,
    ACTIONS(13783), 1,
      anon_sym_end,
    STATE(11594), 1,
      sym_attribute,
    STATE(11836), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552691] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [552748] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13785), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12213), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11596), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [552785] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [552820] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13788), 1,
      anon_sym_LPAREN,
    ACTIONS(13790), 1,
      anon_sym_end,
    STATE(11598), 1,
      sym_attribute,
    STATE(11923), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552877] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13792), 1,
      anon_sym_LPAREN,
    ACTIONS(13794), 1,
      anon_sym_end,
    STATE(11599), 1,
      sym_attribute,
    STATE(12137), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [552934] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13798), 1,
      anon_sym_let,
    ACTIONS(13800), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11115), 1,
      aux_sym_expression_item_repeat1,
    STATE(11600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13796), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [552977] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13802), 1,
      anon_sym_LPAREN,
    ACTIONS(13804), 1,
      anon_sym_end,
    STATE(11601), 1,
      sym_attribute,
    STATE(12126), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553034] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13751), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(11602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [553073] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10273), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [553130] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(11604), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12347), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [553175] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13806), 1,
      anon_sym_LPAREN,
    ACTIONS(13808), 1,
      anon_sym_end,
    STATE(11605), 1,
      sym_attribute,
    STATE(12360), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553232] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8070), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      anon_sym_DQUOTE,
      sym_let_operator,
      aux_sym_directive_token1,
  [553267] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13810), 1,
      anon_sym_LPAREN,
    ACTIONS(13812), 1,
      anon_sym_end,
    STATE(11607), 1,
      sym_attribute,
    STATE(12029), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553324] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13598), 1,
      anon_sym_EQ,
    ACTIONS(13814), 1,
      anon_sym_of,
    ACTIONS(13816), 1,
      anon_sym_COLON2,
    STATE(11608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [553365] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13706), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(11609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13704), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [553404] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13822), 1,
      anon_sym_LPAREN,
    ACTIONS(13824), 1,
      anon_sym_end,
    STATE(11610), 1,
      sym_attribute,
    STATE(12008), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553461] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(13826), 1,
      sym__lowercase_identifier,
    ACTIONS(13828), 1,
      anon_sym_STAR,
    ACTIONS(13830), 1,
      anon_sym_POUND,
    STATE(11611), 1,
      sym_attribute,
    STATE(12571), 1,
      sym_type_constructor_path,
    STATE(17779), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 6,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [553508] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13604), 1,
      anon_sym_EQ,
    ACTIONS(13832), 1,
      anon_sym_of,
    ACTIONS(13834), 1,
      anon_sym_COLON2,
    STATE(11612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [553549] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [553584] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13836), 1,
      anon_sym_LPAREN,
    ACTIONS(13838), 1,
      anon_sym_end,
    STATE(11614), 1,
      sym_attribute,
    STATE(11887), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553641] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13840), 1,
      anon_sym_LPAREN,
    ACTIONS(13842), 1,
      anon_sym_end,
    STATE(11615), 1,
      sym_attribute,
    STATE(12211), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [553698] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13844), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(11616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [553737] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(11617), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [553782] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13848), 1,
      anon_sym_BANG,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(9481), 1,
      sym__module_expression,
    STATE(11618), 1,
      sym_attribute,
    STATE(12897), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [553839] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13856), 1,
      anon_sym_PIPE,
    STATE(11619), 1,
      sym_attribute,
    STATE(11621), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [553878] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13856), 1,
      anon_sym_PIPE,
    STATE(11620), 1,
      sym_attribute,
    STATE(11623), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [553917] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13856), 1,
      anon_sym_PIPE,
    STATE(11621), 1,
      sym_attribute,
    STATE(11624), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [553956] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13858), 1,
      anon_sym_LPAREN,
    ACTIONS(13860), 1,
      anon_sym_end,
    STATE(11622), 1,
      sym_attribute,
    STATE(11987), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554013] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13856), 1,
      anon_sym_PIPE,
    STATE(11623), 1,
      sym_attribute,
    STATE(11624), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [554052] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13862), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11624), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [554089] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12413), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12411), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [554124] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [554159] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13723), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(11627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13721), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [554198] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12049), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13865), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11628), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(12047), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [554235] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13698), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(11629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13696), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [554274] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13868), 1,
      anon_sym_LPAREN,
    ACTIONS(13870), 1,
      anon_sym_end,
    STATE(11630), 1,
      sym_attribute,
    STATE(11998), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554331] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [554366] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13872), 1,
      anon_sym_LPAREN,
    ACTIONS(13874), 1,
      anon_sym_end,
    STATE(11632), 1,
      sym_attribute,
    STATE(12116), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554423] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(11633), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [554468] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13622), 1,
      anon_sym_EQ,
    ACTIONS(13876), 1,
      anon_sym_of,
    ACTIONS(13878), 1,
      anon_sym_COLON2,
    STATE(11634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [554509] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13882), 1,
      anon_sym_let,
    ACTIONS(13884), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(11635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13880), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [554552] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    ACTIONS(13886), 1,
      anon_sym_SEMI,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [554611] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13888), 1,
      anon_sym_LPAREN,
    ACTIONS(13890), 1,
      anon_sym_end,
    STATE(11637), 1,
      sym_attribute,
    STATE(12062), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [554703] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13743), 1,
      anon_sym_let,
    ACTIONS(13892), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11245), 1,
      aux_sym_expression_item_repeat1,
    STATE(11639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13741), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [554746] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13894), 1,
      anon_sym_LPAREN,
    ACTIONS(13896), 1,
      anon_sym_end,
    STATE(11640), 1,
      sym_attribute,
    STATE(12180), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554803] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13898), 1,
      anon_sym_LPAREN,
    ACTIONS(13900), 1,
      anon_sym_end,
    STATE(11641), 1,
      sym_attribute,
    STATE(11934), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554860] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13902), 1,
      anon_sym_LPAREN,
    ACTIONS(13904), 1,
      anon_sym_end,
    STATE(11642), 1,
      sym_attribute,
    STATE(12083), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554917] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13906), 1,
      anon_sym_LPAREN,
    ACTIONS(13908), 1,
      anon_sym_end,
    STATE(11643), 1,
      sym_attribute,
    STATE(12159), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [554974] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [555009] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13910), 1,
      anon_sym_LPAREN,
    ACTIONS(13912), 1,
      anon_sym_end,
    STATE(11645), 1,
      sym_attribute,
    STATE(12072), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555066] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [555101] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13914), 1,
      anon_sym_LPAREN,
    ACTIONS(13916), 1,
      anon_sym_end,
    STATE(11647), 1,
      sym_attribute,
    STATE(11851), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13920), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13918), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      anon_sym_DQUOTE,
      sym_let_operator,
      aux_sym_directive_token1,
  [555193] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13922), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12397), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11649), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555232] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13925), 1,
      anon_sym_LPAREN,
    ACTIONS(13927), 1,
      anon_sym_end,
    STATE(11650), 1,
      sym_attribute,
    STATE(11820), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555289] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12441), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12439), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [555324] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12151), 1,
      anon_sym_STAR,
    STATE(11652), 1,
      sym_attribute,
    STATE(11656), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13674), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13672), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555363] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13931), 1,
      anon_sym_let,
    ACTIONS(13933), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10939), 1,
      aux_sym_expression_item_repeat1,
    STATE(11653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13929), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555406] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13937), 1,
      anon_sym_let,
    ACTIONS(13939), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11196), 1,
      aux_sym_expression_item_repeat1,
    STATE(11654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13935), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555449] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [555484] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13941), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12213), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11656), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555521] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13944), 1,
      anon_sym_LPAREN,
    ACTIONS(13946), 1,
      anon_sym_end,
    STATE(11657), 1,
      sym_attribute,
    STATE(11795), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555578] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 6,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [555633] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13948), 1,
      anon_sym_LPAREN,
    ACTIONS(13950), 1,
      anon_sym_end,
    STATE(11659), 1,
      sym_attribute,
    STATE(12170), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555690] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13882), 1,
      anon_sym_let,
    ACTIONS(13952), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(11660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13880), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555733] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11661), 1,
      sym_attribute,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 5,
      anon_sym_SEMI_SEMI,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12213), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [555778] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13956), 1,
      anon_sym_let,
    ACTIONS(13958), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10943), 1,
      aux_sym_expression_item_repeat1,
    STATE(11662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13954), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555821] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13960), 1,
      anon_sym_LPAREN,
    ACTIONS(13962), 1,
      anon_sym_end,
    STATE(11663), 1,
      sym_attribute,
    STATE(11832), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [555878] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13622), 1,
      anon_sym_EQ,
    ACTIONS(13964), 1,
      anon_sym_of,
    ACTIONS(13966), 1,
      anon_sym_COLON2,
    STATE(11664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [555919] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13972), 1,
      anon_sym_PIPE,
    STATE(11665), 1,
      sym_attribute,
    STATE(11667), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555958] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13972), 1,
      anon_sym_PIPE,
    STATE(11666), 1,
      sym_attribute,
    STATE(11667), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13976), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13974), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [555997] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13978), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12760), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11667), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [556034] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13844), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(11668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [556073] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12464), 4,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12462), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [556108] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13981), 1,
      anon_sym_LPAREN,
    ACTIONS(13983), 1,
      anon_sym_end,
    STATE(11670), 1,
      sym_attribute,
    STATE(12192), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556165] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13985), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11671), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8757), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(8755), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [556202] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [556247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [556282] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [556317] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(8074), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      anon_sym_DQUOTE,
      sym_let_operator,
      aux_sym_directive_token1,
  [556352] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13988), 1,
      anon_sym_PIPE,
    STATE(11676), 1,
      sym_attribute,
    STATE(11679), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13976), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13974), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [556391] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [556426] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(11678), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [556471] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13990), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12760), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11679), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [556508] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13995), 1,
      anon_sym_let,
    ACTIONS(13997), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11089), 1,
      aux_sym_expression_item_repeat1,
    STATE(11680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13993), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [556551] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10912), 1,
      aux_sym_expression_item_repeat1,
    STATE(11681), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13076), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [556596] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11019), 11,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [556631] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [556666] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [556701] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    ACTIONS(14001), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11532), 1,
      aux_sym_expression_item_repeat1,
    STATE(11685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13999), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [556746] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13598), 1,
      anon_sym_EQ,
    ACTIONS(14003), 1,
      anon_sym_of,
    ACTIONS(14005), 1,
      anon_sym_COLON2,
    STATE(11686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [556787] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13620), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(11687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13618), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [556826] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14007), 1,
      anon_sym_LPAREN,
    ACTIONS(14009), 1,
      anon_sym_end,
    STATE(11688), 1,
      sym_attribute,
    STATE(11945), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [556883] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13765), 1,
      sym_pow_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [556922] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12307), 1,
      anon_sym_STAR,
    STATE(11690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 18,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [556959] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14011), 1,
      anon_sym_LPAREN,
    ACTIONS(14013), 1,
      anon_sym_end,
    STATE(11691), 1,
      sym_attribute,
    STATE(12042), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557016] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10908), 1,
      aux_sym_expression_item_repeat1,
    STATE(11692), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557061] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10910), 1,
      aux_sym_expression_item_repeat1,
    STATE(11693), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557106] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10902), 1,
      aux_sym_expression_item_repeat1,
    STATE(11694), 1,
      sym_attribute,
    STATE(11729), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13090), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557151] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [557186] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13972), 1,
      anon_sym_PIPE,
    STATE(11665), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12259), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557225] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10822), 1,
      aux_sym_expression_item_repeat1,
    STATE(11697), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12812), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557270] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13798), 1,
      anon_sym_let,
    ACTIONS(14015), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11115), 1,
      aux_sym_expression_item_repeat1,
    STATE(11698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13796), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557313] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14017), 1,
      anon_sym_LPAREN,
    ACTIONS(14019), 1,
      anon_sym_end,
    STATE(11699), 1,
      sym_attribute,
    STATE(12052), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557370] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11167), 1,
      aux_sym_expression_item_repeat1,
    STATE(11700), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13094), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557415] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14021), 1,
      anon_sym_LPAREN,
    ACTIONS(14023), 1,
      anon_sym_end,
    STATE(11701), 1,
      sym_attribute,
    STATE(12393), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557472] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(14025), 1,
      anon_sym_BANG,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9309), 1,
      sym__module_expression,
    STATE(11702), 1,
      sym_attribute,
    STATE(12618), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [557529] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13755), 1,
      anon_sym_let,
    ACTIONS(14029), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11111), 1,
      aux_sym_expression_item_repeat1,
    STATE(11703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13753), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557572] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13937), 1,
      anon_sym_let,
    ACTIONS(14031), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11196), 1,
      aux_sym_expression_item_repeat1,
    STATE(11704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13935), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [557615] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13604), 1,
      anon_sym_EQ,
    ACTIONS(14033), 1,
      anon_sym_of,
    ACTIONS(14035), 1,
      anon_sym_COLON2,
    STATE(11705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557656] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13612), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(11706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13610), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [557695] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(13826), 1,
      sym__lowercase_identifier,
    ACTIONS(13830), 1,
      anon_sym_POUND,
    ACTIONS(14037), 1,
      anon_sym_DASH_GT,
    ACTIONS(14039), 1,
      anon_sym_STAR,
    STATE(11707), 1,
      sym_attribute,
    STATE(12571), 1,
      sym_type_constructor_path,
    STATE(17779), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 5,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [557744] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [557779] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14041), 1,
      anon_sym_LPAREN,
    ACTIONS(14043), 1,
      anon_sym_end,
    STATE(11709), 1,
      sym_attribute,
    STATE(11808), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [557836] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14047), 1,
      anon_sym_BANG,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(11710), 1,
      sym_attribute,
    STATE(12613), 1,
      sym__attribute,
    STATE(13660), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [557893] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [557928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [557963] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12213), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14055), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11713), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558000] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14058), 1,
      anon_sym_LPAREN,
    ACTIONS(14060), 1,
      anon_sym_end,
    STATE(11714), 1,
      sym_attribute,
    STATE(11898), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558057] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558092] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558127] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14064), 1,
      anon_sym_let,
    ACTIONS(14066), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11097), 1,
      aux_sym_expression_item_repeat1,
    STATE(11717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14062), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [558170] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14068), 1,
      anon_sym_LPAREN,
    ACTIONS(14070), 1,
      anon_sym_end,
    STATE(11718), 1,
      sym_attribute,
    STATE(12148), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [558227] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12021), 1,
      anon_sym_DASH_GT,
    STATE(11719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558264] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13198), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14072), 1,
      anon_sym_and,
    STATE(11628), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13196), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558303] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12295), 1,
      anon_sym_STAR,
    STATE(11596), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(11721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13674), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13672), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [558342] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14076), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11396), 1,
      aux_sym_expression_item_repeat1,
    STATE(11722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14078), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14074), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [558385] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    ACTIONS(13886), 1,
      anon_sym_SEMI,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [558444] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558479] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558514] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558549] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558584] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11174), 1,
      aux_sym_expression_item_repeat1,
    STATE(11728), 1,
      sym_attribute,
    STATE(11761), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13112), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558629] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11194), 1,
      aux_sym_expression_item_repeat1,
    STATE(11729), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12912), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [558674] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    STATE(11730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 9,
      anon_sym_COLON2,
      anon_sym_DASH_GT,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 10,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_GT_RBRACE,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
  [558711] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(11731), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12458), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [558756] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14082), 1,
      anon_sym_let,
    ACTIONS(14084), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11176), 1,
      aux_sym_expression_item_repeat1,
    STATE(11732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14080), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [558799] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13972), 1,
      anon_sym_PIPE,
    STATE(11666), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [558838] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [558873] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    ACTIONS(13886), 1,
      anon_sym_SEMI,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [558932] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(12526), 1,
      anon_sym_POUND,
    STATE(11376), 1,
      sym_type_constructor_path,
    STATE(11736), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12343), 9,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT,
  [558977] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13524), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14072), 1,
      anon_sym_and,
    STATE(11720), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(11737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13522), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_with,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559016] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10343), 8,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_LBRACE,
      anon_sym_object,
      anon_sym_new,
      anon_sym_begin,
      sym__lowercase_identifier,
    ACTIONS(10345), 12,
      anon_sym_LPAREN,
      anon_sym_LBRACK_PIPE,
      anon_sym_LBRACE_LT,
      sym_ocamlyacc_value,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      aux_sym_number_token1,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_prefix_operator,
      sym__uppercase_identifier,
      aux_sym_tag_token1,
  [559051] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14086), 1,
      anon_sym_LPAREN,
    ACTIONS(14088), 1,
      anon_sym_end,
    STATE(11739), 1,
      sym_attribute,
    STATE(12103), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559108] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14090), 1,
      anon_sym_LPAREN,
    ACTIONS(14092), 1,
      anon_sym_end,
    STATE(11740), 1,
      sym_attribute,
    STATE(11863), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559165] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13988), 1,
      anon_sym_PIPE,
    STATE(11741), 1,
      sym_attribute,
    STATE(11784), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12259), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559204] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13931), 1,
      anon_sym_let,
    ACTIONS(14094), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10939), 1,
      aux_sym_expression_item_repeat1,
    STATE(11742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13929), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559247] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14096), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12397), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(11743), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559286] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11098), 1,
      aux_sym_expression_item_repeat1,
    STATE(11744), 1,
      sym_attribute,
    STATE(11772), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559331] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14099), 1,
      anon_sym_LPAREN,
    ACTIONS(14101), 1,
      anon_sym_end,
    STATE(11745), 1,
      sym_attribute,
    STATE(12321), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559388] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10802), 1,
      aux_sym_expression_item_repeat1,
    STATE(11746), 1,
      sym_attribute,
    STATE(11773), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559433] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10817), 1,
      aux_sym_expression_item_repeat1,
    STATE(11747), 1,
      sym_attribute,
    STATE(11774), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13116), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559478] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10951), 1,
      aux_sym_expression_item_repeat1,
    STATE(11748), 1,
      sym_attribute,
    STATE(11780), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13120), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559523] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13956), 1,
      anon_sym_let,
    ACTIONS(14103), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10943), 1,
      aux_sym_expression_item_repeat1,
    STATE(11749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13954), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559566] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(13826), 1,
      sym__lowercase_identifier,
    ACTIONS(13830), 1,
      anon_sym_POUND,
    STATE(11750), 1,
      sym_attribute,
    STATE(12571), 1,
      sym_type_constructor_path,
    STATE(17779), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 7,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [559611] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14107), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11479), 1,
      aux_sym_expression_item_repeat1,
    STATE(11751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14109), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14105), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559654] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14111), 1,
      anon_sym_LPAREN,
    ACTIONS(14113), 1,
      anon_sym_end,
    STATE(11752), 1,
      sym_attribute,
    STATE(12190), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559711] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10807), 1,
      aux_sym_expression_item_repeat1,
    STATE(11753), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12625), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [559756] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14115), 1,
      anon_sym_LPAREN,
    ACTIONS(14117), 1,
      anon_sym_end,
    STATE(11754), 1,
      sym_attribute,
    STATE(11875), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [559813] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13988), 1,
      anon_sym_PIPE,
    STATE(11676), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559852] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [559887] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13765), 1,
      sym_pow_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [559926] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13995), 1,
      anon_sym_let,
    ACTIONS(14119), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11089), 1,
      aux_sym_expression_item_repeat1,
    STATE(11758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13993), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [559969] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14064), 1,
      anon_sym_let,
    ACTIONS(14121), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11097), 1,
      aux_sym_expression_item_repeat1,
    STATE(11759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14062), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [560012] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [560059] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11140), 1,
      aux_sym_expression_item_repeat1,
    STATE(11761), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13124), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560104] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [560139] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11142), 1,
      aux_sym_expression_item_repeat1,
    STATE(11763), 1,
      sym_attribute,
    STATE(11792), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560184] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14082), 1,
      anon_sym_let,
    ACTIONS(14123), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11176), 1,
      aux_sym_expression_item_repeat1,
    STATE(11764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14080), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [560227] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 8,
      anon_sym_SEMI_SEMI,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 12,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [560262] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11144), 1,
      aux_sym_expression_item_repeat1,
    STATE(11692), 1,
      aux_sym_type_binding_repeat1,
    STATE(11766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560307] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    ACTIONS(14127), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11301), 1,
      aux_sym_expression_item_repeat1,
    STATE(11767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14125), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [560352] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14129), 1,
      anon_sym_LPAREN,
    ACTIONS(14131), 1,
      anon_sym_end,
    STATE(11768), 1,
      sym_attribute,
    STATE(12019), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560409] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13733), 1,
      anon_sym_DASH_GT,
    ACTIONS(13735), 1,
      anon_sym_with,
    ACTIONS(14001), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11532), 1,
      aux_sym_expression_item_repeat1,
    STATE(11769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13999), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [560454] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11151), 1,
      aux_sym_expression_item_repeat1,
    STATE(11693), 1,
      aux_sym_type_binding_repeat1,
    STATE(11770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13128), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560499] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    ACTIONS(13771), 1,
      sym_rel_operator,
    ACTIONS(13773), 1,
      sym_and_operator,
    ACTIONS(13775), 1,
      sym_or_operator,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    ACTIONS(13779), 1,
      sym_assign_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10335), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [560556] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11156), 1,
      aux_sym_expression_item_repeat1,
    STATE(11772), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560601] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11158), 1,
      aux_sym_expression_item_repeat1,
    STATE(11773), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560646] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11159), 1,
      aux_sym_expression_item_repeat1,
    STATE(11774), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12653), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560691] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11165), 1,
      aux_sym_expression_item_repeat1,
    STATE(11570), 1,
      aux_sym_type_binding_repeat1,
    STATE(11775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13132), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560736] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14133), 1,
      anon_sym_LPAREN,
    ACTIONS(14135), 1,
      anon_sym_end,
    STATE(11776), 1,
      sym_attribute,
    STATE(11911), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560793] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14137), 1,
      anon_sym_LPAREN,
    ACTIONS(14139), 1,
      anon_sym_end,
    STATE(11777), 1,
      sym_attribute,
    STATE(11974), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560850] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14141), 1,
      anon_sym_LPAREN,
    ACTIONS(14143), 1,
      anon_sym_end,
    STATE(11778), 1,
      sym_attribute,
    STATE(12286), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [560907] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14145), 1,
      aux_sym_attribute_id_token1,
    STATE(11779), 1,
      sym_attribute,
    STATE(11793), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8774), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(8772), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [560946] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11192), 1,
      aux_sym_expression_item_repeat1,
    STATE(11780), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13014), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [560991] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(13826), 1,
      sym__lowercase_identifier,
    ACTIONS(14147), 1,
      anon_sym_POUND,
    STATE(11781), 1,
      sym_attribute,
    STATE(12447), 1,
      sym_type_constructor_path,
    STATE(17779), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 7,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
  [561036] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11212), 1,
      aux_sym_expression_item_repeat1,
    STATE(11580), 1,
      aux_sym_type_binding_repeat1,
    STATE(11782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [561081] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11232), 1,
      aux_sym_expression_item_repeat1,
    STATE(11581), 1,
      aux_sym_type_binding_repeat1,
    STATE(11783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [561126] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13988), 1,
      anon_sym_PIPE,
    STATE(11679), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(11784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [561165] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10896), 1,
      aux_sym_expression_item_repeat1,
    STATE(11583), 1,
      aux_sym_type_binding_repeat1,
    STATE(11785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13136), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [561210] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13614), 1,
      anon_sym_DASH_GT,
    ACTIONS(13616), 1,
      anon_sym_with,
    ACTIONS(14127), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11301), 1,
      aux_sym_expression_item_repeat1,
    STATE(11786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14125), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [561255] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14149), 1,
      anon_sym_LPAREN,
    ACTIONS(14151), 1,
      anon_sym_end,
    STATE(11787), 1,
      sym_attribute,
    STATE(11896), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561312] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14153), 1,
      anon_sym_LPAREN,
    ACTIONS(14155), 1,
      anon_sym_end,
    STATE(11788), 1,
      sym_attribute,
    STATE(12093), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561369] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14076), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11396), 1,
      aux_sym_expression_item_repeat1,
    STATE(11789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14157), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14074), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [561412] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14107), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11479), 1,
      aux_sym_expression_item_repeat1,
    STATE(11790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14159), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14105), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [561455] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13763), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13765), 1,
      sym_pow_operator,
    ACTIONS(13767), 1,
      sym_mult_operator,
    ACTIONS(13769), 1,
      sym_concat_operator,
    STATE(2331), 1,
      sym_add_operator,
    STATE(11791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [561502] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12421), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10907), 1,
      aux_sym_expression_item_repeat1,
    STATE(11792), 1,
      sym_attribute,
    STATE(12518), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13140), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [561547] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14145), 1,
      aux_sym_attribute_id_token1,
    STATE(11671), 1,
      aux_sym_attribute_id_repeat1,
    STATE(11793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8768), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(8766), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [561586] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14165), 1,
      anon_sym_and,
    ACTIONS(14167), 1,
      sym_let_and_operator,
    STATE(11794), 1,
      sym_attribute,
    STATE(12383), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14163), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14161), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [561626] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14169), 1,
      anon_sym_end,
    STATE(11795), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561680] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14171), 1,
      anon_sym_end,
    STATE(11796), 1,
      sym_attribute,
    STATE(11797), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561734] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14173), 1,
      anon_sym_end,
    STATE(11797), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561788] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14175), 1,
      anon_sym_end,
    STATE(11798), 1,
      sym_attribute,
    STATE(11800), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561842] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14177), 1,
      anon_sym_end,
    STATE(11799), 1,
      sym_attribute,
    STATE(11801), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561896] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14179), 1,
      anon_sym_end,
    STATE(11800), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [561950] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14181), 1,
      anon_sym_end,
    STATE(11801), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562004] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14183), 1,
      anon_sym_end,
    STATE(11802), 1,
      sym_attribute,
    STATE(11803), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562058] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14185), 1,
      anon_sym_end,
    STATE(11803), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562112] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14187), 1,
      anon_sym_end,
    STATE(11804), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562166] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14189), 1,
      anon_sym_end,
    STATE(11805), 1,
      sym_attribute,
    STATE(11884), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562220] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14043), 1,
      anon_sym_end,
    STATE(11806), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562274] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14191), 1,
      anon_sym_end,
    STATE(11807), 1,
      sym_attribute,
    STATE(11899), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562328] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14193), 1,
      anon_sym_end,
    STATE(11808), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562382] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14195), 1,
      anon_sym_end,
    STATE(11809), 1,
      sym_attribute,
    STATE(11810), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562436] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14197), 1,
      anon_sym_end,
    STATE(11810), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562490] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14199), 1,
      anon_sym_end,
    STATE(11811), 1,
      sym_attribute,
    STATE(11813), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562544] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14201), 1,
      anon_sym_end,
    STATE(11812), 1,
      sym_attribute,
    STATE(11814), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562598] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14203), 1,
      anon_sym_end,
    STATE(11813), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562652] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14205), 1,
      anon_sym_end,
    STATE(11814), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562706] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14207), 1,
      anon_sym_end,
    STATE(11815), 1,
      sym_attribute,
    STATE(11816), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562760] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14209), 1,
      anon_sym_end,
    STATE(11816), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562814] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14213), 1,
      anon_sym_SEMI,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    ACTIONS(14229), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(11817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10329), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [562872] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13927), 1,
      anon_sym_end,
    STATE(11818), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [562926] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14231), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(11819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [562964] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14233), 1,
      anon_sym_end,
    STATE(11820), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563018] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_COLON2,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14235), 1,
      anon_sym_SEMI,
    ACTIONS(14237), 1,
      sym_rel_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [563076] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14239), 1,
      anon_sym_end,
    STATE(11822), 1,
      sym_attribute,
    STATE(11824), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563130] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14243), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14241), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [563170] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14245), 1,
      anon_sym_end,
    STATE(11824), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563224] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14247), 1,
      anon_sym_end,
    STATE(11825), 1,
      sym_attribute,
    STATE(11827), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14249), 1,
      anon_sym_end,
    STATE(11826), 1,
      sym_attribute,
    STATE(11828), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14251), 1,
      anon_sym_end,
    STATE(11827), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563386] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14253), 1,
      anon_sym_end,
    STATE(11828), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563440] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14255), 1,
      anon_sym_end,
    STATE(11829), 1,
      sym_attribute,
    STATE(11830), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563494] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14257), 1,
      anon_sym_end,
    STATE(11830), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563548] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14261), 1,
      anon_sym_SEMI,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(11831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [563606] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14279), 1,
      anon_sym_end,
    STATE(11832), 1,
      sym_attribute,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563660] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14281), 1,
      anon_sym_constraint,
    ACTIONS(14284), 1,
      anon_sym_val,
    ACTIONS(14287), 1,
      anon_sym_end,
    ACTIONS(14289), 1,
      anon_sym_inherit,
    ACTIONS(14292), 1,
      anon_sym_method,
    ACTIONS(14295), 1,
      anon_sym_initializer,
    ACTIONS(14298), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(14301), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(14304), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11833), 2,
      sym_attribute,
      aux_sym_object_expression_repeat1,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563712] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13783), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563766] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(11835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9184), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [563802] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14307), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563856] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14309), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10939), 1,
      aux_sym_expression_item_repeat1,
    STATE(11837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13929), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [563896] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14311), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10943), 1,
      aux_sym_expression_item_repeat1,
    STATE(11838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13954), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [563936] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14313), 1,
      anon_sym_end,
    STATE(11839), 1,
      sym_attribute,
    STATE(11840), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [563990] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14315), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564044] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14317), 1,
      anon_sym_end,
    STATE(11841), 1,
      sym_attribute,
    STATE(11843), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564098] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14319), 1,
      anon_sym_end,
    STATE(11842), 1,
      sym_attribute,
    STATE(11844), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564152] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14321), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564206] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14323), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564260] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14325), 1,
      anon_sym_end,
    STATE(11845), 1,
      sym_attribute,
    STATE(11846), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564314] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14327), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564368] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13962), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564422] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_COLON2,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14235), 1,
      anon_sym_SEMI,
    ACTIONS(14237), 1,
      sym_rel_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(11848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [564480] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11849), 1,
      sym_attribute,
    STATE(12511), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14329), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [564522] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13916), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564576] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14331), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564630] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(11852), 1,
      sym_attribute,
    STATE(12640), 1,
      sym__attribute,
    STATE(13640), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [564684] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14333), 1,
      anon_sym_end,
    STATE(11853), 1,
      sym_attribute,
    STATE(11854), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564738] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14335), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564792] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14337), 1,
      anon_sym_end,
    STATE(11855), 1,
      sym_attribute,
    STATE(11857), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564846] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14339), 1,
      anon_sym_end,
    STATE(11856), 1,
      sym_attribute,
    STATE(11858), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564900] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14341), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [564954] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14343), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565008] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14345), 1,
      anon_sym_end,
    STATE(11859), 1,
      sym_attribute,
    STATE(11860), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565062] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14347), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565116] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14349), 1,
      anon_sym_RPAREN,
    ACTIONS(14351), 1,
      anon_sym_val,
    STATE(9156), 1,
      sym_module_path,
    STATE(11861), 1,
      sym_attribute,
    STATE(13742), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [565170] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14092), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565224] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14353), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14355), 1,
      anon_sym_end,
    STATE(11864), 1,
      sym_attribute,
    STATE(11866), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565332] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14357), 1,
      anon_sym_COLON2,
    STATE(11865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9184), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [565368] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14359), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565422] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14361), 1,
      anon_sym_end,
    STATE(11867), 1,
      sym_attribute,
    STATE(11869), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565476] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14363), 1,
      anon_sym_end,
    STATE(11868), 1,
      sym_attribute,
    STATE(11870), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565530] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14365), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565584] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14367), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565638] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14369), 1,
      anon_sym_end,
    STATE(11871), 1,
      sym_attribute,
    STATE(11872), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565692] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14371), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565746] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14151), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565800] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14117), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565854] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14373), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565908] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14375), 1,
      anon_sym_end,
    STATE(11876), 1,
      sym_attribute,
    STATE(11877), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [565962] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14377), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566016] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14379), 1,
      anon_sym_end,
    STATE(11878), 1,
      sym_attribute,
    STATE(11880), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566070] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14381), 1,
      anon_sym_end,
    STATE(11879), 1,
      sym_attribute,
    STATE(11881), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566124] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14383), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566178] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14385), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566232] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14387), 1,
      anon_sym_end,
    STATE(11882), 1,
      sym_attribute,
    STATE(11883), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566286] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14389), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566340] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14391), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566394] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14397), 1,
      anon_sym_and,
    ACTIONS(14399), 1,
      sym_let_and_operator,
    STATE(11885), 1,
      sym_attribute,
    STATE(11912), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14395), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [566434] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13838), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566488] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14401), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566542] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14403), 1,
      anon_sym_end,
    STATE(11888), 1,
      sym_attribute,
    STATE(11889), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566596] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14405), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566650] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14407), 1,
      anon_sym_end,
    STATE(11890), 1,
      sym_attribute,
    STATE(11892), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566704] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14409), 1,
      anon_sym_end,
    STATE(11891), 1,
      sym_attribute,
    STATE(11893), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566758] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14411), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566812] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14413), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566866] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14415), 1,
      anon_sym_end,
    STATE(11894), 1,
      sym_attribute,
    STATE(11895), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566920] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14417), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [566974] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14419), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567028] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14060), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567082] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14421), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567136] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14423), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567190] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14425), 1,
      anon_sym_end,
    STATE(11900), 1,
      sym_attribute,
    STATE(11901), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567244] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14427), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567298] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14429), 1,
      anon_sym_end,
    STATE(11902), 1,
      sym_attribute,
    STATE(11904), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567352] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14431), 1,
      anon_sym_end,
    STATE(11903), 1,
      sym_attribute,
    STATE(11905), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567406] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14433), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567460] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14435), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567514] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14437), 1,
      anon_sym_end,
    STATE(11906), 1,
      sym_attribute,
    STATE(11907), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567568] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14439), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567622] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14441), 1,
      anon_sym_end,
    STATE(11908), 1,
      sym_attribute,
    STATE(12039), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567676] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14135), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567730] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14397), 1,
      anon_sym_and,
    ACTIONS(14399), 1,
      sym_let_and_operator,
    STATE(11910), 1,
      sym_attribute,
    STATE(11912), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14445), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [567770] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14447), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567824] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14453), 1,
      anon_sym_and,
    ACTIONS(14456), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14451), 2,
      anon_sym_let,
      anon_sym_in,
    STATE(11912), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14449), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [567862] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14459), 1,
      anon_sym_end,
    STATE(11913), 1,
      sym_attribute,
    STATE(11915), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [567916] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14397), 1,
      anon_sym_and,
    ACTIONS(14399), 1,
      sym_let_and_operator,
    STATE(11914), 1,
      sym_attribute,
    STATE(11943), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14445), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [567956] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14461), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568010] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14463), 1,
      anon_sym_end,
    STATE(11916), 1,
      sym_attribute,
    STATE(11918), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568064] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14465), 1,
      anon_sym_end,
    STATE(11917), 1,
      sym_attribute,
    STATE(11919), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568118] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14467), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568172] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14469), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568226] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14471), 1,
      anon_sym_end,
    STATE(11920), 1,
      sym_attribute,
    STATE(11921), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568280] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14473), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568334] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13790), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568388] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14475), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568442] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14477), 1,
      anon_sym_end,
    STATE(11924), 1,
      sym_attribute,
    STATE(11946), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568496] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14479), 1,
      anon_sym_end,
    STATE(11925), 1,
      sym_attribute,
    STATE(11926), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568550] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14481), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568604] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14483), 1,
      anon_sym_end,
    STATE(11927), 1,
      sym_attribute,
    STATE(11929), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568658] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14485), 1,
      anon_sym_end,
    STATE(11928), 1,
      sym_attribute,
    STATE(11930), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568712] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14487), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568766] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14489), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568820] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14491), 1,
      anon_sym_end,
    STATE(11931), 1,
      sym_attribute,
    STATE(11932), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568874] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14493), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568928] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13900), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [568982] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14495), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569036] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14497), 1,
      anon_sym_end,
    STATE(11935), 1,
      sym_attribute,
    STATE(11936), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569090] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14499), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569144] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14501), 1,
      anon_sym_end,
    STATE(11937), 1,
      sym_attribute,
    STATE(11939), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569198] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14503), 1,
      anon_sym_end,
    STATE(11938), 1,
      sym_attribute,
    STATE(11940), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569252] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14505), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569306] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14507), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569360] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14509), 1,
      anon_sym_end,
    STATE(11941), 1,
      sym_attribute,
    STATE(11942), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569414] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14511), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569468] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14397), 1,
      anon_sym_and,
    ACTIONS(14399), 1,
      sym_let_and_operator,
    STATE(11912), 1,
      aux_sym_value_definition_repeat1,
    STATE(11943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14515), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14513), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [569508] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14009), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569562] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14517), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569616] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14519), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569670] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14521), 1,
      anon_sym_end,
    STATE(11947), 1,
      sym_attribute,
    STATE(11958), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569724] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14523), 1,
      anon_sym_end,
    STATE(11948), 1,
      sym_attribute,
    STATE(11959), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569778] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14525), 1,
      anon_sym_end,
    STATE(11949), 1,
      sym_attribute,
    STATE(11950), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569832] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14527), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569886] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14529), 1,
      anon_sym_end,
    STATE(11951), 1,
      sym_attribute,
    STATE(11953), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569940] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14531), 1,
      anon_sym_end,
    STATE(11952), 1,
      sym_attribute,
    STATE(11954), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [569994] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14533), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570048] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14535), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570102] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14537), 1,
      anon_sym_end,
    STATE(11955), 1,
      sym_attribute,
    STATE(11956), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570156] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14539), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570210] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13749), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570264] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14541), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570318] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14543), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570372] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14545), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570426] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14547), 1,
      anon_sym_end,
    STATE(11961), 1,
      sym_attribute,
    STATE(11963), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570480] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14549), 1,
      anon_sym_end,
    STATE(11962), 1,
      sym_attribute,
    STATE(11964), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570534] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14551), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570588] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14553), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570642] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14555), 1,
      anon_sym_end,
    STATE(11965), 1,
      sym_attribute,
    STATE(11967), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570696] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14557), 1,
      anon_sym_end,
    STATE(11966), 1,
      sym_attribute,
    STATE(11968), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570750] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14559), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570804] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14561), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570858] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14563), 1,
      anon_sym_end,
    STATE(11969), 1,
      sym_attribute,
    STATE(11970), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570912] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14565), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [570966] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14567), 1,
      anon_sym_PIPE,
    STATE(11971), 1,
      sym_attribute,
    STATE(12348), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571004] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14567), 1,
      anon_sym_PIPE,
    STATE(11972), 1,
      sym_attribute,
    STATE(12350), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571042] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14139), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571096] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14569), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571150] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14571), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11089), 1,
      aux_sym_expression_item_repeat1,
    STATE(11975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13993), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571190] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14573), 1,
      anon_sym_end,
    STATE(11976), 1,
      sym_attribute,
    STATE(11977), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571244] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14575), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571298] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14577), 1,
      anon_sym_end,
    STATE(11978), 1,
      sym_attribute,
    STATE(11980), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571352] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14579), 1,
      anon_sym_end,
    STATE(11979), 1,
      sym_attribute,
    STATE(11981), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571406] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14581), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571460] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14583), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571514] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14585), 1,
      anon_sym_end,
    STATE(11982), 1,
      sym_attribute,
    STATE(11983), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571568] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14587), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571622] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14589), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11097), 1,
      aux_sym_expression_item_repeat1,
    STATE(11984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14062), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571662] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11396), 1,
      aux_sym_expression_item_repeat1,
    STATE(11985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14591), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14074), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [571702] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13860), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571756] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14593), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571810] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14595), 1,
      anon_sym_end,
    STATE(11988), 1,
      sym_attribute,
    STATE(11989), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571864] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14597), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571918] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14599), 1,
      anon_sym_end,
    STATE(11990), 1,
      sym_attribute,
    STATE(11992), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [571972] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14601), 1,
      anon_sym_end,
    STATE(11991), 1,
      sym_attribute,
    STATE(11993), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572026] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14603), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572080] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14605), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572134] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14607), 1,
      anon_sym_end,
    STATE(11994), 1,
      sym_attribute,
    STATE(11995), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572188] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14609), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572242] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(11996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 8,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [572278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13870), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14611), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(11998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572386] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14613), 1,
      anon_sym_end,
    STATE(11999), 1,
      sym_attribute,
    STATE(12000), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572440] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14615), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572494] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14617), 1,
      anon_sym_end,
    STATE(12001), 1,
      sym_attribute,
    STATE(12003), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572548] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14619), 1,
      anon_sym_end,
    STATE(12002), 1,
      sym_attribute,
    STATE(12004), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572602] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14621), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572656] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14623), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572710] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14625), 1,
      anon_sym_end,
    STATE(12005), 1,
      sym_attribute,
    STATE(12006), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572764] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14627), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572818] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13824), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572872] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14629), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572926] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14631), 1,
      anon_sym_end,
    STATE(12009), 1,
      sym_attribute,
    STATE(12010), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [572980] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14633), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573034] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14635), 1,
      anon_sym_end,
    STATE(12011), 1,
      sym_attribute,
    STATE(12013), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573088] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14637), 1,
      anon_sym_end,
    STATE(12012), 1,
      sym_attribute,
    STATE(12014), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573142] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14639), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573196] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14641), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573250] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14643), 1,
      anon_sym_end,
    STATE(12015), 1,
      sym_attribute,
    STATE(12016), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573304] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14645), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573358] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14131), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573412] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14649), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14647), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [573452] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14651), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573506] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14653), 1,
      anon_sym_end,
    STATE(12020), 1,
      sym_attribute,
    STATE(12021), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573560] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14655), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573614] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14657), 1,
      anon_sym_end,
    STATE(12022), 1,
      sym_attribute,
    STATE(12024), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573668] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14659), 1,
      anon_sym_end,
    STATE(12023), 1,
      sym_attribute,
    STATE(12025), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573722] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14661), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573776] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14663), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573830] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14665), 1,
      anon_sym_end,
    STATE(12026), 1,
      sym_attribute,
    STATE(12027), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573884] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14667), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573938] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13812), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [573992] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14669), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574046] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11301), 1,
      aux_sym_expression_item_repeat1,
    STATE(12030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14125), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [574088] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14671), 1,
      anon_sym_end,
    STATE(12031), 1,
      sym_attribute,
    STATE(12032), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574142] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14673), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574196] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14675), 1,
      anon_sym_end,
    STATE(12033), 1,
      sym_attribute,
    STATE(12035), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574250] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14677), 1,
      anon_sym_end,
    STATE(12034), 1,
      sym_attribute,
    STATE(12036), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574304] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14679), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574358] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14681), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574412] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14683), 1,
      anon_sym_end,
    STATE(12037), 1,
      sym_attribute,
    STATE(12038), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574466] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14685), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574520] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14687), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574574] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14689), 1,
      anon_sym_RPAREN,
    ACTIONS(14691), 1,
      anon_sym_DOT,
    STATE(12040), 1,
      sym_attribute,
    STATE(20446), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(14693), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [574620] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14013), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574674] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14695), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574728] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14697), 1,
      anon_sym_end,
    STATE(12043), 1,
      sym_attribute,
    STATE(12044), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574782] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14699), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574836] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14701), 1,
      anon_sym_end,
    STATE(12045), 1,
      sym_attribute,
    STATE(12047), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574890] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14703), 1,
      anon_sym_end,
    STATE(12046), 1,
      sym_attribute,
    STATE(12048), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574944] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14705), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [574998] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14707), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575052] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14709), 1,
      anon_sym_end,
    STATE(12049), 1,
      sym_attribute,
    STATE(12050), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575106] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14711), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575160] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14019), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575214] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14713), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575268] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14715), 1,
      anon_sym_end,
    STATE(12053), 1,
      sym_attribute,
    STATE(12054), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575322] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14717), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575376] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14719), 1,
      anon_sym_end,
    STATE(12055), 1,
      sym_attribute,
    STATE(12057), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575430] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14721), 1,
      anon_sym_end,
    STATE(12056), 1,
      sym_attribute,
    STATE(12058), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575484] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14723), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575538] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14725), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575592] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14727), 1,
      anon_sym_end,
    STATE(12059), 1,
      sym_attribute,
    STATE(12060), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575646] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14729), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575700] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13890), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575754] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14731), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575808] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14733), 1,
      anon_sym_end,
    STATE(12063), 1,
      sym_attribute,
    STATE(12064), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575862] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14735), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575916] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14737), 1,
      anon_sym_end,
    STATE(12065), 1,
      sym_attribute,
    STATE(12067), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [575970] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14739), 1,
      anon_sym_end,
    STATE(12066), 1,
      sym_attribute,
    STATE(12068), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576024] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14741), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576078] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14743), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576132] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14745), 1,
      anon_sym_end,
    STATE(12069), 1,
      sym_attribute,
    STATE(12070), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576186] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14747), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576240] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13912), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576294] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14749), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576348] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14751), 1,
      anon_sym_end,
    STATE(12073), 1,
      sym_attribute,
    STATE(12074), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576402] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14753), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576456] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14755), 1,
      anon_sym_end,
    STATE(12075), 1,
      sym_attribute,
    STATE(12077), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576510] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14757), 1,
      anon_sym_end,
    STATE(12076), 1,
      sym_attribute,
    STATE(12078), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576564] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14759), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576618] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14761), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576672] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14763), 1,
      anon_sym_end,
    STATE(12079), 1,
      sym_attribute,
    STATE(12080), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576726] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14765), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576780] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14767), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11176), 1,
      aux_sym_expression_item_repeat1,
    STATE(12081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14080), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [576820] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13904), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576874] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14769), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576928] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14771), 1,
      anon_sym_end,
    STATE(12084), 1,
      sym_attribute,
    STATE(12085), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [576982] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14773), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577036] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14775), 1,
      anon_sym_end,
    STATE(12086), 1,
      sym_attribute,
    STATE(12088), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577090] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14777), 1,
      anon_sym_end,
    STATE(12087), 1,
      sym_attribute,
    STATE(12089), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577144] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14779), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577198] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14781), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577252] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14783), 1,
      anon_sym_end,
    STATE(12090), 1,
      sym_attribute,
    STATE(12091), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577306] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14785), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577360] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14155), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577414] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14787), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577468] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14789), 1,
      anon_sym_end,
    STATE(12094), 1,
      sym_attribute,
    STATE(12095), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577522] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14791), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577576] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14793), 1,
      anon_sym_end,
    STATE(12096), 1,
      sym_attribute,
    STATE(12098), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577630] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14795), 1,
      anon_sym_end,
    STATE(12097), 1,
      sym_attribute,
    STATE(12099), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577684] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14797), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577738] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14799), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577792] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14801), 1,
      anon_sym_end,
    STATE(12100), 1,
      sym_attribute,
    STATE(12101), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577846] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14803), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577900] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14088), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [577954] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14805), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578008] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14807), 1,
      anon_sym_end,
    STATE(12104), 1,
      sym_attribute,
    STATE(12105), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578062] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14809), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578116] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14811), 1,
      anon_sym_end,
    STATE(12106), 1,
      sym_attribute,
    STATE(12108), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578170] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14813), 1,
      anon_sym_end,
    STATE(12107), 1,
      sym_attribute,
    STATE(12109), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578224] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14815), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14817), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14819), 1,
      anon_sym_end,
    STATE(12110), 1,
      sym_attribute,
    STATE(12111), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578386] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14821), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578440] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14825), 1,
      anon_sym_let,
    STATE(12112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14823), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [578474] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13874), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578528] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14213), 1,
      anon_sym_SEMI,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    ACTIONS(14229), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9052), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(9050), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [578586] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14213), 1,
      anon_sym_SEMI,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    ACTIONS(14229), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9032), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(9030), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [578644] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14827), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578698] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14829), 1,
      anon_sym_end,
    STATE(12117), 1,
      sym_attribute,
    STATE(12118), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578752] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14831), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578806] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14833), 1,
      anon_sym_end,
    STATE(12119), 1,
      sym_attribute,
    STATE(12121), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578860] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14835), 1,
      anon_sym_end,
    STATE(12120), 1,
      sym_attribute,
    STATE(12122), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578914] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14837), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [578968] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14839), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579022] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14841), 1,
      anon_sym_end,
    STATE(12123), 1,
      sym_attribute,
    STATE(12124), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579076] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14843), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579130] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13804), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579184] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14845), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579238] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14847), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11196), 1,
      aux_sym_expression_item_repeat1,
    STATE(12127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13935), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [579278] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14849), 1,
      anon_sym_end,
    STATE(12128), 1,
      sym_attribute,
    STATE(12129), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579332] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14851), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579386] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14853), 1,
      anon_sym_end,
    STATE(12130), 1,
      sym_attribute,
    STATE(12132), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579440] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14855), 1,
      anon_sym_end,
    STATE(12131), 1,
      sym_attribute,
    STATE(12133), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579494] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14857), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579548] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14859), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579602] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14861), 1,
      anon_sym_end,
    STATE(12134), 1,
      sym_attribute,
    STATE(12135), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579656] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14863), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579710] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13794), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579764] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14865), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579818] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14867), 1,
      anon_sym_RPAREN,
    ACTIONS(14869), 1,
      anon_sym_val,
    STATE(9156), 1,
      sym_module_path,
    STATE(12138), 1,
      sym_attribute,
    STATE(13774), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [579872] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14871), 1,
      anon_sym_end,
    STATE(12139), 1,
      sym_attribute,
    STATE(12140), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579926] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14873), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [579980] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14875), 1,
      anon_sym_end,
    STATE(12141), 1,
      sym_attribute,
    STATE(12143), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580034] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14877), 1,
      anon_sym_end,
    STATE(12142), 1,
      sym_attribute,
    STATE(12144), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580088] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14879), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580142] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14881), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580196] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14883), 1,
      anon_sym_end,
    STATE(12145), 1,
      sym_attribute,
    STATE(12146), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580250] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14885), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580304] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14070), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580358] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14887), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580412] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14889), 1,
      anon_sym_end,
    STATE(12149), 1,
      sym_attribute,
    STATE(12150), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580466] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14891), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580520] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14893), 1,
      anon_sym_end,
    STATE(12151), 1,
      sym_attribute,
    STATE(12153), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580574] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14895), 1,
      anon_sym_end,
    STATE(12152), 1,
      sym_attribute,
    STATE(12154), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580628] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14897), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580682] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14899), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580736] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14901), 1,
      anon_sym_end,
    STATE(12155), 1,
      sym_attribute,
    STATE(12156), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580790] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14903), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580844] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13983), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580898] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13908), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [580952] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14905), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581006] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14567), 1,
      anon_sym_PIPE,
    STATE(11972), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12259), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [581044] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14907), 1,
      anon_sym_end,
    STATE(12161), 1,
      sym_attribute,
    STATE(12162), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581098] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14909), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581152] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14911), 1,
      anon_sym_end,
    STATE(12163), 1,
      sym_attribute,
    STATE(12165), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581206] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14913), 1,
      anon_sym_end,
    STATE(12164), 1,
      sym_attribute,
    STATE(12166), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581260] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14915), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581314] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14917), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581368] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14919), 1,
      anon_sym_end,
    STATE(12167), 1,
      sym_attribute,
    STATE(12168), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581422] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14921), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581476] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13950), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581530] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14923), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581584] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14925), 1,
      anon_sym_end,
    STATE(12171), 1,
      sym_attribute,
    STATE(12172), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581638] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14927), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581692] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14929), 1,
      anon_sym_end,
    STATE(12173), 1,
      sym_attribute,
    STATE(12175), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581746] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14931), 1,
      anon_sym_end,
    STATE(12174), 1,
      sym_attribute,
    STATE(12176), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581800] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14933), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581854] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14935), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581908] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14937), 1,
      anon_sym_end,
    STATE(12177), 1,
      sym_attribute,
    STATE(12178), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [581962] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14939), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582016] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13896), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582070] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14941), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582124] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14943), 1,
      anon_sym_end,
    STATE(12181), 1,
      sym_attribute,
    STATE(12182), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582178] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14945), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582232] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14947), 1,
      anon_sym_end,
    STATE(12183), 1,
      sym_attribute,
    STATE(12185), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582286] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14949), 1,
      anon_sym_end,
    STATE(12184), 1,
      sym_attribute,
    STATE(12186), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582340] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14951), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582394] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14953), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582448] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14955), 1,
      anon_sym_end,
    STATE(12187), 1,
      sym_attribute,
    STATE(12188), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582502] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14957), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582556] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14113), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582610] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14959), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582664] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14961), 1,
      anon_sym_end,
    STATE(12191), 1,
      sym_attribute,
    STATE(12193), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582718] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14963), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582772] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14965), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582826] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14967), 1,
      anon_sym_end,
    STATE(12194), 1,
      sym_attribute,
    STATE(12196), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582880] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14969), 1,
      anon_sym_end,
    STATE(12195), 1,
      sym_attribute,
    STATE(12197), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582934] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14971), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [582988] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14973), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583042] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14975), 1,
      anon_sym_end,
    STATE(12198), 1,
      sym_attribute,
    STATE(12199), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583096] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14977), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583150] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13761), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583204] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14979), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583258] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14981), 1,
      anon_sym_end,
    STATE(12202), 1,
      sym_attribute,
    STATE(12203), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583312] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14983), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583366] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14985), 1,
      anon_sym_end,
    STATE(12204), 1,
      sym_attribute,
    STATE(12413), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583420] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14987), 1,
      anon_sym_end,
    STATE(12205), 1,
      sym_attribute,
    STATE(12207), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583474] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13946), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583528] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14989), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583582] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14991), 1,
      anon_sym_end,
    STATE(12208), 1,
      sym_attribute,
    STATE(12209), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583636] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14993), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583690] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13842), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583744] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14995), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583798] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14997), 1,
      anon_sym_end,
    STATE(12212), 1,
      sym_attribute,
    STATE(12213), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583852] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14999), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583906] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15001), 1,
      anon_sym_end,
    STATE(12214), 1,
      sym_attribute,
    STATE(12216), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [583960] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15003), 1,
      anon_sym_end,
    STATE(12215), 1,
      sym_attribute,
    STATE(12217), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584014] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15005), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584068] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15007), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584122] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15009), 1,
      anon_sym_end,
    STATE(12218), 1,
      sym_attribute,
    STATE(12219), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584176] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15011), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584230] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_COLON2,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14235), 1,
      anon_sym_SEMI,
    ACTIONS(14237), 1,
      sym_rel_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [584288] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13024), 1,
      anon_sym_EQ,
    ACTIONS(15013), 1,
      anon_sym_of,
    ACTIONS(15015), 1,
      anon_sym_COLON2,
    STATE(12221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13022), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13020), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584328] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      anon_sym_EQ,
    ACTIONS(15017), 1,
      anon_sym_of,
    ACTIONS(15019), 1,
      anon_sym_COLON2,
    STATE(12222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13066), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584368] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13180), 1,
      anon_sym_EQ,
    ACTIONS(15021), 1,
      anon_sym_of,
    ACTIONS(15023), 1,
      anon_sym_COLON2,
    STATE(12223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584408] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14397), 1,
      anon_sym_and,
    ACTIONS(14399), 1,
      sym_let_and_operator,
    STATE(11885), 1,
      aux_sym_value_definition_repeat1,
    STATE(12224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14163), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14161), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584448] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15025), 1,
      anon_sym_end,
    STATE(12225), 1,
      sym_attribute,
    STATE(12230), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584502] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12226), 1,
      sym_attribute,
    STATE(12631), 1,
      sym__attribute,
    STATE(13831), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [584556] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12397), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15027), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12227), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [584594] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14397), 1,
      anon_sym_and,
    ACTIONS(14399), 1,
      sym_let_and_operator,
    STATE(11910), 1,
      aux_sym_value_definition_repeat1,
    STATE(12228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14395), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584634] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15032), 1,
      anon_sym_let,
    STATE(12229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15030), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [584668] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15034), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584722] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15036), 1,
      anon_sym_end,
    STATE(12231), 1,
      sym_attribute,
    STATE(12233), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584776] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15038), 1,
      anon_sym_end,
    STATE(12232), 1,
      sym_attribute,
    STATE(12234), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584830] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15040), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584884] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15042), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584938] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15044), 1,
      anon_sym_end,
    STATE(12235), 1,
      sym_attribute,
    STATE(12236), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [584992] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15046), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [585046] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [585100] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585144] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14217), 1,
      sym_pow_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585182] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14217), 1,
      sym_pow_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585220] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585266] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10235), 4,
      anon_sym_and,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585312] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_and,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [585362] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [585414] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    ACTIONS(14229), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [585470] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585510] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    ACTIONS(14229), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10263), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [585566] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    ACTIONS(14215), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14217), 1,
      sym_pow_operator,
    ACTIONS(14219), 1,
      sym_mult_operator,
    ACTIONS(14221), 1,
      sym_concat_operator,
    ACTIONS(14223), 1,
      sym_rel_operator,
    ACTIONS(14225), 1,
      sym_and_operator,
    ACTIONS(14227), 1,
      sym_or_operator,
    ACTIONS(14229), 1,
      sym_assign_operator,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10273), 2,
      anon_sym_and,
      anon_sym_PIPE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [585622] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14165), 1,
      anon_sym_and,
    ACTIONS(14167), 1,
      sym_let_and_operator,
    STATE(12249), 1,
      sym_attribute,
    STATE(12252), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14445), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585662] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12250), 1,
      sym_attribute,
    STATE(12415), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15048), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [585704] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14451), 3,
      anon_sym_let,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(14449), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      sym_let_and_operator,
      aux_sym_directive_token1,
  [585738] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15050), 1,
      anon_sym_and,
    ACTIONS(15053), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14451), 2,
      anon_sym_let,
      anon_sym_in,
    STATE(12252), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14449), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585776] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14231), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(12253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [585814] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12254), 1,
      sym_attribute,
    STATE(12710), 1,
      sym__attribute,
    STATE(13809), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585868] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9331), 1,
      sym__module_expression,
    STATE(12255), 1,
      sym_attribute,
    STATE(12674), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [585922] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14165), 1,
      anon_sym_and,
    ACTIONS(14167), 1,
      sym_let_and_operator,
    STATE(12256), 1,
      sym_attribute,
    STATE(12404), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14445), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [585962] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11479), 1,
      aux_sym_expression_item_repeat1,
    STATE(12257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15056), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14105), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [586002] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 6,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [586056] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586100] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14265), 1,
      sym_pow_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586138] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14265), 1,
      sym_pow_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586176] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586222] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586268] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_and,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [586318] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_and,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [586370] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [586426] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586466] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [586522] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15058), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(12269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586560] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [586616] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12271), 1,
      sym_attribute,
    STATE(12740), 1,
      sym__attribute,
    STATE(13925), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [586670] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14143), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [586724] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [586780] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    STATE(12274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 10,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586816] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586852] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15058), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(12276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [586890] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13024), 1,
      anon_sym_EQ,
    ACTIONS(15060), 1,
      anon_sym_of,
    ACTIONS(15062), 1,
      anon_sym_COLON2,
    STATE(12277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13022), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13020), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586930] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13070), 1,
      anon_sym_EQ,
    ACTIONS(15064), 1,
      anon_sym_of,
    ACTIONS(15066), 1,
      anon_sym_COLON2,
    STATE(12278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13068), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13066), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [586970] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13180), 1,
      anon_sym_EQ,
    ACTIONS(15068), 1,
      anon_sym_of,
    ACTIONS(15070), 1,
      anon_sym_COLON2,
    STATE(12279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13178), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13176), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [587010] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12280), 1,
      sym_attribute,
    STATE(12760), 1,
      sym__attribute,
    STATE(13711), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [587064] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15072), 1,
      anon_sym_PIPE,
    STATE(12281), 1,
      sym_attribute,
    STATE(12283), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [587102] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15072), 1,
      anon_sym_PIPE,
    STATE(12282), 1,
      sym_attribute,
    STATE(12284), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [587140] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15072), 1,
      anon_sym_PIPE,
    STATE(12283), 1,
      sym_attribute,
    STATE(12285), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [587178] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15072), 1,
      anon_sym_PIPE,
    STATE(12284), 1,
      sym_attribute,
    STATE(12285), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [587216] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15074), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12285), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [587252] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15077), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587306] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12409), 1,
      anon_sym_STAR,
    ACTIONS(13674), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12287), 1,
      sym_attribute,
    STATE(12288), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [587344] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12213), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15079), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12288), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [587380] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12289), 1,
      sym_attribute,
    STATE(12772), 1,
      sym__attribute,
    STATE(13760), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [587434] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15082), 1,
      anon_sym_end,
    STATE(12290), 1,
      sym_attribute,
    STATE(12293), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587488] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12291), 1,
      sym_attribute,
    STATE(12779), 1,
      sym__attribute,
    STATE(13865), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [587542] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12292), 1,
      sym_attribute,
    STATE(12781), 1,
      sym__attribute,
    STATE(13777), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [587596] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15084), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587650] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15086), 1,
      anon_sym_end,
    STATE(12294), 1,
      sym_attribute,
    STATE(12296), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587704] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15088), 1,
      anon_sym_end,
    STATE(12295), 1,
      sym_attribute,
    STATE(12297), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587758] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15090), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587812] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15092), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587866] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15094), 1,
      anon_sym_end,
    STATE(12298), 1,
      sym_attribute,
    STATE(12301), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [587920] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12299), 1,
      sym_attribute,
    STATE(12789), 1,
      sym__attribute,
    STATE(13797), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [587974] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15098), 1,
      anon_sym_let,
    STATE(12300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15096), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [588008] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15100), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [588062] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12451), 1,
      anon_sym_STAR,
    ACTIONS(13674), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12302), 1,
      sym_attribute,
    STATE(12304), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588100] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12303), 1,
      sym_attribute,
    STATE(12799), 1,
      sym__attribute,
    STATE(13862), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588154] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12213), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15102), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12304), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588190] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2305), 1,
      sym_add_operator,
    STATE(12305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [588226] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12306), 1,
      sym_attribute,
    STATE(12810), 1,
      sym__attribute,
    STATE(13739), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588280] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12307), 1,
      sym_attribute,
    STATE(12818), 1,
      sym__attribute,
    STATE(13789), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588334] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15105), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11115), 1,
      aux_sym_expression_item_repeat1,
    STATE(12308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13796), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588374] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15109), 1,
      anon_sym_let,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15107), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [588414] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15111), 1,
      anon_sym_end,
    STATE(11804), 1,
      aux_sym_object_expression_repeat1,
    STATE(12310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [588468] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13598), 1,
      anon_sym_EQ,
    ACTIONS(15113), 1,
      anon_sym_of,
    ACTIONS(15115), 1,
      anon_sym_COLON2,
    STATE(12311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588508] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13604), 1,
      anon_sym_EQ,
    ACTIONS(15117), 1,
      anon_sym_of,
    ACTIONS(15119), 1,
      anon_sym_COLON2,
    STATE(12312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588548] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13622), 1,
      anon_sym_EQ,
    ACTIONS(15121), 1,
      anon_sym_of,
    ACTIONS(15123), 1,
      anon_sym_COLON2,
    STATE(12313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [588588] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12314), 1,
      sym_attribute,
    STATE(12820), 1,
      sym__attribute,
    STATE(13736), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588642] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12315), 1,
      sym_attribute,
    STATE(12822), 1,
      sym__attribute,
    STATE(13749), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588696] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12316), 1,
      sym_attribute,
    STATE(12823), 1,
      sym__attribute,
    STATE(13834), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588750] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14101), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [588804] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12318), 1,
      sym_attribute,
    STATE(12825), 1,
      sym__attribute,
    STATE(13718), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588858] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12319), 1,
      sym_attribute,
    STATE(12827), 1,
      sym__attribute,
    STATE(13816), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588912] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12320), 1,
      sym_attribute,
    STATE(12833), 1,
      sym__attribute,
    STATE(13897), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [588966] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15125), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589020] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12322), 1,
      sym_attribute,
    STATE(12840), 1,
      sym__attribute,
    STATE(13705), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589074] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12323), 1,
      sym_attribute,
    STATE(12842), 1,
      sym__attribute,
    STATE(13909), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589128] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12324), 1,
      sym_attribute,
    STATE(12843), 1,
      sym__attribute,
    STATE(13830), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589182] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15127), 1,
      anon_sym_end,
    STATE(12325), 1,
      sym_attribute,
    STATE(12328), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589236] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12326), 1,
      sym_attribute,
    STATE(12845), 1,
      sym__attribute,
    STATE(13838), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589290] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12327), 1,
      sym_attribute,
    STATE(12846), 1,
      sym__attribute,
    STATE(13904), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589344] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15129), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589398] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15131), 1,
      anon_sym_end,
    STATE(12329), 1,
      sym_attribute,
    STATE(12332), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589452] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15133), 1,
      anon_sym_end,
    STATE(12330), 1,
      sym_attribute,
    STATE(12333), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589506] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12331), 1,
      sym_attribute,
    STATE(12847), 1,
      sym__attribute,
    STATE(13913), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589560] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15135), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589614] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15137), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589668] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15139), 1,
      anon_sym_end,
    STATE(12334), 1,
      sym_attribute,
    STATE(12336), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589722] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12335), 1,
      sym_attribute,
    STATE(12848), 1,
      sym__attribute,
    STATE(13875), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589776] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15141), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [589830] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12337), 1,
      sym_attribute,
    STATE(12849), 1,
      sym__attribute,
    STATE(13751), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589884] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12338), 1,
      sym_attribute,
    STATE(12850), 1,
      sym__attribute,
    STATE(13832), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589938] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12339), 1,
      sym_attribute,
    STATE(12854), 1,
      sym__attribute,
    STATE(13891), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [589992] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12340), 1,
      sym_attribute,
    STATE(12856), 1,
      sym__attribute,
    STATE(13694), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590046] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15143), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(12341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13880), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [590086] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12342), 1,
      sym_attribute,
    STATE(12858), 1,
      sym__attribute,
    STATE(13752), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590140] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12343), 1,
      sym_attribute,
    STATE(12859), 1,
      sym__attribute,
    STATE(13800), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590194] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12344), 1,
      sym_attribute,
    STATE(12860), 1,
      sym__attribute,
    STATE(13889), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590248] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12345), 1,
      sym_attribute,
    STATE(12861), 1,
      sym__attribute,
    STATE(13902), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590302] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12346), 1,
      sym_attribute,
    STATE(12863), 1,
      sym__attribute,
    STATE(13903), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590356] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12347), 1,
      sym_attribute,
    STATE(12865), 1,
      sym__attribute,
    STATE(13698), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590410] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13976), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14567), 1,
      anon_sym_PIPE,
    STATE(12348), 1,
      sym_attribute,
    STATE(12350), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13974), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [590448] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12349), 1,
      sym_attribute,
    STATE(12866), 1,
      sym__attribute,
    STATE(13812), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590502] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12760), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15145), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12350), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [590538] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12351), 1,
      sym_attribute,
    STATE(12867), 1,
      sym__attribute,
    STATE(13863), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590592] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12279), 1,
      anon_sym_DASH_GT,
    STATE(12352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 17,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [590628] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(9519), 1,
      sym__module_expression,
    STATE(12353), 1,
      sym_attribute,
    STATE(12579), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590682] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(13808), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [590736] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12355), 1,
      sym_attribute,
    STATE(12868), 1,
      sym__attribute,
    STATE(13776), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590790] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12356), 1,
      sym_attribute,
    STATE(12869), 1,
      sym__attribute,
    STATE(13704), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590844] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12357), 1,
      sym_attribute,
    STATE(12870), 1,
      sym__attribute,
    STATE(13727), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590898] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12358), 1,
      sym_attribute,
    STATE(12871), 1,
      sym__attribute,
    STATE(13753), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [590952] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12359), 1,
      sym_attribute,
    STATE(12872), 1,
      sym__attribute,
    STATE(13815), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [591006] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15148), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591060] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9310), 1,
      sym__module_expression,
    STATE(12361), 1,
      sym_attribute,
    STATE(12622), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [591114] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15150), 1,
      anon_sym_end,
    STATE(12362), 1,
      sym_attribute,
    STATE(12366), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591168] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15152), 1,
      anon_sym_PIPE,
    STATE(12363), 1,
      sym_attribute,
    STATE(12365), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591206] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15152), 1,
      anon_sym_PIPE,
    STATE(12364), 1,
      sym_attribute,
    STATE(12365), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13976), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13974), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591244] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15154), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12760), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(12365), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591280] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15157), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591334] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15159), 1,
      anon_sym_end,
    STATE(12367), 1,
      sym_attribute,
    STATE(12371), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591388] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15161), 1,
      anon_sym_end,
    STATE(12368), 1,
      sym_attribute,
    STATE(12372), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591442] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15152), 1,
      anon_sym_PIPE,
    STATE(12363), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12259), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591480] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15152), 1,
      anon_sym_PIPE,
    STATE(12364), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591518] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15163), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591572] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15165), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591626] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15167), 1,
      anon_sym_end,
    STATE(12373), 1,
      sym_attribute,
    STATE(12374), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591680] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15169), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [591734] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15171), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11245), 1,
      aux_sym_expression_item_repeat1,
    STATE(12375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13741), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [591774] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15175), 1,
      anon_sym_let,
    STATE(12376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15173), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591808] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13818), 1,
      anon_sym_DASH_GT,
    ACTIONS(13820), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11532), 1,
      aux_sym_expression_item_repeat1,
    STATE(12377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13999), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [591850] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(12378), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11447), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11449), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [591894] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(12379), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11475), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11477), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [591938] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14165), 1,
      anon_sym_and,
    ACTIONS(14167), 1,
      sym_let_and_operator,
    STATE(12249), 1,
      aux_sym_value_definition_repeat1,
    STATE(12380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14395), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [591978] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15177), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11111), 1,
      aux_sym_expression_item_repeat1,
    STATE(12381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13753), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [592018] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15181), 1,
      anon_sym_let,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12018), 1,
      aux_sym_expression_item_repeat1,
    STATE(12382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15179), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592058] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14165), 1,
      anon_sym_and,
    ACTIONS(14167), 1,
      sym_let_and_operator,
    STATE(12252), 1,
      aux_sym_value_definition_repeat1,
    STATE(12383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14395), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592098] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_PIPE,
    STATE(12384), 1,
      sym_attribute,
    STATE(12386), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592136] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_PIPE,
    STATE(12385), 1,
      sym_attribute,
    STATE(12386), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13976), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13974), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592174] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15185), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12760), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(12386), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592210] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_PIPE,
    STATE(12384), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12261), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12259), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592248] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(12388), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11612), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11614), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [592292] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15183), 1,
      anon_sym_PIPE,
    STATE(12385), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13970), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13968), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [592330] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(14023), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592384] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(12391), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12456), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12458), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [592428] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(12392), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12341), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12343), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [592472] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15188), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592526] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12788), 1,
      sym__lowercase_identifier,
    ACTIONS(12792), 1,
      anon_sym_POUND,
    STATE(11765), 1,
      sym_type_constructor_path,
    STATE(12394), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12345), 4,
      anon_sym_SEMI_SEMI,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12347), 10,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT,
  [592570] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15190), 1,
      anon_sym_end,
    STATE(12395), 1,
      sym_attribute,
    STATE(12396), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592624] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15192), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592678] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15194), 1,
      anon_sym_end,
    STATE(12397), 1,
      sym_attribute,
    STATE(12399), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592732] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15196), 1,
      anon_sym_end,
    STATE(12398), 1,
      sym_attribute,
    STATE(12400), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592786] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15198), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592840] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15200), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592894] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15202), 1,
      anon_sym_end,
    STATE(12401), 1,
      sym_attribute,
    STATE(12402), 1,
      aux_sym_object_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [592948] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15204), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [593002] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(9156), 1,
      sym_module_path,
    STATE(12403), 1,
      sym_attribute,
    STATE(12906), 1,
      sym__attribute,
    STATE(13892), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [593056] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14165), 1,
      anon_sym_and,
    ACTIONS(14167), 1,
      sym_let_and_operator,
    STATE(12252), 1,
      aux_sym_value_definition_repeat1,
    STATE(12404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14515), 2,
      anon_sym_let,
      anon_sym_in,
    ACTIONS(14513), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [593096] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13698), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(12405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13696), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593134] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13612), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(12406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13610), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593172] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13620), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(12407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13618), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593210] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13706), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(12408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13704), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593248] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14261), 1,
      anon_sym_SEMI,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9050), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [593306] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_and,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    ACTIONS(14261), 1,
      anon_sym_SEMI,
    ACTIONS(14263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14265), 1,
      sym_pow_operator,
    ACTIONS(14267), 1,
      sym_mult_operator,
    ACTIONS(14269), 1,
      sym_concat_operator,
    ACTIONS(14271), 1,
      sym_rel_operator,
    ACTIONS(14273), 1,
      sym_and_operator,
    ACTIONS(14275), 1,
      sym_or_operator,
    ACTIONS(14277), 1,
      sym_assign_operator,
    STATE(2096), 1,
      sym_add_operator,
    STATE(12410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(9030), 4,
      anon_sym_in,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [593364] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13723), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(12411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13721), 16,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_external,
      anon_sym_type,
      anon_sym_COLON_EQ,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593402] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8757), 9,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
      aux_sym_attribute_id_token1,
    ACTIONS(8755), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [593436] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(12639), 1,
      anon_sym_constraint,
    ACTIONS(12641), 1,
      anon_sym_val,
    ACTIONS(12645), 1,
      anon_sym_inherit,
    ACTIONS(12647), 1,
      anon_sym_method,
    ACTIONS(12649), 1,
      anon_sym_initializer,
    ACTIONS(15210), 1,
      anon_sym_end,
    STATE(11833), 1,
      aux_sym_object_expression_repeat1,
    STATE(12413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14066), 2,
      sym__class_field,
      sym_floating_attribute,
    STATE(14060), 7,
      sym_type_parameter_constraint,
      sym_inheritance_definition,
      sym_instance_variable_definition,
      sym_method_definition,
      sym_class_initializer,
      sym_item_extension,
      sym_quoted_item_extension,
  [593490] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10345), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
    ACTIONS(10343), 10,
      anon_sym_rec,
      anon_sym_nonrec,
      anon_sym__,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_virtual,
      anon_sym_functor,
      anon_sym_struct,
      sym__lowercase_identifier,
  [593523] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15212), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593560] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14351), 1,
      anon_sym_val,
    STATE(9156), 1,
      sym_module_path,
    STATE(12416), 1,
      sym_attribute,
    STATE(13742), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [593611] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14395), 1,
      anon_sym_let,
    ACTIONS(15214), 1,
      anon_sym_and,
    ACTIONS(15216), 1,
      sym_let_and_operator,
    STATE(12417), 1,
      sym_attribute,
    STATE(12507), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [593650] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7131), 1,
      aux_sym_number_token1,
    ACTIONS(7133), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7135), 1,
      anon_sym_SQUOTE,
    ACTIONS(7137), 1,
      anon_sym_DQUOTE,
    ACTIONS(15218), 1,
      anon_sym_LPAREN,
    ACTIONS(15222), 1,
      anon_sym_LBRACE,
    ACTIONS(15224), 1,
      anon_sym_begin,
    STATE(9254), 1,
      sym__signed_constant,
    STATE(12418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15220), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(9071), 2,
      sym__constant,
      sym_signed_number,
    STATE(9062), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [593701] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [593756] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12534), 1,
      anon_sym_STAR,
    STATE(12420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [593791] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    ACTIONS(15244), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [593848] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8290), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [593881] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11499), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11501), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [593914] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11503), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11505), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [593947] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    STATE(12425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 10,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [593982] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [594037] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11507), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11509), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11511), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11513), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594103] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4849), 1,
      aux_sym_number_token1,
    ACTIONS(4853), 1,
      anon_sym_SQUOTE,
    ACTIONS(4855), 1,
      anon_sym_DQUOTE,
    ACTIONS(7199), 1,
      aux_sym_signed_number_token1,
    ACTIONS(15246), 1,
      anon_sym_LPAREN,
    ACTIONS(15250), 1,
      anon_sym_LBRACE,
    ACTIONS(15252), 1,
      anon_sym_begin,
    STATE(12429), 1,
      sym_attribute,
    STATE(13721), 1,
      sym__signed_constant,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15248), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(13682), 2,
      sym__constant,
      sym_signed_number,
    STATE(12638), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [594154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8294), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594187] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8022), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594220] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(8298), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594253] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14515), 1,
      anon_sym_let,
    ACTIONS(15214), 1,
      anon_sym_and,
    ACTIONS(15216), 1,
      sym_let_and_operator,
    STATE(12433), 1,
      sym_attribute,
    STATE(12508), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14513), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594292] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 5,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [594345] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    ACTIONS(15254), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [594402] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15256), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(12436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594439] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    ACTIONS(15254), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [594496] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12520), 1,
      anon_sym_STAR,
    STATE(12438), 1,
      sym_attribute,
    STATE(12494), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13674), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13672), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594533] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14395), 1,
      anon_sym_let,
    ACTIONS(15214), 1,
      anon_sym_and,
    ACTIONS(15216), 1,
      sym_let_and_operator,
    STATE(12439), 1,
      sym_attribute,
    STATE(12508), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594572] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5565), 1,
      anon_sym_DOT,
    STATE(12440), 1,
      sym_attribute,
    STATE(18738), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(5571), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [594615] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12518), 1,
      anon_sym_STAR,
    STATE(12441), 1,
      sym_attribute,
    STATE(12443), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13674), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13672), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594652] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15256), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(12442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [594689] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15258), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12213), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(12443), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594724] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15261), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11115), 1,
      aux_sym_expression_item_repeat1,
    STATE(12444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13796), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [594763] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14163), 1,
      anon_sym_let,
    ACTIONS(15263), 1,
      anon_sym_and,
    ACTIONS(15265), 1,
      sym_let_and_operator,
    STATE(12445), 1,
      sym_attribute,
    STATE(12539), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14161), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [594802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11519), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11521), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594835] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11523), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11525), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594868] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11527), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11529), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594901] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11531), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11533), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [594934] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [594977] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12451), 1,
      sym_attribute,
    STATE(12516), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15267), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595014] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15269), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10874), 1,
      aux_sym_expression_item_repeat1,
    STATE(12452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13880), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595053] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15271), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11245), 1,
      aux_sym_expression_item_repeat1,
    STATE(12453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13741), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595092] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9224), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595125] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11535), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11537), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11539), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11541), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11543), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11545), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595224] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11547), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11549), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595257] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11551), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11553), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595290] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14395), 1,
      anon_sym_let,
    ACTIONS(15263), 1,
      anon_sym_and,
    ACTIONS(15265), 1,
      sym_let_and_operator,
    STATE(12460), 1,
      sym_attribute,
    STATE(12541), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [595329] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11555), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11557), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595362] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11559), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11561), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595395] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [595450] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11563), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11565), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595483] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11567), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11569), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595516] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11571), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11573), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [595549] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15291), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11196), 1,
      aux_sym_expression_item_repeat1,
    STATE(12467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13935), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595588] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15293), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11111), 1,
      aux_sym_expression_item_repeat1,
    STATE(12468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13753), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595627] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15295), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10939), 1,
      aux_sym_expression_item_repeat1,
    STATE(12469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13929), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595666] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15297), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(10943), 1,
      aux_sym_expression_item_repeat1,
    STATE(12470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13954), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595705] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15299), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11089), 1,
      aux_sym_expression_item_repeat1,
    STATE(12471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13993), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595744] = 15,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(15301), 1,
      anon_sym_LPAREN,
    ACTIONS(15303), 1,
      anon_sym_constraint,
    ACTIONS(15305), 1,
      anon_sym_val,
    ACTIONS(15307), 1,
      anon_sym_end,
    ACTIONS(15309), 1,
      anon_sym_inherit,
    ACTIONS(15311), 1,
      anon_sym_method,
    STATE(12472), 1,
      sym_attribute,
    STATE(12617), 1,
      aux_sym_class_body_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14248), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(14255), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [595797] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15313), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11097), 1,
      aux_sym_expression_item_repeat1,
    STATE(12473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14062), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595836] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15315), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11176), 1,
      aux_sym_expression_item_repeat1,
    STATE(12474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14080), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [595875] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14869), 1,
      anon_sym_val,
    STATE(9156), 1,
      sym_module_path,
    STATE(12475), 1,
      sym_attribute,
    STATE(13774), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [595926] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15317), 1,
      anon_sym_PIPE,
    STATE(12476), 1,
      sym_attribute,
    STATE(12478), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [595963] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15317), 1,
      anon_sym_PIPE,
    STATE(12477), 1,
      sym_attribute,
    STATE(12480), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596000] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15317), 1,
      anon_sym_PIPE,
    STATE(12478), 1,
      sym_attribute,
    STATE(12481), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596037] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15319), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [596074] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15317), 1,
      anon_sym_PIPE,
    STATE(12480), 1,
      sym_attribute,
    STATE(12481), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596111] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15321), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12481), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [596146] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5041), 1,
      aux_sym_number_token1,
    ACTIONS(5043), 1,
      aux_sym_signed_number_token1,
    ACTIONS(5045), 1,
      anon_sym_SQUOTE,
    ACTIONS(5047), 1,
      anon_sym_DQUOTE,
    ACTIONS(15324), 1,
      anon_sym_LPAREN,
    ACTIONS(15328), 1,
      anon_sym_LBRACE,
    ACTIONS(15330), 1,
      anon_sym_begin,
    STATE(5835), 1,
      sym__signed_constant,
    STATE(12482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15326), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5663), 2,
      sym__constant,
      sym_signed_number,
    STATE(5685), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [596197] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4693), 1,
      aux_sym_number_token1,
    ACTIONS(4695), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4697), 1,
      anon_sym_SQUOTE,
    ACTIONS(4699), 1,
      anon_sym_DQUOTE,
    ACTIONS(15332), 1,
      anon_sym_LPAREN,
    ACTIONS(15336), 1,
      anon_sym_LBRACE,
    ACTIONS(15338), 1,
      anon_sym_begin,
    STATE(5630), 1,
      sym__signed_constant,
    STATE(12483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15334), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5513), 2,
      sym__constant,
      sym_signed_number,
    STATE(5558), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [596248] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    STATE(12484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 8,
      anon_sym_and,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 9,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [596283] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11201), 1,
      anon_sym_as,
    ACTIONS(15340), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    STATE(12485), 1,
      sym_attribute,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
  [596326] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4865), 1,
      anon_sym_DOT,
    STATE(12486), 1,
      sym_attribute,
    STATE(19798), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(4871), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [596369] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11577), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [596402] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_let,
    ACTIONS(15348), 1,
      anon_sym_and,
    STATE(12488), 1,
      sym_attribute,
    STATE(12492), 1,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15344), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596439] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15346), 1,
      anon_sym_let,
    ACTIONS(15348), 1,
      anon_sym_and,
    STATE(12489), 1,
      sym_attribute,
    STATE(12493), 1,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15344), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596476] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(9184), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [596509] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15350), 1,
      anon_sym_PIPE,
    STATE(12491), 1,
      sym_attribute,
    STATE(12496), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [596546] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14825), 1,
      anon_sym_let,
    ACTIONS(15352), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12492), 2,
      sym_attribute,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(14823), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596581] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15348), 1,
      anon_sym_and,
    ACTIONS(15357), 1,
      anon_sym_let,
    STATE(12492), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(12493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15355), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596618] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15359), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12213), 2,
      anon_sym_let,
      anon_sym_LBRACK_AT_AT,
    STATE(12494), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596653] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13976), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15350), 1,
      anon_sym_PIPE,
    STATE(12495), 1,
      sym_attribute,
    STATE(12496), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13974), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [596690] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12760), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15362), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12496), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [596725] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14163), 1,
      anon_sym_let,
    ACTIONS(15214), 1,
      anon_sym_and,
    ACTIONS(15216), 1,
      sym_let_and_operator,
    STATE(12439), 1,
      aux_sym_value_definition_repeat1,
    STATE(12497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14161), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [596764] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11019), 16,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [596797] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15230), 1,
      sym_pow_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [596834] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7296), 1,
      aux_sym_number_token1,
    ACTIONS(7298), 1,
      aux_sym_signed_number_token1,
    ACTIONS(7300), 1,
      anon_sym_SQUOTE,
    ACTIONS(7302), 1,
      anon_sym_DQUOTE,
    ACTIONS(15365), 1,
      anon_sym_LPAREN,
    ACTIONS(15369), 1,
      anon_sym_LBRACE,
    ACTIONS(15371), 1,
      anon_sym_begin,
    STATE(12500), 1,
      sym_attribute,
    STATE(14880), 1,
      sym__signed_constant,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15367), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(14412), 2,
      sym__constant,
      sym_signed_number,
    STATE(14575), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [596885] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [596930] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_and,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [596975] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_and,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [597024] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    ACTIONS(15254), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [597081] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15373), 1,
      anon_sym_PIPE,
    STATE(12505), 1,
      sym_attribute,
    STATE(12510), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597118] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_and,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_assign_operator,
      sym_let_and_operator,
  [597169] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14445), 1,
      anon_sym_let,
    ACTIONS(15214), 1,
      anon_sym_and,
    ACTIONS(15216), 1,
      sym_let_and_operator,
    STATE(12507), 1,
      sym_attribute,
    STATE(12508), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597208] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14451), 1,
      anon_sym_let,
    ACTIONS(15375), 1,
      anon_sym_and,
    ACTIONS(15378), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12508), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14449), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [597245] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13976), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15373), 1,
      anon_sym_PIPE,
    STATE(12509), 1,
      sym_attribute,
    STATE(12510), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13974), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597282] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12760), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15381), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12510), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597317] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15384), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597354] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5545), 1,
      anon_sym_DOT,
    STATE(12512), 1,
      sym_attribute,
    STATE(18541), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(5551), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [597397] = 16,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [597452] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    ACTIONS(15386), 1,
      anon_sym_SEMI,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 3,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [597509] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12479), 1,
      aux_sym_expression_item_repeat1,
    STATE(12515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15388), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597546] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15390), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597583] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12522), 1,
      anon_sym_STAR,
    ACTIONS(13674), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12517), 1,
      sym_attribute,
    STATE(12519), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597620] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12397), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15392), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12518), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597657] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12213), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15395), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12519), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_PIPE,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [597692] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5585), 1,
      anon_sym_DOT,
    STATE(12520), 1,
      sym_attribute,
    STATE(18866), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(5591), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [597735] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 5,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [597788] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11589), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [597821] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597864] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5459), 1,
      anon_sym_DOT,
    STATE(12524), 1,
      sym_attribute,
    STATE(18430), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(5471), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [597907] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15277), 1,
      sym_pow_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597944] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15277), 1,
      sym_pow_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [597981] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [598026] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [598071] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [598120] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [598171] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [598226] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [598265] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [598320] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15398), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(12534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [598357] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    ACTIONS(15386), 1,
      anon_sym_SEMI,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 3,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598414] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4987), 1,
      aux_sym_number_token1,
    ACTIONS(4989), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4991), 1,
      anon_sym_SQUOTE,
    ACTIONS(4993), 1,
      anon_sym_DQUOTE,
    ACTIONS(15400), 1,
      anon_sym_LPAREN,
    ACTIONS(15404), 1,
      anon_sym_LBRACE,
    ACTIONS(15406), 1,
      anon_sym_begin,
    STATE(5887), 1,
      sym__signed_constant,
    STATE(12536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15402), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5612), 2,
      sym__constant,
      sym_signed_number,
    STATE(5702), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [598465] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4797), 1,
      aux_sym_number_token1,
    ACTIONS(4799), 1,
      aux_sym_signed_number_token1,
    ACTIONS(4801), 1,
      anon_sym_SQUOTE,
    ACTIONS(4803), 1,
      anon_sym_DQUOTE,
    ACTIONS(15408), 1,
      anon_sym_LPAREN,
    ACTIONS(15412), 1,
      anon_sym_LBRACE,
    ACTIONS(15414), 1,
      anon_sym_begin,
    STATE(5645), 1,
      sym__signed_constant,
    STATE(12537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15410), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(5536), 2,
      sym__constant,
      sym_signed_number,
    STATE(5559), 6,
      sym_number,
      sym_character,
      sym_string,
      sym_quoted_string,
      sym_boolean,
      sym_unit,
  [598516] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
  [598571] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14395), 1,
      anon_sym_let,
    ACTIONS(15263), 1,
      anon_sym_and,
    ACTIONS(15265), 1,
      sym_let_and_operator,
    STATE(12539), 1,
      sym_attribute,
    STATE(12543), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14393), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598610] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    ACTIONS(15275), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15277), 1,
      sym_pow_operator,
    ACTIONS(15279), 1,
      sym_mult_operator,
    ACTIONS(15281), 1,
      sym_concat_operator,
    ACTIONS(15283), 1,
      sym_rel_operator,
    ACTIONS(15285), 1,
      sym_and_operator,
    ACTIONS(15287), 1,
      sym_or_operator,
    ACTIONS(15289), 1,
      sym_assign_operator,
    ACTIONS(15386), 1,
      anon_sym_SEMI,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 3,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [598667] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14445), 1,
      anon_sym_let,
    ACTIONS(15263), 1,
      anon_sym_and,
    ACTIONS(15265), 1,
      sym_let_and_operator,
    STATE(12541), 1,
      sym_attribute,
    STATE(12543), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598706] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11108), 1,
      anon_sym_as,
    ACTIONS(15340), 1,
      sym__lowercase_identifier,
    ACTIONS(15416), 1,
      anon_sym_POUND,
    STATE(12542), 1,
      sym_attribute,
    STATE(13013), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
  [598749] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14451), 1,
      anon_sym_let,
    ACTIONS(15418), 1,
      anon_sym_and,
    ACTIONS(15421), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12543), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
    ACTIONS(14449), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598786] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14445), 1,
      anon_sym_let,
    ACTIONS(15263), 1,
      anon_sym_and,
    ACTIONS(15265), 1,
      sym_let_and_operator,
    STATE(12544), 1,
      sym_attribute,
    STATE(12548), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598825] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11481), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [598858] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14445), 1,
      anon_sym_let,
    ACTIONS(15214), 1,
      anon_sym_and,
    ACTIONS(15216), 1,
      sym_let_and_operator,
    STATE(12433), 1,
      aux_sym_value_definition_repeat1,
    STATE(12546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14443), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598897] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5605), 1,
      anon_sym_DOT,
    STATE(12547), 1,
      sym_attribute,
    STATE(18546), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(5611), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [598940] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(14515), 1,
      anon_sym_let,
    ACTIONS(15263), 1,
      anon_sym_and,
    ACTIONS(15265), 1,
      sym_let_and_operator,
    STATE(12543), 1,
      aux_sym_value_definition_repeat1,
    STATE(12548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14513), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [598979] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2082), 1,
      sym_add_operator,
    STATE(12549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599014] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    ACTIONS(15244), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10327), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [599071] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1423), 1,
      anon_sym_DOT,
    STATE(12551), 1,
      sym_attribute,
    STATE(20795), 1,
      sym_add_operator,
    STATE(21355), 1,
      sym__infix_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(1431), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [599114] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12415), 1,
      aux_sym_expression_item_repeat1,
    STATE(12552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15048), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599155] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15348), 1,
      anon_sym_and,
    ACTIONS(15426), 1,
      anon_sym_let,
    STATE(12488), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(12553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15424), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [599192] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15350), 1,
      anon_sym_PIPE,
    STATE(12491), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12259), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599229] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15350), 1,
      anon_sym_PIPE,
    STATE(12495), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599266] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11301), 1,
      aux_sym_expression_item_repeat1,
    STATE(12556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14125), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599307] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11532), 1,
      aux_sym_expression_item_repeat1,
    STATE(12557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13999), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599348] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15398), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(12558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [599385] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15373), 1,
      anon_sym_PIPE,
    STATE(12505), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12259), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599422] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [599457] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [599496] = 17,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_and,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    ACTIONS(15228), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15230), 1,
      sym_pow_operator,
    ACTIONS(15232), 1,
      sym_mult_operator,
    ACTIONS(15234), 1,
      sym_concat_operator,
    ACTIONS(15236), 1,
      sym_rel_operator,
    ACTIONS(15238), 1,
      sym_and_operator,
    ACTIONS(15240), 1,
      sym_or_operator,
    ACTIONS(15242), 1,
      sym_assign_operator,
    ACTIONS(15244), 1,
      anon_sym_SEMI,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [599553] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15373), 1,
      anon_sym_PIPE,
    STATE(12509), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_constraint,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599590] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11483), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11485), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [599623] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11487), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11489), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [599656] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14691), 1,
      anon_sym_DOT,
    STATE(12566), 1,
      sym_attribute,
    STATE(20446), 1,
      sym__infix_operator,
    STATE(20795), 1,
      sym_add_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(1413), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(1415), 3,
      sym_pow_operator,
      sym_concat_operator,
      sym_assign_operator,
    ACTIONS(1411), 4,
      sym_mult_operator,
      sym_rel_operator,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(14693), 5,
      sym_prefix_operator,
      sym_hash_operator,
      sym_let_operator,
      sym_let_and_operator,
      sym_match_operator,
  [599699] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15206), 1,
      anon_sym_DASH_GT,
    ACTIONS(15208), 1,
      anon_sym_with,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(12511), 1,
      aux_sym_expression_item_repeat1,
    STATE(12567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14329), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599740] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11491), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11493), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [599773] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11396), 1,
      aux_sym_expression_item_repeat1,
    STATE(12569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15428), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14074), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599812] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(11479), 1,
      aux_sym_expression_item_repeat1,
    STATE(12570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15430), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(14105), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [599851] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11495), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11497), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
  [599884] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15230), 1,
      sym_pow_operator,
    STATE(2386), 1,
      sym_add_operator,
    STATE(12572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [599921] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [599975] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15452), 1,
      anon_sym_let,
    ACTIONS(15454), 1,
      anon_sym_and,
    STATE(12574), 1,
      sym_attribute,
    STATE(12913), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [600011] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15456), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600047] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15460), 1,
      anon_sym_let,
    ACTIONS(15462), 1,
      anon_sym_DOT,
    STATE(12576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15458), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [600081] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9320), 1,
      sym__module_expression,
    STATE(12577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [600129] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9378), 1,
      sym__module_expression,
    STATE(12578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [600177] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9492), 1,
      sym__module_expression,
    STATE(12579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [600225] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(15464), 1,
      sym__lowercase_identifier,
    ACTIONS(15466), 1,
      anon_sym_POUND,
    STATE(12580), 1,
      sym_attribute,
    STATE(13393), 1,
      sym_type_constructor_path,
    STATE(17850), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11108), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [600267] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(12581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [600301] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
  [600355] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [600407] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600449] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15490), 1,
      sym_pow_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600485] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15490), 1,
      sym_pow_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600521] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [600565] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [600609] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [600657] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [600707] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [600761] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600799] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [600853] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15504), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [600889] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [600943] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    STATE(12596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_and,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 9,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
      sym_let_and_operator,
  [600977] = 18,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(15506), 1,
      anon_sym_COLON_GT,
    ACTIONS(15508), 1,
      anon_sym_RPAREN,
    ACTIONS(15510), 1,
      anon_sym_COLON2,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12597), 1,
      sym_attribute,
    STATE(17882), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601035] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15512), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12598), 2,
      sym_attribute,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(14823), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [601067] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15515), 1,
      anon_sym_and,
    STATE(12598), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(12599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15355), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [601101] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
    ACTIONS(11019), 9,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [601133] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    ACTIONS(15517), 1,
      anon_sym_SEMI,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601189] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    ACTIONS(15517), 1,
      anon_sym_SEMI,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601245] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15521), 1,
      anon_sym_SEMI,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601301] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15521), 1,
      anon_sym_SEMI,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601357] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15541), 1,
      anon_sym_SEMI,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601413] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15541), 1,
      anon_sym_SEMI,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601469] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15561), 1,
      anon_sym_SEMI,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601525] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15561), 1,
      anon_sym_SEMI,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601581] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15581), 1,
      anon_sym_let,
    ACTIONS(15583), 1,
      anon_sym_and,
    STATE(12609), 1,
      sym_attribute,
    STATE(12909), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15579), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [601617] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12604), 1,
      anon_sym_DASH_GT,
    STATE(12610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [601651] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8294), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [601683] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13622), 1,
      anon_sym_EQ,
    ACTIONS(15585), 1,
      anon_sym_of,
    ACTIONS(15587), 1,
      anon_sym_COLON2,
    STATE(12612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [601721] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12613), 1,
      sym_attribute,
    STATE(13640), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [601769] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8022), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [601801] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    ACTIONS(15517), 1,
      anon_sym_SEMI,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601857] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15591), 1,
      anon_sym_SEMI,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [601913] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(15303), 1,
      anon_sym_constraint,
    ACTIONS(15305), 1,
      anon_sym_val,
    ACTIONS(15309), 1,
      anon_sym_inherit,
    ACTIONS(15311), 1,
      anon_sym_method,
    ACTIONS(15609), 1,
      anon_sym_end,
    STATE(12617), 1,
      sym_attribute,
    STATE(12899), 1,
      aux_sym_class_body_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14248), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(14255), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [601963] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9310), 1,
      sym__module_expression,
    STATE(12618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602011] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15613), 1,
      anon_sym_let,
    ACTIONS(15615), 1,
      anon_sym_and,
    STATE(12619), 1,
      sym_attribute,
    STATE(12624), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [602047] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15541), 1,
      anon_sym_SEMI,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [602103] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9295), 1,
      sym__module_expression,
    STATE(12621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602151] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9339), 1,
      sym__module_expression,
    STATE(12622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602199] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15615), 1,
      anon_sym_and,
    ACTIONS(15619), 1,
      anon_sym_let,
    STATE(12623), 1,
      sym_attribute,
    STATE(12624), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [602235] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15032), 1,
      anon_sym_let,
    ACTIONS(15621), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12624), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(15030), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [602269] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15615), 1,
      anon_sym_and,
    ACTIONS(15619), 1,
      anon_sym_let,
    STATE(12625), 1,
      sym_attribute,
    STATE(12632), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [602305] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9292), 1,
      sym__module_expression,
    STATE(12626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602353] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9280), 1,
      sym__module_expression,
    STATE(12627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602401] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9285), 1,
      sym__module_expression,
    STATE(12628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602449] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9091), 1,
      sym__module_expression,
    STATE(9156), 1,
      sym_module_path,
    STATE(12629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602497] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9095), 1,
      sym__module_expression,
    STATE(9156), 1,
      sym_module_path,
    STATE(12630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602545] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12631), 1,
      sym_attribute,
    STATE(13876), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602593] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15615), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_let,
    STATE(12624), 1,
      aux_sym_type_definition_repeat1,
    STATE(12632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [602629] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9288), 1,
      sym__module_expression,
    STATE(12633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602677] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9279), 1,
      sym__module_expression,
    STATE(12634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8330), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8332), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [602757] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12636), 1,
      sym_attribute,
    STATE(13599), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602805] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8338), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8340), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [602837] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8280), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8282), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [602869] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15628), 1,
      anon_sym_PIPE,
    STATE(12639), 1,
      sym_attribute,
    STATE(12642), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602905] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12640), 1,
      sym_attribute,
    STATE(13637), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [602953] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15628), 1,
      anon_sym_PIPE,
    STATE(12641), 1,
      sym_attribute,
    STATE(12645), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [602989] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15628), 1,
      anon_sym_PIPE,
    STATE(12642), 1,
      sym_attribute,
    STATE(12646), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603025] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [603079] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15630), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(12644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603115] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15628), 1,
      anon_sym_PIPE,
    STATE(12645), 1,
      sym_attribute,
    STATE(12646), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603151] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15632), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12646), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603185] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15635), 1,
      anon_sym_PIPE,
    STATE(12647), 1,
      sym_attribute,
    STATE(12649), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603221] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15635), 1,
      anon_sym_PIPE,
    STATE(12648), 1,
      sym_attribute,
    STATE(12650), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603257] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15635), 1,
      anon_sym_PIPE,
    STATE(12649), 1,
      sym_attribute,
    STATE(12651), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603293] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15635), 1,
      anon_sym_PIPE,
    STATE(12650), 1,
      sym_attribute,
    STATE(12651), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603329] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15637), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12651), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603363] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15642), 1,
      anon_sym_let,
    ACTIONS(15644), 1,
      anon_sym_and,
    STATE(12652), 1,
      sym_attribute,
    STATE(12797), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [603399] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15642), 1,
      anon_sym_let,
    ACTIONS(15644), 1,
      anon_sym_and,
    STATE(12653), 1,
      sym_attribute,
    STATE(12798), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [603435] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8342), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8344), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [603467] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15561), 1,
      anon_sym_SEMI,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [603523] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15591), 1,
      anon_sym_SEMI,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [603579] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15646), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603615] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603649] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15648), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(12659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603685] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_assign_operator,
  [603737] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603779] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15436), 1,
      sym_pow_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603815] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15436), 1,
      sym_pow_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [603851] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [603895] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [603939] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_assign_operator,
  [603987] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_assign_operator,
  [604037] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604075] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
  [604129] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8068), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8070), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [604161] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15650), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(12671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604197] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
  [604251] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    STATE(12673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 9,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604285] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13852), 1,
      anon_sym_struct,
    ACTIONS(14027), 1,
      anon_sym_functor,
    STATE(9156), 1,
      sym_module_path,
    STATE(9346), 1,
      sym__module_expression,
    STATE(12674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [604333] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    ACTIONS(15652), 1,
      anon_sym_SEMI,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604389] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    ACTIONS(15652), 1,
      anon_sym_SEMI,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604445] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [604497] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604539] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15525), 1,
      sym_pow_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604575] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15525), 1,
      sym_pow_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604611] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [604655] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [604699] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [604747] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [604797] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [604851] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604889] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [604943] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [604979] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [605033] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605067] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15650), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(12691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605103] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(15464), 1,
      sym__lowercase_identifier,
    ACTIONS(15656), 1,
      anon_sym_DASH_GT,
    ACTIONS(15658), 1,
      anon_sym_STAR,
    ACTIONS(15660), 1,
      anon_sym_POUND,
    STATE(12692), 1,
      sym_attribute,
    STATE(13510), 1,
      sym_type_constructor_path,
    STATE(17850), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 3,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(10383), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [605149] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15515), 1,
      anon_sym_and,
    STATE(12693), 1,
      sym_attribute,
    STATE(12853), 1,
      aux_sym_class_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15424), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [605183] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_assign_operator,
  [605235] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    ACTIONS(15652), 1,
      anon_sym_SEMI,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605291] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605333] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15472), 1,
      sym_pow_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605369] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15472), 1,
      sym_pow_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605405] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [605449] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [605493] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_assign_operator,
  [605541] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
      sym_assign_operator,
  [605591] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [605645] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15613), 1,
      anon_sym_let,
    ACTIONS(15662), 1,
      anon_sym_and,
    STATE(12704), 1,
      sym_attribute,
    STATE(12708), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [605681] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605719] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
  [605773] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15619), 1,
      anon_sym_let,
    ACTIONS(15662), 1,
      anon_sym_and,
    STATE(12707), 1,
      sym_attribute,
    STATE(12708), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [605809] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15032), 1,
      anon_sym_let,
    ACTIONS(15664), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12708), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(15030), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [605843] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15619), 1,
      anon_sym_let,
    ACTIONS(15662), 1,
      anon_sym_and,
    STATE(12709), 1,
      sym_attribute,
    STATE(12711), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [605879] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12710), 1,
      sym_attribute,
    STATE(13864), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [605927] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15626), 1,
      anon_sym_let,
    ACTIONS(15662), 1,
      anon_sym_and,
    STATE(12708), 1,
      aux_sym_type_definition_repeat1,
    STATE(12711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [605963] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15648), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(12712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [605999] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9374), 1,
      sym__module_expression,
    STATE(12713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [606047] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9301), 1,
      sym__module_expression,
    STATE(12714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [606095] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606129] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15654), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606165] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [606219] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15667), 1,
      anon_sym_PIPE,
    STATE(12718), 1,
      sym_attribute,
    STATE(12720), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606255] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15667), 1,
      anon_sym_PIPE,
    STATE(12719), 1,
      sym_attribute,
    STATE(12722), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606291] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15667), 1,
      anon_sym_PIPE,
    STATE(12720), 1,
      sym_attribute,
    STATE(12723), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606327] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8352), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8354), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [606359] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15667), 1,
      anon_sym_PIPE,
    STATE(12722), 1,
      sym_attribute,
    STATE(12723), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606395] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15669), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12723), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606429] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8356), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8358), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [606461] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8072), 3,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_POUND,
    ACTIONS(8074), 14,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
      sym_hash_operator,
  [606493] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [606545] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606587] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15545), 1,
      sym_pow_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606623] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15545), 1,
      sym_pow_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606659] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [606703] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [606747] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [606795] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [606845] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [606899] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [606937] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [606991] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15672), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607027] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    ACTIONS(15543), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15545), 1,
      sym_pow_operator,
    ACTIONS(15547), 1,
      sym_mult_operator,
    ACTIONS(15549), 1,
      sym_concat_operator,
    ACTIONS(15551), 1,
      sym_rel_operator,
    ACTIONS(15553), 1,
      sym_and_operator,
    ACTIONS(15555), 1,
      sym_or_operator,
    ACTIONS(15557), 1,
      sym_assign_operator,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [607081] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_done,
  [607135] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12740), 1,
      sym_attribute,
    STATE(13735), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [607183] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15175), 1,
      anon_sym_let,
    ACTIONS(15674), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12741), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(15173), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [607217] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15583), 1,
      anon_sym_and,
    ACTIONS(15679), 1,
      anon_sym_let,
    STATE(12741), 1,
      aux_sym_class_definition_repeat1,
    STATE(12742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15677), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [607253] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2150), 1,
      sym_add_operator,
    STATE(12743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607287] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15672), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607323] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [607375] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607417] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15565), 1,
      sym_pow_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607453] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15565), 1,
      sym_pow_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607489] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [607533] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [607577] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [607625] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [607675] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [607729] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607767] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [607821] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15681), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607857] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [607911] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15683), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [607947] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9321), 1,
      sym__module_expression,
    STATE(12759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [607995] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12760), 1,
      sym_attribute,
    STATE(13784), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608043] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608077] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15681), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608113] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    ACTIONS(15488), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15490), 1,
      sym_pow_operator,
    ACTIONS(15492), 1,
      sym_mult_operator,
    ACTIONS(15494), 1,
      sym_concat_operator,
    ACTIONS(15496), 1,
      sym_rel_operator,
    ACTIONS(15498), 1,
      sym_and_operator,
    ACTIONS(15500), 1,
      sym_or_operator,
    ACTIONS(15502), 1,
      sym_assign_operator,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [608167] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(15464), 1,
      sym__lowercase_identifier,
    ACTIONS(15660), 1,
      anon_sym_POUND,
    ACTIONS(15685), 1,
      anon_sym_STAR,
    STATE(12764), 1,
      sym_attribute,
    STATE(13510), 1,
      sym_type_constructor_path,
    STATE(17850), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 4,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11160), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [608211] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    ACTIONS(15521), 1,
      anon_sym_SEMI,
    ACTIONS(15523), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15525), 1,
      sym_pow_operator,
    ACTIONS(15527), 1,
      sym_mult_operator,
    ACTIONS(15529), 1,
      sym_concat_operator,
    ACTIONS(15531), 1,
      sym_rel_operator,
    ACTIONS(15533), 1,
      sym_and_operator,
    ACTIONS(15535), 1,
      sym_or_operator,
    ACTIONS(15537), 1,
      sym_assign_operator,
    STATE(2132), 1,
      sym_add_operator,
    STATE(12765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [608267] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(15303), 1,
      anon_sym_constraint,
    ACTIONS(15305), 1,
      anon_sym_val,
    ACTIONS(15309), 1,
      anon_sym_inherit,
    ACTIONS(15311), 1,
      anon_sym_method,
    ACTIONS(15687), 1,
      anon_sym_end,
    STATE(12766), 1,
      sym_attribute,
    STATE(12899), 1,
      aux_sym_class_body_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14248), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(14255), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [608317] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15689), 1,
      anon_sym_EQ,
    ACTIONS(15691), 1,
      anon_sym_of,
    ACTIONS(15693), 1,
      anon_sym_COLON2,
    STATE(12767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [608355] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15695), 1,
      anon_sym_EQ,
    ACTIONS(15697), 1,
      anon_sym_of,
    ACTIONS(15699), 1,
      anon_sym_COLON2,
    STATE(12768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [608393] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15701), 1,
      anon_sym_EQ,
    ACTIONS(15703), 1,
      anon_sym_of,
    ACTIONS(15705), 1,
      anon_sym_COLON2,
    STATE(12769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [608431] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12770), 1,
      sym_attribute,
    STATE(13584), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608479] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12771), 1,
      sym_attribute,
    STATE(13585), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608527] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12772), 1,
      sym_attribute,
    STATE(13779), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608575] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12773), 1,
      sym_attribute,
    STATE(13586), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608623] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15707), 1,
      anon_sym_else,
    STATE(11145), 1,
      sym_else_clause,
    STATE(12774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [608659] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12775), 1,
      sym_attribute,
    STATE(13792), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608707] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15689), 1,
      anon_sym_EQ,
    ACTIONS(15709), 1,
      anon_sym_of,
    ACTIONS(15711), 1,
      anon_sym_COLON2,
    STATE(12776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [608745] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15695), 1,
      anon_sym_EQ,
    ACTIONS(15713), 1,
      anon_sym_of,
    ACTIONS(15715), 1,
      anon_sym_COLON2,
    STATE(12777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [608783] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13178), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15585), 1,
      anon_sym_of,
    ACTIONS(15587), 1,
      anon_sym_COLON2,
    ACTIONS(15701), 1,
      anon_sym_EQ,
    STATE(12778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [608821] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12779), 1,
      sym_attribute,
    STATE(13869), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608869] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    ACTIONS(15717), 1,
      anon_sym_functor,
    STATE(12780), 1,
      sym_attribute,
    STATE(13199), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608917] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12781), 1,
      sym_attribute,
    STATE(13843), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [608965] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9347), 1,
      sym__module_expression,
    STATE(12782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [609013] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15719), 1,
      anon_sym_PIPE,
    STATE(12783), 1,
      sym_attribute,
    STATE(12785), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609049] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15719), 1,
      anon_sym_PIPE,
    STATE(12784), 1,
      sym_attribute,
    STATE(12786), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609085] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15719), 1,
      anon_sym_PIPE,
    STATE(12785), 1,
      sym_attribute,
    STATE(12787), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609121] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15719), 1,
      anon_sym_PIPE,
    STATE(12786), 1,
      sym_attribute,
    STATE(12787), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609157] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15721), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12787), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609191] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(12788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [609225] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12789), 1,
      sym_attribute,
    STATE(13859), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [609273] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609307] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15724), 1,
      anon_sym_PIPE,
    STATE(12791), 1,
      sym_attribute,
    STATE(12793), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609343] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15724), 1,
      anon_sym_PIPE,
    STATE(12792), 1,
      sym_attribute,
    STATE(12794), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609379] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15724), 1,
      anon_sym_PIPE,
    STATE(12793), 1,
      sym_attribute,
    STATE(12795), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609415] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15724), 1,
      anon_sym_PIPE,
    STATE(12794), 1,
      sym_attribute,
    STATE(12795), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609451] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15726), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12795), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609485] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(15464), 1,
      sym__lowercase_identifier,
    ACTIONS(15660), 1,
      anon_sym_POUND,
    STATE(12796), 1,
      sym_attribute,
    STATE(13510), 1,
      sym_type_constructor_path,
    STATE(17850), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(11201), 7,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [609527] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15175), 1,
      anon_sym_let,
    ACTIONS(15729), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12797), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(15173), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [609561] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15644), 1,
      anon_sym_and,
    ACTIONS(15679), 1,
      anon_sym_let,
    STATE(12797), 1,
      aux_sym_class_definition_repeat1,
    STATE(12798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15677), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [609597] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12799), 1,
      sym_attribute,
    STATE(13893), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [609645] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15591), 1,
      anon_sym_SEMI,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609701] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15732), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609737] = 18,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(15510), 1,
      anon_sym_COLON2,
    ACTIONS(15734), 1,
      anon_sym_COLON_GT,
    ACTIONS(15736), 1,
      anon_sym_RPAREN,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12802), 1,
      sym_attribute,
    STATE(18407), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [609795] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [609827] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15738), 1,
      anon_sym_PIPE,
    STATE(12804), 1,
      sym_attribute,
    STATE(12806), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609863] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15738), 1,
      anon_sym_PIPE,
    STATE(12805), 1,
      sym_attribute,
    STATE(12807), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609899] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15738), 1,
      anon_sym_PIPE,
    STATE(12806), 1,
      sym_attribute,
    STATE(12808), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609935] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15738), 1,
      anon_sym_PIPE,
    STATE(12807), 1,
      sym_attribute,
    STATE(12808), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [609971] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15740), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12808), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610005] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13022), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13598), 1,
      anon_sym_EQ,
    ACTIONS(15709), 1,
      anon_sym_of,
    ACTIONS(15711), 1,
      anon_sym_COLON2,
    STATE(12809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610043] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12810), 1,
      sym_attribute,
    STATE(13795), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610091] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(8743), 1,
      sym__module_expression,
    STATE(9156), 1,
      sym_module_path,
    STATE(12811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610139] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15743), 1,
      anon_sym_PIPE,
    STATE(12812), 1,
      sym_attribute,
    STATE(12814), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610175] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15743), 1,
      anon_sym_PIPE,
    STATE(12813), 1,
      sym_attribute,
    STATE(12815), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610211] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15743), 1,
      anon_sym_PIPE,
    STATE(12814), 1,
      sym_attribute,
    STATE(12816), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610247] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15743), 1,
      anon_sym_PIPE,
    STATE(12815), 1,
      sym_attribute,
    STATE(12816), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610283] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15745), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12816), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610317] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15748), 1,
      anon_sym_COLON2,
    STATE(12817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [610351] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12818), 1,
      sym_attribute,
    STATE(13791), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610399] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9025), 1,
      sym__module_expression,
    STATE(9156), 1,
      sym_module_path,
    STATE(12819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610447] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12820), 1,
      sym_attribute,
    STATE(13877), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610495] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13068), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13604), 1,
      anon_sym_EQ,
    ACTIONS(15713), 1,
      anon_sym_of,
    ACTIONS(15715), 1,
      anon_sym_COLON2,
    STATE(12821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [610533] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12822), 1,
      sym_attribute,
    STATE(13881), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610581] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12823), 1,
      sym_attribute,
    STATE(13887), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610629] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [610681] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12825), 1,
      sym_attribute,
    STATE(13737), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610729] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610771] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12827), 1,
      sym_attribute,
    STATE(13825), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [610819] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15595), 1,
      sym_pow_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610855] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15595), 1,
      sym_pow_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [610891] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [610935] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_rel_operator,
      sym_assign_operator,
  [610979] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [611027] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12833), 1,
      sym_attribute,
    STATE(13917), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611075] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
      sym_assign_operator,
  [611125] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611179] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [611217] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
  [611271] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12838), 1,
      sym_attribute,
    STATE(13601), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611319] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14049), 1,
      anon_sym_functor,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    STATE(12839), 1,
      sym_attribute,
    STATE(13602), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611367] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12840), 1,
      sym_attribute,
    STATE(13873), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611415] = 14,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(27), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(29), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(31), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(15303), 1,
      anon_sym_constraint,
    ACTIONS(15305), 1,
      anon_sym_val,
    ACTIONS(15309), 1,
      anon_sym_inherit,
    ACTIONS(15311), 1,
      anon_sym_method,
    ACTIONS(15750), 1,
      anon_sym_end,
    STATE(12766), 1,
      aux_sym_class_body_type_repeat1,
    STATE(12841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14248), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(14255), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [611465] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12842), 1,
      sym_attribute,
    STATE(13914), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611513] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12843), 1,
      sym_attribute,
    STATE(13918), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611561] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15683), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [611597] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12845), 1,
      sym_attribute,
    STATE(13906), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611645] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12846), 1,
      sym_attribute,
    STATE(13804), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611693] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12847), 1,
      sym_attribute,
    STATE(13772), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611741] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12848), 1,
      sym_attribute,
    STATE(13703), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611789] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12849), 1,
      sym_attribute,
    STATE(13771), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611837] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12850), 1,
      sym_attribute,
    STATE(13842), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [611885] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    ACTIONS(15752), 1,
      anon_sym_SEMI,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_else,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [611941] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15456), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [611977] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15515), 1,
      anon_sym_and,
    STATE(12598), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(12853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15344), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612011] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12854), 1,
      sym_attribute,
    STATE(13907), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612059] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15515), 1,
      anon_sym_and,
    STATE(12599), 1,
      aux_sym_class_type_definition_repeat1,
    STATE(12855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15344), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612093] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12856), 1,
      sym_attribute,
    STATE(13697), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612141] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    STATE(2345), 1,
      sym_add_operator,
    STATE(12857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_to,
      anon_sym_downto,
  [612195] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12858), 1,
      sym_attribute,
    STATE(13883), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612243] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12859), 1,
      sym_attribute,
    STATE(13770), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612291] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12860), 1,
      sym_attribute,
    STATE(13794), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612339] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12861), 1,
      sym_attribute,
    STATE(13725), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612387] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15646), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [612423] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12863), 1,
      sym_attribute,
    STATE(13768), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612471] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13088), 1,
      anon_sym_STAR,
    ACTIONS(13674), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(12864), 1,
      sym_attribute,
    STATE(12888), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [612507] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12865), 1,
      sym_attribute,
    STATE(13916), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612555] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12866), 1,
      sym_attribute,
    STATE(13824), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612603] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12867), 1,
      sym_attribute,
    STATE(13884), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612651] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12868), 1,
      sym_attribute,
    STATE(13833), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612699] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12869), 1,
      sym_attribute,
    STATE(13712), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612747] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12870), 1,
      sym_attribute,
    STATE(13730), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612795] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12871), 1,
      sym_attribute,
    STATE(13767), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612843] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12872), 1,
      sym_attribute,
    STATE(13820), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [612891] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(15754), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15758), 1,
      anon_sym_nonrec,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(12873), 1,
      sym_attribute,
    STATE(12874), 1,
      sym_type_binding,
    STATE(13383), 1,
      sym__attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15388), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20072), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [612951] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15615), 1,
      anon_sym_and,
    ACTIONS(15768), 1,
      anon_sym_let,
    STATE(12619), 1,
      aux_sym_type_definition_repeat1,
    STATE(12874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15766), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [612987] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15613), 1,
      anon_sym_let,
    ACTIONS(15615), 1,
      anon_sym_and,
    STATE(12623), 1,
      aux_sym_type_definition_repeat1,
    STATE(12875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613023] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15452), 1,
      anon_sym_let,
    ACTIONS(15770), 1,
      anon_sym_and,
    STATE(12876), 1,
      sym_attribute,
    STATE(12878), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613059] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15770), 1,
      anon_sym_and,
    ACTIONS(15774), 1,
      anon_sym_let,
    STATE(12877), 1,
      sym_attribute,
    STATE(12878), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613095] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15098), 1,
      anon_sym_let,
    ACTIONS(15776), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12878), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(15096), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613129] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15770), 1,
      anon_sym_and,
    ACTIONS(15774), 1,
      anon_sym_let,
    STATE(12879), 1,
      sym_attribute,
    STATE(12881), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613165] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15707), 1,
      anon_sym_else,
    STATE(10876), 1,
      sym_else_clause,
    STATE(12880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613201] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15770), 1,
      anon_sym_and,
    ACTIONS(15781), 1,
      anon_sym_let,
    STATE(12878), 1,
      aux_sym_module_definition_repeat1,
    STATE(12881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15779), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613237] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(14045), 1,
      anon_sym_LPAREN,
    ACTIONS(14051), 1,
      anon_sym_struct,
    ACTIONS(14053), 1,
      sym__uppercase_identifier,
    ACTIONS(15717), 1,
      anon_sym_functor,
    STATE(12882), 1,
      sym_attribute,
    STATE(13273), 1,
      sym__module_expression,
    STATE(13974), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14017), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [613285] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15630), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(12883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613321] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    ACTIONS(15434), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15436), 1,
      sym_pow_operator,
    ACTIONS(15438), 1,
      sym_mult_operator,
    ACTIONS(15440), 1,
      sym_concat_operator,
    ACTIONS(15442), 1,
      sym_rel_operator,
    ACTIONS(15444), 1,
      sym_and_operator,
    ACTIONS(15446), 1,
      sym_or_operator,
    ACTIONS(15448), 1,
      sym_assign_operator,
    STATE(2318), 1,
      sym_add_operator,
    STATE(12884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
  [613375] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15783), 1,
      sym__lowercase_identifier,
    ACTIONS(15785), 1,
      anon_sym_nonrec,
    STATE(12885), 1,
      sym_attribute,
    STATE(12886), 1,
      sym_type_binding,
    STATE(13490), 1,
      sym__attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15467), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20252), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [613435] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15662), 1,
      anon_sym_and,
    ACTIONS(15768), 1,
      anon_sym_let,
    STATE(12704), 1,
      aux_sym_type_definition_repeat1,
    STATE(12886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15766), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613471] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15613), 1,
      anon_sym_let,
    ACTIONS(15662), 1,
      anon_sym_and,
    STATE(12707), 1,
      aux_sym_type_definition_repeat1,
    STATE(12887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [613507] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12213), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15787), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12888), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613541] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15790), 1,
      sym__lowercase_identifier,
    ACTIONS(15792), 1,
      anon_sym_nonrec,
    STATE(12889), 1,
      sym_attribute,
    STATE(13527), 1,
      sym_type_binding,
    STATE(13559), 1,
      sym__attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15490), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(18424), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [613601] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15794), 1,
      anon_sym_PIPE,
    STATE(12890), 1,
      sym_attribute,
    STATE(12892), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613637] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13976), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15794), 1,
      anon_sym_PIPE,
    STATE(12891), 1,
      sym_attribute,
    STATE(12892), 1,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13974), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613673] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12760), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15796), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12892), 2,
      sym_attribute,
      aux_sym_variant_declaration_repeat1,
    ACTIONS(12758), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [613707] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    ACTIONS(15752), 1,
      anon_sym_SEMI,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_else,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [613763] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15732), 1,
      anon_sym_else,
    STATE(8465), 1,
      sym_else_clause,
    STATE(12894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [613799] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    ACTIONS(15470), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15472), 1,
      sym_pow_operator,
    ACTIONS(15474), 1,
      sym_mult_operator,
    ACTIONS(15476), 1,
      sym_concat_operator,
    ACTIONS(15478), 1,
      sym_rel_operator,
    ACTIONS(15480), 1,
      sym_and_operator,
    ACTIONS(15482), 1,
      sym_or_operator,
    ACTIONS(15484), 1,
      sym_assign_operator,
    ACTIONS(15752), 1,
      anon_sym_SEMI,
    STATE(2054), 1,
      sym_add_operator,
    STATE(12895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_else,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [613855] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8298), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [613887] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(9519), 1,
      sym__module_expression,
    STATE(12897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [613935] = 19,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15799), 1,
      sym__lowercase_identifier,
    ACTIONS(15801), 1,
      anon_sym_nonrec,
    STATE(12898), 1,
      sym_attribute,
    STATE(13093), 1,
      sym_type_binding,
    STATE(13462), 1,
      sym__attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15397), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(19934), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [613995] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15803), 1,
      anon_sym_constraint,
    ACTIONS(15806), 1,
      anon_sym_val,
    ACTIONS(15809), 1,
      anon_sym_end,
    ACTIONS(15811), 1,
      anon_sym_inherit,
    ACTIONS(15814), 1,
      anon_sym_method,
    ACTIONS(15817), 1,
      anon_sym_LBRACK_AT_AT_AT,
    ACTIONS(15820), 1,
      anon_sym_LBRACK_PERCENT_PERCENT,
    ACTIONS(15823), 1,
      anon_sym_LBRACE_PERCENT_PERCENT,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12899), 2,
      sym_attribute,
      aux_sym_class_body_type_repeat1,
    STATE(14248), 2,
      sym__class_field_specification,
      sym_floating_attribute,
    STATE(14255), 6,
      sym_inheritance_specification,
      sym_instance_variable_specification,
      sym_method_specification,
      sym_type_parameter_constraint,
      sym_item_extension,
      sym_quoted_item_extension,
  [614043] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15581), 1,
      anon_sym_let,
    ACTIONS(15644), 1,
      anon_sym_and,
    STATE(12652), 1,
      aux_sym_class_definition_repeat1,
    STATE(12900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15579), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614079] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12790), 1,
      anon_sym_STAR,
    STATE(12901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_DASH_GT,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614113] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1918), 1,
      sym_add_operator,
    STATE(12902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [614147] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15504), 1,
      anon_sym_else,
    STATE(8485), 1,
      sym_else_clause,
    STATE(12903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [614183] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15770), 1,
      anon_sym_and,
    ACTIONS(15828), 1,
      anon_sym_let,
    STATE(12876), 1,
      aux_sym_module_definition_repeat1,
    STATE(12904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15826), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614219] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15452), 1,
      anon_sym_let,
    ACTIONS(15770), 1,
      anon_sym_and,
    STATE(12877), 1,
      aux_sym_module_definition_repeat1,
    STATE(12905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614255] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13846), 1,
      anon_sym_LPAREN,
    ACTIONS(13850), 1,
      anon_sym_functor,
    ACTIONS(13852), 1,
      anon_sym_struct,
    STATE(9156), 1,
      sym_module_path,
    STATE(12906), 1,
      sym_attribute,
    STATE(13740), 1,
      sym__module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9195), 4,
      sym__simple_module_expression,
      sym_structure,
      sym_functor,
      sym_module_application,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [614303] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12261), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15794), 1,
      anon_sym_PIPE,
    STATE(12890), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12259), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614339] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13970), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15794), 1,
      anon_sym_PIPE,
    STATE(12891), 1,
      aux_sym_variant_declaration_repeat1,
    STATE(12908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13968), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_and,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [614375] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15583), 1,
      anon_sym_and,
    ACTIONS(15642), 1,
      anon_sym_let,
    STATE(12741), 1,
      aux_sym_class_definition_repeat1,
    STATE(12909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614411] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8290), 15,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      sym__uppercase_identifier,
  [614443] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15583), 1,
      anon_sym_and,
    ACTIONS(15642), 1,
      anon_sym_let,
    STATE(12742), 1,
      aux_sym_class_definition_repeat1,
    STATE(12911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614479] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15452), 1,
      anon_sym_let,
    ACTIONS(15454), 1,
      anon_sym_and,
    STATE(12912), 1,
      sym_attribute,
    STATE(12914), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614515] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15454), 1,
      anon_sym_and,
    ACTIONS(15774), 1,
      anon_sym_let,
    STATE(12913), 1,
      sym_attribute,
    STATE(12914), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614551] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15098), 1,
      anon_sym_let,
    ACTIONS(15830), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12914), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(15096), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614585] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15454), 1,
      anon_sym_and,
    ACTIONS(15774), 1,
      anon_sym_let,
    STATE(12915), 1,
      sym_attribute,
    STATE(12916), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614621] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15454), 1,
      anon_sym_and,
    ACTIONS(15781), 1,
      anon_sym_let,
    STATE(12914), 1,
      aux_sym_module_definition_repeat1,
    STATE(12916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15779), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614657] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15454), 1,
      anon_sym_and,
    ACTIONS(15828), 1,
      anon_sym_let,
    STATE(12912), 1,
      aux_sym_module_definition_repeat1,
    STATE(12917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15826), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [614693] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10335), 1,
      anon_sym_PIPE,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    ACTIONS(15563), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15565), 1,
      sym_pow_operator,
    ACTIONS(15567), 1,
      sym_mult_operator,
    ACTIONS(15569), 1,
      sym_concat_operator,
    ACTIONS(15571), 1,
      sym_rel_operator,
    ACTIONS(15573), 1,
      sym_and_operator,
    ACTIONS(15575), 1,
      sym_or_operator,
    ACTIONS(15577), 1,
      sym_assign_operator,
    STATE(2165), 1,
      sym_add_operator,
    STATE(12918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [614747] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(12919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [614794] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [614829] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [614872] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [614915] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [614962] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [615009] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615060] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15849), 1,
      sym_mult_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [615097] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [615148] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12037), 1,
      anon_sym_COLON2,
    STATE(12928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [615181] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(15863), 1,
      anon_sym_RBRACK,
    ACTIONS(15865), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12929), 1,
      sym_attribute,
    STATE(16466), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615236] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15867), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(12930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [615271] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15871), 1,
      anon_sym_SEMI,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(12931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615324] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(12932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [615375] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_with,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15891), 1,
      anon_sym_SEMI,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    ACTIONS(15907), 1,
      sym_assign_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(12933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615430] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15911), 1,
      anon_sym_SEMI,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15915), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12934), 1,
      sym_attribute,
    STATE(16489), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615485] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    STATE(12935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [615518] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8342), 1,
      anon_sym_let,
    STATE(12936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [615549] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(12937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [615596] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(12938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [615643] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15931), 1,
      anon_sym_DQUOTE,
    STATE(12939), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18922), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [615684] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(12940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615735] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(12941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [615772] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(12942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [615823] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_and,
    STATE(12943), 1,
      sym_attribute,
    STATE(13200), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [615856] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15943), 1,
      anon_sym_SEMI,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(12944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615909] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(15961), 1,
      anon_sym_RBRACK,
    ACTIONS(15963), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12945), 1,
      sym_attribute,
    STATE(15935), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [615964] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15965), 1,
      anon_sym_DQUOTE,
    STATE(12946), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20249), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [616005] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(15967), 1,
      anon_sym_SEMI,
    ACTIONS(15969), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12947), 1,
      sym_attribute,
    STATE(16120), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616060] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_and,
    STATE(12943), 1,
      aux_sym_type_definition_repeat1,
    STATE(12948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [616093] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15971), 1,
      anon_sym_DQUOTE,
    STATE(12949), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20133), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [616134] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(15973), 1,
      anon_sym_RBRACK,
    ACTIONS(15975), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12950), 1,
      sym_attribute,
    STATE(16705), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616189] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11531), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11533), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [616220] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15977), 1,
      anon_sym_and,
    STATE(12952), 1,
      sym_attribute,
    STATE(13095), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [616253] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15943), 1,
      anon_sym_SEMI,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(12953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616306] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(15979), 1,
      anon_sym_SEMI,
    ACTIONS(15981), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12954), 1,
      sym_attribute,
    STATE(16728), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616361] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(15983), 1,
      anon_sym_RBRACK,
    ACTIONS(15985), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12955), 1,
      sym_attribute,
    STATE(16763), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616416] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8306), 1,
      anon_sym_let,
    STATE(12956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [616447] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15987), 1,
      anon_sym_DQUOTE,
    STATE(12957), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18472), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [616488] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15989), 1,
      anon_sym_DQUOTE,
    STATE(12958), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18851), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [616529] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(15991), 1,
      anon_sym_SEMI,
    ACTIONS(15993), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12959), 1,
      sym_attribute,
    STATE(16823), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616584] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15995), 1,
      anon_sym_PIPE,
    STATE(12960), 1,
      sym_attribute,
    STATE(12962), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616619] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15995), 1,
      anon_sym_PIPE,
    STATE(12961), 1,
      sym_attribute,
    STATE(12963), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616654] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15995), 1,
      anon_sym_PIPE,
    STATE(12962), 1,
      sym_attribute,
    STATE(12964), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616689] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15995), 1,
      anon_sym_PIPE,
    STATE(12963), 1,
      sym_attribute,
    STATE(12964), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616724] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15997), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12964), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [616757] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16000), 1,
      anon_sym_DQUOTE,
    STATE(12965), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19008), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [616798] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16002), 1,
      anon_sym_RBRACK,
    ACTIONS(16004), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12966), 1,
      sym_attribute,
    STATE(16886), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616853] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16006), 1,
      anon_sym_SEMI,
    ACTIONS(16008), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12967), 1,
      sym_attribute,
    STATE(16919), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616908] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16012), 1,
      anon_sym_SEMI,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(12968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [616961] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8352), 1,
      anon_sym_let,
    STATE(12969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [616992] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8356), 1,
      anon_sym_let,
    STATE(12970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [617023] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11589), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [617054] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16030), 1,
      anon_sym_DQUOTE,
    STATE(12972), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19815), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [617095] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16032), 1,
      anon_sym_RBRACK,
    ACTIONS(16034), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12973), 1,
      sym_attribute,
    STATE(17180), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617150] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16036), 1,
      anon_sym_DQUOTE,
    STATE(12974), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18510), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [617191] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8212), 1,
      anon_sym_let,
    STATE(12975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8214), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [617222] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16038), 1,
      anon_sym_RBRACK,
    ACTIONS(16040), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12976), 1,
      sym_attribute,
    STATE(16243), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617277] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16042), 1,
      anon_sym_SEMI,
    ACTIONS(16044), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12977), 1,
      sym_attribute,
    STATE(16262), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617332] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16046), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(12978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [617367] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16048), 1,
      anon_sym_SEMI,
    ACTIONS(16050), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12979), 1,
      sym_attribute,
    STATE(15917), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11495), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11497), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [617453] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16012), 1,
      anon_sym_SEMI,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(12981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617506] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    STATE(12982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [617539] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16052), 1,
      anon_sym_PIPE,
    STATE(12983), 1,
      sym_attribute,
    STATE(13057), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [617574] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16054), 1,
      anon_sym_RBRACK,
    ACTIONS(16056), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12984), 1,
      sym_attribute,
    STATE(16207), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617629] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8310), 1,
      anon_sym_let,
    STATE(12985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [617660] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16012), 1,
      anon_sym_SEMI,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(12986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617713] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_end,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16060), 1,
      anon_sym_SEMI,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    ACTIONS(16076), 1,
      sym_assign_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(12987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617768] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8314), 1,
      anon_sym_let,
    STATE(12988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [617799] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_then,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16080), 1,
      anon_sym_SEMI,
    ACTIONS(16082), 1,
      sym_or_operator,
    ACTIONS(16084), 1,
      sym_assign_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(12989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617854] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16086), 1,
      anon_sym_DQUOTE,
    STATE(12990), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21047), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [617895] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16088), 1,
      anon_sym_RBRACK,
    ACTIONS(16090), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12991), 1,
      sym_attribute,
    STATE(15986), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [617950] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16092), 1,
      anon_sym_DQUOTE,
    STATE(12992), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18836), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [617991] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16094), 1,
      anon_sym_SEMI,
    ACTIONS(16096), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12993), 1,
      sym_attribute,
    STATE(15993), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618046] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16098), 1,
      anon_sym_SEMI,
    ACTIONS(16100), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(12994), 1,
      sym_attribute,
    STATE(16313), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618101] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16102), 1,
      anon_sym_RBRACK,
    ACTIONS(16104), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12995), 1,
      sym_attribute,
    STATE(16116), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618156] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16106), 1,
      anon_sym_PIPE,
    STATE(12996), 1,
      sym_attribute,
    STATE(13279), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618191] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16108), 1,
      anon_sym_RBRACK,
    ACTIONS(16110), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12997), 1,
      sym_attribute,
    STATE(16015), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618246] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_done,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16114), 1,
      anon_sym_SEMI,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(12998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618301] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16132), 1,
      anon_sym_RBRACK,
    ACTIONS(16134), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(12999), 1,
      sym_attribute,
    STATE(16523), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618356] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8318), 1,
      anon_sym_let,
    STATE(13000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [618387] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [618438] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16136), 1,
      anon_sym_SEMI,
    ACTIONS(16138), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13002), 1,
      sym_attribute,
    STATE(16039), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618493] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16140), 1,
      anon_sym_SEMI,
    ACTIONS(16142), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13003), 1,
      sym_attribute,
    STATE(16162), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618548] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16144), 1,
      anon_sym_DQUOTE,
    STATE(13004), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18649), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [618589] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618622] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16146), 1,
      anon_sym_PIPE,
    STATE(13006), 1,
      sym_attribute,
    STATE(13008), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618657] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16146), 1,
      anon_sym_PIPE,
    STATE(13007), 1,
      sym_attribute,
    STATE(13009), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618692] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16146), 1,
      anon_sym_PIPE,
    STATE(13008), 1,
      sym_attribute,
    STATE(13010), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618727] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16146), 1,
      anon_sym_PIPE,
    STATE(13009), 1,
      sym_attribute,
    STATE(13010), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618762] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16148), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13010), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618795] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16151), 1,
      anon_sym_RBRACK,
    ACTIONS(16153), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13011), 1,
      sym_attribute,
    STATE(16059), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618850] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16155), 1,
      anon_sym_SEMI,
    ACTIONS(16157), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13012), 1,
      sym_attribute,
    STATE(16070), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [618905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11523), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11525), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [618936] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16159), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [618971] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15977), 1,
      anon_sym_and,
    STATE(12952), 1,
      aux_sym_module_definition_repeat1,
    STATE(13015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [619004] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    ACTIONS(16161), 1,
      anon_sym_SEMI,
    STATE(2345), 1,
      sym_add_operator,
    STATE(13016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619057] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_done,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619108] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [619149] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16163), 1,
      anon_sym_DQUOTE,
    STATE(13019), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18958), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [619190] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8322), 1,
      anon_sym_let,
    STATE(13020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [619221] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    STATE(13021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [619254] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16052), 1,
      anon_sym_PIPE,
    STATE(13022), 1,
      sym_attribute,
    STATE(13078), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [619289] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10383), 1,
      anon_sym_as,
    ACTIONS(15340), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16165), 1,
      anon_sym_DASH_GT,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(13023), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 8,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
      anon_sym_AMP,
  [619334] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8068), 1,
      anon_sym_let,
    STATE(13024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [619365] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16169), 1,
      anon_sym_DQUOTE,
    STATE(13025), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21027), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [619406] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16171), 1,
      anon_sym_DQUOTE,
    STATE(13026), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18940), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [619447] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16173), 1,
      anon_sym_RBRACK,
    ACTIONS(16175), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13027), 1,
      sym_attribute,
    STATE(16138), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619502] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_then,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16080), 1,
      anon_sym_SEMI,
    ACTIONS(16082), 1,
      sym_or_operator,
    ACTIONS(16084), 1,
      sym_assign_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619557] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16177), 1,
      anon_sym_SEMI,
    ACTIONS(16179), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13029), 1,
      sym_attribute,
    STATE(16144), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619612] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    ACTIONS(16181), 1,
      anon_sym_SEMI,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8072), 1,
      anon_sym_let,
    STATE(13031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [619696] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16183), 1,
      anon_sym_DQUOTE,
    STATE(13032), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20816), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [619737] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16185), 1,
      anon_sym_RBRACK,
    ACTIONS(16187), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13033), 1,
      sym_attribute,
    STATE(16507), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619792] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [619825] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16189), 1,
      anon_sym_SEMI,
    ACTIONS(16191), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13035), 1,
      sym_attribute,
    STATE(16550), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619880] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_do,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16195), 1,
      anon_sym_SEMI,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    ACTIONS(16211), 1,
      sym_assign_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [619935] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16118), 1,
      sym_pow_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [619970] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16118), 1,
      sym_pow_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [620005] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16213), 1,
      anon_sym_RBRACK,
    ACTIONS(16215), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13039), 1,
      sym_attribute,
    STATE(16397), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620060] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [620103] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_rel_operator,
      sym_assign_operator,
  [620146] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_assign_operator,
  [620193] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_done,
      sym_assign_operator,
  [620242] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620295] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16217), 1,
      anon_sym_DQUOTE,
    STATE(13045), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19366), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [620336] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620373] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620426] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16219), 1,
      anon_sym_PIPE,
    STATE(13048), 1,
      sym_attribute,
    STATE(13050), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620461] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16219), 1,
      anon_sym_PIPE,
    STATE(13049), 1,
      sym_attribute,
    STATE(13051), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620496] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16219), 1,
      anon_sym_PIPE,
    STATE(13050), 1,
      sym_attribute,
    STATE(13052), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620531] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16219), 1,
      anon_sym_PIPE,
    STATE(13051), 1,
      sym_attribute,
    STATE(13052), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620566] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16221), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13052), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620599] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16224), 1,
      anon_sym_RBRACK,
    ACTIONS(16226), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13053), 1,
      sym_attribute,
    STATE(16233), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620654] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16228), 1,
      anon_sym_SEMI,
    ACTIONS(16230), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13054), 1,
      sym_attribute,
    STATE(16241), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620709] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16232), 1,
      anon_sym_SEMI,
    ACTIONS(16234), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13055), 1,
      sym_attribute,
    STATE(16400), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620764] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_do,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16195), 1,
      anon_sym_SEMI,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    ACTIONS(16211), 1,
      sym_assign_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620819] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16052), 1,
      anon_sym_PIPE,
    STATE(13057), 1,
      sym_attribute,
    STATE(13078), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620854] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16236), 1,
      anon_sym_COLON2,
    STATE(13058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [620887] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10283), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10281), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [620918] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16238), 1,
      anon_sym_RBRACK,
    ACTIONS(16240), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13060), 1,
      sym_attribute,
    STATE(16363), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [620973] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_and,
    STATE(13061), 1,
      sym_attribute,
    STATE(13200), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [621006] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16242), 1,
      anon_sym_SEMI,
    ACTIONS(16244), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13062), 1,
      sym_attribute,
    STATE(16033), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [621061] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16246), 1,
      anon_sym_DQUOTE,
    STATE(13063), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19714), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621102] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15943), 1,
      anon_sym_SEMI,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10327), 2,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [621155] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11551), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11553), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [621186] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16248), 1,
      anon_sym_DQUOTE,
    STATE(13066), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18861), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621227] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16250), 1,
      anon_sym_RBRACK,
    ACTIONS(16252), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13067), 1,
      sym_attribute,
    STATE(16850), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [621282] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16254), 1,
      anon_sym_DQUOTE,
    STATE(13068), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19894), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621323] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16256), 1,
      anon_sym_SEMI,
    ACTIONS(16258), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13069), 1,
      sym_attribute,
    STATE(16890), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [621378] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_do,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16195), 1,
      anon_sym_SEMI,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    ACTIONS(16211), 1,
      sym_assign_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [621433] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16260), 1,
      anon_sym_DQUOTE,
    STATE(13071), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20003), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621474] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10287), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [621505] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16262), 1,
      anon_sym_DQUOTE,
    STATE(13073), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20026), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621546] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16264), 1,
      anon_sym_DQUOTE,
    STATE(13074), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20048), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621587] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16266), 1,
      anon_sym_DQUOTE,
    STATE(13075), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20076), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621628] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16268), 1,
      anon_sym_DQUOTE,
    STATE(13076), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20106), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621669] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16270), 1,
      anon_sym_DQUOTE,
    STATE(13077), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20144), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621710] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16272), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13078), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [621743] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16275), 1,
      anon_sym_DQUOTE,
    STATE(13079), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20182), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621784] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10391), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10389), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [621815] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10279), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10277), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [621846] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16277), 1,
      anon_sym_DQUOTE,
    STATE(13082), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20229), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621887] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_done,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [621940] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16279), 1,
      anon_sym_DQUOTE,
    STATE(13084), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20270), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [621981] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16281), 1,
      anon_sym_DQUOTE,
    STATE(13085), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20325), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622022] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16283), 1,
      anon_sym_DQUOTE,
    STATE(13086), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20369), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622063] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16285), 1,
      anon_sym_DQUOTE,
    STATE(13087), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20419), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622104] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16287), 1,
      anon_sym_DQUOTE,
    STATE(13088), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20465), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622145] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16289), 1,
      anon_sym_RBRACK,
    ACTIONS(16291), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13089), 1,
      sym_attribute,
    STATE(16781), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [622200] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [622233] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16293), 1,
      anon_sym_DQUOTE,
    STATE(13091), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21331), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622274] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16295), 1,
      anon_sym_SEMI,
    ACTIONS(16297), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13092), 1,
      sym_attribute,
    STATE(17003), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [622329] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_and,
    STATE(13093), 1,
      sym_attribute,
    STATE(13177), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15766), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622362] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16299), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [622397] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16301), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13095), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(15096), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622428] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16304), 1,
      anon_sym_COLON_GT,
    ACTIONS(16306), 1,
      anon_sym_EQ,
    ACTIONS(16308), 1,
      anon_sym_COLON2,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13096), 1,
      sym_attribute,
    STATE(13603), 1,
      sym__typed,
    STATE(13807), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16310), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622471] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16312), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [622506] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16314), 1,
      anon_sym_RBRACK,
    ACTIONS(16316), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13098), 1,
      sym_attribute,
    STATE(15987), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [622561] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16318), 1,
      anon_sym_SEMI,
    ACTIONS(16320), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13099), 1,
      sym_attribute,
    STATE(16119), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [622616] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [622649] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16322), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [622684] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15871), 1,
      anon_sym_SEMI,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [622737] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
  [622788] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16324), 1,
      anon_sym_DQUOTE,
    STATE(13104), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19313), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622829] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16326), 1,
      anon_sym_DQUOTE,
    STATE(13105), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19978), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [622870] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16328), 1,
      anon_sym_SEMI_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13106), 2,
      sym_attribute,
      aux_sym__structure_repeat1,
    ACTIONS(8989), 14,
      ts_builtin_sym_end,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622901] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16331), 1,
      anon_sym_RBRACK,
    ACTIONS(16333), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13107), 1,
      sym_attribute,
    STATE(17158), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [622956] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15977), 1,
      anon_sym_and,
    STATE(13108), 1,
      sym_attribute,
    STATE(13269), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [622989] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [623038] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_with,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15891), 1,
      anon_sym_SEMI,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    ACTIONS(15907), 1,
      sym_assign_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [623093] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623126] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623167] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16016), 1,
      sym_pow_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623202] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16016), 1,
      sym_pow_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623237] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [623280] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623313] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11577), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [623344] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16335), 1,
      anon_sym_SEMI,
    ACTIONS(16337), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13118), 1,
      sym_attribute,
    STATE(17181), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [623399] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16339), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623434] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11499), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11501), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [623465] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    ACTIONS(16181), 1,
      anon_sym_SEMI,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [623518] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16341), 1,
      anon_sym_RBRACK,
    ACTIONS(16343), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13122), 1,
      sym_attribute,
    STATE(16468), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [623573] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11503), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11505), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [623604] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11491), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11493), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [623635] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_then,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16080), 1,
      anon_sym_SEMI,
    ACTIONS(16082), 1,
      sym_or_operator,
    ACTIONS(16084), 1,
      sym_assign_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [623690] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [623739] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623780] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15947), 1,
      sym_pow_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623815] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15947), 1,
      sym_pow_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [623850] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [623893] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [623936] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [623983] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
      sym_assign_operator,
  [624030] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [624081] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [624118] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    ACTIONS(16076), 1,
      sym_assign_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [624171] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [624214] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [624261] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_done,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16114), 1,
      anon_sym_SEMI,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [624316] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16345), 1,
      anon_sym_and,
    STATE(13140), 1,
      sym_attribute,
    STATE(13168), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15579), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624349] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [624400] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16159), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [624435] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [624486] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16082), 1,
      sym_or_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [624537] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      sym_assign_operator,
  [624584] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11160), 1,
      anon_sym_as,
    ACTIONS(15340), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16347), 1,
      anon_sym_STAR,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(13146), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_GT,
      anon_sym_AMP,
  [624627] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11507), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11509), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [624658] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16349), 1,
      anon_sym_PIPE,
    STATE(13148), 1,
      sym_attribute,
    STATE(13158), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [624693] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11511), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11513), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [624724] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16351), 1,
      anon_sym_SEMI,
    ACTIONS(16353), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13150), 1,
      sym_attribute,
    STATE(16474), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [624779] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [624820] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16308), 1,
      anon_sym_COLON2,
    ACTIONS(16355), 1,
      anon_sym_COLON_GT,
    ACTIONS(16357), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13152), 1,
      sym_attribute,
    STATE(13613), 1,
      sym__typed,
    STATE(13856), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16359), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [624863] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15835), 1,
      sym_pow_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [624898] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16361), 1,
      anon_sym_SEMI,
    ACTIONS(16363), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13154), 1,
      sym_attribute,
    STATE(16755), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [624953] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625004] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16349), 1,
      anon_sym_PIPE,
    STATE(13156), 1,
      sym_attribute,
    STATE(13361), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [625039] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16365), 1,
      anon_sym_DQUOTE,
    STATE(13157), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18676), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [625080] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16349), 1,
      anon_sym_PIPE,
    STATE(13158), 1,
      sym_attribute,
    STATE(13167), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [625115] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15835), 1,
      sym_pow_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [625150] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [625193] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [625236] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    ACTIONS(16161), 1,
      anon_sym_SEMI,
    STATE(2345), 1,
      sym_add_operator,
    STATE(13162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625289] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [625332] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16082), 1,
      sym_or_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [625381] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16082), 1,
      sym_or_operator,
    ACTIONS(16084), 1,
      sym_assign_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625434] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16367), 1,
      anon_sym_RBRACK,
    ACTIONS(16369), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13166), 1,
      sym_attribute,
    STATE(16327), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625489] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16371), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13167), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [625522] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16345), 1,
      anon_sym_and,
    STATE(13168), 1,
      sym_attribute,
    STATE(13295), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625555] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [625592] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16374), 1,
      anon_sym_SEMI,
    ACTIONS(16376), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13170), 1,
      sym_attribute,
    STATE(16339), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625647] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16345), 1,
      anon_sym_and,
    STATE(13171), 1,
      sym_attribute,
    STATE(13296), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625680] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [625717] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16082), 1,
      sym_or_operator,
    ACTIONS(16084), 1,
      sym_assign_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625770] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10261), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [625821] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    STATE(13175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_to,
      anon_sym_downto,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [625854] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    ACTIONS(15861), 1,
      sym_assign_operator,
    ACTIONS(16181), 1,
      anon_sym_SEMI,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_with,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [625907] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_and,
    STATE(13177), 1,
      sym_attribute,
    STATE(13200), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [625940] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16378), 1,
      anon_sym_DQUOTE,
    STATE(13178), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19919), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [625981] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626032] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [626073] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15977), 1,
      anon_sym_and,
    STATE(13095), 1,
      aux_sym_module_definition_repeat1,
    STATE(13181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626106] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15917), 1,
      sym_pow_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [626141] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11559), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11561), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [626172] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15917), 1,
      sym_pow_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [626207] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_rel_operator,
      sym_assign_operator,
  [626250] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_rel_operator,
      sym_assign_operator,
  [626293] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_assign_operator,
  [626340] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
      sym_assign_operator,
  [626389] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626442] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [626479] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626532] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16339), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [626567] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_with,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15891), 1,
      anon_sym_SEMI,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    ACTIONS(15907), 1,
      sym_assign_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626622] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16380), 1,
      anon_sym_RBRACK,
    ACTIONS(16382), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13194), 1,
      sym_attribute,
    STATE(16562), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626677] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [626728] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626781] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11563), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11565), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [626812] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15833), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15835), 1,
      sym_pow_operator,
    ACTIONS(15837), 1,
      sym_mult_operator,
    ACTIONS(15839), 1,
      sym_concat_operator,
    ACTIONS(15841), 1,
      sym_rel_operator,
    ACTIONS(15843), 1,
      sym_and_operator,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    ACTIONS(16082), 1,
      sym_or_operator,
    ACTIONS(16084), 1,
      sym_assign_operator,
    STATE(1828), 1,
      sym_add_operator,
    STATE(13198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [626865] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    STATE(13199), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10950), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [626904] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16386), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13200), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(15030), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [626935] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16389), 1,
      anon_sym_DQUOTE,
    STATE(13201), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19654), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [626976] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16391), 1,
      anon_sym_SEMI,
    ACTIONS(16393), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13202), 1,
      sym_attribute,
    STATE(16734), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627031] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11567), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11569), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [627062] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16395), 1,
      anon_sym_RBRACK,
    ACTIONS(16397), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13204), 1,
      sym_attribute,
    STATE(16552), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627117] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16399), 1,
      anon_sym_SEMI,
    ACTIONS(16401), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13205), 1,
      sym_attribute,
    STATE(16563), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627172] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10271), 3,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
  [627223] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15871), 1,
      anon_sym_SEMI,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    ACTIONS(15887), 1,
      sym_assign_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9030), 2,
      anon_sym_then,
      anon_sym_else,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627276] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16403), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [627311] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16405), 1,
      anon_sym_DQUOTE,
    STATE(13209), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19223), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [627352] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16299), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [627387] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    ACTIONS(15945), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15947), 1,
      sym_pow_operator,
    ACTIONS(15949), 1,
      sym_mult_operator,
    ACTIONS(15951), 1,
      sym_concat_operator,
    ACTIONS(15953), 1,
      sym_rel_operator,
    ACTIONS(15955), 1,
      sym_and_operator,
    ACTIONS(15957), 1,
      sym_or_operator,
    ACTIONS(15959), 1,
      sym_assign_operator,
    STATE(1986), 1,
      sym_add_operator,
    STATE(13211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_else,
  [627438] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627489] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [627522] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16407), 1,
      anon_sym_SEMI,
    ACTIONS(16409), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13214), 1,
      sym_attribute,
    STATE(15996), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627577] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [627610] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11555), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11557), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [627641] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16411), 1,
      anon_sym_SEMI,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627696] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16411), 1,
      anon_sym_SEMI,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [627751] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    ACTIONS(16014), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16016), 1,
      sym_pow_operator,
    ACTIONS(16018), 1,
      sym_mult_operator,
    ACTIONS(16020), 1,
      sym_concat_operator,
    ACTIONS(16022), 1,
      sym_rel_operator,
    ACTIONS(16024), 1,
      sym_and_operator,
    ACTIONS(16026), 1,
      sym_or_operator,
    ACTIONS(16028), 1,
      sym_assign_operator,
    STATE(1905), 1,
      sym_add_operator,
    STATE(13219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10333), 3,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [627802] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [627843] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16199), 1,
      sym_pow_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [627878] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15867), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [627913] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16413), 1,
      anon_sym_DQUOTE,
    STATE(13223), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21316), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [627954] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16415), 1,
      anon_sym_let,
    STATE(13224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10616), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [627985] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11571), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11573), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628016] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    ACTIONS(15593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15595), 1,
      sym_pow_operator,
    ACTIONS(15597), 1,
      sym_mult_operator,
    ACTIONS(15599), 1,
      sym_concat_operator,
    ACTIONS(15601), 1,
      sym_rel_operator,
    ACTIONS(15603), 1,
      sym_and_operator,
    ACTIONS(15605), 1,
      sym_or_operator,
    ACTIONS(15607), 1,
      sym_assign_operator,
    ACTIONS(16161), 1,
      anon_sym_SEMI,
    STATE(2345), 1,
      sym_add_operator,
    STATE(13226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9050), 2,
      anon_sym_to,
      anon_sym_downto,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [628069] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16417), 1,
      anon_sym_RBRACK,
    ACTIONS(16419), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13227), 1,
      sym_attribute,
    STATE(16469), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [628124] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16199), 1,
      sym_pow_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [628159] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [628202] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [628245] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [628292] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11487), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11489), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628323] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [628372] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    ACTIONS(16211), 1,
      sym_assign_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [628425] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [628462] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    ACTIONS(16211), 1,
      sym_assign_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [628515] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16308), 1,
      anon_sym_COLON2,
    ACTIONS(16421), 1,
      anon_sym_COLON_GT,
    ACTIONS(16423), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13237), 1,
      sym_attribute,
    STATE(13615), 1,
      sym__typed,
    STATE(13911), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16425), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628558] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15977), 1,
      anon_sym_and,
    STATE(13181), 1,
      aux_sym_module_definition_repeat1,
    STATE(13238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15826), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [628591] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16427), 1,
      anon_sym_DQUOTE,
    STATE(13239), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20154), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [628632] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    STATE(13240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [628665] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16431), 1,
      anon_sym_let,
    STATE(13241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16429), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [628696] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11483), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11485), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [628727] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16433), 1,
      anon_sym_DQUOTE,
    STATE(13243), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19669), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [628768] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16435), 1,
      anon_sym_DQUOTE,
    STATE(13244), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19023), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [628809] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16437), 1,
      anon_sym_RBRACK,
    ACTIONS(16439), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13245), 1,
      sym_attribute,
    STATE(15994), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [628864] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16441), 1,
      anon_sym_RBRACK,
    ACTIONS(16443), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13246), 1,
      sym_attribute,
    STATE(16719), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [628919] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16403), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [628954] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_end,
    ACTIONS(9052), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16060), 1,
      anon_sym_SEMI,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    ACTIONS(16076), 1,
      sym_assign_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629009] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16445), 1,
      anon_sym_DQUOTE,
    STATE(13249), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21130), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [629050] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    ACTIONS(16197), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16199), 1,
      sym_pow_operator,
    ACTIONS(16201), 1,
      sym_mult_operator,
    ACTIONS(16203), 1,
      sym_concat_operator,
    ACTIONS(16205), 1,
      sym_rel_operator,
    ACTIONS(16207), 1,
      sym_and_operator,
    ACTIONS(16209), 1,
      sym_or_operator,
    ACTIONS(16211), 1,
      sym_assign_operator,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629103] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16447), 1,
      anon_sym_SEMI,
    ACTIONS(16449), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13251), 1,
      sym_attribute,
    STATE(16723), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629158] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16451), 1,
      anon_sym_RBRACK,
    ACTIONS(16453), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13252), 1,
      sym_attribute,
    STATE(16575), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629213] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16455), 1,
      anon_sym_SEMI,
    ACTIONS(16457), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13253), 1,
      sym_attribute,
    STATE(16007), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629268] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16459), 1,
      anon_sym_SEMI,
    ACTIONS(16461), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13254), 1,
      sym_attribute,
    STATE(16585), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629323] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16463), 1,
      anon_sym_SEMI,
    ACTIONS(16465), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13255), 1,
      sym_attribute,
    STATE(16499), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629378] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_done,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16114), 1,
      anon_sym_SEMI,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629433] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(1842), 1,
      sym_add_operator,
    STATE(13257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [629466] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16467), 1,
      anon_sym_RBRACK,
    ACTIONS(16469), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13258), 1,
      sym_attribute,
    STATE(17146), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629521] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15939), 1,
      anon_sym_and,
    STATE(13061), 1,
      aux_sym_type_definition_repeat1,
    STATE(13259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [629554] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16471), 1,
      anon_sym_DQUOTE,
    STATE(13260), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19226), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [629595] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16473), 1,
      anon_sym_DQUOTE,
    STATE(13261), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20860), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [629636] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11543), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11545), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629667] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    STATE(13263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [629700] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11535), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11537), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629731] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16475), 1,
      anon_sym_SEMI,
    ACTIONS(16477), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13265), 1,
      sym_attribute,
    STATE(17153), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629786] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16479), 1,
      anon_sym_RBRACK,
    ACTIONS(16481), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13266), 1,
      sym_attribute,
    STATE(15946), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [629841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11539), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11541), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [629872] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16483), 1,
      anon_sym_DQUOTE,
    STATE(13268), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21172), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [629913] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15977), 1,
      anon_sym_and,
    STATE(13095), 1,
      aux_sym_module_definition_repeat1,
    STATE(13269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15779), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [629946] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [629979] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16485), 1,
      anon_sym_SEMI,
    ACTIONS(16487), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13271), 1,
      sym_attribute,
    STATE(15955), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [630034] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16489), 1,
      anon_sym_RBRACK,
    ACTIONS(16491), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13272), 1,
      sym_attribute,
    STATE(17043), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [630089] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13584), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13586), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    STATE(13273), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
    ACTIONS(10776), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [630128] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    ACTIONS(15881), 1,
      sym_rel_operator,
    ACTIONS(15883), 1,
      sym_and_operator,
    ACTIONS(15885), 1,
      sym_or_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_assign_operator,
  [630177] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16493), 1,
      anon_sym_RBRACK,
    ACTIONS(16495), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13275), 1,
      sym_attribute,
    STATE(16939), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [630232] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11481), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [630263] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16052), 1,
      anon_sym_PIPE,
    STATE(13022), 1,
      aux_sym__match_cases_repeat1,
    STATE(13277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10375), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10373), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [630298] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16106), 1,
      anon_sym_PIPE,
    STATE(13278), 1,
      sym_attribute,
    STATE(13339), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [630333] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16106), 1,
      anon_sym_PIPE,
    STATE(13279), 1,
      sym_attribute,
    STATE(13342), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10349), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10347), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [630368] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [630419] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8216), 1,
      anon_sym_let,
    STATE(13281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8218), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [630450] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [630491] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16497), 1,
      anon_sym_DQUOTE,
    STATE(13283), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20376), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [630532] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15895), 1,
      sym_pow_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [630567] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15895), 1,
      sym_pow_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [630602] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [630645] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [630688] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16499), 1,
      anon_sym_RBRACK,
    ACTIONS(16501), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13288), 1,
      sym_attribute,
    STATE(16790), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [630743] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13674), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13691), 1,
      anon_sym_STAR,
    STATE(13289), 1,
      sym_attribute,
    STATE(13291), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [630778] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [630825] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12213), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16503), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13291), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(12211), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [630858] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11527), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11529), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [630889] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16506), 1,
      anon_sym_SEMI,
    ACTIONS(16508), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13293), 1,
      sym_attribute,
    STATE(17120), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [630944] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [630993] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16510), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13295), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(15173), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [631024] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16345), 1,
      anon_sym_and,
    STATE(13295), 1,
      aux_sym_class_definition_repeat1,
    STATE(13296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15677), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [631057] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_end,
    ACTIONS(9032), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16060), 1,
      anon_sym_SEMI,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    ACTIONS(16076), 1,
      sym_assign_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631112] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16513), 1,
      anon_sym_SEMI,
    ACTIONS(16515), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13298), 1,
      sym_attribute,
    STATE(16796), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631167] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    ACTIONS(15907), 1,
      sym_assign_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631220] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [631257] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16322), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [631292] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16519), 1,
      anon_sym_let,
    ACTIONS(16521), 1,
      anon_sym_in,
    STATE(13302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16517), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [631325] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16523), 1,
      anon_sym_DQUOTE,
    STATE(13303), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(18684), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [631366] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    ACTIONS(15907), 1,
      sym_assign_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631419] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16519), 1,
      anon_sym_let,
    STATE(13305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16517), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [631450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11547), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11549), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [631481] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16525), 1,
      anon_sym_RBRACK,
    ACTIONS(16527), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13307), 1,
      sym_attribute,
    STATE(17142), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631536] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16529), 1,
      anon_sym_DQUOTE,
    STATE(13308), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19132), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [631577] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16531), 1,
      anon_sym_DQUOTE,
    STATE(13309), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20173), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [631618] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10273), 1,
      anon_sym_PIPE,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    ACTIONS(15893), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15895), 1,
      sym_pow_operator,
    ACTIONS(15897), 1,
      sym_mult_operator,
    ACTIONS(15899), 1,
      sym_concat_operator,
    ACTIONS(15901), 1,
      sym_rel_operator,
    ACTIONS(15903), 1,
      sym_and_operator,
    ACTIONS(15905), 1,
      sym_or_operator,
    ACTIONS(15907), 1,
      sym_assign_operator,
    STATE(1855), 1,
      sym_add_operator,
    STATE(13310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631671] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [631712] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16533), 1,
      anon_sym_SEMI,
    ACTIONS(16535), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13312), 1,
      sym_attribute,
    STATE(15916), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631767] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16537), 1,
      anon_sym_RBRACK,
    ACTIONS(16539), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13313), 1,
      sym_attribute,
    STATE(16134), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631822] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16541), 1,
      anon_sym_SEMI,
    ACTIONS(16543), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13314), 1,
      sym_attribute,
    STATE(16148), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631877] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16545), 1,
      anon_sym_DQUOTE,
    STATE(13315), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20629), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [631918] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16547), 1,
      anon_sym_RBRACK,
    ACTIONS(16549), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13316), 1,
      sym_attribute,
    STATE(16898), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [631973] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13030), 1,
      anon_sym_DASH_GT,
    STATE(13317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [632006] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16551), 1,
      anon_sym_SEMI,
    ACTIONS(16553), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13318), 1,
      sym_attribute,
    STATE(16914), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [632061] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16555), 1,
      anon_sym_SEMI,
    ACTIONS(16557), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13319), 1,
      sym_attribute,
    STATE(15941), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [632116] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    ACTIONS(15851), 1,
      sym_concat_operator,
    ACTIONS(15853), 1,
      sym_rel_operator,
    ACTIONS(15855), 1,
      sym_and_operator,
    ACTIONS(15857), 1,
      sym_or_operator,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10131), 4,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_assign_operator,
  [632165] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    ACTIONS(15847), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15849), 1,
      sym_mult_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632206] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16559), 1,
      anon_sym_DQUOTE,
    STATE(13322), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20765), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [632247] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(15460), 1,
      anon_sym_let,
    STATE(13323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15458), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [632278] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16561), 1,
      anon_sym_RBRACK,
    ACTIONS(16563), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13324), 1,
      sym_attribute,
    STATE(16945), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [632333] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15845), 1,
      sym_pow_operator,
    STATE(1953), 1,
      sym_add_operator,
    STATE(13325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632368] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15875), 1,
      sym_pow_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632403] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    STATE(13327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632436] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16312), 1,
      anon_sym_else,
    STATE(8433), 1,
      sym_else_clause,
    STATE(13328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10317), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10315), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632471] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16565), 1,
      anon_sym_DQUOTE,
    STATE(13329), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(21415), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [632512] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10133), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [632563] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16567), 1,
      anon_sym_SEMI,
    ACTIONS(16569), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13331), 1,
      sym_attribute,
    STATE(16966), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [632618] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16046), 1,
      anon_sym_else,
    STATE(8189), 1,
      sym_else_clause,
    STATE(13332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10267), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10265), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632653] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10325), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632694] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16519), 1,
      anon_sym_let,
    ACTIONS(16571), 1,
      anon_sym_in,
    STATE(13334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16517), 14,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [632727] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16064), 1,
      sym_pow_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [632762] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16064), 1,
      sym_pow_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10235), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [632797] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [632840] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 3,
      anon_sym_PIPE,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [632883] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16106), 1,
      anon_sym_PIPE,
    STATE(13339), 1,
      sym_attribute,
    STATE(13342), 1,
      aux_sym__match_cases_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [632918] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      anon_sym_PIPE,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [632965] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16573), 1,
      anon_sym_RBRACK,
    ACTIONS(16575), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13341), 1,
      sym_attribute,
    STATE(16036), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633020] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16577), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13342), 2,
      sym_attribute,
      aux_sym__match_cases_repeat1,
    ACTIONS(10287), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10285), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [633053] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16580), 1,
      anon_sym_DQUOTE,
    STATE(13343), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20921), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [633094] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [633143] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    ACTIONS(16076), 1,
      sym_assign_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633196] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11519), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11521), 14,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [633227] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16582), 1,
      anon_sym_DQUOTE,
    STATE(13347), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(20854), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [633268] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16584), 1,
      anon_sym_RBRACK,
    ACTIONS(16586), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13348), 1,
      sym_attribute,
    STATE(16171), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633323] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [633360] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16588), 1,
      anon_sym_SEMI,
    ACTIONS(16590), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13350), 1,
      sym_attribute,
    STATE(16182), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633415] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16592), 1,
      anon_sym_RBRACK,
    ACTIONS(16594), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13351), 1,
      sym_attribute,
    STATE(16387), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633470] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10263), 1,
      anon_sym_PIPE,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    ACTIONS(16062), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16064), 1,
      sym_pow_operator,
    ACTIONS(16066), 1,
      sym_mult_operator,
    ACTIONS(16068), 1,
      sym_concat_operator,
    ACTIONS(16070), 1,
      sym_rel_operator,
    ACTIONS(16072), 1,
      sym_and_operator,
    ACTIONS(16074), 1,
      sym_or_operator,
    ACTIONS(16076), 1,
      sym_assign_operator,
    STATE(1868), 1,
      sym_add_operator,
    STATE(13352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633523] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8330), 1,
      anon_sym_let,
    STATE(13353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [633554] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8338), 1,
      anon_sym_let,
    STATE(13354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [633585] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8280), 1,
      anon_sym_let,
    STATE(13355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 15,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym_let_operator,
      aux_sym_directive_token1,
  [633616] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15875), 1,
      sym_pow_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [633651] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15873), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15875), 1,
      sym_pow_operator,
    ACTIONS(15877), 1,
      sym_mult_operator,
    ACTIONS(15879), 1,
      sym_concat_operator,
    STATE(2426), 1,
      sym_add_operator,
    STATE(13357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      anon_sym_else,
      sym_rel_operator,
      sym_assign_operator,
  [633694] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10329), 1,
      anon_sym_PIPE,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16411), 1,
      anon_sym_SEMI,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633749] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16596), 1,
      anon_sym_DQUOTE,
    STATE(13359), 1,
      sym_attribute,
    STATE(13578), 1,
      aux_sym_string_content_repeat1,
    STATE(13657), 1,
      sym_escape_sequence,
    STATE(19987), 1,
      sym_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [633790] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    ACTIONS(16598), 1,
      anon_sym_SEMI,
    ACTIONS(16600), 1,
      anon_sym_PIPE_RBRACK,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13360), 1,
      sym_attribute,
    STATE(16485), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [633845] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16349), 1,
      anon_sym_PIPE,
    STATE(13167), 1,
      aux_sym__match_cases_repeat1,
    STATE(13361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10355), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10353), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [633880] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16602), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13362), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
    ACTIONS(15096), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [633910] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [633952] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_end,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16615), 1,
      anon_sym_SEMI,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [634004] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_done,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    ACTIONS(16633), 1,
      anon_sym_SEMI,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [634056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11573), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11571), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [634086] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_then,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16637), 1,
      anon_sym_SEMI,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [634138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8288), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [634168] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8292), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [634198] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_with,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16657), 1,
      anon_sym_SEMI,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [634250] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8020), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [634280] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_rel_operator,
      sym_assign_operator,
  [634322] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2659), 1,
      anon_sym_LBRACK,
    ACTIONS(2669), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2681), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16675), 1,
      sym__lowercase_identifier,
    ACTIONS(16677), 1,
      anon_sym_LPAREN,
    ACTIONS(16679), 1,
      anon_sym_LBRACE,
    ACTIONS(16681), 1,
      sym__uppercase_identifier,
    STATE(7218), 1,
      sym__constructor_name,
    STATE(7294), 1,
      sym__value_name,
    STATE(7418), 1,
      sym_parenthesized_operator,
    STATE(13373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7293), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [634370] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [634416] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
  [634462] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    STATE(13376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_done,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [634494] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [634544] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [634580] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(13379), 1,
      sym_attribute,
    STATE(13931), 1,
      sym__simple_class_type,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [634626] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16697), 1,
      sym__lowercase_identifier,
    ACTIONS(16699), 1,
      anon_sym_LPAREN,
    ACTIONS(16701), 1,
      anon_sym_LBRACE,
    ACTIONS(16703), 1,
      sym__uppercase_identifier,
    STATE(7156), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7632), 1,
      sym__value_name,
    STATE(13380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7631), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [634674] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16619), 1,
      sym_pow_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [634708] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [634750] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15754), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(16705), 1,
      anon_sym_nonrec,
    STATE(12875), 1,
      sym_type_binding,
    STATE(13383), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15388), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20072), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [634804] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(16707), 1,
      sym__lowercase_identifier,
    ACTIONS(16709), 1,
      anon_sym_DASH_GT,
    ACTIONS(16711), 1,
      anon_sym_STAR,
    ACTIONS(16713), 1,
      anon_sym_POUND,
    STATE(13384), 1,
      sym_attribute,
    STATE(13680), 1,
      sym_type_constructor_path,
    STATE(17903), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 3,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(10383), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [634848] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_rel_operator,
      sym_assign_operator,
  [634890] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11501), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11499), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [634920] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9052), 1,
      anon_sym_DASH_GT,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16715), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [634972] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [635018] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11521), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11519), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635048] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11589), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11587), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635078] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(8296), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635108] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [635158] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11525), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11523), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635188] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11505), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11503), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11529), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11527), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635248] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [635298] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2357), 1,
      anon_sym_LBRACK,
    ACTIONS(2367), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2379), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16717), 1,
      sym__lowercase_identifier,
    ACTIONS(16719), 1,
      anon_sym_LPAREN,
    ACTIONS(16721), 1,
      anon_sym_LBRACE,
    ACTIONS(16723), 1,
      sym__uppercase_identifier,
    STATE(6633), 1,
      sym__constructor_name,
    STATE(6708), 1,
      sym__value_name,
    STATE(6871), 1,
      sym_parenthesized_operator,
    STATE(13397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6657), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [635346] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9032), 1,
      anon_sym_DASH_GT,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16715), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [635398] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11024), 1,
      sym__simple_class_type,
    STATE(13399), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [635444] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1351), 1,
      anon_sym_LBRACK,
    ACTIONS(1361), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1373), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16725), 1,
      sym__lowercase_identifier,
    ACTIONS(16727), 1,
      anon_sym_LPAREN,
    ACTIONS(16729), 1,
      anon_sym_LBRACE,
    ACTIONS(16731), 1,
      sym__uppercase_identifier,
    STATE(6011), 1,
      sym__constructor_name,
    STATE(6038), 1,
      sym__value_name,
    STATE(6069), 1,
      sym_parenthesized_operator,
    STATE(13400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6054), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [635492] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16619), 1,
      sym_pow_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [635526] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2409), 1,
      anon_sym_LBRACK,
    ACTIONS(2419), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2431), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16733), 1,
      sym__lowercase_identifier,
    ACTIONS(16735), 1,
      anon_sym_LPAREN,
    ACTIONS(16737), 1,
      anon_sym_LBRACE,
    ACTIONS(16739), 1,
      sym__uppercase_identifier,
    STATE(6437), 1,
      sym__constructor_name,
    STATE(6682), 1,
      sym_parenthesized_operator,
    STATE(6999), 1,
      sym__value_name,
    STATE(13402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6967), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [635574] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
  [635620] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11533), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11531), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [635650] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8502), 1,
      anon_sym_LBRACK,
    ACTIONS(8510), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8514), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16741), 1,
      sym__lowercase_identifier,
    ACTIONS(16743), 1,
      anon_sym_LPAREN,
    ACTIONS(16745), 1,
      anon_sym_LBRACE,
    ACTIONS(16747), 1,
      sym__uppercase_identifier,
    STATE(7814), 1,
      sym_parenthesized_operator,
    STATE(7905), 1,
      sym__value_name,
    STATE(7994), 1,
      sym__constructor_name,
    STATE(13405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7993), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [635698] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11229), 1,
      sym__simple_class_type,
    STATE(13406), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [635744] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(10081), 1,
      sym__simple_class_type,
    STATE(13407), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [635790] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_end,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    ACTIONS(16749), 1,
      anon_sym_SEMI,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [635842] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(10932), 1,
      sym__simple_class_type,
    STATE(13409), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [635888] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11082), 1,
      sym__simple_class_type,
    STATE(13410), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [635934] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10057), 1,
      anon_sym_let,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(13546), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(13548), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11201), 1,
      sym__simple_class_type,
    STATE(13411), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [635980] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10329), 1,
      anon_sym_DASH_GT,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    ACTIONS(16715), 1,
      anon_sym_SEMI,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636032] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16699), 1,
      anon_sym_LPAREN,
    ACTIONS(16701), 1,
      anon_sym_LBRACE,
    ACTIONS(16703), 1,
      sym__uppercase_identifier,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    STATE(7156), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7632), 1,
      sym__value_name,
    STATE(13413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7631), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [636080] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13828), 1,
      anon_sym_STAR,
    STATE(13414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 13,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [636112] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16753), 2,
      anon_sym_RBRACK,
      anon_sym_SEMI,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636162] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_with,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    ACTIONS(16755), 1,
      anon_sym_SEMI,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636214] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [636246] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_with,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16657), 1,
      anon_sym_SEMI,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636298] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636348] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_do,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    ACTIONS(16757), 1,
      anon_sym_SEMI,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636400] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11123), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [636428] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_do,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    ACTIONS(16757), 1,
      anon_sym_SEMI,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636480] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    STATE(13423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [636512] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_end,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16615), 1,
      anon_sym_SEMI,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [636564] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1983), 1,
      anon_sym_LBRACK,
    ACTIONS(1993), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2005), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16759), 1,
      sym__lowercase_identifier,
    ACTIONS(16761), 1,
      anon_sym_LPAREN,
    ACTIONS(16763), 1,
      anon_sym_LBRACE,
    ACTIONS(16765), 1,
      sym__uppercase_identifier,
    STATE(6099), 1,
      sym_parenthesized_operator,
    STATE(6134), 1,
      sym__constructor_name,
    STATE(6397), 1,
      sym__value_name,
    STATE(13425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6370), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [636612] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [636644] = 14,
    ACTIONS(307), 1,
      anon_sym_LBRACK,
    ACTIONS(325), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(337), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16767), 1,
      sym__lowercase_identifier,
    ACTIONS(16769), 1,
      anon_sym_LPAREN,
    ACTIONS(16771), 1,
      anon_sym_LBRACE,
    ACTIONS(16773), 1,
      sym__uppercase_identifier,
    STATE(4491), 1,
      sym__value_name,
    STATE(4492), 1,
      sym__constructor_name,
    STATE(4691), 1,
      sym_parenthesized_operator,
    STATE(13427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4490), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [636692] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2461), 1,
      anon_sym_LBRACK,
    ACTIONS(2471), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2483), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16775), 1,
      sym__lowercase_identifier,
    ACTIONS(16777), 1,
      anon_sym_LPAREN,
    ACTIONS(16779), 1,
      anon_sym_LBRACE,
    ACTIONS(16781), 1,
      sym__uppercase_identifier,
    STATE(6594), 1,
      sym__value_name,
    STATE(6621), 1,
      sym_parenthesized_operator,
    STATE(6934), 1,
      sym__constructor_name,
    STATE(13428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6564), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [636740] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    STATE(13429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [636772] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11509), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11507), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [636802] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11513), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11511), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [636832] = 14,
    ACTIONS(433), 1,
      anon_sym_LBRACK,
    ACTIONS(443), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(455), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16783), 1,
      sym__lowercase_identifier,
    ACTIONS(16785), 1,
      anon_sym_LPAREN,
    ACTIONS(16787), 1,
      anon_sym_LBRACE,
    ACTIONS(16789), 1,
      sym__uppercase_identifier,
    STATE(3359), 1,
      sym__value_name,
    STATE(3440), 1,
      sym_parenthesized_operator,
    STATE(3472), 1,
      sym__constructor_name,
    STATE(13432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3329), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [636880] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [636916] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [636952] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_do,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637002] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    STATE(13436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [637034] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16791), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637084] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16793), 1,
      anon_sym_and,
    STATE(13438), 1,
      sym_attribute,
    STATE(13469), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [637116] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1175), 1,
      anon_sym_LBRACK,
    ACTIONS(1185), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1201), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16795), 1,
      sym__lowercase_identifier,
    ACTIONS(16797), 1,
      anon_sym_LPAREN,
    ACTIONS(16799), 1,
      anon_sym_LBRACE,
    ACTIONS(16801), 1,
      sym__uppercase_identifier,
    STATE(5201), 1,
      sym__value_name,
    STATE(5215), 1,
      sym__constructor_name,
    STATE(5253), 1,
      sym_parenthesized_operator,
    STATE(13439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5270), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [637164] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2253), 1,
      anon_sym_LBRACK,
    ACTIONS(2263), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2275), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16803), 1,
      sym__lowercase_identifier,
    ACTIONS(16805), 1,
      anon_sym_LPAREN,
    ACTIONS(16807), 1,
      anon_sym_LBRACE,
    ACTIONS(16809), 1,
      sym__uppercase_identifier,
    STATE(6755), 1,
      sym__value_name,
    STATE(6790), 1,
      sym__constructor_name,
    STATE(6901), 1,
      sym_parenthesized_operator,
    STATE(13440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6707), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [637212] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_with,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16657), 1,
      anon_sym_SEMI,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637264] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7917), 2,
      anon_sym_COLON2,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(16811), 13,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_GT_RBRACE,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [637344] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637394] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11485), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11483), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [637424] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_then,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    ACTIONS(16813), 1,
      anon_sym_SEMI,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637476] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_end,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16615), 1,
      anon_sym_SEMI,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637528] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_then,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [637578] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6393), 1,
      anon_sym_LBRACK,
    ACTIONS(6401), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6405), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16815), 1,
      sym__lowercase_identifier,
    ACTIONS(16817), 1,
      anon_sym_LPAREN,
    ACTIONS(16819), 1,
      anon_sym_LBRACE,
    ACTIONS(16821), 1,
      sym__uppercase_identifier,
    STATE(7144), 1,
      sym__constructor_name,
    STATE(7431), 1,
      sym__value_name,
    STATE(7501), 1,
      sym_parenthesized_operator,
    STATE(13449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7388), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [637626] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1285), 1,
      anon_sym_LBRACK,
    ACTIONS(1295), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1315), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16823), 1,
      sym__lowercase_identifier,
    ACTIONS(16825), 1,
      anon_sym_LPAREN,
    ACTIONS(16827), 1,
      anon_sym_LBRACE,
    ACTIONS(16829), 1,
      sym__uppercase_identifier,
    STATE(5862), 1,
      sym__constructor_name,
    STATE(5914), 1,
      sym__value_name,
    STATE(5953), 1,
      sym_parenthesized_operator,
    STATE(13450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5833), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [637674] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16831), 1,
      anon_sym_and,
    STATE(13451), 1,
      sym_attribute,
    STATE(13570), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15826), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [637706] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11577), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11575), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [637736] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5705), 1,
      anon_sym_LBRACK,
    ACTIONS(5713), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5717), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16833), 1,
      sym__lowercase_identifier,
    ACTIONS(16835), 1,
      anon_sym_LPAREN,
    ACTIONS(16837), 1,
      anon_sym_LBRACE,
    ACTIONS(16839), 1,
      sym__uppercase_identifier,
    STATE(6115), 1,
      sym__constructor_name,
    STATE(6324), 1,
      sym__value_name,
    STATE(6342), 1,
      sym_parenthesized_operator,
    STATE(13453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6294), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [637784] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2763), 1,
      anon_sym_LBRACK,
    ACTIONS(2773), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2785), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16841), 1,
      sym__lowercase_identifier,
    ACTIONS(16843), 1,
      anon_sym_LPAREN,
    ACTIONS(16845), 1,
      anon_sym_LBRACE,
    ACTIONS(16847), 1,
      sym__uppercase_identifier,
    STATE(7434), 1,
      sym__constructor_name,
    STATE(7449), 1,
      sym__value_name,
    STATE(7510), 1,
      sym_parenthesized_operator,
    STATE(13454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7448), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [637832] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(16707), 1,
      sym__lowercase_identifier,
    ACTIONS(16849), 1,
      anon_sym_POUND,
    STATE(13455), 1,
      sym_attribute,
    STATE(13649), 1,
      sym_type_constructor_path,
    STATE(17903), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11108), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [637872] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(16707), 1,
      sym__lowercase_identifier,
    ACTIONS(16713), 1,
      anon_sym_POUND,
    STATE(13456), 1,
      sym_attribute,
    STATE(13680), 1,
      sym_type_constructor_path,
    STATE(17903), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11201), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [637912] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11489), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11487), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [637942] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    STATE(13458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_else,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [637974] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [638020] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16793), 1,
      anon_sym_and,
    STATE(13460), 1,
      sym_attribute,
    STATE(13472), 1,
      aux_sym_class_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15640), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [638052] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16851), 1,
      anon_sym_DQUOTE,
    STATE(13657), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16856), 2,
      sym__null,
      aux_sym_string_content_token2,
    STATE(13461), 2,
      sym_attribute,
      aux_sym_string_content_repeat1,
    ACTIONS(16859), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(16853), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [638088] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15799), 1,
      sym__lowercase_identifier,
    ACTIONS(16862), 1,
      anon_sym_nonrec,
    STATE(12948), 1,
      sym_type_binding,
    STATE(13462), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15397), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(19934), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [638142] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(10932), 1,
      sym__simple_class_type,
    STATE(13463), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [638188] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1123), 1,
      anon_sym_LBRACK,
    ACTIONS(1133), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1145), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16864), 1,
      sym__lowercase_identifier,
    ACTIONS(16866), 1,
      anon_sym_LPAREN,
    ACTIONS(16868), 1,
      anon_sym_LBRACE,
    ACTIONS(16870), 1,
      sym__uppercase_identifier,
    STATE(5501), 1,
      sym__constructor_name,
    STATE(5522), 1,
      sym_parenthesized_operator,
    STATE(5542), 1,
      sym__value_name,
    STATE(13464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5483), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [638236] = 14,
    ACTIONS(489), 1,
      anon_sym_LBRACK,
    ACTIONS(499), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(511), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16872), 1,
      sym__lowercase_identifier,
    ACTIONS(16874), 1,
      anon_sym_LPAREN,
    ACTIONS(16876), 1,
      anon_sym_LBRACE,
    ACTIONS(16878), 1,
      sym__uppercase_identifier,
    STATE(3512), 1,
      sym__value_name,
    STATE(3554), 1,
      sym_parenthesized_operator,
    STATE(3793), 1,
      sym__constructor_name,
    STATE(13465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3502), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [638284] = 14,
    ACTIONS(921), 1,
      anon_sym_LBRACK,
    ACTIONS(931), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(951), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16880), 1,
      sym__lowercase_identifier,
    ACTIONS(16882), 1,
      anon_sym_LPAREN,
    ACTIONS(16884), 1,
      anon_sym_LBRACE,
    ACTIONS(16886), 1,
      sym__uppercase_identifier,
    STATE(4961), 1,
      sym__constructor_name,
    STATE(4967), 1,
      sym_parenthesized_operator,
    STATE(4993), 1,
      sym__value_name,
    STATE(13466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4986), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [638332] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8412), 1,
      anon_sym_LBRACK,
    ACTIONS(8420), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8424), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16888), 1,
      sym__lowercase_identifier,
    ACTIONS(16890), 1,
      anon_sym_LPAREN,
    ACTIONS(16892), 1,
      anon_sym_LBRACE,
    ACTIONS(16894), 1,
      sym__uppercase_identifier,
    STATE(10015), 1,
      sym_parenthesized_operator,
    STATE(10093), 1,
      sym__value_name,
    STATE(10299), 1,
      sym__constructor_name,
    STATE(13467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10129), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [638380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    STATE(13468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [638412] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16896), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13469), 2,
      sym_attribute,
      aux_sym_class_definition_repeat1,
    ACTIONS(15173), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [638442] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_end,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    ACTIONS(16749), 1,
      anon_sym_SEMI,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [638494] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [638526] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16793), 1,
      anon_sym_and,
    STATE(13469), 1,
      aux_sym_class_definition_repeat1,
    STATE(13472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15677), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [638558] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11024), 1,
      sym__simple_class_type,
    STATE(13473), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [638604] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11201), 1,
      sym__simple_class_type,
    STATE(13474), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [638650] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_do,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    ACTIONS(16899), 1,
      anon_sym_SEMI,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [638702] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11537), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11535), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [638732] = 14,
    ACTIONS(1069), 1,
      anon_sym_LBRACK,
    ACTIONS(1079), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1091), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16901), 1,
      sym__lowercase_identifier,
    ACTIONS(16903), 1,
      anon_sym_LPAREN,
    ACTIONS(16905), 1,
      anon_sym_LBRACE,
    ACTIONS(16907), 1,
      sym__uppercase_identifier,
    STATE(5300), 1,
      sym__constructor_name,
    STATE(5430), 1,
      sym__value_name,
    STATE(5461), 1,
      sym_parenthesized_operator,
    STATE(13477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5296), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [638780] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    STATE(13478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [638812] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11541), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11539), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [638842] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11545), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11543), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [638872] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13560), 1,
      sym_rel_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16909), 2,
      anon_sym_SEMI,
      anon_sym_GT_RBRACE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [638922] = 14,
    ACTIONS(541), 1,
      anon_sym_LBRACK,
    ACTIONS(551), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(563), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16911), 1,
      sym__lowercase_identifier,
    ACTIONS(16913), 1,
      anon_sym_LPAREN,
    ACTIONS(16915), 1,
      anon_sym_LBRACE,
    ACTIONS(16917), 1,
      sym__uppercase_identifier,
    STATE(3500), 1,
      sym__constructor_name,
    STATE(3670), 1,
      sym__value_name,
    STATE(3769), 1,
      sym_parenthesized_operator,
    STATE(13482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3601), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [638970] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1231), 1,
      anon_sym_LBRACK,
    ACTIONS(1241), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1253), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16919), 1,
      sym__lowercase_identifier,
    ACTIONS(16921), 1,
      anon_sym_LPAREN,
    ACTIONS(16923), 1,
      anon_sym_LBRACE,
    ACTIONS(16925), 1,
      sym__uppercase_identifier,
    STATE(5294), 1,
      sym__constructor_name,
    STATE(5358), 1,
      sym_parenthesized_operator,
    STATE(5453), 1,
      sym__value_name,
    STATE(13483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5452), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639018] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [639060] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11549), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11547), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [639090] = 14,
    ACTIONS(595), 1,
      anon_sym_LBRACK,
    ACTIONS(605), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(617), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16927), 1,
      sym__lowercase_identifier,
    ACTIONS(16929), 1,
      anon_sym_LPAREN,
    ACTIONS(16931), 1,
      anon_sym_LBRACE,
    ACTIONS(16933), 1,
      sym__uppercase_identifier,
    STATE(3539), 1,
      sym__constructor_name,
    STATE(3546), 1,
      sym__value_name,
    STATE(3706), 1,
      sym_parenthesized_operator,
    STATE(13486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3722), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639138] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11553), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11551), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [639168] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_end,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [639218] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11557), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11555), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [639248] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15783), 1,
      sym__lowercase_identifier,
    ACTIONS(16935), 1,
      anon_sym_nonrec,
    STATE(12887), 1,
      sym_type_binding,
    STATE(13490), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15467), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20252), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [639302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    STATE(13491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 8,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      anon_sym_else,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [639334] = 14,
    ACTIONS(709), 1,
      anon_sym_LBRACK,
    ACTIONS(719), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(731), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16937), 1,
      sym__lowercase_identifier,
    ACTIONS(16939), 1,
      anon_sym_LPAREN,
    ACTIONS(16941), 1,
      anon_sym_LBRACE,
    ACTIONS(16943), 1,
      sym__uppercase_identifier,
    STATE(3866), 1,
      sym__constructor_name,
    STATE(3949), 1,
      sym_parenthesized_operator,
    STATE(4083), 1,
      sym__value_name,
    STATE(13492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4039), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639382] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2579), 1,
      anon_sym_LBRACK,
    ACTIONS(2589), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2601), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16945), 1,
      sym__lowercase_identifier,
    ACTIONS(16947), 1,
      anon_sym_LPAREN,
    ACTIONS(16949), 1,
      anon_sym_LBRACE,
    ACTIONS(16951), 1,
      sym__uppercase_identifier,
    STATE(7097), 1,
      sym__value_name,
    STATE(7150), 1,
      sym_parenthesized_operator,
    STATE(7358), 1,
      sym__constructor_name,
    STATE(13493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7071), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639430] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2513), 1,
      anon_sym_LBRACK,
    ACTIONS(2523), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2535), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16953), 1,
      sym__lowercase_identifier,
    ACTIONS(16955), 1,
      anon_sym_LPAREN,
    ACTIONS(16957), 1,
      anon_sym_LBRACE,
    ACTIONS(16959), 1,
      sym__uppercase_identifier,
    STATE(6812), 1,
      sym__value_name,
    STATE(6922), 1,
      sym_parenthesized_operator,
    STATE(6941), 1,
      sym__constructor_name,
    STATE(13494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6754), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639478] = 14,
    ACTIONS(647), 1,
      anon_sym_LBRACK,
    ACTIONS(657), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(669), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16961), 1,
      sym__lowercase_identifier,
    ACTIONS(16963), 1,
      anon_sym_LPAREN,
    ACTIONS(16965), 1,
      anon_sym_LBRACE,
    ACTIONS(16967), 1,
      sym__uppercase_identifier,
    STATE(3623), 1,
      sym__constructor_name,
    STATE(3641), 1,
      sym__value_name,
    STATE(3709), 1,
      sym_parenthesized_operator,
    STATE(13495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3545), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639526] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2711), 1,
      anon_sym_LBRACK,
    ACTIONS(2721), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2733), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16969), 1,
      sym__lowercase_identifier,
    ACTIONS(16971), 1,
      anon_sym_LPAREN,
    ACTIONS(16973), 1,
      anon_sym_LBRACE,
    ACTIONS(16975), 1,
      sym__uppercase_identifier,
    STATE(7028), 1,
      sym__constructor_name,
    STATE(7151), 1,
      sym__value_name,
    STATE(7315), 1,
      sym_parenthesized_operator,
    STATE(13496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7149), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [639574] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [639622] = 11,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(16707), 1,
      sym__lowercase_identifier,
    ACTIONS(16713), 1,
      anon_sym_POUND,
    ACTIONS(16977), 1,
      anon_sym_STAR,
    STATE(13498), 1,
      sym_attribute,
    STATE(13680), 1,
      sym_type_constructor_path,
    STATE(17903), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 4,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11160), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
  [639664] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_with,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    ACTIONS(16755), 1,
      anon_sym_SEMI,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [639716] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [639756] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16661), 1,
      sym_pow_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [639790] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16661), 1,
      sym_pow_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [639824] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [639866] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_rel_operator,
      sym_assign_operator,
  [639908] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [639954] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      sym_assign_operator,
  [640000] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10233), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [640050] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 5,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [640086] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10261), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [640136] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11497), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11495), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [640166] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11479), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [640196] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6805), 1,
      anon_sym_LBRACK,
    ACTIONS(6813), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6817), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16979), 1,
      sym__lowercase_identifier,
    ACTIONS(16981), 1,
      anon_sym_LPAREN,
    ACTIONS(16983), 1,
      anon_sym_LBRACE,
    ACTIONS(16985), 1,
      sym__uppercase_identifier,
    STATE(8203), 1,
      sym_parenthesized_operator,
    STATE(8205), 1,
      sym__value_name,
    STATE(8216), 1,
      sym__constructor_name,
    STATE(13512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8341), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [640244] = 14,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    ACTIONS(1013), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(1025), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16987), 1,
      sym__lowercase_identifier,
    ACTIONS(16989), 1,
      anon_sym_LPAREN,
    ACTIONS(16991), 1,
      anon_sym_LBRACE,
    ACTIONS(16993), 1,
      sym__uppercase_identifier,
    STATE(5041), 1,
      sym_parenthesized_operator,
    STATE(5059), 1,
      sym__constructor_name,
    STATE(5086), 1,
      sym__value_name,
    STATE(13513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5098), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [640292] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    ACTIONS(15913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15917), 1,
      sym_pow_operator,
    ACTIONS(15919), 1,
      sym_mult_operator,
    ACTIONS(15921), 1,
      sym_concat_operator,
    ACTIONS(15923), 1,
      sym_rel_operator,
    ACTIONS(15925), 1,
      sym_and_operator,
    ACTIONS(15927), 1,
      sym_or_operator,
    ACTIONS(15929), 1,
      sym_assign_operator,
    STATE(2292), 1,
      sym_add_operator,
    STATE(13514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16753), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [640342] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_end,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [640382] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9222), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [640412] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16793), 1,
      anon_sym_and,
    STATE(13438), 1,
      aux_sym_class_definition_repeat1,
    STATE(13517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15579), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [640444] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_end,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    ACTIONS(16631), 1,
      sym_assign_operator,
    ACTIONS(16749), 1,
      anon_sym_SEMI,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [640496] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(9182), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [640526] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    STATE(13520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [640558] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11229), 1,
      sym__simple_class_type,
    STATE(13521), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [640604] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10235), 1,
      sym_or_operator,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
  [640650] = 14,
    ACTIONS(865), 1,
      anon_sym_LBRACK,
    ACTIONS(875), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(887), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16995), 1,
      sym__lowercase_identifier,
    ACTIONS(16997), 1,
      anon_sym_LPAREN,
    ACTIONS(16999), 1,
      anon_sym_LBRACE,
    ACTIONS(17001), 1,
      sym__uppercase_identifier,
    STATE(4214), 1,
      sym__constructor_name,
    STATE(4251), 1,
      sym_parenthesized_operator,
    STATE(4391), 1,
      sym__value_name,
    STATE(13523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4350), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [640698] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_then,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    ACTIONS(16813), 1,
      anon_sym_SEMI,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [640750] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10153), 1,
      anon_sym_let,
    ACTIONS(17003), 1,
      sym__lowercase_identifier,
    ACTIONS(17005), 1,
      anon_sym_LBRACK,
    STATE(10081), 1,
      sym__simple_class_type,
    STATE(13525), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [640796] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    ACTIONS(13552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(13554), 1,
      sym_pow_operator,
    ACTIONS(13556), 1,
      sym_mult_operator,
    ACTIONS(13558), 1,
      sym_concat_operator,
    ACTIONS(13562), 1,
      sym_and_operator,
    ACTIONS(13564), 1,
      sym_or_operator,
    ACTIONS(13566), 1,
      sym_assign_operator,
    ACTIONS(14237), 1,
      sym_rel_operator,
    STATE(2040), 1,
      sym_add_operator,
    STATE(13526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17007), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [640846] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17009), 1,
      anon_sym_and,
    STATE(13527), 1,
      sym_attribute,
    STATE(13563), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15766), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [640878] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17009), 1,
      anon_sym_and,
    STATE(13528), 1,
      sym_attribute,
    STATE(13565), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [640910] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(11082), 1,
      sym__simple_class_type,
    STATE(13529), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [640956] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_then,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16637), 1,
      anon_sym_SEMI,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641008] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2305), 1,
      anon_sym_LBRACK,
    ACTIONS(2315), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2327), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(17011), 1,
      sym__lowercase_identifier,
    ACTIONS(17013), 1,
      anon_sym_LPAREN,
    ACTIONS(17015), 1,
      anon_sym_LBRACE,
    ACTIONS(17017), 1,
      sym__uppercase_identifier,
    STATE(6401), 1,
      sym__constructor_name,
    STATE(6855), 1,
      sym__value_name,
    STATE(6936), 1,
      sym_parenthesized_operator,
    STATE(13531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6811), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641056] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11561), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11559), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [641086] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_with,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    ACTIONS(16755), 1,
      anon_sym_SEMI,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641138] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_then,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    ACTIONS(16813), 1,
      anon_sym_SEMI,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641190] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10259), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10257), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [641222] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16619), 1,
      sym_pow_operator,
    ACTIONS(16621), 1,
      sym_mult_operator,
    ACTIONS(16623), 1,
      sym_concat_operator,
    ACTIONS(16625), 1,
      sym_rel_operator,
    ACTIONS(16627), 1,
      sym_and_operator,
    ACTIONS(16629), 1,
      sym_or_operator,
    STATE(2222), 1,
      sym_add_operator,
    STATE(13536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_end,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641270] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11565), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11563), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [641300] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5821), 1,
      anon_sym_LBRACK,
    ACTIONS(5829), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(5833), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(17019), 1,
      sym__lowercase_identifier,
    ACTIONS(17021), 1,
      anon_sym_LPAREN,
    ACTIONS(17023), 1,
      anon_sym_LBRACE,
    ACTIONS(17025), 1,
      sym__uppercase_identifier,
    STATE(6084), 1,
      sym__constructor_name,
    STATE(6221), 1,
      sym__value_name,
    STATE(6275), 1,
      sym_parenthesized_operator,
    STATE(13538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6191), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641348] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17027), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [641376] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8028), 1,
      anon_sym_LBRACK,
    ACTIONS(8034), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8038), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(16701), 1,
      anon_sym_LBRACE,
    ACTIONS(16703), 1,
      sym__uppercase_identifier,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(17029), 1,
      anon_sym_LPAREN,
    STATE(7156), 1,
      sym__constructor_name,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(7632), 1,
      sym__value_name,
    STATE(13540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7631), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641424] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16659), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16661), 1,
      sym_pow_operator,
    ACTIONS(16663), 1,
      sym_mult_operator,
    ACTIONS(16665), 1,
      sym_concat_operator,
    ACTIONS(16667), 1,
      sym_rel_operator,
    ACTIONS(16669), 1,
      sym_and_operator,
    ACTIONS(16671), 1,
      sym_or_operator,
    ACTIONS(16673), 1,
      sym_assign_operator,
    STATE(2207), 1,
      sym_add_operator,
    STATE(13541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10271), 2,
      anon_sym_SEMI,
      anon_sym_with,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641474] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17031), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [641502] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11569), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11567), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [641532] = 13,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10061), 1,
      anon_sym_object,
    ACTIONS(10183), 1,
      anon_sym_let,
    ACTIONS(16693), 1,
      sym__lowercase_identifier,
    ACTIONS(16695), 1,
      anon_sym_LBRACK,
    STATE(10081), 1,
      sym__simple_class_type,
    STATE(13544), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10177), 6,
      sym_instantiated_class_type,
      sym_class_body_type,
      sym_let_open_class_type,
      sym_extension,
      sym_quoted_extension,
      sym_class_type_path,
  [641578] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6173), 1,
      anon_sym_LBRACK,
    ACTIONS(6181), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(6185), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(17033), 1,
      sym__lowercase_identifier,
    ACTIONS(17035), 1,
      anon_sym_LPAREN,
    ACTIONS(17037), 1,
      anon_sym_LBRACE,
    ACTIONS(17039), 1,
      sym__uppercase_identifier,
    STATE(6526), 1,
      sym__value_name,
    STATE(6548), 1,
      sym_parenthesized_operator,
    STATE(6658), 1,
      sym__constructor_name,
    STATE(13545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(6495), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641626] = 14,
    ACTIONS(49), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(93), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17041), 1,
      sym__lowercase_identifier,
    ACTIONS(17043), 1,
      anon_sym_LPAREN,
    ACTIONS(17045), 1,
      anon_sym_LBRACE,
    ACTIONS(17047), 1,
      sym__uppercase_identifier,
    STATE(4656), 1,
      sym__value_name,
    STATE(4662), 1,
      sym_parenthesized_operator,
    STATE(4665), 1,
      sym__constructor_name,
    STATE(13546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4643), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641674] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16831), 1,
      anon_sym_and,
    STATE(13547), 1,
      sym_attribute,
    STATE(13571), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [641706] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(2815), 1,
      anon_sym_LBRACK,
    ACTIONS(2825), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(2837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(17049), 1,
      sym__lowercase_identifier,
    ACTIONS(17051), 1,
      anon_sym_LPAREN,
    ACTIONS(17053), 1,
      anon_sym_LBRACE,
    ACTIONS(17055), 1,
      sym__uppercase_identifier,
    STATE(7048), 1,
      sym__constructor_name,
    STATE(7116), 1,
      sym_parenthesized_operator,
    STATE(7196), 1,
      sym__value_name,
    STATE(13548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7195), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641754] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_done,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    ACTIONS(16633), 1,
      anon_sym_SEMI,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641806] = 14,
    ACTIONS(813), 1,
      anon_sym_LBRACK,
    ACTIONS(823), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(835), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17057), 1,
      sym__lowercase_identifier,
    ACTIONS(17059), 1,
      anon_sym_LPAREN,
    ACTIONS(17061), 1,
      anon_sym_LBRACE,
    ACTIONS(17063), 1,
      sym__uppercase_identifier,
    STATE(4264), 1,
      sym__value_name,
    STATE(4384), 1,
      sym_parenthesized_operator,
    STATE(4408), 1,
      sym__constructor_name,
    STATE(13550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(4206), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [641854] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9008), 15,
      ts_builtin_sym_end,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_RBRACK,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [641882] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_then,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641930] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_then,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    ACTIONS(16637), 1,
      anon_sym_SEMI,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    ACTIONS(16647), 1,
      sym_rel_operator,
    ACTIONS(16649), 1,
      sym_and_operator,
    ACTIONS(16651), 1,
      sym_or_operator,
    ACTIONS(16653), 1,
      sym_assign_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [641982] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [642022] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16641), 1,
      sym_pow_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [642056] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_do,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    ACTIONS(16899), 1,
      anon_sym_SEMI,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [642108] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16641), 1,
      sym_pow_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [642142] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7825), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(7837), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(17065), 1,
      sym__lowercase_identifier,
    ACTIONS(17067), 1,
      anon_sym_LPAREN,
    ACTIONS(17069), 1,
      anon_sym_LBRACE,
    ACTIONS(17071), 1,
      sym__uppercase_identifier,
    STATE(8437), 1,
      sym__constructor_name,
    STATE(9389), 1,
      sym__value_name,
    STATE(9491), 1,
      sym_parenthesized_operator,
    STATE(13558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9669), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [642190] = 17,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15790), 1,
      sym__lowercase_identifier,
    ACTIONS(17073), 1,
      anon_sym_nonrec,
    STATE(13528), 1,
      sym_type_binding,
    STATE(13559), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15490), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(18424), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [642244] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    STATE(13560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
    ACTIONS(10133), 7,
      anon_sym_PIPE,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
  [642276] = 14,
    ACTIONS(761), 1,
      anon_sym_LBRACK,
    ACTIONS(771), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(783), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17075), 1,
      sym__lowercase_identifier,
    ACTIONS(17077), 1,
      anon_sym_LPAREN,
    ACTIONS(17079), 1,
      anon_sym_LBRACE,
    ACTIONS(17081), 1,
      sym__uppercase_identifier,
    STATE(3846), 1,
      sym__constructor_name,
    STATE(3867), 1,
      sym_parenthesized_operator,
    STATE(4013), 1,
      sym__value_name,
    STATE(13561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3937), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [642324] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10327), 1,
      anon_sym_done,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    ACTIONS(16116), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16118), 1,
      sym_pow_operator,
    ACTIONS(16120), 1,
      sym_mult_operator,
    ACTIONS(16122), 1,
      sym_concat_operator,
    ACTIONS(16124), 1,
      sym_rel_operator,
    ACTIONS(16126), 1,
      sym_and_operator,
    ACTIONS(16128), 1,
      sym_or_operator,
    ACTIONS(16130), 1,
      sym_assign_operator,
    ACTIONS(16633), 1,
      anon_sym_SEMI,
    STATE(2276), 1,
      sym_add_operator,
    STATE(13562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [642376] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17009), 1,
      anon_sym_and,
    STATE(13563), 1,
      sym_attribute,
    STATE(13566), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15611), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642408] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10131), 3,
      anon_sym_SEMI,
      anon_sym_do,
      sym_assign_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [642456] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17009), 1,
      anon_sym_and,
    STATE(13565), 1,
      sym_attribute,
    STATE(13566), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642488] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17083), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13566), 2,
      sym_attribute,
      aux_sym_type_definition_repeat1,
    ACTIONS(15030), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642518] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17009), 1,
      anon_sym_and,
    STATE(13567), 1,
      sym_attribute,
    STATE(13577), 1,
      aux_sym_type_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15617), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642550] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_do,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    ACTIONS(16899), 1,
      anon_sym_SEMI,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [642602] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_do,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    ACTIONS(16611), 1,
      sym_concat_operator,
    ACTIONS(16683), 1,
      sym_rel_operator,
    ACTIONS(16685), 1,
      sym_and_operator,
    ACTIONS(16687), 1,
      sym_or_operator,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    ACTIONS(16691), 1,
      sym_assign_operator,
    ACTIONS(16757), 1,
      anon_sym_SEMI,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
  [642654] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16831), 1,
      anon_sym_and,
    STATE(13362), 1,
      aux_sym_module_definition_repeat1,
    STATE(13570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15450), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642686] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16831), 1,
      anon_sym_and,
    STATE(13362), 1,
      aux_sym_module_definition_repeat1,
    STATE(13571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642718] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8456), 1,
      anon_sym_LBRACK,
    ACTIONS(8464), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(8468), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(17086), 1,
      sym__lowercase_identifier,
    ACTIONS(17088), 1,
      anon_sym_LPAREN,
    ACTIONS(17090), 1,
      anon_sym_LBRACE,
    ACTIONS(17092), 1,
      sym__uppercase_identifier,
    STATE(7529), 1,
      sym_parenthesized_operator,
    STATE(7564), 1,
      sym__constructor_name,
    STATE(7574), 1,
      sym__value_name,
    STATE(13572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7566), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [642766] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16831), 1,
      anon_sym_and,
    STATE(13573), 1,
      sym_attribute,
    STATE(13574), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15772), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642798] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16831), 1,
      anon_sym_and,
    STATE(13362), 1,
      aux_sym_module_definition_repeat1,
    STATE(13574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15779), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642830] = 14,
    ACTIONS(377), 1,
      anon_sym_LBRACK,
    ACTIONS(387), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(399), 1,
      anon_sym_LBRACE_LT,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17094), 1,
      sym__lowercase_identifier,
    ACTIONS(17096), 1,
      anon_sym_LPAREN,
    ACTIONS(17098), 1,
      anon_sym_LBRACE,
    ACTIONS(17100), 1,
      sym__uppercase_identifier,
    STATE(3298), 1,
      sym__value_name,
    STATE(3362), 1,
      sym_parenthesized_operator,
    STATE(3475), 1,
      sym__constructor_name,
    STATE(13575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(3272), 5,
      sym_list_expression,
      sym_array_expression,
      sym_record_expression,
      sym_package_expression,
      sym_object_copy_expression,
  [642878] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16605), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16607), 1,
      sym_pow_operator,
    ACTIONS(16609), 1,
      sym_mult_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10325), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10323), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [642918] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17009), 1,
      anon_sym_and,
    STATE(13566), 1,
      aux_sym_type_definition_repeat1,
    STATE(13577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15624), 13,
      anon_sym_SEMI_SEMI,
      anon_sym_external,
      anon_sym_type,
      anon_sym_exception,
      anon_sym_module,
      anon_sym_open,
      anon_sym_include,
      anon_sym_class,
      anon_sym_val,
      anon_sym_end,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [642950] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17102), 1,
      anon_sym_DQUOTE,
    STATE(13461), 1,
      aux_sym_string_content_repeat1,
    STATE(13578), 1,
      sym_attribute,
    STATE(13657), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15935), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(15937), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
    ACTIONS(15933), 6,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [642988] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16607), 1,
      sym_pow_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [643022] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16607), 1,
      sym_pow_operator,
    STATE(2177), 1,
      sym_add_operator,
    STATE(13580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10233), 7,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [643056] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(16641), 1,
      sym_pow_operator,
    ACTIONS(16643), 1,
      sym_mult_operator,
    ACTIONS(16645), 1,
      sym_concat_operator,
    STATE(2136), 1,
      sym_add_operator,
    STATE(13581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10235), 2,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10241), 3,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      aux_sym_add_operator_token1,
    ACTIONS(10233), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_then,
      sym_rel_operator,
      sym_assign_operator,
  [643098] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11493), 7,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      sym__uppercase_identifier,
    ACTIONS(11491), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
      sym__lowercase_identifier,
  [643128] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15754), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(12875), 1,
      sym_type_binding,
    STATE(13583), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15388), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20072), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643179] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13584), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(14995), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11098), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [643222] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13585), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15099), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11098), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [643265] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13586), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15104), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11152), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [643308] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17106), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13587), 1,
      sym_attribute,
    STATE(13788), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17108), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [643345] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17110), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13588), 1,
      sym_attribute,
    STATE(13811), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17112), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [643382] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15754), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(12229), 1,
      sym_type_binding,
    STATE(13589), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15388), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20072), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643433] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15754), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(12625), 1,
      sym_type_binding,
    STATE(13590), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15388), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20072), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643484] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15799), 1,
      sym__lowercase_identifier,
    STATE(13259), 1,
      sym_type_binding,
    STATE(13591), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15397), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(19934), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643535] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8326), 1,
      anon_sym_COLON2,
    STATE(13592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 13,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [643564] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15783), 1,
      sym__lowercase_identifier,
    STATE(12229), 1,
      sym_type_binding,
    STATE(13593), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15467), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20252), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643615] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17114), 1,
      anon_sym_COLON2,
    STATE(13594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [643646] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15783), 1,
      sym__lowercase_identifier,
    STATE(12709), 1,
      sym_type_binding,
    STATE(13595), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15467), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20252), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643697] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17116), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13596), 1,
      sym_attribute,
    STATE(13868), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17118), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [643734] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    STATE(13597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_with,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [643765] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15799), 1,
      sym__lowercase_identifier,
    STATE(12948), 1,
      sym_type_binding,
    STATE(13598), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15397), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(19934), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [643816] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13599), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15091), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11195), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [643859] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17120), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13600), 1,
      sym_attribute,
    STATE(13823), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17122), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [643896] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13601), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15155), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11094), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [643939] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13602), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15156), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11094), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [643982] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17124), 1,
      anon_sym_COLON_GT,
    ACTIONS(17126), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13603), 1,
      sym_attribute,
    STATE(13747), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17128), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644019] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15783), 1,
      sym__lowercase_identifier,
    STATE(12887), 1,
      sym_type_binding,
    STATE(13604), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15467), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20252), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644070] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15790), 1,
      sym__lowercase_identifier,
    STATE(13528), 1,
      sym_type_binding,
    STATE(13605), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15490), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(18424), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644121] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17130), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13606), 1,
      sym_attribute,
    STATE(13755), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17132), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644158] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    STATE(13607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_COLON_COLON,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [644189] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    STATE(13608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_then,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [644220] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17134), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13609), 1,
      sym_attribute,
    STATE(13880), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17136), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644257] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(13610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644288] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15790), 1,
      sym__lowercase_identifier,
    STATE(12229), 1,
      sym_type_binding,
    STATE(13611), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15490), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(18424), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644339] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15790), 1,
      sym__lowercase_identifier,
    STATE(13567), 1,
      sym_type_binding,
    STATE(13612), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15490), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(18424), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644390] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17138), 1,
      anon_sym_COLON_GT,
    ACTIONS(17140), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13613), 1,
      sym_attribute,
    STATE(13790), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17142), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644427] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    STATE(13614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10133), 6,
      aux_sym_signed_number_token1,
      aux_sym_sign_operator_token1,
      sym_mult_operator,
      aux_sym_add_operator_token1,
      sym_and_operator,
      sym_or_operator,
    ACTIONS(10131), 7,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_do,
      sym_pow_operator,
      sym_concat_operator,
      sym_rel_operator,
      sym_assign_operator,
  [644458] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17144), 1,
      anon_sym_COLON_GT,
    ACTIONS(17146), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13615), 1,
      sym_attribute,
    STATE(13723), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17148), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644495] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(14037), 1,
      anon_sym_DASH_GT,
    STATE(13616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 12,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644526] = 16,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    ACTIONS(15799), 1,
      sym__lowercase_identifier,
    STATE(12229), 1,
      sym_type_binding,
    STATE(13617), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15397), 1,
      sym__type_params,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(19934), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644577] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644605] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17150), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13619), 1,
      sym_attribute,
    STATE(13835), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17152), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644639] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8294), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644667] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(13621), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15235), 1,
      sym__type_params,
    STATE(16693), 1,
      sym_type_constructor_path,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [644715] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11255), 1,
      anon_sym_as,
    ACTIONS(17156), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17154), 11,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644745] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8022), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644773] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11019), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644801] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8298), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644829] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17160), 1,
      anon_sym_as,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13626), 1,
      sym_attribute,
    STATE(13920), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17158), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [644863] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11577), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644891] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(12263), 1,
      anon_sym_LPAREN,
    ACTIONS(12265), 1,
      anon_sym_LBRACK,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(17162), 1,
      anon_sym_private,
    ACTIONS(17164), 1,
      anon_sym_DOT_DOT,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    STATE(11007), 1,
      sym_variant_declaration,
    STATE(11008), 1,
      sym_record_declaration,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(13628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12267), 2,
      anon_sym_true,
      anon_sym_false,
  [644939] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11499), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11501), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644967] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11589), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [644995] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8294), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645023] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11503), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11505), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645051] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17168), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13633), 1,
      sym_attribute,
    STATE(13781), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17170), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [645085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11507), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11509), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645113] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11511), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11513), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645141] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 2,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [645171] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11351), 1,
      anon_sym_in,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13637), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15643), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [645213] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11483), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11485), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645241] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8022), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645269] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11247), 1,
      anon_sym_in,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13640), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15543), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [645311] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11487), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11489), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645339] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17174), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(17172), 11,
      anon_sym_DQUOTE,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [645367] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12443), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17176), 1,
      anon_sym_private,
    ACTIONS(17178), 1,
      anon_sym_DOT_DOT,
    STATE(11277), 1,
      sym_variant_declaration,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11443), 1,
      sym_record_declaration,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(13643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12447), 2,
      anon_sym_true,
      anon_sym_false,
  [645415] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12591), 1,
      anon_sym_LPAREN,
    ACTIONS(12593), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17180), 1,
      anon_sym_private,
    ACTIONS(17182), 1,
      anon_sym_DOT_DOT,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(11746), 1,
      sym_variant_declaration,
    STATE(11747), 1,
      sym_record_declaration,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(13644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12595), 2,
      anon_sym_true,
      anon_sym_false,
  [645463] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8298), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645491] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(13646), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15741), 1,
      sym__type_params,
    STATE(16704), 1,
      sym_type_constructor_path,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [645539] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11491), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11493), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645567] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11519), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11521), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645595] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11523), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11525), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645623] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12591), 1,
      anon_sym_LPAREN,
    ACTIONS(12593), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17184), 1,
      anon_sym_private,
    ACTIONS(17186), 1,
      anon_sym_DOT_DOT,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(11783), 1,
      sym_variant_declaration,
    STATE(11785), 1,
      sym_record_declaration,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(13650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12595), 2,
      anon_sym_true,
      anon_sym_false,
  [645671] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9224), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645699] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11527), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11529), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645727] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17188), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13653), 1,
      sym_attribute,
    STATE(13732), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17190), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [645761] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17192), 1,
      anon_sym_private,
    ACTIONS(17194), 1,
      anon_sym_DOT_DOT,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11040), 1,
      sym_variant_declaration,
    STATE(11041), 1,
      sym_record_declaration,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(13654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12305), 2,
      anon_sym_true,
      anon_sym_false,
  [645809] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17196), 1,
      anon_sym_private,
    ACTIONS(17198), 1,
      anon_sym_DOT_DOT,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11054), 1,
      sym_variant_declaration,
    STATE(11055), 1,
      sym_record_declaration,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(13655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12305), 2,
      anon_sym_true,
      anon_sym_false,
  [645857] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12443), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17200), 1,
      anon_sym_private,
    ACTIONS(17202), 1,
      anon_sym_DOT_DOT,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11419), 1,
      sym_variant_declaration,
    STATE(11449), 1,
      sym_record_declaration,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(13656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12447), 2,
      anon_sym_true,
      anon_sym_false,
  [645905] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17206), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(17204), 11,
      anon_sym_DQUOTE,
      aux_sym_string_content_token1,
      aux_sym_string_content_token3,
      aux_sym_string_content_token4,
      aux_sym_string_content_token5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [645933] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9224), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [645961] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(13659), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15764), 1,
      sym__type_params,
    STATE(17150), 1,
      sym_type_constructor_path,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [646009] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(11243), 1,
      anon_sym_in,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(13660), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    STATE(15422), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [646051] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17208), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13661), 1,
      sym_attribute,
    STATE(13782), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17210), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [646085] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646113] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(13663), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15781), 1,
      sym__type_params,
    STATE(15961), 1,
      sym_type_constructor_path,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [646161] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11535), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11537), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646189] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(12263), 1,
      anon_sym_LPAREN,
    ACTIONS(12265), 1,
      anon_sym_LBRACK,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17212), 1,
      anon_sym_private,
    ACTIONS(17214), 1,
      anon_sym_DOT_DOT,
    STATE(10994), 1,
      sym_variant_declaration,
    STATE(10995), 1,
      sym_record_declaration,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(13665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12267), 2,
      anon_sym_true,
      anon_sym_false,
  [646237] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(17216), 1,
      sym__lowercase_identifier,
    ACTIONS(17218), 1,
      anon_sym_STAR,
    ACTIONS(17220), 1,
      anon_sym_POUND,
    STATE(13666), 1,
      sym_attribute,
    STATE(13946), 1,
      sym_type_constructor_path,
    STATE(17826), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 3,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
    ACTIONS(11160), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [646277] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17222), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13667), 1,
      sym_attribute,
    STATE(13746), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17224), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [646311] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(13668), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15788), 1,
      sym__type_params,
    STATE(16013), 1,
      sym_type_constructor_path,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [646359] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11539), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11541), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646387] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(17216), 1,
      sym__lowercase_identifier,
    ACTIONS(17220), 1,
      anon_sym_POUND,
    STATE(13670), 1,
      sym_attribute,
    STATE(13946), 1,
      sym_type_constructor_path,
    STATE(17826), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11199), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
    ACTIONS(11201), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [646425] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(17216), 1,
      sym__lowercase_identifier,
    ACTIONS(17226), 1,
      anon_sym_POUND,
    STATE(13671), 1,
      sym_attribute,
    STATE(13970), 1,
      sym_type_constructor_path,
    STATE(17826), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
    ACTIONS(11108), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [646463] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6793), 1,
      anon_sym_COLON2,
    ACTIONS(17228), 1,
      anon_sym_DOT_DOT,
    STATE(13672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [646493] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(17216), 1,
      sym__lowercase_identifier,
    ACTIONS(17220), 1,
      anon_sym_POUND,
    ACTIONS(17230), 1,
      anon_sym_DASH_GT,
    ACTIONS(17232), 1,
      anon_sym_STAR,
    STATE(13673), 1,
      sym_attribute,
    STATE(13946), 1,
      sym_type_constructor_path,
    STATE(17826), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 2,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
    ACTIONS(10383), 4,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [646535] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11543), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11545), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646563] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11547), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11549), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646591] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11255), 1,
      anon_sym_as,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13676), 1,
      sym_attribute,
    STATE(13743), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17234), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [646625] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8290), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646653] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11551), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11553), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646681] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11555), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11557), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646709] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11495), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11497), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646737] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11559), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11561), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646765] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9044), 1,
      anon_sym_COLON2,
    STATE(13682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9046), 12,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [646793] = 15,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(12524), 1,
      sym__lowercase_identifier,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(15764), 1,
      anon_sym__,
    STATE(13683), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15410), 1,
      sym__type_params,
    STATE(16239), 1,
      sym_type_constructor_path,
    STATE(17203), 1,
      sym__type_param,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [646841] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11481), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646869] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11563), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11565), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646897] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17238), 1,
      anon_sym_as,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13686), 1,
      sym_attribute,
    STATE(13724), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17236), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [646931] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11567), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11569), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646959] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 4,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8290), 9,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [646987] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11571), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11573), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [647015] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17240), 1,
      anon_sym_EQ,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13690), 1,
      sym_attribute,
    STATE(13822), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17242), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9026), 1,
      anon_sym_COLON2,
    STATE(13691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9028), 12,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [647077] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11531), 6,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11533), 7,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [647105] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12443), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17244), 1,
      anon_sym_DOT_DOT,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11493), 1,
      sym_variant_declaration,
    STATE(11496), 1,
      sym_record_declaration,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(13693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12447), 2,
      anon_sym_true,
      anon_sym_false,
  [647150] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17246), 1,
      anon_sym_RPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13694), 1,
      sym_attribute,
    STATE(21386), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647189] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17252), 1,
      anon_sym_COLON2,
    STATE(13695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17250), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [647216] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17254), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647247] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17256), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13697), 1,
      sym_attribute,
    STATE(19326), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647286] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17258), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13698), 1,
      sym_attribute,
    STATE(19860), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647325] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17260), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647356] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9634), 1,
      anon_sym_COLON2,
    STATE(13700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [647383] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9638), 1,
      anon_sym_COLON2,
    STATE(13701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9640), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [647410] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9642), 1,
      anon_sym_COLON2,
    STATE(13702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [647437] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17262), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13703), 1,
      sym_attribute,
    STATE(19813), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647476] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17264), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13704), 1,
      sym_attribute,
    STATE(18433), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647515] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17266), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13705), 1,
      sym_attribute,
    STATE(21067), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647554] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9090), 1,
      anon_sym_COLON2,
    STATE(13706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9092), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [647581] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17268), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13707), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8757), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647608] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(12263), 1,
      anon_sym_LPAREN,
    ACTIONS(12265), 1,
      anon_sym_LBRACK,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17271), 1,
      anon_sym_DOT_DOT,
    STATE(11015), 1,
      sym_variant_declaration,
    STATE(11016), 1,
      sym_record_declaration,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(13708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12267), 2,
      anon_sym_true,
      anon_sym_false,
  [647653] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13709), 1,
      sym_attribute,
    STATE(13905), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17273), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647684] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17275), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647715] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17277), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13711), 1,
      sym_attribute,
    STATE(18913), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647754] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17279), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13712), 1,
      sym_attribute,
    STATE(18491), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647793] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7621), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647824] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17281), 1,
      anon_sym_COLON2,
    STATE(13714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [647853] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7581), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647884] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17285), 1,
      anon_sym_LPAREN,
    ACTIONS(17287), 1,
      anon_sym_COLON2,
    STATE(13716), 1,
      sym_attribute,
    STATE(14220), 1,
      aux_sym_module_binding_repeat1,
    STATE(14301), 1,
      sym_module_parameter,
    STATE(14433), 1,
      sym__module_typed,
    STATE(15196), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11934), 2,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(17283), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [647927] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13717), 1,
      sym_attribute,
    STATE(13900), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17289), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [647958] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17291), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13718), 1,
      sym_attribute,
    STATE(19180), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [647997] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17293), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648028] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13720), 1,
      sym_attribute,
    STATE(13840), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17295), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9150), 1,
      anon_sym_COLON2,
    STATE(13721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9152), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [648086] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13722), 1,
      sym_attribute,
    STATE(13845), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17297), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648117] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17299), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648148] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17301), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648179] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17303), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13725), 1,
      sym_attribute,
    STATE(19721), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648218] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13726), 1,
      sym_attribute,
    STATE(13874), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17305), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648249] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17307), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13727), 1,
      sym_attribute,
    STATE(18730), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648288] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13728), 1,
      sym_attribute,
    STATE(13821), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17309), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648319] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10360), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [648344] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17311), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13730), 1,
      sym_attribute,
    STATE(18778), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648383] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10366), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [648408] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17313), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648439] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10377), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [648464] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10385), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [648489] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17315), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13735), 1,
      sym_attribute,
    STATE(20037), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648528] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17317), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13736), 1,
      sym_attribute,
    STATE(21350), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648567] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17319), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13737), 1,
      sym_attribute,
    STATE(19514), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648606] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17321), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648637] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17323), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13739), 1,
      sym_attribute,
    STATE(18916), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648676] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17325), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13740), 1,
      sym_attribute,
    STATE(21240), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648715] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17327), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648746] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17329), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13742), 1,
      sym_attribute,
    STATE(18882), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [648785] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17331), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648816] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8204), 1,
      anon_sym_COLON2,
    STATE(13744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 11,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [648843] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17333), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648874] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17335), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648905] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17337), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648936] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13748), 1,
      sym_attribute,
    STATE(13885), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17339), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [648967] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17341), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13749), 1,
      sym_attribute,
    STATE(19355), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9818), 1,
      anon_sym_COLON2,
    STATE(13750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9820), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [649033] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17343), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13751), 1,
      sym_attribute,
    STATE(20220), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649072] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17345), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13752), 1,
      sym_attribute,
    STATE(18595), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649111] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17347), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13753), 1,
      sym_attribute,
    STATE(19035), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649150] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13741), 1,
      aux_sym_expression_item_repeat1,
    STATE(13754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17349), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649181] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17351), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649212] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17353), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649243] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13757), 1,
      sym_attribute,
    STATE(13894), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17355), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649274] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17357), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649305] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17359), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649336] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17361), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13760), 1,
      sym_attribute,
    STATE(20131), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649375] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13761), 1,
      sym_attribute,
    STATE(13766), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17363), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649406] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13762), 1,
      sym_attribute,
    STATE(13828), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17365), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649437] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9094), 1,
      anon_sym_COLON2,
    STATE(13763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9096), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [649464] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17367), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649495] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9826), 1,
      anon_sym_COLON2,
    STATE(13765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9828), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [649522] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17369), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649553] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17371), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13767), 1,
      sym_attribute,
    STATE(19113), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649592] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17373), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13768), 1,
      sym_attribute,
    STATE(21129), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649631] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13769), 1,
      sym_attribute,
    STATE(13870), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17375), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649662] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17377), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13770), 1,
      sym_attribute,
    STATE(21255), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649701] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17379), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13771), 1,
      sym_attribute,
    STATE(20248), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649740] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17381), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13772), 1,
      sym_attribute,
    STATE(19437), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649779] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17383), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649810] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17385), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13774), 1,
      sym_attribute,
    STATE(21062), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649849] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13775), 1,
      sym_attribute,
    STATE(13827), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17387), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [649880] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17389), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13776), 1,
      sym_attribute,
    STATE(20046), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649919] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17391), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13777), 1,
      sym_attribute,
    STATE(21229), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [649958] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9122), 1,
      anon_sym_COLON2,
    STATE(13778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9124), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [649985] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17393), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13779), 1,
      sym_attribute,
    STATE(20224), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650024] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(17285), 1,
      anon_sym_LPAREN,
    ACTIONS(17287), 1,
      anon_sym_COLON2,
    STATE(13716), 1,
      aux_sym_module_binding_repeat1,
    STATE(13780), 1,
      sym_attribute,
    STATE(14301), 1,
      sym_module_parameter,
    STATE(14403), 1,
      sym__module_typed,
    STATE(15009), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12011), 2,
      anon_sym_and,
      anon_sym_in,
    ACTIONS(17395), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [650067] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17397), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650098] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17399), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650129] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17401), 1,
      aux_sym_attribute_id_token1,
    STATE(13783), 1,
      sym_attribute,
    STATE(13803), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8774), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650158] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17403), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13784), 1,
      sym_attribute,
    STATE(19027), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650197] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(10383), 1,
      anon_sym_as,
    ACTIONS(15340), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(17405), 1,
      anon_sym_DASH_GT,
    ACTIONS(17407), 1,
      anon_sym_STAR,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(13785), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 4,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [650238] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12591), 1,
      anon_sym_LPAREN,
    ACTIONS(12593), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17409), 1,
      anon_sym_DOT_DOT,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(11766), 1,
      sym_variant_declaration,
    STATE(11770), 1,
      sym_record_declaration,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(13786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12595), 2,
      anon_sym_true,
      anon_sym_false,
  [650283] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9202), 1,
      anon_sym_COLON2,
    STATE(13787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [650310] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17411), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650341] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17413), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13789), 1,
      sym_attribute,
    STATE(19594), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650380] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17415), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650411] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17417), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13791), 1,
      sym_attribute,
    STATE(19834), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650450] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8474), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(8476), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(16384), 1,
      anon_sym_LPAREN,
    STATE(13792), 1,
      sym_attribute,
    STATE(13995), 1,
      sym__simple_module_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10776), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    STATE(13996), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650485] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9414), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12591), 1,
      anon_sym_LPAREN,
    ACTIONS(12593), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17419), 1,
      anon_sym_DOT_DOT,
    STATE(11574), 1,
      sym_variant_declaration,
    STATE(11579), 1,
      sym_record_declaration,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(12559), 1,
      sym_constructor_declaration,
    STATE(13793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12595), 2,
      anon_sym_true,
      anon_sym_false,
  [650530] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17421), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13794), 1,
      sym_attribute,
    STATE(18497), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650569] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17423), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13795), 1,
      sym_attribute,
    STATE(19826), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650608] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13699), 1,
      aux_sym_expression_item_repeat1,
    STATE(13796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17425), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650639] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17427), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13797), 1,
      sym_attribute,
    STATE(19125), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650678] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17429), 1,
      anon_sym_DOT_DOT,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11046), 1,
      sym_variant_declaration,
    STATE(11047), 1,
      sym_record_declaration,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(13798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12305), 2,
      anon_sym_true,
      anon_sym_false,
  [650723] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [650748] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17431), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13800), 1,
      sym_attribute,
    STATE(18939), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650787] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13738), 1,
      aux_sym_expression_item_repeat1,
    STATE(13801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17433), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650818] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9352), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17435), 1,
      anon_sym_DOT_DOT,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(11062), 1,
      sym_variant_declaration,
    STATE(11063), 1,
      sym_record_declaration,
    STATE(11696), 1,
      sym_constructor_declaration,
    STATE(13802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12305), 2,
      anon_sym_true,
      anon_sym_false,
  [650863] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17401), 1,
      aux_sym_attribute_id_token1,
    STATE(13707), 1,
      aux_sym_attribute_id_repeat1,
    STATE(13803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8768), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650892] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17437), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13804), 1,
      sym_attribute,
    STATE(19143), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [650931] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17439), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650962] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11160), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15685), 1,
      anon_sym_STAR,
    STATE(13806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 10,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [650991] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17441), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651022] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17443), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651053] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17445), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13809), 1,
      sym_attribute,
    STATE(20771), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651092] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11160), 1,
      anon_sym_as,
    ACTIONS(15340), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(17447), 1,
      anon_sym_STAR,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(13810), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 5,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [651131] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17449), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651162] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17451), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13812), 1,
      sym_attribute,
    STATE(21176), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651201] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9684), 1,
      anon_sym_COLON2,
    STATE(13813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [651228] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9688), 1,
      anon_sym_COLON2,
    STATE(13814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [651255] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17453), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13815), 1,
      sym_attribute,
    STATE(19454), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651294] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17455), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13816), 1,
      sym_attribute,
    STATE(21043), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651333] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9692), 1,
      anon_sym_COLON2,
    STATE(13817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [651360] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9696), 1,
      anon_sym_COLON2,
    STATE(13818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [651387] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9700), 1,
      anon_sym_COLON2,
    STATE(13819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9702), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [651414] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17457), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13820), 1,
      sym_attribute,
    STATE(19544), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651453] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17459), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651484] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17461), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651515] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17463), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651546] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17465), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13824), 1,
      sym_attribute,
    STATE(18469), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651585] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17467), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13825), 1,
      sym_attribute,
    STATE(21173), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651624] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9316), 1,
      anon_sym_PIPE,
    ACTIONS(12263), 1,
      anon_sym_LPAREN,
    ACTIONS(12265), 1,
      anon_sym_LBRACK,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17469), 1,
      anon_sym_DOT_DOT,
    STATE(10999), 1,
      sym_variant_declaration,
    STATE(11000), 1,
      sym_record_declaration,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(11741), 1,
      sym_constructor_declaration,
    STATE(13826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12267), 2,
      anon_sym_true,
      anon_sym_false,
  [651669] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17471), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651700] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17473), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651731] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17477), 1,
      anon_sym_COLON2,
    STATE(13829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17475), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [651758] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17479), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13830), 1,
      sym_attribute,
    STATE(20721), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651797] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17481), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13831), 1,
      sym_attribute,
    STATE(20175), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651836] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17483), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13832), 1,
      sym_attribute,
    STATE(20437), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651875] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17485), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13833), 1,
      sym_attribute,
    STATE(20268), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651914] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17487), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13834), 1,
      sym_attribute,
    STATE(19108), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [651953] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17489), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [651984] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13710), 1,
      aux_sym_expression_item_repeat1,
    STATE(13836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17491), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652015] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13756), 1,
      aux_sym_expression_item_repeat1,
    STATE(13837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17493), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652046] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17495), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13838), 1,
      sym_attribute,
    STATE(18630), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652085] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17497), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652116] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17499), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652147] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11257), 1,
      anon_sym_COLON2,
    STATE(13841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [652176] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17501), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13842), 1,
      sym_attribute,
    STATE(20473), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652215] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17503), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13843), 1,
      sym_attribute,
    STATE(20798), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652254] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17505), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652285] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17507), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652316] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17511), 1,
      anon_sym_COLON2,
    STATE(13846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17509), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_COLON2,
    STATE(13847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9728), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652370] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9730), 1,
      anon_sym_COLON2,
    STATE(13848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9732), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652397] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9734), 1,
      anon_sym_COLON2,
    STATE(13849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652424] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9738), 1,
      anon_sym_COLON2,
    STATE(13850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9740), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652451] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17515), 1,
      anon_sym_COLON2,
    STATE(13851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17513), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652478] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13758), 1,
      aux_sym_expression_item_repeat1,
    STATE(13852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17517), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652509] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17521), 1,
      anon_sym_COLON2,
    STATE(13853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17519), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652536] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13844), 1,
      aux_sym_expression_item_repeat1,
    STATE(13854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17523), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652567] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10337), 12,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_LBRACK_AT_AT,
  [652592] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16310), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652623] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13764), 1,
      aux_sym_expression_item_repeat1,
    STATE(13857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17525), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6793), 1,
      anon_sym_COLON2,
    STATE(13858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652681] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17527), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13859), 1,
      sym_attribute,
    STATE(18458), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652720] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13719), 1,
      aux_sym_expression_item_repeat1,
    STATE(13860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17529), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [652751] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17533), 1,
      anon_sym_COLON2,
    STATE(13861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17531), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652778] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17535), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13862), 1,
      sym_attribute,
    STATE(21160), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652817] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17537), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13863), 1,
      sym_attribute,
    STATE(19290), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652856] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17539), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13864), 1,
      sym_attribute,
    STATE(21083), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652895] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17541), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13865), 1,
      sym_attribute,
    STATE(20833), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [652934] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17545), 1,
      anon_sym_COLON2,
    STATE(13866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17543), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652961] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9758), 1,
      anon_sym_COLON2,
    STATE(13867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9760), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [652988] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17547), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653019] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17549), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13869), 1,
      sym_attribute,
    STATE(20923), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653058] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17551), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653089] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13871), 1,
      sym_attribute,
    STATE(13901), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17553), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653120] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13808), 1,
      aux_sym_expression_item_repeat1,
    STATE(13872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17555), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653151] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17557), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13873), 1,
      sym_attribute,
    STATE(18449), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653190] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17559), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653221] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17561), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13875), 1,
      sym_attribute,
    STATE(19754), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653260] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17563), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13876), 1,
      sym_attribute,
    STATE(18852), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653299] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17565), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13877), 1,
      sym_attribute,
    STATE(20770), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17569), 1,
      anon_sym_COLON2,
    STATE(13878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17567), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [653365] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9770), 1,
      anon_sym_COLON2,
    STATE(13879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9772), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [653392] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17571), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653423] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17573), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13881), 1,
      sym_attribute,
    STATE(20480), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653462] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13882), 1,
      sym_attribute,
    STATE(13886), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17575), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653493] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17577), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13883), 1,
      sym_attribute,
    STATE(19284), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653532] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17579), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13884), 1,
      sym_attribute,
    STATE(19378), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653571] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17581), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653602] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17583), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653633] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17585), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13887), 1,
      sym_attribute,
    STATE(19668), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653672] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17589), 1,
      anon_sym_COLON2,
    STATE(13888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17587), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [653699] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17591), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13889), 1,
      sym_attribute,
    STATE(21024), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653738] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17595), 1,
      anon_sym_COLON2,
    STATE(13890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17593), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [653765] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17597), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13891), 1,
      sym_attribute,
    STATE(20950), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653804] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17599), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13892), 1,
      sym_attribute,
    STATE(20223), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653843] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17601), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13893), 1,
      sym_attribute,
    STATE(21165), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [653882] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17603), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [653913] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17607), 1,
      anon_sym_COLON2,
    STATE(13895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17605), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [653940] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17611), 1,
      anon_sym_COLON2,
    STATE(13896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17609), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [653967] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17613), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13897), 1,
      sym_attribute,
    STATE(20140), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9058), 1,
      anon_sym_COLON2,
    STATE(13898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9060), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [654033] = 14,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9386), 1,
      anon_sym_PIPE,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12443), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      anon_sym_LBRACK,
    ACTIONS(17166), 1,
      anon_sym_LBRACE,
    ACTIONS(17615), 1,
      anon_sym_DOT_DOT,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(11391), 1,
      sym_variant_declaration,
    STATE(11522), 1,
      sym_record_declaration,
    STATE(12160), 1,
      sym_constructor_declaration,
    STATE(13899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12447), 2,
      anon_sym_true,
      anon_sym_false,
  [654078] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17617), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654109] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17619), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654140] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17621), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13902), 1,
      sym_attribute,
    STATE(19486), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654179] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17623), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13903), 1,
      sym_attribute,
    STATE(21015), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654218] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17625), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13904), 1,
      sym_attribute,
    STATE(19063), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654257] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17627), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654288] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17629), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13906), 1,
      sym_attribute,
    STATE(18729), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654327] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17631), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13907), 1,
      sym_attribute,
    STATE(21036), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654366] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13773), 1,
      aux_sym_expression_item_repeat1,
    STATE(13908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17633), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654397] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17635), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13909), 1,
      sym_attribute,
    STATE(19232), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654436] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17639), 1,
      anon_sym_COLON2,
    STATE(13910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17637), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [654463] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(16359), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654494] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17643), 1,
      anon_sym_COLON2,
    STATE(13912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17641), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [654521] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17645), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13913), 1,
      sym_attribute,
    STATE(19393), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654560] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17647), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13914), 1,
      sym_attribute,
    STATE(19445), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654599] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17651), 1,
      anon_sym_COLON2,
    STATE(13915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [654626] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17653), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13916), 1,
      sym_attribute,
    STATE(21194), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654665] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17655), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13917), 1,
      sym_attribute,
    STATE(18466), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654704] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17657), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13918), 1,
      sym_attribute,
    STATE(20998), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9622), 1,
      anon_sym_COLON2,
    STATE(13919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [654770] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17659), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654801] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13759), 1,
      aux_sym_expression_item_repeat1,
    STATE(13921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17661), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654832] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13805), 1,
      aux_sym_expression_item_repeat1,
    STATE(13922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17663), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654863] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7609), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [654894] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9626), 1,
      anon_sym_COLON2,
    STATE(13924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 11,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [654921] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4845), 1,
      anon_sym_LBRACK_PERCENT,
    ACTIONS(4847), 1,
      anon_sym_LBRACE_PERCENT,
    ACTIONS(10778), 1,
      anon_sym_LPAREN,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(17665), 1,
      anon_sym_RPAREN,
    STATE(9275), 1,
      sym__simple_module_expression,
    STATE(13925), 1,
      sym_attribute,
    STATE(19777), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9225), 5,
      sym_typed_module_expression,
      sym_packed_module,
      sym_parenthesized_module_expression,
      sym_extension,
      sym_quoted_extension,
  [654960] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11567), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11569), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [654986] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17667), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13927), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
    ACTIONS(8755), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8757), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [655014] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8757), 11,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
      aux_sym_attribute_id_token1,
  [655038] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11491), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11493), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655064] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17670), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655094] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13931), 1,
      sym_attribute,
    STATE(13942), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17672), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655124] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(10383), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(15656), 1,
      anon_sym_DASH_GT,
    STATE(13932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655152] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11483), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11485), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655178] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11571), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11573), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655204] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13930), 1,
      aux_sym_expression_item_repeat1,
    STATE(13935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17674), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655234] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11499), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11501), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655260] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11503), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11505), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655286] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11507), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11509), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655312] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17676), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655342] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11511), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11513), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655368] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11527), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11529), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655394] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17678), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655424] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9222), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9224), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11551), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11553), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655476] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11589), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655502] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11495), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11497), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655528] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11555), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11557), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655554] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13948), 1,
      sym_attribute,
    STATE(13960), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17680), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655584] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17682), 1,
      aux_sym_attribute_id_token1,
    STATE(13927), 1,
      aux_sym_attribute_id_repeat1,
    STATE(13949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8766), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8768), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [655614] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11487), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11489), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655640] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13939), 1,
      aux_sym_expression_item_repeat1,
    STATE(13951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17684), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655670] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11535), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11537), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655696] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8296), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8298), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655722] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17682), 1,
      aux_sym_attribute_id_token1,
    STATE(13949), 1,
      aux_sym_attribute_id_repeat1,
    STATE(13954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8772), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8774), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [655752] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9182), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(9184), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655778] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8288), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8290), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655804] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16347), 1,
      anon_sym_STAR,
    STATE(13957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 10,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_AMP,
  [655830] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8292), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8294), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655856] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13959), 1,
      sym_attribute,
    STATE(13973), 1,
      aux_sym_expression_item_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17686), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655886] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17688), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [655916] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11019), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655942] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11519), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11521), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655968] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8020), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(8022), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [655994] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8360), 11,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656018] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11481), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656044] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11531), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11533), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656070] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11539), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11541), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656096] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11577), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656122] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17692), 1,
      anon_sym_COLON,
    ACTIONS(17694), 1,
      anon_sym_COLON2,
    STATE(13969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17690), 9,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [656150] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11523), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11525), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656176] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8304), 11,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656200] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11563), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11565), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656226] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(6865), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(9773), 1,
      aux_sym_expression_item_repeat1,
    STATE(10536), 1,
      sym_item_attribute,
    STATE(13973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17696), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [656256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17698), 1,
      anon_sym_DOT,
    STATE(13974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11011), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656282] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11559), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11561), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11543), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11545), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656334] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11547), 5,
      anon_sym_and,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
      sym__lowercase_identifier,
    ACTIONS(11549), 6,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__uppercase_identifier,
  [656360] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8755), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(8757), 6,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
      aux_sym_attribute_id_token1,
  [656385] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10345), 10,
      anon_sym_LPAREN,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [656408] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17651), 1,
      anon_sym_COLON2,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    STATE(13980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 7,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_when,
  [656437] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17704), 1,
      anon_sym_constraint,
    STATE(14226), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13981), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [656464] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17477), 1,
      anon_sym_COLON2,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    STATE(13982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17475), 6,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_when,
  [656495] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12381), 1,
      anon_sym_LPAREN,
    ACTIONS(12383), 1,
      anon_sym_LBRACK,
    ACTIONS(17709), 1,
      anon_sym_private,
    ACTIONS(17711), 1,
      anon_sym_PIPE,
    STATE(11230), 1,
      sym_variant_declaration,
    STATE(11528), 1,
      sym__constructor_name,
    STATE(12387), 1,
      sym_constructor_declaration,
    STATE(13983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12385), 2,
      anon_sym_true,
      anon_sym_false,
  [656534] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11090), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656557] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11036), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656580] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11475), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11477), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(13986), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656621] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12381), 1,
      anon_sym_LPAREN,
    ACTIONS(12383), 1,
      anon_sym_LBRACK,
    ACTIONS(17711), 1,
      anon_sym_PIPE,
    ACTIONS(17717), 1,
      anon_sym_private,
    STATE(11195), 1,
      sym_variant_declaration,
    STATE(11528), 1,
      sym__constructor_name,
    STATE(12387), 1,
      sym_constructor_declaration,
    STATE(13987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12385), 2,
      anon_sym_true,
      anon_sym_false,
  [656660] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11072), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656683] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16977), 1,
      anon_sym_STAR,
    STATE(13989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [656708] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17651), 1,
      anon_sym_COLON2,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    STATE(13990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 8,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [656735] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_LBRACK,
    ACTIONS(17719), 1,
      anon_sym_private,
    ACTIONS(17721), 1,
      anon_sym_PIPE,
    STATE(11230), 1,
      sym_variant_declaration,
    STATE(12312), 1,
      sym__constructor_name,
    STATE(12907), 1,
      sym_constructor_declaration,
    STATE(13991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13190), 2,
      anon_sym_true,
      anon_sym_false,
  [656774] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11060), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656797] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8290), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656820] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16165), 1,
      anon_sym_DASH_GT,
    STATE(13994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 9,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_AMP,
  [656845] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11086), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656868] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(13996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11064), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [656891] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17723), 1,
      anon_sym_constraint,
    STATE(13997), 1,
      sym_attribute,
    STATE(14015), 1,
      aux_sym_type_binding_repeat1,
    STATE(14226), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12474), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [656920] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11447), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11449), 1,
      anon_sym_in,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(13998), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [656961] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11602), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11604), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(13999), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657002] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12367), 1,
      anon_sym_LPAREN,
    ACTIONS(12369), 1,
      anon_sym_LBRACK,
    ACTIONS(17725), 1,
      anon_sym_private,
    ACTIONS(17727), 1,
      anon_sym_PIPE,
    STATE(11195), 1,
      sym_variant_declaration,
    STATE(11303), 1,
      sym__constructor_name,
    STATE(12369), 1,
      sym_constructor_declaration,
    STATE(14000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12371), 2,
      anon_sym_true,
      anon_sym_false,
  [657041] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8298), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657064] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11608), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11610), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14002), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657105] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11082), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657128] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(14004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [657153] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12367), 1,
      anon_sym_LPAREN,
    ACTIONS(12369), 1,
      anon_sym_LBRACK,
    ACTIONS(17727), 1,
      anon_sym_PIPE,
    ACTIONS(17729), 1,
      anon_sym_private,
    STATE(11230), 1,
      sym_variant_declaration,
    STATE(11303), 1,
      sym__constructor_name,
    STATE(12369), 1,
      sym_constructor_declaration,
    STATE(14005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12371), 2,
      anon_sym_true,
      anon_sym_false,
  [657192] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17723), 1,
      anon_sym_constraint,
    STATE(14006), 1,
      sym_attribute,
    STATE(14025), 1,
      aux_sym_type_binding_repeat1,
    STATE(14226), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12468), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [657221] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4669), 1,
      anon_sym_COLON2,
    ACTIONS(17228), 1,
      anon_sym_DOT_DOT,
    STATE(14007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [657248] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_LBRACK,
    ACTIONS(17721), 1,
      anon_sym_PIPE,
    ACTIONS(17731), 1,
      anon_sym_private,
    STATE(11195), 1,
      sym_variant_declaration,
    STATE(12312), 1,
      sym__constructor_name,
    STATE(12907), 1,
      sym_constructor_declaration,
    STATE(14008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13190), 2,
      anon_sym_true,
      anon_sym_false,
  [657287] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12577), 1,
      anon_sym_LPAREN,
    ACTIONS(12579), 1,
      anon_sym_LBRACK,
    ACTIONS(17733), 1,
      anon_sym_private,
    ACTIONS(17735), 1,
      anon_sym_PIPE,
    STATE(11230), 1,
      sym_variant_declaration,
    STATE(11612), 1,
      sym__constructor_name,
    STATE(12554), 1,
      sym_constructor_declaration,
    STATE(14009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 2,
      anon_sym_true,
      anon_sym_false,
  [657326] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11030), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657349] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11612), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11614), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14011), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657390] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11026), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657413] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12577), 1,
      anon_sym_LPAREN,
    ACTIONS(12579), 1,
      anon_sym_LBRACK,
    ACTIONS(17735), 1,
      anon_sym_PIPE,
    ACTIONS(17737), 1,
      anon_sym_private,
    STATE(11195), 1,
      sym_variant_declaration,
    STATE(11612), 1,
      sym__constructor_name,
    STATE(12554), 1,
      sym_constructor_declaration,
    STATE(14013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 2,
      anon_sym_true,
      anon_sym_false,
  [657452] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11076), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657475] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17723), 1,
      anon_sym_constraint,
    STATE(13981), 1,
      aux_sym_type_binding_repeat1,
    STATE(14015), 1,
      sym_attribute,
    STATE(14226), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12482), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [657504] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8294), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657527] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11011), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657550] = 13,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_DASH_GT,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(11648), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11650), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14018), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(16279), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657591] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8022), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657614] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17741), 1,
      anon_sym_COLON2,
    STATE(14020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17739), 8,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_as,
      anon_sym_when,
  [657641] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11042), 10,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
  [657664] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17745), 1,
      anon_sym_COLON2,
    ACTIONS(17747), 1,
      anon_sym_as,
    STATE(14022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17743), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_when,
  [657697] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(17751), 1,
      anon_sym_COLON2,
    STATE(14023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17749), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
      anon_sym_when,
  [657730] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(14024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [657755] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17723), 1,
      anon_sym_constraint,
    STATE(13981), 1,
      aux_sym_type_binding_repeat1,
    STATE(14025), 1,
      sym_attribute,
    STATE(14226), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12478), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [657784] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17753), 1,
      sym__lowercase_identifier,
    ACTIONS(17755), 1,
      anon_sym_LPAREN,
    ACTIONS(17757), 1,
      anon_sym_LBRACK,
    ACTIONS(17759), 1,
      anon_sym_LBRACE,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    STATE(6597), 1,
      sym_field_path,
    STATE(14026), 1,
      sym_attribute,
    STATE(16828), 1,
      sym_indexing_operator_path,
    STATE(19959), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657822] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17763), 1,
      sym__lowercase_identifier,
    ACTIONS(17765), 1,
      anon_sym_LPAREN,
    ACTIONS(17767), 1,
      anon_sym_LBRACK,
    ACTIONS(17769), 1,
      anon_sym_LBRACE,
    STATE(3420), 1,
      sym_field_path,
    STATE(14027), 1,
      sym_attribute,
    STATE(16891), 1,
      sym_indexing_operator_path,
    STATE(18806), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657860] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9132), 1,
      anon_sym_COLON2,
    STATE(14028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [657884] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(17773), 1,
      anon_sym_LPAREN,
    ACTIONS(17775), 1,
      anon_sym_LBRACK,
    ACTIONS(17777), 1,
      anon_sym_LBRACE,
    STATE(7628), 1,
      sym_field_path,
    STATE(14029), 1,
      sym_attribute,
    STATE(16787), 1,
      sym_indexing_operator_path,
    STATE(18710), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [657922] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9154), 1,
      anon_sym_COLON2,
    STATE(14030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9156), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [657946] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_COLON2,
    STATE(14031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [657970] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17779), 1,
      sym__lowercase_identifier,
    ACTIONS(17781), 1,
      anon_sym_LPAREN,
    ACTIONS(17783), 1,
      anon_sym_LBRACK,
    ACTIONS(17785), 1,
      anon_sym_LBRACE,
    STATE(6043), 1,
      sym_field_path,
    STATE(14032), 1,
      sym_attribute,
    STATE(17020), 1,
      sym_indexing_operator_path,
    STATE(19661), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658008] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17787), 1,
      sym__lowercase_identifier,
    ACTIONS(17789), 1,
      anon_sym_LPAREN,
    ACTIONS(17791), 1,
      anon_sym_LBRACK,
    ACTIONS(17793), 1,
      anon_sym_LBRACE,
    STATE(3380), 1,
      sym_field_path,
    STATE(14033), 1,
      sym_attribute,
    STATE(16861), 1,
      sym_indexing_operator_path,
    STATE(18532), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658046] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9118), 1,
      anon_sym_COLON2,
    STATE(14034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [658070] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(16709), 1,
      anon_sym_DASH_GT,
    STATE(14035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [658094] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17795), 1,
      sym__lowercase_identifier,
    ACTIONS(17797), 1,
      anon_sym_LPAREN,
    ACTIONS(17799), 1,
      anon_sym_LBRACK,
    ACTIONS(17801), 1,
      anon_sym_LBRACE,
    STATE(10126), 1,
      sym_field_path,
    STATE(14036), 1,
      sym_attribute,
    STATE(16951), 1,
      sym_indexing_operator_path,
    STATE(19229), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658132] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17803), 1,
      anon_sym_LPAREN,
    ACTIONS(17805), 1,
      anon_sym_LBRACE,
    ACTIONS(17807), 1,
      sym__uppercase_identifier,
    STATE(9518), 1,
      sym__constructor_name,
    STATE(14037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14650), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [658166] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14038), 1,
      sym_attribute,
    STATE(18675), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [658196] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9178), 1,
      anon_sym_COLON2,
    STATE(14039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9180), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [658220] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17815), 1,
      sym__lowercase_identifier,
    ACTIONS(17817), 1,
      anon_sym_LPAREN,
    ACTIONS(17819), 1,
      anon_sym_LBRACK,
    ACTIONS(17821), 1,
      anon_sym_LBRACE,
    STATE(4103), 1,
      sym_field_path,
    STATE(14040), 1,
      sym_attribute,
    STATE(16896), 1,
      sym_indexing_operator_path,
    STATE(18860), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658258] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17823), 1,
      sym__lowercase_identifier,
    ACTIONS(17825), 1,
      anon_sym_LPAREN,
    ACTIONS(17827), 1,
      anon_sym_LBRACK,
    ACTIONS(17829), 1,
      anon_sym_LBRACE,
    STATE(3142), 1,
      sym_field_path,
    STATE(14041), 1,
      sym_attribute,
    STATE(17026), 1,
      sym_indexing_operator_path,
    STATE(19699), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658296] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17831), 1,
      sym__lowercase_identifier,
    ACTIONS(17833), 1,
      anon_sym_LPAREN,
    ACTIONS(17835), 1,
      anon_sym_LBRACK,
    ACTIONS(17837), 1,
      anon_sym_LBRACE,
    STATE(4948), 1,
      sym_field_path,
    STATE(14042), 1,
      sym_attribute,
    STATE(16848), 1,
      sym_indexing_operator_path,
    STATE(21246), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658334] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17071), 1,
      sym__uppercase_identifier,
    ACTIONS(17839), 1,
      anon_sym_LPAREN,
    ACTIONS(17841), 1,
      anon_sym_LBRACE,
    STATE(8437), 1,
      sym__constructor_name,
    STATE(14043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14886), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [658368] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17843), 1,
      sym__lowercase_identifier,
    ACTIONS(17845), 1,
      anon_sym_LPAREN,
    ACTIONS(17847), 1,
      anon_sym_LBRACK,
    ACTIONS(17849), 1,
      anon_sym_LBRACE,
    STATE(5267), 1,
      sym_field_path,
    STATE(14044), 1,
      sym_attribute,
    STATE(16757), 1,
      sym_indexing_operator_path,
    STATE(20034), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658406] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9218), 1,
      anon_sym_COLON2,
    STATE(14045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [658430] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11409), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [658452] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11108), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17851), 1,
      anon_sym_POUND,
    STATE(14047), 1,
      sym_attribute,
    STATE(14489), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11106), 3,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
  [658486] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17853), 1,
      sym__lowercase_identifier,
    ACTIONS(17855), 1,
      anon_sym_LPAREN,
    ACTIONS(17857), 1,
      anon_sym_LBRACK,
    ACTIONS(17859), 1,
      anon_sym_LBRACE,
    STATE(5678), 1,
      sym_field_path,
    STATE(14048), 1,
      sym_attribute,
    STATE(17032), 1,
      sym_indexing_operator_path,
    STATE(19736), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658524] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14049), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19665), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [658554] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17861), 1,
      anon_sym_LPAREN,
    ACTIONS(17863), 1,
      anon_sym_LBRACE,
    ACTIONS(17865), 1,
      sym__uppercase_identifier,
    STATE(14050), 1,
      sym_attribute,
    STATE(14121), 1,
      sym__constructor_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13702), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [658588] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7705), 1,
      anon_sym_LBRACK,
    ACTIONS(7709), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17841), 1,
      anon_sym_LBRACE,
    ACTIONS(17867), 1,
      anon_sym_LPAREN,
    ACTIONS(17869), 1,
      sym__uppercase_identifier,
    STATE(14051), 1,
      sym_attribute,
    STATE(14825), 1,
      sym__constructor_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14886), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [658622] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14052), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20626), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [658652] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5413), 1,
      anon_sym_LBRACK,
    ACTIONS(5427), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17871), 1,
      anon_sym_LPAREN,
    ACTIONS(17873), 1,
      anon_sym_LBRACE,
    ACTIONS(17875), 1,
      sym__uppercase_identifier,
    STATE(9027), 1,
      sym__constructor_name,
    STATE(14053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10558), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [658686] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14054), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20920), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [658716] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11289), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11405), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [658740] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17877), 1,
      sym__lowercase_identifier,
    ACTIONS(17879), 1,
      anon_sym_LPAREN,
    ACTIONS(17881), 1,
      anon_sym_LBRACK,
    ACTIONS(17883), 1,
      anon_sym_LBRACE,
    STATE(5252), 1,
      sym_field_path,
    STATE(14056), 1,
      sym_attribute,
    STATE(17037), 1,
      sym_indexing_operator_path,
    STATE(19773), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658778] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17885), 1,
      sym__lowercase_identifier,
    ACTIONS(17887), 1,
      anon_sym_LPAREN,
    ACTIONS(17889), 1,
      anon_sym_LBRACK,
    ACTIONS(17891), 1,
      anon_sym_LBRACE,
    STATE(6242), 1,
      sym_field_path,
    STATE(14057), 1,
      sym_attribute,
    STATE(16959), 1,
      sym_indexing_operator_path,
    STATE(19269), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658816] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14058), 1,
      sym_attribute,
    STATE(19026), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [658846] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17893), 1,
      sym__lowercase_identifier,
    ACTIONS(17895), 1,
      anon_sym_LPAREN,
    ACTIONS(17897), 1,
      anon_sym_LBRACK,
    ACTIONS(17899), 1,
      anon_sym_LBRACE,
    STATE(9666), 1,
      sym_field_path,
    STATE(14059), 1,
      sym_attribute,
    STATE(16904), 1,
      sym_indexing_operator_path,
    STATE(18914), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [658884] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17901), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [658906] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17875), 1,
      sym__uppercase_identifier,
    ACTIONS(17903), 1,
      anon_sym_LPAREN,
    ACTIONS(17905), 1,
      anon_sym_LBRACE,
    STATE(9027), 1,
      sym__constructor_name,
    STATE(14061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14031), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [658940] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14062), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20993), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [658970] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9226), 1,
      anon_sym_COLON2,
    STATE(14063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [658994] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17907), 1,
      sym__lowercase_identifier,
    ACTIONS(17909), 1,
      anon_sym_LPAREN,
    ACTIONS(17911), 1,
      anon_sym_LBRACK,
    ACTIONS(17913), 1,
      anon_sym_LBRACE,
    STATE(3369), 1,
      sym_field_path,
    STATE(14064), 1,
      sym_attribute,
    STATE(17045), 1,
      sym_indexing_operator_path,
    STATE(19809), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659032] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9198), 1,
      anon_sym_COLON2,
    STATE(14065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9200), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [659056] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17915), 9,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_initializer,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [659078] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14067), 1,
      sym_attribute,
    STATE(18673), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659108] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17917), 1,
      sym__lowercase_identifier,
    ACTIONS(17919), 1,
      anon_sym_LPAREN,
    ACTIONS(17921), 1,
      anon_sym_LBRACK,
    ACTIONS(17923), 1,
      anon_sym_LBRACE,
    STATE(4133), 1,
      sym_field_path,
    STATE(14068), 1,
      sym_attribute,
    STATE(16710), 1,
      sym_indexing_operator_path,
    STATE(21088), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659146] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9214), 1,
      anon_sym_COLON2,
    STATE(14069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [659170] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11409), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11413), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [659194] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17925), 1,
      sym__lowercase_identifier,
    ACTIONS(17927), 1,
      anon_sym_LPAREN,
    ACTIONS(17929), 1,
      anon_sym_LBRACK,
    ACTIONS(17931), 1,
      anon_sym_LBRACE,
    STATE(3404), 1,
      sym_field_path,
    STATE(14071), 1,
      sym_attribute,
    STATE(17053), 1,
      sym_indexing_operator_path,
    STATE(19837), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659232] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9078), 1,
      anon_sym_COLON2,
    STATE(14072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9080), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [659256] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11021), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11019), 7,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
      aux_sym_type_variable_token1,
  [659280] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9140), 1,
      anon_sym_COLON2,
    STATE(14074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [659304] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9186), 1,
      anon_sym_COLON2,
    STATE(14075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9188), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [659328] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14076), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19222), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659358] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17933), 1,
      sym__lowercase_identifier,
    ACTIONS(17935), 1,
      anon_sym_LPAREN,
    ACTIONS(17937), 1,
      anon_sym_LBRACK,
    ACTIONS(17939), 1,
      anon_sym_LBRACE,
    STATE(6267), 1,
      sym_field_path,
    STATE(14077), 1,
      sym_attribute,
    STATE(16967), 1,
      sym_indexing_operator_path,
    STATE(19309), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659396] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14078), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20842), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659426] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17941), 1,
      sym__lowercase_identifier,
    ACTIONS(17943), 1,
      anon_sym_LPAREN,
    ACTIONS(17945), 1,
      anon_sym_LBRACK,
    ACTIONS(17947), 1,
      anon_sym_LBRACE,
    STATE(5875), 1,
      sym_field_path,
    STATE(14079), 1,
      sym_attribute,
    STATE(16910), 1,
      sym_indexing_operator_path,
    STATE(18968), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659464] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17949), 1,
      sym__lowercase_identifier,
    ACTIONS(17951), 1,
      anon_sym_LPAREN,
    ACTIONS(17953), 1,
      anon_sym_LBRACK,
    ACTIONS(17955), 1,
      anon_sym_LBRACE,
    STATE(8337), 1,
      sym_field_path,
    STATE(14080), 1,
      sym_attribute,
    STATE(16866), 1,
      sym_indexing_operator_path,
    STATE(18588), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659502] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14081), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(21049), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659532] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17957), 1,
      anon_sym_as,
    STATE(14082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11251), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [659556] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11285), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [659578] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14084), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19965), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659608] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14085), 1,
      sym_attribute,
    STATE(18827), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659638] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17959), 1,
      sym__lowercase_identifier,
    ACTIONS(17961), 1,
      anon_sym_LPAREN,
    ACTIONS(17963), 1,
      anon_sym_LBRACK,
    ACTIONS(17965), 1,
      anon_sym_LBRACE,
    STATE(6853), 1,
      sym_field_path,
    STATE(14086), 1,
      sym_attribute,
    STATE(16810), 1,
      sym_indexing_operator_path,
    STATE(19246), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659676] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14087), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20813), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659706] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6851), 1,
      anon_sym_LBRACK,
    ACTIONS(6861), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17967), 1,
      anon_sym_LPAREN,
    ACTIONS(17969), 1,
      anon_sym_LBRACE,
    ACTIONS(17971), 1,
      sym__uppercase_identifier,
    STATE(7734), 1,
      sym__constructor_name,
    STATE(14088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7757), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [659740] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14089), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(21379), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659770] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7113), 1,
      anon_sym_LBRACK,
    ACTIONS(7121), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17973), 1,
      anon_sym_LPAREN,
    ACTIONS(17975), 1,
      anon_sym_LBRACE,
    ACTIONS(17977), 1,
      sym__uppercase_identifier,
    STATE(9191), 1,
      sym__constructor_name,
    STATE(14090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9204), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [659804] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14091), 1,
      sym_attribute,
    STATE(18838), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659834] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17979), 1,
      sym__lowercase_identifier,
    ACTIONS(17981), 1,
      anon_sym_LPAREN,
    ACTIONS(17983), 1,
      anon_sym_LBRACK,
    ACTIONS(17985), 1,
      anon_sym_LBRACE,
    STATE(3697), 1,
      sym_field_path,
    STATE(14092), 1,
      sym_attribute,
    STATE(16973), 1,
      sym_indexing_operator_path,
    STATE(19349), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [659872] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14093), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19969), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659902] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12367), 1,
      anon_sym_LPAREN,
    ACTIONS(12369), 1,
      anon_sym_LBRACK,
    ACTIONS(17727), 1,
      anon_sym_PIPE,
    STATE(11246), 1,
      sym_variant_declaration,
    STATE(11303), 1,
      sym__constructor_name,
    STATE(12369), 1,
      sym_constructor_declaration,
    STATE(14094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12371), 2,
      anon_sym_true,
      anon_sym_false,
  [659938] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14095), 1,
      sym_attribute,
    STATE(19019), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [659968] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10343), 4,
      anon_sym_module,
      anon_sym_sig,
      anon_sym_functor,
      sym__lowercase_identifier,
    ACTIONS(10345), 5,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PERCENT,
      anon_sym_LBRACE_PERCENT,
      sym__uppercase_identifier,
  [659992] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9062), 1,
      anon_sym_COLON2,
    STATE(14097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9064), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [660016] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17863), 1,
      anon_sym_LBRACE,
    ACTIONS(17987), 1,
      anon_sym_LPAREN,
    ACTIONS(17989), 1,
      sym__uppercase_identifier,
    STATE(8785), 1,
      sym__constructor_name,
    STATE(14098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13702), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [660050] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14099), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20161), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660080] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17991), 1,
      sym__lowercase_identifier,
    ACTIONS(17993), 1,
      anon_sym_LPAREN,
    ACTIONS(17995), 1,
      anon_sym_LBRACK,
    ACTIONS(17997), 1,
      anon_sym_LBRACE,
    STATE(7602), 1,
      sym_field_path,
    STATE(14100), 1,
      sym_attribute,
    STATE(16840), 1,
      sym_indexing_operator_path,
    STATE(20933), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660118] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14101), 1,
      sym_attribute,
    STATE(18507), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660148] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14102), 1,
      sym_attribute,
    STATE(18957), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660178] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [660200] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12367), 1,
      anon_sym_LPAREN,
    ACTIONS(12369), 1,
      anon_sym_LBRACK,
    ACTIONS(17727), 1,
      anon_sym_PIPE,
    STATE(10814), 1,
      sym_variant_declaration,
    STATE(11303), 1,
      sym__constructor_name,
    STATE(12369), 1,
      sym_constructor_declaration,
    STATE(14104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12371), 2,
      anon_sym_true,
      anon_sym_false,
  [660236] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14105), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19308), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660266] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14106), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19652), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660296] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14107), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20153), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660326] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17999), 1,
      sym__lowercase_identifier,
    ACTIONS(18001), 1,
      anon_sym_LPAREN,
    ACTIONS(18003), 1,
      anon_sym_LBRACK,
    ACTIONS(18005), 1,
      anon_sym_LBRACE,
    STATE(5116), 1,
      sym_field_path,
    STATE(14108), 1,
      sym_attribute,
    STATE(16916), 1,
      sym_indexing_operator_path,
    STATE(19022), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660364] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14109), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20375), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660394] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17863), 1,
      anon_sym_LBRACE,
    ACTIONS(18007), 1,
      anon_sym_LPAREN,
    ACTIONS(18009), 1,
      sym__uppercase_identifier,
    STATE(9253), 1,
      sym__constructor_name,
    STATE(14110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13702), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [660428] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17865), 1,
      sym__uppercase_identifier,
    ACTIONS(17905), 1,
      anon_sym_LBRACE,
    ACTIONS(18011), 1,
      anon_sym_LPAREN,
    STATE(14111), 1,
      sym_attribute,
    STATE(14121), 1,
      sym__constructor_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14031), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [660462] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14112), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20764), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660492] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18013), 1,
      sym__lowercase_identifier,
    ACTIONS(18015), 1,
      anon_sym_LPAREN,
    ACTIONS(18017), 1,
      anon_sym_LBRACK,
    ACTIONS(18019), 1,
      anon_sym_LBRACE,
    STATE(6291), 1,
      sym_field_path,
    STATE(14113), 1,
      sym_attribute,
    STATE(16978), 1,
      sym_indexing_operator_path,
    STATE(19389), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660530] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18021), 1,
      sym__lowercase_identifier,
    ACTIONS(18023), 1,
      anon_sym_LPAREN,
    ACTIONS(18025), 1,
      anon_sym_LBRACK,
    ACTIONS(18027), 1,
      anon_sym_LBRACE,
    STATE(4131), 1,
      sym_field_path,
    STATE(14114), 1,
      sym_attribute,
    STATE(16765), 1,
      sym_indexing_operator_path,
    STATE(20319), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [660568] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14115), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(21314), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660598] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18033), 1,
      sym__right_quoted_string_delimiter,
    STATE(14116), 1,
      sym_attribute,
    STATE(14252), 1,
      aux_sym_quoted_string_content_repeat1,
    STATE(20386), 1,
      sym_quoted_string_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18031), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(18029), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [660628] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14117), 1,
      sym_attribute,
    STATE(18906), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660658] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4675), 1,
      anon_sym_LBRACK,
    ACTIONS(4683), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18035), 1,
      anon_sym_LPAREN,
    ACTIONS(18037), 1,
      anon_sym_LBRACE,
    ACTIONS(18039), 1,
      sym__uppercase_identifier,
    STATE(5574), 1,
      sym__constructor_name,
    STATE(14118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5609), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [660692] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14119), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(21330), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660722] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14120), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19864), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660752] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 9,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_in,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_AT_AT,
  [660774] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
    ACTIONS(11481), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [660800] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14123), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19220), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660830] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7565), 1,
      anon_sym_LBRACK,
    ACTIONS(7577), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18041), 1,
      anon_sym_LPAREN,
    ACTIONS(18043), 1,
      anon_sym_LBRACE,
    ACTIONS(18045), 1,
      sym__uppercase_identifier,
    STATE(9172), 1,
      sym__constructor_name,
    STATE(14124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9155), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [660864] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14125), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20845), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660894] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9066), 1,
      anon_sym_COLON2,
    STATE(14126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9068), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [660918] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14127), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19888), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660948] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14128), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20066), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [660978] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9110), 1,
      anon_sym_COLON2,
    STATE(14129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [661002] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14130), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20085), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661032] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18047), 1,
      sym__lowercase_identifier,
    ACTIONS(18049), 1,
      anon_sym_LPAREN,
    ACTIONS(18051), 1,
      anon_sym_LBRACK,
    ACTIONS(18053), 1,
      anon_sym_LBRACE,
    STATE(4051), 1,
      sym_field_path,
    STATE(14131), 1,
      sym_attribute,
    STATE(16870), 1,
      sym_indexing_operator_path,
    STATE(18643), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661070] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14132), 1,
      sym_attribute,
    STATE(19002), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661100] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18055), 1,
      sym__lowercase_identifier,
    ACTIONS(18057), 1,
      anon_sym_LPAREN,
    ACTIONS(18059), 1,
      anon_sym_LBRACK,
    ACTIONS(18061), 1,
      anon_sym_LBRACE,
    STATE(3768), 1,
      sym_field_path,
    STATE(14133), 1,
      sym_attribute,
    STATE(16984), 1,
      sym_indexing_operator_path,
    STATE(19429), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661138] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4669), 1,
      anon_sym_COLON2,
    STATE(14134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [661162] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18063), 1,
      sym__lowercase_identifier,
    ACTIONS(18065), 1,
      anon_sym_LPAREN,
    ACTIONS(18067), 1,
      anon_sym_LBRACK,
    ACTIONS(18069), 1,
      anon_sym_LBRACE,
    STATE(5403), 1,
      sym_field_path,
    STATE(14135), 1,
      sym_attribute,
    STATE(16922), 1,
      sym_indexing_operator_path,
    STATE(19069), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661200] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14136), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19812), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661230] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18071), 1,
      sym__lowercase_identifier,
    ACTIONS(18073), 1,
      anon_sym_LPAREN,
    ACTIONS(18075), 1,
      anon_sym_LBRACK,
    ACTIONS(18077), 1,
      anon_sym_LBRACE,
    STATE(6949), 1,
      sym_field_path,
    STATE(14137), 1,
      sym_attribute,
    STATE(16821), 1,
      sym_indexing_operator_path,
    STATE(19651), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [661268] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14138), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(21040), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661298] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12577), 1,
      anon_sym_LPAREN,
    ACTIONS(12579), 1,
      anon_sym_LBRACK,
    ACTIONS(17735), 1,
      anon_sym_PIPE,
    STATE(10814), 1,
      sym_variant_declaration,
    STATE(11612), 1,
      sym__constructor_name,
    STATE(12554), 1,
      sym_constructor_declaration,
    STATE(14139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 2,
      anon_sym_true,
      anon_sym_false,
  [661334] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17957), 1,
      anon_sym_as,
    STATE(14140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11417), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [661358] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14141), 1,
      sym_attribute,
    STATE(18648), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661388] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6895), 1,
      anon_sym_LBRACK,
    ACTIONS(6905), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18079), 1,
      anon_sym_LPAREN,
    ACTIONS(18081), 1,
      anon_sym_LBRACE,
    ACTIONS(18083), 1,
      sym__uppercase_identifier,
    STATE(7862), 1,
      sym__constructor_name,
    STATE(14142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(7901), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [661422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7959), 1,
      anon_sym_POUND,
    STATE(14143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7961), 8,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      sym_hash_operator,
  [661446] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5023), 1,
      anon_sym_LBRACK,
    ACTIONS(5031), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18085), 1,
      anon_sym_LPAREN,
    ACTIONS(18087), 1,
      anon_sym_LBRACE,
    ACTIONS(18089), 1,
      sym__uppercase_identifier,
    STATE(5675), 1,
      sym__constructor_name,
    STATE(14144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5840), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [661480] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14145), 1,
      sym_attribute,
    STATE(18938), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661510] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14146), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19364), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661540] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11019), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_as,
      anon_sym_LBRACK_AT_AT,
  [661562] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14148), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19713), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661592] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14149), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(19893), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661622] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14150), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20002), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661652] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14151), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20024), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661682] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14152), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20047), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661712] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14153), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20069), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661742] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14154), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20104), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661772] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14155), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20142), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661802] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14156), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20181), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661832] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14157), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20228), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661862] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14158), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20263), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661892] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14159), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20318), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661922] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14160), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20368), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661952] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14161), 1,
      sym_attribute,
    STATE(19045), 1,
      sym_escape_sequence,
    STATE(20416), 1,
      sym_character_content,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [661982] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18091), 1,
      anon_sym_LPAREN,
    ACTIONS(18093), 1,
      anon_sym_LBRACK,
    STATE(11489), 1,
      sym_constructor_declaration,
    STATE(12222), 1,
      sym__constructor_name,
    STATE(14162), 1,
      sym_attribute,
    STATE(14333), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18095), 2,
      anon_sym_true,
      anon_sym_false,
  [662018] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(16703), 1,
      sym__uppercase_identifier,
    ACTIONS(17905), 1,
      anon_sym_LBRACE,
    ACTIONS(18097), 1,
      anon_sym_LPAREN,
    STATE(7156), 1,
      sym__constructor_name,
    STATE(14163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14031), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [662052] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(17773), 1,
      anon_sym_LPAREN,
    ACTIONS(17775), 1,
      anon_sym_LBRACK,
    ACTIONS(17777), 1,
      anon_sym_LBRACE,
    ACTIONS(18099), 1,
      sym__lowercase_identifier,
    STATE(7628), 1,
      sym_field_path,
    STATE(14164), 1,
      sym_attribute,
    STATE(16787), 1,
      sym_indexing_operator_path,
    STATE(20202), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662090] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9236), 1,
      anon_sym_COLON2,
    STATE(14165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9238), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662114] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9240), 1,
      anon_sym_COLON2,
    STATE(14166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9242), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662138] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12577), 1,
      anon_sym_LPAREN,
    ACTIONS(12579), 1,
      anon_sym_LBRACK,
    ACTIONS(17735), 1,
      anon_sym_PIPE,
    STATE(11246), 1,
      sym_variant_declaration,
    STATE(11612), 1,
      sym__constructor_name,
    STATE(12554), 1,
      sym_constructor_declaration,
    STATE(14167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 2,
      anon_sym_true,
      anon_sym_false,
  [662174] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_LBRACK,
    ACTIONS(17721), 1,
      anon_sym_PIPE,
    STATE(11246), 1,
      sym_variant_declaration,
    STATE(12312), 1,
      sym__constructor_name,
    STATE(12907), 1,
      sym_constructor_declaration,
    STATE(14168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13190), 2,
      anon_sym_true,
      anon_sym_false,
  [662210] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18101), 1,
      sym__lowercase_identifier,
    ACTIONS(18103), 1,
      anon_sym_LPAREN,
    ACTIONS(18105), 1,
      anon_sym_LBRACK,
    ACTIONS(18107), 1,
      anon_sym_LBRACE,
    STATE(7384), 1,
      sym_field_path,
    STATE(14169), 1,
      sym_attribute,
    STATE(16989), 1,
      sym_indexing_operator_path,
    STATE(19469), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662248] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9174), 1,
      anon_sym_COLON2,
    STATE(14170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662272] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9230), 1,
      anon_sym_COLON2,
    STATE(14171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9232), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662296] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_LBRACK,
    ACTIONS(17721), 1,
      anon_sym_PIPE,
    STATE(10814), 1,
      sym_variant_declaration,
    STATE(12312), 1,
      sym__constructor_name,
    STATE(12907), 1,
      sym_constructor_declaration,
    STATE(14172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13190), 2,
      anon_sym_true,
      anon_sym_false,
  [662332] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9164), 1,
      anon_sym_COLON2,
    STATE(14173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662356] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18109), 1,
      sym__lowercase_identifier,
    ACTIONS(18111), 1,
      anon_sym_LPAREN,
    ACTIONS(18113), 1,
      anon_sym_LBRACK,
    ACTIONS(18115), 1,
      anon_sym_LBRACE,
    STATE(6188), 1,
      sym_field_path,
    STATE(14174), 1,
      sym_attribute,
    STATE(16929), 1,
      sym_indexing_operator_path,
    STATE(19109), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662394] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9074), 1,
      anon_sym_COLON2,
    STATE(14175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9076), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662418] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18117), 1,
      sym__lowercase_identifier,
    ACTIONS(18119), 1,
      anon_sym_LPAREN,
    ACTIONS(18121), 1,
      anon_sym_LBRACK,
    ACTIONS(18123), 1,
      anon_sym_LBRACE,
    STATE(6491), 1,
      sym_field_path,
    STATE(14176), 1,
      sym_attribute,
    STATE(16854), 1,
      sym_indexing_operator_path,
    STATE(18465), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662456] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9098), 1,
      anon_sym_COLON2,
    STATE(14177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9100), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662480] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12381), 1,
      anon_sym_LPAREN,
    ACTIONS(12383), 1,
      anon_sym_LBRACK,
    ACTIONS(17711), 1,
      anon_sym_PIPE,
    STATE(11246), 1,
      sym_variant_declaration,
    STATE(11528), 1,
      sym__constructor_name,
    STATE(12387), 1,
      sym_constructor_declaration,
    STATE(14178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12385), 2,
      anon_sym_true,
      anon_sym_false,
  [662516] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9082), 1,
      anon_sym_COLON2,
    STATE(14179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9084), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662540] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12381), 1,
      anon_sym_LPAREN,
    ACTIONS(12383), 1,
      anon_sym_LBRACK,
    ACTIONS(17711), 1,
      anon_sym_PIPE,
    STATE(10814), 1,
      sym_variant_declaration,
    STATE(11528), 1,
      sym__constructor_name,
    STATE(12387), 1,
      sym_constructor_declaration,
    STATE(14180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12385), 2,
      anon_sym_true,
      anon_sym_false,
  [662576] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7274), 1,
      anon_sym_LBRACK,
    ACTIONS(7284), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17805), 1,
      anon_sym_LBRACE,
    ACTIONS(17869), 1,
      sym__uppercase_identifier,
    ACTIONS(18125), 1,
      anon_sym_LPAREN,
    STATE(14181), 1,
      sym_attribute,
    STATE(14825), 1,
      sym__constructor_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14650), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [662610] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18127), 1,
      anon_sym_LPAREN,
    ACTIONS(18129), 1,
      anon_sym_LBRACK,
    STATE(11489), 1,
      sym_constructor_declaration,
    STATE(12278), 1,
      sym__constructor_name,
    STATE(14182), 1,
      sym_attribute,
    STATE(14551), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18131), 2,
      anon_sym_true,
      anon_sym_false,
  [662646] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18133), 1,
      sym__lowercase_identifier,
    ACTIONS(18135), 1,
      anon_sym_LPAREN,
    ACTIONS(18137), 1,
      anon_sym_LBRACK,
    ACTIONS(18139), 1,
      anon_sym_LBRACE,
    STATE(6541), 1,
      sym_field_path,
    STATE(14183), 1,
      sym_attribute,
    STATE(16877), 1,
      sym_indexing_operator_path,
    STATE(18698), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662684] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7061), 1,
      anon_sym_LBRACK,
    ACTIONS(7071), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18141), 1,
      anon_sym_LPAREN,
    ACTIONS(18143), 1,
      anon_sym_LBRACE,
    ACTIONS(18145), 1,
      sym__uppercase_identifier,
    STATE(8084), 1,
      sym__constructor_name,
    STATE(14184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8153), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [662718] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9194), 1,
      anon_sym_COLON2,
    STATE(14185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662742] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18147), 1,
      sym__lowercase_identifier,
    ACTIONS(18149), 1,
      anon_sym_LPAREN,
    ACTIONS(18151), 1,
      anon_sym_LBRACK,
    ACTIONS(18153), 1,
      anon_sym_LBRACE,
    STATE(7006), 1,
      sym_field_path,
    STATE(14186), 1,
      sym_attribute,
    STATE(16832), 1,
      sym_indexing_operator_path,
    STATE(20478), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662780] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18155), 1,
      anon_sym_LPAREN,
    ACTIONS(18157), 1,
      anon_sym_LBRACK,
    ACTIONS(18161), 1,
      sym__uppercase_identifier,
    STATE(14187), 1,
      sym_attribute,
    STATE(14410), 1,
      sym__attribute,
    STATE(15183), 1,
      sym__constructor_name,
    STATE(15337), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18159), 2,
      anon_sym_true,
      anon_sym_false,
  [662816] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9070), 1,
      anon_sym_COLON2,
    STATE(14188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9072), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662840] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9206), 1,
      anon_sym_COLON2,
    STATE(14189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662864] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18163), 1,
      sym__lowercase_identifier,
    ACTIONS(18165), 1,
      anon_sym_LPAREN,
    ACTIONS(18167), 1,
      anon_sym_LBRACK,
    ACTIONS(18169), 1,
      anon_sym_LBRACE,
    STATE(7949), 1,
      sym_field_path,
    STATE(14190), 1,
      sym_attribute,
    STATE(16998), 1,
      sym_indexing_operator_path,
    STATE(19508), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [662902] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18171), 1,
      anon_sym_LPAREN,
    ACTIONS(18173), 1,
      anon_sym_LBRACK,
    STATE(11489), 1,
      sym_constructor_declaration,
    STATE(12768), 1,
      sym__constructor_name,
    STATE(14191), 1,
      sym_attribute,
    STATE(14616), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18175), 2,
      anon_sym_true,
      anon_sym_false,
  [662938] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9210), 1,
      anon_sym_COLON2,
    STATE(14192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9212), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [662962] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18177), 1,
      sym__lowercase_identifier,
    ACTIONS(18179), 1,
      anon_sym_LPAREN,
    ACTIONS(18181), 1,
      anon_sym_LBRACK,
    ACTIONS(18183), 1,
      anon_sym_LBRACE,
    STATE(6220), 1,
      sym_field_path,
    STATE(14193), 1,
      sym_attribute,
    STATE(16936), 1,
      sym_indexing_operator_path,
    STATE(19149), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663000] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14194), 1,
      sym_attribute,
    STATE(18471), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [663030] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18185), 1,
      anon_sym_LPAREN,
    ACTIONS(18187), 1,
      anon_sym_LBRACK,
    STATE(11489), 1,
      sym_constructor_declaration,
    STATE(12777), 1,
      sym__constructor_name,
    STATE(14195), 1,
      sym_attribute,
    STATE(14533), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18189), 2,
      anon_sym_true,
      anon_sym_false,
  [663066] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18191), 1,
      anon_sym_LPAREN,
    ACTIONS(18193), 1,
      anon_sym_DOT,
    STATE(14196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11421), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [663092] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4821), 1,
      anon_sym_LBRACK,
    ACTIONS(4837), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(16703), 1,
      sym__uppercase_identifier,
    ACTIONS(17863), 1,
      anon_sym_LBRACE,
    ACTIONS(18007), 1,
      anon_sym_LPAREN,
    STATE(7156), 1,
      sym__constructor_name,
    STATE(14197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13702), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [663126] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18195), 1,
      sym__lowercase_identifier,
    ACTIONS(18197), 1,
      anon_sym_LPAREN,
    ACTIONS(18199), 1,
      anon_sym_LBRACK,
    ACTIONS(18201), 1,
      anon_sym_LBRACE,
    STATE(4872), 1,
      sym_field_path,
    STATE(14198), 1,
      sym_attribute,
    STATE(17004), 1,
      sym_indexing_operator_path,
    STATE(19547), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663164] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7151), 1,
      anon_sym_LBRACK,
    ACTIONS(7161), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18203), 1,
      anon_sym_LPAREN,
    ACTIONS(18205), 1,
      anon_sym_LBRACE,
    ACTIONS(18207), 1,
      sym__uppercase_identifier,
    STATE(8365), 1,
      sym__constructor_name,
    STATE(14199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(8359), 3,
      sym_record_pattern,
      sym_list_pattern,
      sym_array_pattern,
  [663198] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5457), 1,
      anon_sym_LBRACK,
    ACTIONS(5467), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(17905), 1,
      anon_sym_LBRACE,
    ACTIONS(18009), 1,
      sym__uppercase_identifier,
    ACTIONS(18097), 1,
      anon_sym_LPAREN,
    STATE(9253), 1,
      sym__constructor_name,
    STATE(14200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14031), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [663232] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4969), 1,
      anon_sym_LBRACK,
    ACTIONS(4977), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18209), 1,
      anon_sym_LPAREN,
    ACTIONS(18211), 1,
      anon_sym_LBRACE,
    ACTIONS(18213), 1,
      sym__uppercase_identifier,
    STATE(5730), 1,
      sym__constructor_name,
    STATE(14201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5750), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [663266] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18215), 1,
      sym__lowercase_identifier,
    ACTIONS(18217), 1,
      anon_sym_LPAREN,
    ACTIONS(18219), 1,
      anon_sym_LBRACK,
    ACTIONS(18221), 1,
      anon_sym_LBRACE,
    STATE(6160), 1,
      sym_field_path,
    STATE(14202), 1,
      sym_attribute,
    STATE(16883), 1,
      sym_indexing_operator_path,
    STATE(18752), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663304] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4779), 1,
      anon_sym_LBRACK,
    ACTIONS(4787), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(18223), 1,
      anon_sym_LPAREN,
    ACTIONS(18225), 1,
      anon_sym_LBRACE,
    ACTIONS(18227), 1,
      sym__uppercase_identifier,
    STATE(5525), 1,
      sym__constructor_name,
    STATE(14203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(5670), 3,
      sym_record_binding_pattern,
      sym_list_binding_pattern,
      sym_array_binding_pattern,
  [663338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7963), 1,
      anon_sym_POUND,
    STATE(14204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7965), 8,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON2,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_with,
      sym_hash_operator,
  [663362] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9128), 1,
      anon_sym_COLON2,
    STATE(14205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9130), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663386] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18229), 1,
      anon_sym_LPAREN,
    ACTIONS(18231), 1,
      anon_sym_LBRACK,
    STATE(11489), 1,
      sym_constructor_declaration,
    STATE(12821), 1,
      sym__constructor_name,
    STATE(14206), 1,
      sym_attribute,
    STATE(14315), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18233), 2,
      anon_sym_true,
      anon_sym_false,
  [663422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9170), 1,
      anon_sym_COLON2,
    STATE(14207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9172), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663446] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18235), 1,
      sym__lowercase_identifier,
    ACTIONS(18237), 1,
      anon_sym_LPAREN,
    ACTIONS(18239), 1,
      anon_sym_LBRACK,
    ACTIONS(18241), 1,
      anon_sym_LBRACE,
    STATE(3131), 1,
      sym_field_path,
    STATE(14208), 1,
      sym_attribute,
    STATE(17008), 1,
      sym_indexing_operator_path,
    STATE(19585), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663484] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9136), 1,
      anon_sym_COLON2,
    STATE(14209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9138), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663508] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17957), 1,
      anon_sym_as,
    STATE(14210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11259), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [663532] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9086), 1,
      anon_sym_COLON2,
    STATE(14211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9088), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663556] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18243), 1,
      sym__lowercase_identifier,
    ACTIONS(18245), 1,
      anon_sym_LPAREN,
    ACTIONS(18247), 1,
      anon_sym_LBRACK,
    ACTIONS(18249), 1,
      anon_sym_LBRACE,
    STATE(6229), 1,
      sym_field_path,
    STATE(14212), 1,
      sym_attribute,
    STATE(16942), 1,
      sym_indexing_operator_path,
    STATE(19189), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663594] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17811), 1,
      aux_sym_character_content_token2,
    STATE(14213), 1,
      sym_attribute,
    STATE(18839), 1,
      sym_character_content,
    STATE(19045), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17809), 2,
      sym__null,
      aux_sym_character_content_token1,
    ACTIONS(17813), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [663624] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9102), 1,
      anon_sym_COLON2,
    STATE(14214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663648] = 12,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11451), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12025), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    ACTIONS(18251), 1,
      anon_sym_STAR,
    STATE(14215), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(15367), 1,
      aux_sym__constructor_argument_repeat1,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663686] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9106), 1,
      anon_sym_COLON2,
    STATE(14216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663710] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11289), 9,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [663732] = 12,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17761), 1,
      sym_indexing_operator,
    ACTIONS(18253), 1,
      sym__lowercase_identifier,
    ACTIONS(18255), 1,
      anon_sym_LPAREN,
    ACTIONS(18257), 1,
      anon_sym_LBRACK,
    ACTIONS(18259), 1,
      anon_sym_LBRACE,
    STATE(6344), 1,
      sym_field_path,
    STATE(14218), 1,
      sym_attribute,
    STATE(17013), 1,
      sym_indexing_operator_path,
    STATE(19623), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663770] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9146), 1,
      anon_sym_COLON2,
    STATE(14219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9148), 8,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [663794] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11593), 1,
      anon_sym_COLON2,
    ACTIONS(18261), 1,
      anon_sym_LPAREN,
    STATE(14301), 1,
      sym_module_parameter,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14220), 2,
      sym_attribute,
      aux_sym_module_binding_repeat1,
    ACTIONS(11591), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [663822] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18264), 1,
      anon_sym_SEMI,
    ACTIONS(18266), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14221), 1,
      sym_attribute,
    STATE(15922), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663857] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11267), 1,
      anon_sym_LBRACK,
    ACTIONS(11269), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11271), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18268), 1,
      sym__lowercase_identifier,
    ACTIONS(18270), 1,
      anon_sym_LPAREN,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    STATE(14222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14395), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [663890] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7913), 1,
      anon_sym_POUND,
    STATE(14223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 3,
      anon_sym_DOT,
      anon_sym_with,
      sym_hash_operator,
    ACTIONS(7965), 4,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [663915] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17218), 1,
      anon_sym_STAR,
    STATE(14224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 7,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [663938] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18274), 1,
      anon_sym_SEMI,
    ACTIONS(18276), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14225), 1,
      sym_attribute,
    STATE(16031), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [663973] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11778), 8,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [663994] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18278), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14227), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(12047), 6,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [664017] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18281), 1,
      anon_sym_COLON,
    STATE(14228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9038), 7,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [664040] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18283), 1,
      anon_sym_EQ,
    ACTIONS(18285), 1,
      anon_sym_RPAREN,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    STATE(14229), 1,
      sym_attribute,
    STATE(17547), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664075] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18289), 1,
      anon_sym_and,
    STATE(14230), 1,
      sym_attribute,
    STATE(14245), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13522), 6,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [664100] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18291), 1,
      anon_sym_SEMI,
    ACTIONS(18293), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14231), 1,
      sym_attribute,
    STATE(16164), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664135] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9958), 1,
      anon_sym_LBRACK,
    ACTIONS(9960), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9962), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18295), 1,
      sym__lowercase_identifier,
    ACTIONS(18297), 1,
      anon_sym_LPAREN,
    STATE(14232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(12428), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664168] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18299), 1,
      anon_sym_SEMI,
    ACTIONS(18301), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14233), 1,
      sym_attribute,
    STATE(16201), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664203] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9936), 1,
      anon_sym_LBRACK,
    ACTIONS(9938), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9940), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18303), 1,
      sym__lowercase_identifier,
    ACTIONS(18305), 1,
      anon_sym_LPAREN,
    STATE(14234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11553), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664236] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18307), 1,
      anon_sym_EQ,
    ACTIONS(18309), 1,
      anon_sym_RPAREN,
    STATE(14235), 1,
      sym_attribute,
    STATE(17211), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664271] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18311), 1,
      sym__lowercase_identifier,
    ACTIONS(18313), 1,
      anon_sym_LPAREN,
    STATE(14236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13149), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664304] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18315), 1,
      anon_sym_SEMI,
    ACTIONS(18317), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14237), 1,
      sym_attribute,
    STATE(17023), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664339] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18319), 1,
      anon_sym_SEMI,
    ACTIONS(18321), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14238), 1,
      sym_attribute,
    STATE(16927), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664374] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18323), 1,
      anon_sym_SEMI,
    ACTIONS(18325), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14239), 1,
      sym_attribute,
    STATE(16551), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664409] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18327), 1,
      anon_sym_SEMI,
    ACTIONS(18329), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14240), 1,
      sym_attribute,
    STATE(16490), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664444] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18331), 1,
      anon_sym_SEMI,
    ACTIONS(18333), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14241), 1,
      sym_attribute,
    STATE(16204), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664479] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18335), 1,
      anon_sym_SEMI,
    ACTIONS(18337), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14242), 1,
      sym_attribute,
    STATE(17184), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664514] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11339), 1,
      anon_sym_LBRACK,
    ACTIONS(11341), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11343), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18339), 1,
      sym__lowercase_identifier,
    ACTIONS(18341), 1,
      anon_sym_LPAREN,
    STATE(14243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11096), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664547] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9420), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9422), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18343), 1,
      sym__lowercase_identifier,
    ACTIONS(18345), 1,
      anon_sym_LPAREN,
    STATE(14244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10365), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664580] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18289), 1,
      anon_sym_and,
    STATE(14227), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(14245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13196), 6,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [664605] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9358), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9360), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10856), 1,
      anon_sym_LBRACK,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18347), 1,
      sym__lowercase_identifier,
    ACTIONS(18349), 1,
      anon_sym_LPAREN,
    STATE(14246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9765), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664638] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18351), 1,
      anon_sym_SEMI,
    ACTIONS(18353), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14247), 1,
      sym_attribute,
    STATE(16252), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664673] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18355), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [664694] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18357), 1,
      anon_sym_EQ,
    ACTIONS(18359), 1,
      anon_sym_RPAREN,
    STATE(14249), 1,
      sym_attribute,
    STATE(17829), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664729] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18361), 1,
      anon_sym_SEMI,
    ACTIONS(18363), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14250), 1,
      sym_attribute,
    STATE(15985), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664764] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18365), 1,
      anon_sym_SEMI,
    ACTIONS(18367), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14251), 1,
      sym_attribute,
    STATE(16824), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664799] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18369), 1,
      sym__right_quoted_string_delimiter,
    STATE(14252), 1,
      sym_attribute,
    STATE(14259), 1,
      aux_sym_quoted_string_content_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18031), 2,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(18029), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [664826] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11391), 1,
      anon_sym_LBRACK,
    ACTIONS(11393), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11395), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18371), 1,
      sym__lowercase_identifier,
    ACTIONS(18373), 1,
      anon_sym_LPAREN,
    STATE(14253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11482), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664859] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18375), 1,
      anon_sym_SEMI,
    ACTIONS(18377), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14254), 1,
      sym_attribute,
    STATE(16714), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664894] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18379), 8,
      anon_sym_constraint,
      anon_sym_val,
      anon_sym_end,
      anon_sym_inherit,
      anon_sym_method,
      anon_sym_LBRACK_AT_AT_AT,
      anon_sym_LBRACK_PERCENT_PERCENT,
      anon_sym_LBRACE_PERCENT_PERCENT,
  [664915] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18381), 1,
      anon_sym_SEMI,
    ACTIONS(18383), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14256), 1,
      sym_attribute,
    STATE(16292), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [664950] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18313), 1,
      anon_sym_LPAREN,
    ACTIONS(18385), 1,
      sym__lowercase_identifier,
    STATE(14257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13149), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [664983] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18387), 1,
      anon_sym_EQ,
    ACTIONS(18389), 1,
      anon_sym_RPAREN,
    STATE(14258), 1,
      sym_attribute,
    STATE(18281), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665018] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18397), 1,
      sym__right_quoted_string_delimiter,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18394), 2,
      sym__null,
      aux_sym_string_content_token2,
    STATE(14259), 2,
      sym_attribute,
      aux_sym_quoted_string_content_repeat1,
    ACTIONS(18391), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [665043] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18399), 1,
      anon_sym_SEMI,
    ACTIONS(18401), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14260), 1,
      sym_attribute,
    STATE(16129), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665078] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10667), 1,
      anon_sym_LBRACK,
    ACTIONS(10669), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10671), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18403), 1,
      sym__lowercase_identifier,
    ACTIONS(18405), 1,
      anon_sym_LPAREN,
    STATE(14261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13940), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665111] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18407), 1,
      anon_sym_COLON,
    STATE(14262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17690), 7,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [665134] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18409), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14263), 2,
      sym_attribute,
      aux_sym_type_binding_repeat1,
    ACTIONS(12395), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [665159] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7913), 1,
      anon_sym_POUND,
    STATE(14264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 3,
      anon_sym_DOT,
      anon_sym_with,
      sym_hash_operator,
    ACTIONS(7961), 4,
      anon_sym_EQ,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [665184] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10701), 1,
      anon_sym_LBRACK,
    ACTIONS(10703), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10705), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18412), 1,
      sym__lowercase_identifier,
    ACTIONS(18414), 1,
      anon_sym_LPAREN,
    STATE(14265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10199), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665217] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18313), 1,
      anon_sym_LPAREN,
    ACTIONS(18416), 1,
      sym__lowercase_identifier,
    STATE(14266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13149), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665250] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11317), 1,
      anon_sym_LBRACK,
    ACTIONS(11319), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11321), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18418), 1,
      sym__lowercase_identifier,
    ACTIONS(18420), 1,
      anon_sym_LPAREN,
    STATE(14267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10568), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665283] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11301), 1,
      anon_sym_LBRACK,
    ACTIONS(11303), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11305), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18422), 1,
      sym__lowercase_identifier,
    ACTIONS(18424), 1,
      anon_sym_LPAREN,
    STATE(14268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(10688), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665316] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18313), 1,
      anon_sym_LPAREN,
    ACTIONS(18426), 1,
      sym__lowercase_identifier,
    STATE(14269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13149), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665349] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18428), 1,
      anon_sym_SEMI,
    ACTIONS(18430), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14270), 1,
      sym_attribute,
    STATE(16962), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665384] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18432), 1,
      anon_sym_SEMI,
    ACTIONS(18434), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14271), 1,
      sym_attribute,
    STATE(16682), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665419] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18436), 1,
      anon_sym_SEMI,
    ACTIONS(18438), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14272), 1,
      sym_attribute,
    STATE(16430), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665454] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12213), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14273), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 2,
      anon_sym_STAR,
      anon_sym_LBRACK_AT_AT,
  [665487] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11361), 1,
      anon_sym_LBRACK,
    ACTIONS(11363), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11365), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18440), 1,
      sym__lowercase_identifier,
    ACTIONS(18442), 1,
      anon_sym_LPAREN,
    STATE(14274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11538), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665520] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11217), 1,
      anon_sym_LBRACK,
    ACTIONS(11219), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(11221), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18444), 1,
      sym__lowercase_identifier,
    ACTIONS(18446), 1,
      anon_sym_LPAREN,
    STATE(14275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11262), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665553] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10513), 1,
      anon_sym_LBRACK,
    ACTIONS(10515), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10517), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18448), 1,
      sym__lowercase_identifier,
    ACTIONS(18450), 1,
      anon_sym_LPAREN,
    STATE(14276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9452), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665586] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18452), 1,
      anon_sym_SEMI,
    ACTIONS(18454), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14277), 1,
      sym_attribute,
    STATE(16087), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665621] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9392), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9394), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10687), 1,
      anon_sym_LBRACK,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    ACTIONS(18458), 1,
      anon_sym_LPAREN,
    STATE(14278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9983), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665654] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18460), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(14279), 1,
      sym_attribute,
    STATE(14281), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12468), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [665681] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18460), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(14280), 1,
      sym_attribute,
    STATE(14282), 1,
      aux_sym_type_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12474), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [665708] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18460), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(14263), 1,
      aux_sym_type_binding_repeat1,
    STATE(14281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12478), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [665735] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18460), 1,
      anon_sym_constraint,
    STATE(9624), 1,
      sym_type_constraint,
    STATE(14263), 1,
      aux_sym_type_binding_repeat1,
    STATE(14282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12482), 5,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [665762] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18462), 1,
      anon_sym_SEMI,
    ACTIONS(18464), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14283), 1,
      sym_attribute,
    STATE(16379), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665797] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18466), 1,
      anon_sym_EQ,
    ACTIONS(18468), 1,
      anon_sym_RPAREN,
    STATE(14284), 1,
      sym_attribute,
    STATE(17716), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665832] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18313), 1,
      anon_sym_LPAREN,
    ACTIONS(18470), 1,
      sym__lowercase_identifier,
    STATE(14285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13149), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665865] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10818), 1,
      anon_sym_LBRACK,
    ACTIONS(10820), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10822), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18472), 1,
      sym__lowercase_identifier,
    ACTIONS(18474), 1,
      anon_sym_LPAREN,
    STATE(14286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13635), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [665898] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18476), 1,
      anon_sym_EQ,
    ACTIONS(18478), 1,
      anon_sym_RPAREN,
    STATE(14287), 1,
      sym_attribute,
    STATE(17766), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665933] = 11,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18480), 1,
      anon_sym_SEMI,
    ACTIONS(18482), 1,
      anon_sym_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14288), 1,
      sym_attribute,
    STATE(16002), 1,
      aux_sym_object_type_repeat1,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [665968] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7639), 1,
      anon_sym_LBRACK,
    ACTIONS(7655), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(7657), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18313), 1,
      anon_sym_LPAREN,
    ACTIONS(18484), 1,
      sym__lowercase_identifier,
    STATE(14289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13149), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [666001] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9324), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9326), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(10774), 1,
      anon_sym_LBRACK,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18486), 1,
      sym__lowercase_identifier,
    ACTIONS(18488), 1,
      anon_sym_LPAREN,
    STATE(14290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9904), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [666034] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9858), 1,
      anon_sym_LBRACK,
    ACTIONS(9860), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(9862), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18490), 1,
      sym__lowercase_identifier,
    ACTIONS(18492), 1,
      anon_sym_LPAREN,
    STATE(14291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13431), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [666067] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10794), 1,
      anon_sym_LBRACK,
    ACTIONS(10796), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10798), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18494), 1,
      sym__lowercase_identifier,
    ACTIONS(18496), 1,
      anon_sym_LPAREN,
    STATE(14292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9409), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [666100] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10009), 1,
      anon_sym_LBRACK,
    ACTIONS(10011), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10013), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18498), 1,
      sym__lowercase_identifier,
    ACTIONS(18500), 1,
      anon_sym_LPAREN,
    STATE(14293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11683), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [666133] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10733), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_LBRACK_GT,
    ACTIONS(10737), 1,
      anon_sym_LBRACK_LT,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18502), 1,
      sym__lowercase_identifier,
    ACTIONS(18504), 1,
      anon_sym_LPAREN,
    STATE(14294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9899), 2,
      sym_polymorphic_variant_type,
      sym_package_type,
  [666166] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9036), 1,
      anon_sym_PIPE,
    ACTIONS(18506), 1,
      anon_sym_COLON,
    STATE(14295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9038), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [666190] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14296), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15925), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [666220] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18510), 1,
      anon_sym_RPAREN,
    STATE(14297), 1,
      sym_attribute,
    STATE(21347), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666252] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18512), 1,
      anon_sym_COLON2,
    STATE(14298), 1,
      sym_attribute,
    STATE(17572), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 5,
      anon_sym_SEMI,
      anon_sym_GT,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [666276] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11413), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [666296] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18514), 1,
      anon_sym_RPAREN,
    STATE(14300), 1,
      sym_attribute,
    STATE(21367), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666328] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12315), 1,
      anon_sym_COLON2,
    STATE(14301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12313), 6,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [666350] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12072), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [666370] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14303), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16309), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    STATE(20981), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666402] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14304), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16314), 1,
      sym_field_binding_pattern,
    STATE(18674), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666434] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18516), 1,
      anon_sym_DASH_GT,
    ACTIONS(18518), 1,
      anon_sym_when,
    STATE(14305), 1,
      sym_attribute,
    STATE(18601), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666466] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18520), 1,
      anon_sym_RPAREN,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    STATE(14306), 1,
      sym_attribute,
    STATE(19700), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666498] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(18530), 1,
      anon_sym_DASH_GT,
    ACTIONS(18532), 1,
      anon_sym_STAR,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14307), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666530] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18539), 1,
      anon_sym_RBRACK,
    ACTIONS(18541), 1,
      anon_sym_SEMI,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14308), 1,
      sym_attribute,
    STATE(16071), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666562] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18551), 1,
      anon_sym_SEMI,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18557), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14309), 1,
      sym_attribute,
    STATE(16076), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666594] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18559), 1,
      anon_sym_DASH_GT,
    STATE(14310), 1,
      sym_attribute,
    STATE(21363), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666626] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18561), 1,
      anon_sym_DASH_GT,
    STATE(14311), 1,
      sym_attribute,
    STATE(20947), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666658] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    STATE(14312), 1,
      sym_attribute,
    STATE(18490), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11409), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
    ACTIONS(11413), 3,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [666684] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18563), 1,
      anon_sym_RPAREN,
    STATE(14313), 1,
      sym_attribute,
    STATE(18476), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666716] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18565), 1,
      anon_sym_RPAREN,
    STATE(14314), 1,
      sym_attribute,
    STATE(18483), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666748] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(18229), 1,
      anon_sym_LPAREN,
    ACTIONS(18231), 1,
      anon_sym_LBRACK,
    STATE(11440), 1,
      sym_constructor_declaration,
    STATE(12821), 1,
      sym__constructor_name,
    STATE(14315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18233), 2,
      anon_sym_true,
      anon_sym_false,
  [666778] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18567), 1,
      anon_sym_DASH_GT,
    STATE(14316), 1,
      sym_attribute,
    STATE(20549), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666810] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18569), 1,
      anon_sym_DASH_GT,
    STATE(14317), 1,
      sym_attribute,
    STATE(19090), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666842] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18571), 1,
      anon_sym_RPAREN,
    STATE(14318), 1,
      sym_attribute,
    STATE(18543), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666874] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18573), 1,
      anon_sym_RPAREN,
    STATE(14319), 1,
      sym_attribute,
    STATE(18550), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666906] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17230), 1,
      anon_sym_DASH_GT,
    STATE(14320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 6,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_constraint,
      anon_sym_with,
      anon_sym_as,
  [666928] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11575), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11577), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [666950] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18577), 1,
      anon_sym__,
    ACTIONS(18579), 1,
      anon_sym_RBRACE,
    STATE(14322), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [666982] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18581), 1,
      anon_sym_RPAREN,
    STATE(14323), 1,
      sym_attribute,
    STATE(20951), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667014] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18583), 1,
      anon_sym_RPAREN,
    STATE(14324), 1,
      sym_attribute,
    STATE(18598), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667046] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18585), 1,
      anon_sym__,
    ACTIONS(18587), 1,
      anon_sym_RBRACE,
    STATE(14325), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667078] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18589), 1,
      anon_sym_RPAREN,
    STATE(14326), 1,
      sym_attribute,
    STATE(18605), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667110] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18591), 1,
      anon_sym_RPAREN,
    STATE(14327), 1,
      sym_attribute,
    STATE(19307), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667142] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18593), 1,
      anon_sym_DASH_GT,
    STATE(14328), 1,
      sym_attribute,
    STATE(19735), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667174] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18595), 1,
      anon_sym_RPAREN,
    STATE(14329), 1,
      sym_attribute,
    STATE(18653), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667206] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18597), 1,
      anon_sym_RPAREN,
    STATE(14330), 1,
      sym_attribute,
    STATE(18660), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667238] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18599), 1,
      anon_sym_DASH_GT,
    STATE(14331), 1,
      sym_attribute,
    STATE(18832), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667270] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18601), 1,
      anon_sym_RPAREN,
    STATE(14332), 1,
      sym_attribute,
    STATE(19334), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667302] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(18091), 1,
      anon_sym_LPAREN,
    ACTIONS(18093), 1,
      anon_sym_LBRACK,
    STATE(11440), 1,
      sym_constructor_declaration,
    STATE(12222), 1,
      sym__constructor_name,
    STATE(14333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18095), 2,
      anon_sym_true,
      anon_sym_false,
  [667332] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11612), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11614), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14334), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667364] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18603), 1,
      anon_sym_RPAREN,
    STATE(14335), 1,
      sym_attribute,
    STATE(18708), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667396] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18605), 1,
      anon_sym_RPAREN,
    STATE(14336), 1,
      sym_attribute,
    STATE(18715), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667428] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18468), 1,
      anon_sym_RPAREN,
    STATE(14337), 1,
      sym_attribute,
    STATE(18867), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667460] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18611), 1,
      anon_sym_RBRACK,
    ACTIONS(18613), 1,
      anon_sym_SEMI,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14338), 1,
      sym_attribute,
    STATE(16355), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667492] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(18617), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14339), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667524] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18623), 1,
      anon_sym_SEMI,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18629), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14340), 1,
      sym_attribute,
    STATE(16360), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667556] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18631), 1,
      anon_sym_RPAREN,
    STATE(14341), 1,
      sym_attribute,
    STATE(18893), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667588] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18633), 1,
      anon_sym_RBRACK,
    ACTIONS(18635), 1,
      anon_sym_SEMI,
    STATE(14342), 1,
      sym_attribute,
    STATE(16362), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667620] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18637), 1,
      anon_sym_RPAREN,
    STATE(14343), 1,
      sym_attribute,
    STATE(20137), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667652] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18639), 1,
      anon_sym_SEMI,
    ACTIONS(18641), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14344), 1,
      sym_attribute,
    STATE(16366), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667684] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18643), 1,
      anon_sym_RPAREN,
    STATE(14345), 1,
      sym_attribute,
    STATE(18762), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667716] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18645), 1,
      anon_sym_RBRACK,
    ACTIONS(18647), 1,
      anon_sym_SEMI,
    STATE(14346), 1,
      sym_attribute,
    STATE(16419), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667748] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18649), 1,
      anon_sym__,
    ACTIONS(18651), 1,
      anon_sym_RBRACE,
    STATE(14347), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667780] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18653), 1,
      anon_sym_RPAREN,
    STATE(14348), 1,
      sym_attribute,
    STATE(18769), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667812] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18655), 1,
      anon_sym_DASH_GT,
    STATE(14349), 1,
      sym_attribute,
    STATE(20870), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667844] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18657), 1,
      anon_sym__,
    ACTIONS(18659), 1,
      anon_sym_RBRACE,
    STATE(14350), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667876] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14351), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16009), 1,
      sym_field_pattern,
    STATE(18642), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667908] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14352), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16336), 1,
      sym_field_binding_pattern,
    STATE(19756), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [667940] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14353), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18661), 2,
      anon_sym_SEMI,
      anon_sym_GT,
  [667970] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18663), 1,
      anon_sym_RPAREN,
    STATE(14354), 1,
      sym_attribute,
    STATE(18816), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668002] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(18665), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14355), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668034] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18667), 1,
      anon_sym_RPAREN,
    STATE(14356), 1,
      sym_attribute,
    STATE(18823), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668066] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18669), 1,
      anon_sym_DASH_GT,
    STATE(14357), 1,
      sym_attribute,
    STATE(20589), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668098] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4669), 1,
      anon_sym_PIPE,
    ACTIONS(18671), 1,
      anon_sym_DOT_DOT,
    STATE(14358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [668122] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18673), 1,
      anon_sym_RPAREN,
    STATE(14359), 1,
      sym_attribute,
    STATE(18870), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668154] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18675), 1,
      anon_sym_SEMI,
    ACTIONS(18677), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14360), 1,
      sym_attribute,
    STATE(16454), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668186] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18679), 1,
      anon_sym_RPAREN,
    STATE(14361), 1,
      sym_attribute,
    STATE(18877), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668218] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18681), 1,
      anon_sym__,
    ACTIONS(18683), 1,
      anon_sym_RBRACE,
    STATE(14362), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668250] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18685), 1,
      anon_sym__,
    ACTIONS(18687), 1,
      anon_sym_RBRACE,
    STATE(14363), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668282] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18689), 1,
      anon_sym_DASH_GT,
    STATE(14364), 1,
      sym_attribute,
    STATE(21230), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668314] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18691), 1,
      anon_sym_RPAREN,
    STATE(14365), 1,
      sym_attribute,
    STATE(18924), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668346] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18693), 1,
      anon_sym_RPAREN,
    STATE(14366), 1,
      sym_attribute,
    STATE(18931), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668378] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11499), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11501), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [668400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9036), 1,
      anon_sym_COLON2,
    ACTIONS(18695), 1,
      anon_sym_COLON,
    STATE(14368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9038), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [668424] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12443), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(11290), 1,
      sym__constructor_name,
    STATE(14369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12447), 2,
      anon_sym_true,
      anon_sym_false,
  [668454] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18697), 1,
      anon_sym__,
    ACTIONS(18699), 1,
      anon_sym_RBRACE,
    STATE(14370), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668486] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18701), 1,
      anon_sym_RPAREN,
    STATE(14371), 1,
      sym_attribute,
    STATE(18978), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668518] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18703), 1,
      anon_sym_RPAREN,
    STATE(14372), 1,
      sym_attribute,
    STATE(18985), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668550] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14373), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(16058), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [668580] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12273), 1,
      anon_sym_COLON2,
    STATE(14374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12271), 6,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [668602] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11503), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11505), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [668624] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18705), 1,
      anon_sym__,
    ACTIONS(18707), 1,
      anon_sym_RBRACE,
    STATE(14376), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668656] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18709), 1,
      anon_sym__,
    ACTIONS(18711), 1,
      anon_sym_RBRACE,
    STATE(14377), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668688] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18713), 1,
      anon_sym_DASH_GT,
    ACTIONS(18715), 1,
      anon_sym_with,
    STATE(14378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13704), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [668712] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18717), 1,
      anon_sym_RPAREN,
    STATE(14379), 1,
      sym_attribute,
    STATE(19031), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668744] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18719), 1,
      anon_sym__,
    ACTIONS(18721), 1,
      anon_sym_RBRACE,
    STATE(14380), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668776] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18723), 1,
      anon_sym_RPAREN,
    STATE(14381), 1,
      sym_attribute,
    STATE(19038), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668808] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18725), 1,
      anon_sym_RPAREN,
    STATE(14382), 1,
      sym_attribute,
    STATE(21185), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668840] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18359), 1,
      anon_sym_RPAREN,
    STATE(14383), 1,
      sym_attribute,
    STATE(20366), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668872] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12263), 1,
      anon_sym_LPAREN,
    ACTIONS(12265), 1,
      anon_sym_LBRACK,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(11219), 1,
      sym__constructor_name,
    STATE(14384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12267), 2,
      anon_sym_true,
      anon_sym_false,
  [668902] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18727), 1,
      anon_sym_RPAREN,
    STATE(14385), 1,
      sym_attribute,
    STATE(19074), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668934] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11507), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11509), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [668956] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18729), 1,
      anon_sym_RPAREN,
    STATE(14387), 1,
      sym_attribute,
    STATE(19080), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [668988] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18731), 1,
      anon_sym__,
    ACTIONS(18733), 1,
      anon_sym_RBRACE,
    STATE(14388), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669020] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18735), 1,
      anon_sym_RPAREN,
    STATE(14389), 1,
      sym_attribute,
    STATE(19114), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669052] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18737), 1,
      anon_sym_RPAREN,
    STATE(14390), 1,
      sym_attribute,
    STATE(19120), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669084] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18739), 1,
      anon_sym_DASH_GT,
    STATE(14391), 1,
      sym_attribute,
    STATE(18587), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669116] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18741), 1,
      anon_sym_RPAREN,
    STATE(14392), 1,
      sym_attribute,
    STATE(19154), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669148] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18743), 1,
      anon_sym_RPAREN,
    STATE(14393), 1,
      sym_attribute,
    STATE(19160), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669180] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17743), 3,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [669208] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11511), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11513), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [669230] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 5,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [669254] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    STATE(14397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 6,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [669276] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17475), 4,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [669302] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17739), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [669324] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18745), 1,
      anon_sym_RPAREN,
    STATE(14400), 1,
      sym_attribute,
    STATE(19194), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669356] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18747), 1,
      anon_sym_RPAREN,
    STATE(14401), 1,
      sym_attribute,
    STATE(21324), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669388] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18749), 1,
      anon_sym_RPAREN,
    STATE(14402), 1,
      sym_attribute,
    STATE(19200), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669420] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(18751), 1,
      anon_sym_EQ,
    ACTIONS(18753), 1,
      anon_sym_COLON_EQ,
    STATE(14403), 1,
      sym_attribute,
    STATE(15069), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13080), 2,
      anon_sym_and,
      anon_sym_in,
  [669450] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14404), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16559), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    STATE(20032), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669482] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14405), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16564), 1,
      sym_field_binding_pattern,
    STATE(18941), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669514] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18755), 1,
      anon_sym_RPAREN,
    STATE(14406), 1,
      sym_attribute,
    STATE(19234), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669546] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18757), 1,
      anon_sym_RPAREN,
    STATE(14407), 1,
      sym_attribute,
    STATE(19240), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669578] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18713), 1,
      anon_sym_DASH_GT,
    ACTIONS(18715), 1,
      anon_sym_with,
    STATE(14408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13696), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [669602] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18759), 1,
      anon_sym_DASH_GT,
    STATE(14409), 1,
      sym_attribute,
    STATE(20291), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669634] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18155), 1,
      anon_sym_LPAREN,
    ACTIONS(18157), 1,
      anon_sym_LBRACK,
    ACTIONS(18161), 1,
      sym__uppercase_identifier,
    STATE(14410), 1,
      sym_attribute,
    STATE(15183), 1,
      sym__constructor_name,
    STATE(15404), 1,
      sym_constructor_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18159), 2,
      anon_sym_true,
      anon_sym_false,
  [669664] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18761), 1,
      anon_sym_RPAREN,
    STATE(14411), 1,
      sym_attribute,
    STATE(19274), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669696] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9044), 1,
      anon_sym_PIPE,
    STATE(14412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9046), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [669718] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18763), 1,
      anon_sym_RPAREN,
    STATE(14413), 1,
      sym_attribute,
    STATE(20873), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669750] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18765), 1,
      anon_sym_RPAREN,
    STATE(14414), 1,
      sym_attribute,
    STATE(19280), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669782] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18767), 1,
      anon_sym_RBRACK,
    ACTIONS(18769), 1,
      anon_sym_SEMI,
    STATE(14415), 1,
      sym_attribute,
    STATE(16547), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669814] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18771), 1,
      anon_sym_SEMI,
    ACTIONS(18773), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14416), 1,
      sym_attribute,
    STATE(16595), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669846] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11587), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11589), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [669868] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18775), 1,
      anon_sym_RPAREN,
    STATE(14418), 1,
      sym_attribute,
    STATE(19701), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669900] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18777), 1,
      anon_sym_RPAREN,
    STATE(14419), 1,
      sym_attribute,
    STATE(19314), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669932] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12149), 1,
      anon_sym_COLON2,
    STATE(14420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12147), 6,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [669954] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18779), 1,
      anon_sym_RPAREN,
    STATE(14421), 1,
      sym_attribute,
    STATE(18820), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [669986] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18781), 1,
      anon_sym_RPAREN,
    STATE(14422), 1,
      sym_attribute,
    STATE(19320), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670018] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18783), 1,
      anon_sym__,
    ACTIONS(18785), 1,
      anon_sym_RBRACE,
    STATE(14423), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670050] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18787), 1,
      anon_sym_RPAREN,
    STATE(14424), 1,
      sym_attribute,
    STATE(19354), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670082] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18789), 1,
      anon_sym_RPAREN,
    STATE(14425), 1,
      sym_attribute,
    STATE(19360), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670114] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18791), 1,
      anon_sym_RBRACK,
    ACTIONS(18793), 1,
      anon_sym_SEMI,
    STATE(14426), 1,
      sym_attribute,
    STATE(16798), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670146] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18795), 1,
      anon_sym_SEMI,
    ACTIONS(18797), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14427), 1,
      sym_attribute,
    STATE(16924), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670178] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 5,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [670202] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    STATE(14429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 6,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [670224] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18799), 1,
      anon_sym_RPAREN,
    STATE(14430), 1,
      sym_attribute,
    STATE(19394), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670256] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18801), 1,
      anon_sym_RPAREN,
    STATE(14431), 1,
      sym_attribute,
    STATE(19400), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670288] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 4,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [670314] = 9,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(18803), 1,
      anon_sym_EQ,
    ACTIONS(18805), 1,
      anon_sym_COLON_EQ,
    STATE(14433), 1,
      sym_attribute,
    STATE(15189), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13098), 2,
      anon_sym_and,
      anon_sym_in,
  [670344] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 6,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
  [670366] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18713), 1,
      anon_sym_DASH_GT,
    ACTIONS(18715), 1,
      anon_sym_with,
    STATE(14435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13721), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [670390] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18807), 1,
      anon_sym_RPAREN,
    STATE(14436), 1,
      sym_attribute,
    STATE(19739), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670422] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18809), 1,
      anon_sym_RPAREN,
    STATE(14437), 1,
      sym_attribute,
    STATE(19434), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670454] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18811), 1,
      anon_sym_RPAREN,
    STATE(14438), 1,
      sym_attribute,
    STATE(19440), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670486] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12057), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [670506] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18813), 1,
      anon_sym__,
    ACTIONS(18815), 1,
      anon_sym_RBRACE,
    STATE(14440), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670538] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17447), 1,
      anon_sym_STAR,
    STATE(14441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11158), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_GT,
  [670560] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18817), 1,
      anon_sym_RPAREN,
    STATE(14442), 1,
      sym_attribute,
    STATE(19474), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670592] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18819), 1,
      anon_sym_RPAREN,
    STATE(14443), 1,
      sym_attribute,
    STATE(19480), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670624] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11447), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11449), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14444), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670656] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18821), 1,
      anon_sym_RPAREN,
    STATE(14445), 1,
      sym_attribute,
    STATE(19513), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670688] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18823), 1,
      anon_sym_RPAREN,
    STATE(14446), 1,
      sym_attribute,
    STATE(19519), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670720] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9026), 1,
      anon_sym_PIPE,
    STATE(14447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9028), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [670742] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18478), 1,
      anon_sym_RPAREN,
    STATE(14448), 1,
      sym_attribute,
    STATE(18596), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670774] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18825), 1,
      anon_sym_RPAREN,
    STATE(14449), 1,
      sym_attribute,
    STATE(19552), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670806] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18827), 1,
      anon_sym_RBRACK,
    ACTIONS(18829), 1,
      anon_sym_SEMI,
    STATE(14450), 1,
      sym_attribute,
    STATE(16349), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670838] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18831), 1,
      anon_sym_RPAREN,
    STATE(14451), 1,
      sym_attribute,
    STATE(19558), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670870] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18833), 1,
      anon_sym_DASH_GT,
    STATE(14452), 1,
      sym_attribute,
    STATE(18919), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670902] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18835), 1,
      anon_sym__,
    ACTIONS(18837), 1,
      anon_sym_RBRACE,
    STATE(14453), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670934] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18839), 1,
      anon_sym_RPAREN,
    STATE(14454), 1,
      sym_attribute,
    STATE(19590), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670966] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18841), 1,
      anon_sym_RPAREN,
    STATE(14455), 1,
      sym_attribute,
    STATE(19596), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [670998] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18389), 1,
      anon_sym_RPAREN,
    STATE(14456), 1,
      sym_attribute,
    STATE(20256), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671030] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18843), 1,
      anon_sym_DASH_GT,
    STATE(14457), 1,
      sym_attribute,
    STATE(19032), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671062] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14458), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16799), 1,
      sym_field_binding_pattern,
    STATE(18700), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671094] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18845), 1,
      anon_sym_DASH_GT,
    STATE(14459), 1,
      sym_attribute,
    STATE(20706), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671126] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18847), 1,
      anon_sym_RBRACK,
    ACTIONS(18849), 1,
      anon_sym_SEMI,
    STATE(14460), 1,
      sym_attribute,
    STATE(16422), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671158] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14461), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16880), 1,
      sym_field_pattern,
    STATE(18911), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671190] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14462), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16885), 1,
      sym_field_binding_pattern,
    STATE(18479), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671222] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18851), 1,
      anon_sym_RPAREN,
    STATE(14463), 1,
      sym_attribute,
    STATE(19628), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671254] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18853), 1,
      anon_sym_RPAREN,
    STATE(14464), 1,
      sym_attribute,
    STATE(19634), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671286] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(18855), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14465), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671318] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14466), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671350] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8300), 1,
      anon_sym_PIPE,
    ACTIONS(8304), 1,
      anon_sym_DOT,
    STATE(14467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [671374] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18859), 1,
      anon_sym_DASH_GT,
    STATE(14468), 1,
      sym_attribute,
    STATE(19849), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671406] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18861), 1,
      anon_sym_RPAREN,
    STATE(14469), 1,
      sym_attribute,
    STATE(19666), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671438] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18863), 1,
      anon_sym_RPAREN,
    STATE(14470), 1,
      sym_attribute,
    STATE(19672), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671470] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11906), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [671490] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18865), 1,
      anon_sym_RPAREN,
    STATE(14472), 1,
      sym_attribute,
    STATE(19984), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671522] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18867), 1,
      anon_sym_RPAREN,
    STATE(14473), 1,
      sym_attribute,
    STATE(19704), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671554] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18869), 1,
      anon_sym_RPAREN,
    STATE(14474), 1,
      sym_attribute,
    STATE(19709), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671586] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18309), 1,
      anon_sym_RPAREN,
    STATE(14475), 1,
      sym_attribute,
    STATE(20091), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671618] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18871), 1,
      anon_sym_RBRACK,
    ACTIONS(18873), 1,
      anon_sym_SEMI,
    STATE(14476), 1,
      sym_attribute,
    STATE(16687), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671650] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18875), 1,
      anon_sym_SEMI,
    ACTIONS(18877), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14477), 1,
      sym_attribute,
    STATE(16426), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671682] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18879), 1,
      anon_sym_SEMI,
    ACTIONS(18881), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14478), 1,
      sym_attribute,
    STATE(16694), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671714] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11916), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [671734] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18883), 1,
      anon_sym_RPAREN,
    STATE(14480), 1,
      sym_attribute,
    STATE(20116), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671766] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18885), 1,
      anon_sym_RPAREN,
    STATE(14481), 1,
      sym_attribute,
    STATE(19741), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671798] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18887), 1,
      anon_sym_RBRACK,
    ACTIONS(18889), 1,
      anon_sym_SEMI,
    STATE(14482), 1,
      sym_attribute,
    STATE(16696), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671830] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18891), 1,
      anon_sym_SEMI,
    ACTIONS(18893), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14483), 1,
      sym_attribute,
    STATE(16067), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671862] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18895), 1,
      anon_sym_RPAREN,
    STATE(14484), 1,
      sym_attribute,
    STATE(19746), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [671894] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18713), 1,
      anon_sym_DASH_GT,
    ACTIONS(18715), 1,
      anon_sym_with,
    STATE(14485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13610), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [671918] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14486), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 2,
      anon_sym_DASH_GT,
      anon_sym_STAR,
  [671948] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11519), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11521), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [671970] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18897), 1,
      anon_sym_RPAREN,
    STATE(14488), 1,
      sym_attribute,
    STATE(19995), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672002] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11523), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11525), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [672024] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18899), 1,
      anon_sym_RPAREN,
    STATE(14490), 1,
      sym_attribute,
    STATE(19778), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672056] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18901), 1,
      anon_sym_RPAREN,
    STATE(14491), 1,
      sym_attribute,
    STATE(19783), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672088] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18903), 1,
      anon_sym__,
    ACTIONS(18905), 1,
      anon_sym_RBRACE,
    STATE(14492), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672120] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11527), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11529), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [672142] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18907), 1,
      anon_sym_RPAREN,
    STATE(14494), 1,
      sym_attribute,
    STATE(19814), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672174] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18909), 1,
      anon_sym_RPAREN,
    STATE(14495), 1,
      sym_attribute,
    STATE(19819), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672206] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11531), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11533), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [672228] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18911), 1,
      anon_sym__,
    ACTIONS(18913), 1,
      anon_sym_RBRACE,
    STATE(14497), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672260] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18915), 1,
      anon_sym_RPAREN,
    STATE(14498), 1,
      sym_attribute,
    STATE(19841), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672292] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18917), 1,
      anon_sym_RPAREN,
    STATE(14499), 1,
      sym_attribute,
    STATE(19843), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672324] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18919), 1,
      anon_sym_RPAREN,
    STATE(14500), 1,
      sym_attribute,
    STATE(19863), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672356] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18921), 1,
      anon_sym_RPAREN,
    STATE(14501), 1,
      sym_attribute,
    STATE(19865), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672388] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18713), 1,
      anon_sym_DASH_GT,
    ACTIONS(18715), 1,
      anon_sym_with,
    STATE(14502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13618), 5,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [672412] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18923), 1,
      anon_sym_RPAREN,
    STATE(14503), 1,
      sym_attribute,
    STATE(19613), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672444] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18925), 1,
      anon_sym_RBRACK,
    ACTIONS(18927), 1,
      anon_sym_SEMI,
    STATE(14504), 1,
      sym_attribute,
    STATE(16061), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672476] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18929), 1,
      anon_sym_DASH_GT,
    STATE(14505), 1,
      sym_attribute,
    STATE(19438), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672508] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14506), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16677), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    STATE(20353), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672540] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11405), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [672560] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18931), 1,
      anon_sym_RPAREN,
    STATE(14508), 1,
      sym_attribute,
    STATE(20570), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672592] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14509), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(16496), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [672622] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18933), 1,
      anon_sym_DASH_GT,
    STATE(14510), 1,
      sym_attribute,
    STATE(20874), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672654] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18935), 1,
      anon_sym__,
    ACTIONS(18937), 1,
      anon_sym_RBRACE,
    STATE(14511), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672686] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18939), 1,
      anon_sym_RBRACK,
    ACTIONS(18941), 1,
      anon_sym_SEMI,
    STATE(14512), 1,
      sym_attribute,
    STATE(16433), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672718] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14513), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(16576), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [672748] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18943), 1,
      anon_sym_RPAREN,
    STATE(14514), 1,
      sym_attribute,
    STATE(20234), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672780] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18945), 1,
      anon_sym__,
    ACTIONS(18947), 1,
      anon_sym_RBRACE,
    STATE(14515), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672812] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18949), 1,
      anon_sym_RPAREN,
    STATE(14516), 1,
      sym_attribute,
    STATE(20253), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672844] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17749), 3,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [672872] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12577), 1,
      anon_sym_LPAREN,
    ACTIONS(12579), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(11612), 1,
      sym__constructor_name,
    STATE(14518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12581), 2,
      anon_sym_true,
      anon_sym_false,
  [672902] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18951), 1,
      anon_sym_DASH_GT,
    STATE(14519), 1,
      sym_attribute,
    STATE(19662), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672934] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18953), 1,
      anon_sym_SEMI,
    ACTIONS(18955), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14520), 1,
      sym_attribute,
    STATE(16442), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672966] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18957), 1,
      anon_sym_DASH_GT,
    STATE(14521), 1,
      sym_attribute,
    STATE(19369), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [672998] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18959), 1,
      anon_sym_DASH_GT,
    STATE(14522), 1,
      sym_attribute,
    STATE(19492), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673030] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6793), 1,
      anon_sym_PIPE,
    ACTIONS(18671), 1,
      anon_sym_DOT_DOT,
    STATE(14523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [673054] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12047), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [673074] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(18961), 1,
      anon_sym_SEMI,
    ACTIONS(18963), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14525), 1,
      sym_attribute,
    STATE(16729), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673106] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18965), 1,
      anon_sym__,
    ACTIONS(18967), 1,
      anon_sym_RBRACE,
    STATE(14526), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673138] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18969), 1,
      anon_sym__,
    ACTIONS(18971), 1,
      anon_sym_RBRACE,
    STATE(14527), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673170] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(18973), 1,
      anon_sym__,
    ACTIONS(18975), 1,
      anon_sym_RBRACE,
    STATE(14528), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673202] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18977), 1,
      anon_sym_DASH_GT,
    STATE(14529), 1,
      sym_attribute,
    STATE(20422), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673234] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14530), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(16386), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [673264] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12367), 1,
      anon_sym_LPAREN,
    ACTIONS(12369), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(11303), 1,
      sym__constructor_name,
    STATE(14531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12371), 2,
      anon_sym_true,
      anon_sym_false,
  [673294] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18979), 1,
      anon_sym_RPAREN,
    STATE(14532), 1,
      sym_attribute,
    STATE(18480), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673326] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(18185), 1,
      anon_sym_LPAREN,
    ACTIONS(18187), 1,
      anon_sym_LBRACK,
    STATE(11440), 1,
      sym_constructor_declaration,
    STATE(12777), 1,
      sym__constructor_name,
    STATE(14533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18189), 2,
      anon_sym_true,
      anon_sym_false,
  [673356] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18981), 1,
      anon_sym_DASH_GT,
    STATE(14534), 1,
      sym_attribute,
    STATE(19046), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673388] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18983), 1,
      anon_sym_RPAREN,
    STATE(14535), 1,
      sym_attribute,
    STATE(20532), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673420] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14536), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(17114), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [673450] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14537), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(17130), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [673480] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12591), 1,
      anon_sym_LPAREN,
    ACTIONS(12593), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(11705), 1,
      sym__constructor_name,
    STATE(14538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12595), 2,
      anon_sym_true,
      anon_sym_false,
  [673510] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18985), 1,
      anon_sym_RPAREN,
    STATE(14539), 1,
      sym_attribute,
    STATE(20591), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673542] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18987), 1,
      anon_sym_DASH_GT,
    STATE(14540), 1,
      sym_attribute,
    STATE(19968), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673574] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18989), 1,
      sym__lowercase_identifier,
    ACTIONS(18991), 1,
      anon_sym_type,
    ACTIONS(18993), 1,
      anon_sym_LBRACK,
    ACTIONS(18995), 1,
      anon_sym_virtual,
    STATE(12900), 1,
      sym_class_binding,
    STATE(14541), 1,
      sym_attribute,
    STATE(15369), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673606] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18997), 1,
      anon_sym_DASH_GT,
    STATE(14542), 1,
      sym_attribute,
    STATE(19169), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673638] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12301), 1,
      anon_sym_LPAREN,
    ACTIONS(12303), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(10979), 1,
      sym__constructor_name,
    STATE(14543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12305), 2,
      anon_sym_true,
      anon_sym_false,
  [673668] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11479), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11481), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [673690] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14545), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15943), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [673720] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8300), 1,
      anon_sym_PIPE,
    ACTIONS(8360), 1,
      anon_sym_DOT,
    STATE(14546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [673744] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14547), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(15949), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [673774] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(18999), 1,
      anon_sym_DASH_GT,
    STATE(14548), 1,
      sym_attribute,
    STATE(19729), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673806] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19003), 3,
      sym__right_quoted_string_delimiter,
      sym__null,
      aux_sym_string_content_token2,
    ACTIONS(19001), 4,
      aux_sym_string_content_token1,
      aux_sym_quoted_string_content_token1,
      sym_conversion_specification,
      sym_pretty_printing_indication,
  [673828] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(13186), 1,
      anon_sym_LPAREN,
    ACTIONS(13188), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(12312), 1,
      sym__constructor_name,
    STATE(14550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13190), 2,
      anon_sym_true,
      anon_sym_false,
  [673858] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(18127), 1,
      anon_sym_LPAREN,
    ACTIONS(18129), 1,
      anon_sym_LBRACK,
    STATE(11440), 1,
      sym_constructor_declaration,
    STATE(12278), 1,
      sym__constructor_name,
    STATE(14551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18131), 2,
      anon_sym_true,
      anon_sym_false,
  [673888] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11535), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11537), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [673910] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19005), 1,
      anon_sym_RPAREN,
    STATE(14553), 1,
      sym_attribute,
    STATE(20040), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [673942] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14554), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(17157), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [673972] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19007), 1,
      anon_sym_RBRACK,
    ACTIONS(19009), 1,
      anon_sym_SEMI,
    STATE(14555), 1,
      sym_attribute,
    STATE(16953), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674004] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12456), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12458), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14556), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674036] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11539), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11541), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [674058] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19011), 1,
      anon_sym_SEMI,
    ACTIONS(19013), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14558), 1,
      sym_attribute,
    STATE(16970), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674090] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(12381), 1,
      anon_sym_LPAREN,
    ACTIONS(12383), 1,
      anon_sym_LBRACK,
    STATE(10844), 1,
      sym_constructor_declaration,
    STATE(11528), 1,
      sym__constructor_name,
    STATE(14559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12385), 2,
      anon_sym_true,
      anon_sym_false,
  [674120] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14560), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16109), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    STATE(20603), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674152] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14561), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16130), 1,
      sym_field_binding_pattern,
    STATE(18642), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674184] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12341), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12343), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14562), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674216] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11577), 1,
      anon_sym_RPAREN,
    ACTIONS(12404), 1,
      anon_sym_COLON2,
    STATE(14563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [674240] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11543), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11545), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [674262] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14565), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(16460), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [674292] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11547), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11549), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [674314] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11551), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11553), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [674336] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19015), 1,
      anon_sym__,
    ACTIONS(19017), 1,
      anon_sym_RBRACE,
    STATE(14568), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674368] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11555), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11557), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [674390] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19019), 1,
      sym__lowercase_identifier,
    ACTIONS(19021), 1,
      anon_sym_type,
    ACTIONS(19023), 1,
      anon_sym_LBRACK,
    ACTIONS(19025), 1,
      anon_sym_virtual,
    STATE(13517), 1,
      sym_class_binding,
    STATE(14570), 1,
      sym_attribute,
    STATE(15398), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8330), 1,
      anon_sym_PIPE,
    STATE(14571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8332), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [674444] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19027), 1,
      anon_sym_RBRACK,
    ACTIONS(19029), 1,
      anon_sym_when,
    STATE(14572), 1,
      sym_attribute,
    STATE(21090), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674476] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8338), 1,
      anon_sym_PIPE,
    STATE(14573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8340), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [674498] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19031), 1,
      anon_sym_RPAREN,
    STATE(14574), 1,
      sym_attribute,
    STATE(20293), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674530] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8280), 1,
      anon_sym_PIPE,
    STATE(14575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8282), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [674552] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19033), 1,
      anon_sym__,
    ACTIONS(19035), 1,
      anon_sym_RBRACE,
    STATE(14576), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674584] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8342), 1,
      anon_sym_PIPE,
    STATE(14577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8344), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [674606] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19037), 1,
      anon_sym_RPAREN,
    STATE(14578), 1,
      sym_attribute,
    STATE(20457), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674638] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(19039), 1,
      anon_sym_DASH_GT,
    STATE(14579), 1,
      sym_attribute,
    STATE(20766), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674670] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18285), 1,
      anon_sym_RPAREN,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    STATE(14580), 1,
      sym_attribute,
    STATE(20796), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674702] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19041), 1,
      anon_sym_RBRACK,
    ACTIONS(19043), 1,
      anon_sym_SEMI,
    STATE(14581), 1,
      sym_attribute,
    STATE(16933), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674734] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19045), 1,
      anon_sym_SEMI,
    ACTIONS(19047), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14582), 1,
      sym_attribute,
    STATE(16938), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674766] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19049), 1,
      anon_sym_RPAREN,
    STATE(14583), 1,
      sym_attribute,
    STATE(20814), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674798] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19051), 1,
      anon_sym_RBRACK,
    ACTIONS(19053), 1,
      anon_sym_SEMI,
    STATE(14584), 1,
      sym_attribute,
    STATE(16940), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674830] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19055), 1,
      anon_sym_SEMI,
    ACTIONS(19057), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14585), 1,
      sym_attribute,
    STATE(16946), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674862] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8068), 1,
      anon_sym_PIPE,
    STATE(14586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8070), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [674884] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(19059), 1,
      anon_sym_DASH_GT,
    STATE(14587), 1,
      sym_attribute,
    STATE(20982), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674916] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(18530), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14588), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674948] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(19061), 1,
      anon_sym_DASH_GT,
    STATE(14589), 1,
      sym_attribute,
    STATE(20068), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [674980] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19063), 1,
      anon_sym__,
    ACTIONS(19065), 1,
      anon_sym_RBRACE,
    STATE(14590), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675012] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(19067), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14591), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675044] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12005), 7,
      anon_sym_and,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT,
      anon_sym_with,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [675064] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19069), 1,
      anon_sym__,
    ACTIONS(19071), 1,
      anon_sym_RBRACE,
    STATE(14593), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675096] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19073), 1,
      anon_sym__,
    ACTIONS(19075), 1,
      anon_sym_RBRACE,
    STATE(14594), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 7,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [675148] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19077), 1,
      anon_sym__,
    ACTIONS(19079), 1,
      anon_sym_RBRACE,
    STATE(14596), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 7,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [675200] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19081), 1,
      anon_sym__,
    ACTIONS(19083), 1,
      anon_sym_RBRACE,
    STATE(14598), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675232] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19085), 1,
      anon_sym_RPAREN,
    STATE(14599), 1,
      sym_attribute,
    STATE(20992), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675264] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19087), 1,
      anon_sym__,
    ACTIONS(19089), 1,
      anon_sym_RBRACE,
    STATE(14600), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675296] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19091), 1,
      anon_sym_rec,
    ACTIONS(19093), 1,
      anon_sym_type,
    STATE(13238), 1,
      sym_module_binding,
    STATE(14601), 1,
      sym_attribute,
    STATE(15686), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19095), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [675326] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8352), 1,
      anon_sym_PIPE,
    STATE(14602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8354), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [675348] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8356), 1,
      anon_sym_PIPE,
    STATE(14603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8358), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [675370] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8072), 1,
      anon_sym_PIPE,
    STATE(14604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8074), 6,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [675392] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(18991), 1,
      anon_sym_type,
    ACTIONS(19097), 1,
      sym__lowercase_identifier,
    ACTIONS(19099), 1,
      anon_sym_LBRACK,
    ACTIONS(19101), 1,
      anon_sym_virtual,
    STATE(12609), 1,
      sym_class_binding,
    STATE(14605), 1,
      sym_attribute,
    STATE(15865), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675424] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12345), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12347), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14606), 1,
      sym_attribute,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675456] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(18575), 1,
      sym__lowercase_identifier,
    ACTIONS(19103), 1,
      anon_sym__,
    ACTIONS(19105), 1,
      anon_sym_RBRACE,
    STATE(14607), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675488] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19107), 1,
      anon_sym_rec,
    ACTIONS(19109), 1,
      anon_sym_type,
    STATE(12904), 1,
      sym_module_binding,
    STATE(14608), 1,
      sym_attribute,
    STATE(15724), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19111), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [675518] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14609), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16567), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    STATE(20863), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675550] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19113), 1,
      anon_sym_RPAREN,
    STATE(14610), 1,
      sym_attribute,
    STATE(21028), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675582] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(19115), 1,
      anon_sym_DASH_GT,
    STATE(14611), 1,
      sym_attribute,
    STATE(18619), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675614] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19021), 1,
      anon_sym_type,
    ACTIONS(19117), 1,
      sym__lowercase_identifier,
    ACTIONS(19119), 1,
      anon_sym_LBRACK,
    ACTIONS(19121), 1,
      anon_sym_virtual,
    STATE(13140), 1,
      sym_class_binding,
    STATE(14612), 1,
      sym_attribute,
    STATE(15505), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675646] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(19123), 1,
      anon_sym_DASH_GT,
    STATE(14613), 1,
      sym_attribute,
    STATE(19003), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675678] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18518), 1,
      anon_sym_when,
    ACTIONS(19125), 1,
      anon_sym_DASH_GT,
    STATE(14614), 1,
      sym_attribute,
    STATE(20195), 1,
      sym_guard,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675710] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11559), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11561), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675732] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12269), 1,
      sym__uppercase_identifier,
    ACTIONS(18171), 1,
      anon_sym_LPAREN,
    ACTIONS(18173), 1,
      anon_sym_LBRACK,
    STATE(11440), 1,
      sym_constructor_declaration,
    STATE(12768), 1,
      sym__constructor_name,
    STATE(14616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18175), 2,
      anon_sym_true,
      anon_sym_false,
  [675762] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11483), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11485), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675784] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11487), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11489), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675806] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11563), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11565), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675828] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11491), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11493), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675850] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11567), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11569), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675872] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(16167), 1,
      anon_sym_STAR,
    ACTIONS(19127), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14622), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675904] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14623), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(15995), 1,
      sym_field_pattern,
    STATE(18991), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675936] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14624), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16006), 1,
      sym_field_binding_pattern,
    STATE(18991), 1,
      sym__quoted_string,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [675968] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11495), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11497), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [675990] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14626), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(17134), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [676020] = 10,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11475), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(11477), 1,
      anon_sym_in,
    ACTIONS(17713), 1,
      sym__lowercase_identifier,
    ACTIONS(17715), 1,
      anon_sym_POUND,
    STATE(14625), 1,
      sym_type_constructor_path,
    STATE(14627), 1,
      sym_attribute,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676052] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14628), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(17119), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [676082] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11571), 2,
      anon_sym_in,
      sym__lowercase_identifier,
    ACTIONS(11573), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      anon_sym_LBRACK_AT_AT,
      sym__uppercase_identifier,
  [676104] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(15762), 1,
      anon_sym_BANG,
    ACTIONS(18508), 1,
      anon_sym__,
    STATE(14630), 1,
      sym_attribute,
    STATE(15018), 1,
      sym_type_variable,
    STATE(17136), 1,
      sym__type_param,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15760), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [676134] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17694), 1,
      anon_sym_PIPE,
    ACTIONS(19129), 1,
      anon_sym_COLON,
    STATE(14631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17690), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676158] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19131), 1,
      anon_sym_RPAREN,
    STATE(14632), 1,
      sym_attribute,
    STATE(18782), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676190] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19133), 1,
      anon_sym_rec,
    ACTIONS(19135), 1,
      anon_sym_type,
    STATE(12917), 1,
      sym_module_binding,
    STATE(14633), 1,
      sym_attribute,
    STATE(15893), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19137), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [676220] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19139), 1,
      anon_sym_rec,
    ACTIONS(19141), 1,
      anon_sym_type,
    STATE(13451), 1,
      sym_module_binding,
    STATE(14634), 1,
      sym_attribute,
    STATE(15883), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19143), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [676250] = 10,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19145), 1,
      anon_sym_SEMI,
    ACTIONS(19147), 1,
      anon_sym_PIPE_RBRACK,
    STATE(14635), 1,
      sym_attribute,
    STATE(16700), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676282] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19149), 1,
      sym__lowercase_identifier,
    STATE(4329), 1,
      sym_class_path,
    STATE(14636), 1,
      sym_attribute,
    STATE(15322), 1,
      sym__attribute,
    STATE(19006), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676311] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9174), 1,
      anon_sym_PIPE,
    STATE(14637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9176), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676332] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19151), 1,
      anon_sym_RBRACE,
    STATE(14638), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676361] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    STATE(14639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17743), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [676388] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17569), 1,
      anon_sym_PIPE,
    STATE(14640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17567), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676409] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17651), 1,
      anon_sym_PIPE,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    STATE(14641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 3,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [676434] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9546), 1,
      anon_sym_PIPE,
    STATE(14642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9548), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676455] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17651), 1,
      anon_sym_PIPE,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    STATE(14643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 4,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676478] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17651), 1,
      anon_sym_PIPE,
    STATE(14644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17649), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676499] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    STATE(14645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17475), 3,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [676524] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17477), 1,
      anon_sym_PIPE,
    STATE(14646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17475), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676545] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17643), 1,
      anon_sym_PIPE,
    STATE(14647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17641), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676566] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17741), 1,
      anon_sym_PIPE,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    STATE(14648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17739), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [676589] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19153), 1,
      anon_sym_RBRACE,
    STATE(14649), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676618] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9642), 1,
      anon_sym_PIPE,
    STATE(14650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9644), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676639] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19155), 1,
      anon_sym_RBRACE,
    STATE(14651), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676668] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9128), 1,
      anon_sym_PIPE,
    STATE(14652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9130), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676689] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17252), 1,
      anon_sym_PIPE,
    STATE(14653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17250), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676710] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19157), 1,
      anon_sym_RBRACE,
    STATE(14654), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9136), 1,
      anon_sym_PIPE,
    STATE(14655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9138), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676760] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9726), 1,
      anon_sym_PIPE,
    STATE(14656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9728), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676781] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19159), 1,
      anon_sym_RBRACE,
    STATE(14657), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676810] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19161), 1,
      anon_sym_RBRACE,
    STATE(14658), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676839] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19163), 1,
      sym__lowercase_identifier,
    STATE(7370), 1,
      sym_class_path,
    STATE(14659), 1,
      sym_attribute,
    STATE(15205), 1,
      sym__attribute,
    STATE(18682), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676868] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19165), 1,
      sym__lowercase_identifier,
    STATE(6179), 1,
      sym_class_path,
    STATE(14660), 1,
      sym_attribute,
    STATE(15544), 1,
      sym__attribute,
    STATE(19177), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676897] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19167), 1,
      anon_sym_RBRACE,
    STATE(14661), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676926] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9622), 1,
      anon_sym_PIPE,
    STATE(14662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9624), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [676947] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19169), 1,
      sym__lowercase_identifier,
    STATE(7429), 1,
      sym_class_path,
    STATE(14663), 1,
      sym_attribute,
    STATE(15579), 1,
      sym__attribute,
    STATE(20122), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [676976] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19171), 1,
      anon_sym_RBRACE,
    STATE(14664), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677005] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19173), 1,
      anon_sym_RBRACE,
    STATE(14665), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677034] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19175), 1,
      anon_sym_RBRACE,
    STATE(14666), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9058), 1,
      anon_sym_PIPE,
    STATE(14667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9060), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677084] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9086), 1,
      anon_sym_PIPE,
    STATE(14668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9088), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677105] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19177), 1,
      anon_sym_RBRACE,
    STATE(14669), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677134] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8314), 1,
      anon_sym_PIPE,
    STATE(14670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8316), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677155] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19179), 1,
      anon_sym_RBRACE,
    STATE(14671), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677184] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19181), 1,
      anon_sym_RBRACE,
    STATE(14672), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677213] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19183), 1,
      anon_sym_RBRACE,
    STATE(14673), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677242] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9626), 1,
      anon_sym_PIPE,
    STATE(14674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9628), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677263] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19185), 1,
      sym__lowercase_identifier,
    STATE(4171), 1,
      sym_class_path,
    STATE(14675), 1,
      sym_attribute,
    STATE(15598), 1,
      sym__attribute,
    STATE(18790), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677292] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19187), 1,
      anon_sym_RBRACE,
    STATE(14676), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677321] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19189), 1,
      anon_sym_RBRACE,
    STATE(14677), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677350] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19191), 1,
      anon_sym_RBRACE,
    STATE(14678), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677379] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19193), 1,
      anon_sym_RBRACE,
    STATE(14679), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677408] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19195), 1,
      anon_sym_RBRACE,
    STATE(14680), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677437] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19197), 1,
      anon_sym_RBRACE,
    STATE(14681), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677466] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9102), 1,
      anon_sym_PIPE,
    STATE(14682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9104), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677487] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19199), 1,
      anon_sym_RBRACE,
    STATE(14683), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677516] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19201), 1,
      anon_sym_RBRACE,
    STATE(14684), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677545] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9770), 1,
      anon_sym_PIPE,
    STATE(14685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9772), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677566] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19203), 1,
      anon_sym_rec,
    STATE(14686), 1,
      sym_attribute,
    STATE(15353), 1,
      sym__attribute,
    STATE(16189), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19205), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [677593] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19207), 1,
      anon_sym_RBRACE,
    STATE(14687), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677622] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9070), 1,
      anon_sym_PIPE,
    STATE(14688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9072), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677643] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9106), 1,
      anon_sym_PIPE,
    STATE(14689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9108), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677664] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19209), 1,
      anon_sym_RBRACE,
    STATE(14690), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677693] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19211), 1,
      sym__lowercase_identifier,
    STATE(3316), 1,
      sym_class_path,
    STATE(14691), 1,
      sym_attribute,
    STATE(15283), 1,
      sym__attribute,
    STATE(19724), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677722] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19213), 1,
      anon_sym_RBRACE,
    STATE(14692), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677751] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19215), 1,
      sym__lowercase_identifier,
    STATE(3645), 1,
      sym_class_path,
    STATE(14693), 1,
      sym_attribute,
    STATE(15317), 1,
      sym__attribute,
    STATE(19832), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677780] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19217), 1,
      anon_sym_RBRACE,
    STATE(14694), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9634), 1,
      anon_sym_PIPE,
    STATE(14695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9636), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [677830] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19219), 1,
      sym__lowercase_identifier,
    ACTIONS(19221), 1,
      anon_sym_BANG,
    STATE(13237), 1,
      sym__instance_variable_name,
    STATE(14696), 1,
      sym_attribute,
    STATE(15052), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19223), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [677857] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19225), 1,
      anon_sym_RBRACE,
    STATE(14697), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677886] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19227), 1,
      anon_sym_RBRACE,
    STATE(14698), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677915] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19229), 1,
      anon_sym_RBRACE,
    STATE(14699), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677944] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19231), 1,
      anon_sym_RBRACE,
    STATE(14700), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [677973] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19233), 1,
      sym__lowercase_identifier,
    STATE(5373), 1,
      sym_class_path,
    STATE(14701), 1,
      sym_attribute,
    STATE(15304), 1,
      sym__attribute,
    STATE(19797), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678002] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19235), 1,
      anon_sym_RBRACE,
    STATE(14702), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678031] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19237), 1,
      sym__lowercase_identifier,
    STATE(5567), 1,
      sym_class_path,
    STATE(14703), 1,
      sym_attribute,
    STATE(15500), 1,
      sym__attribute,
    STATE(19137), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678060] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19239), 1,
      anon_sym_RBRACE,
    STATE(14704), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678089] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19241), 1,
      anon_sym_RBRACE,
    STATE(14705), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678118] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19243), 1,
      sym__lowercase_identifier,
    STATE(7208), 1,
      sym_class_path,
    STATE(14706), 1,
      sym_attribute,
    STATE(15437), 1,
      sym__attribute,
    STATE(19926), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678147] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19245), 1,
      anon_sym_RBRACE,
    STATE(14707), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678176] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19247), 1,
      anon_sym_RBRACE,
    STATE(14708), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678205] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19249), 1,
      sym__lowercase_identifier,
    STATE(3780), 1,
      sym_class_path,
    STATE(14709), 1,
      sym_attribute,
    STATE(15683), 1,
      sym__attribute,
    STATE(18736), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678234] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19251), 1,
      anon_sym_RBRACE,
    STATE(14710), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678263] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19253), 1,
      anon_sym_RBRACE,
    STATE(14711), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678292] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19255), 1,
      anon_sym_RBRACE,
    STATE(14712), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678321] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19257), 1,
      anon_sym_RBRACE,
    STATE(14713), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678350] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19259), 1,
      anon_sym_RBRACE,
    STATE(14714), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678379] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19261), 1,
      anon_sym_RBRACE,
    STATE(14715), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678408] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19263), 1,
      anon_sym_RBRACE,
    STATE(14716), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678437] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19265), 1,
      anon_sym_RBRACE,
    STATE(14717), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678466] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19267), 1,
      anon_sym_RBRACE,
    STATE(14718), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678495] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19269), 1,
      anon_sym_RBRACE,
    STATE(14719), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678524] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19271), 1,
      anon_sym_RBRACE,
    STATE(14720), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678553] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19273), 1,
      anon_sym_RBRACE,
    STATE(14721), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678582] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9730), 1,
      anon_sym_PIPE,
    STATE(14722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9732), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [678603] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19275), 1,
      anon_sym_RBRACE,
    STATE(14723), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678632] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19277), 1,
      anon_sym_RBRACE,
    STATE(14724), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678661] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17589), 1,
      anon_sym_PIPE,
    STATE(14725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17587), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [678682] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9158), 1,
      anon_sym_COLON2,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    STATE(14726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_as,
  [678705] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19279), 1,
      anon_sym_RBRACE,
    STATE(14727), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678734] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9734), 1,
      anon_sym_PIPE,
    STATE(14728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9736), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [678755] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19285), 1,
      anon_sym_AMP,
    STATE(14729), 1,
      sym_attribute,
    STATE(15071), 1,
      aux_sym_tag_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19281), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [678780] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19287), 1,
      anon_sym_RBRACE,
    STATE(14730), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(6793), 1,
      anon_sym_PIPE,
    STATE(14731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(6787), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [678830] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19289), 1,
      anon_sym_RBRACE,
    STATE(14732), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678859] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19291), 1,
      anon_sym_RBRACE,
    STATE(14733), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678888] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19293), 1,
      anon_sym_RBRACE,
    STATE(14734), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678917] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(14735), 1,
      sym_attribute,
    STATE(15727), 1,
      sym__attribute,
    STATE(18279), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678946] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19297), 1,
      anon_sym_RBRACE,
    STATE(14736), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [678975] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19299), 1,
      sym__lowercase_identifier,
    STATE(7926), 1,
      sym_class_path,
    STATE(14737), 1,
      sym_attribute,
    STATE(15215), 1,
      sym__attribute,
    STATE(19535), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679004] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19301), 1,
      anon_sym_RBRACE,
    STATE(14738), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679033] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19303), 1,
      anon_sym_RBRACE,
    STATE(14739), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679062] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19305), 1,
      anon_sym_RBRACE,
    STATE(14740), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679091] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9178), 1,
      anon_sym_PIPE,
    STATE(14741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9180), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679112] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19307), 1,
      anon_sym_RBRACE,
    STATE(14742), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679141] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19309), 1,
      anon_sym_RBRACE,
    STATE(14743), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679170] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(11970), 1,
      anon_sym_and,
    ACTIONS(19311), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11968), 2,
      anon_sym_in,
      sym_let_and_operator,
    STATE(14744), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
  [679195] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19314), 1,
      anon_sym_RBRACE,
    STATE(14745), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679224] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19316), 1,
      anon_sym_RBRACE,
    STATE(14746), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679253] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19318), 1,
      sym__lowercase_identifier,
    STATE(6643), 1,
      sym_class_path,
    STATE(14747), 1,
      sym_attribute,
    STATE(15595), 1,
      sym__attribute,
    STATE(19217), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679282] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17515), 1,
      anon_sym_PIPE,
    STATE(14748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17513), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679303] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9198), 1,
      anon_sym_PIPE,
    STATE(14749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9200), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679324] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19320), 1,
      anon_sym_RBRACE,
    STATE(14750), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679353] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19322), 1,
      anon_sym_RBRACE,
    STATE(14751), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679382] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19324), 1,
      sym__lowercase_identifier,
    STATE(5090), 1,
      sym_class_path,
    STATE(14752), 1,
      sym_attribute,
    STATE(15742), 1,
      sym__attribute,
    STATE(18572), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679411] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19326), 1,
      anon_sym_RBRACE,
    STATE(14753), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679440] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8334), 1,
      anon_sym_PIPE,
    STATE(14754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8336), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679461] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19328), 1,
      anon_sym_RBRACE,
    STATE(14755), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679490] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19330), 1,
      anon_sym_RBRACE,
    STATE(14756), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679519] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9738), 1,
      anon_sym_PIPE,
    STATE(14757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9740), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679540] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19332), 1,
      anon_sym_and,
    STATE(14758), 1,
      sym_attribute,
    STATE(14767), 1,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13196), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [679563] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19334), 1,
      sym__lowercase_identifier,
    STATE(6552), 1,
      sym_class_path,
    STATE(14759), 1,
      sym_attribute,
    STATE(15216), 1,
      sym__attribute,
    STATE(18898), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679592] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9758), 1,
      anon_sym_PIPE,
    STATE(14760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9760), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679613] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17521), 1,
      anon_sym_PIPE,
    STATE(14761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17519), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679634] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17533), 1,
      anon_sym_PIPE,
    STATE(14762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17531), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679655] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19336), 1,
      anon_sym_RBRACE,
    STATE(14763), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679684] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19338), 1,
      anon_sym_RBRACE,
    STATE(14764), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679713] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17545), 1,
      anon_sym_PIPE,
    STATE(14765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17543), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679734] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17595), 1,
      anon_sym_PIPE,
    STATE(14766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17593), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679755] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19340), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14767), 2,
      sym_attribute,
      aux_sym_module_type_constraint_repeat1,
    ACTIONS(12047), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [679776] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19343), 1,
      anon_sym_RBRACE,
    STATE(14768), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679805] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19345), 1,
      anon_sym_RBRACE,
    STATE(14769), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679834] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9164), 1,
      anon_sym_PIPE,
    STATE(14770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9166), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679855] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(5978), 1,
      sym_class_path,
    STATE(14771), 1,
      sym_attribute,
    STATE(15423), 1,
      sym__attribute,
    STATE(19056), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679884] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9214), 1,
      anon_sym_PIPE,
    STATE(14772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9216), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17405), 1,
      anon_sym_DASH_GT,
    STATE(14773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(10381), 5,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_GT,
  [679926] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9078), 1,
      anon_sym_PIPE,
    STATE(14774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9080), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679947] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19349), 1,
      anon_sym_RBRACE,
    STATE(14775), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [679976] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9140), 1,
      anon_sym_PIPE,
    STATE(14776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9142), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [679997] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19351), 1,
      anon_sym_RBRACE,
    STATE(14777), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680026] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12404), 1,
      anon_sym_COLON2,
    STATE(14778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9184), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [680047] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19353), 1,
      anon_sym_RBRACE,
    STATE(14779), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680076] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19355), 1,
      anon_sym_RBRACE,
    STATE(14780), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680105] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19357), 1,
      anon_sym_RBRACE,
    STATE(14781), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680134] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19359), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [680161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9170), 1,
      anon_sym_PIPE,
    STATE(14783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9172), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [680182] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9186), 1,
      anon_sym_PIPE,
    STATE(14784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9188), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [680203] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19361), 1,
      anon_sym_RBRACE,
    STATE(14785), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680232] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19363), 1,
      anon_sym_RBRACE,
    STATE(14786), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680261] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19365), 1,
      anon_sym_RBRACE,
    STATE(14787), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680290] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19367), 1,
      anon_sym_RBRACE,
    STATE(14788), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680319] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19369), 1,
      anon_sym_RBRACE,
    STATE(14789), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680348] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19371), 1,
      sym__lowercase_identifier,
    STATE(5012), 1,
      sym_class_path,
    STATE(14790), 1,
      sym_attribute,
    STATE(15228), 1,
      sym__attribute,
    STATE(19573), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680377] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19373), 1,
      anon_sym_RBRACE,
    STATE(14791), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680406] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19375), 1,
      anon_sym_RBRACE,
    STATE(14792), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680435] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(15342), 1,
      anon_sym_POUND,
    ACTIONS(19377), 1,
      anon_sym_DASH_GT,
    STATE(12980), 1,
      sym_type_constructor_path,
    STATE(14793), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680464] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19379), 1,
      anon_sym_RBRACE,
    STATE(14794), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680493] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19381), 1,
      anon_sym_RBRACE,
    STATE(14795), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680522] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19383), 1,
      anon_sym_RBRACE,
    STATE(14796), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680551] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19385), 1,
      anon_sym_RBRACE,
    STATE(14797), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680580] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8318), 1,
      anon_sym_PIPE,
    STATE(14798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8320), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [680601] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19387), 1,
      anon_sym_RBRACE,
    STATE(14799), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680630] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19389), 1,
      anon_sym_RBRACE,
    STATE(14800), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680659] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    STATE(14801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19391), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [680686] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19393), 1,
      anon_sym_RBRACE,
    STATE(14802), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680715] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19395), 1,
      anon_sym_RBRACE,
    STATE(14803), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680744] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9110), 1,
      anon_sym_PIPE,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    STATE(14804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 3,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [680769] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19397), 1,
      anon_sym_RBRACE,
    STATE(14805), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680798] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19399), 1,
      anon_sym_RBRACE,
    STATE(14806), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680827] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18553), 1,
      anon_sym_as,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    STATE(14807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19401), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [680854] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19403), 1,
      sym__lowercase_identifier,
    STATE(6693), 1,
      sym_class_path,
    STATE(14808), 1,
      sym_attribute,
    STATE(15637), 1,
      sym__attribute,
    STATE(19257), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680883] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12855), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14809), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12853), 2,
      anon_sym_in,
      sym_let_and_operator,
  [680910] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9818), 1,
      anon_sym_PIPE,
    STATE(14810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9820), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [680931] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8322), 1,
      anon_sym_PIPE,
    STATE(14811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8324), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [680952] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19405), 1,
      anon_sym_RBRACE,
    STATE(14812), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [680981] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9110), 1,
      anon_sym_PIPE,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    STATE(14813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 4,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681004] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9110), 1,
      anon_sym_PIPE,
    STATE(14814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681025] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12859), 1,
      anon_sym_and,
    STATE(14815), 1,
      sym_attribute,
    STATE(14867), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12857), 2,
      anon_sym_in,
      sym_let_and_operator,
  [681052] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12871), 1,
      anon_sym_and,
    STATE(14816), 1,
      sym_attribute,
    STATE(14869), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12869), 2,
      anon_sym_in,
      sym_let_and_operator,
  [681079] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19407), 1,
      anon_sym_RBRACE,
    STATE(14817), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681108] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19409), 1,
      sym__lowercase_identifier,
    STATE(3887), 1,
      sym_class_path,
    STATE(14818), 1,
      sym_attribute,
    STATE(15763), 1,
      sym__attribute,
    STATE(19417), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681137] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19411), 1,
      anon_sym_RBRACE,
    STATE(14819), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681166] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17607), 1,
      anon_sym_PIPE,
    STATE(14820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17605), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681187] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17611), 1,
      anon_sym_PIPE,
    STATE(14821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17609), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681208] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9826), 1,
      anon_sym_PIPE,
    STATE(14822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9828), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681229] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19413), 1,
      anon_sym_RBRACE,
    STATE(14823), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681258] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19415), 1,
      anon_sym_RBRACE,
    STATE(14824), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681287] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8362), 1,
      anon_sym_PIPE,
    STATE(14825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8364), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681308] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19417), 1,
      anon_sym_RBRACE,
    STATE(14826), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681337] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19419), 1,
      sym__lowercase_identifier,
    STATE(6740), 1,
      sym_class_path,
    STATE(14827), 1,
      sym_attribute,
    STATE(15689), 1,
      sym__attribute,
    STATE(19337), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681366] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19421), 1,
      anon_sym_RBRACE,
    STATE(14828), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681395] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19423), 1,
      anon_sym_RBRACE,
    STATE(14829), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681424] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19425), 1,
      sym__lowercase_identifier,
    STATE(4018), 1,
      sym_class_path,
    STATE(14830), 1,
      sym_attribute,
    STATE(15869), 1,
      sym__attribute,
    STATE(19496), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681453] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19427), 1,
      anon_sym_RBRACE,
    STATE(14831), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681482] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8306), 1,
      anon_sym_PIPE,
    STATE(14832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8308), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681503] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19429), 1,
      anon_sym_RBRACE,
    STATE(14833), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681532] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19431), 1,
      anon_sym_RBRACE,
    STATE(14834), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681561] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9202), 1,
      anon_sym_PIPE,
    STATE(14835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9204), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681582] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19433), 1,
      anon_sym_RBRACE,
    STATE(14836), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681611] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    ACTIONS(18549), 1,
      anon_sym_PIPE,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    STATE(14837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 3,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [681636] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(14838), 1,
      sym_attribute,
    STATE(15682), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(19489), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [681663] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9062), 1,
      anon_sym_PIPE,
    STATE(14839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9064), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681684] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19437), 1,
      anon_sym_RBRACE,
    STATE(14840), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681713] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19439), 1,
      anon_sym_RBRACE,
    STATE(14841), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681742] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19441), 1,
      sym__lowercase_identifier,
    STATE(3565), 1,
      sym_class_path,
    STATE(14842), 1,
      sym_attribute,
    STATE(15266), 1,
      sym__attribute,
    STATE(18952), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681771] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19443), 1,
      sym__lowercase_identifier,
    STATE(3253), 1,
      sym_class_path,
    STATE(14843), 1,
      sym_attribute,
    STATE(15243), 1,
      sym__attribute,
    STATE(19611), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681800] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9230), 1,
      anon_sym_PIPE,
    STATE(14844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9232), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681821] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19445), 1,
      anon_sym_RBRACE,
    STATE(14845), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681850] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9206), 1,
      anon_sym_PIPE,
    STATE(14846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9208), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681871] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19447), 1,
      anon_sym_RBRACE,
    STATE(14847), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681900] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9210), 1,
      anon_sym_PIPE,
    STATE(14848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9212), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [681921] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19449), 1,
      anon_sym_RBRACE,
    STATE(14849), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681950] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19451), 1,
      anon_sym_RBRACE,
    STATE(14850), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [681979] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19453), 1,
      anon_sym_RBRACE,
    STATE(14851), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682008] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12297), 1,
      anon_sym_RPAREN,
    STATE(14852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11481), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [682029] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9132), 1,
      anon_sym_PIPE,
    STATE(14853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682050] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19455), 1,
      sym__lowercase_identifier,
    STATE(6281), 1,
      sym_class_path,
    STATE(14854), 1,
      sym_attribute,
    STATE(15795), 1,
      sym__attribute,
    STATE(19457), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682079] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19457), 1,
      anon_sym_RBRACE,
    STATE(14855), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682108] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(14856), 1,
      sym_attribute,
    STATE(15909), 1,
      sym__attribute,
    STATE(17690), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682137] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19459), 1,
      anon_sym_RBRACE,
    STATE(14857), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682166] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19461), 1,
      sym__lowercase_identifier,
    STATE(3527), 1,
      sym_class_path,
    STATE(14858), 1,
      sym_attribute,
    STATE(15332), 1,
      sym__attribute,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682195] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9090), 1,
      anon_sym_PIPE,
    STATE(14859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9092), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682216] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9094), 1,
      anon_sym_PIPE,
    STATE(14860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9096), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682237] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9154), 1,
      anon_sym_PIPE,
    STATE(14861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9156), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682258] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19463), 1,
      sym__lowercase_identifier,
    STATE(9650), 1,
      sym_class_path,
    STATE(14862), 1,
      sym_attribute,
    STATE(15376), 1,
      sym__attribute,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682287] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19465), 1,
      anon_sym_RBRACE,
    STATE(14863), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682316] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19467), 1,
      anon_sym_RBRACE,
    STATE(14864), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682345] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13442), 1,
      anon_sym_and,
    STATE(14865), 1,
      sym_attribute,
    STATE(14907), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13440), 2,
      anon_sym_in,
      sym_let_and_operator,
  [682372] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19469), 1,
      sym__lowercase_identifier,
    STATE(7326), 1,
      sym_class_path,
    STATE(14866), 1,
      sym_attribute,
    STATE(15664), 1,
      sym__attribute,
    STATE(20410), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682401] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13279), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14867), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13277), 2,
      anon_sym_in,
      sym_let_and_operator,
  [682428] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19471), 1,
      sym__lowercase_identifier,
    STATE(6797), 1,
      sym_class_path,
    STATE(14868), 1,
      sym_attribute,
    STATE(15719), 1,
      sym__attribute,
    STATE(19377), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682457] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12756), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14869), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12754), 2,
      anon_sym_in,
      sym_let_and_operator,
  [682484] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12778), 1,
      anon_sym_and,
    STATE(14870), 1,
      sym_attribute,
    STATE(14913), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12776), 2,
      anon_sym_in,
      sym_let_and_operator,
  [682511] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17639), 1,
      anon_sym_PIPE,
    STATE(14871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17637), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682532] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19391), 2,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [682559] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9146), 1,
      anon_sym_PIPE,
    STATE(14873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9148), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682580] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9158), 1,
      anon_sym_PIPE,
    ACTIONS(18555), 1,
      anon_sym_COLON_COLON,
    STATE(14874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9160), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_PIPE_RBRACK,
  [682603] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19473), 1,
      anon_sym_RBRACE,
    STATE(14875), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682632] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19475), 1,
      anon_sym_RBRACE,
    STATE(14876), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682661] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19477), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [682688] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19479), 1,
      sym__lowercase_identifier,
    STATE(5258), 1,
      sym_class_path,
    STATE(14878), 1,
      sym_attribute,
    STATE(15457), 1,
      sym__attribute,
    STATE(19097), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682717] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9684), 1,
      anon_sym_PIPE,
    STATE(14879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9686), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682738] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9150), 1,
      anon_sym_PIPE,
    STATE(14880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9152), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682759] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19481), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682788] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19483), 1,
      sym__lowercase_identifier,
    STATE(7611), 1,
      sym_class_path,
    STATE(14882), 1,
      sym_attribute,
    STATE(15639), 1,
      sym__attribute,
    STATE(19181), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682817] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9122), 1,
      anon_sym_PIPE,
    STATE(14883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9124), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682838] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19485), 1,
      anon_sym_RBRACE,
    STATE(14884), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682867] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9066), 1,
      anon_sym_PIPE,
    STATE(14885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9068), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682888] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9114), 1,
      anon_sym_PIPE,
    STATE(14886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9116), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9118), 1,
      anon_sym_PIPE,
    STATE(14887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9120), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682930] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19487), 1,
      anon_sym_RBRACE,
    STATE(14888), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [682959] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9688), 1,
      anon_sym_PIPE,
    STATE(14889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9690), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [682980] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(14890), 1,
      sym_attribute,
    STATE(15550), 1,
      sym__attribute,
    STATE(17672), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683009] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19489), 1,
      anon_sym_RBRACE,
    STATE(14891), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683038] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19491), 1,
      sym__lowercase_identifier,
    STATE(5767), 1,
      sym_class_path,
    STATE(14892), 1,
      sym_attribute,
    STATE(15290), 1,
      sym__attribute,
    STATE(19761), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683067] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19493), 1,
      anon_sym_RBRACE,
    STATE(14893), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683096] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19495), 1,
      anon_sym_RBRACE,
    STATE(14894), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683125] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19497), 1,
      anon_sym_RBRACE,
    STATE(14895), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683154] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19499), 1,
      anon_sym_RBRACE,
    STATE(14896), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683183] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19501), 1,
      anon_sym_RBRACE,
    STATE(14897), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683212] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19503), 1,
      sym__lowercase_identifier,
    STATE(7699), 1,
      sym_class_path,
    STATE(14898), 1,
      sym_attribute,
    STATE(15859), 1,
      sym__attribute,
    STATE(18447), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683241] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8204), 1,
      anon_sym_PIPE,
    STATE(14899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8206), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683262] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19505), 1,
      anon_sym_RBRACE,
    STATE(14900), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683291] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19507), 1,
      anon_sym_RBRACE,
    STATE(14901), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683320] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19509), 1,
      anon_sym_RBRACE,
    STATE(14902), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683349] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    ACTIONS(18609), 1,
      anon_sym_PIPE,
    ACTIONS(18615), 1,
      anon_sym_COLON_COLON,
    STATE(14903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19511), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [683376] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8310), 1,
      anon_sym_PIPE,
    STATE(14904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8312), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683397] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19513), 1,
      anon_sym_RBRACE,
    STATE(14905), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683426] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19515), 1,
      anon_sym_RBRACE,
    STATE(14906), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683455] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13036), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14907), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13034), 2,
      anon_sym_in,
      sym_let_and_operator,
  [683482] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13040), 1,
      anon_sym_and,
    STATE(14908), 1,
      sym_attribute,
    STATE(14928), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13038), 2,
      anon_sym_in,
      sym_let_and_operator,
  [683509] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19517), 1,
      anon_sym_RBRACE,
    STATE(14909), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683538] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19519), 1,
      anon_sym_RBRACE,
    STATE(14910), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683567] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19521), 1,
      sym__lowercase_identifier,
    STATE(4449), 1,
      sym_class_path,
    STATE(14911), 1,
      sym_attribute,
    STATE(15464), 1,
      sym__attribute,
    STATE(20914), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683596] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13044), 1,
      anon_sym_and,
    STATE(14912), 1,
      sym_attribute,
    STATE(14929), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13042), 2,
      anon_sym_in,
      sym_let_and_operator,
  [683623] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13052), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14913), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13050), 2,
      anon_sym_in,
      sym_let_and_operator,
  [683650] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8326), 1,
      anon_sym_PIPE,
    STATE(14914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8328), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683671] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19523), 1,
      anon_sym_RBRACE,
    STATE(14915), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683700] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19525), 1,
      anon_sym_RBRACE,
    STATE(14916), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683729] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19527), 1,
      sym__lowercase_identifier,
    STATE(10076), 1,
      sym_class_path,
    STATE(14917), 1,
      sym_attribute,
    STATE(15663), 1,
      sym__attribute,
    STATE(19297), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683758] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9692), 1,
      anon_sym_PIPE,
    STATE(14918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9694), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683779] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19529), 1,
      anon_sym_RBRACE,
    STATE(14919), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683808] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9696), 1,
      anon_sym_PIPE,
    STATE(14920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9698), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683829] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9700), 1,
      anon_sym_PIPE,
    STATE(14921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9702), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683850] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19531), 1,
      sym__lowercase_identifier,
    STATE(6954), 1,
      sym_class_path,
    STATE(14922), 1,
      sym_attribute,
    STATE(15253), 1,
      sym__attribute,
    STATE(19649), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683879] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19533), 1,
      anon_sym_RBRACE,
    STATE(14923), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683908] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19535), 1,
      anon_sym_RBRACE,
    STATE(14924), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [683937] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19401), 2,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [683964] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9236), 1,
      anon_sym_PIPE,
    STATE(14926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9238), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [683985] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19537), 1,
      anon_sym_RBRACE,
    STATE(14927), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684014] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13331), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14928), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13329), 2,
      anon_sym_in,
      sym_let_and_operator,
  [684041] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13347), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14929), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13345), 2,
      anon_sym_in,
      sym_let_and_operator,
  [684068] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13363), 1,
      anon_sym_and,
    STATE(14930), 1,
      sym_attribute,
    STATE(14934), 1,
      aux_sym_expression_item_repeat1,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13361), 2,
      anon_sym_in,
      sym_let_and_operator,
  [684095] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19539), 1,
      sym__lowercase_identifier,
    STATE(6480), 1,
      sym_class_path,
    STATE(14931), 1,
      sym_attribute,
    STATE(15621), 1,
      sym__attribute,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684124] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19541), 1,
      anon_sym_RBRACE,
    STATE(14932), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684153] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9218), 1,
      anon_sym_PIPE,
    STATE(14933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9220), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684174] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13323), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14934), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13321), 2,
      anon_sym_in,
      sym_let_and_operator,
  [684201] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    ACTIONS(18537), 1,
      anon_sym_PIPE,
    ACTIONS(18543), 1,
      anon_sym_as,
    ACTIONS(18545), 1,
      anon_sym_COLON_COLON,
    STATE(14935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19543), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [684228] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9226), 1,
      anon_sym_PIPE,
    STATE(14936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9228), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684249] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19545), 1,
      anon_sym_RBRACE,
    STATE(14937), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684278] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7913), 1,
      anon_sym_PIPE,
    STATE(14938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(7915), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684299] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8284), 1,
      anon_sym_PIPE,
    STATE(14939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8286), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684320] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19547), 1,
      anon_sym_RBRACE,
    STATE(14940), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684349] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19285), 1,
      anon_sym_AMP,
    STATE(14941), 1,
      sym_attribute,
    STATE(15173), 1,
      aux_sym_tag_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19549), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [684374] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19551), 1,
      sym__lowercase_identifier,
    ACTIONS(19553), 1,
      anon_sym_LBRACK,
    ACTIONS(19555), 1,
      anon_sym_virtual,
    STATE(12553), 1,
      sym_class_type_binding,
    STATE(14942), 1,
      sym_attribute,
    STATE(15732), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684403] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4669), 1,
      anon_sym_PIPE,
    STATE(14943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(4667), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684424] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19557), 1,
      sym__lowercase_identifier,
    ACTIONS(19559), 1,
      anon_sym_LBRACK,
    ACTIONS(19561), 1,
      anon_sym_virtual,
    STATE(12693), 1,
      sym_class_type_binding,
    STATE(14944), 1,
      sym_attribute,
    STATE(15465), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684453] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9240), 1,
      anon_sym_PIPE,
    STATE(14945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9242), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684474] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19332), 1,
      anon_sym_and,
    STATE(14758), 1,
      aux_sym_module_type_constraint_repeat1,
    STATE(14946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13522), 4,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_with,
  [684497] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19563), 1,
      anon_sym_RBRACE,
    STATE(14947), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684526] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9074), 1,
      anon_sym_PIPE,
    STATE(14948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9076), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684547] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9098), 1,
      anon_sym_PIPE,
    STATE(14949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9100), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684568] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9082), 1,
      anon_sym_PIPE,
    STATE(14950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9084), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684589] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19565), 1,
      anon_sym_RBRACE,
    STATE(14951), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684618] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19567), 1,
      anon_sym_RBRACE,
    STATE(14952), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684647] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19569), 1,
      anon_sym_RBRACE,
    STATE(14953), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684676] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19571), 1,
      anon_sym_RBRACE,
    STATE(14954), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684705] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19573), 1,
      anon_sym_RBRACE,
    STATE(14955), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684734] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19575), 1,
      sym__lowercase_identifier,
    STATE(5395), 1,
      sym_class_path,
    STATE(14956), 1,
      sym_attribute,
    STATE(15778), 1,
      sym__attribute,
    STATE(18580), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684763] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19577), 1,
      anon_sym_RBRACE,
    STATE(14957), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684792] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19579), 1,
      sym__lowercase_identifier,
    STATE(4633), 1,
      sym_class_path,
    STATE(14958), 1,
      sym_attribute,
    STATE(15276), 1,
      sym__attribute,
    STATE(19245), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684821] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19581), 1,
      anon_sym_RBRACE,
    STATE(14959), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684850] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19583), 1,
      anon_sym_RBRACE,
    STATE(14960), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684879] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(12635), 1,
      anon_sym_and,
    STATE(14809), 1,
      aux_sym_expression_item_repeat1,
    STATE(14961), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12633), 2,
      anon_sym_in,
      sym_let_and_operator,
  [684906] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9638), 1,
      anon_sym_PIPE,
    STATE(14962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9640), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [684927] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19585), 1,
      anon_sym_RBRACE,
    STATE(14963), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684956] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19587), 1,
      anon_sym_RBRACE,
    STATE(14964), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [684985] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19589), 1,
      anon_sym_RBRACE,
    STATE(14965), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685014] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19591), 1,
      sym__lowercase_identifier,
    STATE(7339), 1,
      sym_class_path,
    STATE(14966), 1,
      sym_attribute,
    STATE(15770), 1,
      sym__attribute,
    STATE(20844), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685043] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19593), 1,
      anon_sym_RBRACE,
    STATE(14967), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685072] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19595), 1,
      anon_sym_RBRACE,
    STATE(14968), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685101] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19597), 1,
      anon_sym_RBRACE,
    STATE(14969), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685130] = 8,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(7693), 1,
      anon_sym_LBRACK_AT_AT,
    ACTIONS(13406), 1,
      anon_sym_and,
    STATE(14744), 1,
      aux_sym_expression_item_repeat1,
    STATE(14970), 1,
      sym_attribute,
    STATE(15472), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13404), 2,
      anon_sym_in,
      sym_let_and_operator,
  [685157] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11589), 1,
      anon_sym_RPAREN,
    STATE(14971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9224), 5,
      anon_sym_DASH_GT,
      anon_sym_STAR,
      anon_sym_POUND,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [685178] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19599), 1,
      anon_sym_RBRACE,
    STATE(14972), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685207] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19601), 1,
      anon_sym_RBRACE,
    STATE(14973), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685236] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19603), 1,
      sym__lowercase_identifier,
    STATE(6358), 1,
      sym_class_path,
    STATE(14974), 1,
      sym_attribute,
    STATE(15268), 1,
      sym__attribute,
    STATE(19687), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685265] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(14975), 1,
      sym_attribute,
    STATE(15887), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21317), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [685292] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19605), 1,
      anon_sym_RBRACE,
    STATE(14976), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685321] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19607), 1,
      anon_sym_RBRACE,
    STATE(14977), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685350] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19609), 1,
      anon_sym_RBRACE,
    STATE(14978), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685379] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9194), 1,
      anon_sym_PIPE,
    STATE(14979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9196), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [685400] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19611), 1,
      anon_sym_RBRACE,
    STATE(14980), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685429] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19613), 1,
      sym__lowercase_identifier,
    STATE(7060), 1,
      sym_class_path,
    STATE(14981), 1,
      sym_attribute,
    STATE(15757), 1,
      sym__attribute,
    STATE(18844), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685458] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9110), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    STATE(14982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 3,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_as,
  [685483] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19615), 1,
      sym__lowercase_identifier,
    STATE(8265), 1,
      sym_class_path,
    STATE(14983), 1,
      sym_attribute,
    STATE(15346), 1,
      sym__attribute,
    STATE(19557), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685512] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19617), 1,
      anon_sym_RBRACE,
    STATE(14984), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685541] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19619), 1,
      anon_sym_RBRACE,
    STATE(14985), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685570] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    ACTIONS(18621), 1,
      anon_sym_PIPE,
    ACTIONS(18625), 1,
      anon_sym_as,
    ACTIONS(18627), 1,
      anon_sym_COLON_COLON,
    STATE(14986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17749), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [685597] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19621), 1,
      anon_sym_RBRACE,
    STATE(14987), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685626] = 9,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    ACTIONS(19623), 1,
      anon_sym_RBRACE,
    STATE(14988), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685655] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9110), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    STATE(14989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9112), 4,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_as,
      anon_sym_COLON_COLON,
  [685678] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(14990), 1,
      sym_attribute,
    STATE(15902), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21338), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [685705] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(14991), 1,
      sym_attribute,
    STATE(15904), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21341), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [685732] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9132), 1,
      anon_sym_COLON2,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    STATE(14992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(9134), 2,
      anon_sym_RPAREN,
      anon_sym_as,
  [685759] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17511), 1,
      anon_sym_PIPE,
    STATE(14993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17509), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_RBRACK,
  [685780] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14994), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17173), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685806] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(14995), 1,
      sym_attribute,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13353), 2,
      anon_sym_and,
      anon_sym_in,
  [685830] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(14996), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(18343), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685856] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19627), 1,
      anon_sym_SEMI,
    ACTIONS(19629), 1,
      anon_sym_GT_RBRACE,
    STATE(14997), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16544), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685882] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11355), 1,
      sym__lowercase_identifier,
    ACTIONS(19631), 1,
      anon_sym_POUND,
    STATE(9876), 1,
      sym_type_constructor_path,
    STATE(14998), 1,
      sym_attribute,
    STATE(17717), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685908] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(14999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8302), 5,
      anon_sym_EQ,
      anon_sym_of,
      anon_sym_COLON2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [685926] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19633), 1,
      anon_sym_SEMI,
    ACTIONS(19635), 1,
      anon_sym_GT_RBRACE,
    STATE(15000), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685952] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15001), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17601), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [685978] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15002), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16567), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686004] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19637), 1,
      anon_sym_SEMI,
    ACTIONS(19639), 1,
      anon_sym_GT_RBRACE,
    STATE(15003), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16133), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686030] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15004), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16030), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686056] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    ACTIONS(19641), 1,
      anon_sym_POUND,
    STATE(13262), 1,
      sym_type_constructor_path,
    STATE(15005), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686082] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15006), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16501), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686108] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15007), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(15937), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686134] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19643), 1,
      anon_sym_type,
    ACTIONS(19645), 1,
      anon_sym_module,
    STATE(15008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11501), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [686156] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15009), 1,
      sym_attribute,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11934), 2,
      anon_sym_and,
      anon_sym_in,
  [686180] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15010), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16166), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686206] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19647), 1,
      anon_sym_SEMI,
    ACTIONS(19649), 1,
      anon_sym_GT_RBRACE,
    STATE(15011), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16900), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686232] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15012), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(15924), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686258] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19651), 1,
      anon_sym_SEMI,
    ACTIONS(19653), 1,
      anon_sym_GT_RBRACE,
    STATE(15013), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17160), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686284] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19655), 1,
      anon_sym_SEMI,
    ACTIONS(19657), 1,
      anon_sym_GT_RBRACE,
    STATE(15014), 1,
      sym_attribute,
    STATE(15989), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686310] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15015), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16802), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686336] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19659), 1,
      anon_sym_EQ,
    ACTIONS(19661), 1,
      anon_sym_of,
    ACTIONS(19663), 1,
      anon_sym_COLON2,
    STATE(15016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13176), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [686360] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10819), 1,
      sym_constructor_path,
    STATE(15017), 1,
      sym_attribute,
    STATE(18554), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19667), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686404] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15019), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16799), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686430] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15020), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16167), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686456] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11211), 1,
      sym__lowercase_identifier,
    ACTIONS(19669), 1,
      anon_sym_POUND,
    STATE(9728), 1,
      sym_type_constructor_path,
    STATE(15021), 1,
      sym_attribute,
    STATE(17650), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686482] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19219), 1,
      sym__lowercase_identifier,
    STATE(15022), 1,
      sym_attribute,
    STATE(15604), 1,
      aux_sym_instance_variable_specification_repeat1,
    STATE(17707), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19223), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [686506] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15023), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16009), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686532] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19219), 1,
      sym__lowercase_identifier,
    STATE(13152), 1,
      sym__instance_variable_name,
    STATE(15024), 1,
      sym_attribute,
    STATE(15107), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19223), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [686556] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19671), 1,
      anon_sym_SEMI,
    ACTIONS(19673), 1,
      anon_sym_GT_RBRACE,
    STATE(15025), 1,
      sym_attribute,
    STATE(15970), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686582] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15026), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16484), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686608] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15027), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16932), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686634] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19675), 1,
      anon_sym_SEMI,
    ACTIONS(19677), 1,
      anon_sym_GT_RBRACE,
    STATE(15028), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16863), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686660] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19679), 1,
      anon_sym_SEMI,
    ACTIONS(19681), 1,
      anon_sym_GT_RBRACE,
    STATE(15029), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16125), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686686] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19683), 1,
      anon_sym_SEMI,
    ACTIONS(19685), 1,
      anon_sym_GT_RBRACE,
    STATE(15030), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17141), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686712] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19687), 1,
      anon_sym_RPAREN,
    STATE(15031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686738] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12373), 1,
      sym__lowercase_identifier,
    ACTIONS(19689), 1,
      anon_sym_POUND,
    STATE(13674), 1,
      sym_type_constructor_path,
    STATE(15032), 1,
      sym_attribute,
    STATE(17903), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686764] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11333), 1,
      sym__lowercase_identifier,
    ACTIONS(19691), 1,
      anon_sym_POUND,
    STATE(10294), 1,
      sym_type_constructor_path,
    STATE(15033), 1,
      sym_attribute,
    STATE(17387), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686790] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11357), 1,
      sym__lowercase_identifier,
    ACTIONS(19693), 1,
      anon_sym_POUND,
    STATE(11438), 1,
      sym_type_constructor_path,
    STATE(15034), 1,
      sym_attribute,
    STATE(17663), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686816] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19695), 1,
      anon_sym_RPAREN,
    STATE(15035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686842] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19697), 1,
      anon_sym_SEMI,
    ACTIONS(19699), 1,
      anon_sym_GT_RBRACE,
    STATE(15036), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16912), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686868] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15037), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16230), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686894] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15038), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16964), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686920] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19701), 1,
      anon_sym_RPAREN,
    STATE(15039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19703), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [686964] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19705), 1,
      anon_sym_SEMI,
    ACTIONS(19707), 1,
      anon_sym_GT_RBRACE,
    STATE(15041), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16168), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [686990] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15042), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16384), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687016] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15043), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16766), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687042] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15044), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16685), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687068] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15045), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16011), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687094] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(10906), 1,
      sym_constructor_path,
    STATE(15046), 1,
      sym_attribute,
    STATE(19838), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687120] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19709), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11968), 2,
      anon_sym_and,
      anon_sym_in,
    STATE(15047), 2,
      sym_attribute,
      aux_sym_expression_item_repeat1,
  [687142] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19712), 1,
      anon_sym_SEMI,
    ACTIONS(19714), 1,
      anon_sym_GT_RBRACE,
    STATE(15048), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16520), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687168] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19716), 1,
      anon_sym_type,
    ACTIONS(19718), 1,
      anon_sym_module,
    STATE(15049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9888), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [687190] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15050), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(15979), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687216] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15051), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17016), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687242] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19219), 1,
      sym__lowercase_identifier,
    STATE(13152), 1,
      sym__instance_variable_name,
    STATE(15052), 1,
      sym_attribute,
    STATE(15604), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19223), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [687266] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19720), 1,
      anon_sym_SEMI,
    ACTIONS(19722), 1,
      anon_sym_GT_RBRACE,
    STATE(15053), 1,
      sym_attribute,
    STATE(15980), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687292] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(19724), 1,
      anon_sym_LPAREN,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10906), 1,
      sym_constructor_path,
    STATE(15054), 1,
      sym_attribute,
    STATE(20953), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687318] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12415), 1,
      sym__lowercase_identifier,
    ACTIONS(19726), 1,
      anon_sym_POUND,
    STATE(13976), 1,
      sym_type_constructor_path,
    STATE(15055), 1,
      sym_attribute,
    STATE(17826), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687344] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19219), 1,
      sym__lowercase_identifier,
    STATE(15022), 1,
      aux_sym_instance_variable_specification_repeat1,
    STATE(15056), 1,
      sym_attribute,
    STATE(18250), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19223), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [687368] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15057), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16880), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687394] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15058), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16450), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687420] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12466), 1,
      sym__lowercase_identifier,
    ACTIONS(19728), 1,
      anon_sym_POUND,
    STATE(9461), 1,
      sym_type_constructor_path,
    STATE(15059), 1,
      sym_attribute,
    STATE(18423), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687446] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19730), 1,
      sym__lowercase_identifier,
    ACTIONS(19734), 1,
      anon_sym_BANG,
    STATE(15060), 1,
      sym_attribute,
    STATE(15373), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19732), 2,
      anon_sym_private,
      anon_sym_virtual,
  [687470] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(19724), 1,
      anon_sym_LPAREN,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10819), 1,
      sym_constructor_path,
    STATE(15061), 1,
      sym_attribute,
    STATE(20953), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687496] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15062), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16885), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687522] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19736), 1,
      sym__lowercase_identifier,
    ACTIONS(19738), 1,
      anon_sym_LPAREN,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(13281), 1,
      sym__value_name,
    STATE(15063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687548] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19742), 1,
      anon_sym_SEMI,
    ACTIONS(19744), 1,
      anon_sym_GT_RBRACE,
    STATE(15064), 1,
      sym_attribute,
    STATE(15921), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687574] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19746), 1,
      anon_sym_SEMI,
    ACTIONS(19748), 1,
      anon_sym_GT_RBRACE,
    STATE(15065), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16052), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687600] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15066), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16221), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19750), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [687644] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19752), 1,
      anon_sym_SEMI,
    ACTIONS(19754), 1,
      anon_sym_GT_RBRACE,
    STATE(15068), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16237), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687670] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15069), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12816), 2,
      anon_sym_and,
      anon_sym_in,
  [687694] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11387), 1,
      sym__lowercase_identifier,
    ACTIONS(19756), 1,
      anon_sym_POUND,
    STATE(11326), 1,
      sym_type_constructor_path,
    STATE(15070), 1,
      sym_attribute,
    STATE(17839), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687720] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19285), 1,
      anon_sym_AMP,
    STATE(15071), 1,
      sym_attribute,
    STATE(15080), 1,
      aux_sym_tag_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19758), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [687742] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19643), 1,
      anon_sym_type,
    ACTIONS(19645), 1,
      anon_sym_module,
    STATE(15072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9888), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [687764] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19760), 1,
      anon_sym_RPAREN,
    STATE(15073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687790] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    ACTIONS(19766), 1,
      anon_sym_RBRACK,
    STATE(15074), 1,
      sym_attribute,
    STATE(16846), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687816] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15075), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16309), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687842] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19768), 1,
      anon_sym_RPAREN,
    STATE(15076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687868] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19770), 1,
      anon_sym_RPAREN,
    STATE(15077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687894] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11213), 1,
      sym__lowercase_identifier,
    ACTIONS(19772), 1,
      anon_sym_POUND,
    STATE(11324), 1,
      sym_type_constructor_path,
    STATE(15078), 1,
      sym_attribute,
    STATE(17735), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687920] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(15079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19774), 4,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
      anon_sym_AMP,
  [687940] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19776), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15080), 2,
      sym_attribute,
      aux_sym_tag_specification_repeat1,
    ACTIONS(19774), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [687960] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19779), 1,
      anon_sym_SEMI,
    ACTIONS(19781), 1,
      anon_sym_GT_RBRACE,
    STATE(15081), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16706), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [687986] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15082), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(18271), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688012] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12429), 1,
      sym__lowercase_identifier,
    ACTIONS(19783), 1,
      anon_sym_POUND,
    STATE(12457), 1,
      sym_type_constructor_path,
    STATE(15083), 1,
      sym_attribute,
    STATE(17779), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19785), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688056] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19787), 1,
      anon_sym_SEMI,
    ACTIONS(19789), 1,
      anon_sym_GT_RBRACE,
    STATE(15085), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16542), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688082] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9294), 1,
      sym__uppercase_identifier,
    ACTIONS(19791), 1,
      anon_sym_LPAREN,
    STATE(14103), 1,
      sym__constructor_name,
    STATE(15086), 1,
      sym_attribute,
    STATE(17651), 1,
      sym_constructor_path,
    STATE(18620), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688108] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12402), 1,
      sym__lowercase_identifier,
    ACTIONS(19793), 1,
      anon_sym_POUND,
    STATE(9738), 1,
      sym_type_constructor_path,
    STATE(15087), 1,
      sym_attribute,
    STATE(17792), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688134] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19795), 1,
      anon_sym_SEMI,
    ACTIONS(19797), 1,
      anon_sym_GT_RBRACE,
    STATE(15088), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16703), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688160] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15089), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16096), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688186] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19799), 1,
      anon_sym_RPAREN,
    STATE(15090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688212] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15091), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12830), 2,
      anon_sym_and,
      anon_sym_in,
  [688236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19801), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [688254] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8112), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    STATE(15093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8114), 3,
      anon_sym_COMMA,
      anon_sym_with,
      sym_hash_operator,
  [688276] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19805), 1,
      anon_sym_SEMI,
    ACTIONS(19807), 1,
      anon_sym_GT_RBRACE,
    STATE(15094), 1,
      sym_attribute,
    STATE(15981), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688302] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15095), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16038), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688328] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15096), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16559), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688354] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15097), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16296), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688380] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11293), 1,
      sym__lowercase_identifier,
    ACTIONS(19809), 1,
      anon_sym_POUND,
    STATE(11716), 1,
      sym_type_constructor_path,
    STATE(15098), 1,
      sym_attribute,
    STATE(17763), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688406] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15099), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13353), 2,
      anon_sym_and,
      anon_sym_in,
  [688430] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15100), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16715), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688456] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15101), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16573), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688482] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19811), 1,
      anon_sym_SEMI,
    ACTIONS(19813), 1,
      anon_sym_GT_RBRACE,
    STATE(15102), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16976), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688508] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19815), 1,
      anon_sym_SEMI,
    ACTIONS(19817), 1,
      anon_sym_GT_RBRACE,
    STATE(15103), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16142), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688534] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15104), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13373), 2,
      anon_sym_and,
      anon_sym_in,
  [688558] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15105), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16200), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688584] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19819), 1,
      anon_sym_SEMI,
    ACTIONS(19821), 1,
      anon_sym_GT_RBRACE,
    STATE(15106), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16231), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688610] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19219), 1,
      sym__lowercase_identifier,
    STATE(13096), 1,
      sym__instance_variable_name,
    STATE(15107), 1,
      sym_attribute,
    STATE(15604), 1,
      aux_sym_instance_variable_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19223), 2,
      anon_sym_mutable,
      anon_sym_virtual,
  [688634] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15108), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16032), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688660] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19823), 1,
      anon_sym_SEMI,
    ACTIONS(19825), 1,
      anon_sym_GT_RBRACE,
    STATE(15109), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16294), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688686] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19827), 1,
      anon_sym_SEMI,
    ACTIONS(19829), 1,
      anon_sym_GT_RBRACE,
    STATE(15110), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16462), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688712] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10906), 1,
      sym_constructor_path,
    STATE(15111), 1,
      sym_attribute,
    STATE(18554), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688738] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19831), 1,
      anon_sym_SEMI,
    ACTIONS(19833), 1,
      anon_sym_GT_RBRACE,
    STATE(15112), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16385), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688764] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15113), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16008), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688790] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15114), 1,
      sym_attribute,
    STATE(15148), 1,
      sym_field_path,
    STATE(16314), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688816] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11297), 1,
      sym__lowercase_identifier,
    ACTIONS(19835), 1,
      anon_sym_POUND,
    STATE(10739), 1,
      sym_type_constructor_path,
    STATE(15115), 1,
      sym_attribute,
    STATE(17804), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688842] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19837), 1,
      anon_sym_type,
    ACTIONS(19839), 1,
      anon_sym_module,
    STATE(15116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14946), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [688864] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15117), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16216), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688890] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    ACTIONS(19841), 1,
      anon_sym_POUND,
    STATE(11313), 1,
      sym_type_constructor_path,
    STATE(15118), 1,
      sym_attribute,
    STATE(17432), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688916] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15119), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16517), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [688942] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    STATE(15120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13610), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [688964] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    STATE(15121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13618), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [688986] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15122), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16844), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689012] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19847), 1,
      anon_sym_SEMI,
    ACTIONS(19849), 1,
      anon_sym_GT_RBRACE,
    STATE(15123), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16441), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689038] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19853), 1,
      anon_sym__,
    STATE(15124), 1,
      sym_attribute,
    STATE(15164), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19851), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [689062] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19855), 1,
      anon_sym_RPAREN,
    STATE(15125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689088] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    STATE(15126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13704), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [689110] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10855), 1,
      sym_constructor_path,
    STATE(15127), 1,
      sym_attribute,
    STATE(18554), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689136] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19857), 1,
      anon_sym_SEMI,
    ACTIONS(19859), 1,
      anon_sym_GT_RBRACE,
    STATE(15128), 1,
      sym_attribute,
    STATE(15983), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689162] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15129), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16109), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689188] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19861), 1,
      anon_sym_type,
    ACTIONS(19863), 1,
      anon_sym_module,
    STATE(15130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9888), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [689210] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15131), 1,
      sym_attribute,
    STATE(15143), 1,
      sym_field_path,
    STATE(16677), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689236] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11335), 1,
      sym__lowercase_identifier,
    ACTIONS(19865), 1,
      anon_sym_POUND,
    STATE(11187), 1,
      sym_type_constructor_path,
    STATE(15132), 1,
      sym_attribute,
    STATE(17698), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689262] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15133), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17015), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689288] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12449), 1,
      sym__lowercase_identifier,
    ACTIONS(19867), 1,
      anon_sym_POUND,
    STATE(13480), 1,
      sym_type_constructor_path,
    STATE(15134), 1,
      sym_attribute,
    STATE(17850), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689314] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15135), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16169), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689340] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19869), 1,
      anon_sym_RPAREN,
    STATE(15136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689366] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19871), 1,
      anon_sym_type,
    ACTIONS(19873), 1,
      anon_sym_module,
    STATE(15137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14524), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [689388] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19716), 1,
      anon_sym_type,
    ACTIONS(19718), 1,
      anon_sym_module,
    STATE(15138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11737), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [689410] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15139), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16319), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689436] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19875), 1,
      anon_sym_RPAREN,
    STATE(15140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689462] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19877), 1,
      anon_sym_SEMI,
    ACTIONS(19879), 1,
      anon_sym_GT_RBRACE,
    STATE(15141), 1,
      sym_attribute,
    STATE(16010), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689488] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(10855), 1,
      sym_constructor_path,
    STATE(15142), 1,
      sym_attribute,
    STATE(19838), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689514] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19881), 1,
      anon_sym_EQ,
    ACTIONS(19883), 1,
      anon_sym_COLON2,
    STATE(15143), 1,
      sym_attribute,
    STATE(16545), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19885), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [689538] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19837), 1,
      anon_sym_type,
    ACTIONS(19839), 1,
      anon_sym_module,
    STATE(15144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9888), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [689560] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11313), 1,
      sym__lowercase_identifier,
    ACTIONS(19887), 1,
      anon_sym_POUND,
    STATE(10588), 1,
      sym_type_constructor_path,
    STATE(15145), 1,
      sym_attribute,
    STATE(17813), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689586] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19889), 1,
      anon_sym_SEMI,
    ACTIONS(19891), 1,
      anon_sym_GT_RBRACE,
    STATE(15146), 1,
      sym_attribute,
    STATE(16014), 1,
      sym_instance_variable_expression,
    STATE(16042), 1,
      sym__instance_variable_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689612] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19861), 1,
      anon_sym_type,
    ACTIONS(19863), 1,
      anon_sym_module,
    STATE(15147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11241), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [689634] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19883), 1,
      anon_sym_COLON2,
    ACTIONS(19893), 1,
      anon_sym_EQ,
    STATE(15148), 1,
      sym_attribute,
    STATE(16963), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19895), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [689658] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12387), 1,
      sym__lowercase_identifier,
    ACTIONS(19897), 1,
      anon_sym_POUND,
    STATE(9973), 1,
      sym_type_constructor_path,
    STATE(15149), 1,
      sym_attribute,
    STATE(17862), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689684] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15150), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(17029), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689710] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19899), 1,
      anon_sym_SEMI,
    ACTIONS(19901), 1,
      anon_sym_GT_RBRACE,
    STATE(15151), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16108), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689736] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19903), 1,
      anon_sym_SEMI,
    ACTIONS(19905), 1,
      anon_sym_GT_RBRACE,
    STATE(15152), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16448), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689762] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19907), 1,
      anon_sym_SEMI,
    ACTIONS(19909), 1,
      anon_sym_GT_RBRACE,
    STATE(15153), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16814), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689788] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19911), 1,
      anon_sym_type,
    ACTIONS(19913), 1,
      anon_sym_module,
    STATE(15154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(11243), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [689810] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15155), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12678), 2,
      anon_sym_and,
      anon_sym_in,
  [689834] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15156), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12678), 2,
      anon_sym_and,
      anon_sym_in,
  [689858] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15157), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16240), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689884] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    STATE(15158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13721), 3,
      anon_sym_and,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [689906] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15159), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16558), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689932] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19915), 1,
      anon_sym_SEMI,
    ACTIONS(19917), 1,
      anon_sym_GT_RBRACE,
    STATE(15160), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16809), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689958] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19919), 1,
      anon_sym_SEMI,
    ACTIONS(19921), 1,
      anon_sym_GT_RBRACE,
    STATE(15161), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17132), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [689984] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8046), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(7237), 1,
      sym__constructor_name,
    STATE(10819), 1,
      sym_constructor_path,
    STATE(15162), 1,
      sym_attribute,
    STATE(19838), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690010] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19923), 1,
      anon_sym_EQ,
    ACTIONS(19925), 1,
      anon_sym_of,
    ACTIONS(19927), 1,
      anon_sym_COLON2,
    STATE(15163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13020), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [690034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19929), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [690052] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19931), 1,
      anon_sym_SEMI,
    ACTIONS(19933), 1,
      anon_sym_GT_RBRACE,
    STATE(15165), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16785), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690078] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15166), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16736), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690104] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15167), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16834), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690130] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19935), 1,
      anon_sym_SEMI,
    ACTIONS(19937), 1,
      anon_sym_GT_RBRACE,
    STATE(15168), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16868), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690156] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11209), 1,
      sym__lowercase_identifier,
    ACTIONS(19939), 1,
      anon_sym_POUND,
    STATE(10325), 1,
      sym_type_constructor_path,
    STATE(15169), 1,
      sym_attribute,
    STATE(17750), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690182] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19941), 1,
      anon_sym_SEMI,
    ACTIONS(19943), 1,
      anon_sym_GT_RBRACE,
    STATE(15170), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16481), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690208] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19945), 1,
      anon_sym_RPAREN,
    STATE(15171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690234] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15172), 1,
      sym_attribute,
    STATE(15175), 1,
      sym_field_path,
    STATE(16259), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690260] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19285), 1,
      anon_sym_AMP,
    STATE(15080), 1,
      aux_sym_tag_specification_repeat1,
    STATE(15173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19281), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [690282] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19947), 1,
      anon_sym_RPAREN,
    STATE(15174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690308] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19883), 1,
      anon_sym_COLON2,
    ACTIONS(19949), 1,
      anon_sym_EQ,
    STATE(15175), 1,
      sym_attribute,
    STATE(16540), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19951), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [690332] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    ACTIONS(19953), 1,
      anon_sym_POUND,
    STATE(14564), 1,
      sym_type_constructor_path,
    STATE(15176), 1,
      sym_attribute,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690358] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15148), 1,
      sym_field_path,
    STATE(15177), 1,
      sym_attribute,
    STATE(16130), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690384] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    ACTIONS(19955), 1,
      anon_sym_RBRACK,
    STATE(15178), 1,
      sym_attribute,
    STATE(17185), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690410] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19957), 1,
      anon_sym_SEMI,
    ACTIONS(19959), 1,
      anon_sym_GT_RBRACE,
    STATE(15179), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16699), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690436] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15148), 1,
      sym_field_path,
    STATE(15180), 1,
      sym_attribute,
    STATE(16336), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690462] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19961), 1,
      anon_sym_RPAREN,
    STATE(15181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690488] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9294), 1,
      sym__uppercase_identifier,
    ACTIONS(19791), 1,
      anon_sym_LPAREN,
    STATE(14103), 1,
      sym__constructor_name,
    STATE(15182), 1,
      sym_attribute,
    STATE(17406), 1,
      sym_constructor_path,
    STATE(18620), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690514] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(19963), 1,
      anon_sym_EQ,
    ACTIONS(19965), 1,
      anon_sym_of,
    ACTIONS(19967), 1,
      anon_sym_COLON2,
    STATE(15183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13066), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [690538] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9270), 1,
      sym__uppercase_identifier,
    ACTIONS(19724), 1,
      anon_sym_LPAREN,
    STATE(9240), 1,
      sym__constructor_name,
    STATE(10855), 1,
      sym_constructor_path,
    STATE(15184), 1,
      sym_attribute,
    STATE(20953), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690564] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19911), 1,
      anon_sym_type,
    ACTIONS(19913), 1,
      anon_sym_module,
    STATE(15185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(9888), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [690586] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19969), 1,
      anon_sym_SEMI,
    ACTIONS(19971), 1,
      anon_sym_GT_RBRACE,
    STATE(15186), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16836), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690612] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15175), 1,
      sym_field_path,
    STATE(15187), 1,
      sym_attribute,
    STATE(16088), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690638] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15143), 1,
      sym_field_path,
    STATE(15188), 1,
      sym_attribute,
    STATE(15995), 1,
      sym_field_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690664] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15189), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13333), 2,
      anon_sym_and,
      anon_sym_in,
  [690688] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    ACTIONS(19973), 1,
      anon_sym_RPAREN,
    STATE(15190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690714] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9294), 1,
      sym__uppercase_identifier,
    ACTIONS(19791), 1,
      anon_sym_LPAREN,
    STATE(14103), 1,
      sym__constructor_name,
    STATE(15191), 1,
      sym_attribute,
    STATE(17424), 1,
      sym_constructor_path,
    STATE(18620), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690740] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19975), 1,
      anon_sym_SEMI,
    ACTIONS(19977), 1,
      anon_sym_GT_RBRACE,
    STATE(15192), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16948), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690766] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15175), 1,
      sym_field_path,
    STATE(15193), 1,
      sym_attribute,
    STATE(16420), 1,
      sym_field_expression,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690792] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15148), 1,
      sym_field_path,
    STATE(15194), 1,
      sym_attribute,
    STATE(16006), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690818] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19871), 1,
      anon_sym_type,
    ACTIONS(19873), 1,
      anon_sym_module,
    STATE(15195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14230), 3,
      sym_constrain_type,
      sym_constrain_module,
      sym_constrain_module_type,
  [690840] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15196), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12964), 2,
      anon_sym_and,
      anon_sym_in,
  [690864] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    ACTIONS(18524), 1,
      anon_sym_PIPE,
    ACTIONS(18526), 1,
      anon_sym_as,
    ACTIONS(18528), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19979), 1,
      anon_sym_RPAREN,
    STATE(15197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690890] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12435), 1,
      sym__lowercase_identifier,
    ACTIONS(19981), 1,
      anon_sym_POUND,
    STATE(9428), 1,
      sym_type_constructor_path,
    STATE(15198), 1,
      sym_attribute,
    STATE(17878), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690916] = 8,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(17771), 1,
      sym__lowercase_identifier,
    STATE(15148), 1,
      sym_field_path,
    STATE(15199), 1,
      sym_attribute,
    STATE(16564), 1,
      sym_field_binding_pattern,
    STATE(19762), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690942] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(19983), 1,
      anon_sym_DASH_GT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15200), 1,
      sym_attribute,
    STATE(15901), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [690965] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(15201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19985), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [690984] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13852), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [691005] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(19987), 1,
      sym__lowercase_identifier,
    STATE(11762), 1,
      sym_class_type_path,
    STATE(15203), 1,
      sym_attribute,
    STATE(17576), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691028] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19989), 1,
      anon_sym_COLON_GT,
    ACTIONS(19991), 1,
      anon_sym_RPAREN,
    STATE(15204), 1,
      sym_attribute,
    STATE(17322), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691051] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19163), 1,
      sym__lowercase_identifier,
    STATE(7380), 1,
      sym_class_path,
    STATE(15205), 1,
      sym_attribute,
    STATE(18682), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691074] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(19993), 1,
      anon_sym_GT_RBRACE,
    STATE(15206), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691097] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(19995), 1,
      anon_sym_COLON_GT,
    ACTIONS(19997), 1,
      anon_sym_RPAREN,
    STATE(15207), 1,
      sym_attribute,
    STATE(17435), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691120] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20001), 1,
      anon_sym_RBRACK,
    ACTIONS(20003), 1,
      anon_sym_GT,
    STATE(15208), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691143] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20001), 1,
      anon_sym_RBRACK,
    STATE(15209), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691166] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20005), 1,
      anon_sym_GT_RBRACE,
    STATE(15210), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691189] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20007), 1,
      anon_sym_RBRACK,
    STATE(15211), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691212] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20009), 1,
      anon_sym_GT_RBRACE,
    STATE(15212), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691235] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20011), 1,
      anon_sym_RBRACK,
    STATE(15213), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691258] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20013), 1,
      sym__lowercase_identifier,
    STATE(9959), 1,
      sym_class_type_path,
    STATE(15214), 1,
      sym_attribute,
    STATE(18345), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691281] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19299), 1,
      sym__lowercase_identifier,
    STATE(7945), 1,
      sym_class_path,
    STATE(15215), 1,
      sym_attribute,
    STATE(19535), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691304] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19334), 1,
      sym__lowercase_identifier,
    STATE(6559), 1,
      sym_class_path,
    STATE(15216), 1,
      sym_attribute,
    STATE(18898), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691327] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20015), 1,
      sym__lowercase_identifier,
    STATE(13938), 1,
      sym_class_type_path,
    STATE(15217), 1,
      sym_attribute,
    STATE(17687), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691350] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20015), 1,
      sym__lowercase_identifier,
    STATE(13967), 1,
      sym_class_type_path,
    STATE(15218), 1,
      sym_attribute,
    STATE(17687), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691373] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20015), 1,
      sym__lowercase_identifier,
    STATE(13975), 1,
      sym_class_type_path,
    STATE(15219), 1,
      sym_attribute,
    STATE(17687), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691396] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20017), 1,
      anon_sym_COLON_GT,
    ACTIONS(20019), 1,
      anon_sym_RPAREN,
    STATE(15220), 1,
      sym_attribute,
    STATE(17890), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691419] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20021), 1,
      anon_sym_RBRACK,
    ACTIONS(20023), 1,
      anon_sym_GT,
    STATE(15221), 1,
      sym_attribute,
    STATE(15445), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691442] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20021), 1,
      anon_sym_RBRACK,
    ACTIONS(20023), 1,
      anon_sym_GT,
    STATE(15222), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691465] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20025), 1,
      anon_sym_GT_RBRACE,
    STATE(15223), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691488] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20027), 1,
      anon_sym_DOT,
    STATE(15224), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691511] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20029), 1,
      anon_sym_DOT,
    STATE(15225), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691534] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20031), 1,
      anon_sym_DOT,
    STATE(15226), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691557] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20033), 1,
      anon_sym_GT_RBRACE,
    STATE(15227), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691580] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19371), 1,
      sym__lowercase_identifier,
    STATE(4957), 1,
      sym_class_path,
    STATE(15228), 1,
      sym_attribute,
    STATE(19573), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691603] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20035), 1,
      sym__lowercase_identifier,
    STATE(9090), 1,
      sym_type_constructor_path,
    STATE(15229), 1,
      sym_attribute,
    STATE(17681), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691626] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20037), 1,
      anon_sym_COLON_GT,
    ACTIONS(20039), 1,
      anon_sym_RPAREN,
    STATE(15230), 1,
      sym_attribute,
    STATE(17666), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691649] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20041), 1,
      sym__lowercase_identifier,
    STATE(10659), 1,
      sym_class_type_path,
    STATE(15231), 1,
      sym_attribute,
    STATE(17653), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691672] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20043), 1,
      anon_sym_COLON_GT,
    ACTIONS(20045), 1,
      anon_sym_RPAREN,
    STATE(15232), 1,
      sym_attribute,
    STATE(17495), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691695] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20047), 1,
      anon_sym_RPAREN,
    STATE(15233), 1,
      sym_attribute,
    STATE(16149), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691718] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20049), 1,
      anon_sym_DOT,
    STATE(15234), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691741] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(15235), 1,
      sym_attribute,
    STATE(16792), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691764] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20051), 1,
      anon_sym_DOT,
    STATE(15236), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691787] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(20053), 1,
      sym__lowercase_identifier,
    STATE(15237), 1,
      sym_attribute,
    STATE(18173), 1,
      sym_extended_module_path,
    STATE(18211), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691810] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20055), 1,
      anon_sym_GT_RBRACE,
    STATE(15238), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691833] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9898), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20057), 1,
      anon_sym_GT,
    STATE(15239), 1,
      sym_attribute,
    STATE(15273), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691856] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20059), 1,
      anon_sym_GT_RBRACE,
    STATE(15240), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691879] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20061), 1,
      anon_sym_DOT,
    STATE(15241), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691902] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20063), 1,
      anon_sym_RPAREN,
    STATE(15242), 1,
      sym_attribute,
    STATE(16245), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691925] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19443), 1,
      sym__lowercase_identifier,
    STATE(3266), 1,
      sym_class_path,
    STATE(15243), 1,
      sym_attribute,
    STATE(19611), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691948] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9906), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20065), 1,
      anon_sym_GT,
    STATE(15244), 1,
      sym_attribute,
    STATE(15249), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691971] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20067), 1,
      anon_sym_COLON_GT,
    ACTIONS(20069), 1,
      anon_sym_RPAREN,
    STATE(15245), 1,
      sym_attribute,
    STATE(17853), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [691994] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20071), 1,
      anon_sym_GT_RBRACE,
    STATE(15246), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692017] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20073), 1,
      anon_sym_GT_RBRACE,
    STATE(15247), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692040] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20075), 1,
      anon_sym_RBRACK,
    ACTIONS(20077), 1,
      anon_sym_GT,
    STATE(15248), 1,
      sym_attribute,
    STATE(15254), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692063] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20075), 1,
      anon_sym_RBRACK,
    ACTIONS(20077), 1,
      anon_sym_GT,
    STATE(15249), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692086] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20079), 1,
      anon_sym_GT_RBRACE,
    STATE(15250), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692109] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20081), 1,
      sym__lowercase_identifier,
    ACTIONS(20083), 1,
      anon_sym_LPAREN,
    STATE(5806), 1,
      sym_parenthesized_operator,
    STATE(5830), 1,
      sym__value_name,
    STATE(15251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692132] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20085), 1,
      anon_sym_GT_RBRACE,
    STATE(15252), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692155] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19531), 1,
      sym__lowercase_identifier,
    STATE(6963), 1,
      sym_class_path,
    STATE(15253), 1,
      sym_attribute,
    STATE(19649), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692178] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20087), 1,
      anon_sym_RBRACK,
    ACTIONS(20089), 1,
      anon_sym_GT,
    STATE(15254), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692201] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20087), 1,
      anon_sym_RBRACK,
    STATE(15255), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692224] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20091), 1,
      anon_sym_COLON_GT,
    ACTIONS(20093), 1,
      anon_sym_RPAREN,
    STATE(15256), 1,
      sym_attribute,
    STATE(18310), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692247] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20095), 1,
      anon_sym_GT_RBRACE,
    STATE(15257), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692270] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20097), 1,
      anon_sym_RBRACK,
    STATE(15258), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692293] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20099), 1,
      anon_sym_GT_RBRACE,
    STATE(15259), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692316] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20103), 1,
      anon_sym_RBRACE,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    STATE(15260), 1,
      sym_attribute,
    STATE(18307), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692339] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12413), 1,
      anon_sym_and,
    STATE(15261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12411), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [692358] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20107), 1,
      anon_sym_DOT,
    STATE(15262), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692381] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20109), 1,
      anon_sym_RBRACK,
    STATE(15263), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692404] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20111), 1,
      anon_sym_GT_RBRACE,
    STATE(15264), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692427] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20113), 1,
      sym__lowercase_identifier,
    STATE(7956), 1,
      sym_type_constructor_path,
    STATE(15265), 1,
      sym_attribute,
    STATE(17542), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692450] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19441), 1,
      sym__lowercase_identifier,
    STATE(3593), 1,
      sym_class_path,
    STATE(15266), 1,
      sym_attribute,
    STATE(18952), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692473] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20115), 1,
      sym__lowercase_identifier,
    STATE(11480), 1,
      sym_class_type_path,
    STATE(15267), 1,
      sym_attribute,
    STATE(17706), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692496] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19603), 1,
      sym__lowercase_identifier,
    STATE(6366), 1,
      sym_class_path,
    STATE(15268), 1,
      sym_attribute,
    STATE(19687), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692519] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20115), 1,
      sym__lowercase_identifier,
    STATE(11320), 1,
      sym_class_type_path,
    STATE(15269), 1,
      sym_attribute,
    STATE(17706), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692542] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20115), 1,
      sym__lowercase_identifier,
    STATE(11346), 1,
      sym_class_type_path,
    STATE(15270), 1,
      sym_attribute,
    STATE(17706), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692565] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20117), 1,
      sym__lowercase_identifier,
    STATE(11469), 1,
      sym_class_type_path,
    STATE(15271), 1,
      sym_attribute,
    STATE(17281), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692588] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20119), 1,
      anon_sym_RBRACK,
    ACTIONS(20121), 1,
      anon_sym_GT,
    STATE(15272), 1,
      sym_attribute,
    STATE(15296), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692611] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20119), 1,
      anon_sym_RBRACK,
    ACTIONS(20121), 1,
      anon_sym_GT,
    STATE(15273), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692634] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20123), 1,
      sym__lowercase_identifier,
    ACTIONS(20125), 1,
      anon_sym_LPAREN,
    STATE(5708), 1,
      sym_parenthesized_operator,
    STATE(5739), 1,
      sym__value_name,
    STATE(15274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692657] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20127), 1,
      anon_sym_COLON_GT,
    ACTIONS(20129), 1,
      anon_sym_RPAREN,
    STATE(15275), 1,
      sym_attribute,
    STATE(17208), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692680] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19579), 1,
      sym__lowercase_identifier,
    STATE(4553), 1,
      sym_class_path,
    STATE(15276), 1,
      sym_attribute,
    STATE(19245), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692703] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20131), 1,
      anon_sym_GT_RBRACE,
    STATE(15277), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692726] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20133), 1,
      anon_sym_GT_RBRACE,
    STATE(15278), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692749] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20135), 1,
      anon_sym_COLON_GT,
    ACTIONS(20137), 1,
      anon_sym_RPAREN,
    STATE(15279), 1,
      sym_attribute,
    STATE(17312), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692772] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20139), 1,
      anon_sym_GT_RBRACE,
    STATE(15280), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692795] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20141), 1,
      sym__lowercase_identifier,
    ACTIONS(20143), 1,
      anon_sym_LPAREN,
    STATE(15281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(14647), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [692816] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20145), 1,
      sym__lowercase_identifier,
    STATE(10794), 1,
      sym_class_type_path,
    STATE(15282), 1,
      sym_attribute,
    STATE(17671), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692839] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19211), 1,
      sym__lowercase_identifier,
    STATE(3325), 1,
      sym_class_path,
    STATE(15283), 1,
      sym_attribute,
    STATE(19724), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692862] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20147), 1,
      anon_sym_COLON_GT,
    ACTIONS(20149), 1,
      anon_sym_RPAREN,
    STATE(15284), 1,
      sym_attribute,
    STATE(17306), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692885] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20151), 1,
      anon_sym_GT_RBRACE,
    STATE(15285), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692908] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20153), 1,
      anon_sym_RPAREN,
    STATE(15286), 1,
      sym_attribute,
    STATE(16265), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692931] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10003), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20155), 1,
      anon_sym_GT,
    STATE(15287), 1,
      sym_attribute,
    STATE(15300), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692954] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20157), 1,
      anon_sym_GT_RBRACE,
    STATE(15288), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [692977] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20159), 1,
      anon_sym_RPAREN,
    STATE(15289), 1,
      sym_attribute,
    STATE(16722), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693000] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19491), 1,
      sym__lowercase_identifier,
    STATE(5802), 1,
      sym_class_path,
    STATE(15290), 1,
      sym_attribute,
    STATE(19761), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693023] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20161), 1,
      sym__lowercase_identifier,
    STATE(9723), 1,
      sym_class_type_path,
    STATE(15291), 1,
      sym_attribute,
    STATE(17405), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693046] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20163), 1,
      anon_sym_RBRACK,
    STATE(15292), 1,
      sym_attribute,
    STATE(16808), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693069] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20165), 1,
      anon_sym_COLON_GT,
    ACTIONS(20167), 1,
      anon_sym_RPAREN,
    STATE(15293), 1,
      sym_attribute,
    STATE(17386), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693092] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9976), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20169), 1,
      anon_sym_GT,
    STATE(15294), 1,
      sym_attribute,
    STATE(15432), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693115] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20171), 1,
      anon_sym_GT_RBRACE,
    STATE(15295), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693138] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20173), 1,
      anon_sym_RBRACK,
    ACTIONS(20175), 1,
      anon_sym_GT,
    STATE(15296), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693161] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20173), 1,
      anon_sym_RBRACK,
    STATE(15297), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693184] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20177), 1,
      anon_sym_GT_RBRACE,
    STATE(15298), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693207] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20179), 1,
      anon_sym_RBRACK,
    ACTIONS(20181), 1,
      anon_sym_GT,
    STATE(15299), 1,
      sym_attribute,
    STATE(15307), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693230] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20179), 1,
      anon_sym_RBRACK,
    ACTIONS(20181), 1,
      anon_sym_GT,
    STATE(15300), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693253] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20183), 1,
      anon_sym_GT_RBRACE,
    STATE(15301), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693276] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10051), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20185), 1,
      anon_sym_GT,
    STATE(15302), 1,
      sym_attribute,
    STATE(15589), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693299] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20187), 1,
      anon_sym_GT_RBRACE,
    STATE(15303), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693322] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19233), 1,
      sym__lowercase_identifier,
    STATE(5379), 1,
      sym_class_path,
    STATE(15304), 1,
      sym_attribute,
    STATE(19797), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693345] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(13898), 1,
      sym_type_constructor_path,
    STATE(15305), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693368] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20189), 1,
      anon_sym_COLON_GT,
    ACTIONS(20191), 1,
      anon_sym_RPAREN,
    STATE(15306), 1,
      sym_attribute,
    STATE(17468), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693391] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20193), 1,
      anon_sym_RBRACK,
    ACTIONS(20195), 1,
      anon_sym_GT,
    STATE(15307), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693414] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20193), 1,
      anon_sym_RBRACK,
    STATE(15308), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693437] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20197), 1,
      anon_sym_COLON_GT,
    ACTIONS(20199), 1,
      anon_sym_RPAREN,
    STATE(15309), 1,
      sym_attribute,
    STATE(18293), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693460] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20201), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19985), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    STATE(15310), 2,
      sym_attribute,
      aux_sym_instantiated_class_type_repeat1,
  [693479] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20204), 1,
      anon_sym_EQ,
    ACTIONS(20206), 1,
      anon_sym_RPAREN,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(15311), 1,
      sym_attribute,
    STATE(18236), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693502] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20210), 1,
      anon_sym_GT_RBRACE,
    STATE(15312), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693525] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20212), 1,
      anon_sym_DOT,
    STATE(15313), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693548] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20214), 1,
      anon_sym_COLON_GT,
    ACTIONS(20216), 1,
      anon_sym_RPAREN,
    STATE(15314), 1,
      sym_attribute,
    STATE(17852), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693571] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20218), 1,
      anon_sym_GT_RBRACE,
    STATE(15315), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693594] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20220), 1,
      anon_sym_RBRACK,
    STATE(15316), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693617] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19215), 1,
      sym__lowercase_identifier,
    STATE(3710), 1,
      sym_class_path,
    STATE(15317), 1,
      sym_attribute,
    STATE(19832), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693640] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20117), 1,
      sym__lowercase_identifier,
    STATE(11254), 1,
      sym_class_type_path,
    STATE(15318), 1,
      sym_attribute,
    STATE(17281), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693663] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20222), 1,
      anon_sym_RBRACK,
    STATE(15319), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693686] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20224), 1,
      anon_sym_RBRACK,
    STATE(15320), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693709] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20226), 1,
      anon_sym_COLON_GT,
    ACTIONS(20228), 1,
      anon_sym_RPAREN,
    STATE(15321), 1,
      sym_attribute,
    STATE(17567), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693732] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19149), 1,
      sym__lowercase_identifier,
    STATE(4344), 1,
      sym_class_path,
    STATE(15322), 1,
      sym_attribute,
    STATE(19006), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693755] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20230), 1,
      sym__lowercase_identifier,
    STATE(13430), 1,
      sym_class_type_path,
    STATE(15323), 1,
      sym_attribute,
    STATE(17725), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693778] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20232), 1,
      anon_sym_GT_RBRACE,
    STATE(15324), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693801] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20230), 1,
      sym__lowercase_identifier,
    STATE(13479), 1,
      sym_class_type_path,
    STATE(15325), 1,
      sym_attribute,
    STATE(17725), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693824] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20230), 1,
      sym__lowercase_identifier,
    STATE(13532), 1,
      sym_class_type_path,
    STATE(15326), 1,
      sym_attribute,
    STATE(17725), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693847] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20234), 1,
      sym__lowercase_identifier,
    STATE(10509), 1,
      sym_class_type_path,
    STATE(15327), 1,
      sym_attribute,
    STATE(17551), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693870] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20236), 1,
      anon_sym_GT_RBRACE,
    STATE(15328), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693893] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(20238), 1,
      aux_sym_attribute_id_token1,
    STATE(15329), 1,
      sym_attribute,
    STATE(15370), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8774), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
  [693914] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20240), 1,
      anon_sym_GT_RBRACE,
    STATE(15330), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693937] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20242), 1,
      anon_sym_RBRACK,
    STATE(15331), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693960] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19461), 1,
      sym__lowercase_identifier,
    STATE(3537), 1,
      sym_class_path,
    STATE(15332), 1,
      sym_attribute,
    STATE(19855), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [693983] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20244), 1,
      anon_sym_DOT,
    STATE(15333), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694006] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20246), 1,
      anon_sym_COLON_GT,
    ACTIONS(20248), 1,
      anon_sym_RPAREN,
    STATE(15334), 1,
      sym_attribute,
    STATE(17662), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694029] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20250), 1,
      anon_sym_COLON_GT,
    ACTIONS(20252), 1,
      anon_sym_RPAREN,
    STATE(15335), 1,
      sym_attribute,
    STATE(17737), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694052] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20015), 1,
      sym__lowercase_identifier,
    STATE(13929), 1,
      sym_class_type_path,
    STATE(15336), 1,
      sym_attribute,
    STATE(17687), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694075] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13710), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15337), 1,
      sym_attribute,
    STATE(15403), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694098] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20254), 1,
      anon_sym_DOT,
    STATE(15338), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694121] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20256), 1,
      anon_sym_GT_RBRACE,
    STATE(15339), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694144] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20258), 1,
      anon_sym_DOT,
    STATE(15340), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694167] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20260), 1,
      anon_sym_GT_RBRACE,
    STATE(15341), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694190] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20262), 1,
      anon_sym_GT_RBRACE,
    STATE(15342), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694213] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20264), 1,
      anon_sym_COLON_GT,
    ACTIONS(20266), 1,
      anon_sym_RPAREN,
    STATE(15343), 1,
      sym_attribute,
    STATE(17754), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694236] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20268), 1,
      anon_sym_RPAREN,
    STATE(15344), 1,
      sym_attribute,
    STATE(16283), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694259] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10049), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20270), 1,
      anon_sym_GT,
    STATE(15345), 1,
      sym_attribute,
    STATE(15356), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694282] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19615), 1,
      sym__lowercase_identifier,
    STATE(8332), 1,
      sym_class_path,
    STATE(15346), 1,
      sym_attribute,
    STATE(19557), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694305] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20272), 1,
      anon_sym_GT_RBRACE,
    STATE(15347), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694328] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19736), 1,
      sym__lowercase_identifier,
    STATE(10894), 1,
      sym_parenthesized_operator,
    STATE(14030), 1,
      sym__value_name,
    STATE(15348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694351] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20274), 1,
      anon_sym_GT_RBRACE,
    STATE(15349), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694374] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20276), 1,
      anon_sym_GT_RBRACE,
    STATE(15350), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694397] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20278), 1,
      sym__lowercase_identifier,
    STATE(9897), 1,
      sym_class_type_path,
    STATE(15351), 1,
      sym_attribute,
    STATE(17643), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694420] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20280), 1,
      anon_sym_DOT,
    STATE(15352), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694443] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20282), 1,
      anon_sym_rec,
    STATE(15353), 1,
      sym_attribute,
    STATE(16674), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19205), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [694464] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20284), 1,
      anon_sym_RBRACK,
    ACTIONS(20286), 1,
      anon_sym_GT,
    STATE(15354), 1,
      sym_attribute,
    STATE(15365), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694487] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20161), 1,
      sym__lowercase_identifier,
    STATE(9837), 1,
      sym_class_type_path,
    STATE(15355), 1,
      sym_attribute,
    STATE(17405), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694510] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20284), 1,
      anon_sym_RBRACK,
    ACTIONS(20286), 1,
      anon_sym_GT,
    STATE(15356), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694533] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20288), 1,
      anon_sym_COLON_GT,
    ACTIONS(20290), 1,
      anon_sym_RPAREN,
    STATE(15357), 1,
      sym_attribute,
    STATE(17883), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694556] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20292), 1,
      anon_sym_RPAREN,
    STATE(15358), 1,
      sym_attribute,
    STATE(16797), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694579] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20278), 1,
      sym__lowercase_identifier,
    STATE(9729), 1,
      sym_class_type_path,
    STATE(15359), 1,
      sym_attribute,
    STATE(17643), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694602] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10053), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20294), 1,
      anon_sym_GT,
    STATE(15360), 1,
      sym_attribute,
    STATE(15391), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694625] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20296), 1,
      anon_sym_GT_RBRACE,
    STATE(15361), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694648] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20298), 1,
      anon_sym_GT_RBRACE,
    STATE(15362), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694671] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20300), 1,
      anon_sym_GT_RBRACE,
    STATE(15363), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694694] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20278), 1,
      sym__lowercase_identifier,
    STATE(9753), 1,
      sym_class_type_path,
    STATE(15364), 1,
      sym_attribute,
    STATE(17643), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694717] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20302), 1,
      anon_sym_RBRACK,
    ACTIONS(20304), 1,
      anon_sym_GT,
    STATE(15365), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694740] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20302), 1,
      anon_sym_RBRACK,
    STATE(15366), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694763] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(18251), 1,
      anon_sym_STAR,
    STATE(15367), 1,
      sym_attribute,
    STATE(15617), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13672), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [694784] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20306), 1,
      sym__lowercase_identifier,
    STATE(15368), 1,
      sym_attribute,
    STATE(15607), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19732), 2,
      anon_sym_private,
      anon_sym_virtual,
  [694805] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18989), 1,
      sym__lowercase_identifier,
    ACTIONS(18993), 1,
      anon_sym_LBRACK,
    ACTIONS(18995), 1,
      anon_sym_virtual,
    STATE(12653), 1,
      sym_class_binding,
    STATE(15369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694828] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(20238), 1,
      aux_sym_attribute_id_token1,
    STATE(15370), 1,
      sym_attribute,
    STATE(15439), 1,
      aux_sym_attribute_id_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8768), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
  [694849] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20308), 1,
      anon_sym_GT_RBRACE,
    STATE(15371), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694872] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20310), 1,
      anon_sym_RBRACK,
    STATE(15372), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694895] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20306), 1,
      sym__lowercase_identifier,
    STATE(15373), 1,
      sym_attribute,
    STATE(15610), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19732), 2,
      anon_sym_private,
      anon_sym_virtual,
  [694916] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20312), 1,
      anon_sym_RBRACK,
    STATE(15374), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694939] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20314), 1,
      anon_sym_DOT,
    STATE(15375), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694962] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19463), 1,
      sym__lowercase_identifier,
    STATE(9664), 1,
      sym_class_path,
    STATE(15376), 1,
      sym_attribute,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [694985] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20316), 1,
      sym__lowercase_identifier,
    STATE(10176), 1,
      sym_class_type_path,
    STATE(15377), 1,
      sym_attribute,
    STATE(17740), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695008] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20316), 1,
      sym__lowercase_identifier,
    STATE(9972), 1,
      sym_class_type_path,
    STATE(15378), 1,
      sym_attribute,
    STATE(17740), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695031] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20316), 1,
      sym__lowercase_identifier,
    STATE(9999), 1,
      sym_class_type_path,
    STATE(15379), 1,
      sym_attribute,
    STATE(17740), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695054] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    ACTIONS(20318), 1,
      anon_sym_EQ,
    ACTIONS(20320), 1,
      anon_sym_RPAREN,
    STATE(15380), 1,
      sym_attribute,
    STATE(17303), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695077] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20322), 1,
      anon_sym_with,
    ACTIONS(20324), 1,
      sym_hash_operator,
    STATE(15381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695100] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    ACTIONS(20326), 1,
      anon_sym_EQ,
    ACTIONS(20328), 1,
      anon_sym_RPAREN,
    STATE(15382), 1,
      sym_attribute,
    STATE(18325), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695123] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20330), 1,
      sym__lowercase_identifier,
    STATE(15383), 1,
      sym_attribute,
    STATE(15810), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19732), 2,
      anon_sym_private,
      anon_sym_virtual,
  [695144] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20332), 1,
      anon_sym_DOT,
    STATE(15384), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695167] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20334), 1,
      anon_sym_COLON_GT,
    ACTIONS(20336), 1,
      anon_sym_RPAREN,
    STATE(15385), 1,
      sym_attribute,
    STATE(18296), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695190] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20338), 1,
      anon_sym_DOT,
    STATE(15386), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695213] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20115), 1,
      sym__lowercase_identifier,
    STATE(11351), 1,
      sym_class_type_path,
    STATE(15387), 1,
      sym_attribute,
    STATE(17706), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695236] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20340), 1,
      sym__lowercase_identifier,
    STATE(15388), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20094), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695259] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20342), 1,
      anon_sym_RPAREN,
    STATE(15389), 1,
      sym_attribute,
    STATE(16101), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695282] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20344), 1,
      anon_sym_RBRACK,
    ACTIONS(20346), 1,
      anon_sym_GT,
    STATE(15390), 1,
      sym_attribute,
    STATE(15407), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695305] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20344), 1,
      anon_sym_RBRACK,
    ACTIONS(20346), 1,
      anon_sym_GT,
    STATE(15391), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695328] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20348), 1,
      anon_sym_RPAREN,
    STATE(15392), 1,
      sym_attribute,
    STATE(16301), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695351] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9882), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20350), 1,
      anon_sym_GT,
    STATE(15393), 1,
      sym_attribute,
    STATE(15406), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695374] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20352), 1,
      anon_sym_GT_RBRACE,
    STATE(15394), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695397] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20354), 1,
      anon_sym_DOT,
    STATE(15395), 1,
      sym_attribute,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695420] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20356), 1,
      anon_sym_RPAREN,
    STATE(15396), 1,
      sym_attribute,
    STATE(16127), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695443] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20358), 1,
      sym__lowercase_identifier,
    STATE(15397), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(19391), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695466] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19019), 1,
      sym__lowercase_identifier,
    ACTIONS(19023), 1,
      anon_sym_LBRACK,
    ACTIONS(19025), 1,
      anon_sym_virtual,
    STATE(13460), 1,
      sym_class_binding,
    STATE(15398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695489] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19463), 1,
      sym__lowercase_identifier,
    STATE(10557), 1,
      sym_class_path,
    STATE(15399), 1,
      sym_attribute,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695512] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20360), 1,
      anon_sym_GT_RBRACE,
    STATE(15400), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695535] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15401), 1,
      sym_attribute,
    STATE(18362), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20362), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [695556] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9896), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20364), 1,
      anon_sym_GT,
    STATE(15402), 1,
      sym_attribute,
    STATE(15558), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695579] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13683), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15403), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695602] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13683), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15404), 1,
      sym_attribute,
    STATE(15532), 1,
      aux_sym_expression_item_repeat1,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695625] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20366), 1,
      anon_sym_RBRACK,
    ACTIONS(20368), 1,
      anon_sym_GT,
    STATE(15405), 1,
      sym_attribute,
    STATE(15413), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695648] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20366), 1,
      anon_sym_RBRACK,
    ACTIONS(20368), 1,
      anon_sym_GT,
    STATE(15406), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695671] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20370), 1,
      anon_sym_RBRACK,
    ACTIONS(20372), 1,
      anon_sym_GT,
    STATE(15407), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695694] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20370), 1,
      anon_sym_RBRACK,
    STATE(15408), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695717] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20374), 1,
      anon_sym_GT_RBRACE,
    STATE(15409), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695740] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(15410), 1,
      sym_attribute,
    STATE(17055), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695763] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(20053), 1,
      sym__lowercase_identifier,
    STATE(15411), 1,
      sym_attribute,
    STATE(17259), 1,
      sym_module_type_path,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695786] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20376), 1,
      anon_sym_RBRACK,
    STATE(15412), 1,
      sym_attribute,
    STATE(16740), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695809] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20378), 1,
      anon_sym_RBRACK,
    ACTIONS(20380), 1,
      anon_sym_GT,
    STATE(15413), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695832] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20378), 1,
      anon_sym_RBRACK,
    STATE(15414), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695855] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19463), 1,
      sym__lowercase_identifier,
    STATE(10525), 1,
      sym_class_path,
    STATE(15415), 1,
      sym_attribute,
    STATE(21188), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695878] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20382), 1,
      anon_sym_RBRACK,
    STATE(15416), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695901] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20384), 1,
      anon_sym_RBRACK,
    STATE(15417), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695924] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17509), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    STATE(15418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695947] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20386), 1,
      sym__lowercase_identifier,
    STATE(7788), 1,
      sym_type_constructor_path,
    STATE(15419), 1,
      sym_attribute,
    STATE(17591), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695970] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20388), 1,
      anon_sym_RBRACK,
    STATE(15420), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [695993] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20390), 1,
      anon_sym_RBRACK,
    STATE(15421), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696016] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13590), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15422), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696039] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19347), 1,
      sym__lowercase_identifier,
    STATE(6037), 1,
      sym_class_path,
    STATE(15423), 1,
      sym_attribute,
    STATE(19056), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696062] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20392), 1,
      sym__lowercase_identifier,
    STATE(9408), 1,
      sym_class_type_path,
    STATE(15424), 1,
      sym_attribute,
    STATE(17755), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696085] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20392), 1,
      sym__lowercase_identifier,
    STATE(9427), 1,
      sym_class_type_path,
    STATE(15425), 1,
      sym_attribute,
    STATE(17755), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696108] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20392), 1,
      sym__lowercase_identifier,
    STATE(9435), 1,
      sym_class_type_path,
    STATE(15426), 1,
      sym_attribute,
    STATE(17755), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696131] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17250), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    STATE(15427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696154] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20394), 1,
      anon_sym_as,
    STATE(15428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17154), 3,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [696173] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20396), 1,
      anon_sym_COLON_GT,
    ACTIONS(20398), 1,
      anon_sym_RPAREN,
    STATE(15429), 1,
      sym_attribute,
    STATE(17269), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696196] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20400), 1,
      anon_sym_COLON_GT,
    ACTIONS(20402), 1,
      anon_sym_RPAREN,
    STATE(15430), 1,
      sym_attribute,
    STATE(17212), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696219] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20404), 1,
      anon_sym_RBRACK,
    ACTIONS(20406), 1,
      anon_sym_GT,
    STATE(15431), 1,
      sym_attribute,
    STATE(15509), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696242] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20404), 1,
      anon_sym_RBRACK,
    ACTIONS(20406), 1,
      anon_sym_GT,
    STATE(15432), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696265] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20230), 1,
      sym__lowercase_identifier,
    STATE(13582), 1,
      sym_class_type_path,
    STATE(15433), 1,
      sym_attribute,
    STATE(17725), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696288] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20408), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696311] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18989), 1,
      sym__lowercase_identifier,
    ACTIONS(18993), 1,
      anon_sym_LBRACK,
    ACTIONS(18995), 1,
      anon_sym_virtual,
    STATE(12376), 1,
      sym_class_binding,
    STATE(15435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696334] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20410), 1,
      sym__lowercase_identifier,
    STATE(14620), 1,
      sym_class_type_path,
    STATE(15436), 1,
      sym_attribute,
    STATE(17599), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696357] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19243), 1,
      sym__lowercase_identifier,
    STATE(7288), 1,
      sym_class_path,
    STATE(15437), 1,
      sym_attribute,
    STATE(19926), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696380] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20412), 1,
      anon_sym_RPAREN,
    STATE(15438), 1,
      sym_attribute,
    STATE(16320), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696403] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(20414), 1,
      aux_sym_attribute_id_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8757), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
    STATE(15439), 2,
      sym_attribute,
      aux_sym_attribute_id_repeat1,
  [696422] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14161), 1,
      anon_sym_in,
    ACTIONS(20417), 1,
      anon_sym_and,
    ACTIONS(20419), 1,
      sym_let_and_operator,
    STATE(15440), 1,
      sym_attribute,
    STATE(15581), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696445] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20421), 1,
      sym__lowercase_identifier,
    STATE(11095), 1,
      sym_class_type_path,
    STATE(15441), 1,
      sym_attribute,
    STATE(17477), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696468] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20423), 1,
      anon_sym_GT,
    STATE(15442), 1,
      sym_attribute,
    STATE(15450), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696491] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20421), 1,
      sym__lowercase_identifier,
    STATE(11186), 1,
      sym_class_type_path,
    STATE(15443), 1,
      sym_attribute,
    STATE(17477), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696514] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20421), 1,
      sym__lowercase_identifier,
    STATE(11202), 1,
      sym_class_type_path,
    STATE(15444), 1,
      sym_attribute,
    STATE(17477), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696537] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20425), 1,
      anon_sym_RBRACK,
    ACTIONS(20427), 1,
      anon_sym_GT,
    STATE(15445), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696560] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20425), 1,
      anon_sym_RBRACK,
    STATE(15446), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696583] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20429), 1,
      sym__lowercase_identifier,
    STATE(15447), 1,
      sym_attribute,
    STATE(15690), 1,
      aux_sym__abstract_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20431), 2,
      anon_sym_RPAREN,
      anon_sym_DOT,
  [696604] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20433), 1,
      anon_sym_GT_RBRACE,
    STATE(15448), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696627] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20435), 1,
      anon_sym_RBRACK,
    ACTIONS(20437), 1,
      anon_sym_GT,
    STATE(15449), 1,
      sym_attribute,
    STATE(15453), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696650] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20435), 1,
      anon_sym_RBRACK,
    ACTIONS(20437), 1,
      anon_sym_GT,
    STATE(15450), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696673] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20439), 1,
      anon_sym_GT_RBRACE,
    STATE(15451), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696696] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20441), 1,
      anon_sym_GT_RBRACE,
    STATE(15452), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696719] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20443), 1,
      anon_sym_RBRACK,
    ACTIONS(20445), 1,
      anon_sym_GT,
    STATE(15453), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696742] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20443), 1,
      anon_sym_RBRACK,
    STATE(15454), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696765] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20447), 1,
      anon_sym_RBRACK,
    STATE(15455), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696788] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20449), 1,
      anon_sym_RBRACK,
    STATE(15456), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696811] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19479), 1,
      sym__lowercase_identifier,
    STATE(5265), 1,
      sym_class_path,
    STATE(15457), 1,
      sym_attribute,
    STATE(19097), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696834] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20451), 1,
      sym__lowercase_identifier,
    STATE(9451), 1,
      sym_class_type_path,
    STATE(15458), 1,
      sym_attribute,
    STATE(17771), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696857] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20451), 1,
      sym__lowercase_identifier,
    STATE(9460), 1,
      sym_class_type_path,
    STATE(15459), 1,
      sym_attribute,
    STATE(17771), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696880] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20451), 1,
      sym__lowercase_identifier,
    STATE(9467), 1,
      sym_class_type_path,
    STATE(15460), 1,
      sym_attribute,
    STATE(17771), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696903] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20453), 1,
      anon_sym_DOT,
    ACTIONS(20455), 1,
      aux_sym_type_variable_token1,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15461), 2,
      sym_attribute,
      aux_sym_constructor_declaration_repeat1,
  [696924] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20458), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15462), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696947] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    ACTIONS(20460), 1,
      anon_sym_RBRACE,
    STATE(15463), 1,
      sym_attribute,
    STATE(18307), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696970] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19521), 1,
      sym__lowercase_identifier,
    STATE(4483), 1,
      sym_class_path,
    STATE(15464), 1,
      sym_attribute,
    STATE(20914), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [696993] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19557), 1,
      sym__lowercase_identifier,
    ACTIONS(19559), 1,
      anon_sym_LBRACK,
    ACTIONS(19561), 1,
      anon_sym_virtual,
    STATE(12855), 1,
      sym_class_type_binding,
    STATE(15465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697016] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20462), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15466), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697039] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20464), 1,
      sym__lowercase_identifier,
    STATE(15467), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(20265), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697062] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(19955), 1,
      anon_sym_RBRACK,
    STATE(15468), 1,
      sym_attribute,
    STATE(17185), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697085] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20466), 1,
      anon_sym_COLON_GT,
    ACTIONS(20468), 1,
      anon_sym_RPAREN,
    STATE(15469), 1,
      sym_attribute,
    STATE(17298), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697108] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20316), 1,
      sym__lowercase_identifier,
    STATE(10229), 1,
      sym_class_type_path,
    STATE(15470), 1,
      sym_attribute,
    STATE(17740), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697131] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20470), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15471), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697154] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12464), 1,
      anon_sym_and,
    STATE(15472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12462), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [697173] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20472), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15473), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697196] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15474), 1,
      sym_attribute,
    STATE(17291), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20474), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [697217] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19615), 1,
      sym__lowercase_identifier,
    STATE(8748), 1,
      sym_class_path,
    STATE(15475), 1,
      sym_attribute,
    STATE(19557), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697240] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20476), 1,
      anon_sym_RPAREN,
    STATE(15476), 1,
      sym_attribute,
    STATE(16176), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697263] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20478), 1,
      anon_sym_RBRACK,
    STATE(15477), 1,
      sym_attribute,
    STATE(17162), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697286] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20480), 1,
      anon_sym_RPAREN,
    STATE(15478), 1,
      sym_attribute,
    STATE(15910), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697309] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(9798), 1,
      anon_sym_COMMA,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    STATE(15479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697332] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9894), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20482), 1,
      anon_sym_GT,
    STATE(15480), 1,
      sym_attribute,
    STATE(15485), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697355] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10041), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20484), 1,
      anon_sym_GT,
    STATE(15481), 1,
      sym_attribute,
    STATE(15517), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697378] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20486), 1,
      anon_sym_GT_RBRACE,
    STATE(15482), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697401] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20490), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20488), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    STATE(15483), 2,
      sym_attribute,
      aux_sym__type_params_repeat1,
  [697420] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20493), 1,
      anon_sym_RBRACK,
    ACTIONS(20495), 1,
      anon_sym_GT,
    STATE(15484), 1,
      sym_attribute,
    STATE(15491), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697443] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20493), 1,
      anon_sym_RBRACK,
    ACTIONS(20495), 1,
      anon_sym_GT,
    STATE(15485), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697466] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20497), 1,
      anon_sym_GT_RBRACE,
    STATE(15486), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697489] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20394), 1,
      anon_sym_as,
    STATE(15487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12661), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [697508] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20499), 1,
      anon_sym_GT_RBRACE,
    STATE(15488), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697531] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20501), 1,
      sym__lowercase_identifier,
    STATE(10776), 1,
      sym_type_constructor_path,
    STATE(15489), 1,
      sym_attribute,
    STATE(17330), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697554] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20503), 1,
      sym__lowercase_identifier,
    STATE(15490), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    STATE(21192), 1,
      sym_type_constructor_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697577] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20505), 1,
      anon_sym_RBRACK,
    ACTIONS(20507), 1,
      anon_sym_GT,
    STATE(15491), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697600] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20505), 1,
      anon_sym_RBRACK,
    STATE(15492), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697623] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10025), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20509), 1,
      anon_sym_GT,
    STATE(15222), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697646] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20511), 1,
      anon_sym_RBRACK,
    STATE(15494), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697669] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20513), 1,
      anon_sym_COLON_GT,
    ACTIONS(20515), 1,
      anon_sym_RPAREN,
    STATE(15495), 1,
      sym_attribute,
    STATE(17411), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697692] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20517), 1,
      anon_sym_RBRACK,
    STATE(15496), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697715] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15497), 1,
      sym_attribute,
    STATE(17359), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20519), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [697736] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20161), 1,
      sym__lowercase_identifier,
    STATE(9935), 1,
      sym_class_type_path,
    STATE(15498), 1,
      sym_attribute,
    STATE(17405), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697759] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20521), 1,
      anon_sym_GT_RBRACE,
    STATE(15499), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697782] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19237), 1,
      sym__lowercase_identifier,
    STATE(5476), 1,
      sym_class_path,
    STATE(15500), 1,
      sym_attribute,
    STATE(19137), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697805] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20523), 1,
      sym__lowercase_identifier,
    STATE(13634), 1,
      sym_class_type_path,
    STATE(15501), 1,
      sym_attribute,
    STATE(17784), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697828] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20523), 1,
      sym__lowercase_identifier,
    STATE(13669), 1,
      sym_class_type_path,
    STATE(15502), 1,
      sym_attribute,
    STATE(17784), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697851] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20523), 1,
      sym__lowercase_identifier,
    STATE(13681), 1,
      sym_class_type_path,
    STATE(15503), 1,
      sym_attribute,
    STATE(17784), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697874] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20525), 1,
      anon_sym_RBRACK,
    STATE(15504), 1,
      sym_attribute,
    STATE(15969), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697897] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19117), 1,
      sym__lowercase_identifier,
    ACTIONS(19119), 1,
      anon_sym_LBRACK,
    ACTIONS(19121), 1,
      anon_sym_virtual,
    STATE(13171), 1,
      sym_class_binding,
    STATE(15505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697920] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20527), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15506), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697943] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20529), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15507), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697966] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20531), 1,
      anon_sym_COLON_GT,
    ACTIONS(20533), 1,
      anon_sym_RPAREN,
    STATE(15508), 1,
      sym_attribute,
    STATE(17385), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [697989] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20535), 1,
      anon_sym_RBRACK,
    ACTIONS(20537), 1,
      anon_sym_GT,
    STATE(15509), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698012] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20392), 1,
      sym__lowercase_identifier,
    STATE(9404), 1,
      sym_class_type_path,
    STATE(15510), 1,
      sym_attribute,
    STATE(17755), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698035] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20539), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15511), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698058] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20535), 1,
      anon_sym_RBRACK,
    STATE(15512), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698081] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20541), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15513), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698104] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20543), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15514), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698127] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19019), 1,
      sym__lowercase_identifier,
    ACTIONS(19023), 1,
      anon_sym_LBRACK,
    ACTIONS(19025), 1,
      anon_sym_virtual,
    STATE(12376), 1,
      sym_class_binding,
    STATE(15515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698150] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20545), 1,
      anon_sym_RBRACK,
    ACTIONS(20547), 1,
      anon_sym_GT,
    STATE(15516), 1,
      sym_attribute,
    STATE(15552), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698173] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20545), 1,
      anon_sym_RBRACK,
    ACTIONS(20547), 1,
      anon_sym_GT,
    STATE(15517), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698196] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20549), 1,
      anon_sym_RPAREN,
    STATE(15518), 1,
      sym_attribute,
    STATE(16353), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698219] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9908), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20551), 1,
      anon_sym_GT,
    STATE(15519), 1,
      sym_attribute,
    STATE(15528), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698242] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20553), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15520), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698265] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15521), 1,
      sym_attribute,
    STATE(17412), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20555), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [698286] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20557), 1,
      anon_sym_GT_RBRACE,
    STATE(15522), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698309] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(20559), 1,
      sym__lowercase_identifier,
    STATE(14030), 1,
      sym__value_name,
    STATE(14597), 1,
      sym_parenthesized_operator,
    STATE(15523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698332] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20561), 1,
      anon_sym_RBRACK,
    STATE(15524), 1,
      sym_attribute,
    STATE(16023), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698355] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20563), 1,
      anon_sym_RPAREN,
    STATE(15525), 1,
      sym_attribute,
    STATE(17155), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698378] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9892), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20565), 1,
      anon_sym_GT,
    STATE(15526), 1,
      sym_attribute,
    STATE(15546), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698401] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20567), 1,
      anon_sym_RBRACK,
    ACTIONS(20569), 1,
      anon_sym_GT,
    STATE(15527), 1,
      sym_attribute,
    STATE(15534), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698424] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20567), 1,
      anon_sym_RBRACK,
    ACTIONS(20569), 1,
      anon_sym_GT,
    STATE(15528), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698447] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17567), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    STATE(15529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698470] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    ACTIONS(20571), 1,
      anon_sym_RBRACE,
    STATE(15530), 1,
      sym_attribute,
    STATE(18307), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698493] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20573), 1,
      anon_sym_GT_RBRACE,
    STATE(15531), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698516] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13687), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15532), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698539] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20575), 1,
      anon_sym_GT_RBRACE,
    STATE(15533), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698562] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20577), 1,
      anon_sym_RBRACK,
    ACTIONS(20579), 1,
      anon_sym_GT,
    STATE(15534), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698585] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20577), 1,
      anon_sym_RBRACK,
    STATE(15535), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698608] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20581), 1,
      anon_sym_GT_RBRACE,
    STATE(15536), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698631] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20583), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15537), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698654] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    ACTIONS(20585), 1,
      anon_sym_EQ,
    ACTIONS(20587), 1,
      anon_sym_RPAREN,
    STATE(15538), 1,
      sym_attribute,
    STATE(17484), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698677] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15539), 1,
      sym_attribute,
    STATE(17447), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20589), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [698698] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20591), 1,
      anon_sym_RBRACK,
    STATE(15540), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698721] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20593), 1,
      anon_sym_RBRACK,
    STATE(15541), 1,
      sym_attribute,
    STATE(16072), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698744] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20595), 1,
      anon_sym_RBRACK,
    STATE(15542), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698767] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13656), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15543), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698790] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19165), 1,
      sym__lowercase_identifier,
    STATE(6186), 1,
      sym_class_path,
    STATE(15544), 1,
      sym_attribute,
    STATE(19177), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698813] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20597), 1,
      anon_sym_RBRACK,
    ACTIONS(20599), 1,
      anon_sym_GT,
    STATE(15545), 1,
      sym_attribute,
    STATE(15559), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698836] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20597), 1,
      anon_sym_RBRACK,
    ACTIONS(20599), 1,
      anon_sym_GT,
    STATE(15546), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698859] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19615), 1,
      sym__lowercase_identifier,
    STATE(8792), 1,
      sym_class_path,
    STATE(15547), 1,
      sym_attribute,
    STATE(19557), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698882] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20601), 1,
      anon_sym_GT_RBRACE,
    STATE(15548), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698905] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15549), 1,
      sym_attribute,
    STATE(17481), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20603), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [698926] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(15550), 1,
      sym_attribute,
    STATE(17673), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698949] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(20605), 1,
      sym__lowercase_identifier,
    STATE(7685), 1,
      sym_class_path,
    STATE(15551), 1,
      sym_attribute,
    STATE(18515), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698972] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20607), 1,
      anon_sym_RBRACK,
    ACTIONS(20609), 1,
      anon_sym_GT,
    STATE(15552), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [698995] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20611), 1,
      anon_sym_COLON_GT,
    ACTIONS(20613), 1,
      anon_sym_RPAREN,
    STATE(15553), 1,
      sym_attribute,
    STATE(17515), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699018] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20607), 1,
      anon_sym_RBRACK,
    STATE(15554), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699041] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20451), 1,
      sym__lowercase_identifier,
    STATE(9446), 1,
      sym_class_type_path,
    STATE(15555), 1,
      sym_attribute,
    STATE(17771), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699064] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20615), 1,
      anon_sym_RBRACK,
    ACTIONS(20617), 1,
      anon_sym_GT,
    STATE(15556), 1,
      sym_attribute,
    STATE(15612), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699087] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20619), 1,
      anon_sym_RBRACK,
    STATE(15557), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699110] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20615), 1,
      anon_sym_RBRACK,
    ACTIONS(20617), 1,
      anon_sym_GT,
    STATE(15558), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699133] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20621), 1,
      anon_sym_RBRACK,
    ACTIONS(20623), 1,
      anon_sym_GT,
    STATE(15559), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699156] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20621), 1,
      anon_sym_RBRACK,
    STATE(15560), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699179] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17587), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    STATE(15561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15562), 1,
      sym_attribute,
    STATE(17511), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20625), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699223] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(20605), 1,
      sym__lowercase_identifier,
    STATE(7702), 1,
      sym_class_path,
    STATE(15563), 1,
      sym_attribute,
    STATE(18515), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699246] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17593), 1,
      anon_sym_COMMA,
    ACTIONS(17702), 1,
      anon_sym_COLON_COLON,
    ACTIONS(17707), 1,
      anon_sym_PIPE,
    ACTIONS(17747), 1,
      anon_sym_as,
    STATE(15564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699269] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20627), 1,
      anon_sym_RBRACK,
    STATE(15565), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699292] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20629), 1,
      anon_sym_RPAREN,
    STATE(15566), 1,
      sym_attribute,
    STATE(16369), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699315] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9922), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20631), 1,
      anon_sym_GT,
    STATE(15567), 1,
      sym_attribute,
    STATE(15575), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(15568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(17154), 3,
      anon_sym_COLON_GT,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [699357] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20633), 1,
      sym__lowercase_identifier,
    STATE(8079), 1,
      sym_type_constructor_path,
    STATE(15569), 1,
      sym_attribute,
    STATE(18269), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15570), 1,
      sym_attribute,
    STATE(17533), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20635), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699401] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20637), 1,
      anon_sym_RBRACK,
    STATE(15571), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699424] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20639), 1,
      anon_sym_GT_RBRACE,
    STATE(15572), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699447] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20641), 1,
      anon_sym_RBRACK,
    STATE(15573), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699470] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20643), 1,
      anon_sym_RBRACK,
    ACTIONS(20645), 1,
      anon_sym_GT,
    STATE(15574), 1,
      sym_attribute,
    STATE(15585), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699493] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20643), 1,
      anon_sym_RBRACK,
    ACTIONS(20645), 1,
      anon_sym_GT,
    STATE(15575), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699516] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14393), 1,
      anon_sym_in,
    ACTIONS(20417), 1,
      anon_sym_and,
    ACTIONS(20419), 1,
      sym_let_and_operator,
    STATE(15576), 1,
      sym_attribute,
    STATE(15668), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699539] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15577), 1,
      sym_attribute,
    STATE(17556), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20647), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699560] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20649), 1,
      anon_sym_RBRACK,
    STATE(15578), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699583] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19169), 1,
      sym__lowercase_identifier,
    STATE(7444), 1,
      sym_class_path,
    STATE(15579), 1,
      sym_attribute,
    STATE(20122), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699606] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20651), 1,
      anon_sym_GT_RBRACE,
    STATE(15580), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699629] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14393), 1,
      anon_sym_in,
    ACTIONS(20417), 1,
      anon_sym_and,
    ACTIONS(20419), 1,
      sym_let_and_operator,
    STATE(15581), 1,
      sym_attribute,
    STATE(15675), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699652] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20653), 1,
      sym__lowercase_identifier,
    STATE(9763), 1,
      sym_class_type_path,
    STATE(15582), 1,
      sym_attribute,
    STATE(17506), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699675] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20653), 1,
      sym__lowercase_identifier,
    STATE(9874), 1,
      sym_class_type_path,
    STATE(15583), 1,
      sym_attribute,
    STATE(17506), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699698] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20653), 1,
      sym__lowercase_identifier,
    STATE(9789), 1,
      sym_class_type_path,
    STATE(15584), 1,
      sym_attribute,
    STATE(17506), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699721] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20655), 1,
      anon_sym_RBRACK,
    ACTIONS(20657), 1,
      anon_sym_GT,
    STATE(15585), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699744] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20655), 1,
      anon_sym_RBRACK,
    STATE(15586), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699767] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20659), 1,
      anon_sym_RBRACK,
    STATE(15587), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699790] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20661), 1,
      anon_sym_RBRACK,
    ACTIONS(20663), 1,
      anon_sym_GT,
    STATE(15588), 1,
      sym_attribute,
    STATE(15748), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699813] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20661), 1,
      anon_sym_RBRACK,
    ACTIONS(20663), 1,
      anon_sym_GT,
    STATE(15589), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699836] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15590), 1,
      sym_attribute,
    STATE(17582), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20665), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699857] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20667), 1,
      anon_sym_RBRACK,
    STATE(15591), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699880] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20013), 1,
      sym__lowercase_identifier,
    STATE(9982), 1,
      sym_class_type_path,
    STATE(15592), 1,
      sym_attribute,
    STATE(18345), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699903] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20669), 1,
      anon_sym_GT_RBRACE,
    STATE(15593), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699926] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20671), 1,
      anon_sym_RBRACK,
    STATE(15594), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699949] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19318), 1,
      sym__lowercase_identifier,
    STATE(6652), 1,
      sym_class_path,
    STATE(15595), 1,
      sym_attribute,
    STATE(19217), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [699972] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15596), 1,
      sym_attribute,
    STATE(17606), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20673), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [699993] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20675), 1,
      anon_sym_COLON_GT,
    ACTIONS(20677), 1,
      anon_sym_RPAREN,
    STATE(15597), 1,
      sym_attribute,
    STATE(17624), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700016] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19185), 1,
      sym__lowercase_identifier,
    STATE(4196), 1,
      sym_class_path,
    STATE(15598), 1,
      sym_attribute,
    STATE(18790), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700039] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20523), 1,
      sym__lowercase_identifier,
    STATE(13647), 1,
      sym_class_type_path,
    STATE(15599), 1,
      sym_attribute,
    STATE(17784), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700062] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(20053), 1,
      sym__lowercase_identifier,
    STATE(15600), 1,
      sym_attribute,
    STATE(18173), 1,
      sym_extended_module_path,
    STATE(18421), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700085] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20041), 1,
      sym__lowercase_identifier,
    STATE(10687), 1,
      sym_class_type_path,
    STATE(15601), 1,
      sym_attribute,
    STATE(17653), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700108] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19539), 1,
      sym__lowercase_identifier,
    STATE(7878), 1,
      sym_class_path,
    STATE(15602), 1,
      sym_attribute,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700131] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20041), 1,
      sym__lowercase_identifier,
    STATE(10738), 1,
      sym_class_type_path,
    STATE(15603), 1,
      sym_attribute,
    STATE(17653), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700154] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20679), 1,
      sym__lowercase_identifier,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20681), 2,
      anon_sym_mutable,
      anon_sym_virtual,
    STATE(15604), 2,
      sym_attribute,
      aux_sym_instance_variable_specification_repeat1,
  [700173] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20041), 1,
      sym__lowercase_identifier,
    STATE(10749), 1,
      sym_class_type_path,
    STATE(15605), 1,
      sym_attribute,
    STATE(17653), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700196] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13726), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [700217] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20684), 1,
      sym__lowercase_identifier,
    STATE(15607), 1,
      sym_attribute,
    STATE(15610), 1,
      aux_sym_method_specification_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19732), 2,
      anon_sym_private,
      anon_sym_virtual,
  [700238] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15608), 1,
      sym_attribute,
    STATE(17629), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20686), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [700259] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20688), 1,
      anon_sym_RPAREN,
    STATE(15609), 1,
      sym_attribute,
    STATE(16389), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700282] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20690), 1,
      sym__lowercase_identifier,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20692), 2,
      anon_sym_private,
      anon_sym_virtual,
    STATE(15610), 2,
      sym_attribute,
      aux_sym_method_specification_repeat1,
  [700301] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9952), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20695), 1,
      anon_sym_GT,
    STATE(15611), 1,
      sym_attribute,
    STATE(15623), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700324] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20697), 1,
      anon_sym_RBRACK,
    ACTIONS(20699), 1,
      anon_sym_GT,
    STATE(15612), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700347] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20697), 1,
      anon_sym_RBRACK,
    STATE(15613), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700370] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20701), 1,
      anon_sym_GT_RBRACE,
    STATE(15614), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700393] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20703), 1,
      sym__lowercase_identifier,
    STATE(5583), 1,
      sym_type_constructor_path,
    STATE(15615), 1,
      sym_attribute,
    STATE(17465), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700416] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19117), 1,
      sym__lowercase_identifier,
    ACTIONS(19119), 1,
      anon_sym_LBRACK,
    ACTIONS(19121), 1,
      anon_sym_virtual,
    STATE(12376), 1,
      sym_class_binding,
    STATE(15616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700439] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(20705), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12211), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
    STATE(15617), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
  [700458] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20708), 1,
      anon_sym_GT_RBRACE,
    STATE(15618), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700481] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20710), 1,
      anon_sym_COLON_GT,
    ACTIONS(20712), 1,
      anon_sym_RPAREN,
    STATE(15619), 1,
      sym_attribute,
    STATE(17697), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700504] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20714), 1,
      sym__lowercase_identifier,
    STATE(11385), 1,
      sym_class_type_path,
    STATE(15620), 1,
      sym_attribute,
    STATE(17443), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700527] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19539), 1,
      sym__lowercase_identifier,
    STATE(6489), 1,
      sym_class_path,
    STATE(15621), 1,
      sym_attribute,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700550] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20716), 1,
      anon_sym_RBRACK,
    ACTIONS(20718), 1,
      anon_sym_GT,
    STATE(15622), 1,
      sym_attribute,
    STATE(15628), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700573] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20716), 1,
      anon_sym_RBRACK,
    ACTIONS(20718), 1,
      anon_sym_GT,
    STATE(15623), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700596] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20720), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15624), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700619] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20722), 1,
      anon_sym_GT_RBRACE,
    STATE(15625), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700642] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20724), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15626), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700665] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20726), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15627), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700688] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20728), 1,
      anon_sym_RBRACK,
    ACTIONS(20730), 1,
      anon_sym_GT,
    STATE(15628), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700711] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20728), 1,
      anon_sym_RBRACK,
    STATE(15629), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700734] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20143), 1,
      anon_sym_LPAREN,
    ACTIONS(20732), 1,
      sym__lowercase_identifier,
    STATE(14861), 1,
      sym__value_name,
    STATE(14939), 1,
      sym_parenthesized_operator,
    STATE(15630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700757] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20734), 1,
      sym__lowercase_identifier,
    STATE(10164), 1,
      sym_class_type_path,
    STATE(15631), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700780] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20736), 1,
      anon_sym_RBRACK,
    STATE(15632), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700803] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20738), 1,
      anon_sym_RPAREN,
    STATE(15633), 1,
      sym_attribute,
    STATE(15964), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700826] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20740), 1,
      anon_sym_RBRACK,
    STATE(15634), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700849] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9920), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20742), 1,
      anon_sym_GT,
    STATE(15635), 1,
      sym_attribute,
    STATE(15646), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700872] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20744), 1,
      anon_sym_RBRACK,
    STATE(15636), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700895] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19403), 1,
      sym__lowercase_identifier,
    STATE(6701), 1,
      sym_class_path,
    STATE(15637), 1,
      sym_attribute,
    STATE(19257), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700918] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20746), 1,
      anon_sym_GT_RBRACE,
    STATE(15638), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700941] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19483), 1,
      sym__lowercase_identifier,
    STATE(7626), 1,
      sym_class_path,
    STATE(15639), 1,
      sym_attribute,
    STATE(19181), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700964] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20748), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15640), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [700987] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    ACTIONS(20750), 1,
      anon_sym_EQ,
    ACTIONS(20752), 1,
      anon_sym_RPAREN,
    STATE(15641), 1,
      sym_attribute,
    STATE(17764), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701010] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20754), 1,
      anon_sym_COLON_GT,
    ACTIONS(20756), 1,
      anon_sym_RPAREN,
    STATE(15642), 1,
      sym_attribute,
    STATE(17765), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701033] = 7,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(13636), 1,
      anon_sym_in,
    ACTIONS(17104), 1,
      anon_sym_LBRACK_AT_AT,
    STATE(15047), 1,
      aux_sym_expression_item_repeat1,
    STATE(15643), 1,
      sym_attribute,
    STATE(17128), 1,
      sym_item_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701056] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20758), 1,
      anon_sym_RBRACK,
    STATE(15644), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701079] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20760), 1,
      anon_sym_RBRACK,
    ACTIONS(20762), 1,
      anon_sym_GT,
    STATE(15645), 1,
      sym_attribute,
    STATE(15651), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701102] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20760), 1,
      anon_sym_RBRACK,
    ACTIONS(20762), 1,
      anon_sym_GT,
    STATE(15646), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701125] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20764), 1,
      sym__lowercase_identifier,
    STATE(5936), 1,
      sym_type_constructor_path,
    STATE(15647), 1,
      sym_attribute,
    STATE(17614), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701148] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20766), 1,
      anon_sym_GT_RBRACE,
    STATE(15648), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701171] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(20768), 1,
      sym__lowercase_identifier,
    STATE(7608), 1,
      sym_class_path,
    STATE(15649), 1,
      sym_attribute,
    STATE(18627), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701194] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(19851), 1,
      anon_sym_BANG,
    ACTIONS(19853), 1,
      anon_sym__,
    STATE(15164), 1,
      sym_type_variable,
    STATE(15650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701217] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20770), 1,
      anon_sym_RBRACK,
    ACTIONS(20772), 1,
      anon_sym_GT,
    STATE(15651), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701240] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20770), 1,
      anon_sym_RBRACK,
    STATE(15652), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701263] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20774), 1,
      anon_sym_GT_RBRACE,
    STATE(15653), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701286] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20776), 1,
      anon_sym_COLON_GT,
    ACTIONS(20778), 1,
      anon_sym_RPAREN,
    STATE(15654), 1,
      sym_attribute,
    STATE(17865), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701309] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20780), 1,
      anon_sym_RBRACK,
    STATE(15655), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701332] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(20768), 1,
      sym__lowercase_identifier,
    STATE(7615), 1,
      sym_class_path,
    STATE(15656), 1,
      sym_attribute,
    STATE(18627), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701355] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20782), 1,
      sym__lowercase_identifier,
    STATE(12568), 1,
      sym_class_type_path,
    STATE(15657), 1,
      sym_attribute,
    STATE(17622), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701378] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20784), 1,
      anon_sym_RBRACK,
    STATE(15658), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701401] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20786), 1,
      anon_sym_GT_RBRACE,
    STATE(15659), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701424] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20788), 1,
      anon_sym_RBRACK,
    STATE(15660), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701447] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20790), 1,
      anon_sym_RBRACK,
    STATE(15661), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701470] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19557), 1,
      sym__lowercase_identifier,
    ACTIONS(19559), 1,
      anon_sym_LBRACK,
    ACTIONS(19561), 1,
      anon_sym_virtual,
    STATE(12112), 1,
      sym_class_type_binding,
    STATE(15662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701493] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19527), 1,
      sym__lowercase_identifier,
    STATE(10112), 1,
      sym_class_path,
    STATE(15663), 1,
      sym_attribute,
    STATE(19297), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701516] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19469), 1,
      sym__lowercase_identifier,
    STATE(7056), 1,
      sym_class_path,
    STATE(15664), 1,
      sym_attribute,
    STATE(20410), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701539] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20792), 1,
      sym__lowercase_identifier,
    STATE(11308), 1,
      sym_class_type_path,
    STATE(15665), 1,
      sym_attribute,
    STATE(17527), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701562] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20792), 1,
      sym__lowercase_identifier,
    STATE(11306), 1,
      sym_class_type_path,
    STATE(15666), 1,
      sym_attribute,
    STATE(17527), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701585] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20792), 1,
      sym__lowercase_identifier,
    STATE(11459), 1,
      sym_class_type_path,
    STATE(15667), 1,
      sym_attribute,
    STATE(17527), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701608] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14443), 1,
      anon_sym_in,
    ACTIONS(20417), 1,
      anon_sym_and,
    ACTIONS(20419), 1,
      sym_let_and_operator,
    STATE(15668), 1,
      sym_attribute,
    STATE(15675), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701631] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20714), 1,
      sym__lowercase_identifier,
    STATE(11503), 1,
      sym_class_type_path,
    STATE(15669), 1,
      sym_attribute,
    STATE(17443), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701654] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20117), 1,
      sym__lowercase_identifier,
    STATE(11535), 1,
      sym_class_type_path,
    STATE(15670), 1,
      sym_attribute,
    STATE(17281), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701677] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20794), 1,
      anon_sym_COLON_GT,
    ACTIONS(20796), 1,
      anon_sym_RPAREN,
    STATE(15671), 1,
      sym_attribute,
    STATE(17869), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701700] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20798), 1,
      sym__lowercase_identifier,
    STATE(13124), 1,
      sym_class_type_path,
    STATE(15672), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701723] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20800), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15673), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701746] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20802), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15674), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701769] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14449), 1,
      anon_sym_in,
    ACTIONS(20804), 1,
      anon_sym_and,
    ACTIONS(20807), 1,
      sym_let_and_operator,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15675), 2,
      sym_attribute,
      aux_sym_value_definition_repeat1,
  [701790] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20810), 1,
      anon_sym_GT_RBRACE,
    STATE(15676), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701813] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14443), 1,
      anon_sym_in,
    ACTIONS(20417), 1,
      anon_sym_and,
    ACTIONS(20419), 1,
      sym_let_and_operator,
    STATE(15677), 1,
      sym_attribute,
    STATE(15776), 1,
      aux_sym_value_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701836] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20812), 1,
      anon_sym_RPAREN,
    STATE(15678), 1,
      sym_attribute,
    STATE(16205), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701859] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9912), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20814), 1,
      anon_sym_GT,
    STATE(15679), 1,
      sym_attribute,
    STATE(15703), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701882] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20816), 1,
      anon_sym_GT_RBRACE,
    STATE(15680), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701905] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20798), 1,
      sym__lowercase_identifier,
    STATE(13147), 1,
      sym_class_type_path,
    STATE(15681), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701928] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(20782), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [701949] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19249), 1,
      sym__lowercase_identifier,
    STATE(3822), 1,
      sym_class_path,
    STATE(15683), 1,
      sym_attribute,
    STATE(18736), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701972] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20818), 1,
      anon_sym_GT_RBRACE,
    STATE(15684), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [701995] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15685), 1,
      sym_attribute,
    STATE(17734), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20820), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [702016] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20822), 1,
      anon_sym_rec,
    STATE(13015), 1,
      sym_module_binding,
    STATE(15686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19095), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [702037] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15687), 1,
      sym_attribute,
    STATE(17559), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20824), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [702058] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20117), 1,
      sym__lowercase_identifier,
    STATE(11312), 1,
      sym_class_type_path,
    STATE(15688), 1,
      sym_attribute,
    STATE(17281), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702081] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19419), 1,
      sym__lowercase_identifier,
    STATE(6749), 1,
      sym_class_path,
    STATE(15689), 1,
      sym_attribute,
    STATE(19337), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702104] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20826), 1,
      sym__lowercase_identifier,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20829), 2,
      anon_sym_RPAREN,
      anon_sym_DOT,
    STATE(15690), 2,
      sym_attribute,
      aux_sym__abstract_type_repeat1,
  [702123] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20831), 1,
      anon_sym_GT_RBRACE,
    STATE(15691), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702146] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20714), 1,
      sym__lowercase_identifier,
    STATE(11437), 1,
      sym_class_type_path,
    STATE(15692), 1,
      sym_attribute,
    STATE(17443), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702169] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20714), 1,
      sym__lowercase_identifier,
    STATE(11251), 1,
      sym_class_type_path,
    STATE(15693), 1,
      sym_attribute,
    STATE(17443), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702192] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20833), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15694), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702215] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20835), 1,
      anon_sym_RBRACK,
    STATE(15695), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702238] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(12349), 1,
      sym__lowercase_identifier,
    STATE(13898), 1,
      sym_type_constructor_path,
    STATE(15696), 1,
      sym_attribute,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702261] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    ACTIONS(20837), 1,
      anon_sym_RBRACE,
    STATE(15697), 1,
      sym_attribute,
    STATE(18307), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702284] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20839), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15698), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702307] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20841), 1,
      anon_sym_COLON_GT,
    ACTIONS(20843), 1,
      anon_sym_RPAREN,
    STATE(15699), 1,
      sym_attribute,
    STATE(17998), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702330] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20845), 1,
      anon_sym_COLON_GT,
    ACTIONS(20847), 1,
      anon_sym_RPAREN,
    STATE(15700), 1,
      sym_attribute,
    STATE(17976), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702353] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20421), 1,
      sym__lowercase_identifier,
    STATE(10977), 1,
      sym_class_type_path,
    STATE(15701), 1,
      sym_attribute,
    STATE(17477), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702376] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20849), 1,
      anon_sym_RBRACK,
    ACTIONS(20851), 1,
      anon_sym_GT,
    STATE(15702), 1,
      sym_attribute,
    STATE(15720), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702399] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20849), 1,
      anon_sym_RBRACK,
    ACTIONS(20851), 1,
      anon_sym_GT,
    STATE(15703), 1,
      sym_attribute,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20394), 1,
      anon_sym_as,
    STATE(15704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12706), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [702441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20394), 1,
      anon_sym_as,
    STATE(15705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12710), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [702460] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20853), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15706), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702483] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20855), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15707), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702506] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20782), 1,
      sym__lowercase_identifier,
    STATE(12427), 1,
      sym_class_type_path,
    STATE(15708), 1,
      sym_attribute,
    STATE(17622), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702529] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20857), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20860), 2,
      anon_sym_RBRACK,
      anon_sym_GT,
    STATE(15709), 2,
      sym_attribute,
      aux_sym_polymorphic_variant_type_repeat1,
  [702548] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20782), 1,
      sym__lowercase_identifier,
    STATE(12456), 1,
      sym_class_type_path,
    STATE(15710), 1,
      sym_attribute,
    STATE(17622), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702571] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20862), 1,
      anon_sym_GT_RBRACE,
    STATE(15711), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702594] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20864), 1,
      sym__lowercase_identifier,
    ACTIONS(20866), 1,
      anon_sym_LPAREN,
    STATE(9221), 1,
      sym_parenthesized_operator,
    STATE(9263), 1,
      sym__value_name,
    STATE(15712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702617] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20868), 1,
      anon_sym_GT_RBRACE,
    STATE(15713), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702640] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20870), 1,
      anon_sym_RPAREN,
    STATE(15714), 1,
      sym_attribute,
    STATE(16016), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702663] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9900), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20872), 1,
      anon_sym_GT,
    STATE(15715), 1,
      sym_attribute,
    STATE(15739), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702686] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20874), 1,
      anon_sym_GT_RBRACE,
    STATE(15716), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702709] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20876), 1,
      anon_sym_GT_RBRACE,
    STATE(15717), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702732] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20782), 1,
      sym__lowercase_identifier,
    STATE(12462), 1,
      sym_class_type_path,
    STATE(15718), 1,
      sym_attribute,
    STATE(17622), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702755] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19471), 1,
      sym__lowercase_identifier,
    STATE(6807), 1,
      sym_class_path,
    STATE(15719), 1,
      sym_attribute,
    STATE(19377), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702778] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20878), 1,
      anon_sym_RBRACK,
    ACTIONS(20880), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702801] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20878), 1,
      anon_sym_RBRACK,
    STATE(15721), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702824] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20882), 1,
      anon_sym_DASH_GT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15722), 1,
      sym_attribute,
    STATE(15786), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702847] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20882), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702870] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20884), 1,
      anon_sym_rec,
    STATE(12905), 1,
      sym_module_binding,
    STATE(15724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19111), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [702891] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20886), 1,
      anon_sym_DASH_GT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15725), 1,
      sym_attribute,
    STATE(15731), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702914] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20886), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702937] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(15727), 1,
      sym_attribute,
    STATE(18294), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702960] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20888), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15728), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [702983] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    ACTIONS(20890), 1,
      anon_sym_EQ,
    ACTIONS(20892), 1,
      anon_sym_RPAREN,
    STATE(15729), 1,
      sym_attribute,
    STATE(18154), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703006] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20894), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703029] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20896), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703052] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19551), 1,
      sym__lowercase_identifier,
    ACTIONS(19553), 1,
      anon_sym_LBRACK,
    ACTIONS(19555), 1,
      anon_sym_virtual,
    STATE(12489), 1,
      sym_class_type_binding,
    STATE(15732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703075] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20898), 1,
      anon_sym_with,
    STATE(15733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703098] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20900), 1,
      anon_sym_COLON_GT,
    ACTIONS(20902), 1,
      anon_sym_RPAREN,
    STATE(15734), 1,
      sym_attribute,
    STATE(18145), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703121] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20904), 1,
      anon_sym_RBRACK,
    STATE(15735), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703144] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20906), 1,
      anon_sym_GT_RBRACE,
    STATE(15736), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703167] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19551), 1,
      sym__lowercase_identifier,
    ACTIONS(19553), 1,
      anon_sym_LBRACK,
    ACTIONS(19555), 1,
      anon_sym_virtual,
    STATE(12112), 1,
      sym_class_type_binding,
    STATE(15737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703190] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20908), 1,
      anon_sym_RBRACK,
    ACTIONS(20910), 1,
      anon_sym_GT,
    STATE(15738), 1,
      sym_attribute,
    STATE(15752), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703213] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20908), 1,
      anon_sym_RBRACK,
    ACTIONS(20910), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703236] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20912), 1,
      anon_sym_RBRACK,
    STATE(15740), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703259] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(15741), 1,
      sym_attribute,
    STATE(16739), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703282] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19324), 1,
      sym__lowercase_identifier,
    STATE(5033), 1,
      sym_class_path,
    STATE(15742), 1,
      sym_attribute,
    STATE(18572), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703305] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(20914), 1,
      anon_sym_RPAREN,
    STATE(15743), 1,
      sym_attribute,
    STATE(16179), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703328] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20161), 1,
      sym__lowercase_identifier,
    STATE(9891), 1,
      sym_class_type_path,
    STATE(15744), 1,
      sym_attribute,
    STATE(17405), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703351] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20916), 1,
      anon_sym_GT_RBRACE,
    STATE(15745), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703374] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20410), 1,
      sym__lowercase_identifier,
    STATE(14386), 1,
      sym_class_type_path,
    STATE(15746), 1,
      sym_attribute,
    STATE(17599), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703397] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19163), 1,
      sym__lowercase_identifier,
    STATE(8111), 1,
      sym_class_path,
    STATE(15747), 1,
      sym_attribute,
    STATE(18682), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703420] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20918), 1,
      anon_sym_RBRACK,
    ACTIONS(20920), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703443] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20922), 1,
      anon_sym_GT_RBRACE,
    STATE(15749), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703466] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20410), 1,
      sym__lowercase_identifier,
    STATE(14557), 1,
      sym_class_type_path,
    STATE(15750), 1,
      sym_attribute,
    STATE(17599), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703489] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20924), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703512] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20926), 1,
      anon_sym_RBRACK,
    ACTIONS(20928), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703535] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20410), 1,
      sym__lowercase_identifier,
    STATE(14615), 1,
      sym_class_type_path,
    STATE(15753), 1,
      sym_attribute,
    STATE(17599), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703558] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20926), 1,
      anon_sym_RBRACK,
    STATE(15754), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703581] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20918), 1,
      anon_sym_RBRACK,
    STATE(15755), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703604] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20930), 1,
      anon_sym_GT_RBRACE,
    STATE(15756), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703627] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19613), 1,
      sym__lowercase_identifier,
    STATE(7067), 1,
      sym_class_path,
    STATE(15757), 1,
      sym_attribute,
    STATE(18844), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703650] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20932), 1,
      anon_sym_with,
    STATE(15758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703673] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19163), 1,
      sym__lowercase_identifier,
    STATE(8151), 1,
      sym_class_path,
    STATE(15759), 1,
      sym_attribute,
    STATE(18682), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703696] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20934), 1,
      anon_sym_RBRACK,
    STATE(15760), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703719] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20145), 1,
      sym__lowercase_identifier,
    STATE(10567), 1,
      sym_class_type_path,
    STATE(15761), 1,
      sym_attribute,
    STATE(17671), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703742] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20145), 1,
      sym__lowercase_identifier,
    STATE(10587), 1,
      sym_class_type_path,
    STATE(15762), 1,
      sym_attribute,
    STATE(17671), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703765] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19409), 1,
      sym__lowercase_identifier,
    STATE(3919), 1,
      sym_class_path,
    STATE(15763), 1,
      sym_attribute,
    STATE(19417), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703788] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(15764), 1,
      sym_attribute,
    STATE(17161), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703811] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20145), 1,
      sym__lowercase_identifier,
    STATE(10595), 1,
      sym_class_type_path,
    STATE(15765), 1,
      sym_attribute,
    STATE(17671), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703834] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(20936), 1,
      anon_sym_RBRACK,
    STATE(15766), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703857] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20938), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15767), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703880] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20940), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703903] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20798), 1,
      sym__lowercase_identifier,
    STATE(10082), 1,
      sym_class_type_path,
    STATE(15769), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703926] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19591), 1,
      sym__lowercase_identifier,
    STATE(7490), 1,
      sym_class_path,
    STATE(15770), 1,
      sym_attribute,
    STATE(20844), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703949] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20942), 1,
      anon_sym_COLON_GT,
    ACTIONS(20944), 1,
      anon_sym_RPAREN,
    STATE(15771), 1,
      sym_attribute,
    STATE(18208), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [703972] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(15772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19764), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [703991] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20234), 1,
      sym__lowercase_identifier,
    STATE(10360), 1,
      sym_class_type_path,
    STATE(15773), 1,
      sym_attribute,
    STATE(17551), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704014] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20234), 1,
      sym__lowercase_identifier,
    STATE(10321), 1,
      sym_class_type_path,
    STATE(15774), 1,
      sym_attribute,
    STATE(17551), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704037] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20234), 1,
      sym__lowercase_identifier,
    STATE(10494), 1,
      sym_class_type_path,
    STATE(15775), 1,
      sym_attribute,
    STATE(17551), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704060] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14513), 1,
      anon_sym_in,
    ACTIONS(20417), 1,
      anon_sym_and,
    ACTIONS(20419), 1,
      sym_let_and_operator,
    STATE(15675), 1,
      aux_sym_value_definition_repeat1,
    STATE(15776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704083] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20946), 1,
      anon_sym_with,
    STATE(15777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704106] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19575), 1,
      sym__lowercase_identifier,
    STATE(5437), 1,
      sym_class_path,
    STATE(15778), 1,
      sym_attribute,
    STATE(18580), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704129] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20013), 1,
      sym__lowercase_identifier,
    STATE(10022), 1,
      sym_class_type_path,
    STATE(15779), 1,
      sym_attribute,
    STATE(18345), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704152] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20948), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704175] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(15781), 1,
      sym_attribute,
    STATE(15968), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704198] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(19766), 1,
      anon_sym_RBRACK,
    STATE(15782), 1,
      sym_attribute,
    STATE(16846), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704221] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20950), 1,
      anon_sym_GT_RBRACE,
    STATE(15783), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704244] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20952), 1,
      anon_sym_with,
    STATE(15784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704267] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19539), 1,
      sym__lowercase_identifier,
    STATE(7724), 1,
      sym_class_path,
    STATE(15785), 1,
      sym_attribute,
    STATE(19750), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704290] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20954), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704313] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(20956), 1,
      anon_sym_GT_RBRACE,
    STATE(15787), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704336] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11279), 1,
      sym__lowercase_identifier,
    STATE(15788), 1,
      sym_attribute,
    STATE(16022), 1,
      sym_type_constructor_path,
    STATE(17267), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704359] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20798), 1,
      sym__lowercase_identifier,
    STATE(10164), 1,
      sym_class_type_path,
    STATE(15789), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704382] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20958), 1,
      anon_sym_with,
    STATE(15790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704405] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20960), 1,
      sym__lowercase_identifier,
    ACTIONS(20962), 1,
      anon_sym_LPAREN,
    STATE(5634), 1,
      sym__value_name,
    STATE(5641), 1,
      sym_parenthesized_operator,
    STATE(15791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704428] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20964), 1,
      anon_sym_with,
    STATE(15792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704451] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20966), 1,
      sym__lowercase_identifier,
    STATE(8318), 1,
      sym_type_constructor_path,
    STATE(15793), 1,
      sym_attribute,
    STATE(17638), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704474] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20968), 1,
      anon_sym_with,
    STATE(15794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704497] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19455), 1,
      sym__lowercase_identifier,
    STATE(6289), 1,
      sym_class_path,
    STATE(15795), 1,
      sym_attribute,
    STATE(19457), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704520] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(11263), 1,
      sym__lowercase_identifier,
    STATE(14667), 1,
      sym_type_constructor_path,
    STATE(15796), 1,
      sym_attribute,
    STATE(17494), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704543] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20970), 1,
      anon_sym_with,
    STATE(15797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704566] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20013), 1,
      sym__lowercase_identifier,
    STATE(10101), 1,
      sym_class_type_path,
    STATE(15798), 1,
      sym_attribute,
    STATE(18345), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704589] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20734), 1,
      sym__lowercase_identifier,
    STATE(10082), 1,
      sym_class_type_path,
    STATE(15799), 1,
      sym_attribute,
    STATE(17351), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704612] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20972), 1,
      anon_sym_with,
    STATE(15800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704635] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20798), 1,
      sym__lowercase_identifier,
    STATE(13183), 1,
      sym_class_type_path,
    STATE(15801), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704658] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20974), 1,
      anon_sym_COLON_GT,
    ACTIONS(20976), 1,
      anon_sym_RPAREN,
    STATE(15802), 1,
      sym_attribute,
    STATE(18261), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704681] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20978), 1,
      anon_sym_with,
    STATE(15803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704704] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20653), 1,
      sym__lowercase_identifier,
    STATE(9850), 1,
      sym_class_type_path,
    STATE(15804), 1,
      sym_attribute,
    STATE(17506), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704727] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(20980), 1,
      anon_sym_COLON_GT,
    ACTIONS(20982), 1,
      anon_sym_RPAREN,
    STATE(15805), 1,
      sym_attribute,
    STATE(18339), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704750] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20984), 1,
      anon_sym_with,
    STATE(15806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704773] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20986), 1,
      sym__lowercase_identifier,
    STATE(5651), 1,
      sym_type_constructor_path,
    STATE(15807), 1,
      sym_attribute,
    STATE(17256), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704796] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20988), 1,
      anon_sym_with,
    STATE(15808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704819] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20990), 1,
      anon_sym_with,
    STATE(15809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704842] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20992), 1,
      sym__lowercase_identifier,
    STATE(15610), 1,
      aux_sym_method_specification_repeat1,
    STATE(15810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19732), 2,
      anon_sym_private,
      anon_sym_virtual,
  [704863] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20994), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15811), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704886] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(20996), 1,
      anon_sym_with,
    STATE(15812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704909] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(20998), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15813), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704932] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21000), 1,
      anon_sym_with,
    STATE(15814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704955] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20278), 1,
      sym__lowercase_identifier,
    STATE(9810), 1,
      sym_class_type_path,
    STATE(15815), 1,
      sym_attribute,
    STATE(17643), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [704978] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21002), 1,
      anon_sym_with,
    STATE(15816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705001] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(21004), 1,
      anon_sym_COLON_GT,
    ACTIONS(21006), 1,
      anon_sym_RPAREN,
    STATE(15817), 1,
      sym_attribute,
    STATE(18285), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705024] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21008), 1,
      sym__lowercase_identifier,
    ACTIONS(21010), 1,
      anon_sym_LPAREN,
    STATE(5819), 1,
      sym__value_name,
    STATE(5868), 1,
      sym_parenthesized_operator,
    STATE(15818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705047] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21012), 1,
      anon_sym_with,
    STATE(15819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705070] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21014), 1,
      anon_sym_RPAREN,
    STATE(15820), 1,
      sym_attribute,
    STATE(16068), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705093] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21016), 1,
      anon_sym_with,
    STATE(15821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705116] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10027), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21018), 1,
      anon_sym_GT,
    STATE(15822), 1,
      sym_attribute,
    STATE(15834), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705139] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21020), 1,
      anon_sym_with,
    STATE(15823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705162] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21022), 1,
      anon_sym_with,
    STATE(15824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705185] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21024), 1,
      anon_sym_with,
    STATE(15825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705208] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21026), 1,
      anon_sym_GT_RBRACE,
    STATE(15826), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705231] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21028), 1,
      anon_sym_with,
    STATE(15827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705254] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(21030), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15828), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705277] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21032), 1,
      anon_sym_with,
    STATE(15829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705300] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21034), 1,
      anon_sym_with,
    STATE(15830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705323] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21036), 1,
      anon_sym_with,
    STATE(15831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705346] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21038), 1,
      anon_sym_with,
    STATE(15832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705369] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21040), 1,
      anon_sym_RBRACK,
    ACTIONS(21042), 1,
      anon_sym_GT,
    STATE(15833), 1,
      sym_attribute,
    STATE(15843), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705392] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21040), 1,
      anon_sym_RBRACK,
    ACTIONS(21042), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705415] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21044), 1,
      anon_sym_with,
    STATE(15835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705438] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21046), 1,
      anon_sym_with,
    STATE(15836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705461] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21048), 1,
      anon_sym_GT_RBRACE,
    STATE(15837), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705484] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21050), 1,
      anon_sym_with,
    STATE(15838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705507] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21052), 1,
      anon_sym_with,
    STATE(15839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705530] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21054), 1,
      anon_sym_GT_RBRACE,
    STATE(15840), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705553] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21056), 1,
      anon_sym_with,
    STATE(15841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705576] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21058), 1,
      anon_sym_with,
    STATE(15842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705599] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21060), 1,
      anon_sym_RBRACK,
    ACTIONS(21062), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705622] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(21060), 1,
      anon_sym_RBRACK,
    STATE(15844), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705645] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21064), 1,
      anon_sym_with,
    STATE(15845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705668] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(21066), 1,
      sym__lowercase_identifier,
    STATE(5864), 1,
      sym_type_constructor_path,
    STATE(15846), 1,
      sym_attribute,
    STATE(17565), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705691] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21068), 1,
      anon_sym_with,
    STATE(15847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705714] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21070), 1,
      anon_sym_with,
    STATE(15848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705737] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(21072), 1,
      anon_sym_RBRACK,
    STATE(15849), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705760] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21074), 1,
      anon_sym_with,
    STATE(15850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705783] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(21076), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15851), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705806] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(21078), 1,
      anon_sym_RBRACK,
    STATE(15852), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705829] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21080), 1,
      anon_sym_with,
    STATE(15853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705852] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(21082), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15854), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705875] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21084), 1,
      anon_sym_GT_RBRACE,
    STATE(15855), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705898] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21086), 1,
      anon_sym_with,
    STATE(15856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705921] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21088), 1,
      anon_sym_with,
    STATE(15857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705944] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21090), 1,
      anon_sym_with,
    STATE(15858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705967] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19503), 1,
      sym__lowercase_identifier,
    STATE(7715), 1,
      sym_class_path,
    STATE(15859), 1,
      sym_attribute,
    STATE(18447), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [705990] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(19987), 1,
      sym__lowercase_identifier,
    STATE(11695), 1,
      sym_class_type_path,
    STATE(15860), 1,
      sym_attribute,
    STATE(17576), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706013] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9722), 1,
      anon_sym_POUND,
    ACTIONS(19803), 1,
      anon_sym_DOT,
    ACTIONS(20324), 1,
      sym_hash_operator,
    ACTIONS(21092), 1,
      anon_sym_with,
    STATE(15861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706036] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(19987), 1,
      sym__lowercase_identifier,
    STATE(11712), 1,
      sym_class_type_path,
    STATE(15862), 1,
      sym_attribute,
    STATE(17576), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706059] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(19987), 1,
      sym__lowercase_identifier,
    STATE(11577), 1,
      sym_class_type_path,
    STATE(15863), 1,
      sym_attribute,
    STATE(17576), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706082] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(13912), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [706103] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19097), 1,
      sym__lowercase_identifier,
    ACTIONS(19099), 1,
      anon_sym_LBRACK,
    ACTIONS(19101), 1,
      anon_sym_virtual,
    STATE(12911), 1,
      sym_class_binding,
    STATE(15865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706126] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21094), 1,
      anon_sym_RPAREN,
    STATE(15866), 1,
      sym_attribute,
    STATE(16222), 1,
      aux_sym_instantiated_class_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706149] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15867), 1,
      sym_attribute,
    STATE(18373), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21096), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [706170] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10033), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21098), 1,
      anon_sym_GT,
    STATE(15868), 1,
      sym_attribute,
    STATE(15903), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706193] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(19425), 1,
      sym__lowercase_identifier,
    STATE(4033), 1,
      sym_class_path,
    STATE(15869), 1,
      sym_attribute,
    STATE(19496), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706216] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    STATE(15870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(13696), 2,
      anon_sym_COLON_GT,
      anon_sym_RPAREN,
  [706237] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(20053), 1,
      sym__lowercase_identifier,
    STATE(15871), 1,
      sym_attribute,
    STATE(18150), 1,
      sym_module_type_path,
    STATE(18173), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706260] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21102), 1,
      anon_sym_of,
    STATE(15872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21100), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [706279] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(21104), 1,
      anon_sym_COLON_GT,
    ACTIONS(21106), 1,
      anon_sym_RPAREN,
    STATE(15873), 1,
      sym_attribute,
    STATE(18399), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706302] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    ACTIONS(21108), 1,
      anon_sym_RBRACK,
    STATE(15874), 1,
      sym_attribute,
    STATE(15878), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706325] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(21110), 1,
      anon_sym_COLON_GT,
    ACTIONS(21112), 1,
      anon_sym_RPAREN,
    STATE(15875), 1,
      sym_attribute,
    STATE(18393), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706348] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(20940), 1,
      anon_sym_DASH_GT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15434), 1,
      aux_sym_module_binding_repeat1,
    STATE(15876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706371] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21114), 1,
      anon_sym_GT_RBRACE,
    STATE(15877), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706394] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21116), 1,
      anon_sym_RBRACK,
    ACTIONS(21118), 1,
      aux_sym_tag_token1,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(15878), 2,
      sym_attribute,
      aux_sym_polymorphic_variant_type_repeat2,
  [706415] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(12441), 1,
      anon_sym_and,
    STATE(15879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12439), 3,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
      sym_let_and_operator,
  [706434] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19097), 1,
      sym__lowercase_identifier,
    ACTIONS(19099), 1,
      anon_sym_LBRACK,
    ACTIONS(19101), 1,
      anon_sym_virtual,
    STATE(12376), 1,
      sym_class_binding,
    STATE(15880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706457] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(21121), 1,
      sym__lowercase_identifier,
    STATE(9217), 1,
      sym_type_constructor_path,
    STATE(15881), 1,
      sym_attribute,
    STATE(17520), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706480] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(21123), 1,
      anon_sym_DOT,
    STATE(15461), 1,
      aux_sym_constructor_declaration_repeat1,
    STATE(15882), 1,
      sym_attribute,
    STATE(17226), 1,
      sym_type_variable,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706503] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21125), 1,
      anon_sym_rec,
    STATE(13547), 1,
      sym_module_binding,
    STATE(15883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19143), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [706524] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21127), 1,
      anon_sym_DASH_GT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15884), 1,
      sym_attribute,
    STATE(15886), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706547] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21127), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706570] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21129), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706593] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21322), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [706614] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21131), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706637] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(21133), 1,
      anon_sym_COLON_GT,
    ACTIONS(21135), 1,
      anon_sym_RPAREN,
    STATE(15889), 1,
      sym_attribute,
    STATE(18055), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706660] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20798), 1,
      sym__lowercase_identifier,
    STATE(13267), 1,
      sym_class_type_path,
    STATE(15890), 1,
      sym_attribute,
    STATE(17832), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706683] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    ACTIONS(20792), 1,
      sym__lowercase_identifier,
    STATE(11529), 1,
      sym_class_type_path,
    STATE(15891), 1,
      sym_attribute,
    STATE(17527), 1,
      sym_extended_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706706] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21137), 1,
      anon_sym_GT_RBRACE,
    STATE(15892), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706729] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21139), 1,
      anon_sym_rec,
    STATE(12574), 1,
      sym_module_binding,
    STATE(15893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19137), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [706750] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21141), 1,
      anon_sym_DASH_GT,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15894), 1,
      sym_attribute,
    STATE(15896), 1,
      aux_sym_module_binding_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706773] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21141), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706796] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21143), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706819] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15897), 1,
      sym_attribute,
    STATE(18415), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21145), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [706840] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(20053), 1,
      sym__lowercase_identifier,
    STATE(15898), 1,
      sym_attribute,
    STATE(18173), 1,
      sym_extended_module_path,
    STATE(18412), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706863] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(19983), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706886] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21147), 1,
      anon_sym_RBRACK,
    ACTIONS(21149), 1,
      anon_sym_GT,
    STATE(15208), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706909] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(21151), 1,
      anon_sym_DASH_GT,
    STATE(9480), 1,
      aux_sym_module_binding_repeat1,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706932] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21340), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [706953] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21147), 1,
      anon_sym_RBRACK,
    ACTIONS(21149), 1,
      anon_sym_GT,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [706976] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(21342), 2,
      sym__simple_value_pattern,
      sym_parenthesized_operator,
  [706997] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18287), 1,
      anon_sym_COLON2,
    ACTIONS(21153), 1,
      anon_sym_COLON_GT,
    ACTIONS(21155), 1,
      anon_sym_RPAREN,
    STATE(15905), 1,
      sym_attribute,
    STATE(17391), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707020] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13854), 1,
      anon_sym_PERCENT,
    STATE(15906), 1,
      sym_attribute,
    STATE(18419), 1,
      sym__attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21157), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707041] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    ACTIONS(21159), 1,
      anon_sym_GT_RBRACE,
    STATE(15907), 1,
      sym_attribute,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707064] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12504), 1,
      sym__uppercase_identifier,
    ACTIONS(20053), 1,
      sym__lowercase_identifier,
    STATE(15908), 1,
      sym_attribute,
    STATE(18173), 1,
      sym_extended_module_path,
    STATE(18420), 1,
      sym_module_type_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707087] = 7,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16751), 1,
      sym__lowercase_identifier,
    ACTIONS(19295), 1,
      anon_sym_LPAREN,
    STATE(7248), 1,
      sym_parenthesized_operator,
    STATE(15909), 1,
      sym_attribute,
    STATE(18411), 1,
      sym__value_name,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707110] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21161), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707130] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18480), 1,
      anon_sym_SEMI,
    ACTIONS(18482), 1,
      anon_sym_GT,
    STATE(15911), 1,
      sym_attribute,
    STATE(16002), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707150] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19451), 1,
      anon_sym_RBRACE,
    ACTIONS(21163), 1,
      anon_sym_SEMI,
    STATE(15912), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707170] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21165), 1,
      anon_sym_RPAREN,
    STATE(15913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707190] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20493), 1,
      anon_sym_RBRACK,
    STATE(15914), 1,
      sym_attribute,
    STATE(15933), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707210] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20493), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707230] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3331), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21167), 1,
      anon_sym_SEMI,
    STATE(15916), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707250] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3583), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21169), 1,
      anon_sym_SEMI,
    STATE(15917), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707270] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19587), 1,
      anon_sym_RBRACE,
    ACTIONS(21171), 1,
      anon_sym_SEMI,
    STATE(15918), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12657), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [707306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12661), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_GT,
  [707322] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21173), 1,
      anon_sym_SEMI,
    ACTIONS(21175), 1,
      anon_sym_GT_RBRACE,
    STATE(15921), 1,
      sym_attribute,
    STATE(15957), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707342] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11868), 1,
      anon_sym_GT,
    ACTIONS(21177), 1,
      anon_sym_SEMI,
    STATE(15922), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707362] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21179), 1,
      sym__lowercase_identifier,
    ACTIONS(21181), 1,
      anon_sym_LPAREN,
    STATE(7840), 1,
      sym__simple_value_pattern,
    STATE(15923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707382] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21183), 1,
      anon_sym_SEMI,
    ACTIONS(21185), 1,
      anon_sym_RBRACE,
    STATE(15924), 1,
      sym_attribute,
    STATE(15939), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707402] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21187), 1,
      anon_sym_RPAREN,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    STATE(15925), 1,
      sym_attribute,
    STATE(16412), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707422] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20497), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21191), 1,
      anon_sym_SEMI,
    STATE(15926), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707442] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19314), 1,
      anon_sym_RBRACE,
    ACTIONS(21193), 1,
      anon_sym_SEMI,
    STATE(15927), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707462] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20210), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21195), 1,
      anon_sym_SEMI,
    STATE(15928), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707482] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21197), 1,
      sym__lowercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    STATE(15929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707502] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21201), 1,
      anon_sym_RPAREN,
    STATE(15930), 1,
      sym_attribute,
    STATE(20507), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707522] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21203), 1,
      anon_sym_RPAREN,
    STATE(15931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707542] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19301), 1,
      anon_sym_RBRACE,
    ACTIONS(21205), 1,
      anon_sym_SEMI,
    STATE(15932), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707562] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20505), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707582] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20505), 1,
      anon_sym_RBRACK,
    STATE(15934), 1,
      sym_attribute,
    STATE(15945), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707602] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3385), 1,
      anon_sym_RBRACK,
    ACTIONS(21207), 1,
      anon_sym_SEMI,
    STATE(15935), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707622] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12), 1,
      sym_attribute_id,
    STATE(15936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707640] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21211), 1,
      anon_sym_SEMI,
    ACTIONS(21213), 1,
      anon_sym_RBRACE,
    STATE(15937), 1,
      sym_attribute,
    STATE(15950), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707660] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13), 1,
      sym_attribute_id,
    STATE(15938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [707678] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19445), 1,
      anon_sym_RBRACE,
    ACTIONS(21215), 1,
      anon_sym_SEMI,
    STATE(15939), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707698] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19305), 1,
      anon_sym_RBRACE,
    ACTIONS(21217), 1,
      anon_sym_SEMI,
    STATE(15940), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707718] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3491), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21219), 1,
      anon_sym_SEMI,
    STATE(15941), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707738] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21221), 1,
      aux_sym_quoted_extension_token1,
    STATE(15942), 1,
      sym_attribute,
    STATE(18980), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707758] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21223), 1,
      anon_sym_RBRACK,
    STATE(15943), 1,
      sym_attribute,
    STATE(15948), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707778] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20071), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21225), 1,
      anon_sym_SEMI,
    STATE(15944), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707798] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20511), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707818] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3487), 1,
      anon_sym_RBRACK,
    ACTIONS(21227), 1,
      anon_sym_SEMI,
    STATE(15946), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707838] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21229), 1,
      sym__lowercase_identifier,
    STATE(15947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707858] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21231), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(15948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707878] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21231), 1,
      anon_sym_RBRACK,
    STATE(15949), 1,
      sym_attribute,
    STATE(15962), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707898] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19316), 1,
      anon_sym_RBRACE,
    ACTIONS(21233), 1,
      anon_sym_SEMI,
    STATE(15950), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707918] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    ACTIONS(21235), 1,
      anon_sym__,
    STATE(15092), 1,
      sym_type_variable,
    STATE(15951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707938] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20220), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707958] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19326), 1,
      anon_sym_RBRACE,
    ACTIONS(21237), 1,
      anon_sym_SEMI,
    STATE(15953), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707978] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21239), 1,
      anon_sym_SEMI,
    ACTIONS(21241), 1,
      anon_sym_RBRACE,
    STATE(15954), 1,
      sym_attribute,
    STATE(16037), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [707998] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3489), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21243), 1,
      anon_sym_SEMI,
    STATE(15955), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708018] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19199), 1,
      anon_sym_RBRACE,
    ACTIONS(21245), 1,
      anon_sym_SEMI,
    STATE(15956), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708038] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20073), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21247), 1,
      anon_sym_SEMI,
    STATE(15957), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708058] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20521), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21249), 1,
      anon_sym_SEMI,
    STATE(15958), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708078] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20224), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708098] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21251), 1,
      anon_sym_SEMI,
    ACTIONS(21253), 1,
      anon_sym_RBRACE,
    STATE(15960), 1,
      sym_attribute,
    STATE(16261), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708118] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10546), 1,
      sym__type_equation,
    STATE(15961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21255), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [708136] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21257), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(15962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708156] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21259), 1,
      anon_sym_RPAREN,
    STATE(15963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708176] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21261), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708196] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15560), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15965), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708216] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20075), 1,
      anon_sym_RBRACK,
    STATE(15966), 1,
      sym_attribute,
    STATE(16085), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708236] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19297), 1,
      anon_sym_RBRACE,
    ACTIONS(21263), 1,
      anon_sym_SEMI,
    STATE(15967), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708256] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10547), 1,
      sym__type_equation,
    STATE(15968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21255), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [708274] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21265), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(15969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708294] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21267), 1,
      anon_sym_SEMI,
    ACTIONS(21269), 1,
      anon_sym_GT_RBRACE,
    STATE(15970), 1,
      sym_attribute,
    STATE(16043), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708314] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15565), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15971), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708334] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21271), 1,
      anon_sym_SEMI,
    ACTIONS(21273), 1,
      anon_sym_RBRACE,
    STATE(15972), 1,
      sym_attribute,
    STATE(15992), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708354] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15571), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(15973), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708374] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21275), 1,
      anon_sym_RPAREN,
    STATE(15974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708394] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21277), 1,
      anon_sym_RPAREN,
    STATE(15975), 1,
      sym_attribute,
    STATE(19774), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708414] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20535), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708434] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20075), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708454] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20535), 1,
      anon_sym_RBRACK,
    STATE(15978), 1,
      sym_attribute,
    STATE(16111), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708474] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21279), 1,
      anon_sym_SEMI,
    ACTIONS(21281), 1,
      anon_sym_RBRACE,
    STATE(15979), 1,
      sym_attribute,
    STATE(16017), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708494] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21283), 1,
      anon_sym_SEMI,
    ACTIONS(21285), 1,
      anon_sym_GT_RBRACE,
    STATE(15980), 1,
      sym_attribute,
    STATE(16000), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708514] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21287), 1,
      anon_sym_SEMI,
    ACTIONS(21289), 1,
      anon_sym_GT_RBRACE,
    STATE(15981), 1,
      sym_attribute,
    STATE(16099), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708534] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21291), 1,
      anon_sym_SEMI,
    ACTIONS(21293), 1,
      anon_sym_RBRACE,
    STATE(15982), 1,
      sym_attribute,
    STATE(16004), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708554] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21295), 1,
      anon_sym_SEMI,
    ACTIONS(21297), 1,
      anon_sym_GT_RBRACE,
    STATE(15983), 1,
      sym_attribute,
    STATE(16146), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708574] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21299), 1,
      anon_sym_RPAREN,
    STATE(15984), 1,
      sym_attribute,
    STATE(18444), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708594] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11788), 1,
      anon_sym_GT,
    ACTIONS(21301), 1,
      anon_sym_SEMI,
    STATE(15985), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708614] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3599), 1,
      anon_sym_RBRACK,
    ACTIONS(21303), 1,
      anon_sym_SEMI,
    STATE(15986), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708634] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3421), 1,
      anon_sym_RBRACK,
    ACTIONS(21305), 1,
      anon_sym_SEMI,
    STATE(15987), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708654] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21307), 1,
      anon_sym_RPAREN,
    STATE(15988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708674] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21309), 1,
      anon_sym_SEMI,
    ACTIONS(21311), 1,
      anon_sym_GT_RBRACE,
    STATE(15989), 1,
      sym_attribute,
    STATE(16012), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708694] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20545), 1,
      anon_sym_RBRACK,
    STATE(15990), 1,
      sym_attribute,
    STATE(16093), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708714] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20545), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(15991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708734] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19273), 1,
      anon_sym_RBRACE,
    ACTIONS(21313), 1,
      anon_sym_SEMI,
    STATE(15992), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708754] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3601), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21315), 1,
      anon_sym_SEMI,
    STATE(15993), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708774] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3719), 1,
      anon_sym_RBRACK,
    ACTIONS(21317), 1,
      anon_sym_SEMI,
    STATE(15994), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708794] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21319), 1,
      anon_sym_SEMI,
    ACTIONS(21321), 1,
      anon_sym_RBRACE,
    STATE(15995), 1,
      sym_attribute,
    STATE(16064), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708814] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3571), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21323), 1,
      anon_sym_SEMI,
    STATE(15996), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708834] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14), 1,
      sym_attribute_id,
    STATE(15997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [708852] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9908), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(15998), 1,
      sym_attribute,
    STATE(16028), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708872] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21325), 1,
      sym__lowercase_identifier,
    STATE(15999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708892] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20236), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21327), 1,
      anon_sym_SEMI,
    STATE(16000), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708912] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18274), 1,
      anon_sym_SEMI,
    ACTIONS(18276), 1,
      anon_sym_GT,
    STATE(16001), 1,
      sym_attribute,
    STATE(16031), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708932] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11736), 1,
      anon_sym_GT,
    ACTIONS(21329), 1,
      anon_sym_SEMI,
    STATE(16002), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708952] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21331), 1,
      aux_sym_quoted_extension_token1,
    STATE(16003), 1,
      sym_attribute,
    STATE(18712), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708972] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19489), 1,
      anon_sym_RBRACE,
    ACTIONS(21333), 1,
      anon_sym_SEMI,
    STATE(16004), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [708992] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19499), 1,
      anon_sym_RBRACE,
    ACTIONS(21335), 1,
      anon_sym_SEMI,
    STATE(16005), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709012] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21337), 1,
      anon_sym_SEMI,
    ACTIONS(21339), 1,
      anon_sym_RBRACE,
    STATE(16006), 1,
      sym_attribute,
    STATE(16073), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709032] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3721), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21341), 1,
      anon_sym_SEMI,
    STATE(16007), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709052] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21343), 1,
      anon_sym_SEMI,
    ACTIONS(21345), 1,
      anon_sym_RBRACE,
    STATE(16008), 1,
      sym_attribute,
    STATE(16126), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709072] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21347), 1,
      anon_sym_SEMI,
    ACTIONS(21349), 1,
      anon_sym_RBRACE,
    STATE(16009), 1,
      sym_attribute,
    STATE(16446), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709092] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21351), 1,
      anon_sym_SEMI,
    ACTIONS(21353), 1,
      anon_sym_GT_RBRACE,
    STATE(16010), 1,
      sym_attribute,
    STATE(16345), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709112] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21355), 1,
      anon_sym_SEMI,
    ACTIONS(21357), 1,
      anon_sym_RBRACE,
    STATE(16011), 1,
      sym_attribute,
    STATE(16029), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709132] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20557), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21359), 1,
      anon_sym_SEMI,
    STATE(16012), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709152] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10550), 1,
      sym__type_equation,
    STATE(16013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21361), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [709170] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21363), 1,
      anon_sym_SEMI,
    ACTIONS(21365), 1,
      anon_sym_GT_RBRACE,
    STATE(16014), 1,
      sym_attribute,
    STATE(16275), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709190] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3643), 1,
      anon_sym_RBRACK,
    ACTIONS(21367), 1,
      anon_sym_SEMI,
    STATE(16015), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709210] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21369), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709230] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19349), 1,
      anon_sym_RBRACE,
    ACTIONS(21371), 1,
      anon_sym_SEMI,
    STATE(16017), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709250] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15652), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16018), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709270] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21373), 1,
      anon_sym_RPAREN,
    STATE(16019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709290] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9892), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16020), 1,
      sym_attribute,
    STATE(16083), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709310] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21375), 1,
      sym__lowercase_identifier,
    STATE(16021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709330] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10551), 1,
      sym__type_equation,
    STATE(16022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21361), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [709348] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21377), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709368] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15658), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16024), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709388] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20567), 1,
      anon_sym_RBRACK,
    STATE(16025), 1,
      sym_attribute,
    STATE(16046), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709408] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15660), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16026), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709428] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18452), 1,
      anon_sym_SEMI,
    ACTIONS(18454), 1,
      anon_sym_GT,
    STATE(16027), 1,
      sym_attribute,
    STATE(16087), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709448] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20567), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709468] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19601), 1,
      anon_sym_RBRACE,
    ACTIONS(21379), 1,
      anon_sym_SEMI,
    STATE(16029), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709488] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21381), 1,
      anon_sym_SEMI,
    ACTIONS(21383), 1,
      anon_sym_RBRACE,
    STATE(16030), 1,
      sym_attribute,
    STATE(16153), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709508] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11880), 1,
      anon_sym_GT,
    ACTIONS(21385), 1,
      anon_sym_SEMI,
    STATE(16031), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709528] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21387), 1,
      anon_sym_SEMI,
    ACTIONS(21389), 1,
      anon_sym_RBRACE,
    STATE(16032), 1,
      sym_attribute,
    STATE(16054), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709548] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3279), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21391), 1,
      anon_sym_SEMI,
    STATE(16033), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709568] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21393), 1,
      anon_sym_RPAREN,
    STATE(16034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709588] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21395), 1,
      anon_sym_SEMI,
    ACTIONS(21397), 1,
      anon_sym_RBRACE,
    STATE(16035), 1,
      sym_attribute,
    STATE(16881), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709608] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3419), 1,
      anon_sym_RBRACK,
    ACTIONS(21399), 1,
      anon_sym_SEMI,
    STATE(16036), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709628] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19245), 1,
      anon_sym_RBRACE,
    ACTIONS(21401), 1,
      anon_sym_SEMI,
    STATE(16037), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709648] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21403), 1,
      anon_sym_SEMI,
    ACTIONS(21405), 1,
      anon_sym_RBRACE,
    STATE(15940), 1,
      aux_sym_record_expression_repeat1,
    STATE(16038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709668] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3651), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21407), 1,
      anon_sym_SEMI,
    STATE(16039), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709688] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15772), 1,
      anon_sym_in,
    ACTIONS(21409), 1,
      anon_sym_and,
    STATE(16040), 1,
      sym_attribute,
    STATE(16077), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709708] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21411), 1,
      sym__lowercase_identifier,
    STATE(16041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709728] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21413), 1,
      anon_sym_EQ,
    STATE(16042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21415), 2,
      anon_sym_SEMI,
      anon_sym_GT_RBRACE,
  [709746] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20575), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21417), 1,
      anon_sym_SEMI,
    STATE(16043), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709766] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21419), 1,
      anon_sym_RPAREN,
    STATE(16044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709786] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20615), 1,
      anon_sym_RBRACK,
    STATE(16045), 1,
      sym_attribute,
    STATE(16242), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709806] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20577), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709826] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20577), 1,
      anon_sym_RBRACK,
    STATE(16047), 1,
      sym_attribute,
    STATE(16062), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709846] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21421), 1,
      anon_sym_SEMI,
    ACTIONS(21423), 1,
      anon_sym_RBRACE,
    STATE(16048), 1,
      sym_attribute,
    STATE(16063), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709866] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19505), 1,
      anon_sym_RBRACE,
    ACTIONS(21425), 1,
      anon_sym_SEMI,
    STATE(16049), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709886] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15), 1,
      sym_attribute_id,
    STATE(16050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [709904] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21427), 1,
      anon_sym_RPAREN,
    STATE(16051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709924] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21429), 1,
      anon_sym_SEMI,
    ACTIONS(21431), 1,
      anon_sym_GT_RBRACE,
    STATE(16052), 1,
      sym_attribute,
    STATE(16084), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709944] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21433), 1,
      aux_sym_quoted_extension_token1,
    STATE(16053), 1,
      sym_attribute,
    STATE(19707), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709964] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19547), 1,
      anon_sym_RBRACE,
    ACTIONS(21435), 1,
      anon_sym_SEMI,
    STATE(16054), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [709984] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10051), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16055), 1,
      sym_attribute,
    STATE(16194), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710004] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17865), 1,
      sym__uppercase_identifier,
    ACTIONS(19791), 1,
      anon_sym_LPAREN,
    STATE(14121), 1,
      sym__constructor_name,
    STATE(16056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710024] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21437), 1,
      anon_sym_RPAREN,
    ACTIONS(21439), 1,
      anon_sym_COLON2,
    STATE(16057), 1,
      sym_attribute,
    STATE(19958), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710044] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21441), 1,
      anon_sym_RBRACK,
    STATE(16058), 1,
      sym_attribute,
    STATE(16794), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710064] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3623), 1,
      anon_sym_RBRACK,
    ACTIONS(21443), 1,
      anon_sym_SEMI,
    STATE(16059), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710084] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21445), 1,
      anon_sym_RPAREN,
    STATE(16060), 1,
      sym_attribute,
    STATE(19988), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710104] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7887), 1,
      anon_sym_RBRACK,
    ACTIONS(21447), 1,
      anon_sym_SEMI,
    STATE(16061), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710124] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20591), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710144] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19481), 1,
      anon_sym_RBRACE,
    ACTIONS(21449), 1,
      anon_sym_SEMI,
    STATE(16063), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710164] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18785), 1,
      anon_sym_RBRACE,
    ACTIONS(21451), 1,
      anon_sym_SEMI,
    STATE(16064), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710184] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21453), 1,
      sym__lowercase_identifier,
    STATE(16065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710204] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21455), 1,
      anon_sym_SEMI,
    ACTIONS(21457), 1,
      anon_sym_RBRACE,
    STATE(16066), 1,
      sym_attribute,
    STATE(16143), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710224] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7889), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21459), 1,
      anon_sym_SEMI,
    STATE(16067), 1,
      sym_attribute,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710244] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21461), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710264] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15754), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16069), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710284] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3625), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21463), 1,
      anon_sym_SEMI,
    STATE(16070), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710304] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8598), 1,
      anon_sym_RBRACK,
    ACTIONS(21465), 1,
      anon_sym_SEMI,
    STATE(16071), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710324] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21467), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710344] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18815), 1,
      anon_sym_RBRACE,
    ACTIONS(21469), 1,
      anon_sym_SEMI,
    STATE(16073), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710364] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15760), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16074), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710384] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15766), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16075), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710404] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8600), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21471), 1,
      anon_sym_SEMI,
    STATE(16076), 1,
      sym_attribute,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710424] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15096), 1,
      anon_sym_in,
    ACTIONS(21473), 1,
      anon_sym_and,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16077), 2,
      sym_attribute,
      aux_sym_module_definition_repeat1,
  [710442] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15772), 1,
      anon_sym_in,
    ACTIONS(21409), 1,
      anon_sym_and,
    STATE(16078), 1,
      sym_attribute,
    STATE(16348), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710462] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21476), 1,
      sym__lowercase_identifier,
    STATE(16079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710482] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21478), 1,
      anon_sym_RPAREN,
    STATE(16080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710502] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21480), 1,
      anon_sym_RPAREN,
    STATE(16081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710522] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20597), 1,
      anon_sym_RBRACK,
    STATE(16082), 1,
      sym_attribute,
    STATE(16115), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710542] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20597), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710562] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20256), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21482), 1,
      anon_sym_SEMI,
    STATE(16084), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710582] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20087), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710602] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21484), 1,
      anon_sym_RPAREN,
    STATE(16086), 1,
      sym_attribute,
    STATE(20553), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710622] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11581), 1,
      anon_sym_GT,
    ACTIONS(21486), 1,
      anon_sym_SEMI,
    STATE(16087), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710642] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21488), 1,
      anon_sym_SEMI,
    ACTIONS(21490), 1,
      anon_sym_RBRACE,
    STATE(16088), 1,
      sym_attribute,
    STATE(16123), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710662] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20087), 1,
      anon_sym_RBRACK,
    STATE(16089), 1,
      sym_attribute,
    STATE(16190), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710682] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21492), 1,
      anon_sym_RPAREN,
    STATE(16090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710702] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16), 1,
      sym_attribute_id,
    STATE(16091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [710720] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20615), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710740] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20607), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710760] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21494), 1,
      aux_sym_quoted_extension_token1,
    STATE(16094), 1,
      sym_attribute,
    STATE(20661), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710780] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20607), 1,
      anon_sym_RBRACK,
    STATE(16095), 1,
      sym_attribute,
    STATE(16155), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710800] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21496), 1,
      anon_sym_SEMI,
    ACTIONS(21498), 1,
      anon_sym_RBRACE,
    STATE(16096), 1,
      sym_attribute,
    STATE(16107), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710820] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21500), 1,
      sym__lowercase_identifier,
    STATE(16097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710840] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21502), 1,
      sym__lowercase_identifier,
    STATE(16098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710860] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20260), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21504), 1,
      anon_sym_SEMI,
    STATE(16099), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710880] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(16100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12661), 2,
      anon_sym_COLON_GT,
      anon_sym_EQ,
  [710898] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21506), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710918] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15844), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16102), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710938] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21508), 1,
      anon_sym_RPAREN,
    STATE(16103), 1,
      sym_attribute,
    STATE(20247), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710958] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21510), 1,
      sym__lowercase_identifier,
    STATE(16104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710978] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15849), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16105), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [710998] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15852), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16106), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711018] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19159), 1,
      anon_sym_RBRACE,
    ACTIONS(21512), 1,
      anon_sym_SEMI,
    STATE(16107), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711038] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21514), 1,
      anon_sym_SEMI,
    ACTIONS(21516), 1,
      anon_sym_GT_RBRACE,
    STATE(16108), 1,
      sym_attribute,
    STATE(16175), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711058] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21518), 1,
      anon_sym_SEMI,
    ACTIONS(21520), 1,
      anon_sym_RBRACE,
    STATE(16109), 1,
      sym_attribute,
    STATE(16424), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711078] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21522), 1,
      anon_sym_SEMI,
    ACTIONS(21524), 1,
      anon_sym_RBRACE,
    STATE(16110), 1,
      sym_attribute,
    STATE(16147), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711098] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20619), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711118] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17), 1,
      sym_attribute_id,
    STATE(16112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711136] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21526), 1,
      anon_sym_RPAREN,
    STATE(16113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21528), 3,
      anon_sym_mutable,
      anon_sym_virtual,
      sym__lowercase_identifier,
  [711172] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20621), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711192] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3503), 1,
      anon_sym_RBRACK,
    ACTIONS(21530), 1,
      anon_sym_SEMI,
    STATE(16116), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711212] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20621), 1,
      anon_sym_RBRACK,
    STATE(16117), 1,
      sym_attribute,
    STATE(16135), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711232] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21532), 1,
      aux_sym_quoted_extension_token1,
    STATE(16118), 1,
      sym_attribute,
    STATE(19183), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711252] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3425), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21534), 1,
      anon_sym_SEMI,
    STATE(16119), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711272] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3387), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21536), 1,
      anon_sym_SEMI,
    STATE(16120), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711292] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21538), 1,
      anon_sym_SEMI,
    ACTIONS(21540), 1,
      anon_sym_RBRACE,
    STATE(16121), 1,
      sym_attribute,
    STATE(16140), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711312] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10049), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16122), 1,
      sym_attribute,
    STATE(16197), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711332] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19287), 1,
      anon_sym_RBRACE,
    ACTIONS(21542), 1,
      anon_sym_SEMI,
    STATE(16123), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711352] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21544), 1,
      anon_sym_SEMI,
    ACTIONS(21546), 1,
      anon_sym_RBRACE,
    STATE(16124), 1,
      sym_attribute,
    STATE(16181), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711372] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21548), 1,
      anon_sym_SEMI,
    ACTIONS(21550), 1,
      anon_sym_GT_RBRACE,
    STATE(16125), 1,
      sym_attribute,
    STATE(16154), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711392] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19225), 1,
      anon_sym_RBRACE,
    ACTIONS(21552), 1,
      anon_sym_SEMI,
    STATE(16126), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711412] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21554), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711432] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15446), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16128), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711452] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11708), 1,
      anon_sym_GT,
    ACTIONS(21556), 1,
      anon_sym_SEMI,
    STATE(16129), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711472] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21558), 1,
      anon_sym_SEMI,
    ACTIONS(21560), 1,
      anon_sym_RBRACE,
    STATE(16130), 1,
      sym_attribute,
    STATE(16437), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711492] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15634), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16131), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711512] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15661), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16132), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711532] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21562), 1,
      anon_sym_SEMI,
    ACTIONS(21564), 1,
      anon_sym_GT_RBRACE,
    STATE(16133), 1,
      sym_attribute,
    STATE(16156), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711552] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3739), 1,
      anon_sym_RBRACK,
    ACTIONS(21566), 1,
      anon_sym_SEMI,
    STATE(16134), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711572] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20627), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711592] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18331), 1,
      anon_sym_SEMI,
    ACTIONS(18333), 1,
      anon_sym_GT,
    STATE(16136), 1,
      sym_attribute,
    STATE(16204), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711612] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18), 1,
      sym_attribute_id,
    STATE(16137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [711630] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3645), 1,
      anon_sym_RBRACK,
    ACTIONS(21568), 1,
      anon_sym_SEMI,
    STATE(16138), 1,
      sym_attribute,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711650] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9922), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16139), 1,
      sym_attribute,
    STATE(16161), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711670] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19328), 1,
      anon_sym_RBRACE,
    ACTIONS(21570), 1,
      anon_sym_SEMI,
    STATE(16140), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711690] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21572), 1,
      aux_sym_quoted_extension_token1,
    STATE(16141), 1,
      sym_attribute,
    STATE(20763), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711710] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21574), 1,
      anon_sym_SEMI,
    ACTIONS(21576), 1,
      anon_sym_GT_RBRACE,
    STATE(15926), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711730] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19381), 1,
      anon_sym_RBRACE,
    ACTIONS(21578), 1,
      anon_sym_SEMI,
    STATE(16143), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711750] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3647), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21580), 1,
      anon_sym_SEMI,
    STATE(16144), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711770] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18291), 1,
      anon_sym_SEMI,
    ACTIONS(18293), 1,
      anon_sym_GT,
    STATE(16145), 1,
      sym_attribute,
    STATE(16164), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711790] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20025), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21582), 1,
      anon_sym_SEMI,
    STATE(16146), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711810] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19275), 1,
      anon_sym_RBRACE,
    ACTIONS(21584), 1,
      anon_sym_SEMI,
    STATE(16147), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711830] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3741), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21586), 1,
      anon_sym_SEMI,
    STATE(16148), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711850] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21588), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711870] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15613), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16150), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711890] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15644), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16151), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711910] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15655), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16152), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711930] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19269), 1,
      anon_sym_RBRACE,
    ACTIONS(21590), 1,
      anon_sym_SEMI,
    STATE(16153), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711950] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20639), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21592), 1,
      anon_sym_SEMI,
    STATE(16154), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711970] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20641), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [711990] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20272), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21594), 1,
      anon_sym_SEMI,
    STATE(16156), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712010] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16753), 1,
      anon_sym_RBRACK,
    ACTIONS(21596), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16157), 2,
      sym_attribute,
      aux_sym_list_expression_repeat1,
  [712028] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21599), 1,
      anon_sym_RPAREN,
    STATE(16158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712048] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(19), 1,
      sym_attribute_id,
    STATE(16159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712066] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20643), 1,
      anon_sym_RBRACK,
    STATE(16160), 1,
      sym_attribute,
    STATE(16186), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20643), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712106] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3505), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21601), 1,
      anon_sym_SEMI,
    STATE(16162), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712126] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21603), 1,
      anon_sym_SEMI,
    ACTIONS(21605), 1,
      anon_sym_RBRACE,
    STATE(16163), 1,
      sym_attribute,
    STATE(17042), 1,
      aux_sym_record_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712146] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11437), 1,
      anon_sym_GT,
    ACTIONS(21607), 1,
      anon_sym_SEMI,
    STATE(16164), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712166] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21609), 1,
      aux_sym_quoted_extension_token1,
    STATE(16165), 1,
      sym_attribute,
    STATE(20936), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712186] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21611), 1,
      anon_sym_SEMI,
    ACTIONS(21613), 1,
      anon_sym_RBRACE,
    STATE(16166), 1,
      sym_attribute,
    STATE(16192), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712206] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21615), 1,
      anon_sym_SEMI,
    ACTIONS(21617), 1,
      anon_sym_RBRACE,
    STATE(16167), 1,
      sym_attribute,
    STATE(16297), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712226] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21619), 1,
      anon_sym_SEMI,
    ACTIONS(21621), 1,
      anon_sym_GT_RBRACE,
    STATE(16168), 1,
      sym_attribute,
    STATE(16202), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712246] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21623), 1,
      anon_sym_SEMI,
    ACTIONS(21625), 1,
      anon_sym_RBRACE,
    STATE(16169), 1,
      sym_attribute,
    STATE(16177), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712266] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20095), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21627), 1,
      anon_sym_SEMI,
    STATE(16170), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712286] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3509), 1,
      anon_sym_RBRACK,
    ACTIONS(21629), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712306] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21631), 1,
      sym__lowercase_identifier,
    STATE(16172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712326] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21633), 1,
      anon_sym_RPAREN,
    STATE(16173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712346] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21635), 1,
      sym__lowercase_identifier,
    STATE(16174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712366] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20274), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21637), 1,
      anon_sym_SEMI,
    STATE(16175), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712386] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21639), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712406] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19369), 1,
      anon_sym_RBRACE,
    ACTIONS(21641), 1,
      anon_sym_SEMI,
    STATE(16177), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712426] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15297), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16178), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712446] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21643), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712466] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20661), 1,
      anon_sym_RBRACK,
    STATE(16180), 1,
      sym_attribute,
    STATE(17010), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712486] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19399), 1,
      anon_sym_RBRACE,
    ACTIONS(21645), 1,
      anon_sym_SEMI,
    STATE(16181), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712506] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3511), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21647), 1,
      anon_sym_SEMI,
    STATE(16182), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712526] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15320), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16183), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712546] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15331), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16184), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712566] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21649), 1,
      anon_sym_RPAREN,
    STATE(16185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712586] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20655), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712606] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20655), 1,
      anon_sym_RBRACK,
    STATE(16187), 1,
      sym_attribute,
    STATE(16198), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712626] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21651), 1,
      anon_sym_RPAREN,
    STATE(16188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712646] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15826), 1,
      anon_sym_in,
    ACTIONS(21409), 1,
      anon_sym_and,
    STATE(16189), 1,
      sym_attribute,
    STATE(16767), 1,
      aux_sym_module_definition_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712666] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20097), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712686] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(20), 1,
      sym_attribute_id,
    STATE(16191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [712704] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19517), 1,
      anon_sym_RBRACE,
    ACTIONS(21653), 1,
      anon_sym_SEMI,
    STATE(16192), 1,
      sym_attribute,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712724] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21655), 1,
      aux_sym_quoted_extension_token1,
    STATE(16193), 1,
      sym_attribute,
    STATE(19505), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712744] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20661), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712764] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20284), 1,
      anon_sym_RBRACK,
    STATE(16195), 1,
      sym_attribute,
    STATE(16281), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712784] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15755), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16196), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712804] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20284), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712824] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20667), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712844] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21657), 1,
      anon_sym_RPAREN,
    STATE(16199), 1,
      sym_attribute,
    STATE(18696), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712864] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21659), 1,
      anon_sym_SEMI,
    ACTIONS(21661), 1,
      anon_sym_RBRACE,
    STATE(16200), 1,
      sym_attribute,
    STATE(16298), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712884] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11800), 1,
      anon_sym_GT,
    ACTIONS(21663), 1,
      anon_sym_SEMI,
    STATE(16201), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712904] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20099), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21665), 1,
      anon_sym_SEMI,
    STATE(16202), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712924] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18009), 1,
      sym__uppercase_identifier,
    ACTIONS(19724), 1,
      anon_sym_LPAREN,
    STATE(9253), 1,
      sym__constructor_name,
    STATE(16203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712944] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11824), 1,
      anon_sym_GT,
    ACTIONS(21667), 1,
      anon_sym_SEMI,
    STATE(16204), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712964] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21669), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [712984] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15554), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16206), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713004] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3423), 1,
      anon_sym_RBRACK,
    ACTIONS(21671), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713024] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21673), 1,
      sym__lowercase_identifier,
    STATE(16208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713044] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15573), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16209), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713064] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15587), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16210), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713084] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(21), 1,
      sym_attribute_id,
    STATE(16211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713102] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21675), 1,
      aux_sym_quoted_extension_token1,
    STATE(16212), 1,
      sym_attribute,
    STATE(19300), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713122] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21677), 1,
      anon_sym_RPAREN,
    STATE(16213), 1,
      sym_attribute,
    STATE(18833), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713142] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20005), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21679), 1,
      anon_sym_SEMI,
    STATE(16214), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713162] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21681), 1,
      anon_sym_SEMI,
    ACTIONS(21683), 1,
      anon_sym_RBRACE,
    STATE(16215), 1,
      sym_attribute,
    STATE(16525), 1,
      aux_sym_record_declaration_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21685), 1,
      anon_sym_SEMI,
    ACTIONS(21687), 1,
      anon_sym_RBRACE,
    STATE(16216), 1,
      sym_attribute,
    STATE(16750), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21689), 1,
      anon_sym_SEMI,
    ACTIONS(21691), 1,
      anon_sym_RBRACE,
    STATE(16217), 1,
      sym_attribute,
    STATE(16234), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713222] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(29), 1,
      sym_attribute_id,
    STATE(16218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21693), 1,
      anon_sym_SEMI,
    ACTIONS(21696), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16219), 2,
      sym_attribute,
      aux_sym_record_expression_repeat1,
  [713258] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20007), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713278] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21698), 1,
      anon_sym_SEMI,
    ACTIONS(21700), 1,
      anon_sym_RBRACE,
    STATE(16221), 1,
      sym_attribute,
    STATE(16303), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713298] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21702), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713318] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(5), 1,
      sym_attribute_id,
    STATE(16223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713336] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15721), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16224), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713356] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21704), 1,
      anon_sym_SEMI,
    ACTIONS(21706), 1,
      anon_sym_RBRACE,
    STATE(16225), 1,
      sym_attribute,
    STATE(16257), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713376] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15735), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16226), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713396] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15740), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16227), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713416] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21708), 1,
      anon_sym_RPAREN,
    STATE(16228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713436] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12439), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [713452] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21710), 1,
      anon_sym_SEMI,
    ACTIONS(21712), 1,
      anon_sym_RBRACE,
    STATE(16230), 1,
      sym_attribute,
    STATE(16278), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713472] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21714), 1,
      anon_sym_SEMI,
    ACTIONS(21716), 1,
      anon_sym_GT_RBRACE,
    STATE(16231), 1,
      sym_attribute,
    STATE(16256), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713492] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10053), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16232), 1,
      sym_attribute,
    STATE(16477), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713512] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3665), 1,
      anon_sym_RBRACK,
    ACTIONS(21718), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713532] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19533), 1,
      anon_sym_RBRACE,
    ACTIONS(21720), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713552] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(22), 1,
      sym_attribute_id,
    STATE(16235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713570] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8520), 1,
      sym_attribute_id,
    STATE(16236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21722), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713588] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21724), 1,
      anon_sym_SEMI,
    ACTIONS(21726), 1,
      anon_sym_GT_RBRACE,
    STATE(16237), 1,
      sym_attribute,
    STATE(16273), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713608] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21728), 1,
      aux_sym_quoted_extension_token1,
    STATE(16238), 1,
      sym_attribute,
    STATE(21020), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713628] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14006), 1,
      sym__type_equation,
    STATE(16239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21730), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [713646] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21732), 1,
      anon_sym_SEMI,
    ACTIONS(21734), 1,
      anon_sym_RBRACE,
    STATE(16240), 1,
      sym_attribute,
    STATE(16377), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713666] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3667), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21736), 1,
      anon_sym_SEMI,
    STATE(16241), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713686] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20697), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713706] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3215), 1,
      anon_sym_RBRACK,
    ACTIONS(21738), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713726] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21740), 1,
      sym__lowercase_identifier,
    STATE(16244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713746] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21742), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713766] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15209), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16246), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713786] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18327), 1,
      anon_sym_SEMI,
    ACTIONS(18329), 1,
      anon_sym_GT,
    STATE(16247), 1,
      sym_attribute,
    STATE(16490), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713806] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15211), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16248), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713826] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15213), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16249), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713846] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(23), 1,
      sym_attribute_id,
    STATE(16250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [713864] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9952), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16251), 1,
      sym_attribute,
    STATE(16286), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713884] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11692), 1,
      anon_sym_GT,
    ACTIONS(21744), 1,
      anon_sym_SEMI,
    STATE(16252), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713904] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21746), 1,
      aux_sym_quoted_extension_token1,
    STATE(16253), 1,
      sym_attribute,
    STATE(18613), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713924] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20697), 1,
      anon_sym_RBRACK,
    STATE(16254), 1,
      sym_attribute,
    STATE(16344), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713944] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18381), 1,
      anon_sym_SEMI,
    ACTIONS(18383), 1,
      anon_sym_GT,
    STATE(16255), 1,
      sym_attribute,
    STATE(16292), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713964] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20298), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21748), 1,
      anon_sym_SEMI,
    STATE(16256), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [713984] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19485), 1,
      anon_sym_RBRACE,
    ACTIONS(21750), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714004] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21752), 1,
      sym__lowercase_identifier,
    ACTIONS(21754), 1,
      anon_sym_LPAREN,
    STATE(8190), 1,
      sym__simple_value_pattern,
    STATE(16258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714024] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21756), 1,
      anon_sym_SEMI,
    ACTIONS(21758), 1,
      anon_sym_RBRACE,
    STATE(16259), 1,
      sym_attribute,
    STATE(16272), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714044] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21760), 1,
      sym__lowercase_identifier,
    STATE(16260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714064] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19607), 1,
      anon_sym_RBRACE,
    ACTIONS(21762), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714084] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3217), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21764), 1,
      anon_sym_SEMI,
    STATE(16262), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714104] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(16263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12411), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [714120] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13015), 1,
      sym_module_binding,
    STATE(16264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19095), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [714138] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21766), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714158] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21768), 1,
      sym__lowercase_identifier,
    STATE(16266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714178] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15255), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16267), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714198] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21770), 1,
      sym__lowercase_identifier,
    STATE(16268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714218] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15258), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16269), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714238] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15263), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16270), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714258] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(24), 1,
      sym_attribute_id,
    STATE(16271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714276] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19155), 1,
      anon_sym_RBRACE,
    ACTIONS(21772), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714296] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20708), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21774), 1,
      anon_sym_SEMI,
    STATE(16273), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714316] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21776), 1,
      aux_sym_quoted_extension_token1,
    STATE(16274), 1,
      sym_attribute,
    STATE(20848), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714336] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20701), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21778), 1,
      anon_sym_SEMI,
    STATE(16275), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714356] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21780), 1,
      anon_sym_RPAREN,
    STATE(16276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714376] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(21782), 1,
      anon_sym_type,
    STATE(16277), 1,
      sym_attribute,
    STATE(16812), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714396] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19415), 1,
      anon_sym_RBRACE,
    ACTIONS(21784), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714416] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11453), 1,
      anon_sym_STAR,
    ACTIONS(13672), 1,
      anon_sym_DASH_GT,
    STATE(16279), 1,
      sym_attribute,
    STATE(16572), 1,
      aux_sym__constructor_argument_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714436] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21786), 1,
      anon_sym_SEMI,
    ACTIONS(21788), 1,
      anon_sym_RBRACE,
    STATE(16280), 1,
      sym_attribute,
    STATE(16335), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714456] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20302), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714476] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21790), 1,
      anon_sym_RPAREN,
    STATE(16282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714496] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21792), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714516] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20716), 1,
      anon_sym_RBRACK,
    STATE(16284), 1,
      sym_attribute,
    STATE(16311), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714536] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15308), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16285), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714556] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20716), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714576] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20302), 1,
      anon_sym_RBRACK,
    STATE(16287), 1,
      sym_attribute,
    STATE(16332), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714596] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21794), 1,
      anon_sym_RPAREN,
    STATE(16288), 1,
      sym_attribute,
    STATE(20573), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714616] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18299), 1,
      anon_sym_SEMI,
    ACTIONS(18301), 1,
      anon_sym_GT,
    STATE(16201), 1,
      aux_sym_object_type_repeat1,
    STATE(16289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714636] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15316), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16290), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714656] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15319), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16291), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714676] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11465), 1,
      anon_sym_GT,
    ACTIONS(21796), 1,
      anon_sym_SEMI,
    STATE(16292), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714696] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(25), 1,
      sym_attribute_id,
    STATE(16293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714714] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21798), 1,
      anon_sym_SEMI,
    ACTIONS(21800), 1,
      anon_sym_GT_RBRACE,
    STATE(16294), 1,
      sym_attribute,
    STATE(16346), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714734] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21802), 1,
      aux_sym_quoted_extension_token1,
    STATE(16295), 1,
      sym_attribute,
    STATE(18865), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714754] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21804), 1,
      anon_sym_SEMI,
    ACTIONS(21806), 1,
      anon_sym_RBRACE,
    STATE(16296), 1,
      sym_attribute,
    STATE(16316), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714774] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19537), 1,
      anon_sym_RBRACE,
    ACTIONS(21808), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714794] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19589), 1,
      anon_sym_RBRACE,
    ACTIONS(21810), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714814] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11015), 1,
      anon_sym_DOT,
    STATE(16299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21812), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [714832] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21814), 3,
      anon_sym_private,
      anon_sym_virtual,
      sym__lowercase_identifier,
  [714848] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21816), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714868] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15366), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16302), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714888] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19397), 1,
      anon_sym_RBRACE,
    ACTIONS(21818), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714908] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15372), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16304), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714928] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15374), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16305), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714948] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(26), 1,
      sym_attribute_id,
    STATE(16306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [714966] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21820), 1,
      sym__lowercase_identifier,
    STATE(16307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [714986] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21822), 1,
      aux_sym_quoted_extension_token1,
    STATE(16308), 1,
      sym_attribute,
    STATE(20839), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715006] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21824), 1,
      anon_sym_SEMI,
    ACTIONS(21826), 1,
      anon_sym_RBRACE,
    STATE(16309), 1,
      sym_attribute,
    STATE(16358), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715026] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21828), 1,
      anon_sym_RPAREN,
    STATE(16310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715046] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20728), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715066] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20728), 1,
      anon_sym_RBRACK,
    STATE(16312), 1,
      sym_attribute,
    STATE(16322), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3439), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21830), 1,
      anon_sym_SEMI,
    STATE(16313), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715106] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21832), 1,
      anon_sym_SEMI,
    ACTIONS(21834), 1,
      anon_sym_RBRACE,
    STATE(16314), 1,
      sym_attribute,
    STATE(16364), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19764), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [715142] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19565), 1,
      anon_sym_RBRACE,
    ACTIONS(21836), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715162] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21838), 1,
      anon_sym_RPAREN,
    STATE(16317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20740), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21840), 1,
      anon_sym_SEMI,
    ACTIONS(21842), 1,
      anon_sym_RBRACE,
    STATE(16319), 1,
      sym_attribute,
    STATE(17006), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715222] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21844), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715242] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15414), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16321), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715262] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20736), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15417), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16323), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15421), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16324), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715322] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(27), 1,
      sym_attribute_id,
    STATE(16325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [715340] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21846), 1,
      anon_sym_SEMI,
    ACTIONS(21849), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16326), 2,
      sym_attribute,
      aux_sym_record_declaration_repeat1,
  [715358] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3443), 1,
      anon_sym_RBRACK,
    ACTIONS(21851), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715378] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(11427), 1,
      anon_sym_DOT,
    ACTIONS(21853), 1,
      anon_sym_RPAREN,
    STATE(16328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715398] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21855), 1,
      aux_sym_quoted_extension_token1,
    STATE(16329), 1,
      sym_attribute,
    STATE(19068), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715418] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21857), 1,
      sym__lowercase_identifier,
    STATE(16330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715438] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9920), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16331), 1,
      sym_attribute,
    STATE(16373), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715458] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20310), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715478] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18462), 1,
      anon_sym_SEMI,
    ACTIONS(18464), 1,
      anon_sym_GT,
    STATE(16333), 1,
      sym_attribute,
    STATE(16379), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715498] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21859), 1,
      sym__lowercase_identifier,
    STATE(16334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715518] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19193), 1,
      anon_sym_RBRACE,
    ACTIONS(21861), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715538] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21863), 1,
      anon_sym_SEMI,
    ACTIONS(21865), 1,
      anon_sym_RBRACE,
    STATE(16336), 1,
      sym_attribute,
    STATE(16554), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715558] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(21867), 1,
      anon_sym_type,
    STATE(16337), 1,
      sym_attribute,
    STATE(16812), 1,
      sym_module_path,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715578] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15454), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16338), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715598] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3649), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21869), 1,
      anon_sym_SEMI,
    STATE(16339), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715618] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15455), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16340), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715638] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15456), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16341), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715658] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(28), 1,
      sym_attribute_id,
    STATE(16342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [715676] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21871), 1,
      aux_sym_quoted_extension_token1,
    STATE(16343), 1,
      sym_attribute,
    STATE(20208), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715696] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20758), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715716] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20308), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21873), 1,
      anon_sym_SEMI,
    STATE(16345), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715736] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20746), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21875), 1,
      anon_sym_SEMI,
    STATE(16346), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715756] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21877), 1,
      anon_sym_RPAREN,
    STATE(16347), 1,
      sym_attribute,
    STATE(18519), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715776] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15779), 1,
      anon_sym_in,
    ACTIONS(21409), 1,
      anon_sym_and,
    STATE(16077), 1,
      aux_sym_module_definition_repeat1,
    STATE(16348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715796] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7729), 1,
      anon_sym_RBRACK,
    ACTIONS(21879), 1,
      anon_sym_SEMI,
    STATE(16349), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715816] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21439), 1,
      anon_sym_COLON2,
    ACTIONS(21881), 1,
      anon_sym_RPAREN,
    STATE(16350), 1,
      sym_attribute,
    STATE(18983), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715836] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21883), 1,
      anon_sym_RPAREN,
    STATE(16351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715856] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21885), 1,
      anon_sym_RPAREN,
    STATE(16352), 1,
      sym_attribute,
    STATE(19000), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715876] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21887), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715896] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15492), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16354), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715916] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7721), 1,
      anon_sym_RBRACK,
    ACTIONS(21889), 1,
      anon_sym_SEMI,
    STATE(16355), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715936] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15494), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16356), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715956] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15496), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16357), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715976] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18683), 1,
      anon_sym_RBRACE,
    ACTIONS(21891), 1,
      anon_sym_SEMI,
    STATE(16358), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [715996] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(88), 1,
      sym_attribute_id,
    STATE(16359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [716014] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7807), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21893), 1,
      anon_sym_SEMI,
    STATE(16360), 1,
      sym_attribute,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716034] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21895), 1,
      aux_sym_quoted_extension_token1,
    STATE(16361), 1,
      sym_attribute,
    STATE(19044), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716054] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8626), 1,
      anon_sym_RBRACK,
    ACTIONS(21897), 1,
      anon_sym_SEMI,
    STATE(16362), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716074] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3277), 1,
      anon_sym_RBRACK,
    ACTIONS(21899), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716094] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18687), 1,
      anon_sym_RBRACE,
    ACTIONS(21901), 1,
      anon_sym_SEMI,
    STATE(16364), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716114] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16703), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(7156), 1,
      sym__constructor_name,
    STATE(16365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716134] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8630), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21903), 1,
      anon_sym_SEMI,
    STATE(16366), 1,
      sym_attribute,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716154] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20119), 1,
      anon_sym_RBRACK,
    STATE(16367), 1,
      sym_attribute,
    STATE(16805), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716174] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21905), 1,
      anon_sym_SEMI,
    ACTIONS(21907), 1,
      anon_sym_RBRACE,
    STATE(16368), 1,
      sym_attribute,
    STATE(16398), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716194] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21909), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716214] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15535), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16370), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716234] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21911), 1,
      anon_sym_RPAREN,
    STATE(16371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716254] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20760), 1,
      anon_sym_RBRACK,
    STATE(16372), 1,
      sym_attribute,
    STATE(16405), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716274] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20760), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716294] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20119), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716314] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15540), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16375), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716334] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15542), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16376), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716354] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19257), 1,
      anon_sym_RBRACE,
    ACTIONS(21913), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716374] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(30), 1,
      sym_attribute_id,
    STATE(16378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [716392] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11634), 1,
      anon_sym_GT,
    ACTIONS(21915), 1,
      anon_sym_SEMI,
    STATE(16379), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716412] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12506), 1,
      anon_sym_RPAREN,
    STATE(16380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21917), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [716430] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21919), 1,
      aux_sym_quoted_extension_token1,
    STATE(16381), 1,
      sym_attribute,
    STATE(20289), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716450] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18351), 1,
      anon_sym_SEMI,
    ACTIONS(18353), 1,
      anon_sym_GT,
    STATE(16252), 1,
      aux_sym_object_type_repeat1,
    STATE(16382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716470] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20001), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716490] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21921), 1,
      anon_sym_SEMI,
    ACTIONS(21923), 1,
      anon_sym_RBRACE,
    STATE(16384), 1,
      sym_attribute,
    STATE(16416), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716510] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21925), 1,
      anon_sym_SEMI,
    ACTIONS(21927), 1,
      anon_sym_GT_RBRACE,
    STATE(16385), 1,
      sym_attribute,
    STATE(16414), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716530] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21929), 1,
      anon_sym_RBRACK,
    STATE(16386), 1,
      sym_attribute,
    STATE(17024), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716550] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3247), 1,
      anon_sym_RBRACK,
    ACTIONS(21931), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716570] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21933), 1,
      sym__lowercase_identifier,
    STATE(16388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716590] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(21935), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716610] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15586), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16390), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716630] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15591), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16391), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716650] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15594), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16392), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716670] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21439), 1,
      anon_sym_COLON2,
    ACTIONS(21937), 1,
      anon_sym_RPAREN,
    STATE(16393), 1,
      sym_attribute,
    STATE(19833), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716690] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(31), 1,
      sym_attribute_id,
    STATE(16394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [716708] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21939), 1,
      aux_sym_quoted_extension_token1,
    STATE(16395), 1,
      sym_attribute,
    STATE(18525), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716728] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21941), 1,
      anon_sym_RPAREN,
    STATE(16396), 1,
      sym_attribute,
    STATE(19098), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716748] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3237), 1,
      anon_sym_RBRACK,
    ACTIONS(21943), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716768] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19217), 1,
      anon_sym_RBRACE,
    ACTIONS(21945), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716788] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20918), 1,
      anon_sym_RBRACK,
    STATE(16399), 1,
      sym_attribute,
    STATE(17040), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716808] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3239), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21947), 1,
      anon_sym_SEMI,
    STATE(16400), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716828] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12414), 1,
      sym_attribute_id,
    STATE(16401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21949), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [716846] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21951), 1,
      anon_sym_RPAREN,
    STATE(16402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716866] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15629), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16403), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716886] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(21953), 1,
      anon_sym_RPAREN,
    STATE(16404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716906] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20770), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716926] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20770), 1,
      anon_sym_RBRACK,
    STATE(16406), 1,
      sym_attribute,
    STATE(16423), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716946] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15632), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16407), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716966] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15636), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16408), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [716986] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21439), 1,
      anon_sym_COLON2,
    ACTIONS(21955), 1,
      anon_sym_RPAREN,
    STATE(16409), 1,
      sym_attribute,
    STATE(20989), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(32), 1,
      sym_attribute_id,
    STATE(16410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717024] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21957), 1,
      anon_sym_RPAREN,
    STATE(16411), 1,
      sym_attribute,
    STATE(20895), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717044] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21959), 1,
      anon_sym_RPAREN,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(16412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717064] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21961), 1,
      aux_sym_quoted_extension_token1,
    STATE(16413), 1,
      sym_attribute,
    STATE(18995), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717084] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20774), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(21963), 1,
      anon_sym_SEMI,
    STATE(16414), 1,
      sym_attribute,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717104] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21965), 1,
      anon_sym_SEMI,
    ACTIONS(21967), 1,
      anon_sym_RBRACE,
    STATE(16415), 1,
      sym_attribute,
    STATE(16598), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717124] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19345), 1,
      anon_sym_RBRACE,
    ACTIONS(21969), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717144] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(21971), 1,
      anon_sym_RPAREN,
    STATE(16417), 1,
      sym_attribute,
    STATE(21021), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717164] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(33), 1,
      sym_attribute_id,
    STATE(16418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7809), 1,
      anon_sym_RBRACK,
    ACTIONS(21973), 1,
      anon_sym_SEMI,
    STATE(16419), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21975), 1,
      anon_sym_SEMI,
    ACTIONS(21977), 1,
      anon_sym_RBRACE,
    STATE(16420), 1,
      sym_attribute,
    STATE(16431), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717222] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21979), 1,
      aux_sym_quoted_extension_token1,
    STATE(16421), 1,
      sym_attribute,
    STATE(19330), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717242] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7799), 1,
      anon_sym_RBRACK,
    ACTIONS(21981), 1,
      anon_sym_SEMI,
    STATE(16422), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717262] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20784), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18579), 1,
      anon_sym_RBRACE,
    ACTIONS(21983), 1,
      anon_sym_SEMI,
    STATE(16424), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21985), 1,
      anon_sym_SEMI,
    ACTIONS(21987), 1,
      anon_sym_RBRACE,
    STATE(16425), 1,
      sym_attribute,
    STATE(16487), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717322] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7855), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(21989), 1,
      anon_sym_SEMI,
    STATE(16426), 1,
      sym_attribute,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717342] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(2), 1,
      sym_attribute_id,
    STATE(16427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717360] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(21991), 1,
      aux_sym_quoted_extension_token1,
    STATE(16428), 1,
      sym_attribute,
    STATE(19683), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(21993), 1,
      sym__lowercase_identifier,
    STATE(16429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11724), 1,
      anon_sym_GT,
    ACTIONS(21995), 1,
      anon_sym_SEMI,
    STATE(16430), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717420] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19293), 1,
      anon_sym_RBRACE,
    ACTIONS(21997), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717440] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(34), 1,
      sym_attribute_id,
    STATE(16432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717458] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8564), 1,
      anon_sym_RBRACK,
    ACTIONS(21999), 1,
      anon_sym_SEMI,
    STATE(16433), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717478] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22001), 1,
      aux_sym_quoted_extension_token1,
    STATE(16434), 1,
      sym_attribute,
    STATE(20163), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717498] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19429), 1,
      anon_sym_RBRACE,
    ACTIONS(22003), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717518] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22005), 1,
      anon_sym_SEMI,
    ACTIONS(22007), 1,
      anon_sym_RBRACE,
    STATE(16436), 1,
      sym_attribute,
    STATE(17111), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717538] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18587), 1,
      anon_sym_RBRACE,
    ACTIONS(22009), 1,
      anon_sym_SEMI,
    STATE(16437), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717558] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22011), 1,
      aux_sym_quoted_extension_token1,
    STATE(16438), 1,
      sym_attribute,
    STATE(19381), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717578] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(35), 1,
      sym_attribute_id,
    STATE(16439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717596] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22013), 1,
      aux_sym_quoted_extension_token1,
    STATE(16440), 1,
      sym_attribute,
    STATE(20390), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717616] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22015), 1,
      anon_sym_SEMI,
    ACTIONS(22017), 1,
      anon_sym_GT_RBRACE,
    STATE(16441), 1,
      sym_attribute,
    STATE(16513), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717636] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8566), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22019), 1,
      anon_sym_SEMI,
    STATE(16442), 1,
      sym_attribute,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717656] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22021), 1,
      anon_sym_SEMI,
    ACTIONS(22023), 1,
      anon_sym_RBRACE,
    STATE(16443), 1,
      sym_attribute,
    STATE(16483), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717676] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(36), 1,
      sym_attribute_id,
    STATE(16444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717694] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22025), 1,
      anon_sym_SEMI,
    ACTIONS(22027), 1,
      anon_sym_RBRACE,
    STATE(16445), 1,
      sym_attribute,
    STATE(17171), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717714] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19017), 1,
      anon_sym_RBRACE,
    ACTIONS(22029), 1,
      anon_sym_SEMI,
    STATE(16446), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717734] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22031), 1,
      aux_sym_quoted_extension_token1,
    STATE(16447), 1,
      sym_attribute,
    STATE(20811), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717754] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22033), 1,
      anon_sym_SEMI,
    ACTIONS(22035), 1,
      anon_sym_GT_RBRACE,
    STATE(16448), 1,
      sym_attribute,
    STATE(16515), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717774] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22037), 1,
      anon_sym_RPAREN,
    STATE(16449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717794] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22039), 1,
      anon_sym_SEMI,
    ACTIONS(22041), 1,
      anon_sym_RBRACE,
    STATE(16450), 1,
      sym_attribute,
    STATE(17125), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717814] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22043), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(16451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717834] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22045), 1,
      anon_sym_SEMI,
    ACTIONS(22047), 1,
      anon_sym_RBRACE,
    STATE(16452), 1,
      sym_attribute,
    STATE(16533), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717854] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22049), 1,
      anon_sym_SEMI,
    ACTIONS(22051), 1,
      anon_sym_RBRACE,
    STATE(16453), 1,
      sym_attribute,
    STATE(16470), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717874] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7865), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22053), 1,
      anon_sym_SEMI,
    STATE(16454), 1,
      sym_attribute,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717894] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(37), 1,
      sym_attribute_id,
    STATE(16455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [717912] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15780), 1,
      aux_sym_module_binding_repeat1,
    STATE(16456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717932] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22055), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(16457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717952] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22057), 1,
      aux_sym_quoted_extension_token1,
    STATE(16458), 1,
      sym_attribute,
    STATE(21335), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [717972] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12300), 1,
      sym_module_binding,
    STATE(16459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19095), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [717990] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22055), 1,
      anon_sym_RBRACK,
    STATE(16451), 1,
      aux_sym__type_params_repeat1,
    STATE(16460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718010] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14451), 1,
      anon_sym_and,
    STATE(16461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(14449), 2,
      anon_sym_in,
      sym_let_and_operator,
  [718028] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22059), 1,
      anon_sym_SEMI,
    ACTIONS(22061), 1,
      anon_sym_GT_RBRACE,
    STATE(16462), 1,
      sym_attribute,
    STATE(16480), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718048] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(8), 1,
      sym_attribute_id,
    STATE(16463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718066] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(38), 1,
      sym_attribute_id,
    STATE(16464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718084] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22063), 1,
      aux_sym_quoted_extension_token1,
    STATE(16465), 1,
      sym_attribute,
    STATE(19477), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718104] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3755), 1,
      anon_sym_RBRACK,
    ACTIONS(22065), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718124] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22067), 1,
      anon_sym_SEMI,
    ACTIONS(22070), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16467), 2,
      sym_attribute,
      aux_sym_object_copy_expression_repeat1,
  [718142] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3261), 1,
      anon_sym_RBRACK,
    ACTIONS(22072), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718162] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3715), 1,
      anon_sym_RBRACK,
    ACTIONS(22074), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19351), 1,
      anon_sym_RBRACE,
    ACTIONS(22076), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22078), 1,
      anon_sym_RPAREN,
    STATE(16471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718222] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20344), 1,
      anon_sym_RBRACK,
    STATE(16472), 1,
      sym_attribute,
    STATE(16691), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718242] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(6), 1,
      sym_attribute_id,
    STATE(16473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718260] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3263), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22080), 1,
      anon_sym_SEMI,
    STATE(16474), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718280] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(39), 1,
      sym_attribute_id,
    STATE(16475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718298] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9912), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16476), 1,
      sym_attribute,
    STATE(16538), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718318] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20344), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718338] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22082), 1,
      aux_sym_quoted_extension_token1,
    STATE(16478), 1,
      sym_attribute,
    STATE(21409), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718358] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(9), 1,
      sym_attribute_id,
    STATE(16479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718376] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20816), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22084), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718396] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22086), 1,
      anon_sym_SEMI,
    ACTIONS(22088), 1,
      anon_sym_GT_RBRACE,
    STATE(16481), 1,
      sym_attribute,
    STATE(16568), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718416] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18323), 1,
      anon_sym_SEMI,
    ACTIONS(18325), 1,
      anon_sym_GT,
    STATE(16482), 1,
      sym_attribute,
    STATE(16551), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718436] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19467), 1,
      anon_sym_RBRACE,
    ACTIONS(22090), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718456] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22092), 1,
      anon_sym_SEMI,
    ACTIONS(22094), 1,
      anon_sym_RBRACE,
    STATE(16484), 1,
      sym_attribute,
    STATE(16497), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718476] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3257), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22096), 1,
      anon_sym_SEMI,
    STATE(16485), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718496] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(40), 1,
      sym_attribute_id,
    STATE(16486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718514] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19365), 1,
      anon_sym_RBRACE,
    ACTIONS(22098), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718534] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22100), 1,
      aux_sym_quoted_extension_token1,
    STATE(16488), 1,
      sym_attribute,
    STATE(20013), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718554] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3527), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22102), 1,
      anon_sym_SEMI,
    STATE(16489), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718574] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11812), 1,
      anon_sym_GT,
    ACTIONS(22104), 1,
      anon_sym_SEMI,
    STATE(16490), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718594] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22106), 1,
      sym__lowercase_identifier,
    STATE(16491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718614] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22108), 1,
      aux_sym_quoted_extension_token1,
    STATE(16492), 1,
      sym_attribute,
    STATE(18998), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718634] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16438), 1,
      sym_attribute_id,
    STATE(16493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718652] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22112), 1,
      sym__lowercase_identifier,
    STATE(16494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718672] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(41), 1,
      sym_attribute_id,
    STATE(16495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718690] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22114), 1,
      anon_sym_RBRACK,
    STATE(16496), 1,
      sym_attribute,
    STATE(16570), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718710] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19379), 1,
      anon_sym_RBRACE,
    ACTIONS(22116), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718730] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22118), 1,
      aux_sym_quoted_extension_token1,
    STATE(16498), 1,
      sym_attribute,
    STATE(19254), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718750] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3717), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22120), 1,
      anon_sym_SEMI,
    STATE(16499), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20860), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_GT,
  [718786] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22122), 1,
      anon_sym_SEMI,
    ACTIONS(22124), 1,
      anon_sym_RBRACE,
    STATE(16501), 1,
      sym_attribute,
    STATE(16712), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10917), 1,
      sym_attribute_id,
    STATE(16502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22126), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718824] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(42), 1,
      sym_attribute_id,
    STATE(16503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718842] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22128), 1,
      anon_sym_RPAREN,
    STATE(16504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718862] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22130), 1,
      aux_sym_quoted_extension_token1,
    STATE(16505), 1,
      sym_attribute,
    STATE(20899), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718882] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14096), 1,
      sym_attribute_id,
    STATE(16506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22132), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [718900] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3557), 1,
      anon_sym_RBRACK,
    ACTIONS(22134), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718920] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20021), 1,
      anon_sym_RBRACK,
    STATE(16508), 1,
      sym_attribute,
    STATE(16807), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718940] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18659), 1,
      anon_sym_RBRACE,
    ACTIONS(22136), 1,
      anon_sym_SEMI,
    STATE(16509), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718960] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9882), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16510), 1,
      sym_attribute,
    STATE(16678), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [718980] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(16511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12706), 2,
      anon_sym_COLON_GT,
      anon_sym_EQ,
  [718998] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(43), 1,
      sym_attribute_id,
    STATE(16512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719016] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20831), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22138), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719036] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22140), 1,
      aux_sym_quoted_extension_token1,
    STATE(16514), 1,
      sym_attribute,
    STATE(18467), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719056] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20131), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22142), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719076] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(16516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12710), 2,
      anon_sym_COLON_GT,
      anon_sym_EQ,
  [719094] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22144), 1,
      anon_sym_SEMI,
    ACTIONS(22146), 1,
      anon_sym_RBRACE,
    STATE(16517), 1,
      sym_attribute,
    STATE(16555), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719114] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22148), 1,
      sym__lowercase_identifier,
    STATE(16518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719134] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22150), 1,
      sym__lowercase_identifier,
    ACTIONS(22152), 1,
      anon_sym_LPAREN,
    STATE(9072), 1,
      sym__simple_value_pattern,
    STATE(16519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719154] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22154), 1,
      anon_sym_SEMI,
    ACTIONS(22156), 1,
      anon_sym_GT_RBRACE,
    STATE(16520), 1,
      sym_attribute,
    STATE(16774), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719174] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(44), 1,
      sym_attribute_id,
    STATE(16521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719192] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22158), 1,
      aux_sym_quoted_extension_token1,
    STATE(16522), 1,
      sym_attribute,
    STATE(20336), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719212] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3621), 1,
      anon_sym_RBRACK,
    ACTIONS(22160), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719232] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22162), 1,
      anon_sym_RPAREN,
    STATE(16524), 1,
      sym_attribute,
    STATE(19827), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719252] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20837), 1,
      anon_sym_RBRACE,
    ACTIONS(22164), 1,
      anon_sym_SEMI,
    STATE(16326), 1,
      aux_sym_record_declaration_repeat1,
    STATE(16525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719272] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    STATE(16163), 1,
      sym_field_declaration,
    STATE(16526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719292] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(45), 1,
      sym_attribute_id,
    STATE(16527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719310] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18432), 1,
      anon_sym_SEMI,
    ACTIONS(18434), 1,
      anon_sym_GT,
    STATE(16528), 1,
      sym_attribute,
    STATE(16682), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719330] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18009), 1,
      sym__uppercase_identifier,
    ACTIONS(19665), 1,
      anon_sym_LPAREN,
    STATE(9253), 1,
      sym__constructor_name,
    STATE(16529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719350] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22166), 1,
      aux_sym_quoted_extension_token1,
    STATE(16530), 1,
      sym_attribute,
    STATE(19058), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719370] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22168), 1,
      sym__lowercase_identifier,
    STATE(16531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719390] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22170), 1,
      anon_sym_SEMI,
    ACTIONS(22172), 1,
      anon_sym_RBRACE,
    STATE(16532), 1,
      sym_attribute,
    STATE(16556), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719410] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19513), 1,
      anon_sym_RBRACE,
    ACTIONS(22174), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719430] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13108), 1,
      sym_module_binding,
    STATE(16534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19095), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [719448] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22176), 1,
      anon_sym_SEMI,
    ACTIONS(22178), 1,
      anon_sym_RBRACE,
    STATE(16535), 1,
      sym_attribute,
    STATE(16584), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719468] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22180), 1,
      anon_sym_RPAREN,
    STATE(16536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719488] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20849), 1,
      anon_sym_RBRACK,
    STATE(16537), 1,
      sym_attribute,
    STATE(16601), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719508] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20849), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719528] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(46), 1,
      sym_attribute_id,
    STATE(16539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719546] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22182), 1,
      anon_sym_EQ,
    STATE(16540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22184), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [719564] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22186), 1,
      aux_sym_quoted_extension_token1,
    STATE(16541), 1,
      sym_attribute,
    STATE(19886), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719584] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22188), 1,
      anon_sym_SEMI,
    ACTIONS(22190), 1,
      anon_sym_GT_RBRACE,
    STATE(16542), 1,
      sym_attribute,
    STATE(16566), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719604] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15888), 1,
      aux_sym_module_binding_repeat1,
    STATE(16543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719624] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22192), 1,
      anon_sym_SEMI,
    ACTIONS(22194), 1,
      anon_sym_GT_RBRACE,
    STATE(16544), 1,
      sym_attribute,
    STATE(16597), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719644] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22196), 1,
      anon_sym_EQ,
    STATE(16545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22198), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [719662] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(47), 1,
      sym_attribute_id,
    STATE(16546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719680] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8558), 1,
      anon_sym_RBRACK,
    ACTIONS(22200), 1,
      anon_sym_SEMI,
    STATE(16547), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719700] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16548), 1,
      sym_attribute,
    STATE(16674), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19205), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [719718] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22202), 1,
      aux_sym_quoted_extension_token1,
    STATE(16549), 1,
      sym_attribute,
    STATE(21087), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719738] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3559), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22204), 1,
      anon_sym_SEMI,
    STATE(16550), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719758] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11748), 1,
      anon_sym_GT,
    ACTIONS(22206), 1,
      anon_sym_SEMI,
    STATE(16551), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719778] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3283), 1,
      anon_sym_RBRACK,
    ACTIONS(22208), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719798] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9896), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16092), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719818] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19079), 1,
      anon_sym_RBRACE,
    ACTIONS(22210), 1,
      anon_sym_SEMI,
    STATE(16554), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719838] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19507), 1,
      anon_sym_RBRACE,
    ACTIONS(22212), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719858] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19433), 1,
      anon_sym_RBRACE,
    ACTIONS(22214), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719878] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(48), 1,
      sym_attribute_id,
    STATE(16557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [719896] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22216), 1,
      anon_sym_SEMI,
    ACTIONS(22218), 1,
      anon_sym_RBRACE,
    STATE(16558), 1,
      sym_attribute,
    STATE(16676), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719916] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22220), 1,
      anon_sym_SEMI,
    ACTIONS(22222), 1,
      anon_sym_RBRACE,
    STATE(16559), 1,
      sym_attribute,
    STATE(16688), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719936] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20021), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719956] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22224), 1,
      aux_sym_quoted_extension_token1,
    STATE(16561), 1,
      sym_attribute,
    STATE(18657), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719976] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3455), 1,
      anon_sym_RBRACK,
    ACTIONS(22226), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [719996] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3285), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22228), 1,
      anon_sym_SEMI,
    STATE(16563), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720016] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22230), 1,
      anon_sym_SEMI,
    ACTIONS(22232), 1,
      anon_sym_RBRACE,
    STATE(16564), 1,
      sym_attribute,
    STATE(16698), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720036] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(22234), 1,
      anon_sym_type,
    STATE(16299), 1,
      sym_module_path,
    STATE(16565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720056] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20862), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22236), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720076] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22238), 1,
      anon_sym_SEMI,
    ACTIONS(22240), 1,
      anon_sym_RBRACE,
    STATE(16509), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720096] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20360), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22242), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720116] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(49), 1,
      sym_attribute_id,
    STATE(16569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720134] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22244), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(16570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720154] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22246), 1,
      aux_sym_quoted_extension_token1,
    STATE(16571), 1,
      sym_attribute,
    STATE(18947), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720174] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12211), 1,
      anon_sym_DASH_GT,
    ACTIONS(22248), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16572), 2,
      sym_attribute,
      aux_sym__constructor_argument_repeat1,
  [720192] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22251), 1,
      anon_sym_SEMI,
    ACTIONS(22253), 1,
      anon_sym_RBRACE,
    STATE(16573), 1,
      sym_attribute,
    STATE(16587), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720212] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22255), 1,
      sym__lowercase_identifier,
    STATE(16574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720232] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3459), 1,
      anon_sym_RBRACK,
    ACTIONS(22257), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720252] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22244), 1,
      anon_sym_RBRACK,
    STATE(16576), 1,
      sym_attribute,
    STATE(16711), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720272] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9900), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16577), 1,
      sym_attribute,
    STATE(16709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720292] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22259), 1,
      anon_sym_SEMI,
    ACTIONS(22261), 1,
      anon_sym_RBRACE,
    STATE(15956), 1,
      aux_sym_record_expression_repeat1,
    STATE(16578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720312] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(50), 1,
      sym_attribute_id,
    STATE(16579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720330] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22263), 1,
      aux_sym_quoted_extension_token1,
    STATE(16580), 1,
      sym_attribute,
    STATE(19374), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720350] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18375), 1,
      anon_sym_SEMI,
    ACTIONS(18377), 1,
      anon_sym_GT,
    STATE(16581), 1,
      sym_attribute,
    STATE(16714), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720370] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22265), 1,
      anon_sym_RPAREN,
    STATE(16582), 1,
      sym_attribute,
    STATE(21221), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720390] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22267), 1,
      sym__lowercase_identifier,
    STATE(16583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720410] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19259), 1,
      anon_sym_RBRACE,
    ACTIONS(22269), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720430] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3619), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22271), 1,
      anon_sym_SEMI,
    STATE(16585), 1,
      sym_attribute,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(51), 1,
      sym_attribute_id,
    STATE(16586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720468] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19475), 1,
      anon_sym_RBRACE,
    ACTIONS(22273), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720488] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22275), 1,
      aux_sym_quoted_extension_token1,
    STATE(16588), 1,
      sym_attribute,
    STATE(19717), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720508] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22277), 1,
      anon_sym_RPAREN,
    STATE(16589), 1,
      sym_attribute,
    STATE(20128), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720528] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(52), 1,
      sym_attribute_id,
    STATE(16590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720546] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22279), 1,
      aux_sym_quoted_extension_token1,
    STATE(16591), 1,
      sym_attribute,
    STATE(19903), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720566] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(53), 1,
      sym_attribute_id,
    STATE(16592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720584] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22281), 1,
      anon_sym_RPAREN,
    STATE(16593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720604] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22283), 1,
      aux_sym_quoted_extension_token1,
    STATE(16594), 1,
      sym_attribute,
    STATE(20006), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720624] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8560), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22285), 1,
      anon_sym_SEMI,
    STATE(16595), 1,
      sym_attribute,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720644] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(54), 1,
      sym_attribute_id,
    STATE(16596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720662] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20876), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22287), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720682] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19209), 1,
      anon_sym_RBRACE,
    ACTIONS(22289), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720702] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22291), 1,
      aux_sym_quoted_extension_token1,
    STATE(16599), 1,
      sym_attribute,
    STATE(20029), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720722] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(55), 1,
      sym_attribute_id,
    STATE(16600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720740] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20878), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720760] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22293), 1,
      aux_sym_quoted_extension_token1,
    STATE(16602), 1,
      sym_attribute,
    STATE(20051), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720780] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(56), 1,
      sym_attribute_id,
    STATE(16603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720798] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22295), 1,
      aux_sym_quoted_extension_token1,
    STATE(16604), 1,
      sym_attribute,
    STATE(20079), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720818] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(57), 1,
      sym_attribute_id,
    STATE(16605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720836] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20878), 1,
      anon_sym_RBRACK,
    STATE(16606), 1,
      sym_attribute,
    STATE(16702), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720856] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22297), 1,
      aux_sym_quoted_extension_token1,
    STATE(16607), 1,
      sym_attribute,
    STATE(20114), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720876] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(58), 1,
      sym_attribute_id,
    STATE(16608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720894] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22299), 1,
      aux_sym_quoted_extension_token1,
    STATE(16609), 1,
      sym_attribute,
    STATE(20150), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720914] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(59), 1,
      sym_attribute_id,
    STATE(16610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720932] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22301), 1,
      aux_sym_quoted_extension_token1,
    STATE(16611), 1,
      sym_attribute,
    STATE(20184), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720952] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(60), 1,
      sym_attribute_id,
    STATE(16612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [720970] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9898), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16374), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [720990] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22303), 1,
      aux_sym_quoted_extension_token1,
    STATE(16614), 1,
      sym_attribute,
    STATE(20231), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721010] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(61), 1,
      sym_attribute_id,
    STATE(16615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721028] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22305), 1,
      anon_sym_RPAREN,
    STATE(16616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721048] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22307), 1,
      aux_sym_quoted_extension_token1,
    STATE(16617), 1,
      sym_attribute,
    STATE(20280), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721068] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(62), 1,
      sym_attribute_id,
    STATE(16618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22309), 1,
      anon_sym_SEMI,
    ACTIONS(22311), 1,
      anon_sym_RBRACE,
    STATE(16619), 1,
      sym_attribute,
    STATE(16786), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721106] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22313), 1,
      aux_sym_quoted_extension_token1,
    STATE(16620), 1,
      sym_attribute,
    STATE(20339), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721126] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(63), 1,
      sym_attribute_id,
    STATE(16621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721144] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22315), 1,
      aux_sym_quoted_extension_token1,
    STATE(16622), 1,
      sym_attribute,
    STATE(20373), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721164] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(64), 1,
      sym_attribute_id,
    STATE(16623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20366), 1,
      anon_sym_RBRACK,
    STATE(16624), 1,
      sym_attribute,
    STATE(16725), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721202] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22317), 1,
      aux_sym_quoted_extension_token1,
    STATE(16625), 1,
      sym_attribute,
    STATE(20426), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721222] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(65), 1,
      sym_attribute_id,
    STATE(16626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721240] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22319), 1,
      aux_sym_quoted_extension_token1,
    STATE(16627), 1,
      sym_attribute,
    STATE(20467), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721260] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(66), 1,
      sym_attribute_id,
    STATE(16628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721278] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22321), 1,
      aux_sym_quoted_extension_token1,
    STATE(16629), 1,
      sym_attribute,
    STATE(20483), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721298] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22323), 1,
      sym__lowercase_identifier,
    STATE(16630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721318] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22325), 1,
      aux_sym_quoted_extension_token1,
    STATE(16631), 1,
      sym_attribute,
    STATE(20503), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721338] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(68), 1,
      sym_attribute_id,
    STATE(16632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721356] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22327), 1,
      aux_sym_quoted_extension_token1,
    STATE(16633), 1,
      sym_attribute,
    STATE(20513), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721376] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(69), 1,
      sym_attribute_id,
    STATE(16634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721394] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22329), 1,
      aux_sym_quoted_extension_token1,
    STATE(16635), 1,
      sym_attribute,
    STATE(20530), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721414] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(70), 1,
      sym_attribute_id,
    STATE(16636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721432] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22331), 1,
      aux_sym_quoted_extension_token1,
    STATE(16637), 1,
      sym_attribute,
    STATE(20546), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721452] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(71), 1,
      sym_attribute_id,
    STATE(16638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721470] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22333), 1,
      aux_sym_quoted_extension_token1,
    STATE(16639), 1,
      sym_attribute,
    STATE(20555), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721490] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(72), 1,
      sym_attribute_id,
    STATE(16640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721508] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22335), 1,
      aux_sym_quoted_extension_token1,
    STATE(16641), 1,
      sym_attribute,
    STATE(20565), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721528] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(73), 1,
      sym_attribute_id,
    STATE(16642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721546] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22337), 1,
      aux_sym_quoted_extension_token1,
    STATE(16643), 1,
      sym_attribute,
    STATE(20572), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721566] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(74), 1,
      sym_attribute_id,
    STATE(16644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721584] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22339), 1,
      aux_sym_quoted_extension_token1,
    STATE(16645), 1,
      sym_attribute,
    STATE(20584), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721604] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(75), 1,
      sym_attribute_id,
    STATE(16646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721622] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22341), 1,
      aux_sym_quoted_extension_token1,
    STATE(16647), 1,
      sym_attribute,
    STATE(20596), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721642] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(76), 1,
      sym_attribute_id,
    STATE(16648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721660] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22343), 1,
      aux_sym_quoted_extension_token1,
    STATE(16649), 1,
      sym_attribute,
    STATE(20606), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721680] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(77), 1,
      sym_attribute_id,
    STATE(16650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721698] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22345), 1,
      aux_sym_quoted_extension_token1,
    STATE(16651), 1,
      sym_attribute,
    STATE(20619), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721718] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(78), 1,
      sym_attribute_id,
    STATE(16652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721736] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22347), 1,
      aux_sym_quoted_extension_token1,
    STATE(16653), 1,
      sym_attribute,
    STATE(20631), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(79), 1,
      sym_attribute_id,
    STATE(16654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721774] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22349), 1,
      aux_sym_quoted_extension_token1,
    STATE(16655), 1,
      sym_attribute,
    STATE(20647), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721794] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(80), 1,
      sym_attribute_id,
    STATE(16656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721812] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22351), 1,
      aux_sym_quoted_extension_token1,
    STATE(16657), 1,
      sym_attribute,
    STATE(20655), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721832] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(81), 1,
      sym_attribute_id,
    STATE(16658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721850] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22353), 1,
      aux_sym_quoted_extension_token1,
    STATE(16659), 1,
      sym_attribute,
    STATE(20667), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721870] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(82), 1,
      sym_attribute_id,
    STATE(16660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721888] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22355), 1,
      aux_sym_quoted_extension_token1,
    STATE(16661), 1,
      sym_attribute,
    STATE(20675), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721908] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(83), 1,
      sym_attribute_id,
    STATE(16662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721926] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22357), 1,
      aux_sym_quoted_extension_token1,
    STATE(16663), 1,
      sym_attribute,
    STATE(20687), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721946] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(84), 1,
      sym_attribute_id,
    STATE(16664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [721964] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22359), 1,
      aux_sym_quoted_extension_token1,
    STATE(16665), 1,
      sym_attribute,
    STATE(20693), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [721984] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(85), 1,
      sym_attribute_id,
    STATE(16666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722002] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22361), 1,
      aux_sym_quoted_extension_token1,
    STATE(16667), 1,
      sym_attribute,
    STATE(20703), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722022] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(86), 1,
      sym_attribute_id,
    STATE(16668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722040] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22363), 1,
      aux_sym_quoted_extension_token1,
    STATE(16669), 1,
      sym_attribute,
    STATE(20717), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722060] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(87), 1,
      sym_attribute_id,
    STATE(16670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722078] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22365), 1,
      aux_sym_quoted_extension_token1,
    STATE(16671), 1,
      sym_attribute,
    STATE(20723), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722098] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(3), 1,
      sym_attribute_id,
    STATE(16672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722116] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22367), 1,
      aux_sym_quoted_extension_token1,
    STATE(16673), 1,
      sym_attribute,
    STATE(20734), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722136] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15450), 1,
      anon_sym_in,
    ACTIONS(21409), 1,
      anon_sym_and,
    STATE(16040), 1,
      aux_sym_module_definition_repeat1,
    STATE(16674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722156] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15874), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16675), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722176] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19405), 1,
      anon_sym_RBRACE,
    ACTIONS(22369), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722196] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22371), 1,
      anon_sym_SEMI,
    ACTIONS(22373), 1,
      anon_sym_RBRACE,
    STATE(16677), 1,
      sym_attribute,
    STATE(16842), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722216] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20366), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722236] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16492), 1,
      sym_attribute_id,
    STATE(16679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722254] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22375), 1,
      sym__lowercase_identifier,
    STATE(16680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722274] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11272), 1,
      sym_attribute_id,
    STATE(16681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22377), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [722292] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11840), 1,
      anon_sym_GT,
    ACTIONS(22379), 1,
      anon_sym_SEMI,
    STATE(16682), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722312] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22381), 1,
      anon_sym_RPAREN,
    STATE(16683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722332] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21439), 1,
      anon_sym_COLON2,
    ACTIONS(22383), 1,
      anon_sym_RPAREN,
    STATE(16684), 1,
      sym_attribute,
    STATE(20199), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722352] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22385), 1,
      anon_sym_SEMI,
    ACTIONS(22387), 1,
      anon_sym_RBRACE,
    STATE(16685), 1,
      sym_attribute,
    STATE(16753), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722372] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22389), 1,
      anon_sym_RPAREN,
    STATE(16686), 1,
      sym_attribute,
    STATE(20204), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722392] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7877), 1,
      anon_sym_RBRACK,
    ACTIONS(22391), 1,
      anon_sym_SEMI,
    STATE(16687), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722412] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18937), 1,
      anon_sym_RBRACE,
    ACTIONS(22393), 1,
      anon_sym_SEMI,
    STATE(16688), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722432] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12300), 1,
      sym_module_binding,
    STATE(16689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19111), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [722450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12879), 1,
      sym_module_binding,
    STATE(16690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19111), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [722468] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20370), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722488] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20370), 1,
      anon_sym_RBRACK,
    STATE(16692), 1,
      sym_attribute,
    STATE(16746), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722508] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10783), 1,
      sym__type_equation,
    STATE(16693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22395), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [722526] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7897), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22397), 1,
      anon_sym_SEMI,
    STATE(16694), 1,
      sym_attribute,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722546] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22399), 1,
      anon_sym_SEMI,
    ACTIONS(22401), 1,
      anon_sym_RBRACE,
    STATE(16695), 1,
      sym_attribute,
    STATE(16716), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722566] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8644), 1,
      anon_sym_RBRACK,
    ACTIONS(22403), 1,
      anon_sym_SEMI,
    STATE(16696), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722586] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22405), 1,
      anon_sym_LPAREN,
    ACTIONS(22407), 1,
      anon_sym_LBRACK,
    ACTIONS(22409), 1,
      anon_sym_LBRACE,
    STATE(16697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722606] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18947), 1,
      anon_sym_RBRACE,
    ACTIONS(22411), 1,
      anon_sym_SEMI,
    STATE(16698), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722626] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22413), 1,
      anon_sym_SEMI,
    ACTIONS(22415), 1,
      anon_sym_GT_RBRACE,
    STATE(16699), 1,
      sym_attribute,
    STATE(16874), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722646] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8646), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22417), 1,
      anon_sym_SEMI,
    STATE(16700), 1,
      sym_attribute,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722666] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22419), 1,
      anon_sym_SEMI,
    ACTIONS(22421), 1,
      anon_sym_RBRACE,
    STATE(16701), 1,
      sym_attribute,
    STATE(16720), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722686] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20904), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722706] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22423), 1,
      anon_sym_SEMI,
    ACTIONS(22425), 1,
      anon_sym_GT_RBRACE,
    STATE(16703), 1,
      sym_attribute,
    STATE(16751), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722726] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14279), 1,
      sym__type_equation,
    STATE(16704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22427), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [722744] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3545), 1,
      anon_sym_RBRACK,
    ACTIONS(22429), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722764] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22431), 1,
      anon_sym_SEMI,
    ACTIONS(22433), 1,
      anon_sym_GT_RBRACE,
    STATE(16706), 1,
      sym_attribute,
    STATE(16732), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722784] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22435), 1,
      anon_sym_RPAREN,
    STATE(16707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722804] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20908), 1,
      anon_sym_RBRACK,
    STATE(16708), 1,
      sym_attribute,
    STATE(16737), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722824] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20908), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722844] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22437), 1,
      anon_sym_LPAREN,
    ACTIONS(22439), 1,
      anon_sym_LBRACK,
    ACTIONS(22441), 1,
      anon_sym_LBRACE,
    STATE(16710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722864] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22443), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(16711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722884] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19417), 1,
      anon_sym_RBRACE,
    ACTIONS(22445), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722904] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20906), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22447), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722924] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11658), 1,
      anon_sym_GT,
    ACTIONS(22449), 1,
      anon_sym_SEMI,
    STATE(16714), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722944] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22451), 1,
      anon_sym_SEMI,
    ACTIONS(22453), 1,
      anon_sym_RBRACE,
    STATE(16715), 1,
      sym_attribute,
    STATE(16752), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722964] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19563), 1,
      anon_sym_RBRACE,
    ACTIONS(22455), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [722984] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22457), 1,
      sym__lowercase_identifier,
    STATE(16717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723004] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22459), 1,
      anon_sym_RPAREN,
    STATE(16718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723024] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3303), 1,
      anon_sym_RBRACK,
    ACTIONS(22461), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723044] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19599), 1,
      anon_sym_RBRACE,
    ACTIONS(22463), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723064] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16753), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22465), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16721), 2,
      sym_attribute,
      aux_sym_list_expression_repeat1,
  [723082] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(22468), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723102] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3305), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22470), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723122] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15512), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16724), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723142] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20378), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723162] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22472), 1,
      sym__lowercase_identifier,
    STATE(16726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20378), 1,
      anon_sym_RBRACK,
    STATE(16727), 1,
      sym_attribute,
    STATE(16762), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3547), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22474), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723222] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7797), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22476), 1,
      anon_sym_SEMI,
    STATE(16729), 1,
      sym_attribute,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723242] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22478), 1,
      anon_sym_RPAREN,
    STATE(16730), 1,
      sym_attribute,
    STATE(20283), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723262] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22480), 1,
      anon_sym_RPAREN,
    STATE(16731), 1,
      sym_attribute,
    STATE(20709), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20922), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22482), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723302] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(4), 1,
      sym_attribute_id,
    STATE(16733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723320] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3457), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22484), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723340] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22486), 1,
      anon_sym_RPAREN,
    STATE(16735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723360] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22488), 1,
      anon_sym_SEMI,
    ACTIONS(22490), 1,
      anon_sym_RBRACE,
    STATE(16736), 1,
      sym_attribute,
    STATE(16748), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20926), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20926), 1,
      anon_sym_RBRACK,
    STATE(16738), 1,
      sym_attribute,
    STATE(16758), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723420] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(14280), 1,
      sym__type_equation,
    STATE(16739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22427), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [723438] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(22492), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723458] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15751), 1,
      aux_sym_module_binding_repeat1,
    STATE(16741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723478] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19391), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22494), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16742), 2,
      sym_attribute,
      aux_sym_list_pattern_repeat1,
  [723496] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19401), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22497), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16743), 2,
      sym_attribute,
      aux_sym_list_binding_pattern_repeat1,
  [723514] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19625), 1,
      sym__lowercase_identifier,
    STATE(16042), 1,
      sym__instance_variable_name,
    STATE(16744), 1,
      sym_attribute,
    STATE(17864), 1,
      sym_instance_variable_expression,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723534] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15557), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16745), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723554] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20382), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723574] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22500), 1,
      sym__lowercase_identifier,
    STATE(16747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723594] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19619), 1,
      anon_sym_RBRACE,
    ACTIONS(22502), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723614] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16749), 1,
      sym_attribute,
    STATE(17113), 1,
      sym_attribute_id,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [723632] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19175), 1,
      anon_sym_RBRACE,
    ACTIONS(22504), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723652] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20151), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22506), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723672] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19361), 1,
      anon_sym_RBRACE,
    ACTIONS(22508), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723692] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19573), 1,
      anon_sym_RBRACE,
    ACTIONS(22510), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723712] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22512), 1,
      anon_sym_LPAREN,
    ACTIONS(22514), 1,
      anon_sym_LBRACK,
    ACTIONS(22516), 1,
      anon_sym_LBRACE,
    STATE(16754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723732] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3607), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22518), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723752] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22522), 1,
      anon_sym_LBRACK,
    STATE(16756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22520), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [723770] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22524), 1,
      anon_sym_LPAREN,
    ACTIONS(22526), 1,
      anon_sym_LBRACK,
    ACTIONS(22528), 1,
      anon_sym_LBRACE,
    STATE(16757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723790] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20934), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723810] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15578), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(16759), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723830] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18399), 1,
      anon_sym_SEMI,
    ACTIONS(18401), 1,
      anon_sym_GT,
    STATE(16129), 1,
      aux_sym_object_type_repeat1,
    STATE(16760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723850] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16761), 1,
      sym_attribute,
    STATE(17455), 1,
      sym_module_binding,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19205), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [723868] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20384), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723888] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3415), 1,
      anon_sym_RBRACK,
    ACTIONS(22530), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723908] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20001), 1,
      anon_sym_RBRACK,
    STATE(16220), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723928] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22532), 1,
      anon_sym_LPAREN,
    ACTIONS(22534), 1,
      anon_sym_LBRACK,
    ACTIONS(22536), 1,
      anon_sym_LBRACE,
    STATE(16765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723948] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22538), 1,
      anon_sym_SEMI,
    ACTIONS(22540), 1,
      anon_sym_RBRACE,
    STATE(16766), 1,
      sym_attribute,
    STATE(16777), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723968] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15450), 1,
      anon_sym_in,
    ACTIONS(21409), 1,
      anon_sym_and,
    STATE(16077), 1,
      aux_sym_module_definition_repeat1,
    STATE(16767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [723988] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16078), 1,
      sym_module_binding,
    STATE(16768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19205), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [724006] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10003), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16769), 1,
      sym_attribute,
    STATE(17000), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724026] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19231), 1,
      anon_sym_RBRACE,
    ACTIONS(22542), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724046] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(22544), 1,
      aux_sym_quoted_extension_token1,
    STATE(16771), 1,
      sym_attribute,
    STATE(18453), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724066] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22546), 1,
      anon_sym_SEMI,
    ACTIONS(22548), 1,
      anon_sym_RBRACE,
    STATE(16772), 1,
      sym_attribute,
    STATE(16793), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724086] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(15942), 1,
      sym_attribute_id,
    STATE(16773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724104] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20055), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22550), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724124] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22552), 1,
      sym__lowercase_identifier,
    STATE(16775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724144] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22554), 1,
      anon_sym_RPAREN,
    STATE(16776), 1,
      sym_attribute,
    STATE(19792), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724164] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19583), 1,
      anon_sym_RBRACE,
    ACTIONS(22556), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724184] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18315), 1,
      anon_sym_SEMI,
    ACTIONS(18317), 1,
      anon_sym_GT,
    STATE(16778), 1,
      sym_attribute,
    STATE(17023), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724204] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22558), 1,
      anon_sym_RPAREN,
    STATE(16779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724224] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22560), 1,
      anon_sym_RPAREN,
    STATE(16780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724244] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3565), 1,
      anon_sym_RBRACK,
    ACTIONS(22562), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724264] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22564), 1,
      anon_sym_LPAREN,
    ACTIONS(22566), 1,
      anon_sym_LBRACK,
    ACTIONS(22568), 1,
      anon_sym_LBRACE,
    STATE(16782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724284] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22570), 1,
      anon_sym_RPAREN,
    STATE(16783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22572), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [724302] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16771), 1,
      sym_attribute_id,
    STATE(16784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724320] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22574), 1,
      anon_sym_SEMI,
    ACTIONS(22576), 1,
      anon_sym_GT_RBRACE,
    STATE(16785), 1,
      sym_attribute,
    STATE(16801), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724340] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19239), 1,
      anon_sym_RBRACE,
    ACTIONS(22578), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724360] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22580), 1,
      anon_sym_LPAREN,
    ACTIONS(22582), 1,
      anon_sym_LBRACK,
    ACTIONS(22584), 1,
      anon_sym_LBRACE,
    STATE(16787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    STATE(16788), 1,
      sym_attribute,
    STATE(18307), 1,
      sym_field_declaration,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22586), 1,
      anon_sym_RPAREN,
    STATE(16789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724420] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3321), 1,
      anon_sym_RBRACK,
    ACTIONS(22588), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724440] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22590), 1,
      anon_sym_RPAREN,
    STATE(16791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724460] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10670), 1,
      sym__type_equation,
    STATE(16792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22395), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [724478] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19465), 1,
      anon_sym_RBRACE,
    ACTIONS(22592), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724498] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(22594), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(16794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724518] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22596), 1,
      anon_sym_RPAREN,
    STATE(16795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724538] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3323), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22598), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724558] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(22600), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724578] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7793), 1,
      anon_sym_RBRACK,
    ACTIONS(22602), 1,
      anon_sym_SEMI,
    STATE(16798), 1,
      sym_attribute,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724598] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22604), 1,
      anon_sym_SEMI,
    ACTIONS(22606), 1,
      anon_sym_RBRACE,
    STATE(16799), 1,
      sym_attribute,
    STATE(16958), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724618] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20404), 1,
      anon_sym_RBRACK,
    STATE(15976), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724638] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20950), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22608), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724658] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22610), 1,
      anon_sym_SEMI,
    ACTIONS(22612), 1,
      anon_sym_RBRACE,
    STATE(16802), 1,
      sym_attribute,
    STATE(16815), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724678] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16003), 1,
      sym_attribute_id,
    STATE(16803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724696] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20404), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724716] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20173), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724736] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22614), 1,
      anon_sym_LPAREN,
    ACTIONS(22616), 1,
      anon_sym_LBRACK,
    ACTIONS(22618), 1,
      anon_sym_LBRACE,
    STATE(16806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724756] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20425), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724776] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(22620), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724796] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22622), 1,
      anon_sym_SEMI,
    ACTIONS(22624), 1,
      anon_sym_GT_RBRACE,
    STATE(15944), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724816] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22626), 1,
      anon_sym_LPAREN,
    ACTIONS(22628), 1,
      anon_sym_LBRACK,
    ACTIONS(22630), 1,
      anon_sym_LBRACE,
    STATE(16810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724836] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22632), 1,
      sym__lowercase_identifier,
    STATE(16811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724856] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11015), 1,
      anon_sym_DOT,
    STATE(16812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22634), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [724874] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16053), 1,
      sym_attribute_id,
    STATE(16813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [724892] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22636), 1,
      anon_sym_SEMI,
    ACTIONS(22638), 1,
      anon_sym_GT_RBRACE,
    STATE(16713), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724912] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19571), 1,
      anon_sym_RBRACE,
    ACTIONS(22640), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724932] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21439), 1,
      anon_sym_COLON2,
    ACTIONS(22642), 1,
      anon_sym_RPAREN,
    STATE(16816), 1,
      sym_attribute,
    STATE(20452), 1,
      sym__class_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724952] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22644), 1,
      anon_sym_SEMI,
    ACTIONS(22646), 1,
      anon_sym_RBRACE,
    STATE(16817), 1,
      sym_attribute,
    STATE(16879), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724972] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22648), 1,
      sym__lowercase_identifier,
    ACTIONS(22650), 1,
      anon_sym_LPAREN,
    STATE(10772), 1,
      sym__simple_value_pattern,
    STATE(16818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [724992] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22652), 1,
      anon_sym_LPAREN,
    ACTIONS(22654), 1,
      anon_sym_LBRACK,
    ACTIONS(22656), 1,
      anon_sym_LBRACE,
    STATE(16819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725012] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11738), 1,
      sym_attribute_id,
    STATE(16820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22658), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725030] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22660), 1,
      anon_sym_LPAREN,
    ACTIONS(22662), 1,
      anon_sym_LBRACK,
    ACTIONS(22664), 1,
      anon_sym_LBRACE,
    STATE(16821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725050] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16094), 1,
      sym_attribute_id,
    STATE(16822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725068] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3417), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22666), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725088] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11642), 1,
      anon_sym_GT,
    ACTIONS(22668), 1,
      anon_sym_SEMI,
    STATE(16824), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725108] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(7), 1,
      sym_attribute_id,
    STATE(16825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725126] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22670), 1,
      anon_sym_LPAREN,
    ACTIONS(22672), 1,
      anon_sym_LBRACK,
    ACTIONS(22674), 1,
      anon_sym_LBRACE,
    STATE(16826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725146] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22676), 1,
      anon_sym_RPAREN,
    STATE(16827), 1,
      sym_attribute,
    STATE(18692), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725166] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22678), 1,
      anon_sym_LPAREN,
    ACTIONS(22680), 1,
      anon_sym_LBRACK,
    ACTIONS(22682), 1,
      anon_sym_LBRACE,
    STATE(16828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725186] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16118), 1,
      sym_attribute_id,
    STATE(16829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725204] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20173), 1,
      anon_sym_RBRACK,
    STATE(15959), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725224] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22684), 1,
      anon_sym_LPAREN,
    ACTIONS(22686), 1,
      anon_sym_LBRACK,
    ACTIONS(22688), 1,
      anon_sym_LBRACE,
    STATE(16831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725244] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22690), 1,
      anon_sym_LPAREN,
    ACTIONS(22692), 1,
      anon_sym_LBRACK,
    ACTIONS(22694), 1,
      anon_sym_LBRACE,
    STATE(16832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725264] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16141), 1,
      sym_attribute_id,
    STATE(16833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22696), 1,
      anon_sym_SEMI,
    ACTIONS(22698), 1,
      anon_sym_RBRACE,
    STATE(16834), 1,
      sym_attribute,
    STATE(16887), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12365), 1,
      anon_sym_DQUOTE,
    STATE(10422), 1,
      aux_sym_external_repeat1,
    STATE(11648), 1,
      sym_string,
    STATE(16835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725322] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22700), 1,
      anon_sym_SEMI,
    ACTIONS(22702), 1,
      anon_sym_GT_RBRACE,
    STATE(16836), 1,
      sym_attribute,
    STATE(16903), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725342] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22704), 1,
      anon_sym_LPAREN,
    ACTIONS(22706), 1,
      anon_sym_LBRACK,
    ACTIONS(22708), 1,
      anon_sym_LBRACE,
    STATE(16837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725362] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19391), 1,
      anon_sym_RBRACK,
    ACTIONS(22710), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16838), 2,
      sym_attribute,
      aux_sym_list_pattern_repeat1,
  [725380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20425), 1,
      anon_sym_RBRACK,
    STATE(16318), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22713), 1,
      anon_sym_LPAREN,
    ACTIONS(22715), 1,
      anon_sym_LBRACK,
    ACTIONS(22717), 1,
      anon_sym_LBRACE,
    STATE(16840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725420] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16165), 1,
      sym_attribute_id,
    STATE(16841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725438] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19035), 1,
      anon_sym_RBRACE,
    ACTIONS(22719), 1,
      anon_sym_SEMI,
    STATE(16842), 1,
      sym_attribute,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725458] = 5,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8755), 1,
      aux_sym_attribute_id_token1,
    STATE(16843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(8757), 2,
      sym__left_quoted_string_delimiter,
      aux_sym_quoted_extension_token1,
  [725476] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22721), 1,
      anon_sym_SEMI,
    ACTIONS(22723), 1,
      anon_sym_RBRACE,
    STATE(16005), 1,
      aux_sym_record_expression_repeat1,
    STATE(16844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725496] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22725), 1,
      sym__lowercase_identifier,
    STATE(16845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725516] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(22727), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(16846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725536] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22729), 1,
      anon_sym_LPAREN,
    ACTIONS(22731), 1,
      anon_sym_LBRACK,
    ACTIONS(22733), 1,
      anon_sym_LBRACE,
    STATE(16847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725556] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22735), 1,
      anon_sym_LPAREN,
    ACTIONS(22737), 1,
      anon_sym_LBRACK,
    ACTIONS(22739), 1,
      anon_sym_LBRACE,
    STATE(16848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725576] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16193), 1,
      sym_attribute_id,
    STATE(16849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725594] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3639), 1,
      anon_sym_RBRACK,
    ACTIONS(22741), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725614] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12365), 1,
      anon_sym_DQUOTE,
    STATE(10333), 1,
      aux_sym_external_repeat1,
    STATE(11648), 1,
      sym_string,
    STATE(16851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725634] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9976), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16804), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725654] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22743), 1,
      anon_sym_LPAREN,
    ACTIONS(22745), 1,
      anon_sym_LBRACK,
    ACTIONS(22747), 1,
      anon_sym_LBRACE,
    STATE(16853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725674] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22749), 1,
      anon_sym_LPAREN,
    ACTIONS(22751), 1,
      anon_sym_LBRACK,
    ACTIONS(22753), 1,
      anon_sym_LBRACE,
    STATE(16854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725694] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16212), 1,
      sym_attribute_id,
    STATE(16855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725712] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22755), 1,
      anon_sym_SEMI,
    ACTIONS(22757), 1,
      anon_sym_RBRACE,
    STATE(16856), 1,
      sym_attribute,
    STATE(16909), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725732] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22759), 1,
      anon_sym_SEMI,
    ACTIONS(22761), 1,
      anon_sym_RBRACE,
    STATE(16857), 1,
      sym_attribute,
    STATE(16899), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725752] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22763), 1,
      anon_sym_SEMI,
    ACTIONS(22765), 1,
      anon_sym_RBRACE,
    STATE(15927), 1,
      aux_sym_record_expression_repeat1,
    STATE(16858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725772] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16859), 1,
      sym_attribute,
    STATE(16918), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725792] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22767), 1,
      anon_sym_LPAREN,
    ACTIONS(22769), 1,
      anon_sym_LBRACK,
    ACTIONS(22771), 1,
      anon_sym_LBRACE,
    STATE(16860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725812] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22773), 1,
      anon_sym_LPAREN,
    ACTIONS(22775), 1,
      anon_sym_LBRACK,
    ACTIONS(22777), 1,
      anon_sym_LBRACE,
    STATE(16861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725832] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16238), 1,
      sym_attribute_id,
    STATE(16862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725850] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22779), 1,
      anon_sym_SEMI,
    ACTIONS(22781), 1,
      anon_sym_GT_RBRACE,
    STATE(16170), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725870] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22783), 1,
      anon_sym_SEMI,
    ACTIONS(22785), 1,
      anon_sym_GT_RBRACE,
    STATE(16864), 1,
      sym_attribute,
    STATE(16921), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725890] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22787), 1,
      anon_sym_LPAREN,
    ACTIONS(22789), 1,
      anon_sym_LBRACK,
    ACTIONS(22791), 1,
      anon_sym_LBRACE,
    STATE(16865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725910] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22793), 1,
      anon_sym_LPAREN,
    ACTIONS(22795), 1,
      anon_sym_LBRACK,
    ACTIONS(22797), 1,
      anon_sym_LBRACE,
    STATE(16866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725930] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16253), 1,
      sym_attribute_id,
    STATE(16867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [725948] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22799), 1,
      anon_sym_SEMI,
    ACTIONS(22801), 1,
      anon_sym_GT_RBRACE,
    STATE(16868), 1,
      sym_attribute,
    STATE(16947), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725968] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22803), 1,
      anon_sym_LPAREN,
    ACTIONS(22805), 1,
      anon_sym_LBRACK,
    ACTIONS(22807), 1,
      anon_sym_LBRACE,
    STATE(16869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [725988] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22809), 1,
      anon_sym_LPAREN,
    ACTIONS(22811), 1,
      anon_sym_LBRACK,
    ACTIONS(22813), 1,
      anon_sym_LBRACE,
    STATE(16870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726008] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16274), 1,
      sym_attribute_id,
    STATE(16871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726026] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(11427), 1,
      anon_sym_DOT,
    ACTIONS(22815), 1,
      anon_sym_RPAREN,
    STATE(16872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726046] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(22817), 1,
      sym__lowercase_identifier,
    STATE(16873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726066] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20171), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22819), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18319), 1,
      anon_sym_SEMI,
    ACTIONS(18321), 1,
      anon_sym_GT,
    STATE(16875), 1,
      sym_attribute,
    STATE(16927), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726106] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22821), 1,
      anon_sym_LPAREN,
    ACTIONS(22823), 1,
      anon_sym_LBRACK,
    ACTIONS(22825), 1,
      anon_sym_LBRACE,
    STATE(16876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726126] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22827), 1,
      anon_sym_LPAREN,
    ACTIONS(22829), 1,
      anon_sym_LBRACK,
    ACTIONS(22831), 1,
      anon_sym_LBRACE,
    STATE(16877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726146] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16295), 1,
      sym_attribute_id,
    STATE(16878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726164] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19413), 1,
      anon_sym_RBRACE,
    ACTIONS(22833), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726184] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22835), 1,
      anon_sym_SEMI,
    ACTIONS(22837), 1,
      anon_sym_RBRACE,
    STATE(16880), 1,
      sym_attribute,
    STATE(16934), 1,
      aux_sym_record_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726204] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19189), 1,
      anon_sym_RBRACE,
    ACTIONS(22839), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726224] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22841), 1,
      anon_sym_LPAREN,
    ACTIONS(22843), 1,
      anon_sym_LBRACK,
    ACTIONS(22845), 1,
      anon_sym_LBRACE,
    STATE(16882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726244] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22847), 1,
      anon_sym_LPAREN,
    ACTIONS(22849), 1,
      anon_sym_LBRACK,
    ACTIONS(22851), 1,
      anon_sym_LBRACE,
    STATE(16883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726264] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16308), 1,
      sym_attribute_id,
    STATE(16884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22853), 1,
      anon_sym_SEMI,
    ACTIONS(22855), 1,
      anon_sym_RBRACE,
    STATE(16885), 1,
      sym_attribute,
    STATE(16944), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3561), 1,
      anon_sym_RBRACK,
    ACTIONS(22857), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726322] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19247), 1,
      anon_sym_RBRACE,
    ACTIONS(22859), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726342] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22861), 1,
      anon_sym_SEMI,
    ACTIONS(22863), 1,
      anon_sym_RBRACE,
    STATE(16888), 1,
      sym_attribute,
    STATE(16949), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726362] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22865), 1,
      anon_sym_LPAREN,
    ACTIONS(22867), 1,
      anon_sym_LBRACK,
    ACTIONS(22869), 1,
      anon_sym_LBRACE,
    STATE(16889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726382] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3641), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22871), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726402] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22873), 1,
      anon_sym_LPAREN,
    ACTIONS(22875), 1,
      anon_sym_LBRACK,
    ACTIONS(22877), 1,
      anon_sym_LBRACE,
    STATE(16891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16329), 1,
      sym_attribute_id,
    STATE(16892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726440] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22879), 1,
      anon_sym_SEMI,
    ACTIONS(22881), 1,
      anon_sym_RBRACE,
    STATE(16893), 1,
      sym_attribute,
    STATE(17117), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22883), 3,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym__lowercase_identifier,
  [726476] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22885), 1,
      anon_sym_LPAREN,
    ACTIONS(22887), 1,
      anon_sym_LBRACK,
    ACTIONS(22889), 1,
      anon_sym_LBRACE,
    STATE(16895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726496] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22891), 1,
      anon_sym_LPAREN,
    ACTIONS(22893), 1,
      anon_sym_LBRACK,
    ACTIONS(22895), 1,
      anon_sym_LBRACE,
    STATE(16896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726516] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16343), 1,
      sym_attribute_id,
    STATE(16897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726534] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3357), 1,
      anon_sym_RBRACK,
    ACTIONS(22897), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726554] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19617), 1,
      anon_sym_RBRACE,
    ACTIONS(22899), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726574] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22901), 1,
      anon_sym_SEMI,
    ACTIONS(22903), 1,
      anon_sym_GT_RBRACE,
    STATE(16214), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726594] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10027), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16901), 1,
      sym_attribute,
    STATE(16956), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726614] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22905), 1,
      anon_sym_LPAREN,
    ACTIONS(22907), 1,
      anon_sym_LBRACK,
    ACTIONS(22909), 1,
      anon_sym_LBRACE,
    STATE(16902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726634] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20433), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22911), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726654] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22913), 1,
      anon_sym_LPAREN,
    ACTIONS(22915), 1,
      anon_sym_LBRACK,
    ACTIONS(22917), 1,
      anon_sym_LBRACE,
    STATE(16904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16361), 1,
      sym_attribute_id,
    STATE(16905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726692] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18428), 1,
      anon_sym_SEMI,
    ACTIONS(18430), 1,
      anon_sym_GT,
    STATE(16906), 1,
      sym_attribute,
    STATE(16962), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726712] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(22919), 1,
      anon_sym_RPAREN,
    STATE(16907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726732] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22921), 1,
      anon_sym_LPAREN,
    ACTIONS(22923), 1,
      anon_sym_LBRACK,
    ACTIONS(22925), 1,
      anon_sym_LBRACE,
    STATE(16908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726752] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19501), 1,
      anon_sym_RBRACE,
    ACTIONS(22927), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726772] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22929), 1,
      anon_sym_LPAREN,
    ACTIONS(22931), 1,
      anon_sym_LBRACK,
    ACTIONS(22933), 1,
      anon_sym_LBRACE,
    STATE(16910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726792] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16381), 1,
      sym_attribute_id,
    STATE(16911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726810] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22935), 1,
      anon_sym_SEMI,
    ACTIONS(22937), 1,
      anon_sym_GT_RBRACE,
    STATE(16912), 1,
      sym_attribute,
    STATE(16986), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726830] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20435), 1,
      anon_sym_RBRACK,
    STATE(16913), 1,
      sym_attribute,
    STATE(16981), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726850] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3359), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22939), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726870] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22941), 1,
      anon_sym_LPAREN,
    ACTIONS(22943), 1,
      anon_sym_LBRACK,
    ACTIONS(22945), 1,
      anon_sym_LBRACE,
    STATE(16915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726890] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22947), 1,
      anon_sym_LPAREN,
    ACTIONS(22949), 1,
      anon_sym_LBRACK,
    ACTIONS(22951), 1,
      anon_sym_LBRACE,
    STATE(16916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726910] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16395), 1,
      sym_attribute_id,
    STATE(16917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [726928] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20435), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726948] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3563), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22953), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726968] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22955), 1,
      anon_sym_LPAREN,
    ACTIONS(22957), 1,
      anon_sym_LBRACK,
    ACTIONS(22959), 1,
      anon_sym_LBRACE,
    STATE(16920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [726988] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21026), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(22961), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727008] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22963), 1,
      anon_sym_LPAREN,
    ACTIONS(22965), 1,
      anon_sym_LBRACK,
    ACTIONS(22967), 1,
      anon_sym_LBRACE,
    STATE(16922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727028] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16413), 1,
      sym_attribute_id,
    STATE(16923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727046] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7805), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(22969), 1,
      anon_sym_SEMI,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727066] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22971), 1,
      anon_sym_SEMI,
    ACTIONS(22974), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(16925), 2,
      sym_attribute,
      aux_sym_record_pattern_repeat1,
  [727084] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18365), 1,
      anon_sym_SEMI,
    ACTIONS(18367), 1,
      anon_sym_GT,
    STATE(16824), 1,
      aux_sym_object_type_repeat1,
    STATE(16926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727104] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11852), 1,
      anon_sym_GT,
    ACTIONS(22976), 1,
      anon_sym_SEMI,
    STATE(16927), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727124] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22978), 1,
      anon_sym_LPAREN,
    ACTIONS(22980), 1,
      anon_sym_LBRACK,
    ACTIONS(22982), 1,
      anon_sym_LBRACE,
    STATE(16928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727144] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22984), 1,
      anon_sym_LPAREN,
    ACTIONS(22986), 1,
      anon_sym_LBRACK,
    ACTIONS(22988), 1,
      anon_sym_LBRACE,
    STATE(16929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727164] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16421), 1,
      sym_attribute_id,
    STATE(16930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727182] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(22990), 1,
      anon_sym_RPAREN,
    STATE(16931), 1,
      sym_attribute,
    STATE(20900), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727202] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22992), 1,
      anon_sym_SEMI,
    ACTIONS(22994), 1,
      anon_sym_RBRACE,
    STATE(16932), 1,
      sym_attribute,
    STATE(16995), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727222] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7893), 1,
      anon_sym_RBRACK,
    ACTIONS(22996), 1,
      anon_sym_SEMI,
    STATE(16838), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727242] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19071), 1,
      anon_sym_RBRACE,
    ACTIONS(22998), 1,
      anon_sym_SEMI,
    STATE(16925), 1,
      aux_sym_record_pattern_repeat1,
    STATE(16934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727262] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23000), 1,
      anon_sym_LPAREN,
    ACTIONS(23002), 1,
      anon_sym_LBRACK,
    ACTIONS(23004), 1,
      anon_sym_LBRACE,
    STATE(16935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23006), 1,
      anon_sym_LPAREN,
    ACTIONS(23008), 1,
      anon_sym_LBRACK,
    ACTIONS(23010), 1,
      anon_sym_LBRACE,
    STATE(16936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727302] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16428), 1,
      sym_attribute_id,
    STATE(16937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727320] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7895), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23012), 1,
      anon_sym_SEMI,
    STATE(16742), 1,
      aux_sym_list_pattern_repeat1,
    STATE(16938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727340] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3325), 1,
      anon_sym_RBRACK,
    ACTIONS(23014), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727360] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8586), 1,
      anon_sym_RBRACK,
    ACTIONS(23016), 1,
      anon_sym_SEMI,
    STATE(16940), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23018), 1,
      anon_sym_LPAREN,
    ACTIONS(23020), 1,
      anon_sym_LBRACK,
    ACTIONS(23022), 1,
      anon_sym_LBRACE,
    STATE(16941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23024), 1,
      anon_sym_LPAREN,
    ACTIONS(23026), 1,
      anon_sym_LBRACK,
    ACTIONS(23028), 1,
      anon_sym_LBRACE,
    STATE(16942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727420] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16434), 1,
      sym_attribute_id,
    STATE(16943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727438] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19075), 1,
      anon_sym_RBRACE,
    ACTIONS(23030), 1,
      anon_sym_SEMI,
    STATE(16944), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727458] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3343), 1,
      anon_sym_RBRACK,
    ACTIONS(23032), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(16945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727478] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8588), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23034), 1,
      anon_sym_SEMI,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727498] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20177), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(23036), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727518] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23038), 1,
      anon_sym_SEMI,
    ACTIONS(23040), 1,
      anon_sym_GT_RBRACE,
    STATE(16948), 1,
      sym_attribute,
    STATE(17127), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727538] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19353), 1,
      anon_sym_RBRACE,
    ACTIONS(23042), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727558] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23044), 1,
      anon_sym_LPAREN,
    ACTIONS(23046), 1,
      anon_sym_LBRACK,
    ACTIONS(23048), 1,
      anon_sym_LBRACE,
    STATE(16950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727578] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23050), 1,
      anon_sym_LPAREN,
    ACTIONS(23052), 1,
      anon_sym_LBRACK,
    ACTIONS(23054), 1,
      anon_sym_LBRACE,
    STATE(16951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727598] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16440), 1,
      sym_attribute_id,
    STATE(16952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727616] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8624), 1,
      anon_sym_RBRACK,
    ACTIONS(23056), 1,
      anon_sym_SEMI,
    STATE(16953), 1,
      sym_attribute,
    STATE(17035), 1,
      aux_sym_list_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727636] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23058), 1,
      anon_sym_RPAREN,
    STATE(16954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727656] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21040), 1,
      anon_sym_RBRACK,
    STATE(16955), 1,
      sym_attribute,
    STATE(16993), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727676] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21040), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727696] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23060), 1,
      anon_sym_LPAREN,
    ACTIONS(23062), 1,
      anon_sym_LBRACK,
    ACTIONS(23064), 1,
      anon_sym_LBRACE,
    STATE(16957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727716] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18975), 1,
      anon_sym_RBRACE,
    ACTIONS(23066), 1,
      anon_sym_SEMI,
    STATE(16958), 1,
      sym_attribute,
    STATE(17052), 1,
      aux_sym_record_binding_pattern_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727736] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23068), 1,
      anon_sym_LPAREN,
    ACTIONS(23070), 1,
      anon_sym_LBRACK,
    ACTIONS(23072), 1,
      anon_sym_LBRACE,
    STATE(16959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16447), 1,
      sym_attribute_id,
    STATE(16960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727774] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(23074), 1,
      sym__lowercase_identifier,
    STATE(16961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727794] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11674), 1,
      anon_sym_GT,
    ACTIONS(23076), 1,
      anon_sym_SEMI,
    STATE(16962), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727814] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23078), 1,
      anon_sym_EQ,
    STATE(16963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23080), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [727832] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23082), 1,
      anon_sym_SEMI,
    ACTIONS(23084), 1,
      anon_sym_RBRACE,
    STATE(16964), 1,
      sym_attribute,
    STATE(17001), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727852] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23086), 1,
      anon_sym_LPAREN,
    ACTIONS(23088), 1,
      anon_sym_LBRACK,
    ACTIONS(23090), 1,
      anon_sym_LBRACE,
    STATE(16965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727872] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3345), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23092), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(16966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727892] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23094), 1,
      anon_sym_LPAREN,
    ACTIONS(23096), 1,
      anon_sym_LBRACK,
    ACTIONS(23098), 1,
      anon_sym_LBRACE,
    STATE(16967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727912] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16458), 1,
      sym_attribute_id,
    STATE(16968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [727930] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23102), 1,
      anon_sym_LBRACK,
    STATE(16969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23100), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [727948] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8632), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23104), 1,
      anon_sym_SEMI,
    STATE(16743), 1,
      aux_sym_list_binding_pattern_repeat1,
    STATE(16970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727968] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23106), 1,
      anon_sym_RPAREN,
    STATE(16971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [727988] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23108), 1,
      anon_sym_LPAREN,
    ACTIONS(23110), 1,
      anon_sym_LBRACK,
    ACTIONS(23112), 1,
      anon_sym_LBRACE,
    STATE(16972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728008] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23114), 1,
      anon_sym_LPAREN,
    ACTIONS(23116), 1,
      anon_sym_LBRACK,
    ACTIONS(23118), 1,
      anon_sym_LBRACE,
    STATE(16973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728028] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16465), 1,
      sym_attribute_id,
    STATE(16974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728046] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(23120), 1,
      sym__lowercase_identifier,
    STATE(16975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728066] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23122), 1,
      anon_sym_SEMI,
    ACTIONS(23124), 1,
      anon_sym_GT_RBRACE,
    STATE(15958), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23126), 1,
      anon_sym_LPAREN,
    ACTIONS(23128), 1,
      anon_sym_LBRACK,
    ACTIONS(23130), 1,
      anon_sym_LBRACE,
    STATE(16977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728106] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23132), 1,
      anon_sym_LPAREN,
    ACTIONS(23134), 1,
      anon_sym_LBRACK,
    ACTIONS(23136), 1,
      anon_sym_LBRACE,
    STATE(16978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728126] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16478), 1,
      sym_attribute_id,
    STATE(16979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728144] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(23138), 1,
      anon_sym_RPAREN,
    STATE(16980), 1,
      sym_attribute,
    STATE(20976), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728164] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20443), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728184] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23140), 1,
      anon_sym_LPAREN,
    ACTIONS(23142), 1,
      anon_sym_LBRACK,
    ACTIONS(23144), 1,
      anon_sym_LBRACE,
    STATE(16982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728204] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20443), 1,
      anon_sym_RBRACK,
    STATE(16983), 1,
      sym_attribute,
    STATE(16997), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728224] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23146), 1,
      anon_sym_LPAREN,
    ACTIONS(23148), 1,
      anon_sym_LBRACK,
    ACTIONS(23150), 1,
      anon_sym_LBRACE,
    STATE(16984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728244] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16488), 1,
      sym_attribute_id,
    STATE(16985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728262] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21054), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(23152), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(16986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728282] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23154), 1,
      anon_sym_RPAREN,
    STATE(16987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23156), 1,
      anon_sym_LPAREN,
    ACTIONS(23158), 1,
      anon_sym_LBRACK,
    ACTIONS(23160), 1,
      anon_sym_LBRACE,
    STATE(16988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728322] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23162), 1,
      anon_sym_LPAREN,
    ACTIONS(23164), 1,
      anon_sym_LBRACK,
    ACTIONS(23166), 1,
      anon_sym_LBRACE,
    STATE(16989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728342] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16498), 1,
      sym_attribute_id,
    STATE(16990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728360] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23168), 1,
      anon_sym_RPAREN,
    STATE(16991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728380] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20179), 1,
      anon_sym_RBRACK,
    STATE(16992), 1,
      sym_attribute,
    STATE(17140), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728400] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21060), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728420] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21060), 1,
      anon_sym_RBRACK,
    STATE(16994), 1,
      sym_attribute,
    STATE(17012), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728440] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19431), 1,
      anon_sym_RBRACE,
    ACTIONS(23170), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(16995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728460] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23172), 1,
      anon_sym_LPAREN,
    ACTIONS(23174), 1,
      anon_sym_LBRACK,
    ACTIONS(23176), 1,
      anon_sym_LBRACE,
    STATE(16996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728480] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20447), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(16997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728500] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23178), 1,
      anon_sym_LPAREN,
    ACTIONS(23180), 1,
      anon_sym_LBRACK,
    ACTIONS(23182), 1,
      anon_sym_LBRACE,
    STATE(16998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728520] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16505), 1,
      sym_attribute_id,
    STATE(16999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728538] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20179), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728558] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19525), 1,
      anon_sym_RBRACE,
    ACTIONS(23184), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728578] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23186), 1,
      anon_sym_LPAREN,
    ACTIONS(23188), 1,
      anon_sym_LBRACK,
    ACTIONS(23190), 1,
      anon_sym_LBRACE,
    STATE(17002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728598] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3633), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23192), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(17003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728618] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23194), 1,
      anon_sym_LPAREN,
    ACTIONS(23196), 1,
      anon_sym_LBRACK,
    ACTIONS(23198), 1,
      anon_sym_LBRACE,
    STATE(17004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728638] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16514), 1,
      sym_attribute_id,
    STATE(17005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728656] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19611), 1,
      anon_sym_RBRACE,
    ACTIONS(23200), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728676] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23202), 1,
      anon_sym_LPAREN,
    ACTIONS(23204), 1,
      anon_sym_LBRACK,
    ACTIONS(23206), 1,
      anon_sym_LBRACE,
    STATE(17007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728696] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23208), 1,
      anon_sym_LPAREN,
    ACTIONS(23210), 1,
      anon_sym_LBRACK,
    ACTIONS(23212), 1,
      anon_sym_LBRACE,
    STATE(17008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728716] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16522), 1,
      sym_attribute_id,
    STATE(17009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728734] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20918), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728754] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23214), 1,
      anon_sym_LPAREN,
    ACTIONS(23216), 1,
      anon_sym_LBRACK,
    ACTIONS(23218), 1,
      anon_sym_LBRACE,
    STATE(17011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728774] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21072), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728794] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23220), 1,
      anon_sym_LPAREN,
    ACTIONS(23222), 1,
      anon_sym_LBRACK,
    ACTIONS(23224), 1,
      anon_sym_LBRACE,
    STATE(17013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728814] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16530), 1,
      sym_attribute_id,
    STATE(17014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728832] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23226), 1,
      anon_sym_SEMI,
    ACTIONS(23228), 1,
      anon_sym_RBRACE,
    STATE(17015), 1,
      sym_attribute,
    STATE(17034), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728852] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23230), 1,
      anon_sym_SEMI,
    ACTIONS(23232), 1,
      anon_sym_RBRACE,
    STATE(17016), 1,
      sym_attribute,
    STATE(17039), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728872] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23234), 1,
      anon_sym_SEMI,
    ACTIONS(23236), 1,
      anon_sym_RBRACE,
    STATE(15967), 1,
      aux_sym_record_expression_repeat1,
    STATE(17017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728892] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(23238), 1,
      sym__lowercase_identifier,
    STATE(17018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728912] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23240), 1,
      anon_sym_LPAREN,
    ACTIONS(23242), 1,
      anon_sym_LBRACK,
    ACTIONS(23244), 1,
      anon_sym_LBRACE,
    STATE(17019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728932] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23246), 1,
      anon_sym_LPAREN,
    ACTIONS(23248), 1,
      anon_sym_LBRACK,
    ACTIONS(23250), 1,
      anon_sym_LBRACE,
    STATE(17020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728952] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16541), 1,
      sym_attribute_id,
    STATE(17021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [728970] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23252), 1,
      sym__lowercase_identifier,
    ACTIONS(23254), 1,
      anon_sym_LPAREN,
    STATE(7742), 1,
      sym__simple_value_pattern,
    STATE(17022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [728990] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11804), 1,
      anon_sym_GT,
    ACTIONS(23256), 1,
      anon_sym_SEMI,
    STATE(17023), 1,
      sym_attribute,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729010] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(21441), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(17024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729030] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23258), 1,
      anon_sym_LPAREN,
    ACTIONS(23260), 1,
      anon_sym_LBRACK,
    ACTIONS(23262), 1,
      anon_sym_LBRACE,
    STATE(17025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729050] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23264), 1,
      anon_sym_LPAREN,
    ACTIONS(23266), 1,
      anon_sym_LBRACK,
    ACTIONS(23268), 1,
      anon_sym_LBRACE,
    STATE(17026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729070] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16549), 1,
      sym_attribute_id,
    STATE(17027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729088] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(23270), 1,
      sym__lowercase_identifier,
    STATE(17028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729108] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23272), 1,
      anon_sym_SEMI,
    ACTIONS(23274), 1,
      anon_sym_RBRACE,
    STATE(15932), 1,
      aux_sym_record_expression_repeat1,
    STATE(17029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729128] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23276), 1,
      anon_sym_LPAREN,
    ACTIONS(23278), 1,
      anon_sym_LBRACK,
    ACTIONS(23280), 1,
      anon_sym_LBRACE,
    STATE(17030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729148] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(23282), 1,
      sym__lowercase_identifier,
    STATE(17031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729168] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23284), 1,
      anon_sym_LPAREN,
    ACTIONS(23286), 1,
      anon_sym_LBRACK,
    ACTIONS(23288), 1,
      anon_sym_LBRACE,
    STATE(17032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729188] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16561), 1,
      sym_attribute_id,
    STATE(17033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729206] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19279), 1,
      anon_sym_RBRACE,
    ACTIONS(23290), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729226] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19401), 1,
      anon_sym_RBRACK,
    ACTIONS(23292), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(17035), 2,
      sym_attribute,
      aux_sym_list_binding_pattern_repeat1,
  [729244] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23295), 1,
      anon_sym_LPAREN,
    ACTIONS(23297), 1,
      anon_sym_LBRACK,
    ACTIONS(23299), 1,
      anon_sym_LBRACE,
    STATE(17036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729264] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23301), 1,
      anon_sym_LPAREN,
    ACTIONS(23303), 1,
      anon_sym_LBRACK,
    ACTIONS(23305), 1,
      anon_sym_LBRACE,
    STATE(17037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729284] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16571), 1,
      sym_attribute_id,
    STATE(17038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729302] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19495), 1,
      anon_sym_RBRACE,
    ACTIONS(23307), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729322] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21108), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729342] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18436), 1,
      anon_sym_SEMI,
    ACTIONS(18438), 1,
      anon_sym_GT,
    STATE(16430), 1,
      aux_sym_object_type_repeat1,
    STATE(17041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729362] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20460), 1,
      anon_sym_RBRACE,
    ACTIONS(23309), 1,
      anon_sym_SEMI,
    STATE(16326), 1,
      aux_sym_record_declaration_repeat1,
    STATE(17042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729382] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3253), 1,
      anon_sym_RBRACK,
    ACTIONS(23311), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(17043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729402] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23313), 1,
      anon_sym_LPAREN,
    ACTIONS(23315), 1,
      anon_sym_LBRACK,
    ACTIONS(23317), 1,
      anon_sym_LBRACE,
    STATE(17044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729422] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23319), 1,
      anon_sym_LPAREN,
    ACTIONS(23321), 1,
      anon_sym_LBRACK,
    ACTIONS(23323), 1,
      anon_sym_LBRACE,
    STATE(17045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729442] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16580), 1,
      sym_attribute_id,
    STATE(17046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729460] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18661), 1,
      anon_sym_GT,
    ACTIONS(23325), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(17047), 2,
      sym_attribute,
      aux_sym_object_type_repeat1,
  [729478] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9906), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(15977), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729498] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(10), 1,
      sym_attribute_id,
    STATE(17049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729516] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23328), 1,
      anon_sym_RPAREN,
    STATE(17050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729536] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23330), 1,
      anon_sym_LPAREN,
    ACTIONS(23332), 1,
      anon_sym_LBRACK,
    ACTIONS(23334), 1,
      anon_sym_LBRACE,
    STATE(17051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729556] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23336), 1,
      anon_sym_SEMI,
    ACTIONS(23339), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    STATE(17052), 2,
      sym_attribute,
      aux_sym_record_binding_pattern_repeat1,
  [729574] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23341), 1,
      anon_sym_LPAREN,
    ACTIONS(23343), 1,
      anon_sym_LBRACK,
    ACTIONS(23345), 1,
      anon_sym_LBRACE,
    STATE(17053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729594] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16588), 1,
      sym_attribute_id,
    STATE(17054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729612] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13997), 1,
      sym__type_equation,
    STATE(17055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21730), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [729630] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23347), 1,
      anon_sym_LPAREN,
    ACTIONS(23349), 1,
      anon_sym_LBRACK,
    ACTIONS(23351), 1,
      anon_sym_LBRACE,
    STATE(17056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729650] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11), 1,
      sym_attribute_id,
    STATE(17057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729668] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16591), 1,
      sym_attribute_id,
    STATE(17058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729686] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23353), 1,
      anon_sym_SEMI,
    ACTIONS(23355), 1,
      anon_sym_RBRACE,
    STATE(15918), 1,
      aux_sym_record_expression_repeat1,
    STATE(17059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729706] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23357), 1,
      anon_sym_LPAREN,
    ACTIONS(23359), 1,
      anon_sym_LBRACK,
    ACTIONS(23361), 1,
      anon_sym_LBRACE,
    STATE(17060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729726] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16594), 1,
      sym_attribute_id,
    STATE(17061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729744] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23363), 1,
      anon_sym_LPAREN,
    ACTIONS(23365), 1,
      anon_sym_LBRACK,
    ACTIONS(23367), 1,
      anon_sym_LBRACE,
    STATE(17062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729764] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16599), 1,
      sym_attribute_id,
    STATE(17063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729782] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23369), 1,
      anon_sym_LPAREN,
    ACTIONS(23371), 1,
      anon_sym_LBRACK,
    ACTIONS(23373), 1,
      anon_sym_LBRACE,
    STATE(17064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729802] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16602), 1,
      sym_attribute_id,
    STATE(17065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729820] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23375), 1,
      anon_sym_LPAREN,
    ACTIONS(23377), 1,
      anon_sym_LBRACK,
    ACTIONS(23379), 1,
      anon_sym_LBRACE,
    STATE(17066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729840] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16604), 1,
      sym_attribute_id,
    STATE(17067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729858] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23381), 1,
      anon_sym_LPAREN,
    ACTIONS(23383), 1,
      anon_sym_LBRACK,
    ACTIONS(23385), 1,
      anon_sym_LBRACE,
    STATE(17068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729878] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16607), 1,
      sym_attribute_id,
    STATE(17069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729896] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23387), 1,
      anon_sym_LPAREN,
    ACTIONS(23389), 1,
      anon_sym_LBRACK,
    ACTIONS(23391), 1,
      anon_sym_LBRACE,
    STATE(17070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729916] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16609), 1,
      sym_attribute_id,
    STATE(17071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729934] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23393), 1,
      anon_sym_LPAREN,
    ACTIONS(23395), 1,
      anon_sym_LBRACK,
    ACTIONS(23397), 1,
      anon_sym_LBRACE,
    STATE(17072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729954] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16611), 1,
      sym_attribute_id,
    STATE(17073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [729972] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23399), 1,
      anon_sym_LPAREN,
    ACTIONS(23401), 1,
      anon_sym_LBRACK,
    ACTIONS(23403), 1,
      anon_sym_LBRACE,
    STATE(17074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [729992] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16614), 1,
      sym_attribute_id,
    STATE(17075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730010] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23405), 1,
      anon_sym_LPAREN,
    ACTIONS(23407), 1,
      anon_sym_LBRACK,
    ACTIONS(23409), 1,
      anon_sym_LBRACE,
    STATE(17076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730030] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16617), 1,
      sym_attribute_id,
    STATE(17077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730048] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23411), 1,
      anon_sym_LPAREN,
    ACTIONS(23413), 1,
      anon_sym_LBRACK,
    ACTIONS(23415), 1,
      anon_sym_LBRACE,
    STATE(17078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730068] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16620), 1,
      sym_attribute_id,
    STATE(17079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23417), 1,
      anon_sym_LPAREN,
    ACTIONS(23419), 1,
      anon_sym_LBRACK,
    ACTIONS(23421), 1,
      anon_sym_LBRACE,
    STATE(17080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16622), 1,
      sym_attribute_id,
    STATE(17081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730124] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23423), 1,
      anon_sym_LPAREN,
    ACTIONS(23425), 1,
      anon_sym_LBRACK,
    ACTIONS(23427), 1,
      anon_sym_LBRACE,
    STATE(17082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730144] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16625), 1,
      sym_attribute_id,
    STATE(17083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730162] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23429), 1,
      anon_sym_LPAREN,
    ACTIONS(23431), 1,
      anon_sym_LBRACK,
    ACTIONS(23433), 1,
      anon_sym_LBRACE,
    STATE(17084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730182] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16627), 1,
      sym_attribute_id,
    STATE(17085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730200] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16629), 1,
      sym_attribute_id,
    STATE(17086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730218] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16631), 1,
      sym_attribute_id,
    STATE(17087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730236] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16633), 1,
      sym_attribute_id,
    STATE(17088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730254] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16635), 1,
      sym_attribute_id,
    STATE(17089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730272] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16637), 1,
      sym_attribute_id,
    STATE(17090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730290] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16639), 1,
      sym_attribute_id,
    STATE(17091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16641), 1,
      sym_attribute_id,
    STATE(17092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730326] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16643), 1,
      sym_attribute_id,
    STATE(17093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730344] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16645), 1,
      sym_attribute_id,
    STATE(17094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730362] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16647), 1,
      sym_attribute_id,
    STATE(17095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730380] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16649), 1,
      sym_attribute_id,
    STATE(17096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730398] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16651), 1,
      sym_attribute_id,
    STATE(17097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730416] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16653), 1,
      sym_attribute_id,
    STATE(17098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730434] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16655), 1,
      sym_attribute_id,
    STATE(17099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730452] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16657), 1,
      sym_attribute_id,
    STATE(17100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730470] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16659), 1,
      sym_attribute_id,
    STATE(17101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730488] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16661), 1,
      sym_attribute_id,
    STATE(17102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730506] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16663), 1,
      sym_attribute_id,
    STATE(17103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730524] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16665), 1,
      sym_attribute_id,
    STATE(17104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730542] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16667), 1,
      sym_attribute_id,
    STATE(17105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730560] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16669), 1,
      sym_attribute_id,
    STATE(17106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730578] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16671), 1,
      sym_attribute_id,
    STATE(17107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730596] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(16673), 1,
      sym_attribute_id,
    STATE(17108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22110), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [730614] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10033), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(17109), 1,
      sym_attribute,
    STATE(17174), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730634] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12905), 1,
      sym_module_binding,
    STATE(17110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19111), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [730652] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19235), 1,
      anon_sym_RBRACE,
    ACTIONS(23435), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730672] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    STATE(10239), 1,
      sym_module_parameter,
    STATE(15730), 1,
      aux_sym_module_binding_repeat1,
    STATE(17112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730692] = 6,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    ACTIONS(23437), 1,
      aux_sym_quoted_extension_token1,
    STATE(17113), 1,
      sym_attribute,
    STATE(18737), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730712] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23439), 1,
      anon_sym_RBRACK,
    STATE(17114), 1,
      sym_attribute,
    STATE(17126), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730732] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21199), 1,
      sym_indexing_operator,
    ACTIONS(23441), 1,
      sym__lowercase_identifier,
    STATE(17115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730752] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18335), 1,
      anon_sym_SEMI,
    ACTIONS(18337), 1,
      anon_sym_GT,
    STATE(17116), 1,
      sym_attribute,
    STATE(17184), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730772] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19427), 1,
      anon_sym_RBRACE,
    ACTIONS(23443), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730792] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23445), 1,
      anon_sym_SEMI,
    ACTIONS(23447), 1,
      anon_sym_RBRACE,
    STATE(17118), 1,
      sym_attribute,
    STATE(17179), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730812] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23449), 1,
      anon_sym_RBRACK,
    STATE(16457), 1,
      aux_sym__type_params_repeat1,
    STATE(17119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730832] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3255), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23451), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(17120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730852] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23453), 1,
      anon_sym_RPAREN,
    STATE(17121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730872] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10025), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(16560), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730892] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23455), 1,
      anon_sym_SEMI,
    ACTIONS(23457), 1,
      anon_sym_RBRACE,
    STATE(17123), 1,
      sym_attribute,
    STATE(17148), 1,
      aux_sym_record_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730912] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18361), 1,
      anon_sym_SEMI,
    ACTIONS(18363), 1,
      anon_sym_GT,
    STATE(15985), 1,
      aux_sym_object_type_repeat1,
    STATE(17124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730932] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19255), 1,
      anon_sym_RBRACE,
    ACTIONS(23459), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730952] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23461), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(17126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730972] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21114), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(23463), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(17127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [730992] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(17128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12462), 3,
      anon_sym_and,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [731008] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15695), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(17129), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731028] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23461), 1,
      anon_sym_RBRACK,
    STATE(17130), 1,
      sym_attribute,
    STATE(17151), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731048] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23465), 1,
      sym__lowercase_identifier,
    ACTIONS(23467), 1,
      anon_sym_LPAREN,
    STATE(8028), 1,
      sym__simple_value_pattern,
    STATE(17131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731068] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23469), 1,
      anon_sym_SEMI,
    ACTIONS(23471), 1,
      anon_sym_GT_RBRACE,
    STATE(17132), 1,
      sym_attribute,
    STATE(17164), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731088] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(23473), 1,
      anon_sym_type,
    STATE(16812), 1,
      sym_module_path,
    STATE(17133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731108] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23475), 1,
      anon_sym_RBRACK,
    STATE(17134), 1,
      sym_attribute,
    STATE(17135), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731128] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23477), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(17135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731148] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23477), 1,
      anon_sym_RBRACK,
    STATE(17136), 1,
      sym_attribute,
    STATE(17137), 1,
      aux_sym__type_params_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731168] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23479), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(17137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731188] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23481), 1,
      anon_sym_RPAREN,
    STATE(17138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731208] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23483), 1,
      anon_sym_SEMI,
    ACTIONS(23485), 1,
      anon_sym_RBRACE,
    STATE(15912), 1,
      aux_sym_record_expression_repeat1,
    STATE(17139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731228] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20193), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731248] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23487), 1,
      anon_sym_SEMI,
    ACTIONS(23489), 1,
      anon_sym_GT_RBRACE,
    STATE(17141), 1,
      sym_attribute,
    STATE(17187), 1,
      aux_sym_object_copy_expression_repeat1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731268] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3485), 1,
      anon_sym_RBRACK,
    ACTIONS(23491), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(17142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731288] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(23493), 1,
      anon_sym_RPAREN,
    STATE(17143), 1,
      sym_attribute,
    STATE(19653), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13979), 1,
      sym_attribute_id,
    STATE(17144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23495), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [731326] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20101), 1,
      sym__lowercase_identifier,
    ACTIONS(20105), 1,
      anon_sym_mutable,
    STATE(16215), 1,
      sym_field_declaration,
    STATE(17145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731346] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3361), 1,
      anon_sym_RBRACK,
    ACTIONS(23497), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(17146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731366] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12300), 1,
      sym_module_binding,
    STATE(17147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19143), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [731384] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19153), 1,
      anon_sym_RBRACE,
    ACTIONS(23499), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731404] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13573), 1,
      sym_module_binding,
    STATE(17149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19143), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [731422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11237), 1,
      sym__type_equation,
    STATE(17150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23501), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [731440] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21189), 1,
      anon_sym_COMMA,
    ACTIONS(23503), 1,
      anon_sym_RBRACK,
    STATE(15483), 1,
      aux_sym__type_params_repeat1,
    STATE(17151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731460] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23505), 1,
      anon_sym_LPAREN,
    ACTIONS(23507), 1,
      anon_sym_LBRACK,
    ACTIONS(23509), 1,
      anon_sym_LBRACE,
    STATE(17152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731480] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3363), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23511), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(17153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731500] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(20193), 1,
      anon_sym_RBRACK,
    STATE(15952), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731520] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(23513), 1,
      anon_sym_RPAREN,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(17155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731540] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15408), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(17156), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(20488), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [731576] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3691), 1,
      anon_sym_RBRACK,
    ACTIONS(23515), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(17158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731596] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23517), 1,
      anon_sym_SEMI,
    ACTIONS(23519), 1,
      anon_sym_RBRACE,
    STATE(16435), 1,
      aux_sym_record_expression_repeat1,
    STATE(17159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731616] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23521), 1,
      anon_sym_SEMI,
    ACTIONS(23523), 1,
      anon_sym_GT_RBRACE,
    STATE(15928), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(17160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731636] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(11238), 1,
      sym__type_equation,
    STATE(17161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23501), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [731654] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(23525), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(17162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12300), 1,
      sym_module_binding,
    STATE(17163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19137), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [731692] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21137), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(23527), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(17164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731712] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12915), 1,
      sym_module_binding,
    STATE(17165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19137), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [731730] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15416), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(17166), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731750] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19843), 1,
      anon_sym_DASH_GT,
    ACTIONS(19845), 1,
      anon_sym_with,
    ACTIONS(23529), 1,
      anon_sym_RPAREN,
    STATE(17167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731770] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21147), 1,
      anon_sym_RBRACK,
    STATE(16383), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731790] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(12574), 1,
      sym_module_binding,
    STATE(17169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19137), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [731808] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9894), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(15915), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731828] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19453), 1,
      anon_sym_RBRACE,
    ACTIONS(23531), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731848] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(23533), 1,
      anon_sym_type,
    STATE(16812), 1,
      sym_module_path,
    STATE(17172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731868] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23535), 1,
      anon_sym_SEMI,
    ACTIONS(23537), 1,
      anon_sym_RBRACE,
    STATE(16770), 1,
      aux_sym_record_expression_repeat1,
    STATE(17173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731888] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    ACTIONS(21147), 1,
      anon_sym_RBRACK,
    STATE(15709), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731908] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8048), 1,
      aux_sym_tag_token1,
    STATE(15420), 1,
      aux_sym_polymorphic_variant_type_repeat2,
    STATE(17175), 1,
      sym_attribute,
    STATE(18167), 1,
      sym_tag,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731928] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23539), 1,
      anon_sym_SEMI,
    ACTIONS(23541), 1,
      anon_sym_RBRACE,
    STATE(16049), 1,
      aux_sym_record_expression_repeat1,
    STATE(17176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731948] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18264), 1,
      anon_sym_SEMI,
    ACTIONS(18266), 1,
      anon_sym_GT,
    STATE(15922), 1,
      aux_sym_object_type_repeat1,
    STATE(17177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731968] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10041), 1,
      anon_sym_RBRACK,
    ACTIONS(19999), 1,
      anon_sym_PIPE,
    STATE(15991), 1,
      aux_sym_polymorphic_variant_type_repeat1,
    STATE(17178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [731988] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19437), 1,
      anon_sym_RBRACE,
    ACTIONS(23543), 1,
      anon_sym_SEMI,
    STATE(16219), 1,
      aux_sym_record_expression_repeat1,
    STATE(17179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732008] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3581), 1,
      anon_sym_RBRACK,
    ACTIONS(23545), 1,
      anon_sym_SEMI,
    STATE(16157), 1,
      aux_sym_list_expression_repeat1,
    STATE(17180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732028] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3693), 1,
      anon_sym_PIPE_RBRACK,
    ACTIONS(23547), 1,
      anon_sym_SEMI,
    STATE(16721), 1,
      aux_sym_list_expression_repeat1,
    STATE(17181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732048] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(13547), 1,
      sym_module_binding,
    STATE(17182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(19143), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [732066] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    ACTIONS(23549), 1,
      anon_sym_RPAREN,
    STATE(17183), 1,
      sym_attribute,
    STATE(19861), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732086] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11772), 1,
      anon_sym_GT,
    ACTIONS(23551), 1,
      anon_sym_SEMI,
    STATE(17047), 1,
      aux_sym_object_type_repeat1,
    STATE(17184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732106] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19762), 1,
      anon_sym_COMMA,
    ACTIONS(23553), 1,
      anon_sym_RBRACK,
    STATE(15310), 1,
      aux_sym_instantiated_class_type_repeat1,
    STATE(17185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732126] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23555), 1,
      anon_sym_SEMI,
    ACTIONS(23557), 1,
      anon_sym_RBRACE,
    STATE(15953), 1,
      aux_sym_record_expression_repeat1,
    STATE(17186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732146] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20486), 1,
      anon_sym_GT_RBRACE,
    ACTIONS(23559), 1,
      anon_sym_SEMI,
    STATE(16467), 1,
      aux_sym_object_copy_expression_repeat1,
    STATE(17187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732166] = 6,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10115), 1,
      sym__uppercase_identifier,
    ACTIONS(23561), 1,
      anon_sym_type,
    STATE(16812), 1,
      sym_module_path,
    STATE(17188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732186] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(67), 1,
      sym_attribute_id,
    STATE(17189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21209), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [732204] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9920), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732221] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23563), 1,
      anon_sym_RPAREN,
    ACTIONS(23565), 1,
      anon_sym_LT_DASH,
    STATE(17191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23567), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [732253] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23569), 1,
      anon_sym_RBRACK,
    ACTIONS(23571), 1,
      anon_sym_SEMI,
    STATE(17193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732270] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23573), 1,
      anon_sym_RPAREN,
    STATE(17194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732287] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23575), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [732302] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23577), 1,
      anon_sym_COLON_GT,
    ACTIONS(23579), 1,
      anon_sym_EQ,
    STATE(17196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732319] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18339), 1,
      sym__lowercase_identifier,
    STATE(17197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23581), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [732351] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23583), 1,
      sym__lowercase_identifier,
    STATE(17199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732368] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(13094), 1,
      sym_then_clause,
    STATE(17200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732385] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23587), 1,
      sym__lowercase_identifier,
    ACTIONS(23589), 1,
      anon_sym_LPAREN,
    STATE(17201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732402] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23591), 1,
      anon_sym_DOT,
    STATE(17202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732419] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23593), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [732434] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23569), 1,
      anon_sym_RBRACE,
    ACTIONS(23595), 1,
      anon_sym_SEMI,
    STATE(17204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732451] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23597), 1,
      anon_sym_then,
    STATE(9004), 1,
      sym_then_clause,
    STATE(17205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732468] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23599), 1,
      anon_sym_then,
    STATE(12801), 1,
      sym_then_clause,
    STATE(17206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732485] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23601), 1,
      sym__lowercase_identifier,
    STATE(17207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732502] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23603), 1,
      anon_sym_COLON_GT,
    ACTIONS(23605), 1,
      anon_sym_RPAREN,
    STATE(17208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732519] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23607), 1,
      sym__lowercase_identifier,
    ACTIONS(23609), 1,
      anon_sym_LPAREN,
    STATE(17209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732536] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23611), 1,
      anon_sym_DOT,
    STATE(17210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732553] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23613), 1,
      anon_sym_EQ,
    ACTIONS(23615), 1,
      anon_sym_RPAREN,
    STATE(17211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732570] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23617), 1,
      anon_sym_COLON_GT,
    ACTIONS(23619), 1,
      anon_sym_RPAREN,
    STATE(17212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732587] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23621), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [732602] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23623), 1,
      sym__lowercase_identifier,
    ACTIONS(23625), 1,
      anon_sym_LPAREN,
    STATE(17214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732619] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9886), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732636] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23627), 1,
      sym__lowercase_identifier,
    STATE(17216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732653] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12271), 2,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
  [732668] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18486), 1,
      sym__lowercase_identifier,
    STATE(17218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732685] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23629), 1,
      anon_sym_RPAREN,
    STATE(17219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732702] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    STATE(16872), 1,
      sym_extended_module_path,
    STATE(17220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732719] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23631), 1,
      sym__lowercase_identifier,
    STATE(17221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732736] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17222), 1,
      sym_attribute,
    STATE(21013), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732753] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23633), 1,
      anon_sym_then,
    STATE(11172), 1,
      sym_then_clause,
    STATE(17223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732770] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23635), 1,
      anon_sym_RPAREN,
    STATE(17224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732787] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23637), 1,
      sym__lowercase_identifier,
    STATE(17225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732804] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12029), 2,
      anon_sym_DOT,
      aux_sym_type_variable_token1,
  [732819] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23639), 1,
      anon_sym_then,
    STATE(12883), 1,
      sym_then_clause,
    STATE(17227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732836] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23641), 1,
      anon_sym_RPAREN,
    ACTIONS(23643), 1,
      anon_sym_LT_DASH,
    STATE(17228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732853] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23645), 1,
      sym__lowercase_identifier,
    ACTIONS(23647), 1,
      sym__uppercase_identifier,
    STATE(17229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732870] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23649), 1,
      anon_sym_RPAREN,
    STATE(17230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732887] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23651), 1,
      sym__lowercase_identifier,
    STATE(17231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732904] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23653), 1,
      anon_sym_RPAREN,
    ACTIONS(23655), 1,
      anon_sym_LT_DASH,
    STATE(17232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732921] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23657), 1,
      anon_sym_RPAREN,
    STATE(17233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732938] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23659), 1,
      sym__lowercase_identifier,
    ACTIONS(23661), 1,
      anon_sym_LBRACK,
    STATE(17234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732955] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23663), 1,
      anon_sym_RPAREN,
    STATE(17235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732972] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23665), 1,
      sym__lowercase_identifier,
    ACTIONS(23667), 1,
      anon_sym_LPAREN,
    STATE(17236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [732989] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18470), 1,
      sym__lowercase_identifier,
    STATE(17237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23669), 1,
      anon_sym_RPAREN,
    ACTIONS(23671), 1,
      anon_sym_LT_DASH,
    STATE(17238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733023] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23673), 1,
      anon_sym_then,
    STATE(8517), 1,
      sym_then_clause,
    STATE(17239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23675), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733055] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23677), 1,
      anon_sym_then,
    STATE(13142), 1,
      sym_then_clause,
    STATE(17241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733072] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23679), 1,
      anon_sym_RPAREN,
    ACTIONS(23681), 1,
      anon_sym_LT_DASH,
    STATE(17242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733089] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23683), 1,
      anon_sym_DOT,
    STATE(17243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23685), 1,
      anon_sym_RPAREN,
    ACTIONS(23687), 1,
      anon_sym_LT_DASH,
    STATE(17244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733123] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23689), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733138] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23691), 1,
      anon_sym_EQ,
    STATE(17246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733155] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23693), 1,
      anon_sym_then,
    STATE(11616), 1,
      sym_then_clause,
    STATE(17247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733172] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23693), 1,
      anon_sym_then,
    STATE(11668), 1,
      sym_then_clause,
    STATE(17248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733189] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23639), 1,
      anon_sym_then,
    STATE(12671), 1,
      sym_then_clause,
    STATE(17249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733206] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23639), 1,
      anon_sym_then,
    STATE(12691), 1,
      sym_then_clause,
    STATE(17250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733223] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23695), 1,
      anon_sym_then,
    STATE(10633), 1,
      sym_then_clause,
    STATE(17251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(13119), 1,
      sym_then_clause,
    STATE(17252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733257] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23693), 1,
      anon_sym_then,
    STATE(11602), 1,
      sym_then_clause,
    STATE(17253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733274] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23693), 1,
      anon_sym_then,
    STATE(11578), 1,
      sym_then_clause,
    STATE(17254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733291] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23697), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733306] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23699), 1,
      anon_sym_DOT,
    STATE(17256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733323] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18347), 1,
      sym__lowercase_identifier,
    STATE(17257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23701), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733355] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23703), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [733370] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23705), 1,
      anon_sym_RPAREN,
    ACTIONS(23707), 1,
      anon_sym_LT_DASH,
    STATE(17260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733387] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23709), 1,
      anon_sym_RPAREN,
    STATE(17261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733404] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23711), 1,
      sym__lowercase_identifier,
    ACTIONS(23713), 1,
      anon_sym_LPAREN,
    STATE(17262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733421] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23715), 1,
      anon_sym_DOT,
    STATE(17263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733438] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23717), 1,
      anon_sym_RPAREN,
    STATE(17264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733455] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23673), 1,
      anon_sym_then,
    STATE(8466), 1,
      sym_then_clause,
    STATE(17265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23719), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733487] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23721), 1,
      anon_sym_DOT,
    STATE(17267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733504] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17268), 1,
      sym_attribute,
    STATE(18642), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733521] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23723), 1,
      anon_sym_COLON_GT,
    ACTIONS(23725), 1,
      anon_sym_RPAREN,
    STATE(17269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733538] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23727), 1,
      anon_sym_EQ,
    STATE(17270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733555] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23677), 1,
      anon_sym_then,
    STATE(13014), 1,
      sym_then_clause,
    STATE(17271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733572] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17272), 1,
      sym_attribute,
    STATE(19999), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733589] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23729), 1,
      anon_sym_then,
    STATE(9881), 1,
      sym_then_clause,
    STATE(17273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733606] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23731), 1,
      anon_sym_do,
    STATE(8509), 1,
      sym_do_clause,
    STATE(17274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23733), 1,
      sym__lowercase_identifier,
    ACTIONS(23735), 1,
      anon_sym_LBRACK,
    STATE(17275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733640] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15382), 1,
      sym__simple_value_pattern,
    STATE(17276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733657] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23737), 1,
      anon_sym_DOT,
    STATE(17277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23739), 1,
      anon_sym_COLON_GT,
    ACTIONS(23741), 1,
      anon_sym_EQ,
    STATE(17278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733691] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17279), 1,
      sym_attribute,
    STATE(20719), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733708] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23743), 1,
      anon_sym_COLON_GT,
    ACTIONS(23745), 1,
      anon_sym_EQ,
    STATE(17280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23747), 1,
      anon_sym_DOT,
    STATE(17281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733742] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23749), 1,
      sym__lowercase_identifier,
    ACTIONS(23751), 1,
      anon_sym_LPAREN,
    STATE(17282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733759] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23753), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23755), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23757), 1,
      sym__lowercase_identifier,
    ACTIONS(23759), 1,
      anon_sym_LBRACK,
    STATE(17285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23761), 1,
      anon_sym_RPAREN,
    ACTIONS(23763), 1,
      anon_sym_SEMI,
    STATE(17286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733823] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23761), 1,
      anon_sym_RBRACK,
    ACTIONS(23765), 1,
      anon_sym_SEMI,
    STATE(17287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733840] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23761), 1,
      anon_sym_RBRACE,
    ACTIONS(23767), 1,
      anon_sym_SEMI,
    STATE(17288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733857] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23769), 1,
      anon_sym_RPAREN,
    STATE(17289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733874] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23771), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [733889] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23773), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [733904] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17292), 1,
      sym_attribute,
    STATE(21051), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733921] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23775), 1,
      anon_sym_EQ,
    STATE(17293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733938] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23777), 1,
      anon_sym_COLON_GT,
    ACTIONS(23779), 1,
      anon_sym_EQ,
    STATE(17294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733955] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23781), 1,
      sym__lowercase_identifier,
    ACTIONS(23783), 1,
      anon_sym_LPAREN,
    STATE(17295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733972] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23785), 1,
      sym__lowercase_identifier,
    ACTIONS(23787), 1,
      anon_sym_LPAREN,
    STATE(17296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [733989] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10041), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23789), 1,
      anon_sym_COLON_GT,
    ACTIONS(23791), 1,
      anon_sym_RPAREN,
    STATE(17298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734023] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17299), 1,
      sym_attribute,
    STATE(21170), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734040] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(23793), 1,
      anon_sym_RPAREN,
    STATE(17300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734057] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23795), 1,
      sym__lowercase_identifier,
    ACTIONS(23797), 1,
      anon_sym_LPAREN,
    STATE(17301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734074] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9894), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734091] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23799), 1,
      anon_sym_EQ,
    ACTIONS(23801), 1,
      anon_sym_RPAREN,
    STATE(17303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734108] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23803), 1,
      anon_sym_EQ,
    STATE(17304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734125] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23805), 1,
      anon_sym_EQ,
    STATE(17305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734142] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23807), 1,
      anon_sym_COLON_GT,
    ACTIONS(23809), 1,
      anon_sym_RPAREN,
    STATE(17306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734159] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23811), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [734174] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23813), 1,
      anon_sym_EQ,
    STATE(17308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734191] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17309), 1,
      sym_attribute,
    STATE(21224), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734208] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23815), 1,
      sym__lowercase_identifier,
    ACTIONS(23817), 1,
      anon_sym_LPAREN,
    STATE(17310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734225] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23819), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [734240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23821), 1,
      anon_sym_COLON_GT,
    ACTIONS(23823), 1,
      anon_sym_RPAREN,
    STATE(17312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734257] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23825), 1,
      sym__lowercase_identifier,
    STATE(17313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734274] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23827), 1,
      sym__lowercase_identifier,
    STATE(17314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734291] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23829), 1,
      anon_sym_RPAREN,
    STATE(17315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18651), 1,
      anon_sym_RBRACE,
    ACTIONS(23831), 1,
      anon_sym_SEMI,
    STATE(17316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734325] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23833), 1,
      sym__lowercase_identifier,
    STATE(17317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734342] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23835), 1,
      anon_sym_RPAREN,
    STATE(17318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734359] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23837), 1,
      sym__lowercase_identifier,
    STATE(17319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734376] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23839), 1,
      anon_sym_RPAREN,
    STATE(17320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734393] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10003), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734410] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23841), 1,
      anon_sym_COLON_GT,
    ACTIONS(23843), 1,
      anon_sym_RPAREN,
    STATE(17322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734427] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23845), 1,
      sym__lowercase_identifier,
    STATE(17323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734444] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23847), 1,
      anon_sym_RPAREN,
    ACTIONS(23849), 1,
      anon_sym_LT_DASH,
    STATE(17324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734461] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23851), 1,
      anon_sym_RPAREN,
    STATE(17325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734478] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18733), 1,
      anon_sym_RBRACE,
    ACTIONS(23853), 1,
      anon_sym_SEMI,
    STATE(17326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734495] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23855), 1,
      anon_sym_RPAREN,
    ACTIONS(23857), 1,
      anon_sym_LT_DASH,
    STATE(17327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734512] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23859), 1,
      anon_sym_RPAREN,
    STATE(17328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734529] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23861), 1,
      anon_sym_RPAREN,
    ACTIONS(23863), 1,
      anon_sym_LT_DASH,
    STATE(17329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734546] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23865), 1,
      anon_sym_DOT,
    STATE(17330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734563] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23867), 1,
      anon_sym_RPAREN,
    STATE(17331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734580] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23869), 1,
      anon_sym_RPAREN,
    STATE(17332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734597] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23871), 1,
      sym__lowercase_identifier,
    ACTIONS(23873), 1,
      anon_sym_LPAREN,
    STATE(17333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734614] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23875), 1,
      anon_sym_RPAREN,
    STATE(17334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734631] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23877), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [734646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23879), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [734661] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23597), 1,
      anon_sym_then,
    STATE(9056), 1,
      sym_then_clause,
    STATE(17337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734678] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23881), 1,
      anon_sym_then,
    STATE(8607), 1,
      sym_then_clause,
    STATE(17338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734695] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17339), 1,
      sym_attribute,
    STATE(19756), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734712] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23883), 1,
      anon_sym_EQ,
    STATE(17340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734729] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23885), 1,
      anon_sym_RPAREN,
    ACTIONS(23887), 1,
      anon_sym_LT_DASH,
    STATE(17341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734746] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17342), 1,
      sym_attribute,
    STATE(19541), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734763] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23889), 1,
      anon_sym_RPAREN,
    ACTIONS(23891), 1,
      anon_sym_LT_DASH,
    STATE(17343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734780] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15538), 1,
      sym__simple_value_pattern,
    STATE(17344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734797] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23893), 1,
      anon_sym_DOT,
    STATE(17345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734814] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23895), 1,
      sym__lowercase_identifier,
    STATE(17346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734831] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23897), 1,
      anon_sym_COLON_GT,
    ACTIONS(23899), 1,
      anon_sym_EQ,
    STATE(17347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734848] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17348), 1,
      sym_attribute,
    STATE(19775), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734865] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_then,
    STATE(12575), 1,
      sym_then_clause,
    STATE(17349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734882] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23903), 1,
      anon_sym_DOT,
    STATE(17350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734899] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23905), 1,
      anon_sym_DOT,
    STATE(17351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23907), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [734931] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9976), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734948] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23909), 1,
      anon_sym_RPAREN,
    ACTIONS(23911), 1,
      anon_sym_SEMI,
    STATE(17354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734965] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23909), 1,
      anon_sym_RBRACK,
    ACTIONS(23913), 1,
      anon_sym_SEMI,
    STATE(17355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734982] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23909), 1,
      anon_sym_RBRACE,
    ACTIONS(23915), 1,
      anon_sym_SEMI,
    STATE(17356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [734999] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23917), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [735014] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23919), 1,
      anon_sym_EQ,
    STATE(17358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735031] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23921), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [735046] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17360), 1,
      sym_attribute,
    STATE(20016), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735063] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23923), 1,
      anon_sym_EQ,
    STATE(17361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735080] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23925), 1,
      anon_sym_COLON_GT,
    ACTIONS(23927), 1,
      anon_sym_EQ,
    STATE(17362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735097] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(13210), 1,
      sym_then_clause,
    STATE(17363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735114] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23929), 1,
      anon_sym_EQ,
    STATE(17364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735131] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23931), 1,
      anon_sym_do,
    STATE(8469), 1,
      sym_do_clause,
    STATE(17365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23933), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [735163] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17367), 1,
      sym_attribute,
    STATE(20165), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735180] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23935), 1,
      anon_sym_EQ,
    STATE(17368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735197] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23937), 1,
      anon_sym_EQ,
    STATE(17369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735214] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23939), 1,
      sym__lowercase_identifier,
    STATE(17370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735231] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23941), 1,
      anon_sym_EQ,
    STATE(17371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735248] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23943), 1,
      sym__lowercase_identifier,
    ACTIONS(23945), 1,
      anon_sym_LPAREN,
    STATE(17372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735265] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23947), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [735280] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18444), 1,
      sym__lowercase_identifier,
    STATE(17374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23949), 1,
      anon_sym_RPAREN,
    STATE(17375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735314] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23951), 1,
      anon_sym_RPAREN,
    ACTIONS(23953), 1,
      anon_sym_LT_DASH,
    STATE(17376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735331] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23955), 1,
      sym__lowercase_identifier,
    STATE(17377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735348] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23957), 1,
      anon_sym_DOT,
    STATE(17378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735365] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(23959), 1,
      sym__lowercase_identifier,
    STATE(17379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735382] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23961), 1,
      sym__lowercase_identifier,
    ACTIONS(23963), 1,
      anon_sym_LPAREN,
    STATE(17380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23965), 1,
      anon_sym_RPAREN,
    STATE(17381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735416] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_then,
    STATE(12852), 1,
      sym_then_clause,
    STATE(17382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23967), 1,
      sym__lowercase_identifier,
    ACTIONS(23969), 1,
      anon_sym_LPAREN,
    STATE(17383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23971), 1,
      sym__lowercase_identifier,
    ACTIONS(23973), 1,
      anon_sym_LPAREN,
    STATE(17384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735467] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23975), 1,
      anon_sym_COLON_GT,
    ACTIONS(23977), 1,
      anon_sym_RPAREN,
    STATE(17385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735484] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23979), 1,
      anon_sym_COLON_GT,
    ACTIONS(23981), 1,
      anon_sym_RPAREN,
    STATE(17386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735501] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23983), 1,
      anon_sym_DOT,
    STATE(17387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735518] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9908), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735535] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23985), 1,
      anon_sym_RPAREN,
    STATE(17389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735552] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23987), 1,
      sym__lowercase_identifier,
    ACTIONS(23989), 1,
      anon_sym_LBRACK,
    STATE(17390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23991), 1,
      anon_sym_COLON_GT,
    ACTIONS(23993), 1,
      anon_sym_RPAREN,
    STATE(17391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735586] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(23995), 1,
      sym__lowercase_identifier,
    STATE(17392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(23997), 1,
      anon_sym_DOT,
    STATE(17393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735620] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(23999), 1,
      anon_sym_RPAREN,
    STATE(17394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735637] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24001), 1,
      anon_sym_then,
    STATE(8477), 1,
      sym_then_clause,
    STATE(17395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24003), 1,
      sym__lowercase_identifier,
    STATE(17396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24005), 1,
      anon_sym_RPAREN,
    STATE(17397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735688] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17398), 1,
      sym_attribute,
    STATE(18991), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24007), 1,
      anon_sym_EQ,
    STATE(17399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735722] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17400), 1,
      sym_attribute,
    STATE(18857), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24009), 1,
      sym__lowercase_identifier,
    STATE(17401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15641), 1,
      sym__simple_value_pattern,
    STATE(17402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735773] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24011), 1,
      anon_sym_DOT,
    STATE(17403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24013), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [735805] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24015), 1,
      anon_sym_DOT,
    STATE(17405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735822] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(17406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11602), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [735837] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24017), 1,
      anon_sym_RPAREN,
    STATE(17407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735854] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24019), 1,
      anon_sym_RPAREN,
    ACTIONS(24021), 1,
      anon_sym_SEMI,
    STATE(17408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735871] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24019), 1,
      anon_sym_RBRACK,
    ACTIONS(24023), 1,
      anon_sym_SEMI,
    STATE(17409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735888] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24019), 1,
      anon_sym_RBRACE,
    ACTIONS(24025), 1,
      anon_sym_SEMI,
    STATE(17410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24027), 1,
      anon_sym_COLON_GT,
    ACTIONS(24029), 1,
      anon_sym_RPAREN,
    STATE(17411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24031), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [735937] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17413), 1,
      sym_attribute,
    STATE(19012), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735954] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24033), 1,
      anon_sym_RPAREN,
    STATE(17414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735971] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9892), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [735988] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18448), 1,
      sym__lowercase_identifier,
    STATE(17416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736005] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17417), 1,
      sym_attribute,
    STATE(19077), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736022] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(17418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11451), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [736037] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24035), 1,
      sym__lowercase_identifier,
    STATE(17419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736054] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24037), 1,
      sym__lowercase_identifier,
    STATE(17420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736071] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24039), 1,
      anon_sym_RPAREN,
    ACTIONS(24041), 1,
      anon_sym_LT_DASH,
    STATE(17421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736088] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24043), 1,
      aux_sym_type_variable_token1,
    STATE(13733), 1,
      sym_type_variable,
    STATE(17422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736105] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24045), 1,
      anon_sym_RPAREN,
    STATE(17423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736122] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(17424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11608), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [736137] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23597), 1,
      anon_sym_then,
    STATE(8993), 1,
      sym_then_clause,
    STATE(17425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736154] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23931), 1,
      anon_sym_do,
    STATE(8513), 1,
      sym_do_clause,
    STATE(17426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736171] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24047), 1,
      anon_sym_RPAREN,
    ACTIONS(24049), 1,
      anon_sym_LT_DASH,
    STATE(17427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736188] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24051), 1,
      sym__lowercase_identifier,
    STATE(17428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736205] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24053), 1,
      anon_sym_RPAREN,
    STATE(17429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736222] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24055), 1,
      anon_sym_RPAREN,
    STATE(17430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736239] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24057), 1,
      aux_sym_type_variable_token1,
    STATE(8545), 1,
      sym_type_variable,
    STATE(17431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736256] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24059), 1,
      anon_sym_DOT,
    STATE(17432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736273] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24061), 1,
      anon_sym_RPAREN,
    ACTIONS(24063), 1,
      anon_sym_LT_DASH,
    STATE(17433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736290] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24065), 1,
      anon_sym_RPAREN,
    STATE(17434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736307] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24067), 1,
      anon_sym_COLON_GT,
    ACTIONS(24069), 1,
      anon_sym_RPAREN,
    STATE(17435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736324] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24071), 1,
      anon_sym_then,
    STATE(8995), 1,
      sym_then_clause,
    STATE(17436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736341] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17437), 1,
      sym_attribute,
    STATE(18674), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736358] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24073), 1,
      anon_sym_EQ,
    STATE(17438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736375] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17439), 1,
      sym_attribute,
    STATE(20084), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736392] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15729), 1,
      sym__simple_value_pattern,
    STATE(17440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736409] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24075), 1,
      anon_sym_RPAREN,
    ACTIONS(24077), 1,
      anon_sym_LT_DASH,
    STATE(17441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24079), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [736441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24081), 1,
      anon_sym_DOT,
    STATE(17443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736458] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24083), 1,
      anon_sym_RPAREN,
    ACTIONS(24085), 1,
      anon_sym_SEMI,
    STATE(17444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736475] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24083), 1,
      anon_sym_RBRACK,
    ACTIONS(24087), 1,
      anon_sym_SEMI,
    STATE(17445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736492] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24083), 1,
      anon_sym_RBRACE,
    ACTIONS(24089), 1,
      anon_sym_SEMI,
    STATE(17446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736509] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24091), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [736524] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17448), 1,
      sym_attribute,
    STATE(20212), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24093), 1,
      anon_sym_RPAREN,
    ACTIONS(24095), 1,
      anon_sym_LT_DASH,
    STATE(17449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736558] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24097), 1,
      anon_sym_RPAREN,
    ACTIONS(24099), 1,
      anon_sym_LT_DASH,
    STATE(17450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736575] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17451), 1,
      sym_attribute,
    STATE(20272), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736592] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24101), 1,
      sym__lowercase_identifier,
    ACTIONS(24103), 1,
      anon_sym_LPAREN,
    STATE(17452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24105), 1,
      anon_sym_RPAREN,
    STATE(17453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736626] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24107), 1,
      anon_sym_DOT,
    STATE(17454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736643] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(15096), 2,
      anon_sym_and,
      anon_sym_in,
  [736658] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24109), 1,
      sym__lowercase_identifier,
    ACTIONS(24111), 1,
      anon_sym_LPAREN,
    STATE(17456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736675] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9898), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736692] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24113), 1,
      anon_sym_then,
    STATE(10121), 1,
      sym_then_clause,
    STATE(17458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24115), 1,
      anon_sym_RPAREN,
    STATE(17459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736726] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24117), 1,
      anon_sym_RPAREN,
    ACTIONS(24119), 1,
      anon_sym_LT_DASH,
    STATE(17460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24121), 1,
      sym__lowercase_identifier,
    STATE(17461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736760] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24123), 1,
      sym__lowercase_identifier,
    ACTIONS(24125), 1,
      anon_sym_LPAREN,
    STATE(17462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736777] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24127), 1,
      anon_sym_RPAREN,
    STATE(17463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24129), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [736809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24131), 1,
      anon_sym_DOT,
    STATE(17465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24133), 2,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [736841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24135), 1,
      anon_sym_SEMI,
    ACTIONS(24137), 1,
      anon_sym_RBRACE,
    STATE(17467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736858] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24139), 1,
      anon_sym_COLON_GT,
    ACTIONS(24141), 1,
      anon_sym_RPAREN,
    STATE(17468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736875] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24143), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [736890] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23881), 1,
      anon_sym_then,
    STATE(8643), 1,
      sym_then_clause,
    STATE(17470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736907] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17471), 1,
      sym_attribute,
    STATE(18941), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736924] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24145), 1,
      anon_sym_EQ,
    STATE(17472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736941] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17473), 1,
      sym_attribute,
    STATE(20788), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736958] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24147), 1,
      sym__lowercase_identifier,
    ACTIONS(24149), 1,
      anon_sym_LPAREN,
    STATE(17474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736975] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24151), 1,
      anon_sym_RPAREN,
    ACTIONS(24153), 1,
      anon_sym_LT_DASH,
    STATE(17475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [736992] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18343), 1,
      sym__lowercase_identifier,
    STATE(17476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737009] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24155), 1,
      anon_sym_DOT,
    STATE(17477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737026] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24157), 1,
      anon_sym_RPAREN,
    ACTIONS(24159), 1,
      anon_sym_SEMI,
    STATE(17478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737043] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24157), 1,
      anon_sym_RBRACK,
    ACTIONS(24161), 1,
      anon_sym_SEMI,
    STATE(17479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737060] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24157), 1,
      anon_sym_RBRACE,
    ACTIONS(24163), 1,
      anon_sym_SEMI,
    STATE(17480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737077] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24165), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [737092] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17482), 1,
      sym_attribute,
    STATE(20915), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737109] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24167), 1,
      anon_sym_RPAREN,
    STATE(17483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737126] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24169), 1,
      anon_sym_EQ,
    ACTIONS(24171), 1,
      anon_sym_RPAREN,
    STATE(17484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737143] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24173), 1,
      anon_sym_SEMI,
    ACTIONS(24175), 1,
      anon_sym_RBRACE,
    STATE(17485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737160] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17486), 1,
      sym_attribute,
    STATE(20962), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737177] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19027), 1,
      anon_sym_RBRACK,
    ACTIONS(19283), 1,
      anon_sym_as,
    STATE(17487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737194] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18905), 1,
      anon_sym_RBRACE,
    ACTIONS(24177), 1,
      anon_sym_SEMI,
    STATE(17488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737211] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24179), 1,
      sym__lowercase_identifier,
    STATE(17489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737228] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18913), 1,
      anon_sym_RBRACE,
    ACTIONS(24181), 1,
      anon_sym_SEMI,
    STATE(17490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737245] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24183), 1,
      anon_sym_EQ,
    STATE(17491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737262] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24185), 1,
      anon_sym_then,
    STATE(12758), 1,
      sym_then_clause,
    STATE(17492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737279] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24187), 1,
      anon_sym_DOT,
    STATE(17493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737296] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24189), 1,
      anon_sym_DOT,
    STATE(17494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737313] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24191), 1,
      anon_sym_COLON_GT,
    ACTIONS(24193), 1,
      anon_sym_RPAREN,
    STATE(17495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737330] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24195), 1,
      anon_sym_RPAREN,
    STATE(17496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737347] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24197), 1,
      anon_sym_RPAREN,
    STATE(17497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737364] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24199), 1,
      anon_sym_RPAREN,
    STATE(17498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24113), 1,
      anon_sym_then,
    STATE(10119), 1,
      sym_then_clause,
    STATE(17499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737398] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24201), 1,
      anon_sym_then,
    STATE(8652), 1,
      sym_then_clause,
    STATE(17500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24203), 1,
      anon_sym_RPAREN,
    STATE(17501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737432] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24205), 1,
      anon_sym_RPAREN,
    STATE(17502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737449] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17503), 1,
      sym_attribute,
    STATE(18479), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737466] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24207), 1,
      anon_sym_EQ,
    STATE(17504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737483] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17505), 1,
      sym_attribute,
    STATE(20342), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737500] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24209), 1,
      anon_sym_DOT,
    STATE(17506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737517] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24211), 1,
      sym__lowercase_identifier,
    ACTIONS(24213), 1,
      anon_sym_LPAREN,
    STATE(17507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737534] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24215), 1,
      anon_sym_RPAREN,
    ACTIONS(24217), 1,
      anon_sym_SEMI,
    STATE(17508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737551] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24215), 1,
      anon_sym_RBRACK,
    ACTIONS(24219), 1,
      anon_sym_SEMI,
    STATE(17509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737568] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24215), 1,
      anon_sym_RBRACE,
    ACTIONS(24221), 1,
      anon_sym_SEMI,
    STATE(17510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737585] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24223), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [737600] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17512), 1,
      sym_attribute,
    STATE(19165), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737617] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24225), 1,
      anon_sym_RPAREN,
    ACTIONS(24227), 1,
      anon_sym_LT_DASH,
    STATE(17513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737634] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24229), 1,
      sym__lowercase_identifier,
    STATE(17514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737651] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24231), 1,
      anon_sym_COLON_GT,
    ACTIONS(24233), 1,
      anon_sym_RPAREN,
    STATE(17515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737668] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24235), 1,
      anon_sym_RPAREN,
    STATE(17516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737685] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24237), 1,
      anon_sym_SEMI,
    ACTIONS(24239), 1,
      anon_sym_RBRACE,
    STATE(17517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737702] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24241), 1,
      anon_sym_SEMI,
    ACTIONS(24243), 1,
      anon_sym_RBRACE,
    STATE(17518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737719] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24245), 1,
      anon_sym_RPAREN,
    STATE(17519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737736] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24247), 1,
      anon_sym_DOT,
    STATE(17520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737753] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9922), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737770] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23931), 1,
      anon_sym_do,
    STATE(8456), 1,
      sym_do_clause,
    STATE(17522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737787] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24249), 1,
      anon_sym_RPAREN,
    ACTIONS(24251), 1,
      anon_sym_LT_DASH,
    STATE(17523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737804] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23673), 1,
      anon_sym_then,
    STATE(8561), 1,
      sym_then_clause,
    STATE(17524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737821] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24253), 1,
      anon_sym_EQ,
    STATE(17525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737838] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17526), 1,
      sym_attribute,
    STATE(18796), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737855] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24255), 1,
      anon_sym_DOT,
    STATE(17527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737872] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23931), 1,
      anon_sym_do,
    STATE(8463), 1,
      sym_do_clause,
    STATE(17528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737889] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24257), 1,
      anon_sym_do,
    STATE(8179), 1,
      sym_do_clause,
    STATE(17529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737906] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24259), 1,
      anon_sym_RPAREN,
    ACTIONS(24261), 1,
      anon_sym_SEMI,
    STATE(17530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737923] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24259), 1,
      anon_sym_RBRACK,
    ACTIONS(24263), 1,
      anon_sym_SEMI,
    STATE(17531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737940] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24259), 1,
      anon_sym_RBRACE,
    ACTIONS(24265), 1,
      anon_sym_SEMI,
    STATE(17532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737957] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24267), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [737972] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24269), 1,
      anon_sym_RPAREN,
    ACTIONS(24271), 1,
      anon_sym_LT_DASH,
    STATE(17534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [737989] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24273), 1,
      anon_sym_RPAREN,
    ACTIONS(24275), 1,
      anon_sym_LT_DASH,
    STATE(17535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738006] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17536), 1,
      sym_attribute,
    STATE(18794), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738023] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24277), 1,
      sym__lowercase_identifier,
    STATE(17537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24279), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [738055] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24281), 1,
      anon_sym_RPAREN,
    ACTIONS(24283), 1,
      anon_sym_LT_DASH,
    STATE(17539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738072] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24285), 1,
      anon_sym_then,
    STATE(13301), 1,
      sym_then_clause,
    STATE(17540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738089] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24287), 1,
      anon_sym_RPAREN,
    STATE(17541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24289), 1,
      anon_sym_DOT,
    STATE(17542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738123] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24291), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [738138] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24293), 1,
      anon_sym_DOT,
    STATE(17544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738155] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24295), 1,
      sym__lowercase_identifier,
    STATE(17545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738172] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24001), 1,
      anon_sym_then,
    STATE(8461), 1,
      sym_then_clause,
    STATE(17546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738189] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24297), 1,
      anon_sym_EQ,
    ACTIONS(24299), 1,
      anon_sym_RPAREN,
    STATE(17547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738206] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24301), 1,
      anon_sym_EQ,
    STATE(17548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738223] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17549), 1,
      sym_attribute,
    STATE(21145), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24303), 1,
      sym__lowercase_identifier,
    STATE(17550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738257] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24305), 1,
      anon_sym_DOT,
    STATE(17551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738274] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24307), 1,
      sym__lowercase_identifier,
    STATE(17552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738291] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24309), 1,
      anon_sym_RPAREN,
    ACTIONS(24311), 1,
      anon_sym_SEMI,
    STATE(17553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24309), 1,
      anon_sym_RBRACK,
    ACTIONS(24313), 1,
      anon_sym_SEMI,
    STATE(17554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738325] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24309), 1,
      anon_sym_RBRACE,
    ACTIONS(24315), 1,
      anon_sym_SEMI,
    STATE(17555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24317), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [738357] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24319), 1,
      anon_sym_RPAREN,
    ACTIONS(24321), 1,
      anon_sym_LT_DASH,
    STATE(17557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738374] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24323), 1,
      anon_sym_then,
    STATE(12862), 1,
      sym_then_clause,
    STATE(17558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738391] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24325), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [738406] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17560), 1,
      sym_attribute,
    STATE(20054), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738423] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24327), 1,
      anon_sym_RPAREN,
    STATE(17561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738440] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24329), 1,
      anon_sym_RPAREN,
    STATE(17562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738457] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24331), 1,
      anon_sym_RPAREN,
    ACTIONS(24333), 1,
      anon_sym_LT_DASH,
    STATE(17563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738474] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24335), 1,
      anon_sym_RPAREN,
    STATE(17564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738491] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24337), 1,
      anon_sym_DOT,
    STATE(17565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738508] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_then,
    STATE(12756), 1,
      sym_then_clause,
    STATE(17566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738525] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24339), 1,
      anon_sym_COLON_GT,
    ACTIONS(24341), 1,
      anon_sym_RPAREN,
    STATE(17567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738542] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24343), 1,
      anon_sym_then,
    STATE(12978), 1,
      sym_then_clause,
    STATE(17568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738559] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24345), 1,
      sym__lowercase_identifier,
    STATE(17569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738576] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23881), 1,
      anon_sym_then,
    STATE(8623), 1,
      sym_then_clause,
    STATE(17570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738593] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24347), 1,
      sym__lowercase_identifier,
    ACTIONS(24349), 1,
      anon_sym_LPAREN,
    STATE(17571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24351), 2,
      anon_sym_SEMI,
      anon_sym_GT,
  [738625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17573), 1,
      sym_attribute,
    STATE(18853), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738642] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24353), 1,
      anon_sym_do,
    STATE(11207), 1,
      sym_do_clause,
    STATE(17574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738659] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24355), 1,
      sym__lowercase_identifier,
    STATE(17575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738676] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24357), 1,
      anon_sym_DOT,
    STATE(17576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738693] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24359), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [738708] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24361), 1,
      anon_sym_RPAREN,
    ACTIONS(24363), 1,
      anon_sym_LT_DASH,
    STATE(17578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24365), 1,
      anon_sym_RPAREN,
    ACTIONS(24367), 1,
      anon_sym_SEMI,
    STATE(17579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738742] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24365), 1,
      anon_sym_RBRACK,
    ACTIONS(24369), 1,
      anon_sym_SEMI,
    STATE(17580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738759] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24365), 1,
      anon_sym_RBRACE,
    ACTIONS(24371), 1,
      anon_sym_SEMI,
    STATE(17581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24373), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [738791] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23695), 1,
      anon_sym_then,
    STATE(10718), 1,
      sym_then_clause,
    STATE(17583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738808] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24375), 1,
      sym__lowercase_identifier,
    STATE(17584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738825] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23729), 1,
      anon_sym_then,
    STATE(9913), 1,
      sym_then_clause,
    STATE(17585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738842] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17586), 1,
      sym_attribute,
    STATE(20340), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738859] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24257), 1,
      anon_sym_do,
    STATE(8183), 1,
      sym_do_clause,
    STATE(17587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24377), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [738891] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18512), 1,
      anon_sym_COLON2,
    STATE(17589), 1,
      sym_attribute,
    STATE(17944), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738908] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24379), 1,
      anon_sym_RPAREN,
    ACTIONS(24381), 1,
      anon_sym_LT_DASH,
    STATE(17590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738925] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24383), 1,
      anon_sym_DOT,
    STATE(17591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24385), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [738957] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18498), 1,
      sym__lowercase_identifier,
    STATE(17593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738974] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24201), 1,
      anon_sym_then,
    STATE(8616), 1,
      sym_then_clause,
    STATE(17594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [738991] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23633), 1,
      anon_sym_then,
    STATE(10806), 1,
      sym_then_clause,
    STATE(17595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739008] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17596), 1,
      sym_attribute,
    STATE(19545), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739025] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24387), 1,
      anon_sym_RPAREN,
    STATE(17597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739042] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17598), 1,
      sym_attribute,
    STATE(20226), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24389), 1,
      anon_sym_DOT,
    STATE(17599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739076] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24071), 1,
      anon_sym_then,
    STATE(9020), 1,
      sym_then_clause,
    STATE(17600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739093] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21696), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [739108] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24391), 1,
      anon_sym_RPAREN,
    STATE(17602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739125] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24393), 1,
      anon_sym_RPAREN,
    ACTIONS(24395), 1,
      anon_sym_SEMI,
    STATE(17603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739142] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24393), 1,
      anon_sym_RBRACK,
    ACTIONS(24397), 1,
      anon_sym_SEMI,
    STATE(17604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739159] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24393), 1,
      anon_sym_RBRACE,
    ACTIONS(24399), 1,
      anon_sym_SEMI,
    STATE(17605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24401), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [739191] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24403), 1,
      anon_sym_DOT,
    STATE(17607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739208] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17608), 1,
      sym_attribute,
    STATE(20071), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739225] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24405), 1,
      anon_sym_RPAREN,
    ACTIONS(24407), 1,
      anon_sym_LT_DASH,
    STATE(17609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739242] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24409), 1,
      anon_sym_RPAREN,
    STATE(17610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739259] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23729), 1,
      anon_sym_then,
    STATE(9803), 1,
      sym_then_clause,
    STATE(17611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739276] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24411), 1,
      anon_sym_RPAREN,
    ACTIONS(24413), 1,
      anon_sym_LT_DASH,
    STATE(17612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739293] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24415), 1,
      anon_sym_RPAREN,
    ACTIONS(24417), 1,
      anon_sym_LT_DASH,
    STATE(17613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739310] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24419), 1,
      anon_sym_DOT,
    STATE(17614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739327] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24421), 1,
      sym__lowercase_identifier,
    STATE(17615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739344] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24423), 1,
      anon_sym_DOT,
    STATE(17616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739361] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24425), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [739376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24427), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [739391] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24429), 1,
      sym__lowercase_identifier,
    ACTIONS(24431), 1,
      anon_sym_LPAREN,
    STATE(17619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739408] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17620), 1,
      sym_attribute,
    STATE(21336), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739425] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24433), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [739440] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24435), 1,
      anon_sym_DOT,
    STATE(17622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739457] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24257), 1,
      anon_sym_do,
    STATE(8209), 1,
      sym_do_clause,
    STATE(17623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739474] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24437), 1,
      anon_sym_COLON_GT,
    ACTIONS(24439), 1,
      anon_sym_RPAREN,
    STATE(17624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739491] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24343), 1,
      anon_sym_then,
    STATE(13332), 1,
      sym_then_clause,
    STATE(17625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739508] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24441), 1,
      anon_sym_RPAREN,
    ACTIONS(24443), 1,
      anon_sym_SEMI,
    STATE(17626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739525] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24441), 1,
      anon_sym_RBRACK,
    ACTIONS(24445), 1,
      anon_sym_SEMI,
    STATE(17627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739542] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24441), 1,
      anon_sym_RBRACE,
    ACTIONS(24447), 1,
      anon_sym_SEMI,
    STATE(17628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739559] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24449), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [739574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24451), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [739589] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24453), 1,
      anon_sym_RPAREN,
    ACTIONS(24455), 1,
      anon_sym_LT_DASH,
    STATE(17631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739606] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9952), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17633), 1,
      sym_attribute,
    STATE(20049), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739640] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24457), 1,
      sym__lowercase_identifier,
    ACTIONS(24459), 1,
      anon_sym_LPAREN,
    STATE(17634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739657] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24461), 1,
      anon_sym_RPAREN,
    STATE(17635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24463), 1,
      sym__lowercase_identifier,
    ACTIONS(24465), 1,
      anon_sym_LPAREN,
    STATE(17636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739691] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18456), 1,
      sym__lowercase_identifier,
    STATE(17637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739708] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24467), 1,
      anon_sym_DOT,
    STATE(17638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18440), 1,
      sym__lowercase_identifier,
    STATE(17639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24469), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [739757] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24471), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [739772] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17642), 1,
      sym_attribute,
    STATE(19343), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24473), 1,
      anon_sym_DOT,
    STATE(17643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24475), 1,
      anon_sym_RPAREN,
    ACTIONS(24477), 1,
      anon_sym_SEMI,
    STATE(17644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739823] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24475), 1,
      anon_sym_RBRACK,
    ACTIONS(24479), 1,
      anon_sym_SEMI,
    STATE(17645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739840] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24475), 1,
      anon_sym_RBRACE,
    ACTIONS(24481), 1,
      anon_sym_SEMI,
    STATE(17646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739857] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24483), 1,
      sym__lowercase_identifier,
    ACTIONS(24485), 1,
      anon_sym_LPAREN,
    STATE(17647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739874] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17648), 1,
      sym_attribute,
    STATE(20931), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739891] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24487), 1,
      sym__lowercase_identifier,
    STATE(17649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739908] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24489), 1,
      anon_sym_DOT,
    STATE(17650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739925] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(17651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(11648), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [739940] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17652), 1,
      sym_attribute,
    STATE(19103), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739957] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24491), 1,
      anon_sym_DOT,
    STATE(17653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739974] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24493), 1,
      anon_sym_RPAREN,
    STATE(17654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [739991] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24495), 1,
      anon_sym_DOT,
    STATE(17655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740008] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24497), 1,
      anon_sym_RPAREN,
    ACTIONS(24499), 1,
      anon_sym_SEMI,
    STATE(17656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740025] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24497), 1,
      anon_sym_RBRACK,
    ACTIONS(24501), 1,
      anon_sym_SEMI,
    STATE(17657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740042] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24497), 1,
      anon_sym_RBRACE,
    ACTIONS(24503), 1,
      anon_sym_SEMI,
    STATE(17658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24505), 1,
      sym__lowercase_identifier,
    STATE(17659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740076] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17660), 1,
      sym_attribute,
    STATE(20065), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740093] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24285), 1,
      anon_sym_then,
    STATE(13101), 1,
      sym_then_clause,
    STATE(17661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740110] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24507), 1,
      anon_sym_COLON_GT,
    ACTIONS(24509), 1,
      anon_sym_RPAREN,
    STATE(17662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740127] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24511), 1,
      anon_sym_DOT,
    STATE(17663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740144] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24513), 1,
      anon_sym_DOT,
    STATE(17664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24515), 1,
      sym__lowercase_identifier,
    STATE(17665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740178] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24517), 1,
      anon_sym_COLON_GT,
    ACTIONS(24519), 1,
      anon_sym_RPAREN,
    STATE(17666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740195] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24521), 1,
      sym__lowercase_identifier,
    ACTIONS(24523), 1,
      anon_sym_LPAREN,
    STATE(17667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740212] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24525), 1,
      anon_sym_RPAREN,
    STATE(17668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740229] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17669), 1,
      sym_attribute,
    STATE(19172), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740246] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24527), 1,
      anon_sym_SEMI,
    ACTIONS(24529), 1,
      anon_sym_RBRACE,
    STATE(17670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740263] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24531), 1,
      anon_sym_DOT,
    STATE(17671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740280] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24533), 1,
      anon_sym_COLON2,
    STATE(12451), 1,
      sym__polymorphic_typed,
    STATE(17672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24533), 1,
      anon_sym_COLON2,
    STATE(12515), 1,
      sym__polymorphic_typed,
    STATE(17673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740314] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24535), 1,
      anon_sym_RPAREN,
    ACTIONS(24537), 1,
      anon_sym_SEMI,
    STATE(17674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740331] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24535), 1,
      anon_sym_RBRACK,
    ACTIONS(24539), 1,
      anon_sym_SEMI,
    STATE(17675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740348] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24535), 1,
      anon_sym_RBRACE,
    ACTIONS(24541), 1,
      anon_sym_SEMI,
    STATE(17676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740365] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24543), 1,
      anon_sym_RPAREN,
    STATE(17677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740382] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24545), 1,
      sym__lowercase_identifier,
    STATE(17678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24547), 1,
      anon_sym_RPAREN,
    ACTIONS(24549), 1,
      anon_sym_LT_DASH,
    STATE(17679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740416] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17680), 1,
      sym_attribute,
    STATE(19697), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24551), 1,
      anon_sym_DOT,
    STATE(17681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24553), 1,
      anon_sym_RPAREN,
    ACTIONS(24555), 1,
      anon_sym_LT_DASH,
    STATE(17682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740467] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24557), 1,
      anon_sym_RPAREN,
    STATE(17683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740484] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24559), 1,
      anon_sym_RPAREN,
    STATE(17684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740501] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17685), 1,
      sym_attribute,
    STATE(21041), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740518] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9906), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740535] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24561), 1,
      anon_sym_DOT,
    STATE(17687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740552] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24563), 1,
      anon_sym_RPAREN,
    STATE(17688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23597), 1,
      anon_sym_then,
    STATE(9038), 1,
      sym_then_clause,
    STATE(17689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740586] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24565), 1,
      anon_sym_COLON2,
    STATE(17690), 1,
      sym_attribute,
    STATE(19825), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24567), 1,
      anon_sym_RPAREN,
    ACTIONS(24569), 1,
      anon_sym_SEMI,
    STATE(17691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740620] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24567), 1,
      anon_sym_RBRACK,
    ACTIONS(24571), 1,
      anon_sym_SEMI,
    STATE(17692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740637] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24567), 1,
      anon_sym_RBRACE,
    ACTIONS(24573), 1,
      anon_sym_SEMI,
    STATE(17693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23633), 1,
      anon_sym_then,
    STATE(10845), 1,
      sym_then_clause,
    STATE(17694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17695), 1,
      sym_attribute,
    STATE(21352), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24575), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [740703] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24577), 1,
      anon_sym_COLON_GT,
    ACTIONS(24579), 1,
      anon_sym_RPAREN,
    STATE(17697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740720] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24581), 1,
      anon_sym_DOT,
    STATE(17698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740737] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24583), 1,
      anon_sym_RPAREN,
    ACTIONS(24585), 1,
      anon_sym_LT_DASH,
    STATE(17699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740754] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24587), 1,
      anon_sym_RPAREN,
    STATE(17700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740771] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24323), 1,
      anon_sym_then,
    STATE(12657), 1,
      sym_then_clause,
    STATE(17701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740788] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24589), 1,
      anon_sym_then,
    STATE(12880), 1,
      sym_then_clause,
    STATE(17702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740805] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17703), 1,
      sym_attribute,
    STATE(20086), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24591), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [740837] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24593), 1,
      anon_sym_RPAREN,
    ACTIONS(24595), 1,
      anon_sym_LT_DASH,
    STATE(17705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740854] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24597), 1,
      anon_sym_DOT,
    STATE(17706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740871] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24599), 1,
      anon_sym_COLON2,
    STATE(13951), 1,
      sym__typed,
    STATE(17707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740888] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24589), 1,
      anon_sym_then,
    STATE(12712), 1,
      sym_then_clause,
    STATE(17708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740905] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24601), 1,
      anon_sym_RPAREN,
    ACTIONS(24603), 1,
      anon_sym_SEMI,
    STATE(17709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740922] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24601), 1,
      anon_sym_RBRACK,
    ACTIONS(24605), 1,
      anon_sym_SEMI,
    STATE(17710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740939] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24601), 1,
      anon_sym_RBRACE,
    ACTIONS(24607), 1,
      anon_sym_SEMI,
    STATE(17711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24609), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [740971] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17713), 1,
      sym_attribute,
    STATE(18691), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [740988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24611), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [741003] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24001), 1,
      anon_sym_then,
    STATE(8459), 1,
      sym_then_clause,
    STATE(17715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741020] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24613), 1,
      anon_sym_EQ,
    ACTIONS(24615), 1,
      anon_sym_RPAREN,
    STATE(17716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741037] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24617), 1,
      anon_sym_DOT,
    STATE(17717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741054] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24619), 1,
      anon_sym_RPAREN,
    ACTIONS(24621), 1,
      anon_sym_LT_DASH,
    STATE(17718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741071] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24623), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [741086] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24625), 1,
      sym__lowercase_identifier,
    STATE(17720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741103] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24627), 1,
      sym__lowercase_identifier,
    ACTIONS(24629), 1,
      anon_sym_LPAREN,
    STATE(17721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741120] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24631), 1,
      anon_sym_EQ,
    STATE(17722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741137] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17723), 1,
      sym_attribute,
    STATE(21065), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741154] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24633), 1,
      anon_sym_then,
    STATE(12436), 1,
      sym_then_clause,
    STATE(17724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741171] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24635), 1,
      anon_sym_DOT,
    STATE(17725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24637), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [741203] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24639), 1,
      anon_sym_RPAREN,
    ACTIONS(24641), 1,
      anon_sym_SEMI,
    STATE(17727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741220] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24639), 1,
      anon_sym_RBRACK,
    ACTIONS(24643), 1,
      anon_sym_SEMI,
    STATE(17728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741237] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24639), 1,
      anon_sym_RBRACE,
    ACTIONS(24645), 1,
      anon_sym_SEMI,
    STATE(17729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(18661), 2,
      anon_sym_SEMI,
      anon_sym_GT,
  [741269] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24647), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [741284] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18295), 1,
      sym__lowercase_identifier,
    STATE(17732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741301] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17733), 1,
      sym_attribute,
    STATE(18529), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24649), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [741333] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24651), 1,
      anon_sym_DOT,
    STATE(17735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741350] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24653), 1,
      sym__lowercase_identifier,
    STATE(17736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741367] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24655), 1,
      anon_sym_COLON_GT,
    ACTIONS(24657), 1,
      anon_sym_RPAREN,
    STATE(17737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741384] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17738), 1,
      sym_attribute,
    STATE(19230), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741401] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24659), 1,
      anon_sym_RPAREN,
    ACTIONS(24661), 1,
      anon_sym_LT_DASH,
    STATE(17739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741418] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24663), 1,
      anon_sym_DOT,
    STATE(17740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741435] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24665), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [741450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24667), 1,
      anon_sym_RPAREN,
    ACTIONS(24669), 1,
      anon_sym_SEMI,
    STATE(17742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741467] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24667), 1,
      anon_sym_RBRACK,
    ACTIONS(24671), 1,
      anon_sym_SEMI,
    STATE(17743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741484] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24667), 1,
      anon_sym_RBRACE,
    ACTIONS(24673), 1,
      anon_sym_SEMI,
    STATE(17744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741501] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24675), 1,
      anon_sym_COLON2,
    STATE(13959), 1,
      sym__polymorphic_typed,
    STATE(17745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741518] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24677), 1,
      anon_sym_RPAREN,
    STATE(17746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741535] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10049), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741552] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17748), 1,
      sym_attribute,
    STATE(19553), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18472), 1,
      sym__lowercase_identifier,
    STATE(17749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741586] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24679), 1,
      anon_sym_DOT,
    STATE(17750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24589), 1,
      anon_sym_then,
    STATE(12659), 1,
      sym_then_clause,
    STATE(17751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741620] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24681), 1,
      sym__lowercase_identifier,
    STATE(17752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741637] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17753), 1,
      sym_attribute,
    STATE(20716), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24683), 1,
      anon_sym_COLON_GT,
    ACTIONS(24685), 1,
      anon_sym_RPAREN,
    STATE(17754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24687), 1,
      anon_sym_DOT,
    STATE(17755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741688] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24689), 1,
      sym__lowercase_identifier,
    ACTIONS(24691), 1,
      anon_sym_LPAREN,
    STATE(17756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24693), 1,
      anon_sym_RPAREN,
    ACTIONS(24695), 1,
      anon_sym_SEMI,
    STATE(17757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741722] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24693), 1,
      anon_sym_RBRACK,
    ACTIONS(24697), 1,
      anon_sym_SEMI,
    STATE(17758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24693), 1,
      anon_sym_RBRACE,
    ACTIONS(24699), 1,
      anon_sym_SEMI,
    STATE(17759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24701), 1,
      anon_sym_RPAREN,
    ACTIONS(24703), 1,
      anon_sym_LT_DASH,
    STATE(17760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741773] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17761), 1,
      sym_attribute,
    STATE(21099), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741790] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24705), 1,
      sym__lowercase_identifier,
    STATE(17762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741807] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24707), 1,
      anon_sym_DOT,
    STATE(17763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741824] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24709), 1,
      anon_sym_EQ,
    ACTIONS(24711), 1,
      anon_sym_RPAREN,
    STATE(17764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24713), 1,
      anon_sym_COLON_GT,
    ACTIONS(24715), 1,
      anon_sym_RPAREN,
    STATE(17765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741858] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24717), 1,
      anon_sym_EQ,
    ACTIONS(24719), 1,
      anon_sym_RPAREN,
    STATE(17766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741875] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18707), 1,
      anon_sym_RBRACE,
    ACTIONS(24721), 1,
      anon_sym_SEMI,
    STATE(17767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741892] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17768), 1,
      sym_attribute,
    STATE(18628), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24723), 1,
      sym__lowercase_identifier,
    STATE(17769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741926] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24725), 1,
      anon_sym_SEMI,
    ACTIONS(24727), 1,
      anon_sym_RBRACE,
    STATE(17770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741943] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24729), 1,
      anon_sym_DOT,
    STATE(17771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741960] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18721), 1,
      anon_sym_RBRACE,
    ACTIONS(24731), 1,
      anon_sym_SEMI,
    STATE(17772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24733), 1,
      anon_sym_RPAREN,
    ACTIONS(24735), 1,
      anon_sym_SEMI,
    STATE(17773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [741994] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24733), 1,
      anon_sym_RBRACK,
    ACTIONS(24737), 1,
      anon_sym_SEMI,
    STATE(17774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742011] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24733), 1,
      anon_sym_RBRACE,
    ACTIONS(24739), 1,
      anon_sym_SEMI,
    STATE(17775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742028] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24741), 1,
      anon_sym_RPAREN,
    STATE(17776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17777), 1,
      sym_attribute,
    STATE(18759), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742062] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24743), 1,
      anon_sym_RPAREN,
    STATE(17778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742079] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24745), 1,
      anon_sym_DOT,
    STATE(17779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742096] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24747), 1,
      sym__lowercase_identifier,
    STATE(17780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742113] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24749), 1,
      sym__lowercase_identifier,
    STATE(17781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742130] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24751), 1,
      anon_sym_RPAREN,
    STATE(17782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742147] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17783), 1,
      sym_attribute,
    STATE(19062), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742164] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24753), 1,
      anon_sym_DOT,
    STATE(17784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742181] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24755), 1,
      anon_sym_RPAREN,
    ACTIONS(24757), 1,
      anon_sym_LT_DASH,
    STATE(17785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742198] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24759), 1,
      anon_sym_RPAREN,
    STATE(17786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742215] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24761), 1,
      anon_sym_RPAREN,
    ACTIONS(24763), 1,
      anon_sym_SEMI,
    STATE(17787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742232] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24761), 1,
      anon_sym_RBRACK,
    ACTIONS(24765), 1,
      anon_sym_SEMI,
    STATE(17788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742249] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24761), 1,
      anon_sym_RBRACE,
    ACTIONS(24767), 1,
      anon_sym_SEMI,
    STATE(17789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742266] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24769), 1,
      sym__lowercase_identifier,
    STATE(17790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742283] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17791), 1,
      sym_attribute,
    STATE(19168), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742300] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24771), 1,
      anon_sym_DOT,
    STATE(17792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742317] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24773), 1,
      anon_sym_RPAREN,
    ACTIONS(24775), 1,
      anon_sym_LT_DASH,
    STATE(17793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742334] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17794), 1,
      sym_attribute,
    STATE(19388), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742351] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24777), 1,
      anon_sym_RPAREN,
    ACTIONS(24779), 1,
      anon_sym_LT_DASH,
    STATE(17795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742368] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24781), 1,
      anon_sym_SEMI,
    ACTIONS(24783), 1,
      anon_sym_RBRACE,
    STATE(17796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742385] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24785), 1,
      anon_sym_SEMI,
    ACTIONS(24787), 1,
      anon_sym_RBRACE,
    STATE(17797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742402] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24789), 1,
      anon_sym_RPAREN,
    ACTIONS(24791), 1,
      anon_sym_SEMI,
    STATE(17798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742419] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24789), 1,
      anon_sym_RBRACK,
    ACTIONS(24793), 1,
      anon_sym_SEMI,
    STATE(17799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742436] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24789), 1,
      anon_sym_RBRACE,
    ACTIONS(24795), 1,
      anon_sym_SEMI,
    STATE(17800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742453] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24797), 1,
      anon_sym_DOT,
    STATE(17801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742470] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17802), 1,
      sym_attribute,
    STATE(19460), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742487] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24799), 1,
      anon_sym_RPAREN,
    STATE(17803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742504] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24801), 1,
      anon_sym_DOT,
    STATE(17804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742521] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24803), 1,
      anon_sym_RPAREN,
    ACTIONS(24805), 1,
      anon_sym_LT_DASH,
    STATE(17805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742538] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17806), 1,
      sym_attribute,
    STATE(19753), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742555] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24807), 1,
      anon_sym_RPAREN,
    ACTIONS(24809), 1,
      anon_sym_LT_DASH,
    STATE(17807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742572] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24811), 1,
      anon_sym_RPAREN,
    STATE(17808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742589] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24813), 1,
      anon_sym_RPAREN,
    ACTIONS(24815), 1,
      anon_sym_SEMI,
    STATE(17809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742606] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24813), 1,
      anon_sym_RBRACK,
    ACTIONS(24817), 1,
      anon_sym_SEMI,
    STATE(17810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742623] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24813), 1,
      anon_sym_RBRACE,
    ACTIONS(24819), 1,
      anon_sym_SEMI,
    STATE(17811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742640] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17812), 1,
      sym_attribute,
    STATE(19842), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742657] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24821), 1,
      anon_sym_DOT,
    STATE(17813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742674] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23677), 1,
      anon_sym_then,
    STATE(13247), 1,
      sym_then_clause,
    STATE(17814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742691] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17815), 1,
      sym_attribute,
    STATE(20219), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742708] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23695), 1,
      anon_sym_then,
    STATE(10771), 1,
      sym_then_clause,
    STATE(17816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742725] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24823), 1,
      anon_sym_RPAREN,
    ACTIONS(24825), 1,
      anon_sym_LT_DASH,
    STATE(17817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742742] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24827), 1,
      anon_sym_RPAREN,
    ACTIONS(24829), 1,
      anon_sym_SEMI,
    STATE(17818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742759] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24827), 1,
      anon_sym_RBRACK,
    ACTIONS(24831), 1,
      anon_sym_SEMI,
    STATE(17819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742776] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24827), 1,
      anon_sym_RBRACE,
    ACTIONS(24833), 1,
      anon_sym_SEMI,
    STATE(17820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742793] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24835), 1,
      anon_sym_then,
    STATE(11819), 1,
      sym_then_clause,
    STATE(17821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742810] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17822), 1,
      sym_attribute,
    STATE(20262), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742827] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24633), 1,
      anon_sym_then,
    STATE(12534), 1,
      sym_then_clause,
    STATE(17823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742844] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24837), 1,
      anon_sym_RPAREN,
    STATE(17824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742861] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24839), 1,
      anon_sym_RPAREN,
    ACTIONS(24841), 1,
      anon_sym_LT_DASH,
    STATE(17825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742878] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24843), 1,
      anon_sym_DOT,
    STATE(17826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742895] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24845), 2,
      anon_sym_to,
      anon_sym_downto,
  [742910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24847), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [742925] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24849), 1,
      anon_sym_EQ,
    ACTIONS(24851), 1,
      anon_sym_RPAREN,
    STATE(17829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742942] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17830), 1,
      sym_attribute,
    STATE(20436), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742959] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24853), 1,
      sym__lowercase_identifier,
    ACTIONS(24855), 1,
      anon_sym_LPAREN,
    STATE(17831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742976] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24857), 1,
      anon_sym_DOT,
    STATE(17832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [742993] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24859), 1,
      anon_sym_RPAREN,
    ACTIONS(24861), 1,
      anon_sym_SEMI,
    STATE(17833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743010] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24859), 1,
      anon_sym_RBRACK,
    ACTIONS(24863), 1,
      anon_sym_SEMI,
    STATE(17834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743027] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24859), 1,
      anon_sym_RBRACE,
    ACTIONS(24865), 1,
      anon_sym_SEMI,
    STATE(17835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24867), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [743059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17837), 1,
      sym_attribute,
    STATE(20488), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743076] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24869), 1,
      sym__lowercase_identifier,
    ACTIONS(24871), 1,
      anon_sym_LPAREN,
    STATE(17838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743093] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24873), 1,
      anon_sym_DOT,
    STATE(17839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743110] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24875), 1,
      sym__lowercase_identifier,
    STATE(17840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743127] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24877), 1,
      anon_sym_RPAREN,
    ACTIONS(24879), 1,
      anon_sym_LT_DASH,
    STATE(17841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743144] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18502), 1,
      sym__lowercase_identifier,
    STATE(17842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743161] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24881), 2,
      anon_sym_to,
      anon_sym_downto,
  [743176] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17844), 1,
      sym_attribute,
    STATE(20932), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743193] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24883), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [743208] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24885), 1,
      anon_sym_RPAREN,
    ACTIONS(24887), 1,
      anon_sym_SEMI,
    STATE(17846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743225] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24885), 1,
      anon_sym_RBRACK,
    ACTIONS(24889), 1,
      anon_sym_SEMI,
    STATE(17847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743242] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24885), 1,
      anon_sym_RBRACE,
    ACTIONS(24891), 1,
      anon_sym_SEMI,
    STATE(17848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743259] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17849), 1,
      sym_attribute,
    STATE(21054), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743276] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24893), 1,
      anon_sym_DOT,
    STATE(17850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743293] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24633), 1,
      anon_sym_then,
    STATE(12558), 1,
      sym_then_clause,
    STATE(17851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743310] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24895), 1,
      anon_sym_COLON_GT,
    ACTIONS(24897), 1,
      anon_sym_RPAREN,
    STATE(17852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743327] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24899), 1,
      anon_sym_COLON_GT,
    ACTIONS(24901), 1,
      anon_sym_RPAREN,
    STATE(17853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743344] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17854), 1,
      sym_attribute,
    STATE(21385), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743361] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24903), 1,
      anon_sym_RPAREN,
    STATE(17855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743378] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24905), 1,
      sym__lowercase_identifier,
    STATE(17856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743395] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24907), 1,
      anon_sym_RPAREN,
    ACTIONS(24909), 1,
      anon_sym_SEMI,
    STATE(17857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743412] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24907), 1,
      anon_sym_RBRACK,
    ACTIONS(24911), 1,
      anon_sym_SEMI,
    STATE(17858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743429] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24907), 1,
      anon_sym_RBRACE,
    ACTIONS(24913), 1,
      anon_sym_SEMI,
    STATE(17859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743446] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24915), 1,
      sym__lowercase_identifier,
    ACTIONS(24917), 1,
      anon_sym_LPAREN,
    STATE(17860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743463] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17861), 1,
      sym_attribute,
    STATE(19617), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743480] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24919), 1,
      anon_sym_DOT,
    STATE(17862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743497] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(24921), 1,
      sym__lowercase_identifier,
    STATE(17863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22070), 2,
      anon_sym_SEMI,
      anon_sym_GT_RBRACE,
  [743529] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24923), 1,
      anon_sym_COLON_GT,
    ACTIONS(24925), 1,
      anon_sym_RPAREN,
    STATE(17865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743546] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24835), 1,
      anon_sym_then,
    STATE(12253), 1,
      sym_then_clause,
    STATE(17866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743563] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(24927), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [743578] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17868), 1,
      sym_attribute,
    STATE(18473), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743595] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24929), 1,
      anon_sym_COLON_GT,
    ACTIONS(24931), 1,
      anon_sym_RPAREN,
    STATE(17869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743612] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23731), 1,
      anon_sym_do,
    STATE(8557), 1,
      sym_do_clause,
    STATE(17870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743629] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10053), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743646] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17872), 1,
      sym_attribute,
    STATE(20394), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743663] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24933), 1,
      anon_sym_RPAREN,
    ACTIONS(24935), 1,
      anon_sym_SEMI,
    STATE(17873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743680] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24933), 1,
      anon_sym_RBRACK,
    ACTIONS(24937), 1,
      anon_sym_SEMI,
    STATE(17874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743697] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24933), 1,
      anon_sym_RBRACE,
    ACTIONS(24939), 1,
      anon_sym_SEMI,
    STATE(17875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743714] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17876), 1,
      sym_attribute,
    STATE(19491), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743731] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9912), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(17877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743748] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24941), 1,
      anon_sym_DOT,
    STATE(17878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743765] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24943), 1,
      sym__lowercase_identifier,
    STATE(17879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743782] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17880), 1,
      sym_attribute,
    STATE(20238), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743799] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17881), 1,
      sym_attribute,
    STATE(18875), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743816] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24945), 1,
      anon_sym_COLON_GT,
    ACTIONS(24947), 1,
      anon_sym_RPAREN,
    STATE(17882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743833] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24949), 1,
      anon_sym_COLON_GT,
    ACTIONS(24951), 1,
      anon_sym_RPAREN,
    STATE(17883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743850] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24953), 1,
      anon_sym_RPAREN,
    ACTIONS(24955), 1,
      anon_sym_SEMI,
    STATE(17884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743867] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24953), 1,
      anon_sym_RBRACK,
    ACTIONS(24957), 1,
      anon_sym_SEMI,
    STATE(17885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743884] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24953), 1,
      anon_sym_RBRACE,
    ACTIONS(24959), 1,
      anon_sym_SEMI,
    STATE(17886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743901] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17887), 1,
      sym_attribute,
    STATE(18567), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743918] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24961), 1,
      anon_sym_RPAREN,
    STATE(17888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743935] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24963), 1,
      anon_sym_RPAREN,
    STATE(17889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743952] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24965), 1,
      anon_sym_COLON_GT,
    ACTIONS(24967), 1,
      anon_sym_RPAREN,
    STATE(17890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743969] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24969), 1,
      sym__lowercase_identifier,
    STATE(17891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [743986] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24971), 1,
      anon_sym_RPAREN,
    ACTIONS(24973), 1,
      anon_sym_LT_DASH,
    STATE(17892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744003] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24633), 1,
      anon_sym_then,
    STATE(12442), 1,
      sym_then_clause,
    STATE(17893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744020] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24975), 1,
      anon_sym_RPAREN,
    ACTIONS(24977), 1,
      anon_sym_LT_DASH,
    STATE(17894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744037] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17895), 1,
      sym_attribute,
    STATE(21019), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744054] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24979), 1,
      anon_sym_RPAREN,
    ACTIONS(24981), 1,
      anon_sym_SEMI,
    STATE(17896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744071] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24979), 1,
      anon_sym_RBRACK,
    ACTIONS(24983), 1,
      anon_sym_SEMI,
    STATE(17897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744088] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24979), 1,
      anon_sym_RBRACE,
    ACTIONS(24985), 1,
      anon_sym_SEMI,
    STATE(17898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744105] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(24987), 1,
      sym__lowercase_identifier,
    STATE(17899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744122] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24989), 1,
      anon_sym_RPAREN,
    ACTIONS(24991), 1,
      anon_sym_LT_DASH,
    STATE(17900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744139] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17901), 1,
      sym_attribute,
    STATE(18631), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744156] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(24993), 1,
      anon_sym_RPAREN,
    STATE(17902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744173] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(24995), 1,
      anon_sym_DOT,
    STATE(17903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744190] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15311), 1,
      sym__simple_value_pattern,
    STATE(17904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744207] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    STATE(13733), 1,
      sym_type_variable,
    STATE(17905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744224] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23713), 1,
      anon_sym_LPAREN,
    ACTIONS(24997), 1,
      sym__lowercase_identifier,
    STATE(17906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744241] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17907), 1,
      sym_attribute,
    STATE(19446), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744258] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24999), 1,
      anon_sym_RPAREN,
    ACTIONS(25001), 1,
      anon_sym_SEMI,
    STATE(17908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744275] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24999), 1,
      anon_sym_RBRACK,
    ACTIONS(25003), 1,
      anon_sym_SEMI,
    STATE(17909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744292] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24999), 1,
      anon_sym_RBRACE,
    ACTIONS(25005), 1,
      anon_sym_SEMI,
    STATE(17910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744309] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25007), 1,
      anon_sym_RPAREN,
    ACTIONS(25009), 1,
      anon_sym_LT_DASH,
    STATE(17911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744326] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24201), 1,
      anon_sym_then,
    STATE(8639), 1,
      sym_then_clause,
    STATE(17912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744343] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17913), 1,
      sym_attribute,
    STATE(19818), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744360] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25011), 1,
      anon_sym_RPAREN,
    STATE(17914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744377] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25013), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [744392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25015), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [744407] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10205), 1,
      anon_sym_RPAREN,
    ACTIONS(25017), 1,
      aux_sym_number_token1,
    STATE(17917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744424] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25019), 1,
      anon_sym_RPAREN,
    ACTIONS(25021), 1,
      anon_sym_LT_DASH,
    STATE(17918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17919), 1,
      sym_attribute,
    STATE(21004), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744458] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24835), 1,
      anon_sym_then,
    STATE(12269), 1,
      sym_then_clause,
    STATE(17920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744475] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25023), 1,
      anon_sym_RPAREN,
    ACTIONS(25025), 1,
      anon_sym_LT_DASH,
    STATE(17921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744492] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25027), 1,
      sym__lowercase_identifier,
    STATE(17922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744509] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25029), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [744524] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25031), 1,
      anon_sym_RPAREN,
    ACTIONS(25033), 1,
      anon_sym_SEMI,
    STATE(17924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744541] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25031), 1,
      anon_sym_RBRACK,
    ACTIONS(25035), 1,
      anon_sym_SEMI,
    STATE(17925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744558] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25031), 1,
      anon_sym_RBRACE,
    ACTIONS(25037), 1,
      anon_sym_SEMI,
    STATE(17926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744575] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25039), 1,
      anon_sym_RPAREN,
    STATE(17927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744592] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17928), 1,
      sym_attribute,
    STATE(21162), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18303), 1,
      sym__lowercase_identifier,
    STATE(17929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744626] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17930), 1,
      sym_attribute,
    STATE(19840), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744643] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25041), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [744658] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5253), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25043), 1,
      anon_sym_RPAREN,
    STATE(17932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744675] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25045), 1,
      anon_sym_RPAREN,
    ACTIONS(25047), 1,
      anon_sym_LT_DASH,
    STATE(17933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744692] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25049), 1,
      anon_sym_RPAREN,
    STATE(17934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25051), 1,
      anon_sym_RPAREN,
    ACTIONS(25053), 1,
      anon_sym_SEMI,
    STATE(17935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744726] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25051), 1,
      anon_sym_RBRACK,
    ACTIONS(25055), 1,
      anon_sym_SEMI,
    STATE(17936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25051), 1,
      anon_sym_RBRACE,
    ACTIONS(25057), 1,
      anon_sym_SEMI,
    STATE(17937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744760] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25059), 1,
      anon_sym_open,
    STATE(17938), 1,
      sym_attribute,
    STATE(19883), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744777] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25061), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [744792] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17940), 1,
      sym_attribute,
    STATE(18590), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744809] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25063), 1,
      anon_sym_RPAREN,
    STATE(17941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744826] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18512), 1,
      anon_sym_COLON2,
    STATE(17867), 1,
      sym__polymorphic_typed,
    STATE(17942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744843] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25065), 1,
      sym__lowercase_identifier,
    ACTIONS(25067), 1,
      anon_sym_LPAREN,
    STATE(17943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744860] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25069), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [744875] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17945), 1,
      sym_attribute,
    STATE(21171), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744892] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18422), 1,
      sym__lowercase_identifier,
    STATE(17946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25071), 1,
      anon_sym_RPAREN,
    ACTIONS(25073), 1,
      anon_sym_SEMI,
    STATE(17947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744926] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25071), 1,
      anon_sym_RBRACK,
    ACTIONS(25075), 1,
      anon_sym_SEMI,
    STATE(17948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744943] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25071), 1,
      anon_sym_RBRACE,
    ACTIONS(25077), 1,
      anon_sym_SEMI,
    STATE(17949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744960] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17950), 1,
      sym_attribute,
    STATE(18512), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25079), 1,
      sym__lowercase_identifier,
    STATE(17951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [744994] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24201), 1,
      anon_sym_then,
    STATE(8654), 1,
      sym_then_clause,
    STATE(17952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745011] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17953), 1,
      sym_attribute,
    STATE(19270), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745028] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25081), 1,
      anon_sym_RPAREN,
    ACTIONS(25083), 1,
      anon_sym_LT_DASH,
    STATE(17954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25085), 1,
      anon_sym_RPAREN,
    STATE(17955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745062] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25087), 1,
      anon_sym_DOT,
    STATE(17956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745079] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25089), 1,
      anon_sym_RPAREN,
    ACTIONS(25091), 1,
      anon_sym_SEMI,
    STATE(17957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745096] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25089), 1,
      anon_sym_RBRACK,
    ACTIONS(25093), 1,
      anon_sym_SEMI,
    STATE(17958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745113] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25089), 1,
      anon_sym_RBRACE,
    ACTIONS(25095), 1,
      anon_sym_SEMI,
    STATE(17959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745130] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25097), 1,
      anon_sym_RPAREN,
    STATE(17960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745147] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17961), 1,
      sym_attribute,
    STATE(19430), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745164] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24835), 1,
      anon_sym_then,
    STATE(12276), 1,
      sym_then_clause,
    STATE(17962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745181] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(17963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25099), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [745196] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23677), 1,
      anon_sym_then,
    STATE(13208), 1,
      sym_then_clause,
    STATE(17964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745213] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17965), 1,
      sym_attribute,
    STATE(20043), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745230] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25101), 1,
      sym__lowercase_identifier,
    ACTIONS(25103), 1,
      anon_sym_LPAREN,
    STATE(17966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745247] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25105), 1,
      anon_sym_RPAREN,
    ACTIONS(25107), 1,
      anon_sym_SEMI,
    STATE(17967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745264] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25105), 1,
      anon_sym_RBRACK,
    ACTIONS(25109), 1,
      anon_sym_SEMI,
    STATE(17968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745281] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25105), 1,
      anon_sym_RBRACE,
    ACTIONS(25111), 1,
      anon_sym_SEMI,
    STATE(17969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745298] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(17970), 1,
      sym_attribute,
    STATE(20344), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745315] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25113), 1,
      sym__lowercase_identifier,
    ACTIONS(25115), 1,
      anon_sym_LPAREN,
    STATE(17971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745332] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25117), 1,
      anon_sym_RPAREN,
    ACTIONS(25119), 1,
      anon_sym_LT_DASH,
    STATE(17972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745349] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23673), 1,
      anon_sym_then,
    STATE(8497), 1,
      sym_then_clause,
    STATE(17973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745366] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(17974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12612), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [745381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17975), 1,
      sym_attribute,
    STATE(18425), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745398] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25121), 1,
      anon_sym_COLON_GT,
    ACTIONS(25123), 1,
      anon_sym_RPAREN,
    STATE(17976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25125), 1,
      sym__lowercase_identifier,
    STATE(17977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745432] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25127), 1,
      sym__lowercase_identifier,
    ACTIONS(25129), 1,
      anon_sym_LPAREN,
    STATE(17978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745449] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25131), 1,
      anon_sym_RPAREN,
    ACTIONS(25133), 1,
      anon_sym_SEMI,
    STATE(17979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745466] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25131), 1,
      anon_sym_RBRACK,
    ACTIONS(25135), 1,
      anon_sym_SEMI,
    STATE(17980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745483] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25131), 1,
      anon_sym_RBRACE,
    ACTIONS(25137), 1,
      anon_sym_SEMI,
    STATE(17981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745500] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24353), 1,
      anon_sym_do,
    STATE(10881), 1,
      sym_do_clause,
    STATE(17982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745517] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    STATE(17983), 1,
      sym_attribute,
    STATE(18481), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745534] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17984), 1,
      sym_attribute,
    STATE(18728), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745551] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25139), 1,
      sym__lowercase_identifier,
    STATE(17985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745568] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25141), 1,
      anon_sym_EQ,
    STATE(17986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745585] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25143), 1,
      anon_sym_RPAREN,
    ACTIONS(25145), 1,
      anon_sym_SEMI,
    STATE(17987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745602] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25143), 1,
      anon_sym_RBRACK,
    ACTIONS(25147), 1,
      anon_sym_SEMI,
    STATE(17988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745619] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25143), 1,
      anon_sym_RBRACE,
    ACTIONS(25149), 1,
      anon_sym_SEMI,
    STATE(17989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745636] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25151), 1,
      anon_sym_DOT,
    STATE(17990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745653] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25153), 1,
      sym__lowercase_identifier,
    STATE(17991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745670] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25155), 1,
      anon_sym_RPAREN,
    STATE(17992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745687] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25157), 1,
      anon_sym_SEMI,
    ACTIONS(25159), 1,
      anon_sym_RBRACE,
    STATE(17993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745704] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25161), 1,
      sym__lowercase_identifier,
    STATE(17994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745721] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(17995), 1,
      sym_attribute,
    STATE(19030), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745738] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25163), 1,
      anon_sym_RPAREN,
    STATE(17996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745755] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25165), 1,
      anon_sym_RPAREN,
    ACTIONS(25167), 1,
      anon_sym_LT_DASH,
    STATE(17997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745772] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25169), 1,
      anon_sym_COLON_GT,
    ACTIONS(25171), 1,
      anon_sym_RPAREN,
    STATE(17998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25173), 1,
      anon_sym_RPAREN,
    ACTIONS(25175), 1,
      anon_sym_LT_DASH,
    STATE(17999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25177), 1,
      anon_sym_RPAREN,
    ACTIONS(25179), 1,
      anon_sym_SEMI,
    STATE(18000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745823] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25177), 1,
      anon_sym_RBRACK,
    ACTIONS(25181), 1,
      anon_sym_SEMI,
    STATE(18001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745840] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25177), 1,
      anon_sym_RBRACE,
    ACTIONS(25183), 1,
      anon_sym_SEMI,
    STATE(18002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745857] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24185), 1,
      anon_sym_then,
    STATE(12844), 1,
      sym_then_clause,
    STATE(18003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745874] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9900), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745891] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25185), 1,
      anon_sym_RPAREN,
    ACTIONS(25187), 1,
      anon_sym_LT_DASH,
    STATE(18005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745908] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25189), 1,
      anon_sym_RPAREN,
    ACTIONS(25191), 1,
      anon_sym_LT_DASH,
    STATE(18006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745925] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18007), 1,
      sym_attribute,
    STATE(19453), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745942] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23729), 1,
      anon_sym_then,
    STATE(9864), 1,
      sym_then_clause,
    STATE(18008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745959] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25193), 1,
      anon_sym_RPAREN,
    ACTIONS(25195), 1,
      anon_sym_LT_DASH,
    STATE(18009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745976] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25197), 1,
      anon_sym_RPAREN,
    ACTIONS(25199), 1,
      anon_sym_SEMI,
    STATE(18010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [745993] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25197), 1,
      anon_sym_RBRACK,
    ACTIONS(25201), 1,
      anon_sym_SEMI,
    STATE(18011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746010] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25197), 1,
      anon_sym_RBRACE,
    ACTIONS(25203), 1,
      anon_sym_SEMI,
    STATE(18012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746027] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25205), 1,
      anon_sym_RPAREN,
    STATE(18013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25207), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [746059] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24071), 1,
      anon_sym_then,
    STATE(8828), 1,
      sym_then_clause,
    STATE(18015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746076] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18016), 1,
      sym_attribute,
    STATE(19745), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746093] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25209), 1,
      anon_sym_RPAREN,
    ACTIONS(25211), 1,
      anon_sym_SEMI,
    STATE(18017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746110] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25209), 1,
      anon_sym_RBRACK,
    ACTIONS(25213), 1,
      anon_sym_SEMI,
    STATE(18018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746127] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25209), 1,
      anon_sym_RBRACE,
    ACTIONS(25215), 1,
      anon_sym_SEMI,
    STATE(18019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746144] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18020), 1,
      sym_attribute,
    STATE(19933), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746161] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25217), 1,
      anon_sym_RPAREN,
    ACTIONS(25219), 1,
      anon_sym_SEMI,
    STATE(18021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746178] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25217), 1,
      anon_sym_RBRACK,
    ACTIONS(25221), 1,
      anon_sym_SEMI,
    STATE(18022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746195] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25217), 1,
      anon_sym_RBRACE,
    ACTIONS(25223), 1,
      anon_sym_SEMI,
    STATE(18023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746212] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25225), 1,
      anon_sym_RPAREN,
    STATE(18024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746229] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25227), 1,
      sym__lowercase_identifier,
    STATE(18025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746246] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18026), 1,
      sym_attribute,
    STATE(20008), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746263] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25229), 1,
      anon_sym_RPAREN,
    ACTIONS(25231), 1,
      anon_sym_SEMI,
    STATE(18027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746280] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25229), 1,
      anon_sym_RBRACK,
    ACTIONS(25233), 1,
      anon_sym_SEMI,
    STATE(18028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746297] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25229), 1,
      anon_sym_RBRACE,
    ACTIONS(25235), 1,
      anon_sym_SEMI,
    STATE(18029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746314] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25237), 1,
      anon_sym_RPAREN,
    ACTIONS(25239), 1,
      anon_sym_LT_DASH,
    STATE(18030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746331] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18031), 1,
      sym_attribute,
    STATE(20030), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746348] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25241), 1,
      anon_sym_RPAREN,
    ACTIONS(25243), 1,
      anon_sym_SEMI,
    STATE(18032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746365] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25241), 1,
      anon_sym_RBRACK,
    ACTIONS(25245), 1,
      anon_sym_SEMI,
    STATE(18033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746382] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25241), 1,
      anon_sym_RBRACE,
    ACTIONS(25247), 1,
      anon_sym_SEMI,
    STATE(18034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746399] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18035), 1,
      sym_attribute,
    STATE(20052), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746416] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25249), 1,
      anon_sym_RPAREN,
    ACTIONS(25251), 1,
      anon_sym_SEMI,
    STATE(18036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746433] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25249), 1,
      anon_sym_RBRACK,
    ACTIONS(25253), 1,
      anon_sym_SEMI,
    STATE(18037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746450] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25249), 1,
      anon_sym_RBRACE,
    ACTIONS(25255), 1,
      anon_sym_SEMI,
    STATE(18038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746467] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25257), 1,
      anon_sym_RPAREN,
    ACTIONS(25259), 1,
      anon_sym_LT_DASH,
    STATE(18039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746484] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25261), 1,
      anon_sym_DOT,
    STATE(18040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746501] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18041), 1,
      sym_attribute,
    STATE(20080), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746518] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25263), 1,
      anon_sym_RPAREN,
    ACTIONS(25265), 1,
      anon_sym_SEMI,
    STATE(18042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746535] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25263), 1,
      anon_sym_RBRACK,
    ACTIONS(25267), 1,
      anon_sym_SEMI,
    STATE(18043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746552] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25263), 1,
      anon_sym_RBRACE,
    ACTIONS(25269), 1,
      anon_sym_SEMI,
    STATE(18044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746569] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18045), 1,
      sym_attribute,
    STATE(20118), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746586] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25271), 1,
      anon_sym_RPAREN,
    ACTIONS(25273), 1,
      anon_sym_SEMI,
    STATE(18046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746603] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25271), 1,
      anon_sym_RBRACK,
    ACTIONS(25275), 1,
      anon_sym_SEMI,
    STATE(18047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746620] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25271), 1,
      anon_sym_RBRACE,
    ACTIONS(25277), 1,
      anon_sym_SEMI,
    STATE(18048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746637] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25279), 1,
      sym__lowercase_identifier,
    STATE(18049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18050), 1,
      sym_attribute,
    STATE(20151), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25281), 1,
      anon_sym_RPAREN,
    ACTIONS(25283), 1,
      anon_sym_SEMI,
    STATE(18051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746688] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25281), 1,
      anon_sym_RBRACK,
    ACTIONS(25285), 1,
      anon_sym_SEMI,
    STATE(18052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25281), 1,
      anon_sym_RBRACE,
    ACTIONS(25287), 1,
      anon_sym_SEMI,
    STATE(18053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746722] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23695), 1,
      anon_sym_then,
    STATE(10708), 1,
      sym_then_clause,
    STATE(18054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25289), 1,
      anon_sym_COLON_GT,
    ACTIONS(25291), 1,
      anon_sym_RPAREN,
    STATE(18055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18056), 1,
      sym_attribute,
    STATE(20188), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746773] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25293), 1,
      anon_sym_RPAREN,
    ACTIONS(25295), 1,
      anon_sym_SEMI,
    STATE(18057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746790] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25293), 1,
      anon_sym_RBRACK,
    ACTIONS(25297), 1,
      anon_sym_SEMI,
    STATE(18058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746807] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25293), 1,
      anon_sym_RBRACE,
    ACTIONS(25299), 1,
      anon_sym_SEMI,
    STATE(18059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746824] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18060), 1,
      sym_attribute,
    STATE(20233), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25301), 1,
      anon_sym_RPAREN,
    ACTIONS(25303), 1,
      anon_sym_SEMI,
    STATE(18061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746858] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25301), 1,
      anon_sym_RBRACK,
    ACTIONS(25305), 1,
      anon_sym_SEMI,
    STATE(18062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746875] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25301), 1,
      anon_sym_RBRACE,
    ACTIONS(25307), 1,
      anon_sym_SEMI,
    STATE(18063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746892] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25309), 1,
      anon_sym_RPAREN,
    ACTIONS(25311), 1,
      anon_sym_LT_DASH,
    STATE(18064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18837), 1,
      anon_sym_RBRACE,
    ACTIONS(25313), 1,
      anon_sym_SEMI,
    STATE(18065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746926] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24285), 1,
      anon_sym_then,
    STATE(12930), 1,
      sym_then_clause,
    STATE(18066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746943] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18067), 1,
      sym_attribute,
    STATE(20282), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746960] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25315), 1,
      anon_sym_RPAREN,
    ACTIONS(25317), 1,
      anon_sym_SEMI,
    STATE(18068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746977] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25315), 1,
      anon_sym_RBRACK,
    ACTIONS(25319), 1,
      anon_sym_SEMI,
    STATE(18069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [746994] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25315), 1,
      anon_sym_RBRACE,
    ACTIONS(25321), 1,
      anon_sym_SEMI,
    STATE(18070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747011] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24001), 1,
      anon_sym_then,
    STATE(8445), 1,
      sym_then_clause,
    STATE(18071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747028] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18072), 1,
      sym_attribute,
    STATE(20347), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747045] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25323), 1,
      anon_sym_RPAREN,
    ACTIONS(25325), 1,
      anon_sym_SEMI,
    STATE(18073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747062] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25323), 1,
      anon_sym_RBRACK,
    ACTIONS(25327), 1,
      anon_sym_SEMI,
    STATE(18074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747079] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25323), 1,
      anon_sym_RBRACE,
    ACTIONS(25329), 1,
      anon_sym_SEMI,
    STATE(18075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25331), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747111] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18077), 1,
      sym_attribute,
    STATE(20378), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747128] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25333), 1,
      anon_sym_RPAREN,
    ACTIONS(25335), 1,
      anon_sym_SEMI,
    STATE(18078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747145] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25333), 1,
      anon_sym_RBRACK,
    ACTIONS(25337), 1,
      anon_sym_SEMI,
    STATE(18079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747162] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25333), 1,
      anon_sym_RBRACE,
    ACTIONS(25339), 1,
      anon_sym_SEMI,
    STATE(18080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747179] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25341), 1,
      anon_sym_RPAREN,
    ACTIONS(25343), 1,
      anon_sym_LT_DASH,
    STATE(18081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747196] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25345), 1,
      sym__lowercase_identifier,
    ACTIONS(25347), 1,
      anon_sym_LPAREN,
    STATE(18082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747213] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18083), 1,
      sym_attribute,
    STATE(20429), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747230] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25349), 1,
      anon_sym_RPAREN,
    ACTIONS(25351), 1,
      anon_sym_SEMI,
    STATE(18084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747247] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25349), 1,
      anon_sym_RBRACK,
    ACTIONS(25353), 1,
      anon_sym_SEMI,
    STATE(18085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747264] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25349), 1,
      anon_sym_RBRACE,
    ACTIONS(25355), 1,
      anon_sym_SEMI,
    STATE(18086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747281] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25357), 1,
      anon_sym_RPAREN,
    ACTIONS(25359), 1,
      anon_sym_LT_DASH,
    STATE(18087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25361), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747313] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18089), 1,
      sym_attribute,
    STATE(20477), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747330] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18090), 1,
      sym_attribute,
    STATE(20485), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747347] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18091), 1,
      sym_attribute,
    STATE(20504), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747364] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18092), 1,
      sym_attribute,
    STATE(20517), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747381] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18093), 1,
      sym_attribute,
    STATE(20534), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747398] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25363), 1,
      anon_sym_RPAREN,
    ACTIONS(25365), 1,
      anon_sym_LT_DASH,
    STATE(18094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747415] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18095), 1,
      sym_attribute,
    STATE(20548), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747432] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25367), 1,
      anon_sym_RPAREN,
    ACTIONS(25369), 1,
      anon_sym_LT_DASH,
    STATE(18096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747449] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18097), 1,
      sym_attribute,
    STATE(20557), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747466] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18098), 1,
      sym_attribute,
    STATE(20566), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747483] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25371), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747498] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18100), 1,
      sym_attribute,
    STATE(20574), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747515] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18101), 1,
      sym_attribute,
    STATE(20588), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747532] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18102), 1,
      sym_attribute,
    STATE(20601), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747549] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18103), 1,
      sym_attribute,
    STATE(20607), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747566] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18104), 1,
      sym_attribute,
    STATE(20623), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747583] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25373), 1,
      anon_sym_RPAREN,
    ACTIONS(25375), 1,
      anon_sym_LT_DASH,
    STATE(18105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747600] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18106), 1,
      sym_attribute,
    STATE(20635), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747617] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25377), 1,
      anon_sym_RPAREN,
    ACTIONS(25379), 1,
      anon_sym_LT_DASH,
    STATE(18107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747634] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18108), 1,
      sym_attribute,
    STATE(20651), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747651] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25381), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747666] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18110), 1,
      sym_attribute,
    STATE(20657), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747683] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18111), 1,
      sym_attribute,
    STATE(20671), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747700] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18112), 1,
      sym_attribute,
    STATE(20679), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747717] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18113), 1,
      sym_attribute,
    STATE(20688), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747734] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18114), 1,
      sym_attribute,
    STATE(20695), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747751] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25383), 1,
      anon_sym_RPAREN,
    ACTIONS(25385), 1,
      anon_sym_LT_DASH,
    STATE(18115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747768] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18116), 1,
      sym_attribute,
    STATE(20707), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747785] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25387), 1,
      anon_sym_RPAREN,
    ACTIONS(25389), 1,
      anon_sym_LT_DASH,
    STATE(18117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747802] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18118), 1,
      sym_attribute,
    STATE(20718), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747819] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25391), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747834] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18120), 1,
      sym_attribute,
    STATE(20725), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747851] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25393), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747866] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18122), 1,
      sym_attribute,
    STATE(20735), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747883] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25395), 1,
      anon_sym_RPAREN,
    STATE(18123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747900] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25397), 1,
      sym__lowercase_identifier,
    STATE(18124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747917] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25399), 1,
      anon_sym_RPAREN,
    STATE(18125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25401), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [747949] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25403), 1,
      anon_sym_RPAREN,
    ACTIONS(25405), 1,
      anon_sym_LT_DASH,
    STATE(18127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747966] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24111), 1,
      anon_sym_LPAREN,
    ACTIONS(25407), 1,
      sym__lowercase_identifier,
    STATE(18128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [747983] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25409), 1,
      anon_sym_RPAREN,
    ACTIONS(25411), 1,
      anon_sym_LT_DASH,
    STATE(18129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748000] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18418), 1,
      sym__lowercase_identifier,
    STATE(18130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748017] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25413), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748032] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25415), 1,
      sym__lowercase_identifier,
    ACTIONS(25417), 1,
      anon_sym_LPAREN,
    STATE(18132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748049] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25419), 1,
      anon_sym_RPAREN,
    ACTIONS(25421), 1,
      anon_sym_LT_DASH,
    STATE(18133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748066] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25423), 1,
      anon_sym_RPAREN,
    ACTIONS(25425), 1,
      anon_sym_LT_DASH,
    STATE(18134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748083] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25427), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748098] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24185), 1,
      anon_sym_then,
    STATE(12903), 1,
      sym_then_clause,
    STATE(18136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748115] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25429), 1,
      anon_sym_RPAREN,
    STATE(18137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748132] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25431), 1,
      anon_sym_RPAREN,
    STATE(18138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748149] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25433), 1,
      anon_sym_RPAREN,
    ACTIONS(25435), 1,
      anon_sym_LT_DASH,
    STATE(18139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748166] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25437), 1,
      sym__lowercase_identifier,
    ACTIONS(25439), 1,
      anon_sym_LPAREN,
    STATE(18140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748183] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25441), 1,
      anon_sym_RPAREN,
    ACTIONS(25443), 1,
      anon_sym_LT_DASH,
    STATE(18141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748200] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25445), 1,
      sym__lowercase_identifier,
    STATE(18142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748217] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25447), 1,
      anon_sym_RPAREN,
    ACTIONS(25449), 1,
      anon_sym_LT_DASH,
    STATE(18143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25451), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748249] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25453), 1,
      anon_sym_COLON_GT,
    ACTIONS(25455), 1,
      anon_sym_RPAREN,
    STATE(18145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748266] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25457), 1,
      sym__lowercase_identifier,
    ACTIONS(25459), 1,
      anon_sym_LBRACK,
    STATE(18146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748283] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25461), 2,
      anon_sym_to,
      anon_sym_downto,
  [748298] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25463), 1,
      anon_sym_RPAREN,
    ACTIONS(25465), 1,
      anon_sym_LT_DASH,
    STATE(18148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748315] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25467), 1,
      anon_sym_RPAREN,
    ACTIONS(25469), 1,
      anon_sym_LT_DASH,
    STATE(18149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25471), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [748347] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25473), 1,
      sym__uppercase_identifier,
    STATE(14196), 1,
      sym_extended_module_path,
    STATE(18151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25475), 2,
      anon_sym_to,
      anon_sym_downto,
  [748379] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25477), 1,
      anon_sym_RPAREN,
    ACTIONS(25479), 1,
      anon_sym_LT_DASH,
    STATE(18153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748396] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25481), 1,
      anon_sym_EQ,
    ACTIONS(25483), 1,
      anon_sym_RPAREN,
    STATE(18154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748413] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25485), 1,
      sym__lowercase_identifier,
    STATE(18155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748430] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18967), 1,
      anon_sym_RBRACE,
    ACTIONS(25487), 1,
      anon_sym_SEMI,
    STATE(18156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748447] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25489), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748462] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18971), 1,
      anon_sym_RBRACE,
    ACTIONS(25491), 1,
      anon_sym_SEMI,
    STATE(18158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748479] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24343), 1,
      anon_sym_then,
    STATE(13097), 1,
      sym_then_clause,
    STATE(18159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25493), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748511] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25495), 1,
      anon_sym_RPAREN,
    STATE(18161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748528] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25497), 1,
      sym__lowercase_identifier,
    ACTIONS(25499), 1,
      anon_sym_LPAREN,
    STATE(18162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748545] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25501), 1,
      anon_sym_RPAREN,
    STATE(18163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748562] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25503), 1,
      anon_sym_RPAREN,
    STATE(18164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748579] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25505), 1,
      anon_sym_RPAREN,
    ACTIONS(25507), 1,
      anon_sym_LT_DASH,
    STATE(18165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748596] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25509), 1,
      anon_sym_RPAREN,
    ACTIONS(25511), 1,
      anon_sym_LT_DASH,
    STATE(18166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748613] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25513), 2,
      anon_sym_RBRACK,
      aux_sym_tag_token1,
  [748628] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23731), 1,
      anon_sym_do,
    STATE(8482), 1,
      sym_do_clause,
    STATE(18168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748645] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25515), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748660] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25517), 1,
      anon_sym_RPAREN,
    ACTIONS(25519), 1,
      anon_sym_LT_DASH,
    STATE(18170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748677] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25521), 1,
      anon_sym_RPAREN,
    STATE(18171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748694] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25523), 1,
      anon_sym_RPAREN,
    STATE(18172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748711] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25525), 1,
      anon_sym_DOT,
    STATE(18173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25527), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748743] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25529), 1,
      anon_sym_RPAREN,
    STATE(18175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748760] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25417), 1,
      anon_sym_LPAREN,
    ACTIONS(25531), 1,
      sym__lowercase_identifier,
    STATE(18176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748777] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25533), 1,
      anon_sym_SEMI,
    ACTIONS(25535), 1,
      anon_sym_RBRACE,
    STATE(18177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748794] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25537), 1,
      anon_sym_SEMI,
    ACTIONS(25539), 1,
      anon_sym_RBRACE,
    STATE(18178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748811] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25541), 1,
      anon_sym_RPAREN,
    ACTIONS(25543), 1,
      anon_sym_LT_DASH,
    STATE(18179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748828] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25545), 1,
      anon_sym_RPAREN,
    ACTIONS(25547), 1,
      anon_sym_LT_DASH,
    STATE(18180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748845] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25549), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748860] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25551), 1,
      anon_sym_RPAREN,
    ACTIONS(25553), 1,
      anon_sym_LT_DASH,
    STATE(18182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748877] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24185), 1,
      anon_sym_then,
    STATE(12594), 1,
      sym_then_clause,
    STATE(18183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25555), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748909] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25557), 1,
      anon_sym_RPAREN,
    ACTIONS(25559), 1,
      anon_sym_LT_DASH,
    STATE(18185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25561), 2,
      anon_sym_to,
      anon_sym_downto,
  [748941] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25563), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25565), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [748971] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24113), 1,
      anon_sym_then,
    STATE(10132), 1,
      sym_then_clause,
    STATE(18189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [748988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25567), 2,
      anon_sym_to,
      anon_sym_downto,
  [749003] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25569), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25571), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749033] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18403), 1,
      sym__lowercase_identifier,
    STATE(18193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749050] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25573), 1,
      anon_sym_EQ,
    STATE(18194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749067] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25575), 1,
      anon_sym_RPAREN,
    STATE(18195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749084] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7669), 1,
      aux_sym_type_variable_token1,
    STATE(8545), 1,
      sym_type_variable,
    STATE(18196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749101] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25577), 1,
      sym__lowercase_identifier,
    STATE(18197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749118] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25579), 1,
      anon_sym_RPAREN,
    ACTIONS(25581), 1,
      anon_sym_LT_DASH,
    STATE(18198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749135] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25583), 1,
      anon_sym_RPAREN,
    STATE(18199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749152] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25585), 1,
      anon_sym_RPAREN,
    ACTIONS(25587), 1,
      anon_sym_LT_DASH,
    STATE(18200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749169] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25589), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25591), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749199] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24323), 1,
      anon_sym_then,
    STATE(12716), 1,
      sym_then_clause,
    STATE(18203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749216] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25593), 1,
      anon_sym_RPAREN,
    ACTIONS(25595), 1,
      anon_sym_LT_DASH,
    STATE(18204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749233] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25597), 1,
      sym__lowercase_identifier,
    ACTIONS(25599), 1,
      anon_sym_LPAREN,
    STATE(18205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749250] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25601), 1,
      anon_sym_RPAREN,
    ACTIONS(25603), 1,
      anon_sym_LT_DASH,
    STATE(18206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749267] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25605), 1,
      anon_sym_RPAREN,
    ACTIONS(25607), 1,
      anon_sym_LT_DASH,
    STATE(18207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749284] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25609), 1,
      anon_sym_COLON_GT,
    ACTIONS(25611), 1,
      anon_sym_RPAREN,
    STATE(18208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749301] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25613), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25615), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749331] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25617), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [749346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25619), 2,
      anon_sym_to,
      anon_sym_downto,
  [749361] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    STATE(9372), 1,
      sym_extended_module_path,
    STATE(18213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749378] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9038), 1,
      anon_sym_COMMA,
    ACTIONS(25621), 1,
      anon_sym_COLON,
    STATE(18214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749395] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10051), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25623), 2,
      anon_sym_to,
      anon_sym_downto,
  [749427] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25625), 1,
      sym__lowercase_identifier,
    STATE(18217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749444] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(18218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12608), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [749459] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25627), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749474] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25629), 1,
      anon_sym_RPAREN,
    STATE(18220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749491] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25631), 1,
      anon_sym_RPAREN,
    STATE(18221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749508] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25633), 1,
      anon_sym_RPAREN,
    ACTIONS(25635), 1,
      anon_sym_LT_DASH,
    STATE(18222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749525] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9748), 1,
      anon_sym_RPAREN,
    STATE(18223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749542] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25637), 1,
      sym__lowercase_identifier,
    STATE(18224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749559] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10079), 1,
      anon_sym_COMMA,
    ACTIONS(25639), 1,
      anon_sym_COLON,
    STATE(18225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749576] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25641), 1,
      anon_sym_RPAREN,
    ACTIONS(25643), 1,
      anon_sym_LT_DASH,
    STATE(18226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749593] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25645), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749608] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25647), 1,
      sym__lowercase_identifier,
    STATE(18228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25417), 1,
      anon_sym_LPAREN,
    ACTIONS(25649), 1,
      sym__lowercase_identifier,
    STATE(18229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749642] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25651), 1,
      anon_sym_RPAREN,
    ACTIONS(25653), 1,
      anon_sym_LT_DASH,
    STATE(18230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749659] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9782), 1,
      anon_sym_RPAREN,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    STATE(18231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749676] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25655), 1,
      anon_sym_RPAREN,
    STATE(18232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749693] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25657), 1,
      anon_sym_RPAREN,
    STATE(18233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749710] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25659), 1,
      sym__lowercase_identifier,
    ACTIONS(25661), 1,
      sym__uppercase_identifier,
    STATE(18234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749727] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25663), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749742] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25665), 1,
      anon_sym_EQ,
    ACTIONS(25667), 1,
      anon_sym_RPAREN,
    STATE(18236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749759] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25669), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25671), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749789] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9842), 1,
      anon_sym_RPAREN,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    STATE(18239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749806] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9586), 1,
      anon_sym_RPAREN,
    STATE(18240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749823] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25673), 1,
      anon_sym_RPAREN,
    STATE(18241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25675), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [749855] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25677), 1,
      sym__lowercase_identifier,
    STATE(18243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749872] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25679), 1,
      anon_sym_RPAREN,
    ACTIONS(25681), 1,
      anon_sym_LT_DASH,
    STATE(18244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749889] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25683), 1,
      anon_sym_COLON_GT,
    ACTIONS(25685), 1,
      anon_sym_EQ,
    STATE(18245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749906] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24323), 1,
      anon_sym_then,
    STATE(12688), 1,
      sym_then_clause,
    STATE(18246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749923] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23731), 1,
      anon_sym_do,
    STATE(8552), 1,
      sym_do_clause,
    STATE(18247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749940] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25687), 1,
      sym__lowercase_identifier,
    ACTIONS(25689), 1,
      anon_sym_LPAREN,
    STATE(18248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749957] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25691), 1,
      anon_sym_RPAREN,
    STATE(18249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749974] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24599), 1,
      anon_sym_COLON2,
    STATE(13935), 1,
      sym__typed,
    STATE(18250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [749991] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18251), 1,
      sym_attribute,
    STATE(20702), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750008] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25693), 1,
      anon_sym_DOT,
    STATE(18252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750025] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25695), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [750040] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24113), 1,
      anon_sym_then,
    STATE(10224), 1,
      sym_then_clause,
    STATE(18254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750057] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25697), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [750072] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25699), 1,
      sym__lowercase_identifier,
    ACTIONS(25701), 1,
      anon_sym_LPAREN,
    STATE(18256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750089] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18371), 1,
      sym__lowercase_identifier,
    STATE(18257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750106] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24675), 1,
      anon_sym_COLON2,
    STATE(13948), 1,
      sym__polymorphic_typed,
    STATE(18258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750123] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25703), 1,
      anon_sym_DOT,
    STATE(18259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750140] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23599), 1,
      anon_sym_then,
    STATE(12744), 1,
      sym_then_clause,
    STATE(18260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750157] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25705), 1,
      anon_sym_COLON_GT,
    ACTIONS(25707), 1,
      anon_sym_RPAREN,
    STATE(18261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750174] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25709), 1,
      sym__lowercase_identifier,
    STATE(18262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750191] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10027), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750208] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19065), 1,
      anon_sym_RBRACE,
    ACTIONS(25711), 1,
      anon_sym_SEMI,
    STATE(18264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750225] = 4,
    ACTIONS(3), 1,
      aux_sym_attribute_token1,
    STATE(18265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(12560), 2,
      anon_sym_in,
      anon_sym_LBRACK_AT_AT,
  [750240] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24343), 1,
      anon_sym_then,
    STATE(13328), 1,
      sym_then_clause,
    STATE(18266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750257] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25713), 1,
      anon_sym_DOT,
    STATE(18267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750274] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18412), 1,
      sym__lowercase_identifier,
    STATE(18268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750291] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25715), 1,
      anon_sym_DOT,
    STATE(18269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750308] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    ACTIONS(25717), 1,
      anon_sym_RPAREN,
    STATE(18270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750325] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(22974), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [750340] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25719), 1,
      anon_sym_DOT,
    STATE(18272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750357] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23881), 1,
      anon_sym_then,
    STATE(8617), 1,
      sym_then_clause,
    STATE(18273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750374] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25721), 1,
      sym__lowercase_identifier,
    ACTIONS(25723), 1,
      anon_sym_LPAREN,
    STATE(18274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750391] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25725), 1,
      sym__lowercase_identifier,
    STATE(18275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750408] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24285), 1,
      anon_sym_then,
    STATE(13222), 1,
      sym_then_clause,
    STATE(18276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750425] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25727), 1,
      anon_sym_RPAREN,
    STATE(18277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750442] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25729), 1,
      anon_sym_DOT,
    STATE(18278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750459] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25731), 1,
      anon_sym_COLON2,
    STATE(12451), 1,
      sym__polymorphic_typed,
    STATE(18279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750476] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25733), 1,
      sym__lowercase_identifier,
    STATE(18280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750493] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25735), 1,
      anon_sym_EQ,
    ACTIONS(25737), 1,
      anon_sym_RPAREN,
    STATE(18281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750510] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25739), 1,
      anon_sym_RPAREN,
    STATE(18282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750527] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7667), 1,
      sym__uppercase_identifier,
    STATE(16328), 1,
      sym_extended_module_path,
    STATE(18283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750544] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25741), 1,
      sym__lowercase_identifier,
    ACTIONS(25743), 1,
      anon_sym_LPAREN,
    STATE(18284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750561] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25745), 1,
      anon_sym_COLON_GT,
    ACTIONS(25747), 1,
      anon_sym_RPAREN,
    STATE(18285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750578] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25749), 1,
      sym__lowercase_identifier,
    ACTIONS(25751), 1,
      anon_sym_LPAREN,
    STATE(18286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750595] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25753), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [750610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25755), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [750625] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25757), 1,
      anon_sym_RPAREN,
    STATE(18289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750642] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17248), 1,
      anon_sym_COLON2,
    STATE(18290), 1,
      sym_attribute,
    STATE(19029), 1,
      sym__module_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750659] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25759), 1,
      sym__lowercase_identifier,
    STATE(18291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750676] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25761), 1,
      anon_sym_RPAREN,
    STATE(18292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750693] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25763), 1,
      anon_sym_COLON_GT,
    ACTIONS(25765), 1,
      anon_sym_RPAREN,
    STATE(18293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750710] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25731), 1,
      anon_sym_COLON2,
    STATE(12515), 1,
      sym__polymorphic_typed,
    STATE(18294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750727] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23713), 1,
      anon_sym_LPAREN,
    ACTIONS(25767), 1,
      sym__lowercase_identifier,
    STATE(18295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750744] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25769), 1,
      anon_sym_COLON_GT,
    ACTIONS(25771), 1,
      anon_sym_RPAREN,
    STATE(18296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750761] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25773), 1,
      sym__lowercase_identifier,
    ACTIONS(25775), 1,
      anon_sym_LPAREN,
    STATE(18297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750778] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25777), 1,
      sym__lowercase_identifier,
    STATE(18298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750795] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9882), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750812] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25779), 1,
      sym__lowercase_identifier,
    ACTIONS(25781), 1,
      anon_sym_LPAREN,
    STATE(18300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750829] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(21500), 1,
      sym__lowercase_identifier,
    STATE(18301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750846] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25783), 1,
      anon_sym_RPAREN,
    ACTIONS(25785), 1,
      anon_sym_LT_DASH,
    STATE(18302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750863] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24071), 1,
      anon_sym_then,
    STATE(8824), 1,
      sym_then_clause,
    STATE(18303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750880] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19083), 1,
      anon_sym_RBRACE,
    ACTIONS(25787), 1,
      anon_sym_SEMI,
    STATE(18304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750897] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25789), 1,
      sym__lowercase_identifier,
    STATE(18305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750914] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(18306), 1,
      sym_attribute,
    STATE(20490), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750931] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(21849), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [750946] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19089), 1,
      anon_sym_RBRACE,
    ACTIONS(25791), 1,
      anon_sym_SEMI,
    STATE(18308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750963] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18309), 1,
      sym_attribute,
    STATE(18700), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750980] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25793), 1,
      anon_sym_COLON_GT,
    ACTIONS(25795), 1,
      anon_sym_RPAREN,
    STATE(18310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [750997] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25797), 1,
      anon_sym_RPAREN,
    STATE(18311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751014] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25799), 1,
      anon_sym_RPAREN,
    ACTIONS(25801), 1,
      anon_sym_LT_DASH,
    STATE(18312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751031] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18494), 1,
      sym__lowercase_identifier,
    STATE(18313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751048] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25803), 1,
      anon_sym_EQ,
    STATE(18314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751065] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17690), 1,
      anon_sym_COMMA,
    ACTIONS(25805), 1,
      anon_sym_COLON,
    STATE(18315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751082] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9896), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751099] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25807), 1,
      anon_sym_RPAREN,
    STATE(18317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751116] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25809), 1,
      anon_sym_RPAREN,
    STATE(18318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751133] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25811), 1,
      anon_sym_SEMI,
    ACTIONS(25813), 1,
      anon_sym_RBRACE,
    STATE(18319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751150] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25815), 1,
      anon_sym_SEMI,
    ACTIONS(25817), 1,
      anon_sym_RBRACE,
    STATE(18320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751167] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(8050), 1,
      sym__left_quoted_string_delimiter,
    STATE(18321), 1,
      sym_attribute,
    STATE(19399), 1,
      sym__quoted_string,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751184] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25819), 1,
      sym__lowercase_identifier,
    STATE(18322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751201] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25821), 1,
      sym__lowercase_identifier,
    STATE(18323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751218] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25823), 1,
      anon_sym_RPAREN,
    ACTIONS(25825), 1,
      anon_sym_LT_DASH,
    STATE(18324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751235] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25827), 1,
      anon_sym_EQ,
    ACTIONS(25829), 1,
      anon_sym_RPAREN,
    STATE(18325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751252] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19435), 1,
      sym__lowercase_identifier,
    STATE(15380), 1,
      sym__simple_value_pattern,
    STATE(18326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751269] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25059), 1,
      anon_sym_open,
    STATE(18327), 1,
      sym_attribute,
    STATE(20539), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751286] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25831), 1,
      anon_sym_DOT,
    STATE(18328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751303] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24589), 1,
      anon_sym_then,
    STATE(12774), 1,
      sym_then_clause,
    STATE(18329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751320] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25833), 1,
      anon_sym_RPAREN,
    STATE(18330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751337] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25835), 1,
      sym__lowercase_identifier,
    ACTIONS(25837), 1,
      anon_sym_LPAREN,
    STATE(18331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751354] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25839), 1,
      anon_sym_COLON_GT,
    ACTIONS(25841), 1,
      anon_sym_EQ,
    STATE(18332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751371] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25843), 1,
      anon_sym_RPAREN,
    ACTIONS(25845), 1,
      anon_sym_LT_DASH,
    STATE(18333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751388] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18699), 1,
      anon_sym_RBRACE,
    ACTIONS(25847), 1,
      anon_sym_SEMI,
    STATE(18334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751405] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25849), 1,
      anon_sym_RPAREN,
    STATE(18335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751422] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(18336), 1,
      sym_attribute,
    STATE(20123), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751439] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19105), 1,
      anon_sym_RBRACE,
    ACTIONS(25851), 1,
      anon_sym_SEMI,
    STATE(18337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25853), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [751471] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25855), 1,
      anon_sym_COLON_GT,
    ACTIONS(25857), 1,
      anon_sym_RPAREN,
    STATE(18339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751488] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25859), 1,
      anon_sym_RPAREN,
    STATE(18340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751505] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18711), 1,
      anon_sym_RBRACE,
    ACTIONS(25861), 1,
      anon_sym_SEMI,
    STATE(18341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751522] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25863), 1,
      anon_sym_EQ,
    STATE(18342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751539] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(23339), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [751554] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25865), 1,
      anon_sym_RPAREN,
    ACTIONS(25867), 1,
      anon_sym_LT_DASH,
    STATE(18344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751571] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(25869), 1,
      anon_sym_DOT,
    STATE(18345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751588] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23633), 1,
      anon_sym_then,
    STATE(10980), 1,
      sym_then_clause,
    STATE(18346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751605] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25871), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [751620] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25873), 1,
      anon_sym_EQ,
    STATE(18348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751637] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25875), 1,
      anon_sym_RPAREN,
    STATE(18349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751654] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25877), 1,
      anon_sym_EQ,
    STATE(18350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751671] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10033), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751688] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25879), 1,
      anon_sym_EQ,
    STATE(18352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751705] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25881), 1,
      anon_sym_RPAREN,
    ACTIONS(25883), 1,
      anon_sym_SEMI,
    STATE(18353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751722] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25881), 1,
      anon_sym_RBRACK,
    ACTIONS(25885), 1,
      anon_sym_SEMI,
    STATE(18354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751739] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25881), 1,
      anon_sym_RBRACE,
    ACTIONS(25887), 1,
      anon_sym_SEMI,
    STATE(18355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751756] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25889), 1,
      sym__lowercase_identifier,
    STATE(18356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751773] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25891), 1,
      anon_sym_RPAREN,
    ACTIONS(25893), 1,
      anon_sym_LT_DASH,
    STATE(18357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751790] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25895), 1,
      anon_sym_COLON_GT,
    ACTIONS(25897), 1,
      anon_sym_EQ,
    STATE(18358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751807] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25899), 1,
      anon_sym_RPAREN,
    STATE(18359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751824] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25901), 1,
      anon_sym_RPAREN,
    STATE(18360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751841] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24257), 1,
      anon_sym_do,
    STATE(8180), 1,
      sym_do_clause,
    STATE(18361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25903), 2,
      anon_sym__,
      sym__uppercase_identifier,
  [751873] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(18363), 1,
      sym_attribute,
    STATE(21354), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751890] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25905), 1,
      anon_sym_EQ,
    STATE(18364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751907] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25907), 1,
      anon_sym_COLON_GT,
    ACTIONS(25909), 1,
      anon_sym_EQ,
    STATE(18365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751924] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(18366), 1,
      sym_attribute,
    STATE(18803), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751941] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25911), 1,
      anon_sym_RPAREN,
    ACTIONS(25913), 1,
      anon_sym_LT_DASH,
    STATE(18367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751958] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25915), 1,
      anon_sym_RPAREN,
    STATE(18368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751975] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(25917), 1,
      sym__lowercase_identifier,
    STATE(18369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [751992] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23585), 1,
      anon_sym_then,
    STATE(13192), 1,
      sym_then_clause,
    STATE(18370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752009] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25919), 1,
      anon_sym_RPAREN,
    ACTIONS(25921), 1,
      anon_sym_LT_DASH,
    STATE(18371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752026] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20208), 1,
      anon_sym_COLON2,
    STATE(18372), 1,
      sym_attribute,
    STATE(19219), 1,
      sym__typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752043] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25923), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752058] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23599), 1,
      anon_sym_then,
    STATE(12737), 1,
      sym_then_clause,
    STATE(18374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752075] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25925), 1,
      anon_sym_RPAREN,
    STATE(18375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752092] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25927), 1,
      sym__lowercase_identifier,
    ACTIONS(25929), 1,
      anon_sym_LBRACK,
    STATE(18376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752109] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25931), 1,
      anon_sym_RPAREN,
    ACTIONS(25933), 1,
      anon_sym_LT_DASH,
    STATE(18377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752126] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25059), 1,
      anon_sym_open,
    STATE(18378), 1,
      sym_attribute,
    STATE(20170), 1,
      sym_open_module,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752143] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25935), 1,
      anon_sym_RPAREN,
    STATE(18379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25937), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752175] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    ACTIONS(18490), 1,
      sym__lowercase_identifier,
    STATE(18381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752192] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25499), 1,
      anon_sym_LPAREN,
    ACTIONS(25939), 1,
      sym__lowercase_identifier,
    STATE(18382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752209] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25941), 1,
      sym__lowercase_identifier,
    ACTIONS(25943), 1,
      anon_sym_LPAREN,
    STATE(18383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752226] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25945), 1,
      anon_sym_SEMI,
    ACTIONS(25947), 1,
      anon_sym_RBRACE,
    STATE(18384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752243] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25949), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25951), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752273] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(25953), 1,
      sym__lowercase_identifier,
    STATE(18387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752290] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25955), 1,
      anon_sym_SEMI,
    ACTIONS(25957), 1,
      anon_sym_RBRACE,
    STATE(18388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752307] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25959), 1,
      anon_sym_RPAREN,
    ACTIONS(25961), 1,
      anon_sym_LT_DASH,
    STATE(18389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752324] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23901), 1,
      anon_sym_then,
    STATE(12762), 1,
      sym_then_clause,
    STATE(18390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752341] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25963), 1,
      anon_sym_RPAREN,
    STATE(18391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752358] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25965), 1,
      anon_sym_EQ,
    STATE(18392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752375] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25967), 1,
      anon_sym_COLON_GT,
    ACTIONS(25969), 1,
      anon_sym_RPAREN,
    STATE(18393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752392] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25971), 1,
      anon_sym_EQ,
    STATE(18394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752409] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25973), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752424] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25975), 1,
      anon_sym_RPAREN,
    STATE(18396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752441] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18268), 1,
      sym__lowercase_identifier,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    STATE(18397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752458] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25977), 1,
      sym__lowercase_identifier,
    ACTIONS(25979), 1,
      anon_sym_LPAREN,
    STATE(18398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752475] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25981), 1,
      anon_sym_COLON_GT,
    ACTIONS(25983), 1,
      anon_sym_RPAREN,
    STATE(18399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752492] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25985), 1,
      sym__lowercase_identifier,
    ACTIONS(25987), 1,
      anon_sym_LPAREN,
    STATE(18400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752509] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10025), 1,
      anon_sym_RBRACK,
    ACTIONS(19764), 1,
      anon_sym_PIPE,
    STATE(18401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752526] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25989), 1,
      anon_sym_EQ,
    STATE(18402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752543] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24353), 1,
      anon_sym_do,
    STATE(11123), 1,
      sym_do_clause,
    STATE(18403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752560] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25991), 1,
      anon_sym_RPAREN,
    ACTIONS(25993), 1,
      anon_sym_LT_DASH,
    STATE(18404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752577] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(25995), 1,
      anon_sym_RPAREN,
    STATE(18405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(25997), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752609] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25999), 1,
      anon_sym_COLON_GT,
    ACTIONS(26001), 1,
      anon_sym_RPAREN,
    STATE(18407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752626] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    ACTIONS(26003), 1,
      sym__lowercase_identifier,
    STATE(18408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752643] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(26005), 1,
      anon_sym_DOT,
    STATE(18409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752660] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23639), 1,
      anon_sym_then,
    STATE(12644), 1,
      sym_then_clause,
    STATE(18410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752677] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24565), 1,
      anon_sym_COLON2,
    STATE(18411), 1,
      sym_attribute,
    STATE(21366), 1,
      sym__polymorphic_typed,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(26007), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [752709] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19283), 1,
      anon_sym_as,
    ACTIONS(26009), 1,
      anon_sym_RPAREN,
    STATE(18413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752726] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20429), 1,
      sym__lowercase_identifier,
    STATE(15447), 1,
      aux_sym__abstract_type_repeat1,
    STATE(18414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752743] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(26011), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752758] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26013), 1,
      anon_sym_RPAREN,
    ACTIONS(26015), 1,
      anon_sym_LT_DASH,
    STATE(18416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752775] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24353), 1,
      anon_sym_do,
    STATE(10930), 1,
      sym_do_clause,
    STATE(18417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752792] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23599), 1,
      anon_sym_then,
    STATE(12894), 1,
      sym_then_clause,
    STATE(18418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752809] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(26017), 2,
      sym__lowercase_identifier,
      sym__uppercase_identifier,
  [752824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(26019), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [752839] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    STATE(18421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
    ACTIONS(26021), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [752854] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23569), 1,
      anon_sym_RPAREN,
    ACTIONS(26023), 1,
      anon_sym_SEMI,
    STATE(18422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752871] = 5,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11425), 1,
      anon_sym_LPAREN,
    ACTIONS(26025), 1,
      anon_sym_DOT,
    STATE(18423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752888] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26027), 1,
      anon_sym_PLUS_EQ,
    STATE(18424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752902] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26029), 1,
      anon_sym_RBRACE,
    STATE(18425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26031), 1,
      anon_sym_RBRACE,
    STATE(18426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752930] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15859), 1,
      anon_sym_COMMA,
    STATE(18427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752944] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18530), 1,
      anon_sym_DASH_GT,
    STATE(18428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752958] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26033), 1,
      anon_sym_LT_DASH,
    STATE(18429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752972] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26035), 1,
      anon_sym_RPAREN,
    STATE(18430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [752986] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26037), 1,
      anon_sym_DOT,
    STATE(18431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753000] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26039), 1,
      anon_sym_RBRACK,
    STATE(18432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753014] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26041), 1,
      anon_sym_RPAREN,
    STATE(18433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753028] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26043), 1,
      anon_sym_DOT,
    STATE(18434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753042] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26045), 1,
      anon_sym_RPAREN,
    STATE(18435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753056] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26047), 1,
      anon_sym_EQ,
    STATE(18436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753070] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26049), 1,
      anon_sym_in,
    STATE(18437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753084] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26051), 1,
      anon_sym_in,
    STATE(18438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753098] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26053), 1,
      anon_sym_STAR,
    STATE(18439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753112] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26055), 1,
      anon_sym_in,
    STATE(18440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26057), 1,
      anon_sym_RPAREN,
    STATE(18441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753140] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26059), 1,
      anon_sym_in,
    STATE(18442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753154] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26061), 1,
      anon_sym_with,
    STATE(18443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753168] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26063), 1,
      anon_sym_RPAREN,
    STATE(18444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753182] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26065), 1,
      anon_sym_RPAREN,
    STATE(18445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753196] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26067), 1,
      anon_sym_with,
    STATE(18446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753210] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26069), 1,
      anon_sym_DOT,
    STATE(18447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753224] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26071), 1,
      anon_sym_RBRACK,
    STATE(18448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26073), 1,
      anon_sym_RPAREN,
    STATE(18449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753252] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26075), 1,
      anon_sym_RBRACK,
    STATE(18450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753266] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26077), 1,
      anon_sym_RPAREN,
    STATE(18451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753280] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26079), 1,
      anon_sym_RBRACE,
    STATE(18452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753294] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26081), 1,
      anon_sym_RBRACE,
    STATE(18453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753308] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26083), 1,
      anon_sym_in,
    STATE(18454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753322] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26085), 1,
      anon_sym_RBRACK,
    STATE(18455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26087), 1,
      anon_sym_DASH_GT,
    STATE(18456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753350] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26089), 1,
      anon_sym_RBRACE,
    STATE(18457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26091), 1,
      anon_sym_RPAREN,
    STATE(18458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753378] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26093), 1,
      anon_sym_with,
    STATE(18459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26095), 1,
      anon_sym_end,
    STATE(18460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753406] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26097), 1,
      anon_sym_with,
    STATE(18461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753420] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5009), 1,
      anon_sym_end,
    STATE(18462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753434] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26099), 1,
      anon_sym_RPAREN,
    STATE(18463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753448] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26101), 1,
      anon_sym_DASH_GT,
    STATE(18464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753462] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26103), 1,
      anon_sym_DOT,
    STATE(18465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753476] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26105), 1,
      anon_sym_RPAREN,
    STATE(18466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753490] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26107), 1,
      anon_sym_RBRACE,
    STATE(18467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753504] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26109), 1,
      aux_sym_number_token1,
    STATE(18468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753518] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26111), 1,
      anon_sym_RPAREN,
    STATE(18469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753532] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20216), 1,
      anon_sym_end,
    STATE(18470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753546] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26113), 1,
      anon_sym_SQUOTE2,
    STATE(18471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26115), 1,
      anon_sym_DQUOTE,
    STATE(18472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26117), 1,
      anon_sym_RBRACE,
    STATE(18473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753588] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26119), 1,
      anon_sym_RPAREN,
    STATE(18474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753602] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1427), 1,
      anon_sym_COLON_COLON,
    STATE(18475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753616] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26121), 1,
      anon_sym_RPAREN,
    STATE(18476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753630] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26123), 1,
      anon_sym_RBRACK,
    STATE(18477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753644] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26125), 1,
      anon_sym_DASH_GT,
    STATE(18478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753658] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26127), 1,
      anon_sym_RBRACE,
    STATE(18479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753672] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26129), 1,
      anon_sym_RPAREN,
    STATE(18480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753686] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26131), 1,
      anon_sym_RPAREN,
    STATE(18481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753700] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26133), 1,
      anon_sym_RBRACE,
    STATE(18482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753714] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26135), 1,
      anon_sym_RPAREN,
    STATE(18483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26137), 1,
      anon_sym_RPAREN,
    STATE(18484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26137), 1,
      anon_sym_RBRACK,
    STATE(18485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753756] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26137), 1,
      anon_sym_RBRACE,
    STATE(18486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26139), 1,
      anon_sym_RPAREN,
    STATE(18487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753784] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26141), 1,
      anon_sym_RPAREN,
    STATE(18488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753798] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26143), 1,
      anon_sym_RPAREN,
    STATE(18489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753812] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26145), 1,
      anon_sym_RPAREN,
    STATE(18490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26147), 1,
      anon_sym_RPAREN,
    STATE(18491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19997), 1,
      anon_sym_end,
    STATE(18492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753854] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11872), 1,
      anon_sym_GT,
    STATE(18493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753868] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26149), 1,
      anon_sym_with,
    STATE(18494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753882] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26151), 1,
      anon_sym_in,
    STATE(18495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753896] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26153), 1,
      anon_sym_DASH_GT,
    STATE(18496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26155), 1,
      anon_sym_RPAREN,
    STATE(18497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753924] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26157), 1,
      anon_sym_DOT,
    STATE(18498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753938] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26159), 1,
      anon_sym_in,
    STATE(18499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753952] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21726), 1,
      anon_sym_GT_RBRACE,
    STATE(18500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753966] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26161), 1,
      anon_sym_RPAREN,
    STATE(18501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753980] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26163), 1,
      anon_sym_RPAREN,
    STATE(18502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [753994] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26165), 1,
      anon_sym_RPAREN,
    STATE(18503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754008] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26167), 1,
      anon_sym_DOT,
    STATE(18504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754022] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20677), 1,
      anon_sym_end,
    STATE(18505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754036] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26169), 1,
      anon_sym_RBRACK,
    STATE(18506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754050] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26171), 1,
      anon_sym_SQUOTE2,
    STATE(18507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754064] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10876), 1,
      anon_sym_COMMA,
    STATE(18508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754078] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26173), 1,
      anon_sym_RBRACE,
    STATE(18509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754092] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26175), 1,
      anon_sym_DQUOTE,
    STATE(18510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754106] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26177), 1,
      anon_sym_STAR,
    STATE(18511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754120] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26179), 1,
      anon_sym_RPAREN,
    STATE(18512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754134] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26181), 1,
      anon_sym_with,
    STATE(18513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26183), 1,
      anon_sym_with,
    STATE(18514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754162] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26185), 1,
      anon_sym_DOT,
    STATE(18515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26187), 1,
      anon_sym_RPAREN,
    STATE(18516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754190] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26189), 1,
      anon_sym_in,
    STATE(18517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754204] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26191), 1,
      anon_sym_RPAREN,
    STATE(18518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754218] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26193), 1,
      anon_sym_RPAREN,
    STATE(18519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754232] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26195), 1,
      anon_sym_DOT,
    STATE(18520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754246] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26197), 1,
      sym__lowercase_identifier,
    STATE(18521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754260] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26199), 1,
      anon_sym_RPAREN,
    STATE(18522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754274] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26201), 1,
      anon_sym_RBRACK,
    STATE(18523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754288] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26203), 1,
      anon_sym_RBRACK,
    STATE(18524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754302] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26205), 1,
      anon_sym_RBRACE,
    STATE(18525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26207), 1,
      anon_sym_RBRACE,
    STATE(18526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754330] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26209), 1,
      anon_sym_with,
    STATE(18527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754344] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26211), 1,
      anon_sym_with,
    STATE(18528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754358] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26213), 1,
      anon_sym_RPAREN,
    STATE(18529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754372] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26215), 1,
      anon_sym_DOT,
    STATE(18530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12718), 1,
      anon_sym_COMMA,
    STATE(18531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754400] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26217), 1,
      anon_sym_DOT,
    STATE(18532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754414] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26219), 1,
      anon_sym_RPAREN,
    STATE(18533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754428] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26221), 1,
      anon_sym_RBRACK,
    STATE(18534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754442] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    STATE(18535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26223), 1,
      anon_sym_DOT,
    STATE(18536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754470] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26225), 1,
      anon_sym_RBRACE,
    STATE(18537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754484] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26227), 1,
      anon_sym_LT_DASH,
    STATE(18538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754498] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26229), 1,
      anon_sym_in,
    STATE(18539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754512] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16689), 1,
      anon_sym_COMMA,
    STATE(18540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754526] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26231), 1,
      anon_sym_RPAREN,
    STATE(18541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754540] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26233), 1,
      anon_sym_LT_DASH,
    STATE(18542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754554] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26235), 1,
      anon_sym_RPAREN,
    STATE(18543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754568] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26237), 1,
      anon_sym_in,
    STATE(18544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754582] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26239), 1,
      anon_sym_RPAREN,
    STATE(18545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754596] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26241), 1,
      anon_sym_RPAREN,
    STATE(18546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26243), 1,
      anon_sym_RPAREN,
    STATE(18547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754624] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26245), 1,
      anon_sym_STAR,
    STATE(18548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754638] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26247), 1,
      anon_sym_RPAREN,
    STATE(18549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754652] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26249), 1,
      anon_sym_RPAREN,
    STATE(18550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754666] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26251), 1,
      anon_sym_RPAREN,
    STATE(18551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754680] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26251), 1,
      anon_sym_RBRACK,
    STATE(18552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26251), 1,
      anon_sym_RBRACE,
    STATE(18553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754708] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26253), 1,
      anon_sym_DOT,
    STATE(18554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754722] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26255), 1,
      anon_sym_DASH_GT,
    STATE(18555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754736] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26257), 1,
      anon_sym_GT,
    STATE(18556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754750] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26259), 1,
      anon_sym_with,
    STATE(18557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754764] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26261), 1,
      anon_sym_RPAREN,
    STATE(18558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754778] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26263), 1,
      sym__lowercase_identifier,
    STATE(18559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754792] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26265), 1,
      anon_sym_in,
    STATE(18560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754806] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18383), 1,
      anon_sym_GT,
    STATE(18561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754820] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26267), 1,
      anon_sym_DOT,
    STATE(18562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754834] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26269), 1,
      anon_sym_RPAREN,
    STATE(18563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754848] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26271), 1,
      sym__lowercase_identifier,
    STATE(18564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754862] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26273), 1,
      anon_sym_in,
    STATE(18565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26275), 1,
      anon_sym_in,
    STATE(18566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754890] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26277), 1,
      anon_sym_RPAREN,
    STATE(18567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754904] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26279), 1,
      anon_sym_STAR,
    STATE(18568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754918] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10434), 1,
      anon_sym_COMMA,
    STATE(18569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754932] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26281), 1,
      anon_sym_with,
    STATE(18570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26283), 1,
      anon_sym_with,
    STATE(18571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754960] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26285), 1,
      anon_sym_DOT,
    STATE(18572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754974] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26287), 1,
      anon_sym_LT_DASH,
    STATE(18573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [754988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26289), 1,
      anon_sym_with,
    STATE(18574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755002] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26291), 1,
      anon_sym_RBRACK,
    STATE(18575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755016] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26293), 1,
      anon_sym_DASH_GT,
    STATE(18576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755030] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3177), 1,
      anon_sym_RPAREN,
    STATE(18577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26295), 1,
      anon_sym_RPAREN,
    STATE(18578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755058] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26297), 1,
      anon_sym_DOT,
    STATE(18579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755072] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26299), 1,
      anon_sym_DOT,
    STATE(18580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755086] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26301), 1,
      anon_sym_in,
    STATE(18581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755100] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11712), 1,
      anon_sym_GT,
    STATE(18582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755114] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26303), 1,
      anon_sym_with,
    STATE(18583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26305), 1,
      anon_sym_with,
    STATE(18584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755142] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14689), 1,
      anon_sym_end,
    STATE(18585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26307), 1,
      aux_sym_number_token1,
    STATE(18586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755170] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26309), 1,
      anon_sym_DASH_GT,
    STATE(18587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26311), 1,
      anon_sym_DOT,
    STATE(18588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755198] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26313), 1,
      anon_sym_DASH_GT,
    STATE(18589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755212] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26315), 1,
      anon_sym_RPAREN,
    STATE(18590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755226] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18353), 1,
      anon_sym_GT,
    STATE(18591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755240] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26317), 1,
      anon_sym_DASH_GT,
    STATE(18592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26319), 1,
      anon_sym_in,
    STATE(18593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755268] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26321), 1,
      anon_sym_in,
    STATE(18594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755282] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26323), 1,
      anon_sym_RPAREN,
    STATE(18595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755296] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24719), 1,
      anon_sym_RPAREN,
    STATE(18596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755310] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26325), 1,
      anon_sym_DASH_GT,
    STATE(18597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755324] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26327), 1,
      anon_sym_RPAREN,
    STATE(18598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755338] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26329), 1,
      anon_sym_in,
    STATE(18599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755352] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26331), 1,
      anon_sym_RPAREN,
    STATE(18600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755366] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26333), 1,
      anon_sym_DASH_GT,
    STATE(18601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755380] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26335), 1,
      anon_sym_in,
    STATE(18602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755394] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26337), 1,
      anon_sym_in,
    STATE(18603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755408] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26339), 1,
      anon_sym_in,
    STATE(18604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755422] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26341), 1,
      anon_sym_RPAREN,
    STATE(18605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755436] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26343), 1,
      anon_sym_RPAREN,
    STATE(18606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755450] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26343), 1,
      anon_sym_RBRACK,
    STATE(18607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755464] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26343), 1,
      anon_sym_RBRACE,
    STATE(18608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755478] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18438), 1,
      anon_sym_GT,
    STATE(18609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755492] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26345), 1,
      anon_sym_in,
    STATE(18610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755506] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18301), 1,
      anon_sym_GT,
    STATE(18611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755520] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26347), 1,
      anon_sym_RBRACK,
    STATE(18612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755534] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26349), 1,
      anon_sym_RBRACE,
    STATE(18613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755548] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26351), 1,
      anon_sym_RBRACE,
    STATE(18614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755562] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26353), 1,
      sym__uppercase_identifier,
    STATE(18615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755576] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26355), 1,
      anon_sym_end,
    STATE(18616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755590] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26357), 1,
      anon_sym_DOT,
    STATE(18617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755604] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26359), 1,
      anon_sym_RBRACE,
    STATE(18618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755618] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26361), 1,
      anon_sym_DASH_GT,
    STATE(18619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755632] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26363), 1,
      anon_sym_DOT,
    STATE(18620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26365), 1,
      anon_sym_in,
    STATE(18621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755660] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26367), 1,
      anon_sym_in,
    STATE(18622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755674] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26369), 1,
      anon_sym_STAR,
    STATE(18623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26371), 1,
      sym__lowercase_identifier,
    STATE(18624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755702] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26373), 1,
      anon_sym_with,
    STATE(18625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755716] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26375), 1,
      anon_sym_with,
    STATE(18626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755730] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26377), 1,
      anon_sym_DOT,
    STATE(18627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755744] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26379), 1,
      anon_sym_RBRACE,
    STATE(18628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755758] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26381), 1,
      anon_sym_RBRACK,
    STATE(18629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755772] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26383), 1,
      anon_sym_RPAREN,
    STATE(18630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755786] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26385), 1,
      anon_sym_RPAREN,
    STATE(18631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755800] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26387), 1,
      anon_sym_RBRACK,
    STATE(18632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755814] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11620), 1,
      anon_sym_DASH_GT,
    STATE(18633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755828] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21431), 1,
      anon_sym_GT_RBRACE,
    STATE(18634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755842] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26389), 1,
      anon_sym_RPAREN,
    STATE(18635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755856] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24529), 1,
      anon_sym_RBRACE,
    STATE(18636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755870] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26391), 1,
      anon_sym_RBRACK,
    STATE(18637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755884] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26393), 1,
      anon_sym_with,
    STATE(18638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755898] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26395), 1,
      anon_sym_with,
    STATE(18639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755912] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11856), 1,
      anon_sym_GT,
    STATE(18640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26397), 1,
      anon_sym_RPAREN,
    STATE(18641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755940] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26399), 1,
      anon_sym_RBRACE,
    STATE(18642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755954] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26401), 1,
      anon_sym_DOT,
    STATE(18643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755968] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26403), 1,
      anon_sym_DASH_GT,
    STATE(18644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755982] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26405), 1,
      anon_sym_in,
    STATE(18645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [755996] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26407), 1,
      anon_sym_RBRACK,
    STATE(18646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756010] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20248), 1,
      anon_sym_end,
    STATE(18647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756024] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26409), 1,
      anon_sym_SQUOTE2,
    STATE(18648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26411), 1,
      anon_sym_DQUOTE,
    STATE(18649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756052] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26413), 1,
      anon_sym_RBRACE,
    STATE(18650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756066] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26415), 1,
      sym__lowercase_identifier,
    STATE(18651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756080] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26417), 1,
      anon_sym_RPAREN,
    STATE(18652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756094] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26419), 1,
      anon_sym_RPAREN,
    STATE(18653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756108] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26421), 1,
      anon_sym_RBRACK,
    STATE(18654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756122] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26423), 1,
      anon_sym_EQ,
    STATE(18655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756136] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26425), 1,
      anon_sym_RPAREN,
    STATE(18656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756150] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26427), 1,
      anon_sym_RBRACE,
    STATE(18657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756164] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26429), 1,
      anon_sym_RBRACK,
    STATE(18658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756178] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26431), 1,
      anon_sym_RPAREN,
    STATE(18659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756192] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26433), 1,
      anon_sym_RPAREN,
    STATE(18660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756206] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26435), 1,
      anon_sym_RPAREN,
    STATE(18661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756220] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26435), 1,
      anon_sym_RBRACK,
    STATE(18662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26435), 1,
      anon_sym_RBRACE,
    STATE(18663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756248] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26437), 1,
      anon_sym_RBRACE,
    STATE(18664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756262] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26439), 1,
      anon_sym_RPAREN,
    STATE(18665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756276] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20398), 1,
      anon_sym_end,
    STATE(18666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26441), 1,
      anon_sym_RBRACE,
    STATE(18667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756304] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21800), 1,
      anon_sym_GT_RBRACE,
    STATE(18668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26443), 1,
      anon_sym_LT_DASH,
    STATE(18669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20712), 1,
      anon_sym_end,
    STATE(18670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26445), 1,
      anon_sym_RBRACE,
    STATE(18671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756360] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26447), 1,
      anon_sym_DOT,
    STATE(18672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756374] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26449), 1,
      anon_sym_SQUOTE2,
    STATE(18673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756388] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26451), 1,
      anon_sym_RBRACE,
    STATE(18674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756402] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26453), 1,
      anon_sym_SQUOTE2,
    STATE(18675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756416] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26455), 1,
      anon_sym_DQUOTE,
    STATE(18676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756430] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11818), 1,
      anon_sym_DASH_GT,
    STATE(18677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756444] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26457), 1,
      anon_sym_STAR,
    STATE(18678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756458] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9050), 1,
      anon_sym_DASH_GT,
    STATE(18679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26459), 1,
      anon_sym_with,
    STATE(18680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756486] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26461), 1,
      anon_sym_with,
    STATE(18681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756500] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26463), 1,
      anon_sym_DOT,
    STATE(18682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26465), 1,
      sym__lowercase_identifier,
    STATE(18683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756528] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26467), 1,
      anon_sym_DQUOTE,
    STATE(18684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756542] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26469), 1,
      anon_sym_in,
    STATE(18685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756556] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26471), 1,
      anon_sym_DASH_GT,
    STATE(18686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756570] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26473), 1,
      anon_sym_DASH_GT,
    STATE(18687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756584] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26475), 1,
      anon_sym_DOT,
    STATE(18688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756598] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26477), 1,
      anon_sym_DASH_GT,
    STATE(18689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756612] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26479), 1,
      anon_sym_in,
    STATE(18690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26481), 1,
      anon_sym_RPAREN,
    STATE(18691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756640] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26483), 1,
      anon_sym_RPAREN,
    STATE(18692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756654] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26485), 1,
      anon_sym_with,
    STATE(18693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756668] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26487), 1,
      anon_sym_with,
    STATE(18694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756682] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26489), 1,
      anon_sym_RPAREN,
    STATE(18695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756696] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26491), 1,
      anon_sym_RPAREN,
    STATE(18696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756710] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26493), 1,
      anon_sym_RPAREN,
    STATE(18697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756724] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26495), 1,
      anon_sym_DOT,
    STATE(18698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756738] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26497), 1,
      anon_sym_with,
    STATE(18699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756752] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26499), 1,
      anon_sym_RBRACE,
    STATE(18700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756766] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26501), 1,
      anon_sym_with,
    STATE(18701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756780] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26503), 1,
      anon_sym_DASH_GT,
    STATE(18702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13550), 1,
      anon_sym_COMMA,
    STATE(18703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756808] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26505), 1,
      anon_sym_DASH_GT,
    STATE(18704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26507), 1,
      anon_sym_DASH_GT,
    STATE(18705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756836] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26509), 1,
      anon_sym_RPAREN,
    STATE(18706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756850] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26511), 1,
      anon_sym_LT_DASH,
    STATE(18707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756864] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26513), 1,
      anon_sym_RPAREN,
    STATE(18708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756878] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26515), 1,
      anon_sym_RBRACK,
    STATE(18709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756892] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26517), 1,
      anon_sym_DOT,
    STATE(18710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756906] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26519), 1,
      anon_sym_RBRACK,
    STATE(18711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756920] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26521), 1,
      anon_sym_RBRACE,
    STATE(18712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26523), 1,
      anon_sym_RPAREN,
    STATE(18713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756948] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26525), 1,
      anon_sym_RBRACE,
    STATE(18714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756962] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26527), 1,
      anon_sym_RPAREN,
    STATE(18715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756976] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26529), 1,
      anon_sym_RPAREN,
    STATE(18716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [756990] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26529), 1,
      anon_sym_RBRACK,
    STATE(18717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757004] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26529), 1,
      anon_sym_RBRACE,
    STATE(18718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26531), 1,
      anon_sym_end,
    STATE(18719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757032] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26533), 1,
      anon_sym_RBRACE,
    STATE(18720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757046] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26535), 1,
      anon_sym_RBRACK,
    STATE(18721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757060] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26537), 1,
      anon_sym_RPAREN,
    STATE(18722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757074] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26539), 1,
      anon_sym_RBRACK,
    STATE(18723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757088] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26541), 1,
      anon_sym_RPAREN,
    STATE(18724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757102] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18617), 1,
      anon_sym_DASH_GT,
    STATE(18725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757116] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26543), 1,
      anon_sym_RBRACE,
    STATE(18726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757130] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26545), 1,
      anon_sym_DOT,
    STATE(18727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757144] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26547), 1,
      anon_sym_RBRACE,
    STATE(18728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757158] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26549), 1,
      anon_sym_RPAREN,
    STATE(18729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757172] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26551), 1,
      anon_sym_RPAREN,
    STATE(18730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757186] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26553), 1,
      anon_sym_RPAREN,
    STATE(18731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757200] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26555), 1,
      anon_sym_RPAREN,
    STATE(18732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757214] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26557), 1,
      anon_sym_LT_DASH,
    STATE(18733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757228] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26559), 1,
      anon_sym_with,
    STATE(18734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757242] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26561), 1,
      anon_sym_with,
    STATE(18735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757256] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26563), 1,
      anon_sym_DOT,
    STATE(18736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757270] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26565), 1,
      anon_sym_RBRACE,
    STATE(18737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757284] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26567), 1,
      anon_sym_RPAREN,
    STATE(18738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26569), 1,
      anon_sym_RBRACK,
    STATE(18739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757312] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26571), 1,
      anon_sym_RPAREN,
    STATE(18740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757326] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26573), 1,
      anon_sym_GT,
    STATE(18741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11469), 1,
      anon_sym_GT,
    STATE(18742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757354] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26575), 1,
      anon_sym_end,
    STATE(18743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757368] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26577), 1,
      anon_sym_end,
    STATE(18744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757382] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26579), 1,
      anon_sym_in,
    STATE(18745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757396] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15519), 1,
      anon_sym_COMMA,
    STATE(18746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757410] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26581), 1,
      anon_sym_with,
    STATE(18747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757424] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26583), 1,
      anon_sym_with,
    STATE(18748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757438] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26585), 1,
      anon_sym_DASH_GT,
    STATE(18749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757452] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26587), 1,
      anon_sym_end,
    STATE(18750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757466] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26589), 1,
      sym__lowercase_identifier,
    STATE(18751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757480] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26591), 1,
      anon_sym_DOT,
    STATE(18752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757494] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26593), 1,
      anon_sym_GT,
    STATE(18753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757508] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11696), 1,
      anon_sym_GT,
    STATE(18754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757522] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26595), 1,
      sym__lowercase_identifier,
    STATE(18755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757536] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26597), 1,
      anon_sym_in,
    STATE(18756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757550] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26599), 1,
      anon_sym_RPAREN,
    STATE(18757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757564] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26601), 1,
      anon_sym_DASH_GT,
    STATE(18758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757578] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26603), 1,
      anon_sym_RPAREN,
    STATE(18759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757592] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26605), 1,
      anon_sym_RPAREN,
    STATE(18760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757606] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26607), 1,
      anon_sym_RPAREN,
    STATE(18761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757620] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26609), 1,
      anon_sym_RPAREN,
    STATE(18762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757634] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26611), 1,
      anon_sym_RBRACK,
    STATE(18763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757648] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26613), 1,
      anon_sym_COLON2,
    STATE(18764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757662] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26615), 1,
      anon_sym_RBRACE,
    STATE(18765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757676] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26617), 1,
      anon_sym_RPAREN,
    STATE(18766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757690] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26619), 1,
      anon_sym_RBRACK,
    STATE(18767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757704] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26621), 1,
      anon_sym_RBRACE,
    STATE(18768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757718] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26623), 1,
      anon_sym_RPAREN,
    STATE(18769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757732] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26625), 1,
      anon_sym_RPAREN,
    STATE(18770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757746] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26625), 1,
      anon_sym_RBRACK,
    STATE(18771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757760] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26625), 1,
      anon_sym_RBRACE,
    STATE(18772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22702), 1,
      anon_sym_GT_RBRACE,
    STATE(18773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757788] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26627), 1,
      anon_sym_LT_DASH,
    STATE(18774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757802] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26629), 1,
      anon_sym_DASH_GT,
    STATE(18775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757816] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26631), 1,
      anon_sym_RPAREN,
    STATE(18776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757830] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3095), 1,
      anon_sym_RPAREN,
    STATE(18777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757844] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26633), 1,
      anon_sym_RPAREN,
    STATE(18778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26635), 1,
      anon_sym_RBRACK,
    STATE(18779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757872] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26637), 1,
      anon_sym_GT,
    STATE(18780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757886] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26639), 1,
      anon_sym_DOT,
    STATE(18781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757900] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26641), 1,
      anon_sym_RPAREN,
    STATE(18782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757914] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18363), 1,
      anon_sym_GT,
    STATE(18783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757928] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26643), 1,
      anon_sym_RPAREN,
    STATE(18784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26645), 1,
      anon_sym_GT,
    STATE(18785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26647), 1,
      anon_sym_end,
    STATE(18786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757970] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26649), 1,
      anon_sym_RPAREN,
    STATE(18787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757984] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26651), 1,
      anon_sym_with,
    STATE(18788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [757998] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26653), 1,
      anon_sym_with,
    STATE(18789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758012] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26655), 1,
      anon_sym_DOT,
    STATE(18790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758026] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18464), 1,
      anon_sym_GT,
    STATE(18791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26657), 1,
      anon_sym_RPAREN,
    STATE(18792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758054] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3121), 1,
      anon_sym_RPAREN,
    STATE(18793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758068] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26659), 1,
      anon_sym_RPAREN,
    STATE(18794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758082] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21112), 1,
      anon_sym_end,
    STATE(18795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26661), 1,
      anon_sym_RBRACE,
    STATE(18796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758110] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26663), 1,
      anon_sym_RPAREN,
    STATE(18797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758124] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21269), 1,
      anon_sym_GT_RBRACE,
    STATE(18798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758138] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26665), 1,
      anon_sym_in,
    STATE(18799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758152] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26667), 1,
      anon_sym_RPAREN,
    STATE(18800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758166] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26669), 1,
      anon_sym_with,
    STATE(18801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26671), 1,
      anon_sym_with,
    STATE(18802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758194] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26673), 1,
      anon_sym_RPAREN,
    STATE(18803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758208] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26675), 1,
      anon_sym_RBRACK,
    STATE(18804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758222] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26677), 1,
      anon_sym_RBRACE,
    STATE(18805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26679), 1,
      anon_sym_DOT,
    STATE(18806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758250] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26681), 1,
      anon_sym_in,
    STATE(18807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758264] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26683), 1,
      anon_sym_in,
    STATE(18808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758278] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26685), 1,
      anon_sym_RBRACE,
    STATE(18809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758292] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26687), 1,
      anon_sym_RPAREN,
    STATE(18810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26689), 1,
      anon_sym_DASH_GT,
    STATE(18811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758320] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26691), 1,
      anon_sym_RPAREN,
    STATE(18812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758334] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26693), 1,
      anon_sym_RBRACK,
    STATE(18813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758348] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21516), 1,
      anon_sym_GT_RBRACE,
    STATE(18814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758362] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20402), 1,
      anon_sym_end,
    STATE(18815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26695), 1,
      anon_sym_RPAREN,
    STATE(18816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758390] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26697), 1,
      anon_sym_RBRACE,
    STATE(18817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758404] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26699), 1,
      anon_sym_RPAREN,
    STATE(18818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758418] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26701), 1,
      anon_sym_RPAREN,
    STATE(18819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758432] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26703), 1,
      anon_sym_RPAREN,
    STATE(18820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758446] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20515), 1,
      anon_sym_end,
    STATE(18821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20252), 1,
      anon_sym_end,
    STATE(18822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758474] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26705), 1,
      anon_sym_RPAREN,
    STATE(18823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758488] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26707), 1,
      anon_sym_RPAREN,
    STATE(18824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758502] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26707), 1,
      anon_sym_RBRACK,
    STATE(18825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758516] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26707), 1,
      anon_sym_RBRACE,
    STATE(18826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758530] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26709), 1,
      anon_sym_SQUOTE2,
    STATE(18827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758544] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26711), 1,
      anon_sym_RPAREN,
    STATE(18828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758558] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26711), 1,
      anon_sym_RBRACK,
    STATE(18829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758572] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26711), 1,
      anon_sym_RBRACE,
    STATE(18830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758586] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26713), 1,
      anon_sym_DASH_GT,
    STATE(18831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758600] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26715), 1,
      anon_sym_DASH_GT,
    STATE(18832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758614] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26717), 1,
      anon_sym_RPAREN,
    STATE(18833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758628] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26719), 1,
      anon_sym_DASH_GT,
    STATE(18834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758642] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26721), 1,
      anon_sym_DOT,
    STATE(18835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758656] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26723), 1,
      anon_sym_DQUOTE,
    STATE(18836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758670] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26725), 1,
      anon_sym_RPAREN,
    STATE(18837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758684] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26727), 1,
      anon_sym_SQUOTE2,
    STATE(18838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758698] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26729), 1,
      anon_sym_SQUOTE2,
    STATE(18839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758712] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26731), 1,
      anon_sym_DASH_GT,
    STATE(18840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758726] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26733), 1,
      anon_sym_end,
    STATE(18841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758740] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26735), 1,
      anon_sym_with,
    STATE(18842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758754] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26737), 1,
      anon_sym_with,
    STATE(18843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758768] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26739), 1,
      anon_sym_DOT,
    STATE(18844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758782] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15589), 1,
      anon_sym_COMMA,
    STATE(18845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758796] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26741), 1,
      anon_sym_RPAREN,
    STATE(18846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758810] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26743), 1,
      sym__lowercase_identifier,
    STATE(18847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18855), 1,
      anon_sym_DASH_GT,
    STATE(18848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758838] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26745), 1,
      anon_sym_LT_DASH,
    STATE(18849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758852] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26747), 1,
      anon_sym_DASH_GT,
    STATE(18850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758866] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26749), 1,
      anon_sym_DQUOTE,
    STATE(18851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758880] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26751), 1,
      anon_sym_RPAREN,
    STATE(18852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26753), 1,
      anon_sym_RBRACE,
    STATE(18853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758908] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15889), 1,
      anon_sym_COMMA,
    STATE(18854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26755), 1,
      anon_sym_with,
    STATE(18855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758936] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26757), 1,
      anon_sym_with,
    STATE(18856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758950] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26759), 1,
      anon_sym_RBRACE,
    STATE(18857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758964] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26761), 1,
      anon_sym_RBRACK,
    STATE(18858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758978] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26763), 1,
      anon_sym_LT_DASH,
    STATE(18859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [758992] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26765), 1,
      anon_sym_DOT,
    STATE(18860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759006] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26767), 1,
      anon_sym_DQUOTE,
    STATE(18861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759020] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16709), 1,
      anon_sym_DASH_GT,
    STATE(18862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16010), 1,
      anon_sym_COMMA,
    STATE(18863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759048] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26769), 1,
      anon_sym_LT_DASH,
    STATE(18864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759062] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26771), 1,
      anon_sym_RBRACE,
    STATE(18865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759076] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26773), 1,
      anon_sym_RPAREN,
    STATE(18866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759090] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24615), 1,
      anon_sym_RPAREN,
    STATE(18867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759104] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10463), 1,
      anon_sym_COMMA,
    STATE(18868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759118] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26775), 1,
      anon_sym_RPAREN,
    STATE(18869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759132] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26777), 1,
      anon_sym_RPAREN,
    STATE(18870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759146] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26779), 1,
      anon_sym_RPAREN,
    STATE(18871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26781), 1,
      anon_sym_RPAREN,
    STATE(18872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759174] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26783), 1,
      anon_sym_LT_DASH,
    STATE(18873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26785), 1,
      anon_sym_RPAREN,
    STATE(18874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759202] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26787), 1,
      anon_sym_RBRACE,
    STATE(18875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759216] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3097), 1,
      anon_sym_RPAREN,
    STATE(18876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759230] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26789), 1,
      anon_sym_RPAREN,
    STATE(18877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759244] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26791), 1,
      anon_sym_RPAREN,
    STATE(18878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26791), 1,
      anon_sym_RBRACK,
    STATE(18879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759272] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26791), 1,
      anon_sym_RBRACE,
    STATE(18880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759286] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26793), 1,
      anon_sym_RPAREN,
    STATE(18881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759300] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26795), 1,
      anon_sym_RPAREN,
    STATE(18882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759314] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26797), 1,
      anon_sym_in,
    STATE(18883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759328] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26799), 1,
      anon_sym_in,
    STATE(18884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26801), 1,
      anon_sym_in,
    STATE(18885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759356] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26803), 1,
      anon_sym_in,
    STATE(18886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759370] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26805), 1,
      anon_sym_in,
    STATE(18887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759384] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26807), 1,
      anon_sym_in,
    STATE(18888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759398] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26809), 1,
      anon_sym_DOT,
    STATE(18889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26811), 1,
      anon_sym_in,
    STATE(18890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3165), 1,
      anon_sym_RPAREN,
    STATE(18891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759440] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26813), 1,
      anon_sym_in,
    STATE(18892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759454] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26815), 1,
      anon_sym_RPAREN,
    STATE(18893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759468] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26817), 1,
      anon_sym_RPAREN,
    STATE(18894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759482] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26819), 1,
      anon_sym_in,
    STATE(18895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26821), 1,
      anon_sym_with,
    STATE(18896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759510] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26823), 1,
      anon_sym_with,
    STATE(18897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759524] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26825), 1,
      anon_sym_DOT,
    STATE(18898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759538] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26827), 1,
      anon_sym_in,
    STATE(18899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759552] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26829), 1,
      anon_sym_in,
    STATE(18900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759566] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26831), 1,
      anon_sym_in,
    STATE(18901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759580] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26833), 1,
      anon_sym_RBRACK,
    STATE(18902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26835), 1,
      anon_sym_in,
    STATE(18903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759608] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3159), 1,
      anon_sym_RPAREN,
    STATE(18904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759622] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5543), 1,
      anon_sym_RPAREN,
    STATE(18905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759636] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26837), 1,
      anon_sym_SQUOTE2,
    STATE(18906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759650] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26839), 1,
      anon_sym_in,
    STATE(18907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759664] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10237), 1,
      anon_sym_COMMA,
    STATE(18908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759678] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26841), 1,
      anon_sym_with,
    STATE(18909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759692] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26843), 1,
      anon_sym_with,
    STATE(18910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759706] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26845), 1,
      anon_sym_RBRACE,
    STATE(18911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759720] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26847), 1,
      anon_sym_GT,
    STATE(18912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759734] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26849), 1,
      anon_sym_RPAREN,
    STATE(18913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759748] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26851), 1,
      anon_sym_DOT,
    STATE(18914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759762] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26853), 1,
      anon_sym_RPAREN,
    STATE(18915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26855), 1,
      anon_sym_RPAREN,
    STATE(18916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26857), 1,
      sym__lowercase_identifier,
    STATE(18917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759804] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26859), 1,
      anon_sym_RBRACE,
    STATE(18918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759818] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26861), 1,
      anon_sym_DASH_GT,
    STATE(18919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759832] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26863), 1,
      anon_sym_RBRACE,
    STATE(18920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759846] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26865), 1,
      anon_sym_RPAREN,
    STATE(18921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759860] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26867), 1,
      anon_sym_DQUOTE,
    STATE(18922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759874] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26869), 1,
      anon_sym_DASH_GT,
    STATE(18923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759888] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26871), 1,
      anon_sym_RPAREN,
    STATE(18924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759902] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24727), 1,
      anon_sym_RBRACE,
    STATE(18925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26873), 1,
      anon_sym_DOT,
    STATE(18926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759930] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26875), 1,
      anon_sym_LT_DASH,
    STATE(18927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759944] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3113), 1,
      anon_sym_RPAREN,
    STATE(18928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759958] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26877), 1,
      anon_sym_RPAREN,
    STATE(18929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759972] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21564), 1,
      anon_sym_GT_RBRACE,
    STATE(18930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [759986] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26879), 1,
      anon_sym_RPAREN,
    STATE(18931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760000] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26881), 1,
      anon_sym_RPAREN,
    STATE(18932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760014] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26881), 1,
      anon_sym_RBRACK,
    STATE(18933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760028] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26881), 1,
      anon_sym_RBRACE,
    STATE(18934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760042] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26883), 1,
      anon_sym_RPAREN,
    STATE(18935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760056] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20266), 1,
      anon_sym_end,
    STATE(18936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760070] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15656), 1,
      anon_sym_DASH_GT,
    STATE(18937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760084] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26885), 1,
      anon_sym_SQUOTE2,
    STATE(18938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760098] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26887), 1,
      anon_sym_RPAREN,
    STATE(18939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760112] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26889), 1,
      anon_sym_DQUOTE,
    STATE(18940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26891), 1,
      anon_sym_RBRACE,
    STATE(18941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760140] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18333), 1,
      anon_sym_GT,
    STATE(18942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760154] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26893), 1,
      anon_sym_DOT,
    STATE(18943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760168] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26895), 1,
      sym__lowercase_identifier,
    STATE(18944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760182] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26897), 1,
      anon_sym_DASH_GT,
    STATE(18945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760196] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26899), 1,
      anon_sym_RBRACK,
    STATE(18946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760210] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26901), 1,
      anon_sym_RBRACE,
    STATE(18947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760224] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21927), 1,
      anon_sym_GT_RBRACE,
    STATE(18948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26903), 1,
      anon_sym_RBRACE,
    STATE(18949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760252] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26905), 1,
      anon_sym_with,
    STATE(18950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760266] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26907), 1,
      anon_sym_with,
    STATE(18951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760280] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26909), 1,
      anon_sym_DOT,
    STATE(18952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760294] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26911), 1,
      anon_sym_DASH_GT,
    STATE(18953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760308] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26913), 1,
      anon_sym_RPAREN,
    STATE(18954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760322] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20756), 1,
      anon_sym_end,
    STATE(18955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22801), 1,
      anon_sym_GT_RBRACE,
    STATE(18956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760350] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26915), 1,
      anon_sym_SQUOTE2,
    STATE(18957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26917), 1,
      anon_sym_DQUOTE,
    STATE(18958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760378] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26919), 1,
      anon_sym_STAR,
    STATE(18959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11654), 1,
      anon_sym_GT,
    STATE(18960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760406] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26921), 1,
      anon_sym_DASH_GT,
    STATE(18961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760420] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5455), 1,
      anon_sym_end,
    STATE(18962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760434] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26923), 1,
      anon_sym_with,
    STATE(18963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760448] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26925), 1,
      anon_sym_with,
    STATE(18964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760462] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26927), 1,
      anon_sym_RPAREN,
    STATE(18965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760476] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26929), 1,
      anon_sym_RBRACK,
    STATE(18966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760490] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26931), 1,
      anon_sym_RBRACE,
    STATE(18967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760504] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26933), 1,
      anon_sym_DOT,
    STATE(18968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760518] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26935), 1,
      sym__lowercase_identifier,
    STATE(18969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760532] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26937), 1,
      anon_sym_DASH_GT,
    STATE(18970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760546] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20167), 1,
      anon_sym_end,
    STATE(18971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26939), 1,
      anon_sym_in,
    STATE(18972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26941), 1,
      anon_sym_RPAREN,
    STATE(18973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760588] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21576), 1,
      anon_sym_GT_RBRACE,
    STATE(18974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760602] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26943), 1,
      anon_sym_RBRACK,
    STATE(18975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760616] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26945), 1,
      anon_sym_in,
    STATE(18976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760630] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26947), 1,
      anon_sym_DASH_GT,
    STATE(18977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760644] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26949), 1,
      anon_sym_RPAREN,
    STATE(18978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760658] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26951), 1,
      sym__lowercase_identifier,
    STATE(18979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760672] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26953), 1,
      anon_sym_RBRACE,
    STATE(18980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760686] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26955), 1,
      anon_sym_DASH_GT,
    STATE(18981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760700] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26957), 1,
      aux_sym_number_token1,
    STATE(18982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760714] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26959), 1,
      anon_sym_RPAREN,
    STATE(18983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26961), 1,
      anon_sym_in,
    STATE(18984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26963), 1,
      anon_sym_RPAREN,
    STATE(18985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760756] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26965), 1,
      anon_sym_RPAREN,
    STATE(18986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26965), 1,
      anon_sym_RBRACK,
    STATE(18987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760784] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26965), 1,
      anon_sym_RBRACE,
    STATE(18988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760798] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26967), 1,
      sym__lowercase_identifier,
    STATE(18989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760812] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26969), 1,
      anon_sym_DASH_GT,
    STATE(18990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26971), 1,
      anon_sym_RBRACE,
    STATE(18991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20199), 1,
      anon_sym_end,
    STATE(18992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760854] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26973), 1,
      anon_sym_RBRACK,
    STATE(18993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760868] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26975), 1,
      anon_sym_RPAREN,
    STATE(18994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760882] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26977), 1,
      anon_sym_RBRACE,
    STATE(18995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760896] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26979), 1,
      anon_sym_in,
    STATE(18996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26981), 1,
      anon_sym_DOT,
    STATE(18997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760924] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26983), 1,
      anon_sym_RBRACE,
    STATE(18998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760938] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26985), 1,
      anon_sym_RPAREN,
    STATE(18999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760952] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26987), 1,
      anon_sym_RPAREN,
    STATE(19000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760966] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26989), 1,
      anon_sym_DASH_GT,
    STATE(19001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760980] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26991), 1,
      anon_sym_SQUOTE2,
    STATE(19002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [760994] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26993), 1,
      anon_sym_DASH_GT,
    STATE(19003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761008] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26995), 1,
      anon_sym_with,
    STATE(19004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761022] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26997), 1,
      anon_sym_with,
    STATE(19005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761036] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(26999), 1,
      anon_sym_DOT,
    STATE(19006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761050] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27001), 1,
      anon_sym_DASH_GT,
    STATE(19007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761064] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27003), 1,
      anon_sym_DQUOTE,
    STATE(19008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761078] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27005), 1,
      anon_sym_in,
    STATE(19009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761092] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21311), 1,
      anon_sym_GT_RBRACE,
    STATE(19010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761106] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27007), 1,
      anon_sym_in,
    STATE(19011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761120] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27009), 1,
      anon_sym_RPAREN,
    STATE(19012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761134] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27011), 1,
      anon_sym_RBRACE,
    STATE(19013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20533), 1,
      anon_sym_end,
    STATE(19014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761162] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27013), 1,
      anon_sym_DASH_GT,
    STATE(19015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27015), 1,
      anon_sym_in,
    STATE(19016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761190] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27017), 1,
      anon_sym_with,
    STATE(19017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761204] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27019), 1,
      anon_sym_with,
    STATE(19018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761218] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27021), 1,
      anon_sym_SQUOTE2,
    STATE(19019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761232] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27023), 1,
      anon_sym_RPAREN,
    STATE(19020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761246] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27025), 1,
      anon_sym_end,
    STATE(19021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761260] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27027), 1,
      anon_sym_DOT,
    STATE(19022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761274] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27029), 1,
      anon_sym_DQUOTE,
    STATE(19023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761288] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27031), 1,
      anon_sym_RBRACK,
    STATE(19024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761302] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4999), 1,
      anon_sym_end,
    STATE(19025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27033), 1,
      anon_sym_SQUOTE2,
    STATE(19026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761330] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27035), 1,
      anon_sym_RPAREN,
    STATE(19027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761344] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27037), 1,
      sym__lowercase_identifier,
    STATE(19028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761358] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27039), 1,
      anon_sym_RPAREN,
    STATE(19029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761372] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27041), 1,
      anon_sym_RBRACE,
    STATE(19030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27043), 1,
      anon_sym_RPAREN,
    STATE(19031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761400] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27045), 1,
      anon_sym_DASH_GT,
    STATE(19032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761414] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27047), 1,
      sym__lowercase_identifier,
    STATE(19033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761428] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27049), 1,
      anon_sym_in,
    STATE(19034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761442] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27051), 1,
      anon_sym_RPAREN,
    STATE(19035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27053), 1,
      anon_sym_RBRACK,
    STATE(19036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761470] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27055), 1,
      anon_sym_RBRACK,
    STATE(19037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761484] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27057), 1,
      anon_sym_RPAREN,
    STATE(19038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761498] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27059), 1,
      anon_sym_RPAREN,
    STATE(19039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761512] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27059), 1,
      anon_sym_RBRACK,
    STATE(19040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761526] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27059), 1,
      anon_sym_RBRACE,
    STATE(19041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761540] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27061), 1,
      anon_sym_RBRACE,
    STATE(19042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761554] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27063), 1,
      anon_sym_RBRACE,
    STATE(19043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761568] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27065), 1,
      anon_sym_RBRACE,
    STATE(19044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761582] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27067), 1,
      anon_sym_SQUOTE2,
    STATE(19045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761596] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27069), 1,
      anon_sym_DASH_GT,
    STATE(19046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11638), 1,
      anon_sym_GT,
    STATE(19047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761624] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27071), 1,
      anon_sym_in,
    STATE(19048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761638] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27073), 1,
      anon_sym_DASH_GT,
    STATE(19049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761652] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27075), 1,
      anon_sym_DOT,
    STATE(19050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761666] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27077), 1,
      anon_sym_RBRACK,
    STATE(19051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761680] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27079), 1,
      anon_sym_RBRACK,
    STATE(19052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27081), 1,
      anon_sym_end,
    STATE(19053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761708] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27083), 1,
      anon_sym_with,
    STATE(19054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761722] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27085), 1,
      anon_sym_with,
    STATE(19055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761736] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27087), 1,
      anon_sym_DOT,
    STATE(19056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761750] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27089), 1,
      anon_sym_RBRACK,
    STATE(19057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761764] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27091), 1,
      anon_sym_RBRACE,
    STATE(19058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761778] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27093), 1,
      sym__lowercase_identifier,
    STATE(19059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761792] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27095), 1,
      anon_sym_RBRACK,
    STATE(19060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761806] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19067), 1,
      anon_sym_DASH_GT,
    STATE(19061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761820] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27097), 1,
      anon_sym_RBRACE,
    STATE(19062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761834] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27099), 1,
      anon_sym_RPAREN,
    STATE(19063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761848] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27101), 1,
      anon_sym_with,
    STATE(19064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761862] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27103), 1,
      anon_sym_with,
    STATE(19065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27105), 1,
      anon_sym_RBRACK,
    STATE(19066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761890] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27107), 1,
      anon_sym_end,
    STATE(19067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761904] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27109), 1,
      anon_sym_RBRACE,
    STATE(19068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761918] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27111), 1,
      anon_sym_DOT,
    STATE(19069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761932] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27113), 1,
      anon_sym_RBRACE,
    STATE(19070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27115), 1,
      anon_sym_in,
    STATE(19071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761960] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27117), 1,
      anon_sym_DASH_GT,
    STATE(19072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761974] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27119), 1,
      anon_sym_RPAREN,
    STATE(19073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [761988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27121), 1,
      anon_sym_RPAREN,
    STATE(19074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762002] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18367), 1,
      anon_sym_GT,
    STATE(19075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762016] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27123), 1,
      anon_sym_in,
    STATE(19076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762030] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27125), 1,
      anon_sym_RPAREN,
    STATE(19077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27127), 1,
      anon_sym_RPAREN,
    STATE(19078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762058] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27129), 1,
      anon_sym_RBRACK,
    STATE(19079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762072] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27131), 1,
      anon_sym_RPAREN,
    STATE(19080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762086] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27133), 1,
      anon_sym_RPAREN,
    STATE(19081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762100] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27133), 1,
      anon_sym_RBRACK,
    STATE(19082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762114] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27133), 1,
      anon_sym_RBRACE,
    STATE(19083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27135), 1,
      anon_sym_RBRACE,
    STATE(19084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762142] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27137), 1,
      anon_sym_in,
    STATE(19085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27139), 1,
      anon_sym_RBRACK,
    STATE(19086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762170] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27141), 1,
      anon_sym_RPAREN,
    STATE(19087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27143), 1,
      anon_sym_DASH_GT,
    STATE(19088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762198] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27145), 1,
      anon_sym_RBRACE,
    STATE(19089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762212] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27147), 1,
      anon_sym_DASH_GT,
    STATE(19090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762226] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27149), 1,
      anon_sym_DOT,
    STATE(19091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762240] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27151), 1,
      anon_sym_RPAREN,
    STATE(19092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18276), 1,
      anon_sym_GT,
    STATE(19093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762268] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27153), 1,
      anon_sym_RPAREN,
    STATE(19094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762282] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27155), 1,
      anon_sym_with,
    STATE(19095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762296] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27157), 1,
      anon_sym_with,
    STATE(19096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762310] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27159), 1,
      anon_sym_DOT,
    STATE(19097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762324] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27161), 1,
      anon_sym_RPAREN,
    STATE(19098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762338] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27163), 1,
      anon_sym_in,
    STATE(19099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762352] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11766), 1,
      anon_sym_DASH_GT,
    STATE(19100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762366] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24783), 1,
      anon_sym_RBRACE,
    STATE(19101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762380] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27165), 1,
      anon_sym_DASH_GT,
    STATE(19102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762394] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27167), 1,
      anon_sym_RBRACE,
    STATE(19103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762408] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27169), 1,
      anon_sym_with,
    STATE(19104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762422] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27171), 1,
      anon_sym_with,
    STATE(19105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762436] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27173), 1,
      anon_sym_DOT,
    STATE(19106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762450] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24787), 1,
      anon_sym_RBRACE,
    STATE(19107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762464] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27175), 1,
      anon_sym_RPAREN,
    STATE(19108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762478] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27177), 1,
      anon_sym_DOT,
    STATE(19109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762492] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27179), 1,
      anon_sym_DASH_GT,
    STATE(19110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762506] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11776), 1,
      anon_sym_GT,
    STATE(19111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762520] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27181), 1,
      anon_sym_DOT,
    STATE(19112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762534] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27183), 1,
      anon_sym_RPAREN,
    STATE(19113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762548] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27185), 1,
      anon_sym_RPAREN,
    STATE(19114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762562] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27187), 1,
      anon_sym_in,
    STATE(19115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762576] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18547), 1,
      anon_sym_COMMA,
    STATE(19116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762590] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27189), 1,
      anon_sym_DOT,
    STATE(19117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762604] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27191), 1,
      anon_sym_GT,
    STATE(19118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762618] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27193), 1,
      anon_sym_RPAREN,
    STATE(19119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762632] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27195), 1,
      anon_sym_RPAREN,
    STATE(19120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27197), 1,
      anon_sym_RPAREN,
    STATE(19121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762660] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27197), 1,
      anon_sym_RBRACK,
    STATE(19122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762674] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27197), 1,
      anon_sym_RBRACE,
    STATE(19123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21175), 1,
      anon_sym_GT_RBRACE,
    STATE(19124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762702] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27199), 1,
      anon_sym_RPAREN,
    STATE(19125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762716] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27201), 1,
      anon_sym_end,
    STATE(19126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762730] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27203), 1,
      anon_sym_RPAREN,
    STATE(19127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762744] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27205), 1,
      anon_sym_RBRACK,
    STATE(19128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762758] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27207), 1,
      anon_sym_DASH_GT,
    STATE(19129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762772] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27209), 1,
      anon_sym_RBRACE,
    STATE(19130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762786] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27211), 1,
      anon_sym_DOT,
    STATE(19131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762800] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27213), 1,
      anon_sym_DQUOTE,
    STATE(19132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762814] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27215), 1,
      anon_sym_DASH_GT,
    STATE(19133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762828] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27217), 1,
      anon_sym_RPAREN,
    STATE(19134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762842] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27219), 1,
      anon_sym_with,
    STATE(19135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762856] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27221), 1,
      anon_sym_with,
    STATE(19136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762870] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27223), 1,
      anon_sym_DOT,
    STATE(19137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762884] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27225), 1,
      anon_sym_RBRACE,
    STATE(19138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762898] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27227), 1,
      anon_sym_DASH_GT,
    STATE(19139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762912] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27229), 1,
      anon_sym_RPAREN,
    STATE(19140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27231), 1,
      anon_sym_RBRACE,
    STATE(19141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762940] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    STATE(19142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762954] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27233), 1,
      anon_sym_RPAREN,
    STATE(19143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762968] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27235), 1,
      anon_sym_with,
    STATE(19144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762982] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27237), 1,
      anon_sym_with,
    STATE(19145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [762996] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27239), 1,
      anon_sym_RPAREN,
    STATE(19146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763010] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27241), 1,
      anon_sym_STAR,
    STATE(19147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763024] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27243), 1,
      anon_sym_RPAREN,
    STATE(19148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27245), 1,
      anon_sym_DOT,
    STATE(19149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763052] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27247), 1,
      anon_sym_in,
    STATE(19150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763066] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27249), 1,
      anon_sym_LT_DASH,
    STATE(19151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763080] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15432), 1,
      anon_sym_COMMA,
    STATE(19152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763094] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27251), 1,
      anon_sym_RPAREN,
    STATE(19153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763108] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27253), 1,
      anon_sym_RPAREN,
    STATE(19154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763122] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27255), 1,
      anon_sym_RBRACE,
    STATE(19155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763136] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27257), 1,
      anon_sym_with,
    STATE(19156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763150] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27259), 1,
      anon_sym_RPAREN,
    STATE(19157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763164] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27261), 1,
      anon_sym_RBRACK,
    STATE(19158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763178] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27263), 1,
      anon_sym_RPAREN,
    STATE(19159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763192] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27265), 1,
      anon_sym_RPAREN,
    STATE(19160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763206] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27267), 1,
      anon_sym_RPAREN,
    STATE(19161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763220] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27267), 1,
      anon_sym_RBRACK,
    STATE(19162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27267), 1,
      anon_sym_RBRACE,
    STATE(19163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763248] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27269), 1,
      anon_sym_RBRACE,
    STATE(19164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763262] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27271), 1,
      anon_sym_RPAREN,
    STATE(19165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763276] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27273), 1,
      anon_sym_RBRACE,
    STATE(19166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27275), 1,
      anon_sym_RPAREN,
    STATE(19167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763304] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27277), 1,
      anon_sym_RPAREN,
    STATE(19168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27279), 1,
      anon_sym_DASH_GT,
    STATE(19169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27281), 1,
      anon_sym_RPAREN,
    STATE(19170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27283), 1,
      anon_sym_DOT,
    STATE(19171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763360] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27285), 1,
      anon_sym_RBRACE,
    STATE(19172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763374] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27287), 1,
      anon_sym_RBRACK,
    STATE(19173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763388] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27289), 1,
      anon_sym_RBRACE,
    STATE(19174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763402] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27291), 1,
      anon_sym_with,
    STATE(19175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763416] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27293), 1,
      anon_sym_with,
    STATE(19176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763430] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27295), 1,
      anon_sym_DOT,
    STATE(19177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763444] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27297), 1,
      anon_sym_RPAREN,
    STATE(19178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763458] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27299), 1,
      anon_sym_with,
    STATE(19179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27301), 1,
      anon_sym_RPAREN,
    STATE(19180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763486] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27303), 1,
      anon_sym_DOT,
    STATE(19181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763500] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27305), 1,
      anon_sym_RPAREN,
    STATE(19182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27307), 1,
      anon_sym_RBRACE,
    STATE(19183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763528] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27309), 1,
      anon_sym_with,
    STATE(19184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763542] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27311), 1,
      anon_sym_with,
    STATE(19185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763556] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27313), 1,
      anon_sym_LT_DASH,
    STATE(19186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763570] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27315), 1,
      anon_sym_EQ,
    STATE(19187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763584] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27317), 1,
      anon_sym_done,
    STATE(19188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763598] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27319), 1,
      anon_sym_DOT,
    STATE(19189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763612] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27321), 1,
      anon_sym_in,
    STATE(19190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27323), 1,
      anon_sym_in,
    STATE(19191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763640] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27325), 1,
      anon_sym_in,
    STATE(19192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763654] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27327), 1,
      anon_sym_in,
    STATE(19193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763668] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27329), 1,
      anon_sym_RPAREN,
    STATE(19194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763682] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27331), 1,
      anon_sym_RPAREN,
    STATE(19195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763696] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27333), 1,
      anon_sym_in,
    STATE(19196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763710] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27335), 1,
      anon_sym_DASH_GT,
    STATE(19197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763724] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27337), 1,
      anon_sym_RPAREN,
    STATE(19198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763738] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27339), 1,
      sym__lowercase_identifier,
    STATE(19199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763752] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27341), 1,
      anon_sym_RPAREN,
    STATE(19200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763766] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27343), 1,
      anon_sym_RPAREN,
    STATE(19201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763780] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27343), 1,
      anon_sym_RBRACK,
    STATE(19202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27343), 1,
      anon_sym_RBRACE,
    STATE(19203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763808] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27345), 1,
      anon_sym_RBRACE,
    STATE(19204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10397), 1,
      anon_sym_COMMA,
    STATE(19205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763836] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20069), 1,
      anon_sym_end,
    STATE(19206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763850] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27347), 1,
      anon_sym_RBRACE,
    STATE(19207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763864] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27349), 1,
      anon_sym_end,
    STATE(19208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763878] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22017), 1,
      anon_sym_GT_RBRACE,
    STATE(19209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763892] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18272), 1,
      sym__uppercase_identifier,
    STATE(19210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763906] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27351), 1,
      anon_sym_DOT,
    STATE(19211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763920] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27353), 1,
      anon_sym_RPAREN,
    STATE(19212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27355), 1,
      anon_sym_DASH_GT,
    STATE(19213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763948] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27357), 1,
      anon_sym_RBRACE,
    STATE(19214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763962] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27359), 1,
      anon_sym_with,
    STATE(19215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763976] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27361), 1,
      anon_sym_with,
    STATE(19216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [763990] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27363), 1,
      anon_sym_DOT,
    STATE(19217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764004] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27365), 1,
      anon_sym_end,
    STATE(19218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27367), 1,
      anon_sym_RPAREN,
    STATE(19219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764032] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27369), 1,
      anon_sym_SQUOTE2,
    STATE(19220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764046] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20778), 1,
      anon_sym_end,
    STATE(19221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764060] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27371), 1,
      anon_sym_SQUOTE2,
    STATE(19222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764074] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27373), 1,
      anon_sym_DQUOTE,
    STATE(19223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764088] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27375), 1,
      anon_sym_with,
    STATE(19224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764102] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27377), 1,
      anon_sym_with,
    STATE(19225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764116] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27379), 1,
      anon_sym_DQUOTE,
    STATE(19226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764130] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27381), 1,
      anon_sym_DASH_GT,
    STATE(19227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764144] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27383), 1,
      anon_sym_RPAREN,
    STATE(19228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764158] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27385), 1,
      anon_sym_DOT,
    STATE(19229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764172] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27387), 1,
      anon_sym_RBRACE,
    STATE(19230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764186] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27389), 1,
      anon_sym_with,
    STATE(19231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764200] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27391), 1,
      anon_sym_RPAREN,
    STATE(19232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764214] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27393), 1,
      sym__lowercase_identifier,
    STATE(19233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764228] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27395), 1,
      anon_sym_RPAREN,
    STATE(19234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764242] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27397), 1,
      anon_sym_with,
    STATE(19235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764256] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27399), 1,
      anon_sym_DASH_GT,
    STATE(19236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764270] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15941), 1,
      anon_sym_COMMA,
    STATE(19237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764284] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27401), 1,
      anon_sym_LT_DASH,
    STATE(19238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27403), 1,
      anon_sym_DASH_GT,
    STATE(19239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764312] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27405), 1,
      anon_sym_RPAREN,
    STATE(19240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764326] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27407), 1,
      anon_sym_RPAREN,
    STATE(19241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27407), 1,
      anon_sym_RBRACK,
    STATE(19242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764354] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27407), 1,
      anon_sym_RBRACE,
    STATE(19243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764368] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3173), 1,
      anon_sym_RPAREN,
    STATE(19244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764382] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27409), 1,
      anon_sym_DOT,
    STATE(19245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764396] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27411), 1,
      anon_sym_DOT,
    STATE(19246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764410] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27413), 1,
      sym__lowercase_identifier,
    STATE(19247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764424] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27415), 1,
      anon_sym_DASH_GT,
    STATE(19248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764438] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13777), 1,
      anon_sym_COMMA,
    STATE(19249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764452] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27417), 1,
      anon_sym_RPAREN,
    STATE(19250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764466] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27419), 1,
      anon_sym_DOT,
    STATE(19251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764480] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27421), 1,
      anon_sym_RBRACK,
    STATE(19252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764494] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27423), 1,
      anon_sym_LT_DASH,
    STATE(19253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764508] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27425), 1,
      anon_sym_RBRACE,
    STATE(19254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764522] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27427), 1,
      anon_sym_with,
    STATE(19255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764536] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27429), 1,
      anon_sym_with,
    STATE(19256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764550] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27431), 1,
      anon_sym_DOT,
    STATE(19257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764564] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27433), 1,
      anon_sym_in,
    STATE(19258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764578] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15273), 1,
      anon_sym_COMMA,
    STATE(19259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764592] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27435), 1,
      anon_sym_in,
    STATE(19260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764606] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27437), 1,
      anon_sym_in,
    STATE(19261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764620] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27439), 1,
      anon_sym_in,
    STATE(19262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764634] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11948), 1,
      anon_sym_COMMA,
    STATE(19263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764648] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27441), 1,
      anon_sym_with,
    STATE(19264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764662] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27443), 1,
      anon_sym_with,
    STATE(19265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764676] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22638), 1,
      anon_sym_GT_RBRACE,
    STATE(19266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764690] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27445), 1,
      sym__lowercase_identifier,
    STATE(19267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764704] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27447), 1,
      anon_sym_in,
    STATE(19268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764718] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27449), 1,
      anon_sym_DOT,
    STATE(19269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764732] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27451), 1,
      anon_sym_RBRACE,
    STATE(19270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764746] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27453), 1,
      anon_sym_RBRACK,
    STATE(19271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764760] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27455), 1,
      anon_sym_DASH_GT,
    STATE(19272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27457), 1,
      anon_sym_LT_DASH,
    STATE(19273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764788] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27459), 1,
      anon_sym_RPAREN,
    STATE(19274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764802] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3141), 1,
      anon_sym_RPAREN,
    STATE(19275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764816] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27461), 1,
      anon_sym_RPAREN,
    STATE(19276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764830] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27463), 1,
      anon_sym_RPAREN,
    STATE(19277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764844] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27465), 1,
      anon_sym_RBRACE,
    STATE(19278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27467), 1,
      anon_sym_DASH_GT,
    STATE(19279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764872] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27469), 1,
      anon_sym_RPAREN,
    STATE(19280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764886] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27471), 1,
      anon_sym_RPAREN,
    STATE(19281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764900] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27471), 1,
      anon_sym_RBRACK,
    STATE(19282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764914] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27471), 1,
      anon_sym_RBRACE,
    STATE(19283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764928] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27473), 1,
      anon_sym_RPAREN,
    STATE(19284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27475), 1,
      anon_sym_RBRACK,
    STATE(19285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27477), 1,
      anon_sym_in,
    STATE(19286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764970] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27479), 1,
      anon_sym_DASH_GT,
    STATE(19287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764984] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27481), 1,
      anon_sym_in,
    STATE(19288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [764998] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27483), 1,
      anon_sym_in,
    STATE(19289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765012] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27485), 1,
      anon_sym_RPAREN,
    STATE(19290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765026] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27487), 1,
      anon_sym_DOT,
    STATE(19291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27489), 1,
      anon_sym_LT_DASH,
    STATE(19292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765054] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16078), 1,
      anon_sym_COMMA,
    STATE(19293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765068] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27491), 1,
      anon_sym_end,
    STATE(19294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765082] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27493), 1,
      anon_sym_with,
    STATE(19295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27495), 1,
      anon_sym_with,
    STATE(19296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765110] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27497), 1,
      anon_sym_DOT,
    STATE(19297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765124] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27499), 1,
      anon_sym_RBRACK,
    STATE(19298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765138] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3137), 1,
      anon_sym_RPAREN,
    STATE(19299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765152] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27501), 1,
      anon_sym_RBRACE,
    STATE(19300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765166] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27503), 1,
      anon_sym_in,
    STATE(19301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22061), 1,
      anon_sym_GT_RBRACE,
    STATE(19302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765194] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27505), 1,
      anon_sym_DASH_GT,
    STATE(19303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765208] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27507), 1,
      anon_sym_with,
    STATE(19304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765222] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27509), 1,
      anon_sym_with,
    STATE(19305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20796), 1,
      anon_sym_end,
    STATE(19306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765250] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27511), 1,
      anon_sym_RPAREN,
    STATE(19307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765264] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27513), 1,
      anon_sym_SQUOTE2,
    STATE(19308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765278] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27515), 1,
      anon_sym_DOT,
    STATE(19309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765292] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27517), 1,
      anon_sym_LT_DASH,
    STATE(19310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3105), 1,
      anon_sym_RPAREN,
    STATE(19311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765320] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27519), 1,
      anon_sym_in,
    STATE(19312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765334] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27521), 1,
      anon_sym_DQUOTE,
    STATE(19313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765348] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27523), 1,
      anon_sym_RPAREN,
    STATE(19314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765362] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27525), 1,
      anon_sym_RPAREN,
    STATE(19315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11728), 1,
      anon_sym_GT,
    STATE(19316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765390] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27527), 1,
      anon_sym_DASH_GT,
    STATE(19317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765404] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27529), 1,
      anon_sym_RBRACK,
    STATE(19318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765418] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27531), 1,
      sym__lowercase_identifier,
    STATE(19319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765432] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27533), 1,
      anon_sym_RPAREN,
    STATE(19320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765446] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27535), 1,
      anon_sym_RPAREN,
    STATE(19321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27535), 1,
      anon_sym_RBRACK,
    STATE(19322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765474] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27535), 1,
      anon_sym_RBRACE,
    STATE(19323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765488] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19027), 1,
      anon_sym_RBRACK,
    STATE(19324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765502] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27537), 1,
      anon_sym_DASH_GT,
    STATE(19325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765516] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27539), 1,
      anon_sym_RPAREN,
    STATE(19326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765530] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27541), 1,
      anon_sym_RBRACK,
    STATE(19327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765544] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27543), 1,
      anon_sym_RBRACK,
    STATE(19328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765558] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18454), 1,
      anon_sym_GT,
    STATE(19329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765572] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27545), 1,
      anon_sym_RBRACE,
    STATE(19330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765586] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27547), 1,
      anon_sym_DOT,
    STATE(19331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765600] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27549), 1,
      anon_sym_RBRACE,
    STATE(19332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765614] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27551), 1,
      anon_sym_in,
    STATE(19333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765628] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27553), 1,
      anon_sym_RPAREN,
    STATE(19334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765642] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27555), 1,
      anon_sym_with,
    STATE(19335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765656] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27557), 1,
      anon_sym_with,
    STATE(19336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765670] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27559), 1,
      anon_sym_DOT,
    STATE(19337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765684] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27561), 1,
      anon_sym_RPAREN,
    STATE(19338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765698] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27561), 1,
      anon_sym_RBRACK,
    STATE(19339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765712] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27561), 1,
      anon_sym_RBRACE,
    STATE(19340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765726] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22035), 1,
      anon_sym_GT_RBRACE,
    STATE(19341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765740] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27563), 1,
      anon_sym_in,
    STATE(19342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765754] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27565), 1,
      anon_sym_RBRACE,
    STATE(19343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765768] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27567), 1,
      anon_sym_with,
    STATE(19344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765782] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27569), 1,
      anon_sym_with,
    STATE(19345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765796] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27571), 1,
      anon_sym_RPAREN,
    STATE(19346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765810] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27573), 1,
      anon_sym_in,
    STATE(19347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27575), 1,
      anon_sym_DASH_GT,
    STATE(19348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765838] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27577), 1,
      anon_sym_DOT,
    STATE(19349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765852] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27579), 1,
      anon_sym_RBRACK,
    STATE(19350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765866] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27581), 1,
      anon_sym_RBRACE,
    STATE(19351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765880] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27583), 1,
      anon_sym_in,
    STATE(19352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21716), 1,
      anon_sym_GT_RBRACE,
    STATE(19353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765908] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27585), 1,
      anon_sym_RPAREN,
    STATE(19354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27587), 1,
      anon_sym_RPAREN,
    STATE(19355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765936] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27589), 1,
      anon_sym_RBRACE,
    STATE(19356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765950] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27591), 1,
      anon_sym_RPAREN,
    STATE(19357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765964] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27593), 1,
      anon_sym_DASH_GT,
    STATE(19358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765978] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20290), 1,
      anon_sym_end,
    STATE(19359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [765992] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27595), 1,
      anon_sym_RPAREN,
    STATE(19360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766006] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27597), 1,
      anon_sym_RPAREN,
    STATE(19361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766020] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27597), 1,
      anon_sym_RBRACK,
    STATE(19362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27597), 1,
      anon_sym_RBRACE,
    STATE(19363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766048] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27599), 1,
      anon_sym_SQUOTE2,
    STATE(19364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766062] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27601), 1,
      anon_sym_RPAREN,
    STATE(19365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766076] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27603), 1,
      anon_sym_DQUOTE,
    STATE(19366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766090] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27605), 1,
      anon_sym_DASH_GT,
    STATE(19367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766104] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27607), 1,
      sym__lowercase_identifier,
    STATE(19368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766118] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27609), 1,
      anon_sym_DASH_GT,
    STATE(19369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766132] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18325), 1,
      anon_sym_GT,
    STATE(19370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766146] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27611), 1,
      anon_sym_DOT,
    STATE(19371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27613), 1,
      anon_sym_RBRACK,
    STATE(19372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766174] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15486), 1,
      anon_sym_COMMA,
    STATE(19373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27615), 1,
      anon_sym_RBRACE,
    STATE(19374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766202] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27617), 1,
      anon_sym_with,
    STATE(19375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766216] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27619), 1,
      anon_sym_with,
    STATE(19376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766230] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27621), 1,
      anon_sym_DOT,
    STATE(19377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766244] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27623), 1,
      anon_sym_RPAREN,
    STATE(19378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27625), 1,
      anon_sym_in,
    STATE(19379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766272] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27627), 1,
      anon_sym_in,
    STATE(19380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766286] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27629), 1,
      anon_sym_RBRACE,
    STATE(19381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766300] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27631), 1,
      anon_sym_end,
    STATE(19382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766314] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27633), 1,
      anon_sym_DASH_GT,
    STATE(19383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766328] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27635), 1,
      anon_sym_with,
    STATE(19384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27637), 1,
      anon_sym_with,
    STATE(19385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766356] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27639), 1,
      anon_sym_RPAREN,
    STATE(19386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766370] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27641), 1,
      anon_sym_RPAREN,
    STATE(19387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766384] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27643), 1,
      anon_sym_RBRACE,
    STATE(19388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766398] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27645), 1,
      anon_sym_DOT,
    STATE(19389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27647), 1,
      anon_sym_RPAREN,
    STATE(19390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27649), 1,
      anon_sym_PLUS_EQ,
    STATE(19391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766440] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27651), 1,
      anon_sym_DASH_GT,
    STATE(19392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766454] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27653), 1,
      anon_sym_RPAREN,
    STATE(19393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766468] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27655), 1,
      anon_sym_RPAREN,
    STATE(19394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766482] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27657), 1,
      anon_sym_DASH_GT,
    STATE(19395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27659), 1,
      anon_sym_RBRACK,
    STATE(19396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766510] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27661), 1,
      anon_sym_RPAREN,
    STATE(19397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766524] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27663), 1,
      sym__lowercase_identifier,
    STATE(19398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766538] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27665), 1,
      anon_sym_RBRACE,
    STATE(19399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766552] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27667), 1,
      anon_sym_RPAREN,
    STATE(19400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766566] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27669), 1,
      anon_sym_RPAREN,
    STATE(19401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766580] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27669), 1,
      anon_sym_RBRACK,
    STATE(19402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27669), 1,
      anon_sym_RBRACE,
    STATE(19403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766608] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11203), 1,
      anon_sym_DASH_GT,
    STATE(19404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766622] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27671), 1,
      anon_sym_RBRACK,
    STATE(19405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766636] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27673), 1,
      anon_sym_in,
    STATE(19406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766650] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27675), 1,
      anon_sym_DASH_GT,
    STATE(19407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766664] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27677), 1,
      anon_sym_DASH_GT,
    STATE(19408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766678] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27679), 1,
      anon_sym_DASH_GT,
    STATE(19409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766692] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27681), 1,
      anon_sym_in,
    STATE(19410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766706] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27683), 1,
      anon_sym_DOT,
    STATE(19411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766720] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27685), 1,
      anon_sym_DASH_GT,
    STATE(19412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766734] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18329), 1,
      anon_sym_GT,
    STATE(19413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766748] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27687), 1,
      anon_sym_DASH_GT,
    STATE(19414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766762] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27689), 1,
      anon_sym_with,
    STATE(19415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27691), 1,
      anon_sym_with,
    STATE(19416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27693), 1,
      anon_sym_DOT,
    STATE(19417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766804] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27695), 1,
      anon_sym_RPAREN,
    STATE(19418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766818] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27697), 1,
      anon_sym_RBRACE,
    STATE(19419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766832] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27699), 1,
      anon_sym_RBRACK,
    STATE(19420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766846] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27701), 1,
      anon_sym_RBRACE,
    STATE(19421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766860] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27703), 1,
      anon_sym_end,
    STATE(19422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766874] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27705), 1,
      anon_sym_RPAREN,
    STATE(19423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766888] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27707), 1,
      anon_sym_with,
    STATE(19424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766902] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27709), 1,
      anon_sym_with,
    STATE(19425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27711), 1,
      anon_sym_RBRACK,
    STATE(19426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766930] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27713), 1,
      anon_sym_RBRACE,
    STATE(19427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766944] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27715), 1,
      anon_sym_RPAREN,
    STATE(19428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766958] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27717), 1,
      anon_sym_DOT,
    STATE(19429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766972] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27719), 1,
      anon_sym_RPAREN,
    STATE(19430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [766986] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27721), 1,
      anon_sym_LT_DASH,
    STATE(19431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767000] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27723), 1,
      anon_sym_RPAREN,
    STATE(19432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767014] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27725), 1,
      anon_sym_DOT,
    STATE(19433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767028] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27727), 1,
      anon_sym_RPAREN,
    STATE(19434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767042] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27729), 1,
      anon_sym_RPAREN,
    STATE(19435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767056] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3155), 1,
      anon_sym_RPAREN,
    STATE(19436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767070] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27731), 1,
      anon_sym_RPAREN,
    STATE(19437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767084] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27733), 1,
      anon_sym_DASH_GT,
    STATE(19438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767098] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27735), 1,
      anon_sym_DASH_GT,
    STATE(19439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767112] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27737), 1,
      anon_sym_RPAREN,
    STATE(19440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27739), 1,
      anon_sym_RPAREN,
    STATE(19441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767140] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27739), 1,
      anon_sym_RBRACK,
    STATE(19442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767154] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27739), 1,
      anon_sym_RBRACE,
    STATE(19443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767168] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27741), 1,
      anon_sym_DASH_GT,
    STATE(19444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767182] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27743), 1,
      anon_sym_RPAREN,
    STATE(19445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767196] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27745), 1,
      anon_sym_RBRACE,
    STATE(19446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767210] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27747), 1,
      anon_sym_in,
    STATE(19447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767224] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27749), 1,
      anon_sym_end,
    STATE(19448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27751), 1,
      anon_sym_RPAREN,
    STATE(19449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767252] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27753), 1,
      sym__lowercase_identifier,
    STATE(19450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767266] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27755), 1,
      anon_sym_DOT,
    STATE(19451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767280] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27757), 1,
      anon_sym_RBRACK,
    STATE(19452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767294] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27759), 1,
      anon_sym_RBRACE,
    STATE(19453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767308] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27761), 1,
      anon_sym_RPAREN,
    STATE(19454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767322] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27763), 1,
      anon_sym_with,
    STATE(19455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27765), 1,
      anon_sym_with,
    STATE(19456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767350] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27767), 1,
      anon_sym_DOT,
    STATE(19457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27769), 1,
      anon_sym_RBRACE,
    STATE(19458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767378] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27771), 1,
      anon_sym_end,
    STATE(19459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27773), 1,
      anon_sym_RPAREN,
    STATE(19460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767406] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27775), 1,
      anon_sym_RPAREN,
    STATE(19461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767420] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27777), 1,
      anon_sym_RBRACK,
    STATE(19462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767434] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27779), 1,
      anon_sym_RBRACE,
    STATE(19463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767448] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27781), 1,
      anon_sym_with,
    STATE(19464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767462] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27783), 1,
      anon_sym_with,
    STATE(19465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767476] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27785), 1,
      anon_sym_RPAREN,
    STATE(19466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767490] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27787), 1,
      anon_sym_RPAREN,
    STATE(19467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767504] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27789), 1,
      anon_sym_RBRACK,
    STATE(19468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767518] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27791), 1,
      anon_sym_DOT,
    STATE(19469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767532] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27793), 1,
      anon_sym_RPAREN,
    STATE(19470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767546] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27795), 1,
      anon_sym_RPAREN,
    STATE(19471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27797), 1,
      anon_sym_in,
    STATE(19472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27799), 1,
      anon_sym_RBRACE,
    STATE(19473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767588] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27801), 1,
      anon_sym_RPAREN,
    STATE(19474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767602] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27803), 1,
      anon_sym_in,
    STATE(19475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767616] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27805), 1,
      anon_sym_in,
    STATE(19476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767630] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27807), 1,
      anon_sym_RBRACE,
    STATE(19477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767644] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27809), 1,
      anon_sym_in,
    STATE(19478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767658] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27811), 1,
      anon_sym_RPAREN,
    STATE(19479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767672] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27813), 1,
      anon_sym_RPAREN,
    STATE(19480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767686] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27815), 1,
      anon_sym_RPAREN,
    STATE(19481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767700] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27815), 1,
      anon_sym_RBRACK,
    STATE(19482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767714] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27815), 1,
      anon_sym_RBRACE,
    STATE(19483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27817), 1,
      anon_sym_DOT_DOT,
    STATE(19484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27819), 1,
      anon_sym_RBRACE,
    STATE(19485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767756] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27821), 1,
      anon_sym_RPAREN,
    STATE(19486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27823), 1,
      anon_sym_DOT_DOT,
    STATE(19487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767784] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27825), 1,
      anon_sym_DOT_DOT,
    STATE(19488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767798] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27827), 1,
      anon_sym_EQ,
    STATE(19489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767812] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27829), 1,
      anon_sym_DOT,
    STATE(19490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27831), 1,
      anon_sym_RPAREN,
    STATE(19491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27833), 1,
      anon_sym_DASH_GT,
    STATE(19492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767854] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11884), 1,
      anon_sym_GT,
    STATE(19493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767868] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27835), 1,
      anon_sym_with,
    STATE(19494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767882] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27837), 1,
      anon_sym_with,
    STATE(19495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767896] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27839), 1,
      anon_sym_DOT,
    STATE(19496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27841), 1,
      anon_sym_RBRACK,
    STATE(19497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767924] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27843), 1,
      anon_sym_RPAREN,
    STATE(19498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767938] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27845), 1,
      anon_sym_RPAREN,
    STATE(19499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767952] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27847), 1,
      anon_sym_RPAREN,
    STATE(19500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767966] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27849), 1,
      anon_sym_DASH_GT,
    STATE(19501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767980] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27851), 1,
      anon_sym_DASH_GT,
    STATE(19502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [767994] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27853), 1,
      anon_sym_with,
    STATE(19503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768008] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27855), 1,
      anon_sym_with,
    STATE(19504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768022] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27857), 1,
      anon_sym_RBRACE,
    STATE(19505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768036] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27859), 1,
      anon_sym_DOT,
    STATE(19506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768050] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27861), 1,
      anon_sym_in,
    STATE(19507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768064] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27863), 1,
      anon_sym_DOT,
    STATE(19508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768078] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27865), 1,
      anon_sym_RBRACK,
    STATE(19509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768092] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16165), 1,
      anon_sym_DASH_GT,
    STATE(19510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768106] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27867), 1,
      anon_sym_DOT,
    STATE(19511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768120] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27869), 1,
      anon_sym_RPAREN,
    STATE(19512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768134] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27871), 1,
      anon_sym_RPAREN,
    STATE(19513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27873), 1,
      anon_sym_RPAREN,
    STATE(19514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768162] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7685), 1,
      anon_sym_COMMA,
    STATE(19515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    STATE(19516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768190] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27875), 1,
      anon_sym_LT_DASH,
    STATE(19517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768204] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3175), 1,
      anon_sym_RPAREN,
    STATE(19518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768218] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27877), 1,
      anon_sym_RPAREN,
    STATE(19519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768232] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27879), 1,
      anon_sym_RPAREN,
    STATE(19520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768246] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27879), 1,
      anon_sym_RBRACK,
    STATE(19521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768260] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27879), 1,
      anon_sym_RBRACE,
    STATE(19522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768274] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27881), 1,
      anon_sym_RPAREN,
    STATE(19523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768288] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27883), 1,
      anon_sym_RPAREN,
    STATE(19524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768302] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27885), 1,
      anon_sym_RBRACK,
    STATE(19525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27887), 1,
      anon_sym_DOT,
    STATE(19526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768330] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27889), 1,
      anon_sym_RPAREN,
    STATE(19527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768344] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27891), 1,
      anon_sym_end,
    STATE(19528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768358] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27893), 1,
      anon_sym_DOT,
    STATE(19529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768372] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27895), 1,
      anon_sym_RBRACE,
    STATE(19530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27897), 1,
      anon_sym_RBRACK,
    STATE(19531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768400] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27899), 1,
      anon_sym_RPAREN,
    STATE(19532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768414] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27901), 1,
      anon_sym_with,
    STATE(19533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768428] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27903), 1,
      anon_sym_with,
    STATE(19534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768442] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27905), 1,
      anon_sym_DOT,
    STATE(19535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27907), 1,
      anon_sym_RPAREN,
    STATE(19536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768470] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27909), 1,
      anon_sym_RBRACK,
    STATE(19537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768484] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27911), 1,
      anon_sym_RBRACE,
    STATE(19538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768498] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1815), 1,
      anon_sym_end,
    STATE(19539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768512] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27913), 1,
      anon_sym_DASH_GT,
    STATE(19540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768526] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27915), 1,
      anon_sym_RBRACE,
    STATE(19541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768540] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27917), 1,
      anon_sym_with,
    STATE(19542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768554] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27919), 1,
      anon_sym_with,
    STATE(19543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768568] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27921), 1,
      anon_sym_RPAREN,
    STATE(19544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768582] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27923), 1,
      anon_sym_RBRACE,
    STATE(19545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768596] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27925), 1,
      anon_sym_STAR,
    STATE(19546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27927), 1,
      anon_sym_DOT,
    STATE(19547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768624] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27929), 1,
      sym__lowercase_identifier,
    STATE(19548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768638] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27931), 1,
      anon_sym_DOT,
    STATE(19549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768652] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27933), 1,
      anon_sym_RBRACE,
    STATE(19550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768666] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27935), 1,
      anon_sym_with,
    STATE(19551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768680] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27937), 1,
      anon_sym_RPAREN,
    STATE(19552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27939), 1,
      anon_sym_RPAREN,
    STATE(19553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768708] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27941), 1,
      anon_sym_RBRACE,
    STATE(19554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768722] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16058), 1,
      anon_sym_COMMA,
    STATE(19555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768736] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27943), 1,
      anon_sym_with,
    STATE(19556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768750] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27945), 1,
      anon_sym_DOT,
    STATE(19557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768764] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27947), 1,
      anon_sym_RPAREN,
    STATE(19558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768778] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27949), 1,
      anon_sym_RPAREN,
    STATE(19559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768792] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27949), 1,
      anon_sym_RBRACK,
    STATE(19560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768806] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27949), 1,
      anon_sym_RBRACE,
    STATE(19561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768820] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5563), 1,
      anon_sym_end,
    STATE(19562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768834] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27951), 1,
      anon_sym_RBRACE,
    STATE(19563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768848] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27953), 1,
      aux_sym_number_token1,
    STATE(19564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768862] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27955), 1,
      anon_sym_RPAREN,
    STATE(19565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27957), 1,
      anon_sym_LT_DASH,
    STATE(19566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768890] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27959), 1,
      anon_sym_DOT,
    STATE(19567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768904] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27961), 1,
      anon_sym_RPAREN,
    STATE(19568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768918] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3147), 1,
      anon_sym_RPAREN,
    STATE(19569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768932] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15226), 1,
      anon_sym_COMMA,
    STATE(19570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27963), 1,
      anon_sym_with,
    STATE(19571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768960] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27965), 1,
      anon_sym_with,
    STATE(19572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768974] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27967), 1,
      anon_sym_DOT,
    STATE(19573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [768988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27969), 1,
      anon_sym_DASH_GT,
    STATE(19574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769002] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27971), 1,
      sym__lowercase_identifier,
    STATE(19575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769016] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27973), 1,
      anon_sym_in,
    STATE(19576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769030] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27975), 1,
      anon_sym_RPAREN,
    STATE(19577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18665), 1,
      anon_sym_DASH_GT,
    STATE(19578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769058] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27977), 1,
      anon_sym_in,
    STATE(19579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769072] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27979), 1,
      anon_sym_with,
    STATE(19580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769086] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27981), 1,
      anon_sym_with,
    STATE(19581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769100] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27983), 1,
      anon_sym_RPAREN,
    STATE(19582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769114] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27985), 1,
      anon_sym_in,
    STATE(19583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27987), 1,
      anon_sym_in,
    STATE(19584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769142] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27989), 1,
      anon_sym_DOT,
    STATE(19585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27991), 1,
      anon_sym_RPAREN,
    STATE(19586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769170] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27993), 1,
      anon_sym_in,
    STATE(19587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18522), 1,
      anon_sym_COMMA,
    STATE(19588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769198] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27995), 1,
      anon_sym_in,
    STATE(19589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769212] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27997), 1,
      anon_sym_RPAREN,
    STATE(19590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769226] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(27999), 1,
      anon_sym_in,
    STATE(19591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769240] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25017), 1,
      aux_sym_number_token1,
    STATE(19592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28001), 1,
      anon_sym_in,
    STATE(19593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769268] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28003), 1,
      anon_sym_RPAREN,
    STATE(19594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769282] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28005), 1,
      anon_sym_RBRACK,
    STATE(19595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769296] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28007), 1,
      anon_sym_RPAREN,
    STATE(19596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769310] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28009), 1,
      anon_sym_RPAREN,
    STATE(19597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769324] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28009), 1,
      anon_sym_RBRACK,
    STATE(19598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769338] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28009), 1,
      anon_sym_RBRACE,
    STATE(19599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769352] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28011), 1,
      anon_sym_in,
    STATE(19600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769366] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28013), 1,
      anon_sym_RBRACE,
    STATE(19601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769380] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28015), 1,
      anon_sym_RPAREN,
    STATE(19602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769394] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28017), 1,
      anon_sym_RPAREN,
    STATE(19603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769408] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28019), 1,
      anon_sym_in,
    STATE(19604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769422] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28021), 1,
      anon_sym_DOT,
    STATE(19605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769436] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28023), 1,
      anon_sym_RBRACK,
    STATE(19606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769450] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28025), 1,
      anon_sym_DASH_GT,
    STATE(19607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769464] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28027), 1,
      anon_sym_DOT,
    STATE(19608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769478] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28029), 1,
      anon_sym_with,
    STATE(19609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769492] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28031), 1,
      anon_sym_with,
    STATE(19610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769506] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28033), 1,
      anon_sym_DOT,
    STATE(19611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769520] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11828), 1,
      anon_sym_GT,
    STATE(19612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769534] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28035), 1,
      anon_sym_RPAREN,
    STATE(19613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769548] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28037), 1,
      anon_sym_RBRACE,
    STATE(19614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769562] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28039), 1,
      anon_sym_RBRACE,
    STATE(19615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769576] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28041), 1,
      anon_sym_RPAREN,
    STATE(19616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769590] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28043), 1,
      anon_sym_RPAREN,
    STATE(19617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769604] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28045), 1,
      anon_sym_with,
    STATE(19618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769618] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28047), 1,
      anon_sym_with,
    STATE(19619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769632] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12279), 1,
      anon_sym_DASH_GT,
    STATE(19620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25043), 1,
      anon_sym_RBRACK,
    STATE(19621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769660] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28049), 1,
      anon_sym_DASH_GT,
    STATE(19622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769674] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28051), 1,
      anon_sym_DOT,
    STATE(19623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28053), 1,
      anon_sym_RPAREN,
    STATE(19624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769702] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15539), 1,
      anon_sym_COMMA,
    STATE(19625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769716] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28055), 1,
      anon_sym_with,
    STATE(19626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769730] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28057), 1,
      anon_sym_RPAREN,
    STATE(19627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769744] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28059), 1,
      anon_sym_RPAREN,
    STATE(19628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769758] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28061), 1,
      anon_sym_LT_DASH,
    STATE(19629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769772] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28063), 1,
      anon_sym_with,
    STATE(19630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769786] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28065), 1,
      anon_sym_RBRACE,
    STATE(19631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769800] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28067), 1,
      anon_sym_GT,
    STATE(19632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769814] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28069), 1,
      anon_sym_DASH_GT,
    STATE(19633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769828] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28071), 1,
      anon_sym_RPAREN,
    STATE(19634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769842] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28073), 1,
      anon_sym_RPAREN,
    STATE(19635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769856] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28073), 1,
      anon_sym_RBRACK,
    STATE(19636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769870] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28073), 1,
      anon_sym_RBRACE,
    STATE(19637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769884] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28075), 1,
      anon_sym_RBRACK,
    STATE(19638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769898] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28077), 1,
      anon_sym_RBRACE,
    STATE(19639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769912] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    STATE(19640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28079), 1,
      anon_sym_RPAREN,
    STATE(19641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769940] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22190), 1,
      anon_sym_GT_RBRACE,
    STATE(19642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769954] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28081), 1,
      anon_sym_DOT,
    STATE(19643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769968] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    STATE(19644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769982] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28083), 1,
      anon_sym_RPAREN,
    STATE(19645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [769996] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18857), 1,
      anon_sym_DASH_GT,
    STATE(19646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770010] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28085), 1,
      anon_sym_with,
    STATE(19647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770024] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28087), 1,
      anon_sym_with,
    STATE(19648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28089), 1,
      anon_sym_DOT,
    STATE(19649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770052] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20847), 1,
      anon_sym_end,
    STATE(19650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770066] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28091), 1,
      anon_sym_DOT,
    STATE(19651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770080] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28093), 1,
      anon_sym_SQUOTE2,
    STATE(19652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770094] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28095), 1,
      anon_sym_RPAREN,
    STATE(19653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770108] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28097), 1,
      anon_sym_DQUOTE,
    STATE(19654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770122] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28099), 1,
      anon_sym_RBRACE,
    STATE(19655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770136] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28101), 1,
      anon_sym_with,
    STATE(19656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770150] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28103), 1,
      anon_sym_with,
    STATE(19657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770164] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22194), 1,
      anon_sym_GT_RBRACE,
    STATE(19658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770178] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28105), 1,
      anon_sym_in,
    STATE(19659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770192] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20843), 1,
      anon_sym_end,
    STATE(19660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770206] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28107), 1,
      anon_sym_DOT,
    STATE(19661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770220] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28109), 1,
      anon_sym_DASH_GT,
    STATE(19662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28111), 1,
      anon_sym_STAR,
    STATE(19663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770248] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28113), 1,
      anon_sym_in,
    STATE(19664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770262] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28115), 1,
      anon_sym_SQUOTE2,
    STATE(19665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770276] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28117), 1,
      anon_sym_RPAREN,
    STATE(19666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28119), 1,
      anon_sym_in,
    STATE(19667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770304] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28121), 1,
      anon_sym_RPAREN,
    STATE(19668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28123), 1,
      anon_sym_DQUOTE,
    STATE(19669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28125), 1,
      anon_sym_in,
    STATE(19670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28127), 1,
      sym__lowercase_identifier,
    STATE(19671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770360] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28129), 1,
      anon_sym_RPAREN,
    STATE(19672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770374] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28131), 1,
      anon_sym_RPAREN,
    STATE(19673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770388] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28131), 1,
      anon_sym_RBRACK,
    STATE(19674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770402] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28131), 1,
      anon_sym_RBRACE,
    STATE(19675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770416] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28133), 1,
      sym__lowercase_identifier,
    STATE(19676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770430] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28135), 1,
      anon_sym_in,
    STATE(19677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770444] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28137), 1,
      anon_sym_RPAREN,
    STATE(19678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770458] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28139), 1,
      anon_sym_RBRACE,
    STATE(19679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28141), 1,
      anon_sym_RBRACK,
    STATE(19680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770486] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28143), 1,
      anon_sym_DOT,
    STATE(19681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770500] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20129), 1,
      anon_sym_end,
    STATE(19682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28145), 1,
      anon_sym_RBRACE,
    STATE(19683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770528] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28147), 1,
      anon_sym_in,
    STATE(19684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770542] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28149), 1,
      anon_sym_with,
    STATE(19685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770556] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28151), 1,
      anon_sym_with,
    STATE(19686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770570] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28153), 1,
      anon_sym_DOT,
    STATE(19687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770584] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28155), 1,
      anon_sym_RPAREN,
    STATE(19688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770598] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18321), 1,
      anon_sym_GT,
    STATE(19689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770612] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28157), 1,
      anon_sym_RBRACE,
    STATE(19690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28159), 1,
      anon_sym_in,
    STATE(19691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770640] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28161), 1,
      anon_sym_DASH_GT,
    STATE(19692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770654] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28163), 1,
      anon_sym_in,
    STATE(19693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770668] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28165), 1,
      anon_sym_with,
    STATE(19694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770682] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28167), 1,
      anon_sym_with,
    STATE(19695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770696] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28169), 1,
      anon_sym_DASH_GT,
    STATE(19696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770710] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28171), 1,
      anon_sym_RPAREN,
    STATE(19697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770724] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28173), 1,
      anon_sym_DASH_GT,
    STATE(19698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770738] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28175), 1,
      anon_sym_DOT,
    STATE(19699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770752] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28177), 1,
      anon_sym_RPAREN,
    STATE(19700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770766] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28179), 1,
      anon_sym_RPAREN,
    STATE(19701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770780] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28181), 1,
      anon_sym_in,
    STATE(19702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28183), 1,
      anon_sym_with,
    STATE(19703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770808] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28185), 1,
      anon_sym_RPAREN,
    STATE(19704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28187), 1,
      anon_sym_end,
    STATE(19705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770836] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28189), 1,
      anon_sym_RBRACK,
    STATE(19706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770850] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28191), 1,
      anon_sym_RBRACE,
    STATE(19707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770864] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28193), 1,
      anon_sym_RPAREN,
    STATE(19708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770878] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28195), 1,
      anon_sym_RPAREN,
    STATE(19709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770892] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28197), 1,
      anon_sym_RPAREN,
    STATE(19710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770906] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28197), 1,
      anon_sym_RBRACK,
    STATE(19711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770920] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28197), 1,
      anon_sym_RBRACE,
    STATE(19712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28199), 1,
      anon_sym_SQUOTE2,
    STATE(19713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770948] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28201), 1,
      anon_sym_DQUOTE,
    STATE(19714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770962] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28203), 1,
      anon_sym_RPAREN,
    STATE(19715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770976] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28205), 1,
      anon_sym_RBRACK,
    STATE(19716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [770990] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28207), 1,
      anon_sym_RBRACE,
    STATE(19717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771004] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28209), 1,
      anon_sym_DOT,
    STATE(19718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28211), 1,
      anon_sym_RBRACK,
    STATE(19719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771032] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28213), 1,
      anon_sym_DASH_GT,
    STATE(19720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771046] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28215), 1,
      anon_sym_RPAREN,
    STATE(19721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771060] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28217), 1,
      anon_sym_with,
    STATE(19722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771074] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28219), 1,
      anon_sym_with,
    STATE(19723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771088] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28221), 1,
      anon_sym_DOT,
    STATE(19724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771102] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28223), 1,
      anon_sym_DASH_GT,
    STATE(19725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771116] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28225), 1,
      anon_sym_DASH_GT,
    STATE(19726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771130] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28227), 1,
      anon_sym_DASH_GT,
    STATE(19727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771144] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25159), 1,
      anon_sym_RBRACE,
    STATE(19728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771158] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28229), 1,
      anon_sym_DASH_GT,
    STATE(19729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771172] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28231), 1,
      anon_sym_with,
    STATE(19730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771186] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28233), 1,
      anon_sym_with,
    STATE(19731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771200] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28235), 1,
      anon_sym_with,
    STATE(19732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771214] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28237), 1,
      anon_sym_DASH_GT,
    STATE(19733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771228] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28239), 1,
      anon_sym_with,
    STATE(19734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771242] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28241), 1,
      anon_sym_DASH_GT,
    STATE(19735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771256] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28243), 1,
      anon_sym_DOT,
    STATE(19736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771270] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28245), 1,
      anon_sym_in,
    STATE(19737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771284] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28247), 1,
      anon_sym_RBRACE,
    STATE(19738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28249), 1,
      anon_sym_RPAREN,
    STATE(19739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771312] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28251), 1,
      anon_sym_RPAREN,
    STATE(19740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771326] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28253), 1,
      anon_sym_RPAREN,
    STATE(19741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28251), 1,
      anon_sym_RBRACK,
    STATE(19742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771354] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28255), 1,
      anon_sym_end,
    STATE(19743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771368] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28251), 1,
      anon_sym_RBRACE,
    STATE(19744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771382] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28257), 1,
      anon_sym_RBRACE,
    STATE(19745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771396] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28259), 1,
      anon_sym_RPAREN,
    STATE(19746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771410] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28261), 1,
      anon_sym_RPAREN,
    STATE(19747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771424] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28261), 1,
      anon_sym_RBRACK,
    STATE(19748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771438] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28261), 1,
      anon_sym_RBRACE,
    STATE(19749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771452] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28263), 1,
      anon_sym_DOT,
    STATE(19750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771466] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28265), 1,
      anon_sym_RBRACE,
    STATE(19751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771480] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28267), 1,
      anon_sym_DASH_GT,
    STATE(19752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771494] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28269), 1,
      anon_sym_RBRACE,
    STATE(19753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771508] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28271), 1,
      anon_sym_RPAREN,
    STATE(19754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771522] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28273), 1,
      anon_sym_DOT,
    STATE(19755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771536] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28275), 1,
      anon_sym_RBRACE,
    STATE(19756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771550] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28277), 1,
      anon_sym_RPAREN,
    STATE(19757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771564] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28279), 1,
      anon_sym_RPAREN,
    STATE(19758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771578] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28281), 1,
      anon_sym_with,
    STATE(19759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771592] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28283), 1,
      anon_sym_with,
    STATE(19760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771606] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28285), 1,
      anon_sym_DOT,
    STATE(19761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771620] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28287), 1,
      anon_sym_DOT,
    STATE(19762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771634] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10313), 1,
      anon_sym_COLON_COLON,
    STATE(19763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771648] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28289), 1,
      anon_sym_RBRACE,
    STATE(19764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771662] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28291), 1,
      anon_sym_RBRACK,
    STATE(19765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771676] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28293), 1,
      anon_sym_DASH_GT,
    STATE(19766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771690] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28295), 1,
      anon_sym_RBRACE,
    STATE(19767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771704] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28297), 1,
      anon_sym_with,
    STATE(19768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771718] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28299), 1,
      anon_sym_with,
    STATE(19769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771732] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4863), 1,
      anon_sym_RPAREN,
    STATE(19770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771746] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28301), 1,
      anon_sym_RPAREN,
    STATE(19771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771760] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28303), 1,
      anon_sym_RPAREN,
    STATE(19772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28305), 1,
      anon_sym_DOT,
    STATE(19773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771788] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28307), 1,
      anon_sym_RPAREN,
    STATE(19774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771802] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28309), 1,
      anon_sym_RPAREN,
    STATE(19775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771816] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28311), 1,
      anon_sym_LT_DASH,
    STATE(19776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771830] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28313), 1,
      anon_sym_RPAREN,
    STATE(19777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771844] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28315), 1,
      anon_sym_RPAREN,
    STATE(19778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28317), 1,
      anon_sym_DASH_GT,
    STATE(19779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771872] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28319), 1,
      anon_sym_RBRACE,
    STATE(19780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771886] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28321), 1,
      anon_sym_in,
    STATE(19781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771900] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28323), 1,
      anon_sym_RPAREN,
    STATE(19782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771914] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28325), 1,
      anon_sym_RPAREN,
    STATE(19783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771928] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28327), 1,
      anon_sym_RPAREN,
    STATE(19784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28327), 1,
      anon_sym_RBRACK,
    STATE(19785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28327), 1,
      anon_sym_RBRACE,
    STATE(19786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771970] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28329), 1,
      anon_sym_RPAREN,
    STATE(19787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771984] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28331), 1,
      anon_sym_GT,
    STATE(19788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [771998] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18377), 1,
      anon_sym_GT,
    STATE(19789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772012] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28333), 1,
      anon_sym_RPAREN,
    STATE(19790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772026] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22415), 1,
      anon_sym_GT_RBRACE,
    STATE(19791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28335), 1,
      anon_sym_RPAREN,
    STATE(19792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772054] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28337), 1,
      anon_sym_DASH_GT,
    STATE(19793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772068] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28339), 1,
      sym__lowercase_identifier,
    STATE(19794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772082] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28341), 1,
      anon_sym_with,
    STATE(19795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28343), 1,
      anon_sym_with,
    STATE(19796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772110] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28345), 1,
      anon_sym_DOT,
    STATE(19797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772124] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28347), 1,
      anon_sym_RPAREN,
    STATE(19798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772138] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22156), 1,
      anon_sym_GT_RBRACE,
    STATE(19799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772152] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28349), 1,
      anon_sym_RPAREN,
    STATE(19800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772166] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28351), 1,
      anon_sym_RBRACK,
    STATE(19801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28353), 1,
      anon_sym_RBRACE,
    STATE(19802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772194] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28355), 1,
      anon_sym_in,
    STATE(19803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772208] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28357), 1,
      anon_sym_with,
    STATE(19804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772222] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28359), 1,
      anon_sym_with,
    STATE(19805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28361), 1,
      anon_sym_RPAREN,
    STATE(19806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772250] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28363), 1,
      anon_sym_RPAREN,
    STATE(19807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772264] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23523), 1,
      anon_sym_GT_RBRACE,
    STATE(19808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772278] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28365), 1,
      anon_sym_DOT,
    STATE(19809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772292] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28367), 1,
      anon_sym_RPAREN,
    STATE(19810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20191), 1,
      anon_sym_end,
    STATE(19811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772320] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28369), 1,
      anon_sym_SQUOTE2,
    STATE(19812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772334] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28371), 1,
      anon_sym_RPAREN,
    STATE(19813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772348] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28373), 1,
      anon_sym_RPAREN,
    STATE(19814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772362] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28375), 1,
      anon_sym_DQUOTE,
    STATE(19815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28377), 1,
      anon_sym_DASH_GT,
    STATE(19816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772390] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28379), 1,
      anon_sym_DASH_GT,
    STATE(19817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772404] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28381), 1,
      anon_sym_RPAREN,
    STATE(19818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772418] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28383), 1,
      anon_sym_RPAREN,
    STATE(19819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772432] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28385), 1,
      anon_sym_RPAREN,
    STATE(19820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772446] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28385), 1,
      anon_sym_RBRACK,
    STATE(19821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28385), 1,
      anon_sym_RBRACE,
    STATE(19822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772474] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28387), 1,
      anon_sym_in,
    STATE(19823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772488] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28389), 1,
      anon_sym_RPAREN,
    STATE(19824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772502] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28391), 1,
      anon_sym_EQ,
    STATE(19825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772516] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28393), 1,
      anon_sym_RPAREN,
    STATE(19826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772530] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28395), 1,
      anon_sym_RPAREN,
    STATE(19827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772544] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3129), 1,
      anon_sym_RPAREN,
    STATE(19828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772558] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28397), 1,
      anon_sym_RPAREN,
    STATE(19829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772572] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28399), 1,
      anon_sym_with,
    STATE(19830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772586] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28401), 1,
      anon_sym_with,
    STATE(19831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772600] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28403), 1,
      anon_sym_DOT,
    STATE(19832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772614] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28405), 1,
      anon_sym_RPAREN,
    STATE(19833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772628] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28407), 1,
      anon_sym_RPAREN,
    STATE(19834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772642] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28409), 1,
      anon_sym_with,
    STATE(19835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772656] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28411), 1,
      anon_sym_with,
    STATE(19836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772670] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28413), 1,
      anon_sym_DOT,
    STATE(19837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772684] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28415), 1,
      anon_sym_DOT,
    STATE(19838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772698] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20045), 1,
      anon_sym_end,
    STATE(19839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772712] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28417), 1,
      anon_sym_RBRACE,
    STATE(19840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772726] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28419), 1,
      anon_sym_RPAREN,
    STATE(19841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772740] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28421), 1,
      anon_sym_RPAREN,
    STATE(19842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772754] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28423), 1,
      anon_sym_RPAREN,
    STATE(19843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772768] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28425), 1,
      anon_sym_RPAREN,
    STATE(19844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772782] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28425), 1,
      anon_sym_RBRACK,
    STATE(19845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772796] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28425), 1,
      anon_sym_RBRACE,
    STATE(19846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772810] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28427), 1,
      anon_sym_RPAREN,
    STATE(19847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28429), 1,
      anon_sym_end,
    STATE(19848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772838] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28431), 1,
      anon_sym_DASH_GT,
    STATE(19849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772852] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28433), 1,
      anon_sym_RBRACK,
    STATE(19850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772866] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28435), 1,
      anon_sym_in,
    STATE(19851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772880] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28437), 1,
      anon_sym_RBRACE,
    STATE(19852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28439), 1,
      anon_sym_with,
    STATE(19853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772908] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28441), 1,
      anon_sym_with,
    STATE(19854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28443), 1,
      anon_sym_DOT,
    STATE(19855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772936] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28445), 1,
      anon_sym_RPAREN,
    STATE(19856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772950] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28447), 1,
      anon_sym_RPAREN,
    STATE(19857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772964] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28449), 1,
      anon_sym_with,
    STATE(19858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772978] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28451), 1,
      anon_sym_with,
    STATE(19859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [772992] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28453), 1,
      anon_sym_RPAREN,
    STATE(19860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773006] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28455), 1,
      anon_sym_RPAREN,
    STATE(19861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773020] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28457), 1,
      sym__lowercase_identifier,
    STATE(19862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28459), 1,
      anon_sym_RPAREN,
    STATE(19863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773048] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28461), 1,
      anon_sym_SQUOTE2,
    STATE(19864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773062] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28463), 1,
      anon_sym_RPAREN,
    STATE(19865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773076] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28465), 1,
      anon_sym_RPAREN,
    STATE(19866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773090] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28465), 1,
      anon_sym_RBRACK,
    STATE(19867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773104] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28465), 1,
      anon_sym_RBRACE,
    STATE(19868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773118] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28467), 1,
      anon_sym_in,
    STATE(19869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773132] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24137), 1,
      anon_sym_RBRACE,
    STATE(19870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773146] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28469), 1,
      anon_sym_in,
    STATE(19871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28471), 1,
      anon_sym_in,
    STATE(19872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773174] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28473), 1,
      anon_sym_RBRACE,
    STATE(19873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28475), 1,
      anon_sym_DASH_GT,
    STATE(19874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773202] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28477), 1,
      anon_sym_RBRACE,
    STATE(19875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773216] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28479), 1,
      anon_sym_done,
    STATE(19876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773230] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28481), 1,
      anon_sym_RBRACK,
    STATE(19877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773244] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28483), 1,
      anon_sym_RPAREN,
    STATE(19878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28483), 1,
      anon_sym_RBRACK,
    STATE(19879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773272] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28483), 1,
      anon_sym_RBRACE,
    STATE(19880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773286] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28485), 1,
      anon_sym_RBRACK,
    STATE(19881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773300] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28487), 1,
      anon_sym_DOT,
    STATE(19882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773314] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28489), 1,
      anon_sym_in,
    STATE(19883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773328] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28491), 1,
      anon_sym_RBRACE,
    STATE(19884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28493), 1,
      anon_sym_end,
    STATE(19885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773356] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28495), 1,
      anon_sym_RBRACE,
    STATE(19886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773370] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11808), 1,
      anon_sym_GT,
    STATE(19887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773384] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28497), 1,
      anon_sym_SQUOTE2,
    STATE(19888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773398] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28499), 1,
      anon_sym_DOT,
    STATE(19889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28501), 1,
      anon_sym_RPAREN,
    STATE(19890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28501), 1,
      anon_sym_RBRACK,
    STATE(19891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773440] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28501), 1,
      anon_sym_RBRACE,
    STATE(19892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773454] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28503), 1,
      anon_sym_SQUOTE2,
    STATE(19893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773468] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28505), 1,
      anon_sym_DQUOTE,
    STATE(19894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773482] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28507), 1,
      anon_sym_RBRACK,
    STATE(19895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28509), 1,
      anon_sym_DASH_GT,
    STATE(19896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773510] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    STATE(19897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773524] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28511), 1,
      anon_sym_DOT,
    STATE(19898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773538] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28513), 1,
      anon_sym_in,
    STATE(19899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773552] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28515), 1,
      anon_sym_RPAREN,
    STATE(19900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773566] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28515), 1,
      anon_sym_RBRACK,
    STATE(19901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773580] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28515), 1,
      anon_sym_RBRACE,
    STATE(19902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28517), 1,
      anon_sym_RBRACE,
    STATE(19903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773608] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16193), 1,
      anon_sym_COMMA,
    STATE(19904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773622] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28519), 1,
      anon_sym_LT_DASH,
    STATE(19905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773636] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28521), 1,
      anon_sym_in,
    STATE(19906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773650] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28523), 1,
      anon_sym_STAR,
    STATE(19907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773664] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28525), 1,
      anon_sym_RPAREN,
    STATE(19908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773678] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28527), 1,
      sym__lowercase_identifier,
    STATE(19909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773692] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28529), 1,
      anon_sym_RPAREN,
    STATE(19910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773706] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28529), 1,
      anon_sym_RBRACK,
    STATE(19911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773720] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28529), 1,
      anon_sym_RBRACE,
    STATE(19912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773734] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28531), 1,
      anon_sym_RBRACK,
    STATE(19913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773748] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28533), 1,
      anon_sym_DASH_GT,
    STATE(19914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773762] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28535), 1,
      anon_sym_RPAREN,
    STATE(19915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28537), 1,
      anon_sym_RBRACK,
    STATE(19916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28539), 1,
      anon_sym_with,
    STATE(19917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773804] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28541), 1,
      anon_sym_RBRACE,
    STATE(19918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773818] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28543), 1,
      anon_sym_DQUOTE,
    STATE(19919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773832] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28545), 1,
      anon_sym_RPAREN,
    STATE(19920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773846] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28545), 1,
      anon_sym_RBRACK,
    STATE(19921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773860] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28545), 1,
      anon_sym_RBRACE,
    STATE(19922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773874] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28547), 1,
      anon_sym_DASH_GT,
    STATE(19923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773888] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28549), 1,
      anon_sym_RPAREN,
    STATE(19924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773902] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28551), 1,
      anon_sym_with,
    STATE(19925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28553), 1,
      anon_sym_DOT,
    STATE(19926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773930] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28555), 1,
      anon_sym_RPAREN,
    STATE(19927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773944] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28557), 1,
      anon_sym_DOT,
    STATE(19928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773958] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28559), 1,
      anon_sym_RPAREN,
    STATE(19929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773972] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28561), 1,
      anon_sym_RPAREN,
    STATE(19930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [773986] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28561), 1,
      anon_sym_RBRACK,
    STATE(19931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774000] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28561), 1,
      anon_sym_RBRACE,
    STATE(19932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774014] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28563), 1,
      anon_sym_RBRACE,
    STATE(19933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774028] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28565), 1,
      anon_sym_PLUS_EQ,
    STATE(19934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774042] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20137), 1,
      anon_sym_end,
    STATE(19935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774056] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28567), 1,
      anon_sym_RPAREN,
    STATE(19936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774070] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28569), 1,
      anon_sym_DASH_GT,
    STATE(19937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774084] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28571), 1,
      anon_sym_DASH_GT,
    STATE(19938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774098] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28573), 1,
      anon_sym_DASH_GT,
    STATE(19939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774112] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28575), 1,
      anon_sym_RPAREN,
    STATE(19940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28575), 1,
      anon_sym_RBRACK,
    STATE(19941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774140] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28575), 1,
      anon_sym_RBRACE,
    STATE(19942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774154] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28577), 1,
      anon_sym_DASH_GT,
    STATE(19943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774168] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28579), 1,
      anon_sym_RPAREN,
    STATE(19944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774182] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28581), 1,
      anon_sym_DASH_GT,
    STATE(19945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774196] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23489), 1,
      anon_sym_GT_RBRACE,
    STATE(19946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774210] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28367), 1,
      anon_sym_RBRACE,
    STATE(19947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774224] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28583), 1,
      anon_sym_RPAREN,
    STATE(19948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28585), 1,
      anon_sym_DASH_GT,
    STATE(19949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774252] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28587), 1,
      anon_sym_RPAREN,
    STATE(19950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774266] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28587), 1,
      anon_sym_RBRACK,
    STATE(19951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774280] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28587), 1,
      anon_sym_RBRACE,
    STATE(19952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774294] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28589), 1,
      anon_sym_with,
    STATE(19953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774308] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28591), 1,
      sym__lowercase_identifier,
    STATE(19954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774322] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28593), 1,
      anon_sym_with,
    STATE(19955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28595), 1,
      anon_sym_in,
    STATE(19956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774350] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28597), 1,
      anon_sym_in,
    STATE(19957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28599), 1,
      anon_sym_RPAREN,
    STATE(19958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774378] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28601), 1,
      anon_sym_DOT,
    STATE(19959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28603), 1,
      anon_sym_RPAREN,
    STATE(19960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774406] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28603), 1,
      anon_sym_RBRACK,
    STATE(19961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774420] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28603), 1,
      anon_sym_RBRACE,
    STATE(19962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774434] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28605), 1,
      anon_sym_DASH_GT,
    STATE(19963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774448] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28607), 1,
      anon_sym_RPAREN,
    STATE(19964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774462] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28609), 1,
      anon_sym_SQUOTE2,
    STATE(19965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774476] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28611), 1,
      anon_sym_COMMA,
    STATE(19966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774490] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20468), 1,
      anon_sym_end,
    STATE(19967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774504] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28613), 1,
      anon_sym_DASH_GT,
    STATE(19968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774518] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28615), 1,
      anon_sym_SQUOTE2,
    STATE(19969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774532] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28617), 1,
      anon_sym_RPAREN,
    STATE(19970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774546] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28617), 1,
      anon_sym_RBRACK,
    STATE(19971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28617), 1,
      anon_sym_RBRACE,
    STATE(19972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5603), 1,
      anon_sym_RPAREN,
    STATE(19973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774588] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11752), 1,
      anon_sym_GT,
    STATE(19974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774602] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28619), 1,
      sym__lowercase_identifier,
    STATE(19975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774616] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28621), 1,
      anon_sym_in,
    STATE(19976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774630] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28623), 1,
      anon_sym_in,
    STATE(19977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774644] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28625), 1,
      anon_sym_DQUOTE,
    STATE(19978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774658] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28627), 1,
      anon_sym_DASH_GT,
    STATE(19979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774672] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28629), 1,
      anon_sym_RPAREN,
    STATE(19980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774686] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28629), 1,
      anon_sym_RBRACK,
    STATE(19981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774700] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28629), 1,
      anon_sym_RBRACE,
    STATE(19982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774714] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24175), 1,
      anon_sym_RBRACE,
    STATE(19983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28631), 1,
      anon_sym_RPAREN,
    STATE(19984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28633), 1,
      anon_sym_RPAREN,
    STATE(19985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774756] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28635), 1,
      anon_sym_end,
    STATE(19986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28637), 1,
      anon_sym_DQUOTE,
    STATE(19987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774784] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28639), 1,
      anon_sym_RPAREN,
    STATE(19988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774798] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28641), 1,
      sym__lowercase_identifier,
    STATE(19989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774812] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28643), 1,
      anon_sym_RPAREN,
    STATE(19990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28643), 1,
      anon_sym_RBRACK,
    STATE(19991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28643), 1,
      anon_sym_RBRACE,
    STATE(19992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774854] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28645), 1,
      anon_sym_DOT,
    STATE(19993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774868] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28647), 1,
      anon_sym_RBRACK,
    STATE(19994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774882] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28649), 1,
      anon_sym_RPAREN,
    STATE(19995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774896] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3103), 1,
      anon_sym_RPAREN,
    STATE(19996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28651), 1,
      anon_sym_RPAREN,
    STATE(19997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774924] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28653), 1,
      anon_sym_RPAREN,
    STATE(19998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774938] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28655), 1,
      anon_sym_RBRACE,
    STATE(19999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774952] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28657), 1,
      anon_sym_RBRACE,
    STATE(20000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774966] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28653), 1,
      anon_sym_RBRACK,
    STATE(20001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774980] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28659), 1,
      anon_sym_SQUOTE2,
    STATE(20002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [774994] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28661), 1,
      anon_sym_DQUOTE,
    STATE(20003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775008] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28653), 1,
      anon_sym_RBRACE,
    STATE(20004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775022] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28663), 1,
      anon_sym_RBRACK,
    STATE(20005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775036] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28665), 1,
      anon_sym_RBRACE,
    STATE(20006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775050] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19740), 1,
      sym__uppercase_identifier,
    STATE(20007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775064] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28667), 1,
      anon_sym_RBRACE,
    STATE(20008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775078] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28669), 1,
      anon_sym_with,
    STATE(20009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775092] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28671), 1,
      anon_sym_in,
    STATE(20010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775106] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28673), 1,
      anon_sym_RPAREN,
    STATE(20011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775120] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22425), 1,
      anon_sym_GT_RBRACE,
    STATE(20012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775134] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28675), 1,
      anon_sym_RBRACE,
    STATE(20013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28677), 1,
      anon_sym_RPAREN,
    STATE(20014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775162] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12021), 1,
      anon_sym_DASH_GT,
    STATE(20015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28679), 1,
      anon_sym_RPAREN,
    STATE(20016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775190] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11740), 1,
      anon_sym_GT,
    STATE(20017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775204] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3123), 1,
      anon_sym_RPAREN,
    STATE(20018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775218] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28681), 1,
      anon_sym_with,
    STATE(20019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775232] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28683), 1,
      anon_sym_RPAREN,
    STATE(20020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775246] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28685), 1,
      sym__lowercase_identifier,
    STATE(20021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775260] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28687), 1,
      anon_sym_in,
    STATE(20022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775274] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28689), 1,
      anon_sym_RBRACE,
    STATE(20023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775288] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28691), 1,
      anon_sym_SQUOTE2,
    STATE(20024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775302] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28693), 1,
      anon_sym_DASH_GT,
    STATE(20025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28695), 1,
      anon_sym_DQUOTE,
    STATE(20026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775330] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28697), 1,
      anon_sym_RBRACK,
    STATE(20027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775344] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28699), 1,
      sym__lowercase_identifier,
    STATE(20028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775358] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28701), 1,
      anon_sym_RBRACE,
    STATE(20029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775372] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28703), 1,
      anon_sym_RBRACE,
    STATE(20030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28705), 1,
      anon_sym_end,
    STATE(20031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775400] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28707), 1,
      anon_sym_RBRACE,
    STATE(20032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775414] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28709), 1,
      anon_sym_RPAREN,
    STATE(20033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775428] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28711), 1,
      anon_sym_DOT,
    STATE(20034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775442] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28713), 1,
      anon_sym_end,
    STATE(20035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28715), 1,
      anon_sym_RPAREN,
    STATE(20036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775470] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28717), 1,
      anon_sym_RPAREN,
    STATE(20037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775484] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17174), 1,
      anon_sym_SQUOTE2,
    STATE(20038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775498] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28719), 1,
      anon_sym_done,
    STATE(20039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775512] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28721), 1,
      anon_sym_RPAREN,
    STATE(20040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775526] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3161), 1,
      anon_sym_RPAREN,
    STATE(20041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775540] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28723), 1,
      anon_sym_RPAREN,
    STATE(20042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775554] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28725), 1,
      anon_sym_RBRACE,
    STATE(20043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775568] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28727), 1,
      anon_sym_RPAREN,
    STATE(20044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775582] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28729), 1,
      anon_sym_RBRACE,
    STATE(20045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775596] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28731), 1,
      anon_sym_RPAREN,
    STATE(20046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28733), 1,
      anon_sym_SQUOTE2,
    STATE(20047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775624] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28735), 1,
      anon_sym_DQUOTE,
    STATE(20048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775638] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28737), 1,
      anon_sym_RPAREN,
    STATE(20049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775652] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28739), 1,
      anon_sym_RBRACK,
    STATE(20050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775666] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28741), 1,
      anon_sym_RBRACE,
    STATE(20051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775680] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28743), 1,
      anon_sym_RBRACE,
    STATE(20052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28745), 1,
      anon_sym_DOT,
    STATE(20053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775708] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28747), 1,
      anon_sym_RPAREN,
    STATE(20054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775722] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28749), 1,
      anon_sym_RPAREN,
    STATE(20055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775736] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28751), 1,
      anon_sym_RPAREN,
    STATE(20056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775750] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28753), 1,
      anon_sym_RPAREN,
    STATE(20057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775764] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28755), 1,
      anon_sym_RPAREN,
    STATE(20058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775778] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28757), 1,
      anon_sym_DOT,
    STATE(20059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775792] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5859), 1,
      anon_sym_COMMA,
    STATE(20060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775806] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28759), 1,
      anon_sym_DOT,
    STATE(20061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775820] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3099), 1,
      anon_sym_RPAREN,
    STATE(20062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775834] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20149), 1,
      anon_sym_end,
    STATE(20063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775848] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28761), 1,
      anon_sym_RPAREN,
    STATE(20064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775862] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28763), 1,
      anon_sym_RPAREN,
    STATE(20065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28765), 1,
      anon_sym_SQUOTE2,
    STATE(20066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775890] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28767), 1,
      anon_sym_RBRACE,
    STATE(20067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775904] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28769), 1,
      anon_sym_DASH_GT,
    STATE(20068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775918] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28771), 1,
      anon_sym_SQUOTE2,
    STATE(20069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775932] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28773), 1,
      anon_sym_DASH_GT,
    STATE(20070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28775), 1,
      anon_sym_RPAREN,
    STATE(20071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775960] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28777), 1,
      anon_sym_PLUS_EQ,
    STATE(20072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775974] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11585), 1,
      anon_sym_GT,
    STATE(20073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [775988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25717), 1,
      anon_sym_RBRACK,
    STATE(20074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776002] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28779), 1,
      anon_sym_DASH_GT,
    STATE(20075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776016] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28781), 1,
      anon_sym_DQUOTE,
    STATE(20076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776030] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28783), 1,
      anon_sym_STAR,
    STATE(20077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28785), 1,
      anon_sym_RBRACK,
    STATE(20078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776058] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28787), 1,
      anon_sym_RBRACE,
    STATE(20079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776072] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28789), 1,
      anon_sym_RBRACE,
    STATE(20080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776086] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10535), 1,
      anon_sym_COMMA,
    STATE(20081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776100] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28791), 1,
      anon_sym_GT,
    STATE(20082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776114] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28793), 1,
      anon_sym_RPAREN,
    STATE(20083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28795), 1,
      anon_sym_RBRACE,
    STATE(20084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776142] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28797), 1,
      anon_sym_SQUOTE2,
    STATE(20085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28799), 1,
      anon_sym_RBRACE,
    STATE(20086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776170] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28801), 1,
      anon_sym_LT_DASH,
    STATE(20087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28803), 1,
      anon_sym_RPAREN,
    STATE(20088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776198] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22781), 1,
      anon_sym_GT_RBRACE,
    STATE(20089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776212] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3183), 1,
      anon_sym_RPAREN,
    STATE(20090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776226] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23615), 1,
      anon_sym_RPAREN,
    STATE(20091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776240] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28805), 1,
      anon_sym_with,
    STATE(20092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28807), 1,
      anon_sym_in,
    STATE(20093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776268] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28809), 1,
      anon_sym_PLUS_EQ,
    STATE(20094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776282] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28811), 1,
      anon_sym_RPAREN,
    STATE(20095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776296] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28813), 1,
      anon_sym_RPAREN,
    STATE(20096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776310] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3115), 1,
      anon_sym_RPAREN,
    STATE(20097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776324] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28815), 1,
      anon_sym_RPAREN,
    STATE(20098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776338] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28817), 1,
      anon_sym_in,
    STATE(20099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776352] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28819), 1,
      anon_sym_RPAREN,
    STATE(20100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776366] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28821), 1,
      anon_sym_RBRACE,
    STATE(20101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776380] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28823), 1,
      anon_sym_in,
    STATE(20102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776394] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28825), 1,
      anon_sym_of,
    STATE(20103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776408] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28827), 1,
      anon_sym_SQUOTE2,
    STATE(20104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776422] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28829), 1,
      anon_sym_EQ,
    STATE(20105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776436] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28831), 1,
      anon_sym_DQUOTE,
    STATE(20106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776450] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28833), 1,
      anon_sym_in,
    STATE(20107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776464] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28835), 1,
      anon_sym_RBRACK,
    STATE(20108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776478] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28837), 1,
      sym__lowercase_identifier,
    STATE(20109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776492] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28839), 1,
      anon_sym_in,
    STATE(20110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776506] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28841), 1,
      anon_sym_RBRACK,
    STATE(20111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776520] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18607), 1,
      anon_sym_COMMA,
    STATE(20112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776534] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28843), 1,
      anon_sym_in,
    STATE(20113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776548] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28845), 1,
      anon_sym_RBRACE,
    STATE(20114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776562] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28847), 1,
      anon_sym_RBRACE,
    STATE(20115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776576] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28849), 1,
      anon_sym_RPAREN,
    STATE(20116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776590] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28851), 1,
      anon_sym_RPAREN,
    STATE(20117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776604] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28853), 1,
      anon_sym_RBRACE,
    STATE(20118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776618] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28855), 1,
      anon_sym_with,
    STATE(20119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776632] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28857), 1,
      anon_sym_in,
    STATE(20120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28859), 1,
      anon_sym_RPAREN,
    STATE(20121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776660] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28861), 1,
      anon_sym_DOT,
    STATE(20122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776674] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28863), 1,
      anon_sym_RPAREN,
    STATE(20123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28865), 1,
      anon_sym_RPAREN,
    STATE(20124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776702] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5583), 1,
      anon_sym_RPAREN,
    STATE(20125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776716] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10289), 1,
      anon_sym_COMMA,
    STATE(20126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776730] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28867), 1,
      anon_sym_RBRACE,
    STATE(20127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776744] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28869), 1,
      anon_sym_RPAREN,
    STATE(20128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776758] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28871), 1,
      anon_sym_DASH_GT,
    STATE(20129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776772] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3131), 1,
      anon_sym_RPAREN,
    STATE(20130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776786] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28873), 1,
      anon_sym_RPAREN,
    STATE(20131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776800] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28875), 1,
      anon_sym_GT,
    STATE(20132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776814] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28877), 1,
      anon_sym_DQUOTE,
    STATE(20133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776828] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28879), 1,
      anon_sym_RPAREN,
    STATE(20134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776842] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28881), 1,
      sym_indexing_operator,
    STATE(20135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776856] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28883), 1,
      anon_sym_EQ,
    STATE(20136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776870] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28885), 1,
      anon_sym_RPAREN,
    STATE(20137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776884] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28887), 1,
      anon_sym_RBRACK,
    STATE(20138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776898] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22433), 1,
      anon_sym_GT_RBRACE,
    STATE(20139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776912] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28889), 1,
      anon_sym_RPAREN,
    STATE(20140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28891), 1,
      anon_sym_RBRACE,
    STATE(20141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776940] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28893), 1,
      anon_sym_SQUOTE2,
    STATE(20142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776954] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28895), 1,
      sym__lowercase_identifier,
    STATE(20143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776968] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28897), 1,
      anon_sym_DQUOTE,
    STATE(20144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776982] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28899), 1,
      sym__lowercase_identifier,
    STATE(20145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [776996] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20902), 1,
      anon_sym_end,
    STATE(20146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777010] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28901), 1,
      anon_sym_PIPE,
    STATE(20147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777024] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28903), 1,
      anon_sym_RBRACK,
    STATE(20148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28905), 1,
      sym__lowercase_identifier,
    STATE(20149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777052] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28907), 1,
      anon_sym_RBRACE,
    STATE(20150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777066] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28909), 1,
      anon_sym_RBRACE,
    STATE(20151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777080] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28911), 1,
      anon_sym_RPAREN,
    STATE(20152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777094] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28913), 1,
      anon_sym_SQUOTE2,
    STATE(20153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777108] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28915), 1,
      anon_sym_DQUOTE,
    STATE(20154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777122] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21550), 1,
      anon_sym_GT_RBRACE,
    STATE(20155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777136] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28917), 1,
      anon_sym_RPAREN,
    STATE(20156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777150] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28919), 1,
      anon_sym_RBRACK,
    STATE(20157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777164] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20613), 1,
      anon_sym_end,
    STATE(20158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777178] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28921), 1,
      sym__lowercase_identifier,
    STATE(20159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777192] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28923), 1,
      anon_sym_RPAREN,
    STATE(20160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777206] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28925), 1,
      anon_sym_SQUOTE2,
    STATE(20161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777220] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28927), 1,
      anon_sym_RBRACK,
    STATE(20162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28929), 1,
      anon_sym_RBRACE,
    STATE(20163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777248] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28931), 1,
      anon_sym_RBRACK,
    STATE(20164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777262] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28933), 1,
      anon_sym_RPAREN,
    STATE(20165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777276] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28935), 1,
      anon_sym_EQ,
    STATE(20166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3143), 1,
      anon_sym_RPAREN,
    STATE(20167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777304] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28937), 1,
      anon_sym_RPAREN,
    STATE(20168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28939), 1,
      anon_sym_RPAREN,
    STATE(20169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28941), 1,
      anon_sym_in,
    STATE(20170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28943), 1,
      anon_sym_RBRACE,
    STATE(20171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777360] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28945), 1,
      anon_sym_DASH_GT,
    STATE(20172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777374] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28947), 1,
      anon_sym_DQUOTE,
    STATE(20173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777388] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28949), 1,
      anon_sym_RBRACE,
    STATE(20174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777402] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28951), 1,
      anon_sym_RPAREN,
    STATE(20175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777416] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28953), 1,
      anon_sym_DOT_DOT,
    STATE(20176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777430] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28955), 1,
      anon_sym_DOT_DOT,
    STATE(20177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777444] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28957), 1,
      anon_sym_DOT_DOT,
    STATE(20178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777458] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28959), 1,
      anon_sym_end,
    STATE(20179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28961), 1,
      anon_sym_DASH_GT,
    STATE(20180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777486] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28963), 1,
      anon_sym_SQUOTE2,
    STATE(20181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777500] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28965), 1,
      anon_sym_DQUOTE,
    STATE(20182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28967), 1,
      anon_sym_RBRACK,
    STATE(20183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777528] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28969), 1,
      anon_sym_RBRACE,
    STATE(20184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777542] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28971), 1,
      anon_sym_RPAREN,
    STATE(20185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777556] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28973), 1,
      anon_sym_RBRACK,
    STATE(20186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777570] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28975), 1,
      anon_sym_RBRACE,
    STATE(20187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777584] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28977), 1,
      anon_sym_RBRACE,
    STATE(20188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777598] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28979), 1,
      anon_sym_RPAREN,
    STATE(20189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777612] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28981), 1,
      anon_sym_with,
    STATE(20190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28983), 1,
      anon_sym_RPAREN,
    STATE(20191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777640] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28985), 1,
      anon_sym_DASH_GT,
    STATE(20192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777654] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28987), 1,
      anon_sym_DASH_GT,
    STATE(20193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777668] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28989), 1,
      anon_sym_with,
    STATE(20194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777682] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28991), 1,
      anon_sym_DASH_GT,
    STATE(20195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777696] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28993), 1,
      anon_sym_EQ,
    STATE(20196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777710] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28995), 1,
      anon_sym_RBRACK,
    STATE(20197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777724] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28997), 1,
      anon_sym_RBRACE,
    STATE(20198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777738] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28999), 1,
      anon_sym_RPAREN,
    STATE(20199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777752] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29001), 1,
      anon_sym_RPAREN,
    STATE(20200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777766] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29003), 1,
      anon_sym_RPAREN,
    STATE(20201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777780] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29005), 1,
      anon_sym_DOT,
    STATE(20202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29007), 1,
      anon_sym_DASH_GT,
    STATE(20203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777808] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29009), 1,
      anon_sym_RPAREN,
    STATE(20204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29011), 1,
      anon_sym_RPAREN,
    STATE(20205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777836] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29013), 1,
      anon_sym_DASH_GT,
    STATE(20206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777850] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29015), 1,
      anon_sym_in,
    STATE(20207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777864] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29017), 1,
      anon_sym_RBRACE,
    STATE(20208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777878] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29019), 1,
      anon_sym_EQ,
    STATE(20209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777892] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29021), 1,
      anon_sym_in,
    STATE(20210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777906] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29023), 1,
      anon_sym_end,
    STATE(20211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777920] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29025), 1,
      anon_sym_RPAREN,
    STATE(20212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29027), 1,
      anon_sym_EQ,
    STATE(20213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777948] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29029), 1,
      ts_builtin_sym_end,
    STATE(20214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777962] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29031), 1,
      anon_sym_in,
    STATE(20215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777976] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29033), 1,
      anon_sym_DASH_GT,
    STATE(20216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [777990] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3157), 1,
      anon_sym_RPAREN,
    STATE(20217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778004] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29035), 1,
      anon_sym_RPAREN,
    STATE(20218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29037), 1,
      anon_sym_RBRACE,
    STATE(20219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778032] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29039), 1,
      anon_sym_RPAREN,
    STATE(20220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778046] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29041), 1,
      anon_sym_RPAREN,
    STATE(20221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778060] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29043), 1,
      anon_sym_RBRACK,
    STATE(20222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778074] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29045), 1,
      anon_sym_RPAREN,
    STATE(20223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778088] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29047), 1,
      anon_sym_RPAREN,
    STATE(20224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778102] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29049), 1,
      anon_sym_RBRACE,
    STATE(20225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778116] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29051), 1,
      anon_sym_RBRACE,
    STATE(20226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778130] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29053), 1,
      anon_sym_RBRACE,
    STATE(20227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778144] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29055), 1,
      anon_sym_SQUOTE2,
    STATE(20228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778158] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29057), 1,
      anon_sym_DQUOTE,
    STATE(20229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778172] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29059), 1,
      anon_sym_RBRACK,
    STATE(20230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778186] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29061), 1,
      anon_sym_RBRACE,
    STATE(20231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778200] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29063), 1,
      sym__lowercase_identifier,
    STATE(20232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778214] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29065), 1,
      anon_sym_RBRACE,
    STATE(20233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778228] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29067), 1,
      anon_sym_RPAREN,
    STATE(20234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778242] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29069), 1,
      anon_sym_RPAREN,
    STATE(20235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778256] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29071), 1,
      anon_sym_RPAREN,
    STATE(20236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778270] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29073), 1,
      anon_sym_DASH_GT,
    STATE(20237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778284] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29075), 1,
      anon_sym_RPAREN,
    STATE(20238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21365), 1,
      anon_sym_GT_RBRACE,
    STATE(20239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778312] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29077), 1,
      anon_sym_RPAREN,
    STATE(20240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778326] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29079), 1,
      anon_sym_RPAREN,
    STATE(20241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29081), 1,
      anon_sym_RPAREN,
    STATE(20242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778354] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29083), 1,
      anon_sym_RBRACK,
    STATE(20243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778368] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29085), 1,
      anon_sym_RBRACE,
    STATE(20244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778382] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29087), 1,
      anon_sym_RPAREN,
    STATE(20245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778396] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29089), 1,
      anon_sym_RPAREN,
    STATE(20246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778410] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29091), 1,
      anon_sym_RPAREN,
    STATE(20247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778424] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29093), 1,
      anon_sym_RPAREN,
    STATE(20248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778438] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29095), 1,
      anon_sym_DQUOTE,
    STATE(20249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778452] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29097), 1,
      anon_sym_DASH_GT,
    STATE(20250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778466] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3171), 1,
      anon_sym_RPAREN,
    STATE(20251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778480] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29099), 1,
      anon_sym_PLUS_EQ,
    STATE(20252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778494] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29101), 1,
      anon_sym_RPAREN,
    STATE(20253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778508] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25399), 1,
      anon_sym_RBRACK,
    STATE(20254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778522] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29103), 1,
      anon_sym_RPAREN,
    STATE(20255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778536] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25737), 1,
      anon_sym_RPAREN,
    STATE(20256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778550] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11662), 1,
      anon_sym_GT,
    STATE(20257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778564] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29105), 1,
      anon_sym_RPAREN,
    STATE(20258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778578] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29105), 1,
      anon_sym_RBRACK,
    STATE(20259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778592] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29105), 1,
      anon_sym_RBRACE,
    STATE(20260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778606] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29107), 1,
      anon_sym_RBRACE,
    STATE(20261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778620] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29109), 1,
      anon_sym_RPAREN,
    STATE(20262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778634] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29111), 1,
      anon_sym_SQUOTE2,
    STATE(20263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778648] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29113), 1,
      anon_sym_RPAREN,
    STATE(20264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778662] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29115), 1,
      anon_sym_PLUS_EQ,
    STATE(20265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778676] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29117), 1,
      anon_sym_RBRACK,
    STATE(20266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778690] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29119), 1,
      sym__lowercase_identifier,
    STATE(20267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778704] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29121), 1,
      anon_sym_RPAREN,
    STATE(20268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778718] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29123), 1,
      anon_sym_RBRACE,
    STATE(20269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778732] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29125), 1,
      anon_sym_DQUOTE,
    STATE(20270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778746] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29127), 1,
      anon_sym_RPAREN,
    STATE(20271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778760] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29129), 1,
      anon_sym_RPAREN,
    STATE(20272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29131), 1,
      anon_sym_RPAREN,
    STATE(20273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778788] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29133), 1,
      anon_sym_RBRACK,
    STATE(20274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778802] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29135), 1,
      anon_sym_RBRACK,
    STATE(20275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778816] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29137), 1,
      anon_sym_RBRACE,
    STATE(20276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778830] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10205), 1,
      anon_sym_RPAREN,
    STATE(20277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778844] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29139), 1,
      anon_sym_RPAREN,
    STATE(20278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29141), 1,
      anon_sym_DASH_GT,
    STATE(20279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778872] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29143), 1,
      anon_sym_RBRACE,
    STATE(20280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778886] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29145), 1,
      anon_sym_RPAREN,
    STATE(20281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778900] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29147), 1,
      anon_sym_RBRACE,
    STATE(20282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778914] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29149), 1,
      anon_sym_RPAREN,
    STATE(20283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778928] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25535), 1,
      anon_sym_RBRACE,
    STATE(20284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29151), 1,
      anon_sym_RBRACK,
    STATE(20285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29153), 1,
      sym__lowercase_identifier,
    STATE(20286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778970] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25539), 1,
      anon_sym_RBRACE,
    STATE(20287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778984] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29155), 1,
      anon_sym_PIPE,
    STATE(20288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [778998] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29157), 1,
      anon_sym_RBRACE,
    STATE(20289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779012] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29159), 1,
      sym__lowercase_identifier,
    STATE(20290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779026] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29161), 1,
      anon_sym_DASH_GT,
    STATE(20291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29163), 1,
      anon_sym_RPAREN,
    STATE(20292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779054] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29165), 1,
      anon_sym_RPAREN,
    STATE(20293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779068] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29167), 1,
      anon_sym_RPAREN,
    STATE(20294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779082] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29169), 1,
      sym__lowercase_identifier,
    STATE(20295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24239), 1,
      anon_sym_RBRACE,
    STATE(20296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779110] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29171), 1,
      anon_sym_GT,
    STATE(20297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779124] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29173), 1,
      anon_sym_DASH_GT,
    STATE(20298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779138] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29175), 1,
      anon_sym_RPAREN,
    STATE(20299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779152] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29177), 1,
      anon_sym_RPAREN,
    STATE(20300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779166] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24243), 1,
      anon_sym_RBRACE,
    STATE(20301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    STATE(20302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779194] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29179), 1,
      anon_sym_RPAREN,
    STATE(20303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779208] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29181), 1,
      anon_sym_RPAREN,
    STATE(20304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779222] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29183), 1,
      anon_sym_RPAREN,
    STATE(20305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29185), 1,
      anon_sym_RBRACE,
    STATE(20306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779250] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29187), 1,
      anon_sym_RBRACK,
    STATE(20307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779264] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29189), 1,
      anon_sym_DOT_DOT,
    STATE(20308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779278] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29191), 1,
      anon_sym_DOT_DOT,
    STATE(20309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779292] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29193), 1,
      anon_sym_DOT_DOT,
    STATE(20310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29195), 1,
      anon_sym_RBRACE,
    STATE(20311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779320] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29197), 1,
      anon_sym_RBRACK,
    STATE(20312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779334] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29199), 1,
      anon_sym_RBRACK,
    STATE(20313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779348] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29201), 1,
      anon_sym_RBRACE,
    STATE(20314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779362] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29203), 1,
      anon_sym_RPAREN,
    STATE(20315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29205), 1,
      anon_sym_RPAREN,
    STATE(20316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779390] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29207), 1,
      anon_sym_RPAREN,
    STATE(20317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779404] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29209), 1,
      anon_sym_SQUOTE2,
    STATE(20318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779418] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29211), 1,
      anon_sym_DOT,
    STATE(20319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779432] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10958), 1,
      anon_sym_COMMA,
    STATE(20320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779446] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29213), 1,
      anon_sym_DOT,
    STATE(20321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29215), 1,
      anon_sym_LT_DASH,
    STATE(20322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779474] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29217), 1,
      anon_sym_DASH_GT,
    STATE(20323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779488] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3187), 1,
      anon_sym_RPAREN,
    STATE(20324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779502] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29219), 1,
      anon_sym_DQUOTE,
    STATE(20325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779516] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29221), 1,
      anon_sym_RBRACE,
    STATE(20326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779530] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29223), 1,
      anon_sym_RBRACK,
    STATE(20327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779544] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29225), 1,
      anon_sym_RPAREN,
    STATE(20328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779558] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10563), 1,
      anon_sym_COMMA,
    STATE(20329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779572] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29227), 1,
      anon_sym_GT,
    STATE(20330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779586] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29229), 1,
      anon_sym_LT_DASH,
    STATE(20331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779600] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29231), 1,
      anon_sym_RPAREN,
    STATE(20332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779614] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5409), 1,
      anon_sym_COMMA,
    STATE(20333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779628] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29233), 1,
      anon_sym_RPAREN,
    STATE(20334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779642] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29235), 1,
      anon_sym_RPAREN,
    STATE(20335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779656] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29237), 1,
      anon_sym_RBRACE,
    STATE(20336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779670] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29239), 1,
      anon_sym_in,
    STATE(20337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779684] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29241), 1,
      anon_sym_in,
    STATE(20338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779698] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29243), 1,
      anon_sym_RBRACE,
    STATE(20339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779712] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29245), 1,
      anon_sym_RPAREN,
    STATE(20340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779726] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29247), 1,
      anon_sym_in,
    STATE(20341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779740] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29249), 1,
      anon_sym_RBRACE,
    STATE(20342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779754] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29251), 1,
      anon_sym_DASH_GT,
    STATE(20343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779768] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29253), 1,
      anon_sym_RPAREN,
    STATE(20344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779782] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29255), 1,
      anon_sym_DOT,
    STATE(20345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779796] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29257), 1,
      anon_sym_in,
    STATE(20346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779810] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29259), 1,
      anon_sym_RBRACE,
    STATE(20347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29261), 1,
      anon_sym_RPAREN,
    STATE(20348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779838] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29263), 1,
      anon_sym_RPAREN,
    STATE(20349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779852] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29265), 1,
      anon_sym_RBRACK,
    STATE(20350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779866] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25503), 1,
      anon_sym_RBRACK,
    STATE(20351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779880] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29267), 1,
      anon_sym_RPAREN,
    STATE(20352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29269), 1,
      anon_sym_RBRACE,
    STATE(20353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779908] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29271), 1,
      anon_sym_DOT,
    STATE(20354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29273), 1,
      anon_sym_RPAREN,
    STATE(20355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779936] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29275), 1,
      anon_sym_RPAREN,
    STATE(20356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779950] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29277), 1,
      anon_sym_DOT,
    STATE(20357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779964] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18293), 1,
      anon_sym_GT,
    STATE(20358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779978] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    STATE(20359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [779992] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29279), 1,
      anon_sym_RPAREN,
    STATE(20360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780006] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29281), 1,
      anon_sym_RPAREN,
    STATE(20361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780020] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29283), 1,
      aux_sym_number_token1,
    STATE(20362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29285), 1,
      sym__lowercase_identifier,
    STATE(20363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780048] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29287), 1,
      anon_sym_DASH_GT,
    STATE(20364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780062] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29289), 1,
      anon_sym_DASH_GT,
    STATE(20365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780076] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24851), 1,
      anon_sym_RPAREN,
    STATE(20366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780090] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29291), 1,
      anon_sym_RBRACE,
    STATE(20367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780104] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29293), 1,
      anon_sym_SQUOTE2,
    STATE(20368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780118] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29295), 1,
      anon_sym_DQUOTE,
    STATE(20369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780132] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(7641), 1,
      anon_sym_RBRACK,
    STATE(20370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780146] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22576), 1,
      anon_sym_GT_RBRACE,
    STATE(20371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29297), 1,
      anon_sym_RBRACK,
    STATE(20372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780174] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29299), 1,
      anon_sym_RBRACE,
    STATE(20373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20944), 1,
      anon_sym_end,
    STATE(20374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780202] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29301), 1,
      anon_sym_SQUOTE2,
    STATE(20375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780216] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29303), 1,
      anon_sym_DQUOTE,
    STATE(20376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780230] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29305), 1,
      anon_sym_RBRACE,
    STATE(20377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780244] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29307), 1,
      anon_sym_RBRACE,
    STATE(20378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29309), 1,
      anon_sym_RBRACE,
    STATE(20379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780272] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29311), 1,
      sym__lowercase_identifier,
    STATE(20380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780286] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29313), 1,
      anon_sym_PIPE,
    STATE(20381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780300] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29315), 1,
      anon_sym_PIPE,
    STATE(20382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780314] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29317), 1,
      sym__lowercase_identifier,
    STATE(20383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780328] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29319), 1,
      sym__lowercase_identifier,
    STATE(20384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29321), 1,
      anon_sym_STAR,
    STATE(20385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780356] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29323), 1,
      sym__right_quoted_string_delimiter,
    STATE(20386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780370] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29325), 1,
      anon_sym_RPAREN,
    STATE(20387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780384] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29327), 1,
      anon_sym_RPAREN,
    STATE(20388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780398] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29329), 1,
      anon_sym_RBRACK,
    STATE(20389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29331), 1,
      anon_sym_RBRACE,
    STATE(20390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29333), 1,
      anon_sym_end,
    STATE(20391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780440] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29335), 1,
      anon_sym_RBRACE,
    STATE(20392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780454] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29337), 1,
      anon_sym_RPAREN,
    STATE(20393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780468] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29339), 1,
      anon_sym_RBRACE,
    STATE(20394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780482] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29341), 1,
      anon_sym_RPAREN,
    STATE(20395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12877), 1,
      anon_sym_COMMA,
    STATE(20396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780510] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29343), 1,
      anon_sym_with,
    STATE(20397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780524] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29345), 1,
      anon_sym_with,
    STATE(20398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780538] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    STATE(20399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780552] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23793), 1,
      anon_sym_RBRACK,
    STATE(20400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780566] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29347), 1,
      anon_sym_RPAREN,
    STATE(20401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780580] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29349), 1,
      anon_sym_DOT_DOT,
    STATE(20402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29351), 1,
      anon_sym_DOT_DOT,
    STATE(20403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780608] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29353), 1,
      anon_sym_DOT_DOT,
    STATE(20404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780622] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29355), 1,
      anon_sym_RBRACK,
    STATE(20405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780636] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29357), 1,
      sym__uppercase_identifier,
    STATE(20406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780650] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29359), 1,
      anon_sym_DASH_GT,
    STATE(20407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780664] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29361), 1,
      anon_sym_with,
    STATE(20408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780678] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29363), 1,
      sym__lowercase_identifier,
    STATE(20409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780692] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29365), 1,
      anon_sym_DOT,
    STATE(20410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780706] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29367), 1,
      anon_sym_EQ,
    STATE(20411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780720] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29369), 1,
      sym__lowercase_identifier,
    STATE(20412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780734] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29371), 1,
      anon_sym_RPAREN,
    STATE(20413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780748] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29373), 1,
      anon_sym_LT_DASH,
    STATE(20414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780762] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29375), 1,
      anon_sym_RBRACE,
    STATE(20415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29377), 1,
      anon_sym_SQUOTE2,
    STATE(20416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29379), 1,
      ts_builtin_sym_end,
    STATE(20417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780804] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29381), 1,
      anon_sym_RBRACE,
    STATE(20418), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780818] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29383), 1,
      anon_sym_DQUOTE,
    STATE(20419), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780832] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29385), 1,
      anon_sym_RBRACK,
    STATE(20420), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780846] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29387), 1,
      sym__lowercase_identifier,
    STATE(20421), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780860] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29389), 1,
      anon_sym_DASH_GT,
    STATE(20422), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780874] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29391), 1,
      anon_sym_of,
    STATE(20423), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780888] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23124), 1,
      anon_sym_GT_RBRACE,
    STATE(20424), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780902] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29393), 1,
      sym__lowercase_identifier,
    STATE(20425), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29395), 1,
      anon_sym_RBRACE,
    STATE(20426), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780930] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29397), 1,
      anon_sym_DOT,
    STATE(20427), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780944] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29399), 1,
      anon_sym_RBRACE,
    STATE(20428), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780958] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29401), 1,
      anon_sym_RBRACE,
    STATE(20429), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780972] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10978), 1,
      anon_sym_COMMA,
    STATE(20430), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [780986] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29403), 1,
      anon_sym_end,
    STATE(20431), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781000] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29405), 1,
      sym__lowercase_identifier,
    STATE(20432), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781014] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29407), 1,
      anon_sym_RBRACE,
    STATE(20433), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781028] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29409), 1,
      anon_sym_GT,
    STATE(20434), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781042] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29411), 1,
      anon_sym_RBRACE,
    STATE(20435), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781056] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29413), 1,
      anon_sym_RBRACE,
    STATE(20436), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781070] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29415), 1,
      anon_sym_RPAREN,
    STATE(20437), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781084] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29417), 1,
      anon_sym_end,
    STATE(20438), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781098] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29419), 1,
      anon_sym_RBRACK,
    STATE(20439), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781112] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10454), 1,
      anon_sym_COMMA,
    STATE(20440), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29421), 1,
      anon_sym_RBRACK,
    STATE(20441), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781140] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29423), 1,
      anon_sym_RBRACE,
    STATE(20442), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781154] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25523), 1,
      anon_sym_RBRACK,
    STATE(20443), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781168] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29425), 1,
      anon_sym_RPAREN,
    STATE(20444), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781182] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29427), 1,
      anon_sym_LT_DASH,
    STATE(20445), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781196] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29429), 1,
      anon_sym_RPAREN,
    STATE(20446), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781210] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29431), 1,
      anon_sym_DASH_GT,
    STATE(20447), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781224] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29433), 1,
      anon_sym_DASH_GT,
    STATE(20448), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29435), 1,
      anon_sym_RBRACE,
    STATE(20449), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781252] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29437), 1,
      anon_sym_RPAREN,
    STATE(20450), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781266] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29439), 1,
      anon_sym_RPAREN,
    STATE(20451), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781280] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29441), 1,
      anon_sym_RPAREN,
    STATE(20452), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781294] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29443), 1,
      anon_sym_RPAREN,
    STATE(20453), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781308] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3133), 1,
      anon_sym_RPAREN,
    STATE(20454), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781322] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29445), 1,
      anon_sym_with,
    STATE(20455), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29447), 1,
      anon_sym_RPAREN,
    STATE(20456), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781350] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29449), 1,
      anon_sym_RPAREN,
    STATE(20457), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29451), 1,
      anon_sym_with,
    STATE(20458), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781378] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29453), 1,
      anon_sym_RPAREN,
    STATE(20459), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29455), 1,
      anon_sym_RBRACK,
    STATE(20460), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781406] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29457), 1,
      sym__lowercase_identifier,
    STATE(20461), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781420] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29459), 1,
      anon_sym_PIPE,
    STATE(20462), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781434] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29461), 1,
      anon_sym_RBRACE,
    STATE(20463), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781448] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29463), 1,
      sym__lowercase_identifier,
    STATE(20464), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781462] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29465), 1,
      anon_sym_DQUOTE,
    STATE(20465), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781476] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29467), 1,
      anon_sym_RBRACK,
    STATE(20466), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781490] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29469), 1,
      anon_sym_RBRACE,
    STATE(20467), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781504] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29471), 1,
      anon_sym_RPAREN,
    STATE(20468), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781518] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29473), 1,
      anon_sym_RPAREN,
    STATE(20469), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781532] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29475), 1,
      anon_sym_DOT_DOT,
    STATE(20470), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781546] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29477), 1,
      anon_sym_DOT_DOT,
    STATE(20471), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29479), 1,
      anon_sym_DOT_DOT,
    STATE(20472), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29481), 1,
      anon_sym_RPAREN,
    STATE(20473), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781588] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29483), 1,
      anon_sym_DASH_GT,
    STATE(20474), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781602] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29485), 1,
      sym__lowercase_identifier,
    STATE(20475), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781616] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25583), 1,
      anon_sym_RBRACK,
    STATE(20476), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781630] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29487), 1,
      anon_sym_RBRACE,
    STATE(20477), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781644] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29489), 1,
      anon_sym_DOT,
    STATE(20478), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781658] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29491), 1,
      anon_sym_RPAREN,
    STATE(20479), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781672] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29493), 1,
      anon_sym_RPAREN,
    STATE(20480), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781686] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29495), 1,
      anon_sym_RBRACK,
    STATE(20481), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781700] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29497), 1,
      anon_sym_RPAREN,
    STATE(20482), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781714] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29499), 1,
      anon_sym_RBRACE,
    STATE(20483), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29497), 1,
      anon_sym_RBRACK,
    STATE(20484), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29501), 1,
      anon_sym_RBRACE,
    STATE(20485), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781756] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29497), 1,
      anon_sym_RBRACE,
    STATE(20486), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29503), 1,
      anon_sym_RPAREN,
    STATE(20487), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781784] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29505), 1,
      anon_sym_RPAREN,
    STATE(20488), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781798] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29507), 1,
      anon_sym_RPAREN,
    STATE(20489), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781812] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29509), 1,
      anon_sym_RPAREN,
    STATE(20490), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29511), 1,
      sym__lowercase_identifier,
    STATE(20491), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29513), 1,
      sym__lowercase_identifier,
    STATE(20492), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781854] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29515), 1,
      anon_sym_PIPE,
    STATE(20493), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781868] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29517), 1,
      anon_sym_RPAREN,
    STATE(20494), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781882] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29519), 1,
      sym__lowercase_identifier,
    STATE(20495), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781896] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29521), 1,
      anon_sym_RBRACK,
    STATE(20496), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29523), 1,
      anon_sym_DOT_DOT,
    STATE(20497), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781924] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29525), 1,
      anon_sym_DOT_DOT,
    STATE(20498), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781938] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29527), 1,
      anon_sym_DOT_DOT,
    STATE(20499), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781952] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29529), 1,
      anon_sym_RPAREN,
    STATE(20500), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781966] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29531), 1,
      anon_sym_RPAREN,
    STATE(20501), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781980] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9748), 1,
      anon_sym_RBRACK,
    STATE(20502), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [781994] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29533), 1,
      anon_sym_RBRACE,
    STATE(20503), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782008] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29535), 1,
      anon_sym_RBRACE,
    STATE(20504), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782022] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29537), 1,
      anon_sym_RBRACK,
    STATE(20505), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782036] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29539), 1,
      anon_sym_RBRACE,
    STATE(20506), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782050] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29541), 1,
      anon_sym_RPAREN,
    STATE(20507), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782064] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29543), 1,
      anon_sym_RPAREN,
    STATE(20508), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782078] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29545), 1,
      anon_sym_DASH_GT,
    STATE(20509), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782092] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29547), 1,
      anon_sym_RBRACK,
    STATE(20510), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782106] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4817), 1,
      anon_sym_end,
    STATE(20511), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782120] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29549), 1,
      aux_sym_number_token1,
    STATE(20512), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782134] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29551), 1,
      anon_sym_RBRACE,
    STATE(20513), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29553), 1,
      anon_sym_RPAREN,
    STATE(20514), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782162] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29555), 1,
      sym__lowercase_identifier,
    STATE(20515), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29557), 1,
      anon_sym_PIPE,
    STATE(20516), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782190] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29559), 1,
      anon_sym_RBRACE,
    STATE(20517), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782204] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29561), 1,
      sym__lowercase_identifier,
    STATE(20518), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782218] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29563), 1,
      anon_sym_LT_DASH,
    STATE(20519), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782232] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29565), 1,
      anon_sym_DOT_DOT,
    STATE(20520), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782246] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29567), 1,
      anon_sym_DOT_DOT,
    STATE(20521), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782260] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29569), 1,
      anon_sym_DOT_DOT,
    STATE(20522), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782274] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25575), 1,
      anon_sym_RBRACK,
    STATE(20523), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782288] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29571), 1,
      anon_sym_RBRACK,
    STATE(20524), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782302] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16613), 1,
      anon_sym_COMMA,
    STATE(20525), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29573), 1,
      anon_sym_LT_DASH,
    STATE(20526), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782330] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29575), 1,
      anon_sym_RPAREN,
    STATE(20527), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782344] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29577), 1,
      anon_sym_in,
    STATE(20528), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782358] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29579), 1,
      anon_sym_RPAREN,
    STATE(20529), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782372] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29581), 1,
      anon_sym_RBRACE,
    STATE(20530), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29583), 1,
      anon_sym_RPAREN,
    STATE(20531), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782400] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29585), 1,
      anon_sym_RPAREN,
    STATE(20532), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782414] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29587), 1,
      anon_sym_DASH_GT,
    STATE(20533), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782428] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29589), 1,
      anon_sym_RBRACE,
    STATE(20534), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782442] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29591), 1,
      anon_sym_in,
    STATE(20535), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29593), 1,
      anon_sym_PIPE,
    STATE(20536), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782470] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29595), 1,
      anon_sym_RPAREN,
    STATE(20537), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782484] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29597), 1,
      sym__lowercase_identifier,
    STATE(20538), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782498] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29599), 1,
      anon_sym_in,
    STATE(20539), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782512] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29601), 1,
      anon_sym_DOT_DOT,
    STATE(20540), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782526] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29603), 1,
      anon_sym_DOT_DOT,
    STATE(20541), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782540] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29605), 1,
      anon_sym_DOT_DOT,
    STATE(20542), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782554] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25629), 1,
      anon_sym_RBRACK,
    STATE(20543), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782568] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29607), 1,
      anon_sym_RBRACK,
    STATE(20544), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782582] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29609), 1,
      sym__lowercase_identifier,
    STATE(20545), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782596] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29611), 1,
      anon_sym_RBRACE,
    STATE(20546), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29613), 1,
      anon_sym_in,
    STATE(20547), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782624] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29615), 1,
      anon_sym_RBRACE,
    STATE(20548), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782638] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29617), 1,
      anon_sym_DASH_GT,
    STATE(20549), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782652] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29619), 1,
      anon_sym_in,
    STATE(20550), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782666] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4863), 1,
      anon_sym_end,
    STATE(20551), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782680] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29621), 1,
      aux_sym_number_token1,
    STATE(20552), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29623), 1,
      anon_sym_RPAREN,
    STATE(20553), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782708] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29625), 1,
      anon_sym_RBRACK,
    STATE(20554), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782722] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29627), 1,
      anon_sym_RBRACE,
    STATE(20555), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782736] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29629), 1,
      anon_sym_PIPE,
    STATE(20556), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782750] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29631), 1,
      anon_sym_RBRACE,
    STATE(20557), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782764] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29633), 1,
      sym__lowercase_identifier,
    STATE(20558), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782778] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29635), 1,
      anon_sym_in,
    STATE(20559), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782792] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29637), 1,
      anon_sym_DOT_DOT,
    STATE(20560), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782806] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29639), 1,
      anon_sym_DOT_DOT,
    STATE(20561), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782820] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29641), 1,
      anon_sym_DOT_DOT,
    STATE(20562), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782834] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25655), 1,
      anon_sym_RBRACK,
    STATE(20563), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782848] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29643), 1,
      anon_sym_RBRACK,
    STATE(20564), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782862] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29645), 1,
      anon_sym_RBRACE,
    STATE(20565), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29647), 1,
      anon_sym_RBRACE,
    STATE(20566), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782890] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29649), 1,
      anon_sym_in,
    STATE(20567), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782904] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29651), 1,
      anon_sym_in,
    STATE(20568), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782918] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29653), 1,
      anon_sym_in,
    STATE(20569), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782932] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29655), 1,
      anon_sym_RPAREN,
    STATE(20570), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29657), 1,
      anon_sym_RBRACK,
    STATE(20571), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782960] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29659), 1,
      anon_sym_RBRACE,
    STATE(20572), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782974] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29661), 1,
      anon_sym_RPAREN,
    STATE(20573), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [782988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29663), 1,
      anon_sym_RBRACE,
    STATE(20574), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783002] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29665), 1,
      anon_sym_PIPE,
    STATE(20575), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783016] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29667), 1,
      anon_sym_in,
    STATE(20576), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783030] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29669), 1,
      sym__lowercase_identifier,
    STATE(20577), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29671), 1,
      anon_sym_in,
    STATE(20578), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783058] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29673), 1,
      anon_sym_DOT_DOT,
    STATE(20579), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783072] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29675), 1,
      anon_sym_DOT_DOT,
    STATE(20580), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783086] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29677), 1,
      anon_sym_DOT_DOT,
    STATE(20581), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783100] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9782), 1,
      anon_sym_RBRACK,
    STATE(20582), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783114] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29679), 1,
      anon_sym_RBRACK,
    STATE(20583), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29681), 1,
      anon_sym_RBRACE,
    STATE(20584), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783142] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(10892), 1,
      anon_sym_COMMA,
    STATE(20585), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29683), 1,
      anon_sym_in,
    STATE(20586), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783170] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16635), 1,
      anon_sym_COMMA,
    STATE(20587), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29685), 1,
      anon_sym_RBRACE,
    STATE(20588), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783198] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29687), 1,
      anon_sym_DASH_GT,
    STATE(20589), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783212] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(13030), 1,
      anon_sym_DASH_GT,
    STATE(20590), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783226] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29689), 1,
      anon_sym_RPAREN,
    STATE(20591), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783240] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29691), 1,
      anon_sym_RBRACK,
    STATE(20592), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29693), 1,
      anon_sym_PIPE,
    STATE(20593), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783268] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29695), 1,
      anon_sym_RPAREN,
    STATE(20594), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783282] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29697), 1,
      sym__lowercase_identifier,
    STATE(20595), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783296] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29699), 1,
      anon_sym_RBRACE,
    STATE(20596), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783310] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29701), 1,
      anon_sym_DOT_DOT,
    STATE(20597), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783324] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29703), 1,
      anon_sym_DOT_DOT,
    STATE(20598), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783338] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29705), 1,
      anon_sym_DOT_DOT,
    STATE(20599), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783352] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9842), 1,
      anon_sym_RBRACK,
    STATE(20600), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783366] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29707), 1,
      anon_sym_RBRACE,
    STATE(20601), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783380] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29695), 1,
      anon_sym_RBRACK,
    STATE(20602), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783394] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29709), 1,
      anon_sym_RBRACE,
    STATE(20603), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783408] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29711), 1,
      anon_sym_RBRACK,
    STATE(20604), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783422] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29713), 1,
      anon_sym_LT_DASH,
    STATE(20605), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783436] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29715), 1,
      anon_sym_RBRACE,
    STATE(20606), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783450] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29717), 1,
      anon_sym_RBRACE,
    STATE(20607), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783464] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3181), 1,
      anon_sym_RPAREN,
    STATE(20608), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783478] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29695), 1,
      anon_sym_RBRACE,
    STATE(20609), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783492] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    STATE(20610), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783506] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29719), 1,
      anon_sym_PIPE,
    STATE(20611), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783520] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29721), 1,
      anon_sym_DASH_GT,
    STATE(20612), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783534] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29723), 1,
      sym__lowercase_identifier,
    STATE(20613), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783548] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29725), 1,
      anon_sym_RBRACK,
    STATE(20614), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783562] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29727), 1,
      anon_sym_DOT_DOT,
    STATE(20615), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783576] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29729), 1,
      anon_sym_DOT_DOT,
    STATE(20616), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783590] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29731), 1,
      anon_sym_DOT_DOT,
    STATE(20617), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783604] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9586), 1,
      anon_sym_RBRACK,
    STATE(20618), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783618] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29733), 1,
      anon_sym_RBRACE,
    STATE(20619), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783632] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12179), 1,
      anon_sym_COMMA,
    STATE(20620), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29735), 1,
      anon_sym_LT_DASH,
    STATE(20621), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783660] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22785), 1,
      anon_sym_GT_RBRACE,
    STATE(20622), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783674] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29737), 1,
      anon_sym_RBRACE,
    STATE(20623), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29739), 1,
      anon_sym_RBRACE,
    STATE(20624), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783702] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20976), 1,
      anon_sym_end,
    STATE(20625), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783716] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29741), 1,
      anon_sym_SQUOTE2,
    STATE(20626), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783730] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29743), 1,
      anon_sym_RBRACK,
    STATE(20627), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783744] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29745), 1,
      anon_sym_PIPE,
    STATE(20628), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783758] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29747), 1,
      anon_sym_DQUOTE,
    STATE(20629), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783772] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29749), 1,
      sym__lowercase_identifier,
    STATE(20630), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783786] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29751), 1,
      anon_sym_RBRACE,
    STATE(20631), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783800] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29753), 1,
      anon_sym_DOT_DOT,
    STATE(20632), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783814] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29755), 1,
      anon_sym_DOT_DOT,
    STATE(20633), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783828] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29757), 1,
      anon_sym_DOT_DOT,
    STATE(20634), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783842] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29759), 1,
      anon_sym_RBRACE,
    STATE(20635), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783856] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29761), 1,
      anon_sym_LT_DASH,
    STATE(20636), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783870] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3111), 1,
      anon_sym_RPAREN,
    STATE(20637), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783884] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29763), 1,
      sym__lowercase_identifier,
    STATE(20638), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783898] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29765), 1,
      anon_sym_LT_DASH,
    STATE(20639), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783912] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29767), 1,
      anon_sym_DASH_GT,
    STATE(20640), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29769), 1,
      anon_sym_RPAREN,
    STATE(20641), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783940] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29771), 1,
      anon_sym_RPAREN,
    STATE(20642), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783954] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29773), 1,
      anon_sym_RBRACK,
    STATE(20643), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783968] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29775), 1,
      anon_sym_PIPE,
    STATE(20644), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783982] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29777), 1,
      anon_sym_end,
    STATE(20645), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [783996] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29779), 1,
      sym__lowercase_identifier,
    STATE(20646), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784010] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29781), 1,
      anon_sym_RBRACE,
    STATE(20647), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784024] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29783), 1,
      anon_sym_DOT_DOT,
    STATE(20648), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29785), 1,
      anon_sym_DOT_DOT,
    STATE(20649), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784052] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29787), 1,
      anon_sym_DOT_DOT,
    STATE(20650), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784066] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29789), 1,
      anon_sym_RBRACE,
    STATE(20651), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784080] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3169), 1,
      anon_sym_RPAREN,
    STATE(20652), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784094] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29791), 1,
      anon_sym_DASH_GT,
    STATE(20653), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784108] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29793), 1,
      anon_sym_RBRACK,
    STATE(20654), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784122] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29795), 1,
      anon_sym_RBRACE,
    STATE(20655), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784136] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29797), 1,
      anon_sym_DASH_GT,
    STATE(20656), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784150] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29799), 1,
      anon_sym_RBRACE,
    STATE(20657), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784164] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29801), 1,
      anon_sym_RBRACK,
    STATE(20658), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784178] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29803), 1,
      anon_sym_in,
    STATE(20659), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784192] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29805), 1,
      anon_sym_PIPE,
    STATE(20660), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784206] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29807), 1,
      anon_sym_RBRACE,
    STATE(20661), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784220] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29809), 1,
      sym__lowercase_identifier,
    STATE(20662), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29811), 1,
      anon_sym_RBRACK,
    STATE(20663), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784248] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29813), 1,
      anon_sym_DOT_DOT,
    STATE(20664), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784262] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29815), 1,
      anon_sym_DOT_DOT,
    STATE(20665), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784276] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29817), 1,
      anon_sym_DOT_DOT,
    STATE(20666), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29819), 1,
      anon_sym_RBRACE,
    STATE(20667), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784304] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29821), 1,
      anon_sym_RPAREN,
    STATE(20668), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29823), 1,
      anon_sym_in,
    STATE(20669), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29825), 1,
      anon_sym_in,
    STATE(20670), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29827), 1,
      anon_sym_RBRACE,
    STATE(20671), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784360] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29829), 1,
      anon_sym_RPAREN,
    STATE(20672), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784374] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29831), 1,
      anon_sym_in,
    STATE(20673), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784388] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29833), 1,
      anon_sym_RBRACK,
    STATE(20674), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784402] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29835), 1,
      anon_sym_RBRACE,
    STATE(20675), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784416] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29837), 1,
      anon_sym_PIPE,
    STATE(20676), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784430] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11169), 1,
      anon_sym_DASH_GT,
    STATE(20677), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784444] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29839), 1,
      sym__lowercase_identifier,
    STATE(20678), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784458] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29841), 1,
      anon_sym_RBRACE,
    STATE(20679), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29843), 1,
      anon_sym_DOT_DOT,
    STATE(20680), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784486] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29845), 1,
      anon_sym_DOT_DOT,
    STATE(20681), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784500] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29847), 1,
      anon_sym_DOT_DOT,
    STATE(20682), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29849), 1,
      anon_sym_DASH_GT,
    STATE(20683), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784528] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5603), 1,
      anon_sym_end,
    STATE(20684), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784542] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29851), 1,
      anon_sym_RBRACK,
    STATE(20685), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784556] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29853), 1,
      anon_sym_in,
    STATE(20686), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784570] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29855), 1,
      anon_sym_RBRACE,
    STATE(20687), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784584] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29857), 1,
      anon_sym_RBRACE,
    STATE(20688), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784598] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12604), 1,
      anon_sym_DASH_GT,
    STATE(20689), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784612] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5563), 1,
      anon_sym_RPAREN,
    STATE(20690), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29859), 1,
      anon_sym_RBRACK,
    STATE(20691), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784640] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29861), 1,
      anon_sym_PIPE,
    STATE(20692), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784654] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29863), 1,
      anon_sym_RBRACE,
    STATE(20693), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784668] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29865), 1,
      sym__lowercase_identifier,
    STATE(20694), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784682] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29867), 1,
      anon_sym_RBRACE,
    STATE(20695), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784696] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29869), 1,
      anon_sym_DOT_DOT,
    STATE(20696), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784710] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29871), 1,
      anon_sym_DOT_DOT,
    STATE(20697), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784724] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29873), 1,
      anon_sym_DOT_DOT,
    STATE(20698), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784738] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3163), 1,
      anon_sym_RPAREN,
    STATE(20699), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784752] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29875), 1,
      anon_sym_RBRACE,
    STATE(20700), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784766] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29877), 1,
      anon_sym_RBRACK,
    STATE(20701), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784780] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29879), 1,
      anon_sym_RBRACE,
    STATE(20702), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29881), 1,
      anon_sym_RBRACE,
    STATE(20703), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784808] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29883), 1,
      aux_sym_number_token1,
    STATE(20704), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11764), 1,
      anon_sym_GT,
    STATE(20705), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784836] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29885), 1,
      anon_sym_DASH_GT,
    STATE(20706), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784850] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29887), 1,
      anon_sym_RBRACE,
    STATE(20707), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784864] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29889), 1,
      anon_sym_PIPE,
    STATE(20708), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784878] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29891), 1,
      anon_sym_RPAREN,
    STATE(20709), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784892] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29893), 1,
      sym__lowercase_identifier,
    STATE(20710), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784906] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29895), 1,
      anon_sym_in,
    STATE(20711), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784920] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29897), 1,
      anon_sym_DOT_DOT,
    STATE(20712), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29899), 1,
      anon_sym_DOT_DOT,
    STATE(20713), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784948] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29901), 1,
      anon_sym_DOT_DOT,
    STATE(20714), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784962] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29903), 1,
      anon_sym_RBRACK,
    STATE(20715), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784976] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29905), 1,
      anon_sym_RBRACE,
    STATE(20716), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [784990] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29907), 1,
      anon_sym_RBRACE,
    STATE(20717), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785004] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29909), 1,
      anon_sym_RBRACE,
    STATE(20718), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29911), 1,
      anon_sym_RPAREN,
    STATE(20719), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785032] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29913), 1,
      anon_sym_RPAREN,
    STATE(20720), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785046] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29915), 1,
      anon_sym_RPAREN,
    STATE(20721), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785060] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29917), 1,
      anon_sym_RBRACK,
    STATE(20722), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785074] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29919), 1,
      anon_sym_RBRACE,
    STATE(20723), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785088] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29921), 1,
      anon_sym_PIPE,
    STATE(20724), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785102] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29923), 1,
      anon_sym_RBRACE,
    STATE(20725), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785116] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29925), 1,
      sym__lowercase_identifier,
    STATE(20726), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785130] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29927), 1,
      anon_sym_in,
    STATE(20727), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785144] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29929), 1,
      anon_sym_DOT_DOT,
    STATE(20728), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785158] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29931), 1,
      anon_sym_DOT_DOT,
    STATE(20729), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785172] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29933), 1,
      anon_sym_DOT_DOT,
    STATE(20730), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785186] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29935), 1,
      anon_sym_RBRACK,
    STATE(20731), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785200] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18430), 1,
      anon_sym_GT,
    STATE(20732), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785214] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29937), 1,
      anon_sym_RPAREN,
    STATE(20733), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785228] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29939), 1,
      anon_sym_RBRACE,
    STATE(20734), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785242] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29941), 1,
      anon_sym_RBRACE,
    STATE(20735), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785256] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29943), 1,
      anon_sym_GT,
    STATE(20736), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785270] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17700), 1,
      anon_sym_COMMA,
    STATE(20737), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785284] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29945), 1,
      anon_sym_RPAREN,
    STATE(20738), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29947), 1,
      anon_sym_in,
    STATE(20739), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785312] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29949), 1,
      anon_sym_PIPE,
    STATE(20740), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785326] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29951), 1,
      anon_sym_GT,
    STATE(20741), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29953), 1,
      sym__lowercase_identifier,
    STATE(20742), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785354] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29955), 1,
      anon_sym_RPAREN,
    STATE(20743), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785368] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29957), 1,
      anon_sym_DOT_DOT,
    STATE(20744), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785382] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29959), 1,
      anon_sym_DOT_DOT,
    STATE(20745), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785396] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29961), 1,
      anon_sym_DOT_DOT,
    STATE(20746), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785410] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29963), 1,
      anon_sym_RPAREN,
    STATE(20747), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785424] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22937), 1,
      anon_sym_GT_RBRACE,
    STATE(20748), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785438] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29965), 1,
      anon_sym_RPAREN,
    STATE(20749), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785452] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29967), 1,
      anon_sym_DASH_GT,
    STATE(20750), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785466] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22624), 1,
      anon_sym_GT_RBRACE,
    STATE(20751), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785480] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21006), 1,
      anon_sym_end,
    STATE(20752), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785494] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29969), 1,
      anon_sym_RBRACE,
    STATE(20753), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785508] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18266), 1,
      anon_sym_GT,
    STATE(20754), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785522] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15559), 1,
      anon_sym_COMMA,
    STATE(20755), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785536] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29971), 1,
      anon_sym_PIPE,
    STATE(20756), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785550] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29973), 1,
      anon_sym_LT_DASH,
    STATE(20757), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785564] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29975), 1,
      sym__lowercase_identifier,
    STATE(20758), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785578] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29977), 1,
      anon_sym_RBRACK,
    STATE(20759), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785592] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29979), 1,
      anon_sym_DOT_DOT,
    STATE(20760), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785606] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29981), 1,
      anon_sym_DOT_DOT,
    STATE(20761), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785620] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29983), 1,
      anon_sym_DOT_DOT,
    STATE(20762), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785634] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29985), 1,
      anon_sym_RBRACE,
    STATE(20763), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785648] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29987), 1,
      anon_sym_SQUOTE2,
    STATE(20764), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785662] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29989), 1,
      anon_sym_DQUOTE,
    STATE(20765), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785676] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29991), 1,
      anon_sym_DASH_GT,
    STATE(20766), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785690] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29993), 1,
      anon_sym_in,
    STATE(20767), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785704] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3145), 1,
      anon_sym_RPAREN,
    STATE(20768), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785718] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29995), 1,
      anon_sym_RBRACE,
    STATE(20769), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785732] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29997), 1,
      anon_sym_RPAREN,
    STATE(20770), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785746] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(29999), 1,
      anon_sym_RPAREN,
    STATE(20771), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785760] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30001), 1,
      anon_sym_PIPE,
    STATE(20772), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11792), 1,
      anon_sym_GT,
    STATE(20773), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785788] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30003), 1,
      sym__lowercase_identifier,
    STATE(20774), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785802] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30005), 1,
      anon_sym_DOT,
    STATE(20775), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785816] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30007), 1,
      anon_sym_DOT_DOT,
    STATE(20776), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785830] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30009), 1,
      anon_sym_DOT_DOT,
    STATE(20777), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785844] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30011), 1,
      anon_sym_DOT_DOT,
    STATE(20778), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30013), 1,
      anon_sym_RPAREN,
    STATE(20779), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785872] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30015), 1,
      anon_sym_end,
    STATE(20780), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785886] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30017), 1,
      anon_sym_type,
    STATE(20781), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785900] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30019), 1,
      anon_sym_EQ,
    STATE(20782), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785914] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30021), 1,
      anon_sym_DOT,
    STATE(20783), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785928] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30023), 1,
      sym__lowercase_identifier,
    STATE(20784), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30025), 1,
      anon_sym_DASH_GT,
    STATE(20785), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30027), 1,
      anon_sym_DASH_GT,
    STATE(20786), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785970] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30029), 1,
      anon_sym_DOT,
    STATE(20787), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785984] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30031), 1,
      anon_sym_RBRACE,
    STATE(20788), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [785998] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30033), 1,
      sym__lowercase_identifier,
    STATE(20789), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786012] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30035), 1,
      anon_sym_RBRACE,
    STATE(20790), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786026] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30037), 1,
      anon_sym_DOT_DOT,
    STATE(20791), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30039), 1,
      anon_sym_DOT_DOT,
    STATE(20792), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786054] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30041), 1,
      anon_sym_DOT_DOT,
    STATE(20793), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786068] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30043), 1,
      anon_sym_RBRACE,
    STATE(20794), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786082] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30045), 1,
      anon_sym_RPAREN,
    STATE(20795), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(24299), 1,
      anon_sym_RPAREN,
    STATE(20796), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786110] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21135), 1,
      anon_sym_end,
    STATE(20797), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786124] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30047), 1,
      anon_sym_RPAREN,
    STATE(20798), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786138] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30049), 1,
      anon_sym_DOT,
    STATE(20799), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786152] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30051), 1,
      anon_sym_RBRACK,
    STATE(20800), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786166] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30053), 1,
      anon_sym_DOT,
    STATE(20801), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22088), 1,
      anon_sym_GT_RBRACE,
    STATE(20802), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786194] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30055), 1,
      anon_sym_RBRACK,
    STATE(20803), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786208] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30057), 1,
      sym__lowercase_identifier,
    STATE(20804), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786222] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9030), 1,
      anon_sym_DASH_GT,
    STATE(20805), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30059), 1,
      anon_sym_DOT_DOT,
    STATE(20806), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786250] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30061), 1,
      anon_sym_DOT_DOT,
    STATE(20807), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786264] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30063), 1,
      anon_sym_DOT_DOT,
    STATE(20808), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786278] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20336), 1,
      anon_sym_end,
    STATE(20809), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786292] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30065), 1,
      anon_sym_in,
    STATE(20810), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30067), 1,
      anon_sym_RBRACE,
    STATE(20811), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786320] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30069), 1,
      anon_sym_in,
    STATE(20812), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786334] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30071), 1,
      anon_sym_SQUOTE2,
    STATE(20813), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786348] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30073), 1,
      anon_sym_RPAREN,
    STATE(20814), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786362] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30075), 1,
      anon_sym_STAR,
    STATE(20815), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30077), 1,
      anon_sym_DQUOTE,
    STATE(20816), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786390] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30079), 1,
      anon_sym_RPAREN,
    STATE(20817), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786404] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23040), 1,
      anon_sym_GT_RBRACE,
    STATE(20818), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786418] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30081), 1,
      sym__lowercase_identifier,
    STATE(20819), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786432] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30083), 1,
      anon_sym_RPAREN,
    STATE(20820), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786446] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30085), 1,
      anon_sym_DOT_DOT,
    STATE(20821), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30087), 1,
      anon_sym_DOT_DOT,
    STATE(20822), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786474] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30089), 1,
      anon_sym_DOT_DOT,
    STATE(20823), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786488] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30091), 1,
      sym__lowercase_identifier,
    STATE(20824), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786502] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30093), 1,
      anon_sym_in,
    STATE(20825), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786516] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15468), 1,
      anon_sym_COMMA,
    STATE(20826), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786530] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30095), 1,
      anon_sym_with,
    STATE(20827), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786544] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21621), 1,
      anon_sym_GT_RBRACE,
    STATE(20828), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786558] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5455), 1,
      anon_sym_RPAREN,
    STATE(20829), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786572] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30097), 1,
      anon_sym_RBRACK,
    STATE(20830), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786586] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30099), 1,
      anon_sym_LT_DASH,
    STATE(20831), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786600] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30101), 1,
      anon_sym_DASH_GT,
    STATE(20832), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786614] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30103), 1,
      anon_sym_RPAREN,
    STATE(20833), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786628] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30105), 1,
      sym__lowercase_identifier,
    STATE(20834), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786642] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30107), 1,
      anon_sym_RBRACE,
    STATE(20835), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786656] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30109), 1,
      anon_sym_DOT_DOT,
    STATE(20836), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786670] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30111), 1,
      anon_sym_DOT_DOT,
    STATE(20837), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786684] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30113), 1,
      anon_sym_DOT_DOT,
    STATE(20838), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786698] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30115), 1,
      anon_sym_RBRACE,
    STATE(20839), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786712] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20982), 1,
      anon_sym_end,
    STATE(20840), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786726] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30117), 1,
      anon_sym_with,
    STATE(20841), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786740] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30119), 1,
      anon_sym_SQUOTE2,
    STATE(20842), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786754] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20093), 1,
      anon_sym_end,
    STATE(20843), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786768] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30121), 1,
      anon_sym_DOT,
    STATE(20844), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786782] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30123), 1,
      anon_sym_SQUOTE2,
    STATE(20845), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786796] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30125), 1,
      anon_sym_DOT,
    STATE(20846), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786810] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30127), 1,
      anon_sym_DASH_GT,
    STATE(20847), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30129), 1,
      anon_sym_RBRACE,
    STATE(20848), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786838] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30131), 1,
      sym__lowercase_identifier,
    STATE(20849), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786852] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30133), 1,
      anon_sym_DOT,
    STATE(20850), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786866] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30135), 1,
      anon_sym_DOT_DOT,
    STATE(20851), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786880] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30137), 1,
      anon_sym_DOT_DOT,
    STATE(20852), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30139), 1,
      anon_sym_DOT_DOT,
    STATE(20853), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786908] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30141), 1,
      anon_sym_DQUOTE,
    STATE(20854), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5617), 1,
      anon_sym_COMMA,
    STATE(20855), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786936] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30143), 1,
      anon_sym_DASH_GT,
    STATE(20856), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786950] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30145), 1,
      anon_sym_DOT,
    STATE(20857), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786964] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30147), 1,
      anon_sym_DASH_GT,
    STATE(20858), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786978] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30149), 1,
      anon_sym_RBRACK,
    STATE(20859), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [786992] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30151), 1,
      anon_sym_DQUOTE,
    STATE(20860), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787006] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3101), 1,
      anon_sym_RPAREN,
    STATE(20861), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787020] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30153), 1,
      anon_sym_DASH_GT,
    STATE(20862), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30155), 1,
      anon_sym_RBRACE,
    STATE(20863), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787048] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30157), 1,
      sym__lowercase_identifier,
    STATE(20864), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787062] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18619), 1,
      anon_sym_COMMA,
    STATE(20865), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787076] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30159), 1,
      anon_sym_DOT_DOT,
    STATE(20866), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787090] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30161), 1,
      anon_sym_DOT_DOT,
    STATE(20867), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787104] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30163), 1,
      anon_sym_DOT_DOT,
    STATE(20868), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787118] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30165), 1,
      anon_sym_of,
    STATE(20869), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787132] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30167), 1,
      anon_sym_DASH_GT,
    STATE(20870), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787146] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30169), 1,
      anon_sym_DASH_GT,
    STATE(20871), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30171), 1,
      anon_sym_done,
    STATE(20872), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787174] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30173), 1,
      anon_sym_RPAREN,
    STATE(20873), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30175), 1,
      anon_sym_DASH_GT,
    STATE(20874), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787202] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30177), 1,
      anon_sym_RBRACK,
    STATE(20875), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787216] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30179), 1,
      sym__lowercase_identifier,
    STATE(20876), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787230] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30181), 1,
      anon_sym_in,
    STATE(20877), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787244] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30183), 1,
      anon_sym_RPAREN,
    STATE(20878), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30185), 1,
      sym__lowercase_identifier,
    STATE(20879), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787272] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30187), 1,
      anon_sym_end,
    STATE(20880), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787286] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30189), 1,
      anon_sym_DOT_DOT,
    STATE(20881), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787300] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30191), 1,
      anon_sym_DOT_DOT,
    STATE(20882), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787314] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30193), 1,
      anon_sym_DOT_DOT,
    STATE(20883), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787328] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30195), 1,
      anon_sym_RBRACK,
    STATE(20884), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30197), 1,
      anon_sym_RBRACK,
    STATE(20885), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787356] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30199), 1,
      anon_sym_RBRACE,
    STATE(20886), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787370] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17405), 1,
      anon_sym_DASH_GT,
    STATE(20887), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787384] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30201), 1,
      anon_sym_STAR,
    STATE(20888), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787398] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30203), 1,
      anon_sym_RPAREN,
    STATE(20889), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30205), 1,
      anon_sym_RPAREN,
    STATE(20890), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30207), 1,
      anon_sym_DASH_GT,
    STATE(20891), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787440] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18434), 1,
      anon_sym_GT,
    STATE(20892), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787454] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30209), 1,
      anon_sym_DASH_GT,
    STATE(20893), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787468] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30211), 1,
      sym__lowercase_identifier,
    STATE(20894), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787482] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30213), 1,
      anon_sym_RPAREN,
    STATE(20895), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30215), 1,
      anon_sym_DOT_DOT,
    STATE(20896), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787510] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30217), 1,
      anon_sym_DOT_DOT,
    STATE(20897), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787524] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30219), 1,
      anon_sym_DOT_DOT,
    STATE(20898), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787538] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30221), 1,
      anon_sym_RBRACE,
    STATE(20899), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787552] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30223), 1,
      anon_sym_RPAREN,
    STATE(20900), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787566] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30225), 1,
      anon_sym_RPAREN,
    STATE(20901), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787580] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30227), 1,
      sym__lowercase_identifier,
    STATE(20902), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30229), 1,
      anon_sym_with,
    STATE(20903), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787608] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30231), 1,
      anon_sym_RBRACK,
    STATE(20904), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787622] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30233), 1,
      anon_sym_RBRACE,
    STATE(20905), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787636] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30235), 1,
      anon_sym_with,
    STATE(20906), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787650] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30237), 1,
      anon_sym_RBRACK,
    STATE(20907), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787664] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30239), 1,
      anon_sym_RBRACE,
    STATE(20908), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787678] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30241), 1,
      sym__lowercase_identifier,
    STATE(20909), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787692] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30243), 1,
      anon_sym_with,
    STATE(20910), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787706] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30245), 1,
      anon_sym_DOT_DOT,
    STATE(20911), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787720] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30247), 1,
      anon_sym_DOT_DOT,
    STATE(20912), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787734] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30249), 1,
      anon_sym_DOT_DOT,
    STATE(20913), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787748] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30251), 1,
      anon_sym_DOT,
    STATE(20914), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787762] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30253), 1,
      anon_sym_RPAREN,
    STATE(20915), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30255), 1,
      anon_sym_RPAREN,
    STATE(20916), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30257), 1,
      anon_sym_with,
    STATE(20917), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787804] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30259), 1,
      anon_sym_end,
    STATE(20918), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787818] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30261), 1,
      anon_sym_end,
    STATE(20919), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787832] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30263), 1,
      anon_sym_SQUOTE2,
    STATE(20920), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787846] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30265), 1,
      anon_sym_DQUOTE,
    STATE(20921), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787860] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30267), 1,
      anon_sym_DOT,
    STATE(20922), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787874] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30269), 1,
      anon_sym_RPAREN,
    STATE(20923), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787888] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30271), 1,
      sym__lowercase_identifier,
    STATE(20924), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787902] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30273), 1,
      anon_sym_RPAREN,
    STATE(20925), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787916] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30275), 1,
      anon_sym_DOT_DOT,
    STATE(20926), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787930] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30277), 1,
      anon_sym_DOT_DOT,
    STATE(20927), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787944] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30279), 1,
      anon_sym_DOT_DOT,
    STATE(20928), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787958] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30281), 1,
      anon_sym_RPAREN,
    STATE(20929), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787972] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30283), 1,
      anon_sym_RBRACK,
    STATE(20930), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [787986] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30285), 1,
      anon_sym_RPAREN,
    STATE(20931), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788000] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30287), 1,
      anon_sym_RBRACE,
    STATE(20932), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788014] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30289), 1,
      anon_sym_DOT,
    STATE(20933), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788028] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30291), 1,
      anon_sym_DASH_GT,
    STATE(20934), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788042] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30293), 1,
      anon_sym_DASH_GT,
    STATE(20935), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788056] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30295), 1,
      anon_sym_RBRACE,
    STATE(20936), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788070] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18482), 1,
      anon_sym_GT,
    STATE(20937), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788084] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30297), 1,
      anon_sym_RPAREN,
    STATE(20938), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788098] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30299), 1,
      sym__lowercase_identifier,
    STATE(20939), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788112] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30301), 1,
      anon_sym_RPAREN,
    STATE(20940), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788126] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30303), 1,
      anon_sym_DOT_DOT,
    STATE(20941), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788140] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30305), 1,
      anon_sym_DOT_DOT,
    STATE(20942), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788154] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30307), 1,
      anon_sym_DOT_DOT,
    STATE(20943), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788168] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30309), 1,
      anon_sym_RBRACK,
    STATE(20944), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788182] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11894), 1,
      anon_sym_GT,
    STATE(20945), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788196] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30311), 1,
      sym__lowercase_identifier,
    STATE(20946), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788210] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30313), 1,
      anon_sym_DASH_GT,
    STATE(20947), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788224] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30315), 1,
      anon_sym_RPAREN,
    STATE(20948), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788238] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4883), 1,
      anon_sym_end,
    STATE(20949), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788252] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30317), 1,
      anon_sym_RPAREN,
    STATE(20950), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788266] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30319), 1,
      anon_sym_RPAREN,
    STATE(20951), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788280] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30321), 1,
      anon_sym_DASH_GT,
    STATE(20952), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788294] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30323), 1,
      anon_sym_DOT,
    STATE(20953), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788308] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30325), 1,
      sym__lowercase_identifier,
    STATE(20954), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788322] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30327), 1,
      anon_sym_RBRACE,
    STATE(20955), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788336] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30329), 1,
      anon_sym_DOT_DOT,
    STATE(20956), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788350] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30331), 1,
      anon_sym_DOT_DOT,
    STATE(20957), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788364] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30333), 1,
      anon_sym_DOT_DOT,
    STATE(20958), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788378] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30335), 1,
      sym__lowercase_identifier,
    STATE(20959), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788392] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15869), 1,
      anon_sym_COMMA,
    STATE(20960), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788406] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30337), 1,
      anon_sym_DASH_GT,
    STATE(20961), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788420] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30339), 1,
      anon_sym_RPAREN,
    STATE(20962), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788434] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30341), 1,
      anon_sym_DASH_GT,
    STATE(20963), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788448] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30343), 1,
      anon_sym_RPAREN,
    STATE(20964), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788462] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30345), 1,
      anon_sym_RBRACK,
    STATE(20965), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788476] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30347), 1,
      anon_sym_RBRACE,
    STATE(20966), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788490] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30349), 1,
      anon_sym_RPAREN,
    STATE(20967), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788504] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30351), 1,
      anon_sym_RPAREN,
    STATE(20968), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788518] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30353), 1,
      sym__lowercase_identifier,
    STATE(20969), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788532] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21155), 1,
      anon_sym_end,
    STATE(20970), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788546] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30355), 1,
      anon_sym_DOT_DOT,
    STATE(20971), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788560] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30357), 1,
      anon_sym_DOT_DOT,
    STATE(20972), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788574] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30359), 1,
      anon_sym_DOT_DOT,
    STATE(20973), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788588] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30361), 1,
      anon_sym_in,
    STATE(20974), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788602] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30363), 1,
      anon_sym_DASH_GT,
    STATE(20975), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788616] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30365), 1,
      anon_sym_RPAREN,
    STATE(20976), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788630] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25813), 1,
      anon_sym_RBRACE,
    STATE(20977), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788644] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30367), 1,
      anon_sym_in,
    STATE(20978), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788658] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30369), 1,
      anon_sym_RBRACE,
    STATE(20979), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788672] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25817), 1,
      anon_sym_RBRACE,
    STATE(20980), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788686] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30371), 1,
      anon_sym_RBRACE,
    STATE(20981), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788700] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30373), 1,
      anon_sym_DASH_GT,
    STATE(20982), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788714] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30375), 1,
      anon_sym_GT,
    STATE(20983), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788728] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30377), 1,
      sym__lowercase_identifier,
    STATE(20984), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788742] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30379), 1,
      anon_sym_RBRACK,
    STATE(20985), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788756] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30381), 1,
      anon_sym_DOT_DOT,
    STATE(20986), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788770] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30383), 1,
      anon_sym_DOT_DOT,
    STATE(20987), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788784] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30385), 1,
      anon_sym_DOT_DOT,
    STATE(20988), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788798] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30387), 1,
      anon_sym_RPAREN,
    STATE(20989), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788812] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30389), 1,
      anon_sym_in,
    STATE(20990), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788826] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30391), 1,
      anon_sym_GT,
    STATE(20991), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788840] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30393), 1,
      anon_sym_RPAREN,
    STATE(20992), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788854] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30395), 1,
      anon_sym_SQUOTE2,
    STATE(20993), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788868] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30397), 1,
      anon_sym_end,
    STATE(20994), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788882] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30399), 1,
      anon_sym_DASH_GT,
    STATE(20995), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788896] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30401), 1,
      anon_sym_DASH_GT,
    STATE(20996), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788910] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30403), 1,
      anon_sym_GT,
    STATE(20997), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788924] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30405), 1,
      anon_sym_RPAREN,
    STATE(20998), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788938] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30407), 1,
      sym__lowercase_identifier,
    STATE(20999), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788952] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30409), 1,
      anon_sym_DASH_GT,
    STATE(21000), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788966] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30411), 1,
      anon_sym_DOT_DOT,
    STATE(21001), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788980] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30413), 1,
      anon_sym_DOT_DOT,
    STATE(21002), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [788994] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30415), 1,
      anon_sym_DOT_DOT,
    STATE(21003), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789008] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30417), 1,
      anon_sym_RBRACE,
    STATE(21004), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789022] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30419), 1,
      anon_sym_RBRACE,
    STATE(21005), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789036] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30421), 1,
      anon_sym_RBRACE,
    STATE(21006), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789050] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30423), 1,
      anon_sym_end,
    STATE(21007), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789064] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30425), 1,
      anon_sym_end,
    STATE(21008), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789078] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30427), 1,
      anon_sym_in,
    STATE(21009), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789092] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30429), 1,
      anon_sym_RPAREN,
    STATE(21010), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789106] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30431), 1,
      anon_sym_RBRACK,
    STATE(21011), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789120] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20039), 1,
      anon_sym_end,
    STATE(21012), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789134] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30433), 1,
      anon_sym_RPAREN,
    STATE(21013), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789148] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30435), 1,
      sym__lowercase_identifier,
    STATE(21014), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789162] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30437), 1,
      anon_sym_RPAREN,
    STATE(21015), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789176] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30439), 1,
      anon_sym_DOT_DOT,
    STATE(21016), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789190] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30441), 1,
      anon_sym_DOT_DOT,
    STATE(21017), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789204] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30443), 1,
      anon_sym_DOT_DOT,
    STATE(21018), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789218] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30445), 1,
      anon_sym_RBRACE,
    STATE(21019), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789232] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30447), 1,
      anon_sym_RBRACE,
    STATE(21020), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789246] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30449), 1,
      anon_sym_RPAREN,
    STATE(21021), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789260] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30451), 1,
      anon_sym_RPAREN,
    STATE(21022), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789274] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21285), 1,
      anon_sym_GT_RBRACE,
    STATE(21023), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789288] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30453), 1,
      anon_sym_RPAREN,
    STATE(21024), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789302] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30455), 1,
      anon_sym_RBRACK,
    STATE(21025), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789316] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30457), 1,
      anon_sym_RBRACE,
    STATE(21026), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789330] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30459), 1,
      anon_sym_DQUOTE,
    STATE(21027), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789344] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30461), 1,
      anon_sym_RPAREN,
    STATE(21028), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789358] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30463), 1,
      anon_sym_RPAREN,
    STATE(21029), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789372] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30465), 1,
      anon_sym_DOT_DOT,
    STATE(21030), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789386] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30467), 1,
      anon_sym_DOT_DOT,
    STATE(21031), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789400] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30469), 1,
      anon_sym_DOT_DOT,
    STATE(21032), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789414] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30463), 1,
      anon_sym_RBRACK,
    STATE(21033), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789428] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30471), 1,
      anon_sym_RPAREN,
    STATE(21034), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789442] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30463), 1,
      anon_sym_RBRACE,
    STATE(21035), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789456] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30473), 1,
      anon_sym_RPAREN,
    STATE(21036), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789470] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20228), 1,
      anon_sym_end,
    STATE(21037), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789484] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30475), 1,
      anon_sym_LT_DASH,
    STATE(21038), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789498] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5583), 1,
      anon_sym_end,
    STATE(21039), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789512] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30477), 1,
      anon_sym_SQUOTE2,
    STATE(21040), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789526] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30479), 1,
      anon_sym_RBRACE,
    STATE(21041), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789540] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30481), 1,
      anon_sym_DASH_GT,
    STATE(21042), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789554] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30483), 1,
      anon_sym_RPAREN,
    STATE(21043), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789568] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30485), 1,
      anon_sym_DOT_DOT,
    STATE(21044), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789582] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30487), 1,
      anon_sym_DOT_DOT,
    STATE(21045), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789596] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30489), 1,
      anon_sym_DOT_DOT,
    STATE(21046), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789610] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30491), 1,
      anon_sym_DQUOTE,
    STATE(21047), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789624] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30493), 1,
      anon_sym_COMMA,
    STATE(21048), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789638] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30495), 1,
      anon_sym_SQUOTE2,
    STATE(21049), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789652] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30497), 1,
      sym__lowercase_identifier,
    STATE(21050), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789666] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30499), 1,
      anon_sym_RPAREN,
    STATE(21051), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789680] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30501), 1,
      anon_sym_in,
    STATE(21052), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789694] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5253), 1,
      anon_sym_COLON_COLON,
    STATE(21053), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789708] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30503), 1,
      anon_sym_RPAREN,
    STATE(21054), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789722] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11441), 1,
      anon_sym_GT,
    STATE(21055), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789736] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30505), 1,
      anon_sym_COMMA,
    STATE(21056), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789750] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30507), 1,
      anon_sym_DASH_GT,
    STATE(21057), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789764] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30509), 1,
      anon_sym_DOT_DOT,
    STATE(21058), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789778] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30511), 1,
      anon_sym_DOT_DOT,
    STATE(21059), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789792] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30513), 1,
      anon_sym_DOT_DOT,
    STATE(21060), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789806] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30515), 1,
      anon_sym_in,
    STATE(21061), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789820] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30517), 1,
      anon_sym_RPAREN,
    STATE(21062), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789834] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30519), 1,
      anon_sym_RPAREN,
    STATE(21063), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789848] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30521), 1,
      anon_sym_DASH_GT,
    STATE(21064), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789862] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30523), 1,
      anon_sym_RBRACE,
    STATE(21065), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789876] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30525), 1,
      anon_sym_RBRACK,
    STATE(21066), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789890] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30527), 1,
      anon_sym_RPAREN,
    STATE(21067), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789904] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30529), 1,
      anon_sym_RPAREN,
    STATE(21068), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789918] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30531), 1,
      anon_sym_RBRACK,
    STATE(21069), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789932] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30533), 1,
      aux_sym_number_token1,
    STATE(21070), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789946] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30535), 1,
      anon_sym_with,
    STATE(21071), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789960] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30537), 1,
      anon_sym_DOT_DOT,
    STATE(21072), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789974] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30539), 1,
      anon_sym_DOT_DOT,
    STATE(21073), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [789988] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30541), 1,
      anon_sym_DOT_DOT,
    STATE(21074), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790002] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30543), 1,
      anon_sym_in,
    STATE(21075), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790016] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30545), 1,
      anon_sym_RBRACE,
    STATE(21076), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790030] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30547), 1,
      anon_sym_type,
    STATE(21077), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790044] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30549), 1,
      anon_sym_RPAREN,
    STATE(21078), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790058] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30551), 1,
      anon_sym_DOT,
    STATE(21079), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790072] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30553), 1,
      anon_sym_with,
    STATE(21080), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790086] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30555), 1,
      anon_sym_LT_DASH,
    STATE(21081), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790100] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18401), 1,
      anon_sym_GT,
    STATE(21082), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790114] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30557), 1,
      anon_sym_RPAREN,
    STATE(21083), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790128] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30559), 1,
      anon_sym_DOT_DOT,
    STATE(21084), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790142] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30561), 1,
      anon_sym_DOT_DOT,
    STATE(21085), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790156] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30563), 1,
      anon_sym_DOT_DOT,
    STATE(21086), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790170] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30565), 1,
      anon_sym_RBRACE,
    STATE(21087), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790184] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30567), 1,
      anon_sym_DOT,
    STATE(21088), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790198] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30569), 1,
      anon_sym_RBRACE,
    STATE(21089), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790212] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30571), 1,
      anon_sym_RBRACK,
    STATE(21090), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790226] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30573), 1,
      anon_sym_RBRACE,
    STATE(21091), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790240] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30575), 1,
      aux_sym_number_token1,
    STATE(21092), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790254] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30577), 1,
      anon_sym_RPAREN,
    STATE(21093), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790268] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30579), 1,
      anon_sym_RPAREN,
    STATE(21094), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790282] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30581), 1,
      anon_sym_in,
    STATE(21095), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790296] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30583), 1,
      anon_sym_DOT_DOT,
    STATE(21096), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790310] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30585), 1,
      anon_sym_DOT_DOT,
    STATE(21097), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790324] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30587), 1,
      anon_sym_DOT_DOT,
    STATE(21098), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790338] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30589), 1,
      anon_sym_RPAREN,
    STATE(21099), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790352] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30591), 1,
      anon_sym_DOT,
    STATE(21100), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790366] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30593), 1,
      anon_sym_DOT_DOT,
    STATE(21101), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790380] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30595), 1,
      anon_sym_DOT_DOT,
    STATE(21102), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790394] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30597), 1,
      anon_sym_DOT_DOT,
    STATE(21103), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790408] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30599), 1,
      anon_sym_RPAREN,
    STATE(21104), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790422] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30601), 1,
      anon_sym_RBRACK,
    STATE(21105), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790436] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30603), 1,
      anon_sym_DOT_DOT,
    STATE(21106), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790450] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30605), 1,
      anon_sym_DOT_DOT,
    STATE(21107), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790464] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30607), 1,
      anon_sym_DOT_DOT,
    STATE(21108), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790478] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30609), 1,
      anon_sym_RPAREN,
    STATE(21109), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790492] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30611), 1,
      anon_sym_RBRACE,
    STATE(21110), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790506] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30613), 1,
      anon_sym_DOT_DOT,
    STATE(21111), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790520] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30615), 1,
      anon_sym_DOT_DOT,
    STATE(21112), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790534] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30617), 1,
      anon_sym_DOT_DOT,
    STATE(21113), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790548] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(16112), 1,
      anon_sym_COMMA,
    STATE(21114), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790562] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30619), 1,
      anon_sym_LT_DASH,
    STATE(21115), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790576] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30621), 1,
      anon_sym_DOT_DOT,
    STATE(21116), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790590] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30623), 1,
      anon_sym_DOT_DOT,
    STATE(21117), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790604] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30625), 1,
      anon_sym_DOT_DOT,
    STATE(21118), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790618] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30627), 1,
      anon_sym_DASH_GT,
    STATE(21119), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790632] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30629), 1,
      anon_sym_RBRACE,
    STATE(21120), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790646] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30631), 1,
      anon_sym_DOT_DOT,
    STATE(21121), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790660] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30633), 1,
      anon_sym_DOT_DOT,
    STATE(21122), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790674] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30635), 1,
      anon_sym_DOT_DOT,
    STATE(21123), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790688] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30637), 1,
      anon_sym_RPAREN,
    STATE(21124), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790702] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30639), 1,
      anon_sym_end,
    STATE(21125), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790716] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30641), 1,
      anon_sym_DOT_DOT,
    STATE(21126), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790730] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30643), 1,
      anon_sym_DOT_DOT,
    STATE(21127), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790744] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30645), 1,
      anon_sym_DOT_DOT,
    STATE(21128), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790758] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30647), 1,
      anon_sym_RPAREN,
    STATE(21129), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790772] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30649), 1,
      anon_sym_DQUOTE,
    STATE(21130), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790786] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30651), 1,
      anon_sym_DOT_DOT,
    STATE(21131), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790800] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30653), 1,
      anon_sym_DOT_DOT,
    STATE(21132), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790814] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30655), 1,
      anon_sym_DOT_DOT,
    STATE(21133), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790828] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30657), 1,
      anon_sym_DOT,
    STATE(21134), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790842] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11832), 1,
      anon_sym_GT,
    STATE(21135), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790856] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30659), 1,
      anon_sym_DOT_DOT,
    STATE(21136), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790870] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30661), 1,
      anon_sym_DOT_DOT,
    STATE(21137), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790884] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30663), 1,
      anon_sym_DOT_DOT,
    STATE(21138), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790898] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3119), 1,
      anon_sym_RPAREN,
    STATE(21139), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790912] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30665), 1,
      anon_sym_DOT,
    STATE(21140), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790926] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30667), 1,
      anon_sym_DOT_DOT,
    STATE(21141), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790940] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30669), 1,
      anon_sym_DOT_DOT,
    STATE(21142), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790954] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30671), 1,
      anon_sym_DOT_DOT,
    STATE(21143), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790968] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30673), 1,
      anon_sym_RBRACK,
    STATE(21144), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790982] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30675), 1,
      anon_sym_RBRACE,
    STATE(21145), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [790996] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30677), 1,
      anon_sym_DOT_DOT,
    STATE(21146), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791010] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30679), 1,
      anon_sym_DOT_DOT,
    STATE(21147), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791024] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30681), 1,
      anon_sym_DOT_DOT,
    STATE(21148), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791038] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30683), 1,
      anon_sym_in,
    STATE(21149), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791052] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30685), 1,
      anon_sym_RPAREN,
    STATE(21150), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791066] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30687), 1,
      anon_sym_DOT_DOT,
    STATE(21151), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791080] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30689), 1,
      anon_sym_DOT_DOT,
    STATE(21152), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791094] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30691), 1,
      anon_sym_DOT_DOT,
    STATE(21153), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791108] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30693), 1,
      anon_sym_RPAREN,
    STATE(21154), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791122] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30695), 1,
      anon_sym_RBRACK,
    STATE(21155), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791136] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30697), 1,
      anon_sym_DOT_DOT,
    STATE(21156), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791150] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30699), 1,
      anon_sym_DOT_DOT,
    STATE(21157), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791164] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30701), 1,
      anon_sym_DOT_DOT,
    STATE(21158), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791178] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30703), 1,
      anon_sym_RBRACE,
    STATE(21159), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791192] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30705), 1,
      anon_sym_RPAREN,
    STATE(21160), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791206] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30707), 1,
      anon_sym_in,
    STATE(21161), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791220] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30709), 1,
      anon_sym_RPAREN,
    STATE(21162), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791234] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30711), 1,
      anon_sym_RBRACE,
    STATE(21163), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791248] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30713), 1,
      anon_sym_RPAREN,
    STATE(21164), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791262] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30715), 1,
      anon_sym_RPAREN,
    STATE(21165), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791276] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30717), 1,
      anon_sym_STAR,
    STATE(21166), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791290] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30719), 1,
      anon_sym_RPAREN,
    STATE(21167), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791304] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30721), 1,
      anon_sym_RPAREN,
    STATE(21168), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791318] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30723), 1,
      anon_sym_RBRACK,
    STATE(21169), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791332] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30725), 1,
      anon_sym_RPAREN,
    STATE(21170), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791346] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30727), 1,
      anon_sym_RBRACE,
    STATE(21171), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791360] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30729), 1,
      anon_sym_DQUOTE,
    STATE(21172), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791374] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30731), 1,
      anon_sym_RPAREN,
    STATE(21173), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791388] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30733), 1,
      anon_sym_with,
    STATE(21174), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791402] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30735), 1,
      anon_sym_RBRACK,
    STATE(21175), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791416] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30737), 1,
      anon_sym_RPAREN,
    STATE(21176), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791430] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30739), 1,
      anon_sym_RPAREN,
    STATE(21177), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791444] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30741), 1,
      anon_sym_RBRACK,
    STATE(21178), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791458] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30743), 1,
      anon_sym_RBRACE,
    STATE(21179), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791472] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30745), 1,
      anon_sym_RBRACE,
    STATE(21180), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791486] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30747), 1,
      anon_sym_RPAREN,
    STATE(21181), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791500] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30749), 1,
      sym__lowercase_identifier,
    STATE(21182), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791514] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30751), 1,
      anon_sym_RPAREN,
    STATE(21183), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791528] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30753), 1,
      anon_sym_RPAREN,
    STATE(21184), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791542] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30755), 1,
      anon_sym_RPAREN,
    STATE(21185), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791556] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30757), 1,
      anon_sym_DASH_GT,
    STATE(21186), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791570] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30759), 1,
      anon_sym_with,
    STATE(21187), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791584] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30761), 1,
      anon_sym_DOT,
    STATE(21188), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791598] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30763), 1,
      anon_sym_type,
    STATE(21189), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791612] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30765), 1,
      anon_sym_DASH_GT,
    STATE(21190), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791626] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30767), 1,
      sym_indexing_operator,
    STATE(21191), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791640] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30769), 1,
      anon_sym_PLUS_EQ,
    STATE(21192), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791654] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30771), 1,
      anon_sym_RPAREN,
    STATE(21193), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791668] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30773), 1,
      anon_sym_RPAREN,
    STATE(21194), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791682] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30775), 1,
      anon_sym_RPAREN,
    STATE(21195), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791696] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11237), 1,
      anon_sym_DASH_GT,
    STATE(21196), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791710] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30777), 1,
      anon_sym_DASH_GT,
    STATE(21197), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791724] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18337), 1,
      anon_sym_GT,
    STATE(21198), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791738] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30779), 1,
      anon_sym_in,
    STATE(21199), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791752] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(28367), 1,
      anon_sym_RBRACK,
    STATE(21200), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791766] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30781), 1,
      anon_sym_GT,
    STATE(21201), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791780] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30783), 1,
      anon_sym_in,
    STATE(21202), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791794] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30785), 1,
      anon_sym_in,
    STATE(21203), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791808] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30787), 1,
      anon_sym_RBRACE,
    STATE(21204), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791822] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30789), 1,
      anon_sym_in,
    STATE(21205), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791836] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30791), 1,
      anon_sym_DASH_GT,
    STATE(21206), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791850] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30793), 1,
      anon_sym_in,
    STATE(21207), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791864] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30795), 1,
      anon_sym_in,
    STATE(21208), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791878] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(11844), 1,
      anon_sym_GT,
    STATE(21209), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791892] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30797), 1,
      sym__lowercase_identifier,
    STATE(21210), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791906] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30799), 1,
      anon_sym_DASH_GT,
    STATE(21211), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791920] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30801), 1,
      anon_sym_RPAREN,
    STATE(21212), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791934] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30803), 1,
      anon_sym_RPAREN,
    STATE(21213), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791948] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30805), 1,
      sym__lowercase_identifier,
    STATE(21214), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791962] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12153), 1,
      anon_sym_COMMA,
    STATE(21215), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791976] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30807), 1,
      anon_sym_LT_DASH,
    STATE(21216), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [791990] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30809), 1,
      sym__lowercase_identifier,
    STATE(21217), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792004] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3149), 1,
      anon_sym_RPAREN,
    STATE(21218), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792018] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30811), 1,
      anon_sym_RPAREN,
    STATE(21219), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792032] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30813), 1,
      anon_sym_RPAREN,
    STATE(21220), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792046] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30815), 1,
      anon_sym_RPAREN,
    STATE(21221), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792060] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30817), 1,
      anon_sym_in,
    STATE(21222), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792074] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30819), 1,
      anon_sym_in,
    STATE(21223), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792088] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30821), 1,
      anon_sym_RPAREN,
    STATE(21224), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792102] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30823), 1,
      anon_sym_DASH_GT,
    STATE(21225), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792116] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30825), 1,
      sym_indexing_operator,
    STATE(21226), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792130] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30827), 1,
      anon_sym_in,
    STATE(21227), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792144] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(22903), 1,
      anon_sym_GT_RBRACE,
    STATE(21228), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792158] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30829), 1,
      anon_sym_RPAREN,
    STATE(21229), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792172] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30831), 1,
      anon_sym_DASH_GT,
    STATE(21230), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792186] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30833), 1,
      anon_sym_in,
    STATE(21231), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792200] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25947), 1,
      anon_sym_RBRACE,
    STATE(21232), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792214] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30835), 1,
      anon_sym_with,
    STATE(21233), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792228] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30837), 1,
      anon_sym_RPAREN,
    STATE(21234), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792242] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30839), 1,
      anon_sym_RBRACE,
    STATE(21235), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792256] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(25957), 1,
      anon_sym_RBRACE,
    STATE(21236), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792270] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21289), 1,
      anon_sym_GT_RBRACE,
    STATE(21237), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792284] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30841), 1,
      anon_sym_RPAREN,
    STATE(21238), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792298] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30843), 1,
      anon_sym_with,
    STATE(21239), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792312] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30845), 1,
      anon_sym_RPAREN,
    STATE(21240), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792326] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30847), 1,
      sym_indexing_operator,
    STATE(21241), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792340] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30849), 1,
      anon_sym_RBRACK,
    STATE(21242), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792354] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(15909), 1,
      anon_sym_COMMA,
    STATE(21243), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792368] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30851), 1,
      anon_sym_end,
    STATE(21244), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792382] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30853), 1,
      anon_sym_end,
    STATE(21245), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792396] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30855), 1,
      anon_sym_DOT,
    STATE(21246), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792410] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(1815), 1,
      anon_sym_RPAREN,
    STATE(21247), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792424] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30857), 1,
      anon_sym_RPAREN,
    STATE(21248), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792438] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21297), 1,
      anon_sym_GT_RBRACE,
    STATE(21249), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792452] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30859), 1,
      anon_sym_DASH_GT,
    STATE(21250), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792466] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30861), 1,
      anon_sym_LT_DASH,
    STATE(21251), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792480] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30863), 1,
      sym_indexing_operator,
    STATE(21252), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792494] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30865), 1,
      anon_sym_RPAREN,
    STATE(21253), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792508] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(23471), 1,
      anon_sym_GT_RBRACE,
    STATE(21254), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792522] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30867), 1,
      anon_sym_RPAREN,
    STATE(21255), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792536] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30869), 1,
      anon_sym_RPAREN,
    STATE(21256), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792550] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12355), 1,
      anon_sym_COMMA,
    STATE(21257), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792564] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30871), 1,
      anon_sym_LT_DASH,
    STATE(21258), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792578] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30873), 1,
      sym_indexing_operator,
    STATE(21259), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792592] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30875), 1,
      sym_indexing_operator,
    STATE(21260), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792606] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30877), 1,
      sym_indexing_operator,
    STATE(21261), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792620] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30879), 1,
      sym_indexing_operator,
    STATE(21262), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792634] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30881), 1,
      sym_indexing_operator,
    STATE(21263), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792648] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30883), 1,
      sym_indexing_operator,
    STATE(21264), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792662] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30885), 1,
      sym_indexing_operator,
    STATE(21265), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792676] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30887), 1,
      sym_indexing_operator,
    STATE(21266), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792690] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30889), 1,
      sym_indexing_operator,
    STATE(21267), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792704] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30891), 1,
      sym_indexing_operator,
    STATE(21268), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792718] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30893), 1,
      sym_indexing_operator,
    STATE(21269), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792732] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30895), 1,
      sym_indexing_operator,
    STATE(21270), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792746] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30897), 1,
      sym_indexing_operator,
    STATE(21271), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792760] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30899), 1,
      sym_indexing_operator,
    STATE(21272), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792774] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30901), 1,
      sym_indexing_operator,
    STATE(21273), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792788] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30903), 1,
      sym_indexing_operator,
    STATE(21274), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792802] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30905), 1,
      sym_indexing_operator,
    STATE(21275), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792816] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30907), 1,
      sym_indexing_operator,
    STATE(21276), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792830] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30909), 1,
      sym_indexing_operator,
    STATE(21277), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792844] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30911), 1,
      sym_indexing_operator,
    STATE(21278), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792858] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30913), 1,
      sym_indexing_operator,
    STATE(21279), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792872] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30915), 1,
      sym_indexing_operator,
    STATE(21280), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792886] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30917), 1,
      sym_indexing_operator,
    STATE(21281), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792900] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30919), 1,
      sym_indexing_operator,
    STATE(21282), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792914] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30921), 1,
      sym_indexing_operator,
    STATE(21283), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792928] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30923), 1,
      sym_indexing_operator,
    STATE(21284), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792942] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30925), 1,
      sym_indexing_operator,
    STATE(21285), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792956] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30927), 1,
      sym_indexing_operator,
    STATE(21286), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792970] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30929), 1,
      sym_indexing_operator,
    STATE(21287), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792984] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30931), 1,
      sym_indexing_operator,
    STATE(21288), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [792998] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30933), 1,
      sym_indexing_operator,
    STATE(21289), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793012] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30935), 1,
      sym_indexing_operator,
    STATE(21290), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793026] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30937), 1,
      sym_indexing_operator,
    STATE(21291), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793040] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30939), 1,
      sym_indexing_operator,
    STATE(21292), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793054] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30941), 1,
      sym_indexing_operator,
    STATE(21293), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793068] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30943), 1,
      sym_indexing_operator,
    STATE(21294), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793082] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30945), 1,
      sym_indexing_operator,
    STATE(21295), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793096] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30947), 1,
      sym_indexing_operator,
    STATE(21296), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793110] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30949), 1,
      sym_indexing_operator,
    STATE(21297), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793124] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30951), 1,
      sym_indexing_operator,
    STATE(21298), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793138] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30953), 1,
      sym_indexing_operator,
    STATE(21299), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793152] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30955), 1,
      sym_indexing_operator,
    STATE(21300), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793166] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30957), 1,
      sym_indexing_operator,
    STATE(21301), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793180] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30959), 1,
      sym_indexing_operator,
    STATE(21302), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793194] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30961), 1,
      sym_indexing_operator,
    STATE(21303), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793208] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30963), 1,
      sym_indexing_operator,
    STATE(21304), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793222] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30965), 1,
      sym_indexing_operator,
    STATE(21305), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793236] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30967), 1,
      sym_indexing_operator,
    STATE(21306), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793250] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30969), 1,
      sym_indexing_operator,
    STATE(21307), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793264] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30971), 1,
      sym_indexing_operator,
    STATE(21308), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793278] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30973), 1,
      sym_indexing_operator,
    STATE(21309), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793292] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21106), 1,
      anon_sym_end,
    STATE(21310), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793306] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3153), 1,
      anon_sym_RPAREN,
    STATE(21311), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793320] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30975), 1,
      sym__lowercase_identifier,
    STATE(21312), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793334] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(18317), 1,
      anon_sym_GT,
    STATE(21313), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793348] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30977), 1,
      anon_sym_SQUOTE2,
    STATE(21314), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793362] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30979), 1,
      anon_sym_RPAREN,
    STATE(21315), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793376] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30981), 1,
      anon_sym_DQUOTE,
    STATE(21316), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793390] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30983), 1,
      anon_sym_EQ,
    STATE(21317), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793404] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19127), 1,
      anon_sym_DASH_GT,
    STATE(21318), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793418] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30985), 1,
      anon_sym_RBRACE,
    STATE(21319), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793432] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30987), 1,
      anon_sym_RPAREN,
    STATE(21320), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793446] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(17230), 1,
      anon_sym_DASH_GT,
    STATE(21321), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793460] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30989), 1,
      anon_sym_EQ,
    STATE(21322), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793474] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30991), 1,
      anon_sym_DASH_GT,
    STATE(21323), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793488] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30993), 1,
      anon_sym_RPAREN,
    STATE(21324), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793502] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(20019), 1,
      anon_sym_end,
    STATE(21325), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793516] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30995), 1,
      anon_sym_RPAREN,
    STATE(21326), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793530] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30995), 1,
      anon_sym_RBRACK,
    STATE(21327), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793544] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30995), 1,
      anon_sym_RBRACE,
    STATE(21328), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793558] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30997), 1,
      sym__lowercase_identifier,
    STATE(21329), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793572] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(30999), 1,
      anon_sym_SQUOTE2,
    STATE(21330), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793586] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31001), 1,
      anon_sym_DQUOTE,
    STATE(21331), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793600] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(5543), 1,
      anon_sym_end,
    STATE(21332), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793614] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31003), 1,
      aux_sym_number_token1,
    STATE(21333), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793628] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31005), 1,
      anon_sym_RBRACK,
    STATE(21334), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793642] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31007), 1,
      anon_sym_RBRACE,
    STATE(21335), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793656] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31009), 1,
      anon_sym_RBRACE,
    STATE(21336), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793670] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31011), 1,
      anon_sym_in,
    STATE(21337), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793684] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31013), 1,
      anon_sym_EQ,
    STATE(21338), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793698] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31015), 1,
      anon_sym_in,
    STATE(21339), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793712] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31017), 1,
      anon_sym_EQ,
    STATE(21340), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793726] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31019), 1,
      anon_sym_EQ,
    STATE(21341), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793740] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31021), 1,
      anon_sym_EQ,
    STATE(21342), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793754] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31023), 1,
      anon_sym_in,
    STATE(21343), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793768] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31025), 1,
      anon_sym_DASH_GT,
    STATE(21344), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793782] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31027), 1,
      anon_sym_GT,
    STATE(21345), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793796] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31029), 1,
      anon_sym_DASH_GT,
    STATE(21346), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793810] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31031), 1,
      anon_sym_RPAREN,
    STATE(21347), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793824] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31033), 1,
      sym__lowercase_identifier,
    STATE(21348), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793838] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(19991), 1,
      anon_sym_end,
    STATE(21349), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793852] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31035), 1,
      anon_sym_RPAREN,
    STATE(21350), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793866] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31037), 1,
      sym__lowercase_identifier,
    STATE(21351), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793880] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31039), 1,
      anon_sym_RPAREN,
    STATE(21352), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793894] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31041), 1,
      anon_sym_RPAREN,
    STATE(21353), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793908] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31043), 1,
      anon_sym_RPAREN,
    STATE(21354), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793922] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3127), 1,
      anon_sym_RPAREN,
    STATE(21355), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793936] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31045), 1,
      anon_sym_in,
    STATE(21356), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793950] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31047), 1,
      anon_sym_RPAREN,
    STATE(21357), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793964] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31049), 1,
      anon_sym_DASH_GT,
    STATE(21358), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793978] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31051), 1,
      anon_sym_RBRACK,
    STATE(21359), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [793992] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31053), 1,
      anon_sym_end,
    STATE(21360), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794006] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(9022), 1,
      anon_sym_DASH_GT,
    STATE(21361), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794020] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31055), 1,
      anon_sym_end,
    STATE(21362), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794034] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31057), 1,
      anon_sym_DASH_GT,
    STATE(21363), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794048] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31059), 1,
      anon_sym_in,
    STATE(21364), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794062] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31061), 1,
      anon_sym_RBRACE,
    STATE(21365), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794076] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31063), 1,
      anon_sym_EQ,
    STATE(21366), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794090] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31065), 1,
      anon_sym_RPAREN,
    STATE(21367), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794104] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31067), 1,
      anon_sym_RPAREN,
    STATE(21368), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794118] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    STATE(21369), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794132] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(14037), 1,
      anon_sym_DASH_GT,
    STATE(21370), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794146] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31069), 1,
      anon_sym_LT_DASH,
    STATE(21371), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794160] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31071), 1,
      anon_sym_RPAREN,
    STATE(21372), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794174] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31071), 1,
      anon_sym_RBRACK,
    STATE(21373), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794188] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31073), 1,
      anon_sym_GT,
    STATE(21374), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794202] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31071), 1,
      anon_sym_RBRACE,
    STATE(21375), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794216] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(3109), 1,
      anon_sym_RPAREN,
    STATE(21376), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794230] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31075), 1,
      anon_sym_RBRACE,
    STATE(21377), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794244] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31077), 1,
      anon_sym_RPAREN,
    STATE(21378), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794258] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31079), 1,
      anon_sym_SQUOTE2,
    STATE(21379), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794272] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4893), 1,
      anon_sym_end,
    STATE(21380), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794286] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31081), 1,
      anon_sym_RPAREN,
    STATE(21381), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794300] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31083), 1,
      anon_sym_end,
    STATE(21382), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794314] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31085), 1,
      anon_sym_in,
    STATE(21383), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794328] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31087), 1,
      anon_sym_RBRACE,
    STATE(21384), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794342] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31089), 1,
      anon_sym_RBRACE,
    STATE(21385), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794356] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31091), 1,
      anon_sym_RPAREN,
    STATE(21386), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794370] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(21353), 1,
      anon_sym_GT_RBRACE,
    STATE(21387), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794384] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31093), 1,
      anon_sym_RBRACE,
    STATE(21388), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794398] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31095), 1,
      anon_sym_in,
    STATE(21389), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794412] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31097), 1,
      anon_sym_in,
    STATE(21390), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794426] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31099), 1,
      anon_sym_RPAREN,
    STATE(21391), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794440] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31101), 1,
      anon_sym_in,
    STATE(21392), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794454] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31103), 1,
      sym__lowercase_identifier,
    STATE(21393), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794468] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31105), 1,
      anon_sym_RPAREN,
    STATE(21394), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794482] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31107), 1,
      anon_sym_RPAREN,
    STATE(21395), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794496] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31109), 1,
      anon_sym_RPAREN,
    STATE(21396), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794510] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31111), 1,
      anon_sym_in,
    STATE(21397), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794524] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31113), 1,
      aux_sym_number_token1,
    STATE(21398), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794538] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31115), 1,
      anon_sym_RPAREN,
    STATE(21399), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794552] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31117), 1,
      anon_sym_RPAREN,
    STATE(21400), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794566] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31119), 1,
      anon_sym_in,
    STATE(21401), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794580] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31121), 1,
      anon_sym_DASH_GT,
    STATE(21402), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794594] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31123), 1,
      anon_sym_RPAREN,
    STATE(21403), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794608] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31125), 1,
      anon_sym_in,
    STATE(21404), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794622] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(4873), 1,
      anon_sym_end,
    STATE(21405), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794636] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31127), 1,
      anon_sym_RPAREN,
    STATE(21406), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794650] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31129), 1,
      anon_sym_in,
    STATE(21407), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794664] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31131), 1,
      anon_sym_RBRACK,
    STATE(21408), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794678] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31133), 1,
      anon_sym_RBRACE,
    STATE(21409), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794692] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31135), 1,
      anon_sym_RPAREN,
    STATE(21410), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794706] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31137), 1,
      anon_sym_with,
    STATE(21411), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794720] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31139), 1,
      anon_sym_RBRACK,
    STATE(21412), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794734] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31141), 1,
      anon_sym_DASH_GT,
    STATE(21413), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794748] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31143), 1,
      anon_sym_in,
    STATE(21414), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794762] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31145), 1,
      anon_sym_DQUOTE,
    STATE(21415), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794776] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31147), 1,
      anon_sym_DASH_GT,
    STATE(21416), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794790] = 4,
    ACTIONS(1097), 1,
      aux_sym_attribute_token1,
    ACTIONS(31149), 1,
      anon_sym_DASH_GT,
    STATE(21417), 1,
      sym_attribute,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_number_directive,
  [794804] = 1,
    ACTIONS(31151), 1,
      ts_builtin_sym_end,
  [794808] = 1,
    ACTIONS(31153), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(3112)] = 0,
  [SMALL_STATE(3113)] = 139,
  [SMALL_STATE(3114)] = 278,
  [SMALL_STATE(3115)] = 355,
  [SMALL_STATE(3116)] = 432,
  [SMALL_STATE(3117)] = 571,
  [SMALL_STATE(3118)] = 710,
  [SMALL_STATE(3119)] = 849,
  [SMALL_STATE(3120)] = 988,
  [SMALL_STATE(3121)] = 1127,
  [SMALL_STATE(3122)] = 1266,
  [SMALL_STATE(3123)] = 1405,
  [SMALL_STATE(3124)] = 1482,
  [SMALL_STATE(3125)] = 1621,
  [SMALL_STATE(3126)] = 1760,
  [SMALL_STATE(3127)] = 1899,
  [SMALL_STATE(3128)] = 2038,
  [SMALL_STATE(3129)] = 2177,
  [SMALL_STATE(3130)] = 2316,
  [SMALL_STATE(3131)] = 2393,
  [SMALL_STATE(3132)] = 2468,
  [SMALL_STATE(3133)] = 2543,
  [SMALL_STATE(3134)] = 2618,
  [SMALL_STATE(3135)] = 2693,
  [SMALL_STATE(3136)] = 2768,
  [SMALL_STATE(3137)] = 2843,
  [SMALL_STATE(3138)] = 2918,
  [SMALL_STATE(3139)] = 3057,
  [SMALL_STATE(3140)] = 3132,
  [SMALL_STATE(3141)] = 3207,
  [SMALL_STATE(3142)] = 3346,
  [SMALL_STATE(3143)] = 3421,
  [SMALL_STATE(3144)] = 3560,
  [SMALL_STATE(3145)] = 3699,
  [SMALL_STATE(3146)] = 3774,
  [SMALL_STATE(3147)] = 3849,
  [SMALL_STATE(3148)] = 3924,
  [SMALL_STATE(3149)] = 3999,
  [SMALL_STATE(3150)] = 4074,
  [SMALL_STATE(3151)] = 4149,
  [SMALL_STATE(3152)] = 4288,
  [SMALL_STATE(3153)] = 4427,
  [SMALL_STATE(3154)] = 4566,
  [SMALL_STATE(3155)] = 4705,
  [SMALL_STATE(3156)] = 4844,
  [SMALL_STATE(3157)] = 4919,
  [SMALL_STATE(3158)] = 4994,
  [SMALL_STATE(3159)] = 5133,
  [SMALL_STATE(3160)] = 5272,
  [SMALL_STATE(3161)] = 5395,
  [SMALL_STATE(3162)] = 5534,
  [SMALL_STATE(3163)] = 5673,
  [SMALL_STATE(3164)] = 5812,
  [SMALL_STATE(3165)] = 5951,
  [SMALL_STATE(3166)] = 6090,
  [SMALL_STATE(3167)] = 6229,
  [SMALL_STATE(3168)] = 6368,
  [SMALL_STATE(3169)] = 6507,
  [SMALL_STATE(3170)] = 6646,
  [SMALL_STATE(3171)] = 6785,
  [SMALL_STATE(3172)] = 6924,
  [SMALL_STATE(3173)] = 7063,
  [SMALL_STATE(3174)] = 7202,
  [SMALL_STATE(3175)] = 7341,
  [SMALL_STATE(3176)] = 7480,
  [SMALL_STATE(3177)] = 7619,
  [SMALL_STATE(3178)] = 7758,
  [SMALL_STATE(3179)] = 7897,
  [SMALL_STATE(3180)] = 8036,
  [SMALL_STATE(3181)] = 8175,
  [SMALL_STATE(3182)] = 8314,
  [SMALL_STATE(3183)] = 8453,
  [SMALL_STATE(3184)] = 8592,
  [SMALL_STATE(3185)] = 8731,
  [SMALL_STATE(3186)] = 8870,
  [SMALL_STATE(3187)] = 9009,
  [SMALL_STATE(3188)] = 9148,
  [SMALL_STATE(3189)] = 9287,
  [SMALL_STATE(3190)] = 9426,
  [SMALL_STATE(3191)] = 9565,
  [SMALL_STATE(3192)] = 9704,
  [SMALL_STATE(3193)] = 9843,
  [SMALL_STATE(3194)] = 9982,
  [SMALL_STATE(3195)] = 10121,
  [SMALL_STATE(3196)] = 10260,
  [SMALL_STATE(3197)] = 10399,
  [SMALL_STATE(3198)] = 10538,
  [SMALL_STATE(3199)] = 10677,
  [SMALL_STATE(3200)] = 10816,
  [SMALL_STATE(3201)] = 10955,
  [SMALL_STATE(3202)] = 11094,
  [SMALL_STATE(3203)] = 11233,
  [SMALL_STATE(3204)] = 11372,
  [SMALL_STATE(3205)] = 11511,
  [SMALL_STATE(3206)] = 11650,
  [SMALL_STATE(3207)] = 11789,
  [SMALL_STATE(3208)] = 11928,
  [SMALL_STATE(3209)] = 12067,
  [SMALL_STATE(3210)] = 12206,
  [SMALL_STATE(3211)] = 12345,
  [SMALL_STATE(3212)] = 12484,
  [SMALL_STATE(3213)] = 12623,
  [SMALL_STATE(3214)] = 12762,
  [SMALL_STATE(3215)] = 12901,
  [SMALL_STATE(3216)] = 13040,
  [SMALL_STATE(3217)] = 13179,
  [SMALL_STATE(3218)] = 13318,
  [SMALL_STATE(3219)] = 13457,
  [SMALL_STATE(3220)] = 13596,
  [SMALL_STATE(3221)] = 13735,
  [SMALL_STATE(3222)] = 13874,
  [SMALL_STATE(3223)] = 14013,
  [SMALL_STATE(3224)] = 14152,
  [SMALL_STATE(3225)] = 14291,
  [SMALL_STATE(3226)] = 14430,
  [SMALL_STATE(3227)] = 14569,
  [SMALL_STATE(3228)] = 14708,
  [SMALL_STATE(3229)] = 14847,
  [SMALL_STATE(3230)] = 14986,
  [SMALL_STATE(3231)] = 15125,
  [SMALL_STATE(3232)] = 15264,
  [SMALL_STATE(3233)] = 15403,
  [SMALL_STATE(3234)] = 15542,
  [SMALL_STATE(3235)] = 15681,
  [SMALL_STATE(3236)] = 15820,
  [SMALL_STATE(3237)] = 15959,
  [SMALL_STATE(3238)] = 16098,
  [SMALL_STATE(3239)] = 16237,
  [SMALL_STATE(3240)] = 16376,
  [SMALL_STATE(3241)] = 16515,
  [SMALL_STATE(3242)] = 16654,
  [SMALL_STATE(3243)] = 16793,
  [SMALL_STATE(3244)] = 16932,
  [SMALL_STATE(3245)] = 17071,
  [SMALL_STATE(3246)] = 17210,
  [SMALL_STATE(3247)] = 17349,
  [SMALL_STATE(3248)] = 17488,
  [SMALL_STATE(3249)] = 17562,
  [SMALL_STATE(3250)] = 17692,
  [SMALL_STATE(3251)] = 17766,
  [SMALL_STATE(3252)] = 17840,
  [SMALL_STATE(3253)] = 17914,
  [SMALL_STATE(3254)] = 17988,
  [SMALL_STATE(3255)] = 18062,
  [SMALL_STATE(3256)] = 18136,
  [SMALL_STATE(3257)] = 18210,
  [SMALL_STATE(3258)] = 18284,
  [SMALL_STATE(3259)] = 18358,
  [SMALL_STATE(3260)] = 18432,
  [SMALL_STATE(3261)] = 18506,
  [SMALL_STATE(3262)] = 18586,
  [SMALL_STATE(3263)] = 18660,
  [SMALL_STATE(3264)] = 18734,
  [SMALL_STATE(3265)] = 18808,
  [SMALL_STATE(3266)] = 18882,
  [SMALL_STATE(3267)] = 18956,
  [SMALL_STATE(3268)] = 19030,
  [SMALL_STATE(3269)] = 19104,
  [SMALL_STATE(3270)] = 19180,
  [SMALL_STATE(3271)] = 19254,
  [SMALL_STATE(3272)] = 19328,
  [SMALL_STATE(3273)] = 19402,
  [SMALL_STATE(3274)] = 19476,
  [SMALL_STATE(3275)] = 19550,
  [SMALL_STATE(3276)] = 19624,
  [SMALL_STATE(3277)] = 19698,
  [SMALL_STATE(3278)] = 19772,
  [SMALL_STATE(3279)] = 19846,
  [SMALL_STATE(3280)] = 19920,
  [SMALL_STATE(3281)] = 19994,
  [SMALL_STATE(3282)] = 20068,
  [SMALL_STATE(3283)] = 20142,
  [SMALL_STATE(3284)] = 20216,
  [SMALL_STATE(3285)] = 20290,
  [SMALL_STATE(3286)] = 20364,
  [SMALL_STATE(3287)] = 20438,
  [SMALL_STATE(3288)] = 20512,
  [SMALL_STATE(3289)] = 20586,
  [SMALL_STATE(3290)] = 20660,
  [SMALL_STATE(3291)] = 20740,
  [SMALL_STATE(3292)] = 20814,
  [SMALL_STATE(3293)] = 20888,
  [SMALL_STATE(3294)] = 20962,
  [SMALL_STATE(3295)] = 21036,
  [SMALL_STATE(3296)] = 21110,
  [SMALL_STATE(3297)] = 21184,
  [SMALL_STATE(3298)] = 21258,
  [SMALL_STATE(3299)] = 21332,
  [SMALL_STATE(3300)] = 21406,
  [SMALL_STATE(3301)] = 21480,
  [SMALL_STATE(3302)] = 21554,
  [SMALL_STATE(3303)] = 21628,
  [SMALL_STATE(3304)] = 21702,
  [SMALL_STATE(3305)] = 21776,
  [SMALL_STATE(3306)] = 21850,
  [SMALL_STATE(3307)] = 21924,
  [SMALL_STATE(3308)] = 21998,
  [SMALL_STATE(3309)] = 22072,
  [SMALL_STATE(3310)] = 22146,
  [SMALL_STATE(3311)] = 22220,
  [SMALL_STATE(3312)] = 22294,
  [SMALL_STATE(3313)] = 22368,
  [SMALL_STATE(3314)] = 22442,
  [SMALL_STATE(3315)] = 22516,
  [SMALL_STATE(3316)] = 22646,
  [SMALL_STATE(3317)] = 22720,
  [SMALL_STATE(3318)] = 22794,
  [SMALL_STATE(3319)] = 22868,
  [SMALL_STATE(3320)] = 23016,
  [SMALL_STATE(3321)] = 23096,
  [SMALL_STATE(3322)] = 23170,
  [SMALL_STATE(3323)] = 23244,
  [SMALL_STATE(3324)] = 23318,
  [SMALL_STATE(3325)] = 23392,
  [SMALL_STATE(3326)] = 23466,
  [SMALL_STATE(3327)] = 23540,
  [SMALL_STATE(3328)] = 23614,
  [SMALL_STATE(3329)] = 23690,
  [SMALL_STATE(3330)] = 23764,
  [SMALL_STATE(3331)] = 23838,
  [SMALL_STATE(3332)] = 23912,
  [SMALL_STATE(3333)] = 23986,
  [SMALL_STATE(3334)] = 24116,
  [SMALL_STATE(3335)] = 24190,
  [SMALL_STATE(3336)] = 24264,
  [SMALL_STATE(3337)] = 24338,
  [SMALL_STATE(3338)] = 24412,
  [SMALL_STATE(3339)] = 24486,
  [SMALL_STATE(3340)] = 24560,
  [SMALL_STATE(3341)] = 24634,
  [SMALL_STATE(3342)] = 24708,
  [SMALL_STATE(3343)] = 24782,
  [SMALL_STATE(3344)] = 24856,
  [SMALL_STATE(3345)] = 24986,
  [SMALL_STATE(3346)] = 25060,
  [SMALL_STATE(3347)] = 25134,
  [SMALL_STATE(3348)] = 25210,
  [SMALL_STATE(3349)] = 25284,
  [SMALL_STATE(3350)] = 25360,
  [SMALL_STATE(3351)] = 25440,
  [SMALL_STATE(3352)] = 25514,
  [SMALL_STATE(3353)] = 25588,
  [SMALL_STATE(3354)] = 25662,
  [SMALL_STATE(3355)] = 25736,
  [SMALL_STATE(3356)] = 25866,
  [SMALL_STATE(3357)] = 25940,
  [SMALL_STATE(3358)] = 26014,
  [SMALL_STATE(3359)] = 26088,
  [SMALL_STATE(3360)] = 26162,
  [SMALL_STATE(3361)] = 26236,
  [SMALL_STATE(3362)] = 26366,
  [SMALL_STATE(3363)] = 26440,
  [SMALL_STATE(3364)] = 26514,
  [SMALL_STATE(3365)] = 26588,
  [SMALL_STATE(3366)] = 26718,
  [SMALL_STATE(3367)] = 26792,
  [SMALL_STATE(3368)] = 26866,
  [SMALL_STATE(3369)] = 26996,
  [SMALL_STATE(3370)] = 27070,
  [SMALL_STATE(3371)] = 27200,
  [SMALL_STATE(3372)] = 27274,
  [SMALL_STATE(3373)] = 27404,
  [SMALL_STATE(3374)] = 27478,
  [SMALL_STATE(3375)] = 27552,
  [SMALL_STATE(3376)] = 27682,
  [SMALL_STATE(3377)] = 27756,
  [SMALL_STATE(3378)] = 27830,
  [SMALL_STATE(3379)] = 27960,
  [SMALL_STATE(3380)] = 28090,
  [SMALL_STATE(3381)] = 28164,
  [SMALL_STATE(3382)] = 28294,
  [SMALL_STATE(3383)] = 28424,
  [SMALL_STATE(3384)] = 28498,
  [SMALL_STATE(3385)] = 28572,
  [SMALL_STATE(3386)] = 28646,
  [SMALL_STATE(3387)] = 28776,
  [SMALL_STATE(3388)] = 28850,
  [SMALL_STATE(3389)] = 28924,
  [SMALL_STATE(3390)] = 28998,
  [SMALL_STATE(3391)] = 29072,
  [SMALL_STATE(3392)] = 29146,
  [SMALL_STATE(3393)] = 29220,
  [SMALL_STATE(3394)] = 29350,
  [SMALL_STATE(3395)] = 29424,
  [SMALL_STATE(3396)] = 29498,
  [SMALL_STATE(3397)] = 29572,
  [SMALL_STATE(3398)] = 29702,
  [SMALL_STATE(3399)] = 29776,
  [SMALL_STATE(3400)] = 29850,
  [SMALL_STATE(3401)] = 29980,
  [SMALL_STATE(3402)] = 30110,
  [SMALL_STATE(3403)] = 30184,
  [SMALL_STATE(3404)] = 30314,
  [SMALL_STATE(3405)] = 30388,
  [SMALL_STATE(3406)] = 30518,
  [SMALL_STATE(3407)] = 30648,
  [SMALL_STATE(3408)] = 30778,
  [SMALL_STATE(3409)] = 30908,
  [SMALL_STATE(3410)] = 31038,
  [SMALL_STATE(3411)] = 31112,
  [SMALL_STATE(3412)] = 31242,
  [SMALL_STATE(3413)] = 31318,
  [SMALL_STATE(3414)] = 31392,
  [SMALL_STATE(3415)] = 31466,
  [SMALL_STATE(3416)] = 31540,
  [SMALL_STATE(3417)] = 31670,
  [SMALL_STATE(3418)] = 31744,
  [SMALL_STATE(3419)] = 31818,
  [SMALL_STATE(3420)] = 31948,
  [SMALL_STATE(3421)] = 32022,
  [SMALL_STATE(3422)] = 32096,
  [SMALL_STATE(3423)] = 32226,
  [SMALL_STATE(3424)] = 32356,
  [SMALL_STATE(3425)] = 32486,
  [SMALL_STATE(3426)] = 32560,
  [SMALL_STATE(3427)] = 32690,
  [SMALL_STATE(3428)] = 32764,
  [SMALL_STATE(3429)] = 32838,
  [SMALL_STATE(3430)] = 32912,
  [SMALL_STATE(3431)] = 33042,
  [SMALL_STATE(3432)] = 33116,
  [SMALL_STATE(3433)] = 33190,
  [SMALL_STATE(3434)] = 33264,
  [SMALL_STATE(3435)] = 33394,
  [SMALL_STATE(3436)] = 33524,
  [SMALL_STATE(3437)] = 33598,
  [SMALL_STATE(3438)] = 33728,
  [SMALL_STATE(3439)] = 33858,
  [SMALL_STATE(3440)] = 33932,
  [SMALL_STATE(3441)] = 34006,
  [SMALL_STATE(3442)] = 34136,
  [SMALL_STATE(3443)] = 34210,
  [SMALL_STATE(3444)] = 34340,
  [SMALL_STATE(3445)] = 34470,
  [SMALL_STATE(3446)] = 34600,
  [SMALL_STATE(3447)] = 34674,
  [SMALL_STATE(3448)] = 34748,
  [SMALL_STATE(3449)] = 34822,
  [SMALL_STATE(3450)] = 34952,
  [SMALL_STATE(3451)] = 35026,
  [SMALL_STATE(3452)] = 35100,
  [SMALL_STATE(3453)] = 35174,
  [SMALL_STATE(3454)] = 35248,
  [SMALL_STATE(3455)] = 35322,
  [SMALL_STATE(3456)] = 35396,
  [SMALL_STATE(3457)] = 35470,
  [SMALL_STATE(3458)] = 35544,
  [SMALL_STATE(3459)] = 35618,
  [SMALL_STATE(3460)] = 35692,
  [SMALL_STATE(3461)] = 35766,
  [SMALL_STATE(3462)] = 35842,
  [SMALL_STATE(3463)] = 35916,
  [SMALL_STATE(3464)] = 35990,
  [SMALL_STATE(3465)] = 36064,
  [SMALL_STATE(3466)] = 36212,
  [SMALL_STATE(3467)] = 36286,
  [SMALL_STATE(3468)] = 36360,
  [SMALL_STATE(3469)] = 36434,
  [SMALL_STATE(3470)] = 36508,
  [SMALL_STATE(3471)] = 36582,
  [SMALL_STATE(3472)] = 36658,
  [SMALL_STATE(3473)] = 36732,
  [SMALL_STATE(3474)] = 36806,
  [SMALL_STATE(3475)] = 36882,
  [SMALL_STATE(3476)] = 36956,
  [SMALL_STATE(3477)] = 37030,
  [SMALL_STATE(3478)] = 37104,
  [SMALL_STATE(3479)] = 37178,
  [SMALL_STATE(3480)] = 37252,
  [SMALL_STATE(3481)] = 37326,
  [SMALL_STATE(3482)] = 37400,
  [SMALL_STATE(3483)] = 37474,
  [SMALL_STATE(3484)] = 37548,
  [SMALL_STATE(3485)] = 37624,
  [SMALL_STATE(3486)] = 37700,
  [SMALL_STATE(3487)] = 37776,
  [SMALL_STATE(3488)] = 37852,
  [SMALL_STATE(3489)] = 37928,
  [SMALL_STATE(3490)] = 38004,
  [SMALL_STATE(3491)] = 38078,
  [SMALL_STATE(3492)] = 38152,
  [SMALL_STATE(3493)] = 38226,
  [SMALL_STATE(3494)] = 38299,
  [SMALL_STATE(3495)] = 38372,
  [SMALL_STATE(3496)] = 38445,
  [SMALL_STATE(3497)] = 38518,
  [SMALL_STATE(3498)] = 38591,
  [SMALL_STATE(3499)] = 38664,
  [SMALL_STATE(3500)] = 38743,
  [SMALL_STATE(3501)] = 38816,
  [SMALL_STATE(3502)] = 38889,
  [SMALL_STATE(3503)] = 38962,
  [SMALL_STATE(3504)] = 39035,
  [SMALL_STATE(3505)] = 39108,
  [SMALL_STATE(3506)] = 39181,
  [SMALL_STATE(3507)] = 39254,
  [SMALL_STATE(3508)] = 39327,
  [SMALL_STATE(3509)] = 39400,
  [SMALL_STATE(3510)] = 39473,
  [SMALL_STATE(3511)] = 39546,
  [SMALL_STATE(3512)] = 39619,
  [SMALL_STATE(3513)] = 39692,
  [SMALL_STATE(3514)] = 39765,
  [SMALL_STATE(3515)] = 39838,
  [SMALL_STATE(3516)] = 39917,
  [SMALL_STATE(3517)] = 39990,
  [SMALL_STATE(3518)] = 40063,
  [SMALL_STATE(3519)] = 40138,
  [SMALL_STATE(3520)] = 40211,
  [SMALL_STATE(3521)] = 40286,
  [SMALL_STATE(3522)] = 40359,
  [SMALL_STATE(3523)] = 40432,
  [SMALL_STATE(3524)] = 40505,
  [SMALL_STATE(3525)] = 40578,
  [SMALL_STATE(3526)] = 40651,
  [SMALL_STATE(3527)] = 40724,
  [SMALL_STATE(3528)] = 40797,
  [SMALL_STATE(3529)] = 40870,
  [SMALL_STATE(3530)] = 40943,
  [SMALL_STATE(3531)] = 41016,
  [SMALL_STATE(3532)] = 41095,
  [SMALL_STATE(3533)] = 41168,
  [SMALL_STATE(3534)] = 41241,
  [SMALL_STATE(3535)] = 41314,
  [SMALL_STATE(3536)] = 41387,
  [SMALL_STATE(3537)] = 41460,
  [SMALL_STATE(3538)] = 41533,
  [SMALL_STATE(3539)] = 41606,
  [SMALL_STATE(3540)] = 41679,
  [SMALL_STATE(3541)] = 41752,
  [SMALL_STATE(3542)] = 41825,
  [SMALL_STATE(3543)] = 41900,
  [SMALL_STATE(3544)] = 41973,
  [SMALL_STATE(3545)] = 42046,
  [SMALL_STATE(3546)] = 42119,
  [SMALL_STATE(3547)] = 42192,
  [SMALL_STATE(3548)] = 42265,
  [SMALL_STATE(3549)] = 42338,
  [SMALL_STATE(3550)] = 42411,
  [SMALL_STATE(3551)] = 42484,
  [SMALL_STATE(3552)] = 42557,
  [SMALL_STATE(3553)] = 42630,
  [SMALL_STATE(3554)] = 42703,
  [SMALL_STATE(3555)] = 42776,
  [SMALL_STATE(3556)] = 42849,
  [SMALL_STATE(3557)] = 42922,
  [SMALL_STATE(3558)] = 42995,
  [SMALL_STATE(3559)] = 43068,
  [SMALL_STATE(3560)] = 43141,
  [SMALL_STATE(3561)] = 43214,
  [SMALL_STATE(3562)] = 43287,
  [SMALL_STATE(3563)] = 43360,
  [SMALL_STATE(3564)] = 43433,
  [SMALL_STATE(3565)] = 43506,
  [SMALL_STATE(3566)] = 43579,
  [SMALL_STATE(3567)] = 43652,
  [SMALL_STATE(3568)] = 43725,
  [SMALL_STATE(3569)] = 43798,
  [SMALL_STATE(3570)] = 43871,
  [SMALL_STATE(3571)] = 43944,
  [SMALL_STATE(3572)] = 44017,
  [SMALL_STATE(3573)] = 44090,
  [SMALL_STATE(3574)] = 44163,
  [SMALL_STATE(3575)] = 44236,
  [SMALL_STATE(3576)] = 44309,
  [SMALL_STATE(3577)] = 44382,
  [SMALL_STATE(3578)] = 44461,
  [SMALL_STATE(3579)] = 44534,
  [SMALL_STATE(3580)] = 44607,
  [SMALL_STATE(3581)] = 44680,
  [SMALL_STATE(3582)] = 44753,
  [SMALL_STATE(3583)] = 44826,
  [SMALL_STATE(3584)] = 44899,
  [SMALL_STATE(3585)] = 44972,
  [SMALL_STATE(3586)] = 45045,
  [SMALL_STATE(3587)] = 45118,
  [SMALL_STATE(3588)] = 45191,
  [SMALL_STATE(3589)] = 45264,
  [SMALL_STATE(3590)] = 45337,
  [SMALL_STATE(3591)] = 45410,
  [SMALL_STATE(3592)] = 45483,
  [SMALL_STATE(3593)] = 45556,
  [SMALL_STATE(3594)] = 45629,
  [SMALL_STATE(3595)] = 45702,
  [SMALL_STATE(3596)] = 45775,
  [SMALL_STATE(3597)] = 45848,
  [SMALL_STATE(3598)] = 45923,
  [SMALL_STATE(3599)] = 45998,
  [SMALL_STATE(3600)] = 46071,
  [SMALL_STATE(3601)] = 46144,
  [SMALL_STATE(3602)] = 46217,
  [SMALL_STATE(3603)] = 46290,
  [SMALL_STATE(3604)] = 46363,
  [SMALL_STATE(3605)] = 46436,
  [SMALL_STATE(3606)] = 46509,
  [SMALL_STATE(3607)] = 46582,
  [SMALL_STATE(3608)] = 46655,
  [SMALL_STATE(3609)] = 46728,
  [SMALL_STATE(3610)] = 46801,
  [SMALL_STATE(3611)] = 46874,
  [SMALL_STATE(3612)] = 46947,
  [SMALL_STATE(3613)] = 47020,
  [SMALL_STATE(3614)] = 47093,
  [SMALL_STATE(3615)] = 47166,
  [SMALL_STATE(3616)] = 47239,
  [SMALL_STATE(3617)] = 47312,
  [SMALL_STATE(3618)] = 47385,
  [SMALL_STATE(3619)] = 47458,
  [SMALL_STATE(3620)] = 47531,
  [SMALL_STATE(3621)] = 47604,
  [SMALL_STATE(3622)] = 47677,
  [SMALL_STATE(3623)] = 47752,
  [SMALL_STATE(3624)] = 47825,
  [SMALL_STATE(3625)] = 47898,
  [SMALL_STATE(3626)] = 47971,
  [SMALL_STATE(3627)] = 48044,
  [SMALL_STATE(3628)] = 48117,
  [SMALL_STATE(3629)] = 48190,
  [SMALL_STATE(3630)] = 48263,
  [SMALL_STATE(3631)] = 48336,
  [SMALL_STATE(3632)] = 48409,
  [SMALL_STATE(3633)] = 48482,
  [SMALL_STATE(3634)] = 48555,
  [SMALL_STATE(3635)] = 48628,
  [SMALL_STATE(3636)] = 48701,
  [SMALL_STATE(3637)] = 48774,
  [SMALL_STATE(3638)] = 48847,
  [SMALL_STATE(3639)] = 48920,
  [SMALL_STATE(3640)] = 48993,
  [SMALL_STATE(3641)] = 49066,
  [SMALL_STATE(3642)] = 49139,
  [SMALL_STATE(3643)] = 49212,
  [SMALL_STATE(3644)] = 49285,
  [SMALL_STATE(3645)] = 49358,
  [SMALL_STATE(3646)] = 49431,
  [SMALL_STATE(3647)] = 49504,
  [SMALL_STATE(3648)] = 49577,
  [SMALL_STATE(3649)] = 49656,
  [SMALL_STATE(3650)] = 49729,
  [SMALL_STATE(3651)] = 49802,
  [SMALL_STATE(3652)] = 49875,
  [SMALL_STATE(3653)] = 49948,
  [SMALL_STATE(3654)] = 50021,
  [SMALL_STATE(3655)] = 50094,
  [SMALL_STATE(3656)] = 50167,
  [SMALL_STATE(3657)] = 50240,
  [SMALL_STATE(3658)] = 50313,
  [SMALL_STATE(3659)] = 50386,
  [SMALL_STATE(3660)] = 50459,
  [SMALL_STATE(3661)] = 50532,
  [SMALL_STATE(3662)] = 50605,
  [SMALL_STATE(3663)] = 50684,
  [SMALL_STATE(3664)] = 50757,
  [SMALL_STATE(3665)] = 50830,
  [SMALL_STATE(3666)] = 50903,
  [SMALL_STATE(3667)] = 50976,
  [SMALL_STATE(3668)] = 51049,
  [SMALL_STATE(3669)] = 51122,
  [SMALL_STATE(3670)] = 51195,
  [SMALL_STATE(3671)] = 51268,
  [SMALL_STATE(3672)] = 51341,
  [SMALL_STATE(3673)] = 51414,
  [SMALL_STATE(3674)] = 51487,
  [SMALL_STATE(3675)] = 51566,
  [SMALL_STATE(3676)] = 51639,
  [SMALL_STATE(3677)] = 51712,
  [SMALL_STATE(3678)] = 51787,
  [SMALL_STATE(3679)] = 51860,
  [SMALL_STATE(3680)] = 51933,
  [SMALL_STATE(3681)] = 52006,
  [SMALL_STATE(3682)] = 52079,
  [SMALL_STATE(3683)] = 52152,
  [SMALL_STATE(3684)] = 52225,
  [SMALL_STATE(3685)] = 52298,
  [SMALL_STATE(3686)] = 52371,
  [SMALL_STATE(3687)] = 52450,
  [SMALL_STATE(3688)] = 52523,
  [SMALL_STATE(3689)] = 52596,
  [SMALL_STATE(3690)] = 52669,
  [SMALL_STATE(3691)] = 52742,
  [SMALL_STATE(3692)] = 52815,
  [SMALL_STATE(3693)] = 52888,
  [SMALL_STATE(3694)] = 52961,
  [SMALL_STATE(3695)] = 53034,
  [SMALL_STATE(3696)] = 53107,
  [SMALL_STATE(3697)] = 53180,
  [SMALL_STATE(3698)] = 53253,
  [SMALL_STATE(3699)] = 53326,
  [SMALL_STATE(3700)] = 53399,
  [SMALL_STATE(3701)] = 53472,
  [SMALL_STATE(3702)] = 53545,
  [SMALL_STATE(3703)] = 53618,
  [SMALL_STATE(3704)] = 53691,
  [SMALL_STATE(3705)] = 53764,
  [SMALL_STATE(3706)] = 53837,
  [SMALL_STATE(3707)] = 53910,
  [SMALL_STATE(3708)] = 53983,
  [SMALL_STATE(3709)] = 54056,
  [SMALL_STATE(3710)] = 54129,
  [SMALL_STATE(3711)] = 54202,
  [SMALL_STATE(3712)] = 54275,
  [SMALL_STATE(3713)] = 54348,
  [SMALL_STATE(3714)] = 54421,
  [SMALL_STATE(3715)] = 54494,
  [SMALL_STATE(3716)] = 54567,
  [SMALL_STATE(3717)] = 54640,
  [SMALL_STATE(3718)] = 54713,
  [SMALL_STATE(3719)] = 54788,
  [SMALL_STATE(3720)] = 54863,
  [SMALL_STATE(3721)] = 54936,
  [SMALL_STATE(3722)] = 55009,
  [SMALL_STATE(3723)] = 55082,
  [SMALL_STATE(3724)] = 55155,
  [SMALL_STATE(3725)] = 55228,
  [SMALL_STATE(3726)] = 55301,
  [SMALL_STATE(3727)] = 55374,
  [SMALL_STATE(3728)] = 55447,
  [SMALL_STATE(3729)] = 55520,
  [SMALL_STATE(3730)] = 55593,
  [SMALL_STATE(3731)] = 55666,
  [SMALL_STATE(3732)] = 55739,
  [SMALL_STATE(3733)] = 55812,
  [SMALL_STATE(3734)] = 55885,
  [SMALL_STATE(3735)] = 55958,
  [SMALL_STATE(3736)] = 56031,
  [SMALL_STATE(3737)] = 56104,
  [SMALL_STATE(3738)] = 56177,
  [SMALL_STATE(3739)] = 56250,
  [SMALL_STATE(3740)] = 56323,
  [SMALL_STATE(3741)] = 56396,
  [SMALL_STATE(3742)] = 56469,
  [SMALL_STATE(3743)] = 56542,
  [SMALL_STATE(3744)] = 56615,
  [SMALL_STATE(3745)] = 56688,
  [SMALL_STATE(3746)] = 56761,
  [SMALL_STATE(3747)] = 56834,
  [SMALL_STATE(3748)] = 56907,
  [SMALL_STATE(3749)] = 56980,
  [SMALL_STATE(3750)] = 57053,
  [SMALL_STATE(3751)] = 57126,
  [SMALL_STATE(3752)] = 57199,
  [SMALL_STATE(3753)] = 57272,
  [SMALL_STATE(3754)] = 57345,
  [SMALL_STATE(3755)] = 57420,
  [SMALL_STATE(3756)] = 57493,
  [SMALL_STATE(3757)] = 57566,
  [SMALL_STATE(3758)] = 57639,
  [SMALL_STATE(3759)] = 57714,
  [SMALL_STATE(3760)] = 57787,
  [SMALL_STATE(3761)] = 57860,
  [SMALL_STATE(3762)] = 57935,
  [SMALL_STATE(3763)] = 58008,
  [SMALL_STATE(3764)] = 58081,
  [SMALL_STATE(3765)] = 58154,
  [SMALL_STATE(3766)] = 58227,
  [SMALL_STATE(3767)] = 58300,
  [SMALL_STATE(3768)] = 58373,
  [SMALL_STATE(3769)] = 58446,
  [SMALL_STATE(3770)] = 58519,
  [SMALL_STATE(3771)] = 58594,
  [SMALL_STATE(3772)] = 58667,
  [SMALL_STATE(3773)] = 58742,
  [SMALL_STATE(3774)] = 58817,
  [SMALL_STATE(3775)] = 58890,
  [SMALL_STATE(3776)] = 58963,
  [SMALL_STATE(3777)] = 59036,
  [SMALL_STATE(3778)] = 59109,
  [SMALL_STATE(3779)] = 59182,
  [SMALL_STATE(3780)] = 59255,
  [SMALL_STATE(3781)] = 59328,
  [SMALL_STATE(3782)] = 59401,
  [SMALL_STATE(3783)] = 59474,
  [SMALL_STATE(3784)] = 59547,
  [SMALL_STATE(3785)] = 59620,
  [SMALL_STATE(3786)] = 59693,
  [SMALL_STATE(3787)] = 59766,
  [SMALL_STATE(3788)] = 59839,
  [SMALL_STATE(3789)] = 59912,
  [SMALL_STATE(3790)] = 59985,
  [SMALL_STATE(3791)] = 60058,
  [SMALL_STATE(3792)] = 60131,
  [SMALL_STATE(3793)] = 60204,
  [SMALL_STATE(3794)] = 60277,
  [SMALL_STATE(3795)] = 60350,
  [SMALL_STATE(3796)] = 60423,
  [SMALL_STATE(3797)] = 60496,
  [SMALL_STATE(3798)] = 60569,
  [SMALL_STATE(3799)] = 60642,
  [SMALL_STATE(3800)] = 60715,
  [SMALL_STATE(3801)] = 60788,
  [SMALL_STATE(3802)] = 60861,
  [SMALL_STATE(3803)] = 60934,
  [SMALL_STATE(3804)] = 61007,
  [SMALL_STATE(3805)] = 61080,
  [SMALL_STATE(3806)] = 61153,
  [SMALL_STATE(3807)] = 61228,
  [SMALL_STATE(3808)] = 61301,
  [SMALL_STATE(3809)] = 61374,
  [SMALL_STATE(3810)] = 61447,
  [SMALL_STATE(3811)] = 61520,
  [SMALL_STATE(3812)] = 61593,
  [SMALL_STATE(3813)] = 61666,
  [SMALL_STATE(3814)] = 61739,
  [SMALL_STATE(3815)] = 61812,
  [SMALL_STATE(3816)] = 61885,
  [SMALL_STATE(3817)] = 61958,
  [SMALL_STATE(3818)] = 62031,
  [SMALL_STATE(3819)] = 62104,
  [SMALL_STATE(3820)] = 62177,
  [SMALL_STATE(3821)] = 62250,
  [SMALL_STATE(3822)] = 62323,
  [SMALL_STATE(3823)] = 62396,
  [SMALL_STATE(3824)] = 62469,
  [SMALL_STATE(3825)] = 62542,
  [SMALL_STATE(3826)] = 62615,
  [SMALL_STATE(3827)] = 62688,
  [SMALL_STATE(3828)] = 62760,
  [SMALL_STATE(3829)] = 62832,
  [SMALL_STATE(3830)] = 62974,
  [SMALL_STATE(3831)] = 63116,
  [SMALL_STATE(3832)] = 63188,
  [SMALL_STATE(3833)] = 63260,
  [SMALL_STATE(3834)] = 63384,
  [SMALL_STATE(3835)] = 63456,
  [SMALL_STATE(3836)] = 63598,
  [SMALL_STATE(3837)] = 63670,
  [SMALL_STATE(3838)] = 63744,
  [SMALL_STATE(3839)] = 63816,
  [SMALL_STATE(3840)] = 63888,
  [SMALL_STATE(3841)] = 63960,
  [SMALL_STATE(3842)] = 64032,
  [SMALL_STATE(3843)] = 64104,
  [SMALL_STATE(3844)] = 64178,
  [SMALL_STATE(3845)] = 64320,
  [SMALL_STATE(3846)] = 64462,
  [SMALL_STATE(3847)] = 64534,
  [SMALL_STATE(3848)] = 64658,
  [SMALL_STATE(3849)] = 64800,
  [SMALL_STATE(3850)] = 64942,
  [SMALL_STATE(3851)] = 65066,
  [SMALL_STATE(3852)] = 65138,
  [SMALL_STATE(3853)] = 65210,
  [SMALL_STATE(3854)] = 65282,
  [SMALL_STATE(3855)] = 65354,
  [SMALL_STATE(3856)] = 65426,
  [SMALL_STATE(3857)] = 65500,
  [SMALL_STATE(3858)] = 65572,
  [SMALL_STATE(3859)] = 65714,
  [SMALL_STATE(3860)] = 65786,
  [SMALL_STATE(3861)] = 65858,
  [SMALL_STATE(3862)] = 65982,
  [SMALL_STATE(3863)] = 66054,
  [SMALL_STATE(3864)] = 66126,
  [SMALL_STATE(3865)] = 66198,
  [SMALL_STATE(3866)] = 66272,
  [SMALL_STATE(3867)] = 66344,
  [SMALL_STATE(3868)] = 66416,
  [SMALL_STATE(3869)] = 66488,
  [SMALL_STATE(3870)] = 66560,
  [SMALL_STATE(3871)] = 66702,
  [SMALL_STATE(3872)] = 66774,
  [SMALL_STATE(3873)] = 66898,
  [SMALL_STATE(3874)] = 66970,
  [SMALL_STATE(3875)] = 67042,
  [SMALL_STATE(3876)] = 67184,
  [SMALL_STATE(3877)] = 67308,
  [SMALL_STATE(3878)] = 67380,
  [SMALL_STATE(3879)] = 67522,
  [SMALL_STATE(3880)] = 67646,
  [SMALL_STATE(3881)] = 67718,
  [SMALL_STATE(3882)] = 67790,
  [SMALL_STATE(3883)] = 67862,
  [SMALL_STATE(3884)] = 67934,
  [SMALL_STATE(3885)] = 68006,
  [SMALL_STATE(3886)] = 68078,
  [SMALL_STATE(3887)] = 68220,
  [SMALL_STATE(3888)] = 68292,
  [SMALL_STATE(3889)] = 68364,
  [SMALL_STATE(3890)] = 68436,
  [SMALL_STATE(3891)] = 68560,
  [SMALL_STATE(3892)] = 68702,
  [SMALL_STATE(3893)] = 68774,
  [SMALL_STATE(3894)] = 68846,
  [SMALL_STATE(3895)] = 68970,
  [SMALL_STATE(3896)] = 69042,
  [SMALL_STATE(3897)] = 69184,
  [SMALL_STATE(3898)] = 69256,
  [SMALL_STATE(3899)] = 69328,
  [SMALL_STATE(3900)] = 69400,
  [SMALL_STATE(3901)] = 69524,
  [SMALL_STATE(3902)] = 69596,
  [SMALL_STATE(3903)] = 69738,
  [SMALL_STATE(3904)] = 69862,
  [SMALL_STATE(3905)] = 70004,
  [SMALL_STATE(3906)] = 70128,
  [SMALL_STATE(3907)] = 70270,
  [SMALL_STATE(3908)] = 70342,
  [SMALL_STATE(3909)] = 70414,
  [SMALL_STATE(3910)] = 70538,
  [SMALL_STATE(3911)] = 70610,
  [SMALL_STATE(3912)] = 70682,
  [SMALL_STATE(3913)] = 70824,
  [SMALL_STATE(3914)] = 70896,
  [SMALL_STATE(3915)] = 70968,
  [SMALL_STATE(3916)] = 71040,
  [SMALL_STATE(3917)] = 71164,
  [SMALL_STATE(3918)] = 71236,
  [SMALL_STATE(3919)] = 71378,
  [SMALL_STATE(3920)] = 71450,
  [SMALL_STATE(3921)] = 71522,
  [SMALL_STATE(3922)] = 71594,
  [SMALL_STATE(3923)] = 71718,
  [SMALL_STATE(3924)] = 71790,
  [SMALL_STATE(3925)] = 71862,
  [SMALL_STATE(3926)] = 72004,
  [SMALL_STATE(3927)] = 72076,
  [SMALL_STATE(3928)] = 72200,
  [SMALL_STATE(3929)] = 72342,
  [SMALL_STATE(3930)] = 72414,
  [SMALL_STATE(3931)] = 72538,
  [SMALL_STATE(3932)] = 72680,
  [SMALL_STATE(3933)] = 72754,
  [SMALL_STATE(3934)] = 72878,
  [SMALL_STATE(3935)] = 73020,
  [SMALL_STATE(3936)] = 73162,
  [SMALL_STATE(3937)] = 73304,
  [SMALL_STATE(3938)] = 73376,
  [SMALL_STATE(3939)] = 73500,
  [SMALL_STATE(3940)] = 73642,
  [SMALL_STATE(3941)] = 73784,
  [SMALL_STATE(3942)] = 73908,
  [SMALL_STATE(3943)] = 74032,
  [SMALL_STATE(3944)] = 74174,
  [SMALL_STATE(3945)] = 74298,
  [SMALL_STATE(3946)] = 74422,
  [SMALL_STATE(3947)] = 74564,
  [SMALL_STATE(3948)] = 74688,
  [SMALL_STATE(3949)] = 74760,
  [SMALL_STATE(3950)] = 74832,
  [SMALL_STATE(3951)] = 74974,
  [SMALL_STATE(3952)] = 75098,
  [SMALL_STATE(3953)] = 75222,
  [SMALL_STATE(3954)] = 75294,
  [SMALL_STATE(3955)] = 75436,
  [SMALL_STATE(3956)] = 75578,
  [SMALL_STATE(3957)] = 75702,
  [SMALL_STATE(3958)] = 75826,
  [SMALL_STATE(3959)] = 75898,
  [SMALL_STATE(3960)] = 76040,
  [SMALL_STATE(3961)] = 76164,
  [SMALL_STATE(3962)] = 76236,
  [SMALL_STATE(3963)] = 76360,
  [SMALL_STATE(3964)] = 76502,
  [SMALL_STATE(3965)] = 76626,
  [SMALL_STATE(3966)] = 76700,
  [SMALL_STATE(3967)] = 76824,
  [SMALL_STATE(3968)] = 76948,
  [SMALL_STATE(3969)] = 77020,
  [SMALL_STATE(3970)] = 77144,
  [SMALL_STATE(3971)] = 77286,
  [SMALL_STATE(3972)] = 77410,
  [SMALL_STATE(3973)] = 77482,
  [SMALL_STATE(3974)] = 77554,
  [SMALL_STATE(3975)] = 77626,
  [SMALL_STATE(3976)] = 77768,
  [SMALL_STATE(3977)] = 77840,
  [SMALL_STATE(3978)] = 77964,
  [SMALL_STATE(3979)] = 78036,
  [SMALL_STATE(3980)] = 78108,
  [SMALL_STATE(3981)] = 78250,
  [SMALL_STATE(3982)] = 78374,
  [SMALL_STATE(3983)] = 78516,
  [SMALL_STATE(3984)] = 78588,
  [SMALL_STATE(3985)] = 78712,
  [SMALL_STATE(3986)] = 78784,
  [SMALL_STATE(3987)] = 78856,
  [SMALL_STATE(3988)] = 78998,
  [SMALL_STATE(3989)] = 79070,
  [SMALL_STATE(3990)] = 79142,
  [SMALL_STATE(3991)] = 79266,
  [SMALL_STATE(3992)] = 79338,
  [SMALL_STATE(3993)] = 79412,
  [SMALL_STATE(3994)] = 79554,
  [SMALL_STATE(3995)] = 79628,
  [SMALL_STATE(3996)] = 79700,
  [SMALL_STATE(3997)] = 79824,
  [SMALL_STATE(3998)] = 79966,
  [SMALL_STATE(3999)] = 80090,
  [SMALL_STATE(4000)] = 80162,
  [SMALL_STATE(4001)] = 80234,
  [SMALL_STATE(4002)] = 80376,
  [SMALL_STATE(4003)] = 80448,
  [SMALL_STATE(4004)] = 80520,
  [SMALL_STATE(4005)] = 80662,
  [SMALL_STATE(4006)] = 80786,
  [SMALL_STATE(4007)] = 80858,
  [SMALL_STATE(4008)] = 81000,
  [SMALL_STATE(4009)] = 81124,
  [SMALL_STATE(4010)] = 81266,
  [SMALL_STATE(4011)] = 81338,
  [SMALL_STATE(4012)] = 81462,
  [SMALL_STATE(4013)] = 81604,
  [SMALL_STATE(4014)] = 81676,
  [SMALL_STATE(4015)] = 81748,
  [SMALL_STATE(4016)] = 81820,
  [SMALL_STATE(4017)] = 81962,
  [SMALL_STATE(4018)] = 82034,
  [SMALL_STATE(4019)] = 82106,
  [SMALL_STATE(4020)] = 82178,
  [SMALL_STATE(4021)] = 82320,
  [SMALL_STATE(4022)] = 82462,
  [SMALL_STATE(4023)] = 82604,
  [SMALL_STATE(4024)] = 82746,
  [SMALL_STATE(4025)] = 82818,
  [SMALL_STATE(4026)] = 82896,
  [SMALL_STATE(4027)] = 83038,
  [SMALL_STATE(4028)] = 83110,
  [SMALL_STATE(4029)] = 83182,
  [SMALL_STATE(4030)] = 83254,
  [SMALL_STATE(4031)] = 83326,
  [SMALL_STATE(4032)] = 83450,
  [SMALL_STATE(4033)] = 83592,
  [SMALL_STATE(4034)] = 83664,
  [SMALL_STATE(4035)] = 83736,
  [SMALL_STATE(4036)] = 83860,
  [SMALL_STATE(4037)] = 83984,
  [SMALL_STATE(4038)] = 84056,
  [SMALL_STATE(4039)] = 84130,
  [SMALL_STATE(4040)] = 84202,
  [SMALL_STATE(4041)] = 84274,
  [SMALL_STATE(4042)] = 84346,
  [SMALL_STATE(4043)] = 84418,
  [SMALL_STATE(4044)] = 84490,
  [SMALL_STATE(4045)] = 84562,
  [SMALL_STATE(4046)] = 84634,
  [SMALL_STATE(4047)] = 84706,
  [SMALL_STATE(4048)] = 84778,
  [SMALL_STATE(4049)] = 84850,
  [SMALL_STATE(4050)] = 84922,
  [SMALL_STATE(4051)] = 84994,
  [SMALL_STATE(4052)] = 85066,
  [SMALL_STATE(4053)] = 85138,
  [SMALL_STATE(4054)] = 85210,
  [SMALL_STATE(4055)] = 85282,
  [SMALL_STATE(4056)] = 85354,
  [SMALL_STATE(4057)] = 85426,
  [SMALL_STATE(4058)] = 85504,
  [SMALL_STATE(4059)] = 85576,
  [SMALL_STATE(4060)] = 85718,
  [SMALL_STATE(4061)] = 85790,
  [SMALL_STATE(4062)] = 85862,
  [SMALL_STATE(4063)] = 85934,
  [SMALL_STATE(4064)] = 86006,
  [SMALL_STATE(4065)] = 86078,
  [SMALL_STATE(4066)] = 86150,
  [SMALL_STATE(4067)] = 86222,
  [SMALL_STATE(4068)] = 86294,
  [SMALL_STATE(4069)] = 86366,
  [SMALL_STATE(4070)] = 86508,
  [SMALL_STATE(4071)] = 86582,
  [SMALL_STATE(4072)] = 86724,
  [SMALL_STATE(4073)] = 86798,
  [SMALL_STATE(4074)] = 86940,
  [SMALL_STATE(4075)] = 87012,
  [SMALL_STATE(4076)] = 87084,
  [SMALL_STATE(4077)] = 87156,
  [SMALL_STATE(4078)] = 87280,
  [SMALL_STATE(4079)] = 87358,
  [SMALL_STATE(4080)] = 87500,
  [SMALL_STATE(4081)] = 87572,
  [SMALL_STATE(4082)] = 87644,
  [SMALL_STATE(4083)] = 87716,
  [SMALL_STATE(4084)] = 87788,
  [SMALL_STATE(4085)] = 87860,
  [SMALL_STATE(4086)] = 87932,
  [SMALL_STATE(4087)] = 88004,
  [SMALL_STATE(4088)] = 88076,
  [SMALL_STATE(4089)] = 88154,
  [SMALL_STATE(4090)] = 88226,
  [SMALL_STATE(4091)] = 88298,
  [SMALL_STATE(4092)] = 88370,
  [SMALL_STATE(4093)] = 88442,
  [SMALL_STATE(4094)] = 88514,
  [SMALL_STATE(4095)] = 88586,
  [SMALL_STATE(4096)] = 88658,
  [SMALL_STATE(4097)] = 88800,
  [SMALL_STATE(4098)] = 88942,
  [SMALL_STATE(4099)] = 89084,
  [SMALL_STATE(4100)] = 89208,
  [SMALL_STATE(4101)] = 89280,
  [SMALL_STATE(4102)] = 89422,
  [SMALL_STATE(4103)] = 89564,
  [SMALL_STATE(4104)] = 89636,
  [SMALL_STATE(4105)] = 89708,
  [SMALL_STATE(4106)] = 89832,
  [SMALL_STATE(4107)] = 89956,
  [SMALL_STATE(4108)] = 90028,
  [SMALL_STATE(4109)] = 90100,
  [SMALL_STATE(4110)] = 90172,
  [SMALL_STATE(4111)] = 90244,
  [SMALL_STATE(4112)] = 90316,
  [SMALL_STATE(4113)] = 90388,
  [SMALL_STATE(4114)] = 90460,
  [SMALL_STATE(4115)] = 90532,
  [SMALL_STATE(4116)] = 90606,
  [SMALL_STATE(4117)] = 90748,
  [SMALL_STATE(4118)] = 90890,
  [SMALL_STATE(4119)] = 91014,
  [SMALL_STATE(4120)] = 91156,
  [SMALL_STATE(4121)] = 91228,
  [SMALL_STATE(4122)] = 91300,
  [SMALL_STATE(4123)] = 91372,
  [SMALL_STATE(4124)] = 91444,
  [SMALL_STATE(4125)] = 91516,
  [SMALL_STATE(4126)] = 91587,
  [SMALL_STATE(4127)] = 91708,
  [SMALL_STATE(4128)] = 91829,
  [SMALL_STATE(4129)] = 91900,
  [SMALL_STATE(4130)] = 92039,
  [SMALL_STATE(4131)] = 92112,
  [SMALL_STATE(4132)] = 92183,
  [SMALL_STATE(4133)] = 92254,
  [SMALL_STATE(4134)] = 92325,
  [SMALL_STATE(4135)] = 92396,
  [SMALL_STATE(4136)] = 92535,
  [SMALL_STATE(4137)] = 92606,
  [SMALL_STATE(4138)] = 92745,
  [SMALL_STATE(4139)] = 92884,
  [SMALL_STATE(4140)] = 93023,
  [SMALL_STATE(4141)] = 93094,
  [SMALL_STATE(4142)] = 93215,
  [SMALL_STATE(4143)] = 93286,
  [SMALL_STATE(4144)] = 93407,
  [SMALL_STATE(4145)] = 93528,
  [SMALL_STATE(4146)] = 93601,
  [SMALL_STATE(4147)] = 93740,
  [SMALL_STATE(4148)] = 93879,
  [SMALL_STATE(4149)] = 93950,
  [SMALL_STATE(4150)] = 94071,
  [SMALL_STATE(4151)] = 94210,
  [SMALL_STATE(4152)] = 94349,
  [SMALL_STATE(4153)] = 94470,
  [SMALL_STATE(4154)] = 94541,
  [SMALL_STATE(4155)] = 94614,
  [SMALL_STATE(4156)] = 94685,
  [SMALL_STATE(4157)] = 94824,
  [SMALL_STATE(4158)] = 94963,
  [SMALL_STATE(4159)] = 95102,
  [SMALL_STATE(4160)] = 95223,
  [SMALL_STATE(4161)] = 95344,
  [SMALL_STATE(4162)] = 95415,
  [SMALL_STATE(4163)] = 95486,
  [SMALL_STATE(4164)] = 95557,
  [SMALL_STATE(4165)] = 95696,
  [SMALL_STATE(4166)] = 95835,
  [SMALL_STATE(4167)] = 95906,
  [SMALL_STATE(4168)] = 96027,
  [SMALL_STATE(4169)] = 96098,
  [SMALL_STATE(4170)] = 96169,
  [SMALL_STATE(4171)] = 96240,
  [SMALL_STATE(4172)] = 96311,
  [SMALL_STATE(4173)] = 96382,
  [SMALL_STATE(4174)] = 96453,
  [SMALL_STATE(4175)] = 96524,
  [SMALL_STATE(4176)] = 96597,
  [SMALL_STATE(4177)] = 96718,
  [SMALL_STATE(4178)] = 96839,
  [SMALL_STATE(4179)] = 96978,
  [SMALL_STATE(4180)] = 97117,
  [SMALL_STATE(4181)] = 97188,
  [SMALL_STATE(4182)] = 97259,
  [SMALL_STATE(4183)] = 97330,
  [SMALL_STATE(4184)] = 97401,
  [SMALL_STATE(4185)] = 97472,
  [SMALL_STATE(4186)] = 97593,
  [SMALL_STATE(4187)] = 97714,
  [SMALL_STATE(4188)] = 97853,
  [SMALL_STATE(4189)] = 97992,
  [SMALL_STATE(4190)] = 98063,
  [SMALL_STATE(4191)] = 98134,
  [SMALL_STATE(4192)] = 98205,
  [SMALL_STATE(4193)] = 98276,
  [SMALL_STATE(4194)] = 98347,
  [SMALL_STATE(4195)] = 98468,
  [SMALL_STATE(4196)] = 98539,
  [SMALL_STATE(4197)] = 98610,
  [SMALL_STATE(4198)] = 98681,
  [SMALL_STATE(4199)] = 98752,
  [SMALL_STATE(4200)] = 98823,
  [SMALL_STATE(4201)] = 98894,
  [SMALL_STATE(4202)] = 98965,
  [SMALL_STATE(4203)] = 99036,
  [SMALL_STATE(4204)] = 99109,
  [SMALL_STATE(4205)] = 99230,
  [SMALL_STATE(4206)] = 99303,
  [SMALL_STATE(4207)] = 99374,
  [SMALL_STATE(4208)] = 99445,
  [SMALL_STATE(4209)] = 99516,
  [SMALL_STATE(4210)] = 99587,
  [SMALL_STATE(4211)] = 99658,
  [SMALL_STATE(4212)] = 99731,
  [SMALL_STATE(4213)] = 99802,
  [SMALL_STATE(4214)] = 99873,
  [SMALL_STATE(4215)] = 99944,
  [SMALL_STATE(4216)] = 100065,
  [SMALL_STATE(4217)] = 100136,
  [SMALL_STATE(4218)] = 100207,
  [SMALL_STATE(4219)] = 100278,
  [SMALL_STATE(4220)] = 100399,
  [SMALL_STATE(4221)] = 100470,
  [SMALL_STATE(4222)] = 100541,
  [SMALL_STATE(4223)] = 100612,
  [SMALL_STATE(4224)] = 100683,
  [SMALL_STATE(4225)] = 100754,
  [SMALL_STATE(4226)] = 100825,
  [SMALL_STATE(4227)] = 100896,
  [SMALL_STATE(4228)] = 100967,
  [SMALL_STATE(4229)] = 101038,
  [SMALL_STATE(4230)] = 101109,
  [SMALL_STATE(4231)] = 101180,
  [SMALL_STATE(4232)] = 101251,
  [SMALL_STATE(4233)] = 101372,
  [SMALL_STATE(4234)] = 101511,
  [SMALL_STATE(4235)] = 101582,
  [SMALL_STATE(4236)] = 101653,
  [SMALL_STATE(4237)] = 101724,
  [SMALL_STATE(4238)] = 101795,
  [SMALL_STATE(4239)] = 101934,
  [SMALL_STATE(4240)] = 102005,
  [SMALL_STATE(4241)] = 102076,
  [SMALL_STATE(4242)] = 102215,
  [SMALL_STATE(4243)] = 102336,
  [SMALL_STATE(4244)] = 102407,
  [SMALL_STATE(4245)] = 102528,
  [SMALL_STATE(4246)] = 102599,
  [SMALL_STATE(4247)] = 102670,
  [SMALL_STATE(4248)] = 102809,
  [SMALL_STATE(4249)] = 102880,
  [SMALL_STATE(4250)] = 103019,
  [SMALL_STATE(4251)] = 103158,
  [SMALL_STATE(4252)] = 103229,
  [SMALL_STATE(4253)] = 103302,
  [SMALL_STATE(4254)] = 103423,
  [SMALL_STATE(4255)] = 103544,
  [SMALL_STATE(4256)] = 103665,
  [SMALL_STATE(4257)] = 103736,
  [SMALL_STATE(4258)] = 103807,
  [SMALL_STATE(4259)] = 103884,
  [SMALL_STATE(4260)] = 104023,
  [SMALL_STATE(4261)] = 104162,
  [SMALL_STATE(4262)] = 104233,
  [SMALL_STATE(4263)] = 104304,
  [SMALL_STATE(4264)] = 104425,
  [SMALL_STATE(4265)] = 104496,
  [SMALL_STATE(4266)] = 104567,
  [SMALL_STATE(4267)] = 104644,
  [SMALL_STATE(4268)] = 104783,
  [SMALL_STATE(4269)] = 104904,
  [SMALL_STATE(4270)] = 104975,
  [SMALL_STATE(4271)] = 105114,
  [SMALL_STATE(4272)] = 105253,
  [SMALL_STATE(4273)] = 105324,
  [SMALL_STATE(4274)] = 105395,
  [SMALL_STATE(4275)] = 105534,
  [SMALL_STATE(4276)] = 105605,
  [SMALL_STATE(4277)] = 105676,
  [SMALL_STATE(4278)] = 105815,
  [SMALL_STATE(4279)] = 105954,
  [SMALL_STATE(4280)] = 106025,
  [SMALL_STATE(4281)] = 106098,
  [SMALL_STATE(4282)] = 106169,
  [SMALL_STATE(4283)] = 106240,
  [SMALL_STATE(4284)] = 106361,
  [SMALL_STATE(4285)] = 106500,
  [SMALL_STATE(4286)] = 106573,
  [SMALL_STATE(4287)] = 106644,
  [SMALL_STATE(4288)] = 106715,
  [SMALL_STATE(4289)] = 106786,
  [SMALL_STATE(4290)] = 106857,
  [SMALL_STATE(4291)] = 106928,
  [SMALL_STATE(4292)] = 106999,
  [SMALL_STATE(4293)] = 107120,
  [SMALL_STATE(4294)] = 107259,
  [SMALL_STATE(4295)] = 107380,
  [SMALL_STATE(4296)] = 107451,
  [SMALL_STATE(4297)] = 107572,
  [SMALL_STATE(4298)] = 107711,
  [SMALL_STATE(4299)] = 107782,
  [SMALL_STATE(4300)] = 107903,
  [SMALL_STATE(4301)] = 108042,
  [SMALL_STATE(4302)] = 108113,
  [SMALL_STATE(4303)] = 108184,
  [SMALL_STATE(4304)] = 108255,
  [SMALL_STATE(4305)] = 108326,
  [SMALL_STATE(4306)] = 108447,
  [SMALL_STATE(4307)] = 108568,
  [SMALL_STATE(4308)] = 108707,
  [SMALL_STATE(4309)] = 108846,
  [SMALL_STATE(4310)] = 108985,
  [SMALL_STATE(4311)] = 109056,
  [SMALL_STATE(4312)] = 109195,
  [SMALL_STATE(4313)] = 109334,
  [SMALL_STATE(4314)] = 109473,
  [SMALL_STATE(4315)] = 109612,
  [SMALL_STATE(4316)] = 109751,
  [SMALL_STATE(4317)] = 109822,
  [SMALL_STATE(4318)] = 109961,
  [SMALL_STATE(4319)] = 110082,
  [SMALL_STATE(4320)] = 110221,
  [SMALL_STATE(4321)] = 110360,
  [SMALL_STATE(4322)] = 110499,
  [SMALL_STATE(4323)] = 110570,
  [SMALL_STATE(4324)] = 110641,
  [SMALL_STATE(4325)] = 110762,
  [SMALL_STATE(4326)] = 110833,
  [SMALL_STATE(4327)] = 110904,
  [SMALL_STATE(4328)] = 110975,
  [SMALL_STATE(4329)] = 111046,
  [SMALL_STATE(4330)] = 111117,
  [SMALL_STATE(4331)] = 111188,
  [SMALL_STATE(4332)] = 111259,
  [SMALL_STATE(4333)] = 111330,
  [SMALL_STATE(4334)] = 111469,
  [SMALL_STATE(4335)] = 111608,
  [SMALL_STATE(4336)] = 111747,
  [SMALL_STATE(4337)] = 111886,
  [SMALL_STATE(4338)] = 112025,
  [SMALL_STATE(4339)] = 112164,
  [SMALL_STATE(4340)] = 112285,
  [SMALL_STATE(4341)] = 112356,
  [SMALL_STATE(4342)] = 112427,
  [SMALL_STATE(4343)] = 112498,
  [SMALL_STATE(4344)] = 112569,
  [SMALL_STATE(4345)] = 112640,
  [SMALL_STATE(4346)] = 112711,
  [SMALL_STATE(4347)] = 112784,
  [SMALL_STATE(4348)] = 112855,
  [SMALL_STATE(4349)] = 112926,
  [SMALL_STATE(4350)] = 112999,
  [SMALL_STATE(4351)] = 113070,
  [SMALL_STATE(4352)] = 113191,
  [SMALL_STATE(4353)] = 113262,
  [SMALL_STATE(4354)] = 113333,
  [SMALL_STATE(4355)] = 113404,
  [SMALL_STATE(4356)] = 113475,
  [SMALL_STATE(4357)] = 113596,
  [SMALL_STATE(4358)] = 113667,
  [SMALL_STATE(4359)] = 113738,
  [SMALL_STATE(4360)] = 113809,
  [SMALL_STATE(4361)] = 113880,
  [SMALL_STATE(4362)] = 113951,
  [SMALL_STATE(4363)] = 114072,
  [SMALL_STATE(4364)] = 114143,
  [SMALL_STATE(4365)] = 114214,
  [SMALL_STATE(4366)] = 114285,
  [SMALL_STATE(4367)] = 114356,
  [SMALL_STATE(4368)] = 114427,
  [SMALL_STATE(4369)] = 114498,
  [SMALL_STATE(4370)] = 114569,
  [SMALL_STATE(4371)] = 114640,
  [SMALL_STATE(4372)] = 114711,
  [SMALL_STATE(4373)] = 114782,
  [SMALL_STATE(4374)] = 114855,
  [SMALL_STATE(4375)] = 114976,
  [SMALL_STATE(4376)] = 115115,
  [SMALL_STATE(4377)] = 115186,
  [SMALL_STATE(4378)] = 115257,
  [SMALL_STATE(4379)] = 115328,
  [SMALL_STATE(4380)] = 115399,
  [SMALL_STATE(4381)] = 115470,
  [SMALL_STATE(4382)] = 115541,
  [SMALL_STATE(4383)] = 115612,
  [SMALL_STATE(4384)] = 115683,
  [SMALL_STATE(4385)] = 115754,
  [SMALL_STATE(4386)] = 115825,
  [SMALL_STATE(4387)] = 115946,
  [SMALL_STATE(4388)] = 116085,
  [SMALL_STATE(4389)] = 116224,
  [SMALL_STATE(4390)] = 116295,
  [SMALL_STATE(4391)] = 116416,
  [SMALL_STATE(4392)] = 116487,
  [SMALL_STATE(4393)] = 116608,
  [SMALL_STATE(4394)] = 116679,
  [SMALL_STATE(4395)] = 116818,
  [SMALL_STATE(4396)] = 116957,
  [SMALL_STATE(4397)] = 117028,
  [SMALL_STATE(4398)] = 117105,
  [SMALL_STATE(4399)] = 117244,
  [SMALL_STATE(4400)] = 117383,
  [SMALL_STATE(4401)] = 117454,
  [SMALL_STATE(4402)] = 117525,
  [SMALL_STATE(4403)] = 117596,
  [SMALL_STATE(4404)] = 117667,
  [SMALL_STATE(4405)] = 117740,
  [SMALL_STATE(4406)] = 117811,
  [SMALL_STATE(4407)] = 117888,
  [SMALL_STATE(4408)] = 118027,
  [SMALL_STATE(4409)] = 118098,
  [SMALL_STATE(4410)] = 118169,
  [SMALL_STATE(4411)] = 118240,
  [SMALL_STATE(4412)] = 118311,
  [SMALL_STATE(4413)] = 118382,
  [SMALL_STATE(4414)] = 118453,
  [SMALL_STATE(4415)] = 118524,
  [SMALL_STATE(4416)] = 118595,
  [SMALL_STATE(4417)] = 118665,
  [SMALL_STATE(4418)] = 118783,
  [SMALL_STATE(4419)] = 118853,
  [SMALL_STATE(4420)] = 118923,
  [SMALL_STATE(4421)] = 119041,
  [SMALL_STATE(4422)] = 119111,
  [SMALL_STATE(4423)] = 119181,
  [SMALL_STATE(4424)] = 119299,
  [SMALL_STATE(4425)] = 119417,
  [SMALL_STATE(4426)] = 119535,
  [SMALL_STATE(4427)] = 119653,
  [SMALL_STATE(4428)] = 119789,
  [SMALL_STATE(4429)] = 119907,
  [SMALL_STATE(4430)] = 120043,
  [SMALL_STATE(4431)] = 120161,
  [SMALL_STATE(4432)] = 120279,
  [SMALL_STATE(4433)] = 120397,
  [SMALL_STATE(4434)] = 120515,
  [SMALL_STATE(4435)] = 120633,
  [SMALL_STATE(4436)] = 120769,
  [SMALL_STATE(4437)] = 120839,
  [SMALL_STATE(4438)] = 120909,
  [SMALL_STATE(4439)] = 120979,
  [SMALL_STATE(4440)] = 121049,
  [SMALL_STATE(4441)] = 121167,
  [SMALL_STATE(4442)] = 121285,
  [SMALL_STATE(4443)] = 121355,
  [SMALL_STATE(4444)] = 121425,
  [SMALL_STATE(4445)] = 121495,
  [SMALL_STATE(4446)] = 121565,
  [SMALL_STATE(4447)] = 121635,
  [SMALL_STATE(4448)] = 121753,
  [SMALL_STATE(4449)] = 121823,
  [SMALL_STATE(4450)] = 121893,
  [SMALL_STATE(4451)] = 121963,
  [SMALL_STATE(4452)] = 122033,
  [SMALL_STATE(4453)] = 122103,
  [SMALL_STATE(4454)] = 122173,
  [SMALL_STATE(4455)] = 122243,
  [SMALL_STATE(4456)] = 122313,
  [SMALL_STATE(4457)] = 122431,
  [SMALL_STATE(4458)] = 122549,
  [SMALL_STATE(4459)] = 122625,
  [SMALL_STATE(4460)] = 122743,
  [SMALL_STATE(4461)] = 122815,
  [SMALL_STATE(4462)] = 122933,
  [SMALL_STATE(4463)] = 123051,
  [SMALL_STATE(4464)] = 123121,
  [SMALL_STATE(4465)] = 123239,
  [SMALL_STATE(4466)] = 123357,
  [SMALL_STATE(4467)] = 123475,
  [SMALL_STATE(4468)] = 123545,
  [SMALL_STATE(4469)] = 123615,
  [SMALL_STATE(4470)] = 123685,
  [SMALL_STATE(4471)] = 123755,
  [SMALL_STATE(4472)] = 123825,
  [SMALL_STATE(4473)] = 123895,
  [SMALL_STATE(4474)] = 124013,
  [SMALL_STATE(4475)] = 124131,
  [SMALL_STATE(4476)] = 124249,
  [SMALL_STATE(4477)] = 124367,
  [SMALL_STATE(4478)] = 124437,
  [SMALL_STATE(4479)] = 124507,
  [SMALL_STATE(4480)] = 124577,
  [SMALL_STATE(4481)] = 124647,
  [SMALL_STATE(4482)] = 124717,
  [SMALL_STATE(4483)] = 124793,
  [SMALL_STATE(4484)] = 124863,
  [SMALL_STATE(4485)] = 124933,
  [SMALL_STATE(4486)] = 125003,
  [SMALL_STATE(4487)] = 125073,
  [SMALL_STATE(4488)] = 125143,
  [SMALL_STATE(4489)] = 125215,
  [SMALL_STATE(4490)] = 125287,
  [SMALL_STATE(4491)] = 125357,
  [SMALL_STATE(4492)] = 125427,
  [SMALL_STATE(4493)] = 125497,
  [SMALL_STATE(4494)] = 125615,
  [SMALL_STATE(4495)] = 125685,
  [SMALL_STATE(4496)] = 125755,
  [SMALL_STATE(4497)] = 125873,
  [SMALL_STATE(4498)] = 125943,
  [SMALL_STATE(4499)] = 126061,
  [SMALL_STATE(4500)] = 126179,
  [SMALL_STATE(4501)] = 126315,
  [SMALL_STATE(4502)] = 126385,
  [SMALL_STATE(4503)] = 126503,
  [SMALL_STATE(4504)] = 126621,
  [SMALL_STATE(4505)] = 126691,
  [SMALL_STATE(4506)] = 126761,
  [SMALL_STATE(4507)] = 126897,
  [SMALL_STATE(4508)] = 127015,
  [SMALL_STATE(4509)] = 127151,
  [SMALL_STATE(4510)] = 127287,
  [SMALL_STATE(4511)] = 127423,
  [SMALL_STATE(4512)] = 127493,
  [SMALL_STATE(4513)] = 127629,
  [SMALL_STATE(4514)] = 127699,
  [SMALL_STATE(4515)] = 127817,
  [SMALL_STATE(4516)] = 127887,
  [SMALL_STATE(4517)] = 127957,
  [SMALL_STATE(4518)] = 128027,
  [SMALL_STATE(4519)] = 128097,
  [SMALL_STATE(4520)] = 128215,
  [SMALL_STATE(4521)] = 128285,
  [SMALL_STATE(4522)] = 128403,
  [SMALL_STATE(4523)] = 128521,
  [SMALL_STATE(4524)] = 128591,
  [SMALL_STATE(4525)] = 128709,
  [SMALL_STATE(4526)] = 128827,
  [SMALL_STATE(4527)] = 128897,
  [SMALL_STATE(4528)] = 128969,
  [SMALL_STATE(4529)] = 129039,
  [SMALL_STATE(4530)] = 129157,
  [SMALL_STATE(4531)] = 129227,
  [SMALL_STATE(4532)] = 129345,
  [SMALL_STATE(4533)] = 129415,
  [SMALL_STATE(4534)] = 129533,
  [SMALL_STATE(4535)] = 129651,
  [SMALL_STATE(4536)] = 129721,
  [SMALL_STATE(4537)] = 129791,
  [SMALL_STATE(4538)] = 129909,
  [SMALL_STATE(4539)] = 129979,
  [SMALL_STATE(4540)] = 130097,
  [SMALL_STATE(4541)] = 130167,
  [SMALL_STATE(4542)] = 130237,
  [SMALL_STATE(4543)] = 130307,
  [SMALL_STATE(4544)] = 130377,
  [SMALL_STATE(4545)] = 130495,
  [SMALL_STATE(4546)] = 130565,
  [SMALL_STATE(4547)] = 130683,
  [SMALL_STATE(4548)] = 130801,
  [SMALL_STATE(4549)] = 130919,
  [SMALL_STATE(4550)] = 131037,
  [SMALL_STATE(4551)] = 131107,
  [SMALL_STATE(4552)] = 131225,
  [SMALL_STATE(4553)] = 131295,
  [SMALL_STATE(4554)] = 131365,
  [SMALL_STATE(4555)] = 131435,
  [SMALL_STATE(4556)] = 131553,
  [SMALL_STATE(4557)] = 131671,
  [SMALL_STATE(4558)] = 131789,
  [SMALL_STATE(4559)] = 131859,
  [SMALL_STATE(4560)] = 131929,
  [SMALL_STATE(4561)] = 131999,
  [SMALL_STATE(4562)] = 132069,
  [SMALL_STATE(4563)] = 132139,
  [SMALL_STATE(4564)] = 132257,
  [SMALL_STATE(4565)] = 132327,
  [SMALL_STATE(4566)] = 132397,
  [SMALL_STATE(4567)] = 132515,
  [SMALL_STATE(4568)] = 132633,
  [SMALL_STATE(4569)] = 132751,
  [SMALL_STATE(4570)] = 132821,
  [SMALL_STATE(4571)] = 132957,
  [SMALL_STATE(4572)] = 133075,
  [SMALL_STATE(4573)] = 133193,
  [SMALL_STATE(4574)] = 133311,
  [SMALL_STATE(4575)] = 133447,
  [SMALL_STATE(4576)] = 133583,
  [SMALL_STATE(4577)] = 133719,
  [SMALL_STATE(4578)] = 133855,
  [SMALL_STATE(4579)] = 133973,
  [SMALL_STATE(4580)] = 134043,
  [SMALL_STATE(4581)] = 134161,
  [SMALL_STATE(4582)] = 134279,
  [SMALL_STATE(4583)] = 134397,
  [SMALL_STATE(4584)] = 134515,
  [SMALL_STATE(4585)] = 134585,
  [SMALL_STATE(4586)] = 134721,
  [SMALL_STATE(4587)] = 134791,
  [SMALL_STATE(4588)] = 134927,
  [SMALL_STATE(4589)] = 135045,
  [SMALL_STATE(4590)] = 135163,
  [SMALL_STATE(4591)] = 135281,
  [SMALL_STATE(4592)] = 135399,
  [SMALL_STATE(4593)] = 135517,
  [SMALL_STATE(4594)] = 135653,
  [SMALL_STATE(4595)] = 135771,
  [SMALL_STATE(4596)] = 135889,
  [SMALL_STATE(4597)] = 136007,
  [SMALL_STATE(4598)] = 136077,
  [SMALL_STATE(4599)] = 136147,
  [SMALL_STATE(4600)] = 136217,
  [SMALL_STATE(4601)] = 136287,
  [SMALL_STATE(4602)] = 136423,
  [SMALL_STATE(4603)] = 136559,
  [SMALL_STATE(4604)] = 136629,
  [SMALL_STATE(4605)] = 136699,
  [SMALL_STATE(4606)] = 136769,
  [SMALL_STATE(4607)] = 136905,
  [SMALL_STATE(4608)] = 137023,
  [SMALL_STATE(4609)] = 137159,
  [SMALL_STATE(4610)] = 137295,
  [SMALL_STATE(4611)] = 137431,
  [SMALL_STATE(4612)] = 137567,
  [SMALL_STATE(4613)] = 137637,
  [SMALL_STATE(4614)] = 137755,
  [SMALL_STATE(4615)] = 137825,
  [SMALL_STATE(4616)] = 137895,
  [SMALL_STATE(4617)] = 137965,
  [SMALL_STATE(4618)] = 138035,
  [SMALL_STATE(4619)] = 138153,
  [SMALL_STATE(4620)] = 138223,
  [SMALL_STATE(4621)] = 138359,
  [SMALL_STATE(4622)] = 138477,
  [SMALL_STATE(4623)] = 138553,
  [SMALL_STATE(4624)] = 138689,
  [SMALL_STATE(4625)] = 138807,
  [SMALL_STATE(4626)] = 138925,
  [SMALL_STATE(4627)] = 139043,
  [SMALL_STATE(4628)] = 139161,
  [SMALL_STATE(4629)] = 139233,
  [SMALL_STATE(4630)] = 139369,
  [SMALL_STATE(4631)] = 139487,
  [SMALL_STATE(4632)] = 139557,
  [SMALL_STATE(4633)] = 139627,
  [SMALL_STATE(4634)] = 139697,
  [SMALL_STATE(4635)] = 139815,
  [SMALL_STATE(4636)] = 139885,
  [SMALL_STATE(4637)] = 139955,
  [SMALL_STATE(4638)] = 140073,
  [SMALL_STATE(4639)] = 140143,
  [SMALL_STATE(4640)] = 140213,
  [SMALL_STATE(4641)] = 140285,
  [SMALL_STATE(4642)] = 140355,
  [SMALL_STATE(4643)] = 140425,
  [SMALL_STATE(4644)] = 140495,
  [SMALL_STATE(4645)] = 140631,
  [SMALL_STATE(4646)] = 140749,
  [SMALL_STATE(4647)] = 140821,
  [SMALL_STATE(4648)] = 140939,
  [SMALL_STATE(4649)] = 141057,
  [SMALL_STATE(4650)] = 141175,
  [SMALL_STATE(4651)] = 141293,
  [SMALL_STATE(4652)] = 141411,
  [SMALL_STATE(4653)] = 141529,
  [SMALL_STATE(4654)] = 141599,
  [SMALL_STATE(4655)] = 141669,
  [SMALL_STATE(4656)] = 141739,
  [SMALL_STATE(4657)] = 141809,
  [SMALL_STATE(4658)] = 141879,
  [SMALL_STATE(4659)] = 141997,
  [SMALL_STATE(4660)] = 142067,
  [SMALL_STATE(4661)] = 142137,
  [SMALL_STATE(4662)] = 142207,
  [SMALL_STATE(4663)] = 142277,
  [SMALL_STATE(4664)] = 142347,
  [SMALL_STATE(4665)] = 142483,
  [SMALL_STATE(4666)] = 142553,
  [SMALL_STATE(4667)] = 142689,
  [SMALL_STATE(4668)] = 142759,
  [SMALL_STATE(4669)] = 142829,
  [SMALL_STATE(4670)] = 142899,
  [SMALL_STATE(4671)] = 142969,
  [SMALL_STATE(4672)] = 143039,
  [SMALL_STATE(4673)] = 143109,
  [SMALL_STATE(4674)] = 143245,
  [SMALL_STATE(4675)] = 143315,
  [SMALL_STATE(4676)] = 143433,
  [SMALL_STATE(4677)] = 143503,
  [SMALL_STATE(4678)] = 143621,
  [SMALL_STATE(4679)] = 143739,
  [SMALL_STATE(4680)] = 143857,
  [SMALL_STATE(4681)] = 143927,
  [SMALL_STATE(4682)] = 144045,
  [SMALL_STATE(4683)] = 144163,
  [SMALL_STATE(4684)] = 144233,
  [SMALL_STATE(4685)] = 144369,
  [SMALL_STATE(4686)] = 144487,
  [SMALL_STATE(4687)] = 144623,
  [SMALL_STATE(4688)] = 144759,
  [SMALL_STATE(4689)] = 144895,
  [SMALL_STATE(4690)] = 145013,
  [SMALL_STATE(4691)] = 145149,
  [SMALL_STATE(4692)] = 145219,
  [SMALL_STATE(4693)] = 145337,
  [SMALL_STATE(4694)] = 145455,
  [SMALL_STATE(4695)] = 145573,
  [SMALL_STATE(4696)] = 145643,
  [SMALL_STATE(4697)] = 145713,
  [SMALL_STATE(4698)] = 145831,
  [SMALL_STATE(4699)] = 145949,
  [SMALL_STATE(4700)] = 146019,
  [SMALL_STATE(4701)] = 146137,
  [SMALL_STATE(4702)] = 146255,
  [SMALL_STATE(4703)] = 146325,
  [SMALL_STATE(4704)] = 146443,
  [SMALL_STATE(4705)] = 146561,
  [SMALL_STATE(4706)] = 146679,
  [SMALL_STATE(4707)] = 146815,
  [SMALL_STATE(4708)] = 146885,
  [SMALL_STATE(4709)] = 147021,
  [SMALL_STATE(4710)] = 147091,
  [SMALL_STATE(4711)] = 147209,
  [SMALL_STATE(4712)] = 147327,
  [SMALL_STATE(4713)] = 147445,
  [SMALL_STATE(4714)] = 147563,
  [SMALL_STATE(4715)] = 147681,
  [SMALL_STATE(4716)] = 147799,
  [SMALL_STATE(4717)] = 147917,
  [SMALL_STATE(4718)] = 148035,
  [SMALL_STATE(4719)] = 148153,
  [SMALL_STATE(4720)] = 148223,
  [SMALL_STATE(4721)] = 148293,
  [SMALL_STATE(4722)] = 148411,
  [SMALL_STATE(4723)] = 148529,
  [SMALL_STATE(4724)] = 148647,
  [SMALL_STATE(4725)] = 148765,
  [SMALL_STATE(4726)] = 148883,
  [SMALL_STATE(4727)] = 149001,
  [SMALL_STATE(4728)] = 149119,
  [SMALL_STATE(4729)] = 149237,
  [SMALL_STATE(4730)] = 149355,
  [SMALL_STATE(4731)] = 149473,
  [SMALL_STATE(4732)] = 149545,
  [SMALL_STATE(4733)] = 149663,
  [SMALL_STATE(4734)] = 149733,
  [SMALL_STATE(4735)] = 149851,
  [SMALL_STATE(4736)] = 149921,
  [SMALL_STATE(4737)] = 149991,
  [SMALL_STATE(4738)] = 150061,
  [SMALL_STATE(4739)] = 150131,
  [SMALL_STATE(4740)] = 150201,
  [SMALL_STATE(4741)] = 150319,
  [SMALL_STATE(4742)] = 150389,
  [SMALL_STATE(4743)] = 150507,
  [SMALL_STATE(4744)] = 150577,
  [SMALL_STATE(4745)] = 150695,
  [SMALL_STATE(4746)] = 150831,
  [SMALL_STATE(4747)] = 150967,
  [SMALL_STATE(4748)] = 151103,
  [SMALL_STATE(4749)] = 151239,
  [SMALL_STATE(4750)] = 151375,
  [SMALL_STATE(4751)] = 151445,
  [SMALL_STATE(4752)] = 151515,
  [SMALL_STATE(4753)] = 151585,
  [SMALL_STATE(4754)] = 151655,
  [SMALL_STATE(4755)] = 151773,
  [SMALL_STATE(4756)] = 151891,
  [SMALL_STATE(4757)] = 152009,
  [SMALL_STATE(4758)] = 152127,
  [SMALL_STATE(4759)] = 152197,
  [SMALL_STATE(4760)] = 152267,
  [SMALL_STATE(4761)] = 152343,
  [SMALL_STATE(4762)] = 152461,
  [SMALL_STATE(4763)] = 152579,
  [SMALL_STATE(4764)] = 152649,
  [SMALL_STATE(4765)] = 152785,
  [SMALL_STATE(4766)] = 152855,
  [SMALL_STATE(4767)] = 152925,
  [SMALL_STATE(4768)] = 152995,
  [SMALL_STATE(4769)] = 153064,
  [SMALL_STATE(4770)] = 153133,
  [SMALL_STATE(4771)] = 153202,
  [SMALL_STATE(4772)] = 153273,
  [SMALL_STATE(4773)] = 153344,
  [SMALL_STATE(4774)] = 153413,
  [SMALL_STATE(4775)] = 153481,
  [SMALL_STATE(4776)] = 153551,
  [SMALL_STATE(4777)] = 153619,
  [SMALL_STATE(4778)] = 153687,
  [SMALL_STATE(4779)] = 153757,
  [SMALL_STATE(4780)] = 153825,
  [SMALL_STATE(4781)] = 153892,
  [SMALL_STATE(4782)] = 153959,
  [SMALL_STATE(4783)] = 154080,
  [SMALL_STATE(4784)] = 154147,
  [SMALL_STATE(4785)] = 154262,
  [SMALL_STATE(4786)] = 154331,
  [SMALL_STATE(4787)] = 154398,
  [SMALL_STATE(4788)] = 154519,
  [SMALL_STATE(4789)] = 154590,
  [SMALL_STATE(4790)] = 154661,
  [SMALL_STATE(4791)] = 154782,
  [SMALL_STATE(4792)] = 154903,
  [SMALL_STATE(4793)] = 155024,
  [SMALL_STATE(4794)] = 155142,
  [SMALL_STATE(4795)] = 155260,
  [SMALL_STATE(4796)] = 155378,
  [SMALL_STATE(4797)] = 155496,
  [SMALL_STATE(4798)] = 155614,
  [SMALL_STATE(4799)] = 155732,
  [SMALL_STATE(4800)] = 155850,
  [SMALL_STATE(4801)] = 155968,
  [SMALL_STATE(4802)] = 156086,
  [SMALL_STATE(4803)] = 156204,
  [SMALL_STATE(4804)] = 156270,
  [SMALL_STATE(4805)] = 156388,
  [SMALL_STATE(4806)] = 156506,
  [SMALL_STATE(4807)] = 156624,
  [SMALL_STATE(4808)] = 156742,
  [SMALL_STATE(4809)] = 156860,
  [SMALL_STATE(4810)] = 156978,
  [SMALL_STATE(4811)] = 157044,
  [SMALL_STATE(4812)] = 157112,
  [SMALL_STATE(4813)] = 157230,
  [SMALL_STATE(4814)] = 157348,
  [SMALL_STATE(4815)] = 157466,
  [SMALL_STATE(4816)] = 157584,
  [SMALL_STATE(4817)] = 157702,
  [SMALL_STATE(4818)] = 157820,
  [SMALL_STATE(4819)] = 157938,
  [SMALL_STATE(4820)] = 158056,
  [SMALL_STATE(4821)] = 158174,
  [SMALL_STATE(4822)] = 158292,
  [SMALL_STATE(4823)] = 158410,
  [SMALL_STATE(4824)] = 158528,
  [SMALL_STATE(4825)] = 158646,
  [SMALL_STATE(4826)] = 158764,
  [SMALL_STATE(4827)] = 158882,
  [SMALL_STATE(4828)] = 159000,
  [SMALL_STATE(4829)] = 159118,
  [SMALL_STATE(4830)] = 159236,
  [SMALL_STATE(4831)] = 159302,
  [SMALL_STATE(4832)] = 159420,
  [SMALL_STATE(4833)] = 159538,
  [SMALL_STATE(4834)] = 159656,
  [SMALL_STATE(4835)] = 159722,
  [SMALL_STATE(4836)] = 159840,
  [SMALL_STATE(4837)] = 159958,
  [SMALL_STATE(4838)] = 160076,
  [SMALL_STATE(4839)] = 160194,
  [SMALL_STATE(4840)] = 160312,
  [SMALL_STATE(4841)] = 160430,
  [SMALL_STATE(4842)] = 160498,
  [SMALL_STATE(4843)] = 160616,
  [SMALL_STATE(4844)] = 160734,
  [SMALL_STATE(4845)] = 160852,
  [SMALL_STATE(4846)] = 160970,
  [SMALL_STATE(4847)] = 161088,
  [SMALL_STATE(4848)] = 161206,
  [SMALL_STATE(4849)] = 161324,
  [SMALL_STATE(4850)] = 161442,
  [SMALL_STATE(4851)] = 161560,
  [SMALL_STATE(4852)] = 161678,
  [SMALL_STATE(4853)] = 161796,
  [SMALL_STATE(4854)] = 161914,
  [SMALL_STATE(4855)] = 162032,
  [SMALL_STATE(4856)] = 162150,
  [SMALL_STATE(4857)] = 162268,
  [SMALL_STATE(4858)] = 162386,
  [SMALL_STATE(4859)] = 162504,
  [SMALL_STATE(4860)] = 162622,
  [SMALL_STATE(4861)] = 162688,
  [SMALL_STATE(4862)] = 162806,
  [SMALL_STATE(4863)] = 162924,
  [SMALL_STATE(4864)] = 163042,
  [SMALL_STATE(4865)] = 163160,
  [SMALL_STATE(4866)] = 163278,
  [SMALL_STATE(4867)] = 163396,
  [SMALL_STATE(4868)] = 163514,
  [SMALL_STATE(4869)] = 163632,
  [SMALL_STATE(4870)] = 163750,
  [SMALL_STATE(4871)] = 163868,
  [SMALL_STATE(4872)] = 163986,
  [SMALL_STATE(4873)] = 164052,
  [SMALL_STATE(4874)] = 164170,
  [SMALL_STATE(4875)] = 164288,
  [SMALL_STATE(4876)] = 164406,
  [SMALL_STATE(4877)] = 164524,
  [SMALL_STATE(4878)] = 164642,
  [SMALL_STATE(4879)] = 164760,
  [SMALL_STATE(4880)] = 164878,
  [SMALL_STATE(4881)] = 164996,
  [SMALL_STATE(4882)] = 165114,
  [SMALL_STATE(4883)] = 165232,
  [SMALL_STATE(4884)] = 165350,
  [SMALL_STATE(4885)] = 165468,
  [SMALL_STATE(4886)] = 165586,
  [SMALL_STATE(4887)] = 165704,
  [SMALL_STATE(4888)] = 165822,
  [SMALL_STATE(4889)] = 165940,
  [SMALL_STATE(4890)] = 166058,
  [SMALL_STATE(4891)] = 166124,
  [SMALL_STATE(4892)] = 166242,
  [SMALL_STATE(4893)] = 166308,
  [SMALL_STATE(4894)] = 166374,
  [SMALL_STATE(4895)] = 166440,
  [SMALL_STATE(4896)] = 166558,
  [SMALL_STATE(4897)] = 166676,
  [SMALL_STATE(4898)] = 166741,
  [SMALL_STATE(4899)] = 166856,
  [SMALL_STATE(4900)] = 166921,
  [SMALL_STATE(4901)] = 166986,
  [SMALL_STATE(4902)] = 167053,
  [SMALL_STATE(4903)] = 167168,
  [SMALL_STATE(4904)] = 167233,
  [SMALL_STATE(4905)] = 167298,
  [SMALL_STATE(4906)] = 167413,
  [SMALL_STATE(4907)] = 167528,
  [SMALL_STATE(4908)] = 167643,
  [SMALL_STATE(4909)] = 167708,
  [SMALL_STATE(4910)] = 167773,
  [SMALL_STATE(4911)] = 167838,
  [SMALL_STATE(4912)] = 167903,
  [SMALL_STATE(4913)] = 167968,
  [SMALL_STATE(4914)] = 168033,
  [SMALL_STATE(4915)] = 168148,
  [SMALL_STATE(4916)] = 168213,
  [SMALL_STATE(4917)] = 168328,
  [SMALL_STATE(4918)] = 168443,
  [SMALL_STATE(4919)] = 168508,
  [SMALL_STATE(4920)] = 168623,
  [SMALL_STATE(4921)] = 168738,
  [SMALL_STATE(4922)] = 168803,
  [SMALL_STATE(4923)] = 168918,
  [SMALL_STATE(4924)] = 168983,
  [SMALL_STATE(4925)] = 169098,
  [SMALL_STATE(4926)] = 169163,
  [SMALL_STATE(4927)] = 169228,
  [SMALL_STATE(4928)] = 169293,
  [SMALL_STATE(4929)] = 169358,
  [SMALL_STATE(4930)] = 169423,
  [SMALL_STATE(4931)] = 169538,
  [SMALL_STATE(4932)] = 169603,
  [SMALL_STATE(4933)] = 169668,
  [SMALL_STATE(4934)] = 169733,
  [SMALL_STATE(4935)] = 169848,
  [SMALL_STATE(4936)] = 169963,
  [SMALL_STATE(4937)] = 170078,
  [SMALL_STATE(4938)] = 170193,
  [SMALL_STATE(4939)] = 170308,
  [SMALL_STATE(4940)] = 170375,
  [SMALL_STATE(4941)] = 170440,
  [SMALL_STATE(4942)] = 170555,
  [SMALL_STATE(4943)] = 170620,
  [SMALL_STATE(4944)] = 170735,
  [SMALL_STATE(4945)] = 170850,
  [SMALL_STATE(4946)] = 170917,
  [SMALL_STATE(4947)] = 170984,
  [SMALL_STATE(4948)] = 171099,
  [SMALL_STATE(4949)] = 171164,
  [SMALL_STATE(4950)] = 171279,
  [SMALL_STATE(4951)] = 171344,
  [SMALL_STATE(4952)] = 171409,
  [SMALL_STATE(4953)] = 171524,
  [SMALL_STATE(4954)] = 171589,
  [SMALL_STATE(4955)] = 171654,
  [SMALL_STATE(4956)] = 171719,
  [SMALL_STATE(4957)] = 171784,
  [SMALL_STATE(4958)] = 171849,
  [SMALL_STATE(4959)] = 171914,
  [SMALL_STATE(4960)] = 172029,
  [SMALL_STATE(4961)] = 172144,
  [SMALL_STATE(4962)] = 172209,
  [SMALL_STATE(4963)] = 172274,
  [SMALL_STATE(4964)] = 172339,
  [SMALL_STATE(4965)] = 172404,
  [SMALL_STATE(4966)] = 172519,
  [SMALL_STATE(4967)] = 172584,
  [SMALL_STATE(4968)] = 172649,
  [SMALL_STATE(4969)] = 172764,
  [SMALL_STATE(4970)] = 172829,
  [SMALL_STATE(4971)] = 172894,
  [SMALL_STATE(4972)] = 173009,
  [SMALL_STATE(4973)] = 173074,
  [SMALL_STATE(4974)] = 173139,
  [SMALL_STATE(4975)] = 173204,
  [SMALL_STATE(4976)] = 173271,
  [SMALL_STATE(4977)] = 173336,
  [SMALL_STATE(4978)] = 173451,
  [SMALL_STATE(4979)] = 173566,
  [SMALL_STATE(4980)] = 173631,
  [SMALL_STATE(4981)] = 173746,
  [SMALL_STATE(4982)] = 173861,
  [SMALL_STATE(4983)] = 173926,
  [SMALL_STATE(4984)] = 173991,
  [SMALL_STATE(4985)] = 174106,
  [SMALL_STATE(4986)] = 174221,
  [SMALL_STATE(4987)] = 174286,
  [SMALL_STATE(4988)] = 174401,
  [SMALL_STATE(4989)] = 174466,
  [SMALL_STATE(4990)] = 174581,
  [SMALL_STATE(4991)] = 174696,
  [SMALL_STATE(4992)] = 174763,
  [SMALL_STATE(4993)] = 174828,
  [SMALL_STATE(4994)] = 174893,
  [SMALL_STATE(4995)] = 174958,
  [SMALL_STATE(4996)] = 175023,
  [SMALL_STATE(4997)] = 175088,
  [SMALL_STATE(4998)] = 175153,
  [SMALL_STATE(4999)] = 175218,
  [SMALL_STATE(5000)] = 175333,
  [SMALL_STATE(5001)] = 175448,
  [SMALL_STATE(5002)] = 175563,
  [SMALL_STATE(5003)] = 175628,
  [SMALL_STATE(5004)] = 175693,
  [SMALL_STATE(5005)] = 175758,
  [SMALL_STATE(5006)] = 175823,
  [SMALL_STATE(5007)] = 175888,
  [SMALL_STATE(5008)] = 175953,
  [SMALL_STATE(5009)] = 176018,
  [SMALL_STATE(5010)] = 176133,
  [SMALL_STATE(5011)] = 176198,
  [SMALL_STATE(5012)] = 176263,
  [SMALL_STATE(5013)] = 176328,
  [SMALL_STATE(5014)] = 176393,
  [SMALL_STATE(5015)] = 176458,
  [SMALL_STATE(5016)] = 176523,
  [SMALL_STATE(5017)] = 176588,
  [SMALL_STATE(5018)] = 176653,
  [SMALL_STATE(5019)] = 176718,
  [SMALL_STATE(5020)] = 176783,
  [SMALL_STATE(5021)] = 176848,
  [SMALL_STATE(5022)] = 176913,
  [SMALL_STATE(5023)] = 176978,
  [SMALL_STATE(5024)] = 177049,
  [SMALL_STATE(5025)] = 177114,
  [SMALL_STATE(5026)] = 177229,
  [SMALL_STATE(5027)] = 177294,
  [SMALL_STATE(5028)] = 177409,
  [SMALL_STATE(5029)] = 177524,
  [SMALL_STATE(5030)] = 177595,
  [SMALL_STATE(5031)] = 177710,
  [SMALL_STATE(5032)] = 177775,
  [SMALL_STATE(5033)] = 177840,
  [SMALL_STATE(5034)] = 177904,
  [SMALL_STATE(5035)] = 177968,
  [SMALL_STATE(5036)] = 178032,
  [SMALL_STATE(5037)] = 178096,
  [SMALL_STATE(5038)] = 178160,
  [SMALL_STATE(5039)] = 178224,
  [SMALL_STATE(5040)] = 178288,
  [SMALL_STATE(5041)] = 178400,
  [SMALL_STATE(5042)] = 178464,
  [SMALL_STATE(5043)] = 178528,
  [SMALL_STATE(5044)] = 178592,
  [SMALL_STATE(5045)] = 178656,
  [SMALL_STATE(5046)] = 178720,
  [SMALL_STATE(5047)] = 178784,
  [SMALL_STATE(5048)] = 178848,
  [SMALL_STATE(5049)] = 178912,
  [SMALL_STATE(5050)] = 178976,
  [SMALL_STATE(5051)] = 179040,
  [SMALL_STATE(5052)] = 179104,
  [SMALL_STATE(5053)] = 179168,
  [SMALL_STATE(5054)] = 179232,
  [SMALL_STATE(5055)] = 179296,
  [SMALL_STATE(5056)] = 179362,
  [SMALL_STATE(5057)] = 179426,
  [SMALL_STATE(5058)] = 179496,
  [SMALL_STATE(5059)] = 179560,
  [SMALL_STATE(5060)] = 179624,
  [SMALL_STATE(5061)] = 179690,
  [SMALL_STATE(5062)] = 179754,
  [SMALL_STATE(5063)] = 179820,
  [SMALL_STATE(5064)] = 179884,
  [SMALL_STATE(5065)] = 179948,
  [SMALL_STATE(5066)] = 180012,
  [SMALL_STATE(5067)] = 180076,
  [SMALL_STATE(5068)] = 180140,
  [SMALL_STATE(5069)] = 180204,
  [SMALL_STATE(5070)] = 180268,
  [SMALL_STATE(5071)] = 180332,
  [SMALL_STATE(5072)] = 180396,
  [SMALL_STATE(5073)] = 180460,
  [SMALL_STATE(5074)] = 180572,
  [SMALL_STATE(5075)] = 180636,
  [SMALL_STATE(5076)] = 180700,
  [SMALL_STATE(5077)] = 180812,
  [SMALL_STATE(5078)] = 180876,
  [SMALL_STATE(5079)] = 180940,
  [SMALL_STATE(5080)] = 181004,
  [SMALL_STATE(5081)] = 181068,
  [SMALL_STATE(5082)] = 181132,
  [SMALL_STATE(5083)] = 181202,
  [SMALL_STATE(5084)] = 181266,
  [SMALL_STATE(5085)] = 181330,
  [SMALL_STATE(5086)] = 181394,
  [SMALL_STATE(5087)] = 181458,
  [SMALL_STATE(5088)] = 181524,
  [SMALL_STATE(5089)] = 181588,
  [SMALL_STATE(5090)] = 181652,
  [SMALL_STATE(5091)] = 181716,
  [SMALL_STATE(5092)] = 181780,
  [SMALL_STATE(5093)] = 181844,
  [SMALL_STATE(5094)] = 181910,
  [SMALL_STATE(5095)] = 181974,
  [SMALL_STATE(5096)] = 182038,
  [SMALL_STATE(5097)] = 182102,
  [SMALL_STATE(5098)] = 182166,
  [SMALL_STATE(5099)] = 182230,
  [SMALL_STATE(5100)] = 182294,
  [SMALL_STATE(5101)] = 182406,
  [SMALL_STATE(5102)] = 182470,
  [SMALL_STATE(5103)] = 182534,
  [SMALL_STATE(5104)] = 182598,
  [SMALL_STATE(5105)] = 182662,
  [SMALL_STATE(5106)] = 182728,
  [SMALL_STATE(5107)] = 182792,
  [SMALL_STATE(5108)] = 182856,
  [SMALL_STATE(5109)] = 182920,
  [SMALL_STATE(5110)] = 182984,
  [SMALL_STATE(5111)] = 183050,
  [SMALL_STATE(5112)] = 183114,
  [SMALL_STATE(5113)] = 183178,
  [SMALL_STATE(5114)] = 183290,
  [SMALL_STATE(5115)] = 183354,
  [SMALL_STATE(5116)] = 183418,
  [SMALL_STATE(5117)] = 183482,
  [SMALL_STATE(5118)] = 183546,
  [SMALL_STATE(5119)] = 183610,
  [SMALL_STATE(5120)] = 183674,
  [SMALL_STATE(5121)] = 183738,
  [SMALL_STATE(5122)] = 183802,
  [SMALL_STATE(5123)] = 183866,
  [SMALL_STATE(5124)] = 183930,
  [SMALL_STATE(5125)] = 183994,
  [SMALL_STATE(5126)] = 184106,
  [SMALL_STATE(5127)] = 184170,
  [SMALL_STATE(5128)] = 184234,
  [SMALL_STATE(5129)] = 184298,
  [SMALL_STATE(5130)] = 184362,
  [SMALL_STATE(5131)] = 184425,
  [SMALL_STATE(5132)] = 184534,
  [SMALL_STATE(5133)] = 184597,
  [SMALL_STATE(5134)] = 184706,
  [SMALL_STATE(5135)] = 184769,
  [SMALL_STATE(5136)] = 184878,
  [SMALL_STATE(5137)] = 184987,
  [SMALL_STATE(5138)] = 185096,
  [SMALL_STATE(5139)] = 185159,
  [SMALL_STATE(5140)] = 185268,
  [SMALL_STATE(5141)] = 185331,
  [SMALL_STATE(5142)] = 185394,
  [SMALL_STATE(5143)] = 185503,
  [SMALL_STATE(5144)] = 185566,
  [SMALL_STATE(5145)] = 185629,
  [SMALL_STATE(5146)] = 185692,
  [SMALL_STATE(5147)] = 185801,
  [SMALL_STATE(5148)] = 185864,
  [SMALL_STATE(5149)] = 185927,
  [SMALL_STATE(5150)] = 185990,
  [SMALL_STATE(5151)] = 186053,
  [SMALL_STATE(5152)] = 186162,
  [SMALL_STATE(5153)] = 186271,
  [SMALL_STATE(5154)] = 186380,
  [SMALL_STATE(5155)] = 186443,
  [SMALL_STATE(5156)] = 186506,
  [SMALL_STATE(5157)] = 186569,
  [SMALL_STATE(5158)] = 186678,
  [SMALL_STATE(5159)] = 186787,
  [SMALL_STATE(5160)] = 186850,
  [SMALL_STATE(5161)] = 186913,
  [SMALL_STATE(5162)] = 186976,
  [SMALL_STATE(5163)] = 187085,
  [SMALL_STATE(5164)] = 187194,
  [SMALL_STATE(5165)] = 187257,
  [SMALL_STATE(5166)] = 187366,
  [SMALL_STATE(5167)] = 187475,
  [SMALL_STATE(5168)] = 187584,
  [SMALL_STATE(5169)] = 187693,
  [SMALL_STATE(5170)] = 187756,
  [SMALL_STATE(5171)] = 187819,
  [SMALL_STATE(5172)] = 187928,
  [SMALL_STATE(5173)] = 187991,
  [SMALL_STATE(5174)] = 188100,
  [SMALL_STATE(5175)] = 188165,
  [SMALL_STATE(5176)] = 188274,
  [SMALL_STATE(5177)] = 188383,
  [SMALL_STATE(5178)] = 188492,
  [SMALL_STATE(5179)] = 188555,
  [SMALL_STATE(5180)] = 188618,
  [SMALL_STATE(5181)] = 188727,
  [SMALL_STATE(5182)] = 188790,
  [SMALL_STATE(5183)] = 188853,
  [SMALL_STATE(5184)] = 188916,
  [SMALL_STATE(5185)] = 188979,
  [SMALL_STATE(5186)] = 189088,
  [SMALL_STATE(5187)] = 189153,
  [SMALL_STATE(5188)] = 189216,
  [SMALL_STATE(5189)] = 189279,
  [SMALL_STATE(5190)] = 189388,
  [SMALL_STATE(5191)] = 189451,
  [SMALL_STATE(5192)] = 189560,
  [SMALL_STATE(5193)] = 189669,
  [SMALL_STATE(5194)] = 189732,
  [SMALL_STATE(5195)] = 189841,
  [SMALL_STATE(5196)] = 189904,
  [SMALL_STATE(5197)] = 190013,
  [SMALL_STATE(5198)] = 190076,
  [SMALL_STATE(5199)] = 190139,
  [SMALL_STATE(5200)] = 190202,
  [SMALL_STATE(5201)] = 190311,
  [SMALL_STATE(5202)] = 190374,
  [SMALL_STATE(5203)] = 190437,
  [SMALL_STATE(5204)] = 190500,
  [SMALL_STATE(5205)] = 190609,
  [SMALL_STATE(5206)] = 190672,
  [SMALL_STATE(5207)] = 190781,
  [SMALL_STATE(5208)] = 190844,
  [SMALL_STATE(5209)] = 190953,
  [SMALL_STATE(5210)] = 191016,
  [SMALL_STATE(5211)] = 191079,
  [SMALL_STATE(5212)] = 191142,
  [SMALL_STATE(5213)] = 191251,
  [SMALL_STATE(5214)] = 191316,
  [SMALL_STATE(5215)] = 191379,
  [SMALL_STATE(5216)] = 191442,
  [SMALL_STATE(5217)] = 191551,
  [SMALL_STATE(5218)] = 191616,
  [SMALL_STATE(5219)] = 191679,
  [SMALL_STATE(5220)] = 191742,
  [SMALL_STATE(5221)] = 191851,
  [SMALL_STATE(5222)] = 191914,
  [SMALL_STATE(5223)] = 191979,
  [SMALL_STATE(5224)] = 192088,
  [SMALL_STATE(5225)] = 192197,
  [SMALL_STATE(5226)] = 192262,
  [SMALL_STATE(5227)] = 192371,
  [SMALL_STATE(5228)] = 192434,
  [SMALL_STATE(5229)] = 192543,
  [SMALL_STATE(5230)] = 192606,
  [SMALL_STATE(5231)] = 192715,
  [SMALL_STATE(5232)] = 192784,
  [SMALL_STATE(5233)] = 192893,
  [SMALL_STATE(5234)] = 193002,
  [SMALL_STATE(5235)] = 193113,
  [SMALL_STATE(5236)] = 193222,
  [SMALL_STATE(5237)] = 193285,
  [SMALL_STATE(5238)] = 193396,
  [SMALL_STATE(5239)] = 193505,
  [SMALL_STATE(5240)] = 193614,
  [SMALL_STATE(5241)] = 193677,
  [SMALL_STATE(5242)] = 193786,
  [SMALL_STATE(5243)] = 193855,
  [SMALL_STATE(5244)] = 193964,
  [SMALL_STATE(5245)] = 194027,
  [SMALL_STATE(5246)] = 194136,
  [SMALL_STATE(5247)] = 194199,
  [SMALL_STATE(5248)] = 194308,
  [SMALL_STATE(5249)] = 194371,
  [SMALL_STATE(5250)] = 194434,
  [SMALL_STATE(5251)] = 194497,
  [SMALL_STATE(5252)] = 194560,
  [SMALL_STATE(5253)] = 194623,
  [SMALL_STATE(5254)] = 194686,
  [SMALL_STATE(5255)] = 194797,
  [SMALL_STATE(5256)] = 194860,
  [SMALL_STATE(5257)] = 194923,
  [SMALL_STATE(5258)] = 194986,
  [SMALL_STATE(5259)] = 195049,
  [SMALL_STATE(5260)] = 195112,
  [SMALL_STATE(5261)] = 195175,
  [SMALL_STATE(5262)] = 195238,
  [SMALL_STATE(5263)] = 195301,
  [SMALL_STATE(5264)] = 195364,
  [SMALL_STATE(5265)] = 195427,
  [SMALL_STATE(5266)] = 195490,
  [SMALL_STATE(5267)] = 195553,
  [SMALL_STATE(5268)] = 195616,
  [SMALL_STATE(5269)] = 195679,
  [SMALL_STATE(5270)] = 195744,
  [SMALL_STATE(5271)] = 195807,
  [SMALL_STATE(5272)] = 195870,
  [SMALL_STATE(5273)] = 195933,
  [SMALL_STATE(5274)] = 195996,
  [SMALL_STATE(5275)] = 196059,
  [SMALL_STATE(5276)] = 196122,
  [SMALL_STATE(5277)] = 196185,
  [SMALL_STATE(5278)] = 196248,
  [SMALL_STATE(5279)] = 196311,
  [SMALL_STATE(5280)] = 196374,
  [SMALL_STATE(5281)] = 196437,
  [SMALL_STATE(5282)] = 196500,
  [SMALL_STATE(5283)] = 196563,
  [SMALL_STATE(5284)] = 196626,
  [SMALL_STATE(5285)] = 196689,
  [SMALL_STATE(5286)] = 196752,
  [SMALL_STATE(5287)] = 196815,
  [SMALL_STATE(5288)] = 196877,
  [SMALL_STATE(5289)] = 196939,
  [SMALL_STATE(5290)] = 197001,
  [SMALL_STATE(5291)] = 197063,
  [SMALL_STATE(5292)] = 197125,
  [SMALL_STATE(5293)] = 197187,
  [SMALL_STATE(5294)] = 197251,
  [SMALL_STATE(5295)] = 197313,
  [SMALL_STATE(5296)] = 197375,
  [SMALL_STATE(5297)] = 197437,
  [SMALL_STATE(5298)] = 197499,
  [SMALL_STATE(5299)] = 197561,
  [SMALL_STATE(5300)] = 197625,
  [SMALL_STATE(5301)] = 197687,
  [SMALL_STATE(5302)] = 197749,
  [SMALL_STATE(5303)] = 197811,
  [SMALL_STATE(5304)] = 197873,
  [SMALL_STATE(5305)] = 197935,
  [SMALL_STATE(5306)] = 197997,
  [SMALL_STATE(5307)] = 198059,
  [SMALL_STATE(5308)] = 198123,
  [SMALL_STATE(5309)] = 198185,
  [SMALL_STATE(5310)] = 198247,
  [SMALL_STATE(5311)] = 198309,
  [SMALL_STATE(5312)] = 198371,
  [SMALL_STATE(5313)] = 198433,
  [SMALL_STATE(5314)] = 198495,
  [SMALL_STATE(5315)] = 198557,
  [SMALL_STATE(5316)] = 198619,
  [SMALL_STATE(5317)] = 198681,
  [SMALL_STATE(5318)] = 198743,
  [SMALL_STATE(5319)] = 198805,
  [SMALL_STATE(5320)] = 198867,
  [SMALL_STATE(5321)] = 198931,
  [SMALL_STATE(5322)] = 198995,
  [SMALL_STATE(5323)] = 199057,
  [SMALL_STATE(5324)] = 199121,
  [SMALL_STATE(5325)] = 199183,
  [SMALL_STATE(5326)] = 199247,
  [SMALL_STATE(5327)] = 199309,
  [SMALL_STATE(5328)] = 199371,
  [SMALL_STATE(5329)] = 199433,
  [SMALL_STATE(5330)] = 199495,
  [SMALL_STATE(5331)] = 199557,
  [SMALL_STATE(5332)] = 199619,
  [SMALL_STATE(5333)] = 199681,
  [SMALL_STATE(5334)] = 199743,
  [SMALL_STATE(5335)] = 199805,
  [SMALL_STATE(5336)] = 199867,
  [SMALL_STATE(5337)] = 199929,
  [SMALL_STATE(5338)] = 199991,
  [SMALL_STATE(5339)] = 200053,
  [SMALL_STATE(5340)] = 200115,
  [SMALL_STATE(5341)] = 200177,
  [SMALL_STATE(5342)] = 200239,
  [SMALL_STATE(5343)] = 200301,
  [SMALL_STATE(5344)] = 200363,
  [SMALL_STATE(5345)] = 200425,
  [SMALL_STATE(5346)] = 200487,
  [SMALL_STATE(5347)] = 200549,
  [SMALL_STATE(5348)] = 200611,
  [SMALL_STATE(5349)] = 200673,
  [SMALL_STATE(5350)] = 200735,
  [SMALL_STATE(5351)] = 200797,
  [SMALL_STATE(5352)] = 200861,
  [SMALL_STATE(5353)] = 200923,
  [SMALL_STATE(5354)] = 200985,
  [SMALL_STATE(5355)] = 201049,
  [SMALL_STATE(5356)] = 201111,
  [SMALL_STATE(5357)] = 201173,
  [SMALL_STATE(5358)] = 201235,
  [SMALL_STATE(5359)] = 201297,
  [SMALL_STATE(5360)] = 201359,
  [SMALL_STATE(5361)] = 201423,
  [SMALL_STATE(5362)] = 201485,
  [SMALL_STATE(5363)] = 201547,
  [SMALL_STATE(5364)] = 201609,
  [SMALL_STATE(5365)] = 201671,
  [SMALL_STATE(5366)] = 201733,
  [SMALL_STATE(5367)] = 201795,
  [SMALL_STATE(5368)] = 201857,
  [SMALL_STATE(5369)] = 201919,
  [SMALL_STATE(5370)] = 201981,
  [SMALL_STATE(5371)] = 202043,
  [SMALL_STATE(5372)] = 202105,
  [SMALL_STATE(5373)] = 202167,
  [SMALL_STATE(5374)] = 202229,
  [SMALL_STATE(5375)] = 202291,
  [SMALL_STATE(5376)] = 202353,
  [SMALL_STATE(5377)] = 202415,
  [SMALL_STATE(5378)] = 202477,
  [SMALL_STATE(5379)] = 202539,
  [SMALL_STATE(5380)] = 202601,
  [SMALL_STATE(5381)] = 202663,
  [SMALL_STATE(5382)] = 202725,
  [SMALL_STATE(5383)] = 202787,
  [SMALL_STATE(5384)] = 202849,
  [SMALL_STATE(5385)] = 202911,
  [SMALL_STATE(5386)] = 202973,
  [SMALL_STATE(5387)] = 203035,
  [SMALL_STATE(5388)] = 203097,
  [SMALL_STATE(5389)] = 203159,
  [SMALL_STATE(5390)] = 203221,
  [SMALL_STATE(5391)] = 203289,
  [SMALL_STATE(5392)] = 203351,
  [SMALL_STATE(5393)] = 203413,
  [SMALL_STATE(5394)] = 203475,
  [SMALL_STATE(5395)] = 203537,
  [SMALL_STATE(5396)] = 203599,
  [SMALL_STATE(5397)] = 203661,
  [SMALL_STATE(5398)] = 203723,
  [SMALL_STATE(5399)] = 203785,
  [SMALL_STATE(5400)] = 203847,
  [SMALL_STATE(5401)] = 203915,
  [SMALL_STATE(5402)] = 203977,
  [SMALL_STATE(5403)] = 204045,
  [SMALL_STATE(5404)] = 204107,
  [SMALL_STATE(5405)] = 204169,
  [SMALL_STATE(5406)] = 204231,
  [SMALL_STATE(5407)] = 204293,
  [SMALL_STATE(5408)] = 204355,
  [SMALL_STATE(5409)] = 204417,
  [SMALL_STATE(5410)] = 204479,
  [SMALL_STATE(5411)] = 204547,
  [SMALL_STATE(5412)] = 204609,
  [SMALL_STATE(5413)] = 204671,
  [SMALL_STATE(5414)] = 204733,
  [SMALL_STATE(5415)] = 204795,
  [SMALL_STATE(5416)] = 204857,
  [SMALL_STATE(5417)] = 204919,
  [SMALL_STATE(5418)] = 204981,
  [SMALL_STATE(5419)] = 205043,
  [SMALL_STATE(5420)] = 205105,
  [SMALL_STATE(5421)] = 205167,
  [SMALL_STATE(5422)] = 205229,
  [SMALL_STATE(5423)] = 205291,
  [SMALL_STATE(5424)] = 205353,
  [SMALL_STATE(5425)] = 205417,
  [SMALL_STATE(5426)] = 205479,
  [SMALL_STATE(5427)] = 205541,
  [SMALL_STATE(5428)] = 205603,
  [SMALL_STATE(5429)] = 205665,
  [SMALL_STATE(5430)] = 205727,
  [SMALL_STATE(5431)] = 205789,
  [SMALL_STATE(5432)] = 205851,
  [SMALL_STATE(5433)] = 205913,
  [SMALL_STATE(5434)] = 205975,
  [SMALL_STATE(5435)] = 206037,
  [SMALL_STATE(5436)] = 206099,
  [SMALL_STATE(5437)] = 206161,
  [SMALL_STATE(5438)] = 206223,
  [SMALL_STATE(5439)] = 206287,
  [SMALL_STATE(5440)] = 206349,
  [SMALL_STATE(5441)] = 206411,
  [SMALL_STATE(5442)] = 206473,
  [SMALL_STATE(5443)] = 206535,
  [SMALL_STATE(5444)] = 206597,
  [SMALL_STATE(5445)] = 206659,
  [SMALL_STATE(5446)] = 206721,
  [SMALL_STATE(5447)] = 206783,
  [SMALL_STATE(5448)] = 206847,
  [SMALL_STATE(5449)] = 206909,
  [SMALL_STATE(5450)] = 206971,
  [SMALL_STATE(5451)] = 207033,
  [SMALL_STATE(5452)] = 207095,
  [SMALL_STATE(5453)] = 207157,
  [SMALL_STATE(5454)] = 207219,
  [SMALL_STATE(5455)] = 207281,
  [SMALL_STATE(5456)] = 207343,
  [SMALL_STATE(5457)] = 207405,
  [SMALL_STATE(5458)] = 207467,
  [SMALL_STATE(5459)] = 207529,
  [SMALL_STATE(5460)] = 207593,
  [SMALL_STATE(5461)] = 207655,
  [SMALL_STATE(5462)] = 207717,
  [SMALL_STATE(5463)] = 207778,
  [SMALL_STATE(5464)] = 207839,
  [SMALL_STATE(5465)] = 207900,
  [SMALL_STATE(5466)] = 207961,
  [SMALL_STATE(5467)] = 208022,
  [SMALL_STATE(5468)] = 208083,
  [SMALL_STATE(5469)] = 208144,
  [SMALL_STATE(5470)] = 208205,
  [SMALL_STATE(5471)] = 208268,
  [SMALL_STATE(5472)] = 208329,
  [SMALL_STATE(5473)] = 208390,
  [SMALL_STATE(5474)] = 208451,
  [SMALL_STATE(5475)] = 208512,
  [SMALL_STATE(5476)] = 208573,
  [SMALL_STATE(5477)] = 208634,
  [SMALL_STATE(5478)] = 208695,
  [SMALL_STATE(5479)] = 208762,
  [SMALL_STATE(5480)] = 208823,
  [SMALL_STATE(5481)] = 208884,
  [SMALL_STATE(5482)] = 208945,
  [SMALL_STATE(5483)] = 209008,
  [SMALL_STATE(5484)] = 209069,
  [SMALL_STATE(5485)] = 209130,
  [SMALL_STATE(5486)] = 209191,
  [SMALL_STATE(5487)] = 209252,
  [SMALL_STATE(5488)] = 209313,
  [SMALL_STATE(5489)] = 209376,
  [SMALL_STATE(5490)] = 209437,
  [SMALL_STATE(5491)] = 209498,
  [SMALL_STATE(5492)] = 209559,
  [SMALL_STATE(5493)] = 209620,
  [SMALL_STATE(5494)] = 209681,
  [SMALL_STATE(5495)] = 209744,
  [SMALL_STATE(5496)] = 209807,
  [SMALL_STATE(5497)] = 209868,
  [SMALL_STATE(5498)] = 209931,
  [SMALL_STATE(5499)] = 209992,
  [SMALL_STATE(5500)] = 210053,
  [SMALL_STATE(5501)] = 210114,
  [SMALL_STATE(5502)] = 210175,
  [SMALL_STATE(5503)] = 210236,
  [SMALL_STATE(5504)] = 210297,
  [SMALL_STATE(5505)] = 210358,
  [SMALL_STATE(5506)] = 210419,
  [SMALL_STATE(5507)] = 210480,
  [SMALL_STATE(5508)] = 210541,
  [SMALL_STATE(5509)] = 210602,
  [SMALL_STATE(5510)] = 210663,
  [SMALL_STATE(5511)] = 210724,
  [SMALL_STATE(5512)] = 210787,
  [SMALL_STATE(5513)] = 210848,
  [SMALL_STATE(5514)] = 210909,
  [SMALL_STATE(5515)] = 210970,
  [SMALL_STATE(5516)] = 211031,
  [SMALL_STATE(5517)] = 211092,
  [SMALL_STATE(5518)] = 211153,
  [SMALL_STATE(5519)] = 211214,
  [SMALL_STATE(5520)] = 211275,
  [SMALL_STATE(5521)] = 211336,
  [SMALL_STATE(5522)] = 211397,
  [SMALL_STATE(5523)] = 211458,
  [SMALL_STATE(5524)] = 211519,
  [SMALL_STATE(5525)] = 211582,
  [SMALL_STATE(5526)] = 211643,
  [SMALL_STATE(5527)] = 211704,
  [SMALL_STATE(5528)] = 211765,
  [SMALL_STATE(5529)] = 211826,
  [SMALL_STATE(5530)] = 211887,
  [SMALL_STATE(5531)] = 211948,
  [SMALL_STATE(5532)] = 212009,
  [SMALL_STATE(5533)] = 212070,
  [SMALL_STATE(5534)] = 212131,
  [SMALL_STATE(5535)] = 212192,
  [SMALL_STATE(5536)] = 212253,
  [SMALL_STATE(5537)] = 212314,
  [SMALL_STATE(5538)] = 212375,
  [SMALL_STATE(5539)] = 212438,
  [SMALL_STATE(5540)] = 212499,
  [SMALL_STATE(5541)] = 212562,
  [SMALL_STATE(5542)] = 212623,
  [SMALL_STATE(5543)] = 212684,
  [SMALL_STATE(5544)] = 212745,
  [SMALL_STATE(5545)] = 212806,
  [SMALL_STATE(5546)] = 212867,
  [SMALL_STATE(5547)] = 212928,
  [SMALL_STATE(5548)] = 212989,
  [SMALL_STATE(5549)] = 213050,
  [SMALL_STATE(5550)] = 213111,
  [SMALL_STATE(5551)] = 213172,
  [SMALL_STATE(5552)] = 213233,
  [SMALL_STATE(5553)] = 213294,
  [SMALL_STATE(5554)] = 213355,
  [SMALL_STATE(5555)] = 213416,
  [SMALL_STATE(5556)] = 213477,
  [SMALL_STATE(5557)] = 213538,
  [SMALL_STATE(5558)] = 213599,
  [SMALL_STATE(5559)] = 213660,
  [SMALL_STATE(5560)] = 213721,
  [SMALL_STATE(5561)] = 213782,
  [SMALL_STATE(5562)] = 213843,
  [SMALL_STATE(5563)] = 213906,
  [SMALL_STATE(5564)] = 213967,
  [SMALL_STATE(5565)] = 214028,
  [SMALL_STATE(5566)] = 214089,
  [SMALL_STATE(5567)] = 214150,
  [SMALL_STATE(5568)] = 214211,
  [SMALL_STATE(5569)] = 214272,
  [SMALL_STATE(5570)] = 214333,
  [SMALL_STATE(5571)] = 214394,
  [SMALL_STATE(5572)] = 214457,
  [SMALL_STATE(5573)] = 214518,
  [SMALL_STATE(5574)] = 214579,
  [SMALL_STATE(5575)] = 214640,
  [SMALL_STATE(5576)] = 214701,
  [SMALL_STATE(5577)] = 214768,
  [SMALL_STATE(5578)] = 214829,
  [SMALL_STATE(5579)] = 214890,
  [SMALL_STATE(5580)] = 214951,
  [SMALL_STATE(5581)] = 215014,
  [SMALL_STATE(5582)] = 215075,
  [SMALL_STATE(5583)] = 215136,
  [SMALL_STATE(5584)] = 215196,
  [SMALL_STATE(5585)] = 215256,
  [SMALL_STATE(5586)] = 215316,
  [SMALL_STATE(5587)] = 215376,
  [SMALL_STATE(5588)] = 215436,
  [SMALL_STATE(5589)] = 215496,
  [SMALL_STATE(5590)] = 215556,
  [SMALL_STATE(5591)] = 215616,
  [SMALL_STATE(5592)] = 215676,
  [SMALL_STATE(5593)] = 215736,
  [SMALL_STATE(5594)] = 215796,
  [SMALL_STATE(5595)] = 215856,
  [SMALL_STATE(5596)] = 215916,
  [SMALL_STATE(5597)] = 215976,
  [SMALL_STATE(5598)] = 216036,
  [SMALL_STATE(5599)] = 216096,
  [SMALL_STATE(5600)] = 216156,
  [SMALL_STATE(5601)] = 216216,
  [SMALL_STATE(5602)] = 216276,
  [SMALL_STATE(5603)] = 216336,
  [SMALL_STATE(5604)] = 216396,
  [SMALL_STATE(5605)] = 216456,
  [SMALL_STATE(5606)] = 216516,
  [SMALL_STATE(5607)] = 216580,
  [SMALL_STATE(5608)] = 216642,
  [SMALL_STATE(5609)] = 216702,
  [SMALL_STATE(5610)] = 216762,
  [SMALL_STATE(5611)] = 216822,
  [SMALL_STATE(5612)] = 216882,
  [SMALL_STATE(5613)] = 216942,
  [SMALL_STATE(5614)] = 217002,
  [SMALL_STATE(5615)] = 217064,
  [SMALL_STATE(5616)] = 217124,
  [SMALL_STATE(5617)] = 217184,
  [SMALL_STATE(5618)] = 217244,
  [SMALL_STATE(5619)] = 217304,
  [SMALL_STATE(5620)] = 217364,
  [SMALL_STATE(5621)] = 217430,
  [SMALL_STATE(5622)] = 217490,
  [SMALL_STATE(5623)] = 217550,
  [SMALL_STATE(5624)] = 217610,
  [SMALL_STATE(5625)] = 217672,
  [SMALL_STATE(5626)] = 217732,
  [SMALL_STATE(5627)] = 217792,
  [SMALL_STATE(5628)] = 217852,
  [SMALL_STATE(5629)] = 217912,
  [SMALL_STATE(5630)] = 217972,
  [SMALL_STATE(5631)] = 218032,
  [SMALL_STATE(5632)] = 218092,
  [SMALL_STATE(5633)] = 218152,
  [SMALL_STATE(5634)] = 218212,
  [SMALL_STATE(5635)] = 218272,
  [SMALL_STATE(5636)] = 218334,
  [SMALL_STATE(5637)] = 218396,
  [SMALL_STATE(5638)] = 218456,
  [SMALL_STATE(5639)] = 218518,
  [SMALL_STATE(5640)] = 218578,
  [SMALL_STATE(5641)] = 218638,
  [SMALL_STATE(5642)] = 218698,
  [SMALL_STATE(5643)] = 218760,
  [SMALL_STATE(5644)] = 218820,
  [SMALL_STATE(5645)] = 218880,
  [SMALL_STATE(5646)] = 218940,
  [SMALL_STATE(5647)] = 219000,
  [SMALL_STATE(5648)] = 219060,
  [SMALL_STATE(5649)] = 219120,
  [SMALL_STATE(5650)] = 219180,
  [SMALL_STATE(5651)] = 219240,
  [SMALL_STATE(5652)] = 219300,
  [SMALL_STATE(5653)] = 219360,
  [SMALL_STATE(5654)] = 219424,
  [SMALL_STATE(5655)] = 219484,
  [SMALL_STATE(5656)] = 219544,
  [SMALL_STATE(5657)] = 219604,
  [SMALL_STATE(5658)] = 219664,
  [SMALL_STATE(5659)] = 219724,
  [SMALL_STATE(5660)] = 219784,
  [SMALL_STATE(5661)] = 219846,
  [SMALL_STATE(5662)] = 219908,
  [SMALL_STATE(5663)] = 219968,
  [SMALL_STATE(5664)] = 220028,
  [SMALL_STATE(5665)] = 220088,
  [SMALL_STATE(5666)] = 220148,
  [SMALL_STATE(5667)] = 220208,
  [SMALL_STATE(5668)] = 220268,
  [SMALL_STATE(5669)] = 220328,
  [SMALL_STATE(5670)] = 220388,
  [SMALL_STATE(5671)] = 220448,
  [SMALL_STATE(5672)] = 220508,
  [SMALL_STATE(5673)] = 220568,
  [SMALL_STATE(5674)] = 220628,
  [SMALL_STATE(5675)] = 220688,
  [SMALL_STATE(5676)] = 220748,
  [SMALL_STATE(5677)] = 220808,
  [SMALL_STATE(5678)] = 220868,
  [SMALL_STATE(5679)] = 220928,
  [SMALL_STATE(5680)] = 220988,
  [SMALL_STATE(5681)] = 221048,
  [SMALL_STATE(5682)] = 221108,
  [SMALL_STATE(5683)] = 221168,
  [SMALL_STATE(5684)] = 221228,
  [SMALL_STATE(5685)] = 221288,
  [SMALL_STATE(5686)] = 221348,
  [SMALL_STATE(5687)] = 221408,
  [SMALL_STATE(5688)] = 221468,
  [SMALL_STATE(5689)] = 221528,
  [SMALL_STATE(5690)] = 221590,
  [SMALL_STATE(5691)] = 221650,
  [SMALL_STATE(5692)] = 221710,
  [SMALL_STATE(5693)] = 221770,
  [SMALL_STATE(5694)] = 221830,
  [SMALL_STATE(5695)] = 221890,
  [SMALL_STATE(5696)] = 221950,
  [SMALL_STATE(5697)] = 222010,
  [SMALL_STATE(5698)] = 222070,
  [SMALL_STATE(5699)] = 222130,
  [SMALL_STATE(5700)] = 222190,
  [SMALL_STATE(5701)] = 222250,
  [SMALL_STATE(5702)] = 222310,
  [SMALL_STATE(5703)] = 222370,
  [SMALL_STATE(5704)] = 222430,
  [SMALL_STATE(5705)] = 222490,
  [SMALL_STATE(5706)] = 222550,
  [SMALL_STATE(5707)] = 222610,
  [SMALL_STATE(5708)] = 222670,
  [SMALL_STATE(5709)] = 222730,
  [SMALL_STATE(5710)] = 222790,
  [SMALL_STATE(5711)] = 222850,
  [SMALL_STATE(5712)] = 222910,
  [SMALL_STATE(5713)] = 222970,
  [SMALL_STATE(5714)] = 223030,
  [SMALL_STATE(5715)] = 223090,
  [SMALL_STATE(5716)] = 223150,
  [SMALL_STATE(5717)] = 223210,
  [SMALL_STATE(5718)] = 223270,
  [SMALL_STATE(5719)] = 223330,
  [SMALL_STATE(5720)] = 223390,
  [SMALL_STATE(5721)] = 223450,
  [SMALL_STATE(5722)] = 223510,
  [SMALL_STATE(5723)] = 223572,
  [SMALL_STATE(5724)] = 223632,
  [SMALL_STATE(5725)] = 223692,
  [SMALL_STATE(5726)] = 223758,
  [SMALL_STATE(5727)] = 223818,
  [SMALL_STATE(5728)] = 223878,
  [SMALL_STATE(5729)] = 223938,
  [SMALL_STATE(5730)] = 223998,
  [SMALL_STATE(5731)] = 224058,
  [SMALL_STATE(5732)] = 224118,
  [SMALL_STATE(5733)] = 224178,
  [SMALL_STATE(5734)] = 224238,
  [SMALL_STATE(5735)] = 224298,
  [SMALL_STATE(5736)] = 224358,
  [SMALL_STATE(5737)] = 224418,
  [SMALL_STATE(5738)] = 224478,
  [SMALL_STATE(5739)] = 224538,
  [SMALL_STATE(5740)] = 224598,
  [SMALL_STATE(5741)] = 224658,
  [SMALL_STATE(5742)] = 224718,
  [SMALL_STATE(5743)] = 224778,
  [SMALL_STATE(5744)] = 224840,
  [SMALL_STATE(5745)] = 224900,
  [SMALL_STATE(5746)] = 224960,
  [SMALL_STATE(5747)] = 225019,
  [SMALL_STATE(5748)] = 225078,
  [SMALL_STATE(5749)] = 225139,
  [SMALL_STATE(5750)] = 225198,
  [SMALL_STATE(5751)] = 225257,
  [SMALL_STATE(5752)] = 225316,
  [SMALL_STATE(5753)] = 225375,
  [SMALL_STATE(5754)] = 225434,
  [SMALL_STATE(5755)] = 225493,
  [SMALL_STATE(5756)] = 225554,
  [SMALL_STATE(5757)] = 225613,
  [SMALL_STATE(5758)] = 225672,
  [SMALL_STATE(5759)] = 225731,
  [SMALL_STATE(5760)] = 225790,
  [SMALL_STATE(5761)] = 225849,
  [SMALL_STATE(5762)] = 225908,
  [SMALL_STATE(5763)] = 225967,
  [SMALL_STATE(5764)] = 226026,
  [SMALL_STATE(5765)] = 226085,
  [SMALL_STATE(5766)] = 226144,
  [SMALL_STATE(5767)] = 226203,
  [SMALL_STATE(5768)] = 226262,
  [SMALL_STATE(5769)] = 226323,
  [SMALL_STATE(5770)] = 226382,
  [SMALL_STATE(5771)] = 226441,
  [SMALL_STATE(5772)] = 226500,
  [SMALL_STATE(5773)] = 226559,
  [SMALL_STATE(5774)] = 226618,
  [SMALL_STATE(5775)] = 226677,
  [SMALL_STATE(5776)] = 226736,
  [SMALL_STATE(5777)] = 226795,
  [SMALL_STATE(5778)] = 226854,
  [SMALL_STATE(5779)] = 226913,
  [SMALL_STATE(5780)] = 226972,
  [SMALL_STATE(5781)] = 227037,
  [SMALL_STATE(5782)] = 227096,
  [SMALL_STATE(5783)] = 227155,
  [SMALL_STATE(5784)] = 227214,
  [SMALL_STATE(5785)] = 227273,
  [SMALL_STATE(5786)] = 227332,
  [SMALL_STATE(5787)] = 227391,
  [SMALL_STATE(5788)] = 227450,
  [SMALL_STATE(5789)] = 227509,
  [SMALL_STATE(5790)] = 227568,
  [SMALL_STATE(5791)] = 227627,
  [SMALL_STATE(5792)] = 227686,
  [SMALL_STATE(5793)] = 227745,
  [SMALL_STATE(5794)] = 227804,
  [SMALL_STATE(5795)] = 227863,
  [SMALL_STATE(5796)] = 227922,
  [SMALL_STATE(5797)] = 227981,
  [SMALL_STATE(5798)] = 228040,
  [SMALL_STATE(5799)] = 228099,
  [SMALL_STATE(5800)] = 228158,
  [SMALL_STATE(5801)] = 228217,
  [SMALL_STATE(5802)] = 228276,
  [SMALL_STATE(5803)] = 228335,
  [SMALL_STATE(5804)] = 228394,
  [SMALL_STATE(5805)] = 228457,
  [SMALL_STATE(5806)] = 228516,
  [SMALL_STATE(5807)] = 228575,
  [SMALL_STATE(5808)] = 228634,
  [SMALL_STATE(5809)] = 228695,
  [SMALL_STATE(5810)] = 228754,
  [SMALL_STATE(5811)] = 228813,
  [SMALL_STATE(5812)] = 228872,
  [SMALL_STATE(5813)] = 228931,
  [SMALL_STATE(5814)] = 228996,
  [SMALL_STATE(5815)] = 229055,
  [SMALL_STATE(5816)] = 229114,
  [SMALL_STATE(5817)] = 229173,
  [SMALL_STATE(5818)] = 229232,
  [SMALL_STATE(5819)] = 229291,
  [SMALL_STATE(5820)] = 229350,
  [SMALL_STATE(5821)] = 229409,
  [SMALL_STATE(5822)] = 229468,
  [SMALL_STATE(5823)] = 229527,
  [SMALL_STATE(5824)] = 229586,
  [SMALL_STATE(5825)] = 229645,
  [SMALL_STATE(5826)] = 229704,
  [SMALL_STATE(5827)] = 229763,
  [SMALL_STATE(5828)] = 229822,
  [SMALL_STATE(5829)] = 229883,
  [SMALL_STATE(5830)] = 229942,
  [SMALL_STATE(5831)] = 230001,
  [SMALL_STATE(5832)] = 230062,
  [SMALL_STATE(5833)] = 230121,
  [SMALL_STATE(5834)] = 230180,
  [SMALL_STATE(5835)] = 230239,
  [SMALL_STATE(5836)] = 230298,
  [SMALL_STATE(5837)] = 230357,
  [SMALL_STATE(5838)] = 230416,
  [SMALL_STATE(5839)] = 230475,
  [SMALL_STATE(5840)] = 230534,
  [SMALL_STATE(5841)] = 230593,
  [SMALL_STATE(5842)] = 230652,
  [SMALL_STATE(5843)] = 230711,
  [SMALL_STATE(5844)] = 230770,
  [SMALL_STATE(5845)] = 230829,
  [SMALL_STATE(5846)] = 230888,
  [SMALL_STATE(5847)] = 230947,
  [SMALL_STATE(5848)] = 231006,
  [SMALL_STATE(5849)] = 231065,
  [SMALL_STATE(5850)] = 231124,
  [SMALL_STATE(5851)] = 231183,
  [SMALL_STATE(5852)] = 231242,
  [SMALL_STATE(5853)] = 231301,
  [SMALL_STATE(5854)] = 231360,
  [SMALL_STATE(5855)] = 231419,
  [SMALL_STATE(5856)] = 231478,
  [SMALL_STATE(5857)] = 231537,
  [SMALL_STATE(5858)] = 231596,
  [SMALL_STATE(5859)] = 231655,
  [SMALL_STATE(5860)] = 231714,
  [SMALL_STATE(5861)] = 231773,
  [SMALL_STATE(5862)] = 231832,
  [SMALL_STATE(5863)] = 231891,
  [SMALL_STATE(5864)] = 231952,
  [SMALL_STATE(5865)] = 232011,
  [SMALL_STATE(5866)] = 232070,
  [SMALL_STATE(5867)] = 232129,
  [SMALL_STATE(5868)] = 232188,
  [SMALL_STATE(5869)] = 232247,
  [SMALL_STATE(5870)] = 232306,
  [SMALL_STATE(5871)] = 232365,
  [SMALL_STATE(5872)] = 232424,
  [SMALL_STATE(5873)] = 232483,
  [SMALL_STATE(5874)] = 232542,
  [SMALL_STATE(5875)] = 232601,
  [SMALL_STATE(5876)] = 232660,
  [SMALL_STATE(5877)] = 232719,
  [SMALL_STATE(5878)] = 232778,
  [SMALL_STATE(5879)] = 232837,
  [SMALL_STATE(5880)] = 232896,
  [SMALL_STATE(5881)] = 232957,
  [SMALL_STATE(5882)] = 233016,
  [SMALL_STATE(5883)] = 233075,
  [SMALL_STATE(5884)] = 233134,
  [SMALL_STATE(5885)] = 233193,
  [SMALL_STATE(5886)] = 233252,
  [SMALL_STATE(5887)] = 233311,
  [SMALL_STATE(5888)] = 233370,
  [SMALL_STATE(5889)] = 233429,
  [SMALL_STATE(5890)] = 233488,
  [SMALL_STATE(5891)] = 233553,
  [SMALL_STATE(5892)] = 233612,
  [SMALL_STATE(5893)] = 233671,
  [SMALL_STATE(5894)] = 233730,
  [SMALL_STATE(5895)] = 233789,
  [SMALL_STATE(5896)] = 233848,
  [SMALL_STATE(5897)] = 233907,
  [SMALL_STATE(5898)] = 233966,
  [SMALL_STATE(5899)] = 234025,
  [SMALL_STATE(5900)] = 234084,
  [SMALL_STATE(5901)] = 234143,
  [SMALL_STATE(5902)] = 234202,
  [SMALL_STATE(5903)] = 234261,
  [SMALL_STATE(5904)] = 234320,
  [SMALL_STATE(5905)] = 234379,
  [SMALL_STATE(5906)] = 234438,
  [SMALL_STATE(5907)] = 234497,
  [SMALL_STATE(5908)] = 234556,
  [SMALL_STATE(5909)] = 234615,
  [SMALL_STATE(5910)] = 234674,
  [SMALL_STATE(5911)] = 234733,
  [SMALL_STATE(5912)] = 234792,
  [SMALL_STATE(5913)] = 234853,
  [SMALL_STATE(5914)] = 234912,
  [SMALL_STATE(5915)] = 234971,
  [SMALL_STATE(5916)] = 235030,
  [SMALL_STATE(5917)] = 235089,
  [SMALL_STATE(5918)] = 235148,
  [SMALL_STATE(5919)] = 235207,
  [SMALL_STATE(5920)] = 235266,
  [SMALL_STATE(5921)] = 235325,
  [SMALL_STATE(5922)] = 235384,
  [SMALL_STATE(5923)] = 235443,
  [SMALL_STATE(5924)] = 235502,
  [SMALL_STATE(5925)] = 235561,
  [SMALL_STATE(5926)] = 235620,
  [SMALL_STATE(5927)] = 235679,
  [SMALL_STATE(5928)] = 235738,
  [SMALL_STATE(5929)] = 235797,
  [SMALL_STATE(5930)] = 235858,
  [SMALL_STATE(5931)] = 235917,
  [SMALL_STATE(5932)] = 235976,
  [SMALL_STATE(5933)] = 236035,
  [SMALL_STATE(5934)] = 236094,
  [SMALL_STATE(5935)] = 236153,
  [SMALL_STATE(5936)] = 236216,
  [SMALL_STATE(5937)] = 236275,
  [SMALL_STATE(5938)] = 236334,
  [SMALL_STATE(5939)] = 236395,
  [SMALL_STATE(5940)] = 236454,
  [SMALL_STATE(5941)] = 236513,
  [SMALL_STATE(5942)] = 236572,
  [SMALL_STATE(5943)] = 236631,
  [SMALL_STATE(5944)] = 236690,
  [SMALL_STATE(5945)] = 236749,
  [SMALL_STATE(5946)] = 236808,
  [SMALL_STATE(5947)] = 236867,
  [SMALL_STATE(5948)] = 236926,
  [SMALL_STATE(5949)] = 236985,
  [SMALL_STATE(5950)] = 237044,
  [SMALL_STATE(5951)] = 237103,
  [SMALL_STATE(5952)] = 237162,
  [SMALL_STATE(5953)] = 237221,
  [SMALL_STATE(5954)] = 237280,
  [SMALL_STATE(5955)] = 237345,
  [SMALL_STATE(5956)] = 237404,
  [SMALL_STATE(5957)] = 237463,
  [SMALL_STATE(5958)] = 237521,
  [SMALL_STATE(5959)] = 237579,
  [SMALL_STATE(5960)] = 237637,
  [SMALL_STATE(5961)] = 237695,
  [SMALL_STATE(5962)] = 237753,
  [SMALL_STATE(5963)] = 237811,
  [SMALL_STATE(5964)] = 237909,
  [SMALL_STATE(5965)] = 237969,
  [SMALL_STATE(5966)] = 238027,
  [SMALL_STATE(5967)] = 238085,
  [SMALL_STATE(5968)] = 238143,
  [SMALL_STATE(5969)] = 238201,
  [SMALL_STATE(5970)] = 238259,
  [SMALL_STATE(5971)] = 238317,
  [SMALL_STATE(5972)] = 238375,
  [SMALL_STATE(5973)] = 238433,
  [SMALL_STATE(5974)] = 238539,
  [SMALL_STATE(5975)] = 238597,
  [SMALL_STATE(5976)] = 238655,
  [SMALL_STATE(5977)] = 238713,
  [SMALL_STATE(5978)] = 238771,
  [SMALL_STATE(5979)] = 238829,
  [SMALL_STATE(5980)] = 238927,
  [SMALL_STATE(5981)] = 238985,
  [SMALL_STATE(5982)] = 239043,
  [SMALL_STATE(5983)] = 239101,
  [SMALL_STATE(5984)] = 239159,
  [SMALL_STATE(5985)] = 239217,
  [SMALL_STATE(5986)] = 239275,
  [SMALL_STATE(5987)] = 239333,
  [SMALL_STATE(5988)] = 239391,
  [SMALL_STATE(5989)] = 239449,
  [SMALL_STATE(5990)] = 239513,
  [SMALL_STATE(5991)] = 239571,
  [SMALL_STATE(5992)] = 239629,
  [SMALL_STATE(5993)] = 239687,
  [SMALL_STATE(5994)] = 239793,
  [SMALL_STATE(5995)] = 239851,
  [SMALL_STATE(5996)] = 239909,
  [SMALL_STATE(5997)] = 239967,
  [SMALL_STATE(5998)] = 240025,
  [SMALL_STATE(5999)] = 240083,
  [SMALL_STATE(6000)] = 240141,
  [SMALL_STATE(6001)] = 240199,
  [SMALL_STATE(6002)] = 240257,
  [SMALL_STATE(6003)] = 240315,
  [SMALL_STATE(6004)] = 240413,
  [SMALL_STATE(6005)] = 240519,
  [SMALL_STATE(6006)] = 240577,
  [SMALL_STATE(6007)] = 240635,
  [SMALL_STATE(6008)] = 240741,
  [SMALL_STATE(6009)] = 240847,
  [SMALL_STATE(6010)] = 240905,
  [SMALL_STATE(6011)] = 240963,
  [SMALL_STATE(6012)] = 241021,
  [SMALL_STATE(6013)] = 241079,
  [SMALL_STATE(6014)] = 241177,
  [SMALL_STATE(6015)] = 241235,
  [SMALL_STATE(6016)] = 241293,
  [SMALL_STATE(6017)] = 241351,
  [SMALL_STATE(6018)] = 241409,
  [SMALL_STATE(6019)] = 241467,
  [SMALL_STATE(6020)] = 241525,
  [SMALL_STATE(6021)] = 241583,
  [SMALL_STATE(6022)] = 241681,
  [SMALL_STATE(6023)] = 241739,
  [SMALL_STATE(6024)] = 241797,
  [SMALL_STATE(6025)] = 241855,
  [SMALL_STATE(6026)] = 241953,
  [SMALL_STATE(6027)] = 242059,
  [SMALL_STATE(6028)] = 242165,
  [SMALL_STATE(6029)] = 242223,
  [SMALL_STATE(6030)] = 242281,
  [SMALL_STATE(6031)] = 242379,
  [SMALL_STATE(6032)] = 242437,
  [SMALL_STATE(6033)] = 242495,
  [SMALL_STATE(6034)] = 242553,
  [SMALL_STATE(6035)] = 242651,
  [SMALL_STATE(6036)] = 242749,
  [SMALL_STATE(6037)] = 242807,
  [SMALL_STATE(6038)] = 242865,
  [SMALL_STATE(6039)] = 242923,
  [SMALL_STATE(6040)] = 243029,
  [SMALL_STATE(6041)] = 243087,
  [SMALL_STATE(6042)] = 243147,
  [SMALL_STATE(6043)] = 243205,
  [SMALL_STATE(6044)] = 243263,
  [SMALL_STATE(6045)] = 243321,
  [SMALL_STATE(6046)] = 243419,
  [SMALL_STATE(6047)] = 243477,
  [SMALL_STATE(6048)] = 243535,
  [SMALL_STATE(6049)] = 243595,
  [SMALL_STATE(6050)] = 243655,
  [SMALL_STATE(6051)] = 243713,
  [SMALL_STATE(6052)] = 243777,
  [SMALL_STATE(6053)] = 243837,
  [SMALL_STATE(6054)] = 243895,
  [SMALL_STATE(6055)] = 243953,
  [SMALL_STATE(6056)] = 244011,
  [SMALL_STATE(6057)] = 244069,
  [SMALL_STATE(6058)] = 244127,
  [SMALL_STATE(6059)] = 244185,
  [SMALL_STATE(6060)] = 244243,
  [SMALL_STATE(6061)] = 244341,
  [SMALL_STATE(6062)] = 244399,
  [SMALL_STATE(6063)] = 244457,
  [SMALL_STATE(6064)] = 244555,
  [SMALL_STATE(6065)] = 244613,
  [SMALL_STATE(6066)] = 244671,
  [SMALL_STATE(6067)] = 244769,
  [SMALL_STATE(6068)] = 244829,
  [SMALL_STATE(6069)] = 244887,
  [SMALL_STATE(6070)] = 244945,
  [SMALL_STATE(6071)] = 245051,
  [SMALL_STATE(6072)] = 245108,
  [SMALL_STATE(6073)] = 245165,
  [SMALL_STATE(6074)] = 245222,
  [SMALL_STATE(6075)] = 245281,
  [SMALL_STATE(6076)] = 245338,
  [SMALL_STATE(6077)] = 245395,
  [SMALL_STATE(6078)] = 245452,
  [SMALL_STATE(6079)] = 245509,
  [SMALL_STATE(6080)] = 245566,
  [SMALL_STATE(6081)] = 245623,
  [SMALL_STATE(6082)] = 245680,
  [SMALL_STATE(6083)] = 245737,
  [SMALL_STATE(6084)] = 245796,
  [SMALL_STATE(6085)] = 245853,
  [SMALL_STATE(6086)] = 245910,
  [SMALL_STATE(6087)] = 245967,
  [SMALL_STATE(6088)] = 246024,
  [SMALL_STATE(6089)] = 246081,
  [SMALL_STATE(6090)] = 246138,
  [SMALL_STATE(6091)] = 246195,
  [SMALL_STATE(6092)] = 246252,
  [SMALL_STATE(6093)] = 246309,
  [SMALL_STATE(6094)] = 246366,
  [SMALL_STATE(6095)] = 246423,
  [SMALL_STATE(6096)] = 246480,
  [SMALL_STATE(6097)] = 246537,
  [SMALL_STATE(6098)] = 246594,
  [SMALL_STATE(6099)] = 246651,
  [SMALL_STATE(6100)] = 246708,
  [SMALL_STATE(6101)] = 246765,
  [SMALL_STATE(6102)] = 246822,
  [SMALL_STATE(6103)] = 246879,
  [SMALL_STATE(6104)] = 246936,
  [SMALL_STATE(6105)] = 246993,
  [SMALL_STATE(6106)] = 247050,
  [SMALL_STATE(6107)] = 247107,
  [SMALL_STATE(6108)] = 247164,
  [SMALL_STATE(6109)] = 247223,
  [SMALL_STATE(6110)] = 247280,
  [SMALL_STATE(6111)] = 247337,
  [SMALL_STATE(6112)] = 247394,
  [SMALL_STATE(6113)] = 247451,
  [SMALL_STATE(6114)] = 247508,
  [SMALL_STATE(6115)] = 247567,
  [SMALL_STATE(6116)] = 247624,
  [SMALL_STATE(6117)] = 247681,
  [SMALL_STATE(6118)] = 247738,
  [SMALL_STATE(6119)] = 247795,
  [SMALL_STATE(6120)] = 247852,
  [SMALL_STATE(6121)] = 247909,
  [SMALL_STATE(6122)] = 247966,
  [SMALL_STATE(6123)] = 248023,
  [SMALL_STATE(6124)] = 248080,
  [SMALL_STATE(6125)] = 248137,
  [SMALL_STATE(6126)] = 248194,
  [SMALL_STATE(6127)] = 248251,
  [SMALL_STATE(6128)] = 248310,
  [SMALL_STATE(6129)] = 248367,
  [SMALL_STATE(6130)] = 248424,
  [SMALL_STATE(6131)] = 248481,
  [SMALL_STATE(6132)] = 248538,
  [SMALL_STATE(6133)] = 248595,
  [SMALL_STATE(6134)] = 248654,
  [SMALL_STATE(6135)] = 248711,
  [SMALL_STATE(6136)] = 248768,
  [SMALL_STATE(6137)] = 248825,
  [SMALL_STATE(6138)] = 248882,
  [SMALL_STATE(6139)] = 248939,
  [SMALL_STATE(6140)] = 248996,
  [SMALL_STATE(6141)] = 249053,
  [SMALL_STATE(6142)] = 249110,
  [SMALL_STATE(6143)] = 249167,
  [SMALL_STATE(6144)] = 249224,
  [SMALL_STATE(6145)] = 249281,
  [SMALL_STATE(6146)] = 249338,
  [SMALL_STATE(6147)] = 249395,
  [SMALL_STATE(6148)] = 249452,
  [SMALL_STATE(6149)] = 249509,
  [SMALL_STATE(6150)] = 249618,
  [SMALL_STATE(6151)] = 249727,
  [SMALL_STATE(6152)] = 249836,
  [SMALL_STATE(6153)] = 249895,
  [SMALL_STATE(6154)] = 249954,
  [SMALL_STATE(6155)] = 250063,
  [SMALL_STATE(6156)] = 250172,
  [SMALL_STATE(6157)] = 250281,
  [SMALL_STATE(6158)] = 250390,
  [SMALL_STATE(6159)] = 250453,
  [SMALL_STATE(6160)] = 250516,
  [SMALL_STATE(6161)] = 250573,
  [SMALL_STATE(6162)] = 250630,
  [SMALL_STATE(6163)] = 250687,
  [SMALL_STATE(6164)] = 250744,
  [SMALL_STATE(6165)] = 250801,
  [SMALL_STATE(6166)] = 250858,
  [SMALL_STATE(6167)] = 250915,
  [SMALL_STATE(6168)] = 250974,
  [SMALL_STATE(6169)] = 251031,
  [SMALL_STATE(6170)] = 251088,
  [SMALL_STATE(6171)] = 251147,
  [SMALL_STATE(6172)] = 251210,
  [SMALL_STATE(6173)] = 251273,
  [SMALL_STATE(6174)] = 251330,
  [SMALL_STATE(6175)] = 251389,
  [SMALL_STATE(6176)] = 251448,
  [SMALL_STATE(6177)] = 251505,
  [SMALL_STATE(6178)] = 251562,
  [SMALL_STATE(6179)] = 251619,
  [SMALL_STATE(6180)] = 251676,
  [SMALL_STATE(6181)] = 251733,
  [SMALL_STATE(6182)] = 251790,
  [SMALL_STATE(6183)] = 251847,
  [SMALL_STATE(6184)] = 251904,
  [SMALL_STATE(6185)] = 251961,
  [SMALL_STATE(6186)] = 252018,
  [SMALL_STATE(6187)] = 252075,
  [SMALL_STATE(6188)] = 252132,
  [SMALL_STATE(6189)] = 252189,
  [SMALL_STATE(6190)] = 252246,
  [SMALL_STATE(6191)] = 252305,
  [SMALL_STATE(6192)] = 252362,
  [SMALL_STATE(6193)] = 252419,
  [SMALL_STATE(6194)] = 252476,
  [SMALL_STATE(6195)] = 252533,
  [SMALL_STATE(6196)] = 252590,
  [SMALL_STATE(6197)] = 252647,
  [SMALL_STATE(6198)] = 252704,
  [SMALL_STATE(6199)] = 252761,
  [SMALL_STATE(6200)] = 252818,
  [SMALL_STATE(6201)] = 252875,
  [SMALL_STATE(6202)] = 252932,
  [SMALL_STATE(6203)] = 252989,
  [SMALL_STATE(6204)] = 253046,
  [SMALL_STATE(6205)] = 253103,
  [SMALL_STATE(6206)] = 253160,
  [SMALL_STATE(6207)] = 253217,
  [SMALL_STATE(6208)] = 253274,
  [SMALL_STATE(6209)] = 253331,
  [SMALL_STATE(6210)] = 253388,
  [SMALL_STATE(6211)] = 253445,
  [SMALL_STATE(6212)] = 253502,
  [SMALL_STATE(6213)] = 253559,
  [SMALL_STATE(6214)] = 253616,
  [SMALL_STATE(6215)] = 253673,
  [SMALL_STATE(6216)] = 253730,
  [SMALL_STATE(6217)] = 253787,
  [SMALL_STATE(6218)] = 253844,
  [SMALL_STATE(6219)] = 253901,
  [SMALL_STATE(6220)] = 253958,
  [SMALL_STATE(6221)] = 254015,
  [SMALL_STATE(6222)] = 254072,
  [SMALL_STATE(6223)] = 254129,
  [SMALL_STATE(6224)] = 254186,
  [SMALL_STATE(6225)] = 254243,
  [SMALL_STATE(6226)] = 254300,
  [SMALL_STATE(6227)] = 254357,
  [SMALL_STATE(6228)] = 254414,
  [SMALL_STATE(6229)] = 254471,
  [SMALL_STATE(6230)] = 254528,
  [SMALL_STATE(6231)] = 254585,
  [SMALL_STATE(6232)] = 254642,
  [SMALL_STATE(6233)] = 254699,
  [SMALL_STATE(6234)] = 254756,
  [SMALL_STATE(6235)] = 254813,
  [SMALL_STATE(6236)] = 254870,
  [SMALL_STATE(6237)] = 254927,
  [SMALL_STATE(6238)] = 254984,
  [SMALL_STATE(6239)] = 255041,
  [SMALL_STATE(6240)] = 255098,
  [SMALL_STATE(6241)] = 255155,
  [SMALL_STATE(6242)] = 255212,
  [SMALL_STATE(6243)] = 255269,
  [SMALL_STATE(6244)] = 255326,
  [SMALL_STATE(6245)] = 255383,
  [SMALL_STATE(6246)] = 255440,
  [SMALL_STATE(6247)] = 255497,
  [SMALL_STATE(6248)] = 255554,
  [SMALL_STATE(6249)] = 255611,
  [SMALL_STATE(6250)] = 255668,
  [SMALL_STATE(6251)] = 255725,
  [SMALL_STATE(6252)] = 255782,
  [SMALL_STATE(6253)] = 255839,
  [SMALL_STATE(6254)] = 255896,
  [SMALL_STATE(6255)] = 255953,
  [SMALL_STATE(6256)] = 256010,
  [SMALL_STATE(6257)] = 256069,
  [SMALL_STATE(6258)] = 256128,
  [SMALL_STATE(6259)] = 256187,
  [SMALL_STATE(6260)] = 256246,
  [SMALL_STATE(6261)] = 256303,
  [SMALL_STATE(6262)] = 256360,
  [SMALL_STATE(6263)] = 256417,
  [SMALL_STATE(6264)] = 256474,
  [SMALL_STATE(6265)] = 256533,
  [SMALL_STATE(6266)] = 256592,
  [SMALL_STATE(6267)] = 256649,
  [SMALL_STATE(6268)] = 256706,
  [SMALL_STATE(6269)] = 256763,
  [SMALL_STATE(6270)] = 256820,
  [SMALL_STATE(6271)] = 256877,
  [SMALL_STATE(6272)] = 256934,
  [SMALL_STATE(6273)] = 256991,
  [SMALL_STATE(6274)] = 257048,
  [SMALL_STATE(6275)] = 257105,
  [SMALL_STATE(6276)] = 257162,
  [SMALL_STATE(6277)] = 257219,
  [SMALL_STATE(6278)] = 257276,
  [SMALL_STATE(6279)] = 257333,
  [SMALL_STATE(6280)] = 257390,
  [SMALL_STATE(6281)] = 257447,
  [SMALL_STATE(6282)] = 257504,
  [SMALL_STATE(6283)] = 257561,
  [SMALL_STATE(6284)] = 257618,
  [SMALL_STATE(6285)] = 257675,
  [SMALL_STATE(6286)] = 257732,
  [SMALL_STATE(6287)] = 257789,
  [SMALL_STATE(6288)] = 257846,
  [SMALL_STATE(6289)] = 257903,
  [SMALL_STATE(6290)] = 257960,
  [SMALL_STATE(6291)] = 258017,
  [SMALL_STATE(6292)] = 258074,
  [SMALL_STATE(6293)] = 258131,
  [SMALL_STATE(6294)] = 258190,
  [SMALL_STATE(6295)] = 258247,
  [SMALL_STATE(6296)] = 258304,
  [SMALL_STATE(6297)] = 258361,
  [SMALL_STATE(6298)] = 258418,
  [SMALL_STATE(6299)] = 258475,
  [SMALL_STATE(6300)] = 258532,
  [SMALL_STATE(6301)] = 258589,
  [SMALL_STATE(6302)] = 258646,
  [SMALL_STATE(6303)] = 258703,
  [SMALL_STATE(6304)] = 258760,
  [SMALL_STATE(6305)] = 258817,
  [SMALL_STATE(6306)] = 258874,
  [SMALL_STATE(6307)] = 258931,
  [SMALL_STATE(6308)] = 258988,
  [SMALL_STATE(6309)] = 259045,
  [SMALL_STATE(6310)] = 259102,
  [SMALL_STATE(6311)] = 259159,
  [SMALL_STATE(6312)] = 259216,
  [SMALL_STATE(6313)] = 259273,
  [SMALL_STATE(6314)] = 259330,
  [SMALL_STATE(6315)] = 259387,
  [SMALL_STATE(6316)] = 259444,
  [SMALL_STATE(6317)] = 259501,
  [SMALL_STATE(6318)] = 259558,
  [SMALL_STATE(6319)] = 259615,
  [SMALL_STATE(6320)] = 259672,
  [SMALL_STATE(6321)] = 259729,
  [SMALL_STATE(6322)] = 259786,
  [SMALL_STATE(6323)] = 259843,
  [SMALL_STATE(6324)] = 259900,
  [SMALL_STATE(6325)] = 259957,
  [SMALL_STATE(6326)] = 260066,
  [SMALL_STATE(6327)] = 260123,
  [SMALL_STATE(6328)] = 260180,
  [SMALL_STATE(6329)] = 260237,
  [SMALL_STATE(6330)] = 260294,
  [SMALL_STATE(6331)] = 260351,
  [SMALL_STATE(6332)] = 260408,
  [SMALL_STATE(6333)] = 260465,
  [SMALL_STATE(6334)] = 260522,
  [SMALL_STATE(6335)] = 260579,
  [SMALL_STATE(6336)] = 260636,
  [SMALL_STATE(6337)] = 260693,
  [SMALL_STATE(6338)] = 260750,
  [SMALL_STATE(6339)] = 260807,
  [SMALL_STATE(6340)] = 260864,
  [SMALL_STATE(6341)] = 260921,
  [SMALL_STATE(6342)] = 260980,
  [SMALL_STATE(6343)] = 261037,
  [SMALL_STATE(6344)] = 261094,
  [SMALL_STATE(6345)] = 261151,
  [SMALL_STATE(6346)] = 261208,
  [SMALL_STATE(6347)] = 261265,
  [SMALL_STATE(6348)] = 261322,
  [SMALL_STATE(6349)] = 261379,
  [SMALL_STATE(6350)] = 261436,
  [SMALL_STATE(6351)] = 261493,
  [SMALL_STATE(6352)] = 261550,
  [SMALL_STATE(6353)] = 261607,
  [SMALL_STATE(6354)] = 261664,
  [SMALL_STATE(6355)] = 261721,
  [SMALL_STATE(6356)] = 261778,
  [SMALL_STATE(6357)] = 261835,
  [SMALL_STATE(6358)] = 261892,
  [SMALL_STATE(6359)] = 261949,
  [SMALL_STATE(6360)] = 262006,
  [SMALL_STATE(6361)] = 262063,
  [SMALL_STATE(6362)] = 262126,
  [SMALL_STATE(6363)] = 262183,
  [SMALL_STATE(6364)] = 262240,
  [SMALL_STATE(6365)] = 262297,
  [SMALL_STATE(6366)] = 262354,
  [SMALL_STATE(6367)] = 262411,
  [SMALL_STATE(6368)] = 262468,
  [SMALL_STATE(6369)] = 262525,
  [SMALL_STATE(6370)] = 262584,
  [SMALL_STATE(6371)] = 262641,
  [SMALL_STATE(6372)] = 262698,
  [SMALL_STATE(6373)] = 262755,
  [SMALL_STATE(6374)] = 262812,
  [SMALL_STATE(6375)] = 262869,
  [SMALL_STATE(6376)] = 262926,
  [SMALL_STATE(6377)] = 262983,
  [SMALL_STATE(6378)] = 263040,
  [SMALL_STATE(6379)] = 263097,
  [SMALL_STATE(6380)] = 263154,
  [SMALL_STATE(6381)] = 263211,
  [SMALL_STATE(6382)] = 263268,
  [SMALL_STATE(6383)] = 263325,
  [SMALL_STATE(6384)] = 263382,
  [SMALL_STATE(6385)] = 263439,
  [SMALL_STATE(6386)] = 263496,
  [SMALL_STATE(6387)] = 263553,
  [SMALL_STATE(6388)] = 263616,
  [SMALL_STATE(6389)] = 263673,
  [SMALL_STATE(6390)] = 263730,
  [SMALL_STATE(6391)] = 263787,
  [SMALL_STATE(6392)] = 263844,
  [SMALL_STATE(6393)] = 263901,
  [SMALL_STATE(6394)] = 263958,
  [SMALL_STATE(6395)] = 264015,
  [SMALL_STATE(6396)] = 264072,
  [SMALL_STATE(6397)] = 264131,
  [SMALL_STATE(6398)] = 264188,
  [SMALL_STATE(6399)] = 264245,
  [SMALL_STATE(6400)] = 264301,
  [SMALL_STATE(6401)] = 264359,
  [SMALL_STATE(6402)] = 264415,
  [SMALL_STATE(6403)] = 264471,
  [SMALL_STATE(6404)] = 264527,
  [SMALL_STATE(6405)] = 264583,
  [SMALL_STATE(6406)] = 264645,
  [SMALL_STATE(6407)] = 264701,
  [SMALL_STATE(6408)] = 264757,
  [SMALL_STATE(6409)] = 264813,
  [SMALL_STATE(6410)] = 264869,
  [SMALL_STATE(6411)] = 264925,
  [SMALL_STATE(6412)] = 264981,
  [SMALL_STATE(6413)] = 265037,
  [SMALL_STATE(6414)] = 265093,
  [SMALL_STATE(6415)] = 265149,
  [SMALL_STATE(6416)] = 265205,
  [SMALL_STATE(6417)] = 265261,
  [SMALL_STATE(6418)] = 265317,
  [SMALL_STATE(6419)] = 265373,
  [SMALL_STATE(6420)] = 265429,
  [SMALL_STATE(6421)] = 265485,
  [SMALL_STATE(6422)] = 265541,
  [SMALL_STATE(6423)] = 265597,
  [SMALL_STATE(6424)] = 265653,
  [SMALL_STATE(6425)] = 265709,
  [SMALL_STATE(6426)] = 265765,
  [SMALL_STATE(6427)] = 265871,
  [SMALL_STATE(6428)] = 265927,
  [SMALL_STATE(6429)] = 265983,
  [SMALL_STATE(6430)] = 266041,
  [SMALL_STATE(6431)] = 266097,
  [SMALL_STATE(6432)] = 266153,
  [SMALL_STATE(6433)] = 266209,
  [SMALL_STATE(6434)] = 266265,
  [SMALL_STATE(6435)] = 266321,
  [SMALL_STATE(6436)] = 266377,
  [SMALL_STATE(6437)] = 266435,
  [SMALL_STATE(6438)] = 266491,
  [SMALL_STATE(6439)] = 266547,
  [SMALL_STATE(6440)] = 266603,
  [SMALL_STATE(6441)] = 266659,
  [SMALL_STATE(6442)] = 266715,
  [SMALL_STATE(6443)] = 266771,
  [SMALL_STATE(6444)] = 266827,
  [SMALL_STATE(6445)] = 266883,
  [SMALL_STATE(6446)] = 266939,
  [SMALL_STATE(6447)] = 266995,
  [SMALL_STATE(6448)] = 267051,
  [SMALL_STATE(6449)] = 267107,
  [SMALL_STATE(6450)] = 267163,
  [SMALL_STATE(6451)] = 267219,
  [SMALL_STATE(6452)] = 267275,
  [SMALL_STATE(6453)] = 267331,
  [SMALL_STATE(6454)] = 267387,
  [SMALL_STATE(6455)] = 267443,
  [SMALL_STATE(6456)] = 267499,
  [SMALL_STATE(6457)] = 267555,
  [SMALL_STATE(6458)] = 267611,
  [SMALL_STATE(6459)] = 267667,
  [SMALL_STATE(6460)] = 267723,
  [SMALL_STATE(6461)] = 267779,
  [SMALL_STATE(6462)] = 267835,
  [SMALL_STATE(6463)] = 267891,
  [SMALL_STATE(6464)] = 267947,
  [SMALL_STATE(6465)] = 268003,
  [SMALL_STATE(6466)] = 268059,
  [SMALL_STATE(6467)] = 268115,
  [SMALL_STATE(6468)] = 268171,
  [SMALL_STATE(6469)] = 268227,
  [SMALL_STATE(6470)] = 268283,
  [SMALL_STATE(6471)] = 268339,
  [SMALL_STATE(6472)] = 268395,
  [SMALL_STATE(6473)] = 268451,
  [SMALL_STATE(6474)] = 268507,
  [SMALL_STATE(6475)] = 268563,
  [SMALL_STATE(6476)] = 268619,
  [SMALL_STATE(6477)] = 268675,
  [SMALL_STATE(6478)] = 268731,
  [SMALL_STATE(6479)] = 268787,
  [SMALL_STATE(6480)] = 268843,
  [SMALL_STATE(6481)] = 268899,
  [SMALL_STATE(6482)] = 268955,
  [SMALL_STATE(6483)] = 269011,
  [SMALL_STATE(6484)] = 269067,
  [SMALL_STATE(6485)] = 269173,
  [SMALL_STATE(6486)] = 269229,
  [SMALL_STATE(6487)] = 269285,
  [SMALL_STATE(6488)] = 269341,
  [SMALL_STATE(6489)] = 269397,
  [SMALL_STATE(6490)] = 269453,
  [SMALL_STATE(6491)] = 269509,
  [SMALL_STATE(6492)] = 269565,
  [SMALL_STATE(6493)] = 269621,
  [SMALL_STATE(6494)] = 269679,
  [SMALL_STATE(6495)] = 269785,
  [SMALL_STATE(6496)] = 269841,
  [SMALL_STATE(6497)] = 269897,
  [SMALL_STATE(6498)] = 269953,
  [SMALL_STATE(6499)] = 270009,
  [SMALL_STATE(6500)] = 270065,
  [SMALL_STATE(6501)] = 270121,
  [SMALL_STATE(6502)] = 270177,
  [SMALL_STATE(6503)] = 270233,
  [SMALL_STATE(6504)] = 270289,
  [SMALL_STATE(6505)] = 270345,
  [SMALL_STATE(6506)] = 270401,
  [SMALL_STATE(6507)] = 270457,
  [SMALL_STATE(6508)] = 270513,
  [SMALL_STATE(6509)] = 270569,
  [SMALL_STATE(6510)] = 270625,
  [SMALL_STATE(6511)] = 270681,
  [SMALL_STATE(6512)] = 270737,
  [SMALL_STATE(6513)] = 270793,
  [SMALL_STATE(6514)] = 270849,
  [SMALL_STATE(6515)] = 270905,
  [SMALL_STATE(6516)] = 270961,
  [SMALL_STATE(6517)] = 271017,
  [SMALL_STATE(6518)] = 271073,
  [SMALL_STATE(6519)] = 271129,
  [SMALL_STATE(6520)] = 271185,
  [SMALL_STATE(6521)] = 271241,
  [SMALL_STATE(6522)] = 271297,
  [SMALL_STATE(6523)] = 271353,
  [SMALL_STATE(6524)] = 271411,
  [SMALL_STATE(6525)] = 271469,
  [SMALL_STATE(6526)] = 271525,
  [SMALL_STATE(6527)] = 271581,
  [SMALL_STATE(6528)] = 271687,
  [SMALL_STATE(6529)] = 271743,
  [SMALL_STATE(6530)] = 271799,
  [SMALL_STATE(6531)] = 271905,
  [SMALL_STATE(6532)] = 271961,
  [SMALL_STATE(6533)] = 272017,
  [SMALL_STATE(6534)] = 272123,
  [SMALL_STATE(6535)] = 272179,
  [SMALL_STATE(6536)] = 272235,
  [SMALL_STATE(6537)] = 272341,
  [SMALL_STATE(6538)] = 272447,
  [SMALL_STATE(6539)] = 272503,
  [SMALL_STATE(6540)] = 272559,
  [SMALL_STATE(6541)] = 272615,
  [SMALL_STATE(6542)] = 272671,
  [SMALL_STATE(6543)] = 272727,
  [SMALL_STATE(6544)] = 272783,
  [SMALL_STATE(6545)] = 272839,
  [SMALL_STATE(6546)] = 272895,
  [SMALL_STATE(6547)] = 272951,
  [SMALL_STATE(6548)] = 273007,
  [SMALL_STATE(6549)] = 273063,
  [SMALL_STATE(6550)] = 273119,
  [SMALL_STATE(6551)] = 273175,
  [SMALL_STATE(6552)] = 273231,
  [SMALL_STATE(6553)] = 273287,
  [SMALL_STATE(6554)] = 273343,
  [SMALL_STATE(6555)] = 273399,
  [SMALL_STATE(6556)] = 273455,
  [SMALL_STATE(6557)] = 273511,
  [SMALL_STATE(6558)] = 273567,
  [SMALL_STATE(6559)] = 273623,
  [SMALL_STATE(6560)] = 273679,
  [SMALL_STATE(6561)] = 273735,
  [SMALL_STATE(6562)] = 273791,
  [SMALL_STATE(6563)] = 273847,
  [SMALL_STATE(6564)] = 273905,
  [SMALL_STATE(6565)] = 273961,
  [SMALL_STATE(6566)] = 274017,
  [SMALL_STATE(6567)] = 274073,
  [SMALL_STATE(6568)] = 274129,
  [SMALL_STATE(6569)] = 274185,
  [SMALL_STATE(6570)] = 274241,
  [SMALL_STATE(6571)] = 274297,
  [SMALL_STATE(6572)] = 274353,
  [SMALL_STATE(6573)] = 274409,
  [SMALL_STATE(6574)] = 274465,
  [SMALL_STATE(6575)] = 274521,
  [SMALL_STATE(6576)] = 274577,
  [SMALL_STATE(6577)] = 274633,
  [SMALL_STATE(6578)] = 274689,
  [SMALL_STATE(6579)] = 274745,
  [SMALL_STATE(6580)] = 274801,
  [SMALL_STATE(6581)] = 274857,
  [SMALL_STATE(6582)] = 274915,
  [SMALL_STATE(6583)] = 274971,
  [SMALL_STATE(6584)] = 275027,
  [SMALL_STATE(6585)] = 275083,
  [SMALL_STATE(6586)] = 275139,
  [SMALL_STATE(6587)] = 275195,
  [SMALL_STATE(6588)] = 275251,
  [SMALL_STATE(6589)] = 275307,
  [SMALL_STATE(6590)] = 275363,
  [SMALL_STATE(6591)] = 275419,
  [SMALL_STATE(6592)] = 275481,
  [SMALL_STATE(6593)] = 275537,
  [SMALL_STATE(6594)] = 275593,
  [SMALL_STATE(6595)] = 275649,
  [SMALL_STATE(6596)] = 275705,
  [SMALL_STATE(6597)] = 275767,
  [SMALL_STATE(6598)] = 275823,
  [SMALL_STATE(6599)] = 275881,
  [SMALL_STATE(6600)] = 275937,
  [SMALL_STATE(6601)] = 275993,
  [SMALL_STATE(6602)] = 276049,
  [SMALL_STATE(6603)] = 276105,
  [SMALL_STATE(6604)] = 276161,
  [SMALL_STATE(6605)] = 276217,
  [SMALL_STATE(6606)] = 276273,
  [SMALL_STATE(6607)] = 276329,
  [SMALL_STATE(6608)] = 276387,
  [SMALL_STATE(6609)] = 276443,
  [SMALL_STATE(6610)] = 276499,
  [SMALL_STATE(6611)] = 276555,
  [SMALL_STATE(6612)] = 276611,
  [SMALL_STATE(6613)] = 276667,
  [SMALL_STATE(6614)] = 276723,
  [SMALL_STATE(6615)] = 276779,
  [SMALL_STATE(6616)] = 276837,
  [SMALL_STATE(6617)] = 276893,
  [SMALL_STATE(6618)] = 276949,
  [SMALL_STATE(6619)] = 277007,
  [SMALL_STATE(6620)] = 277063,
  [SMALL_STATE(6621)] = 277119,
  [SMALL_STATE(6622)] = 277175,
  [SMALL_STATE(6623)] = 277233,
  [SMALL_STATE(6624)] = 277289,
  [SMALL_STATE(6625)] = 277345,
  [SMALL_STATE(6626)] = 277401,
  [SMALL_STATE(6627)] = 277457,
  [SMALL_STATE(6628)] = 277513,
  [SMALL_STATE(6629)] = 277569,
  [SMALL_STATE(6630)] = 277625,
  [SMALL_STATE(6631)] = 277681,
  [SMALL_STATE(6632)] = 277739,
  [SMALL_STATE(6633)] = 277797,
  [SMALL_STATE(6634)] = 277853,
  [SMALL_STATE(6635)] = 277909,
  [SMALL_STATE(6636)] = 277965,
  [SMALL_STATE(6637)] = 278021,
  [SMALL_STATE(6638)] = 278077,
  [SMALL_STATE(6639)] = 278133,
  [SMALL_STATE(6640)] = 278191,
  [SMALL_STATE(6641)] = 278247,
  [SMALL_STATE(6642)] = 278303,
  [SMALL_STATE(6643)] = 278359,
  [SMALL_STATE(6644)] = 278415,
  [SMALL_STATE(6645)] = 278471,
  [SMALL_STATE(6646)] = 278527,
  [SMALL_STATE(6647)] = 278583,
  [SMALL_STATE(6648)] = 278641,
  [SMALL_STATE(6649)] = 278697,
  [SMALL_STATE(6650)] = 278753,
  [SMALL_STATE(6651)] = 278809,
  [SMALL_STATE(6652)] = 278865,
  [SMALL_STATE(6653)] = 278921,
  [SMALL_STATE(6654)] = 278977,
  [SMALL_STATE(6655)] = 279033,
  [SMALL_STATE(6656)] = 279091,
  [SMALL_STATE(6657)] = 279149,
  [SMALL_STATE(6658)] = 279205,
  [SMALL_STATE(6659)] = 279261,
  [SMALL_STATE(6660)] = 279317,
  [SMALL_STATE(6661)] = 279373,
  [SMALL_STATE(6662)] = 279429,
  [SMALL_STATE(6663)] = 279485,
  [SMALL_STATE(6664)] = 279541,
  [SMALL_STATE(6665)] = 279597,
  [SMALL_STATE(6666)] = 279653,
  [SMALL_STATE(6667)] = 279709,
  [SMALL_STATE(6668)] = 279765,
  [SMALL_STATE(6669)] = 279821,
  [SMALL_STATE(6670)] = 279877,
  [SMALL_STATE(6671)] = 279933,
  [SMALL_STATE(6672)] = 279989,
  [SMALL_STATE(6673)] = 280045,
  [SMALL_STATE(6674)] = 280101,
  [SMALL_STATE(6675)] = 280157,
  [SMALL_STATE(6676)] = 280213,
  [SMALL_STATE(6677)] = 280269,
  [SMALL_STATE(6678)] = 280325,
  [SMALL_STATE(6679)] = 280381,
  [SMALL_STATE(6680)] = 280437,
  [SMALL_STATE(6681)] = 280493,
  [SMALL_STATE(6682)] = 280549,
  [SMALL_STATE(6683)] = 280605,
  [SMALL_STATE(6684)] = 280661,
  [SMALL_STATE(6685)] = 280717,
  [SMALL_STATE(6686)] = 280773,
  [SMALL_STATE(6687)] = 280829,
  [SMALL_STATE(6688)] = 280885,
  [SMALL_STATE(6689)] = 280941,
  [SMALL_STATE(6690)] = 280997,
  [SMALL_STATE(6691)] = 281053,
  [SMALL_STATE(6692)] = 281109,
  [SMALL_STATE(6693)] = 281165,
  [SMALL_STATE(6694)] = 281221,
  [SMALL_STATE(6695)] = 281277,
  [SMALL_STATE(6696)] = 281333,
  [SMALL_STATE(6697)] = 281389,
  [SMALL_STATE(6698)] = 281445,
  [SMALL_STATE(6699)] = 281501,
  [SMALL_STATE(6700)] = 281557,
  [SMALL_STATE(6701)] = 281613,
  [SMALL_STATE(6702)] = 281669,
  [SMALL_STATE(6703)] = 281725,
  [SMALL_STATE(6704)] = 281781,
  [SMALL_STATE(6705)] = 281837,
  [SMALL_STATE(6706)] = 281893,
  [SMALL_STATE(6707)] = 281951,
  [SMALL_STATE(6708)] = 282007,
  [SMALL_STATE(6709)] = 282063,
  [SMALL_STATE(6710)] = 282119,
  [SMALL_STATE(6711)] = 282175,
  [SMALL_STATE(6712)] = 282231,
  [SMALL_STATE(6713)] = 282287,
  [SMALL_STATE(6714)] = 282343,
  [SMALL_STATE(6715)] = 282399,
  [SMALL_STATE(6716)] = 282455,
  [SMALL_STATE(6717)] = 282511,
  [SMALL_STATE(6718)] = 282569,
  [SMALL_STATE(6719)] = 282625,
  [SMALL_STATE(6720)] = 282681,
  [SMALL_STATE(6721)] = 282737,
  [SMALL_STATE(6722)] = 282793,
  [SMALL_STATE(6723)] = 282849,
  [SMALL_STATE(6724)] = 282905,
  [SMALL_STATE(6725)] = 282961,
  [SMALL_STATE(6726)] = 283017,
  [SMALL_STATE(6727)] = 283073,
  [SMALL_STATE(6728)] = 283129,
  [SMALL_STATE(6729)] = 283185,
  [SMALL_STATE(6730)] = 283241,
  [SMALL_STATE(6731)] = 283297,
  [SMALL_STATE(6732)] = 283353,
  [SMALL_STATE(6733)] = 283409,
  [SMALL_STATE(6734)] = 283465,
  [SMALL_STATE(6735)] = 283521,
  [SMALL_STATE(6736)] = 283577,
  [SMALL_STATE(6737)] = 283633,
  [SMALL_STATE(6738)] = 283689,
  [SMALL_STATE(6739)] = 283745,
  [SMALL_STATE(6740)] = 283801,
  [SMALL_STATE(6741)] = 283857,
  [SMALL_STATE(6742)] = 283913,
  [SMALL_STATE(6743)] = 283969,
  [SMALL_STATE(6744)] = 284025,
  [SMALL_STATE(6745)] = 284087,
  [SMALL_STATE(6746)] = 284143,
  [SMALL_STATE(6747)] = 284199,
  [SMALL_STATE(6748)] = 284255,
  [SMALL_STATE(6749)] = 284311,
  [SMALL_STATE(6750)] = 284367,
  [SMALL_STATE(6751)] = 284423,
  [SMALL_STATE(6752)] = 284479,
  [SMALL_STATE(6753)] = 284535,
  [SMALL_STATE(6754)] = 284593,
  [SMALL_STATE(6755)] = 284649,
  [SMALL_STATE(6756)] = 284705,
  [SMALL_STATE(6757)] = 284761,
  [SMALL_STATE(6758)] = 284817,
  [SMALL_STATE(6759)] = 284873,
  [SMALL_STATE(6760)] = 284929,
  [SMALL_STATE(6761)] = 284987,
  [SMALL_STATE(6762)] = 285045,
  [SMALL_STATE(6763)] = 285103,
  [SMALL_STATE(6764)] = 285161,
  [SMALL_STATE(6765)] = 285217,
  [SMALL_STATE(6766)] = 285273,
  [SMALL_STATE(6767)] = 285329,
  [SMALL_STATE(6768)] = 285385,
  [SMALL_STATE(6769)] = 285441,
  [SMALL_STATE(6770)] = 285497,
  [SMALL_STATE(6771)] = 285553,
  [SMALL_STATE(6772)] = 285609,
  [SMALL_STATE(6773)] = 285665,
  [SMALL_STATE(6774)] = 285721,
  [SMALL_STATE(6775)] = 285777,
  [SMALL_STATE(6776)] = 285833,
  [SMALL_STATE(6777)] = 285889,
  [SMALL_STATE(6778)] = 285945,
  [SMALL_STATE(6779)] = 286001,
  [SMALL_STATE(6780)] = 286063,
  [SMALL_STATE(6781)] = 286119,
  [SMALL_STATE(6782)] = 286175,
  [SMALL_STATE(6783)] = 286231,
  [SMALL_STATE(6784)] = 286287,
  [SMALL_STATE(6785)] = 286343,
  [SMALL_STATE(6786)] = 286399,
  [SMALL_STATE(6787)] = 286455,
  [SMALL_STATE(6788)] = 286511,
  [SMALL_STATE(6789)] = 286569,
  [SMALL_STATE(6790)] = 286625,
  [SMALL_STATE(6791)] = 286681,
  [SMALL_STATE(6792)] = 286737,
  [SMALL_STATE(6793)] = 286793,
  [SMALL_STATE(6794)] = 286849,
  [SMALL_STATE(6795)] = 286905,
  [SMALL_STATE(6796)] = 286961,
  [SMALL_STATE(6797)] = 287017,
  [SMALL_STATE(6798)] = 287073,
  [SMALL_STATE(6799)] = 287129,
  [SMALL_STATE(6800)] = 287185,
  [SMALL_STATE(6801)] = 287247,
  [SMALL_STATE(6802)] = 287303,
  [SMALL_STATE(6803)] = 287359,
  [SMALL_STATE(6804)] = 287415,
  [SMALL_STATE(6805)] = 287471,
  [SMALL_STATE(6806)] = 287527,
  [SMALL_STATE(6807)] = 287583,
  [SMALL_STATE(6808)] = 287639,
  [SMALL_STATE(6809)] = 287695,
  [SMALL_STATE(6810)] = 287751,
  [SMALL_STATE(6811)] = 287809,
  [SMALL_STATE(6812)] = 287865,
  [SMALL_STATE(6813)] = 287921,
  [SMALL_STATE(6814)] = 287977,
  [SMALL_STATE(6815)] = 288033,
  [SMALL_STATE(6816)] = 288089,
  [SMALL_STATE(6817)] = 288145,
  [SMALL_STATE(6818)] = 288201,
  [SMALL_STATE(6819)] = 288257,
  [SMALL_STATE(6820)] = 288313,
  [SMALL_STATE(6821)] = 288369,
  [SMALL_STATE(6822)] = 288425,
  [SMALL_STATE(6823)] = 288481,
  [SMALL_STATE(6824)] = 288537,
  [SMALL_STATE(6825)] = 288593,
  [SMALL_STATE(6826)] = 288649,
  [SMALL_STATE(6827)] = 288705,
  [SMALL_STATE(6828)] = 288761,
  [SMALL_STATE(6829)] = 288817,
  [SMALL_STATE(6830)] = 288873,
  [SMALL_STATE(6831)] = 288929,
  [SMALL_STATE(6832)] = 288985,
  [SMALL_STATE(6833)] = 289047,
  [SMALL_STATE(6834)] = 289103,
  [SMALL_STATE(6835)] = 289159,
  [SMALL_STATE(6836)] = 289215,
  [SMALL_STATE(6837)] = 289271,
  [SMALL_STATE(6838)] = 289327,
  [SMALL_STATE(6839)] = 289383,
  [SMALL_STATE(6840)] = 289439,
  [SMALL_STATE(6841)] = 289495,
  [SMALL_STATE(6842)] = 289551,
  [SMALL_STATE(6843)] = 289607,
  [SMALL_STATE(6844)] = 289663,
  [SMALL_STATE(6845)] = 289719,
  [SMALL_STATE(6846)] = 289775,
  [SMALL_STATE(6847)] = 289831,
  [SMALL_STATE(6848)] = 289887,
  [SMALL_STATE(6849)] = 289943,
  [SMALL_STATE(6850)] = 289999,
  [SMALL_STATE(6851)] = 290055,
  [SMALL_STATE(6852)] = 290117,
  [SMALL_STATE(6853)] = 290173,
  [SMALL_STATE(6854)] = 290229,
  [SMALL_STATE(6855)] = 290285,
  [SMALL_STATE(6856)] = 290341,
  [SMALL_STATE(6857)] = 290397,
  [SMALL_STATE(6858)] = 290453,
  [SMALL_STATE(6859)] = 290509,
  [SMALL_STATE(6860)] = 290571,
  [SMALL_STATE(6861)] = 290627,
  [SMALL_STATE(6862)] = 290683,
  [SMALL_STATE(6863)] = 290739,
  [SMALL_STATE(6864)] = 290795,
  [SMALL_STATE(6865)] = 290851,
  [SMALL_STATE(6866)] = 290907,
  [SMALL_STATE(6867)] = 290963,
  [SMALL_STATE(6868)] = 291019,
  [SMALL_STATE(6869)] = 291075,
  [SMALL_STATE(6870)] = 291131,
  [SMALL_STATE(6871)] = 291187,
  [SMALL_STATE(6872)] = 291243,
  [SMALL_STATE(6873)] = 291299,
  [SMALL_STATE(6874)] = 291355,
  [SMALL_STATE(6875)] = 291417,
  [SMALL_STATE(6876)] = 291473,
  [SMALL_STATE(6877)] = 291529,
  [SMALL_STATE(6878)] = 291585,
  [SMALL_STATE(6879)] = 291641,
  [SMALL_STATE(6880)] = 291699,
  [SMALL_STATE(6881)] = 291755,
  [SMALL_STATE(6882)] = 291811,
  [SMALL_STATE(6883)] = 291867,
  [SMALL_STATE(6884)] = 291923,
  [SMALL_STATE(6885)] = 291979,
  [SMALL_STATE(6886)] = 292035,
  [SMALL_STATE(6887)] = 292091,
  [SMALL_STATE(6888)] = 292147,
  [SMALL_STATE(6889)] = 292209,
  [SMALL_STATE(6890)] = 292265,
  [SMALL_STATE(6891)] = 292321,
  [SMALL_STATE(6892)] = 292377,
  [SMALL_STATE(6893)] = 292433,
  [SMALL_STATE(6894)] = 292489,
  [SMALL_STATE(6895)] = 292545,
  [SMALL_STATE(6896)] = 292601,
  [SMALL_STATE(6897)] = 292657,
  [SMALL_STATE(6898)] = 292713,
  [SMALL_STATE(6899)] = 292769,
  [SMALL_STATE(6900)] = 292825,
  [SMALL_STATE(6901)] = 292881,
  [SMALL_STATE(6902)] = 292937,
  [SMALL_STATE(6903)] = 292993,
  [SMALL_STATE(6904)] = 293049,
  [SMALL_STATE(6905)] = 293105,
  [SMALL_STATE(6906)] = 293161,
  [SMALL_STATE(6907)] = 293217,
  [SMALL_STATE(6908)] = 293273,
  [SMALL_STATE(6909)] = 293329,
  [SMALL_STATE(6910)] = 293385,
  [SMALL_STATE(6911)] = 293441,
  [SMALL_STATE(6912)] = 293497,
  [SMALL_STATE(6913)] = 293553,
  [SMALL_STATE(6914)] = 293609,
  [SMALL_STATE(6915)] = 293665,
  [SMALL_STATE(6916)] = 293721,
  [SMALL_STATE(6917)] = 293777,
  [SMALL_STATE(6918)] = 293833,
  [SMALL_STATE(6919)] = 293889,
  [SMALL_STATE(6920)] = 293945,
  [SMALL_STATE(6921)] = 294001,
  [SMALL_STATE(6922)] = 294057,
  [SMALL_STATE(6923)] = 294113,
  [SMALL_STATE(6924)] = 294169,
  [SMALL_STATE(6925)] = 294225,
  [SMALL_STATE(6926)] = 294281,
  [SMALL_STATE(6927)] = 294339,
  [SMALL_STATE(6928)] = 294395,
  [SMALL_STATE(6929)] = 294451,
  [SMALL_STATE(6930)] = 294507,
  [SMALL_STATE(6931)] = 294563,
  [SMALL_STATE(6932)] = 294619,
  [SMALL_STATE(6933)] = 294675,
  [SMALL_STATE(6934)] = 294733,
  [SMALL_STATE(6935)] = 294789,
  [SMALL_STATE(6936)] = 294845,
  [SMALL_STATE(6937)] = 294901,
  [SMALL_STATE(6938)] = 294959,
  [SMALL_STATE(6939)] = 295017,
  [SMALL_STATE(6940)] = 295073,
  [SMALL_STATE(6941)] = 295129,
  [SMALL_STATE(6942)] = 295185,
  [SMALL_STATE(6943)] = 295241,
  [SMALL_STATE(6944)] = 295297,
  [SMALL_STATE(6945)] = 295359,
  [SMALL_STATE(6946)] = 295415,
  [SMALL_STATE(6947)] = 295471,
  [SMALL_STATE(6948)] = 295527,
  [SMALL_STATE(6949)] = 295585,
  [SMALL_STATE(6950)] = 295641,
  [SMALL_STATE(6951)] = 295697,
  [SMALL_STATE(6952)] = 295753,
  [SMALL_STATE(6953)] = 295809,
  [SMALL_STATE(6954)] = 295865,
  [SMALL_STATE(6955)] = 295921,
  [SMALL_STATE(6956)] = 295977,
  [SMALL_STATE(6957)] = 296033,
  [SMALL_STATE(6958)] = 296095,
  [SMALL_STATE(6959)] = 296151,
  [SMALL_STATE(6960)] = 296207,
  [SMALL_STATE(6961)] = 296263,
  [SMALL_STATE(6962)] = 296319,
  [SMALL_STATE(6963)] = 296375,
  [SMALL_STATE(6964)] = 296431,
  [SMALL_STATE(6965)] = 296487,
  [SMALL_STATE(6966)] = 296543,
  [SMALL_STATE(6967)] = 296601,
  [SMALL_STATE(6968)] = 296657,
  [SMALL_STATE(6969)] = 296713,
  [SMALL_STATE(6970)] = 296769,
  [SMALL_STATE(6971)] = 296825,
  [SMALL_STATE(6972)] = 296881,
  [SMALL_STATE(6973)] = 296937,
  [SMALL_STATE(6974)] = 296993,
  [SMALL_STATE(6975)] = 297049,
  [SMALL_STATE(6976)] = 297105,
  [SMALL_STATE(6977)] = 297161,
  [SMALL_STATE(6978)] = 297217,
  [SMALL_STATE(6979)] = 297273,
  [SMALL_STATE(6980)] = 297329,
  [SMALL_STATE(6981)] = 297385,
  [SMALL_STATE(6982)] = 297441,
  [SMALL_STATE(6983)] = 297497,
  [SMALL_STATE(6984)] = 297553,
  [SMALL_STATE(6985)] = 297615,
  [SMALL_STATE(6986)] = 297671,
  [SMALL_STATE(6987)] = 297727,
  [SMALL_STATE(6988)] = 297783,
  [SMALL_STATE(6989)] = 297839,
  [SMALL_STATE(6990)] = 297895,
  [SMALL_STATE(6991)] = 297951,
  [SMALL_STATE(6992)] = 298007,
  [SMALL_STATE(6993)] = 298063,
  [SMALL_STATE(6994)] = 298119,
  [SMALL_STATE(6995)] = 298175,
  [SMALL_STATE(6996)] = 298231,
  [SMALL_STATE(6997)] = 298287,
  [SMALL_STATE(6998)] = 298343,
  [SMALL_STATE(6999)] = 298399,
  [SMALL_STATE(7000)] = 298455,
  [SMALL_STATE(7001)] = 298513,
  [SMALL_STATE(7002)] = 298569,
  [SMALL_STATE(7003)] = 298625,
  [SMALL_STATE(7004)] = 298681,
  [SMALL_STATE(7005)] = 298737,
  [SMALL_STATE(7006)] = 298793,
  [SMALL_STATE(7007)] = 298849,
  [SMALL_STATE(7008)] = 298905,
  [SMALL_STATE(7009)] = 298961,
  [SMALL_STATE(7010)] = 299017,
  [SMALL_STATE(7011)] = 299073,
  [SMALL_STATE(7012)] = 299129,
  [SMALL_STATE(7013)] = 299185,
  [SMALL_STATE(7014)] = 299241,
  [SMALL_STATE(7015)] = 299297,
  [SMALL_STATE(7016)] = 299353,
  [SMALL_STATE(7017)] = 299409,
  [SMALL_STATE(7018)] = 299465,
  [SMALL_STATE(7019)] = 299521,
  [SMALL_STATE(7020)] = 299577,
  [SMALL_STATE(7021)] = 299633,
  [SMALL_STATE(7022)] = 299691,
  [SMALL_STATE(7023)] = 299747,
  [SMALL_STATE(7024)] = 299803,
  [SMALL_STATE(7025)] = 299859,
  [SMALL_STATE(7026)] = 299914,
  [SMALL_STATE(7027)] = 299969,
  [SMALL_STATE(7028)] = 300026,
  [SMALL_STATE(7029)] = 300081,
  [SMALL_STATE(7030)] = 300136,
  [SMALL_STATE(7031)] = 300191,
  [SMALL_STATE(7032)] = 300246,
  [SMALL_STATE(7033)] = 300301,
  [SMALL_STATE(7034)] = 300356,
  [SMALL_STATE(7035)] = 300411,
  [SMALL_STATE(7036)] = 300466,
  [SMALL_STATE(7037)] = 300521,
  [SMALL_STATE(7038)] = 300576,
  [SMALL_STATE(7039)] = 300633,
  [SMALL_STATE(7040)] = 300688,
  [SMALL_STATE(7041)] = 300743,
  [SMALL_STATE(7042)] = 300798,
  [SMALL_STATE(7043)] = 300853,
  [SMALL_STATE(7044)] = 300908,
  [SMALL_STATE(7045)] = 300963,
  [SMALL_STATE(7046)] = 301018,
  [SMALL_STATE(7047)] = 301073,
  [SMALL_STATE(7048)] = 301130,
  [SMALL_STATE(7049)] = 301185,
  [SMALL_STATE(7050)] = 301240,
  [SMALL_STATE(7051)] = 301295,
  [SMALL_STATE(7052)] = 301350,
  [SMALL_STATE(7053)] = 301407,
  [SMALL_STATE(7054)] = 301462,
  [SMALL_STATE(7055)] = 301517,
  [SMALL_STATE(7056)] = 301572,
  [SMALL_STATE(7057)] = 301627,
  [SMALL_STATE(7058)] = 301682,
  [SMALL_STATE(7059)] = 301737,
  [SMALL_STATE(7060)] = 301792,
  [SMALL_STATE(7061)] = 301847,
  [SMALL_STATE(7062)] = 301902,
  [SMALL_STATE(7063)] = 301957,
  [SMALL_STATE(7064)] = 302012,
  [SMALL_STATE(7065)] = 302067,
  [SMALL_STATE(7066)] = 302122,
  [SMALL_STATE(7067)] = 302177,
  [SMALL_STATE(7068)] = 302232,
  [SMALL_STATE(7069)] = 302287,
  [SMALL_STATE(7070)] = 302342,
  [SMALL_STATE(7071)] = 302399,
  [SMALL_STATE(7072)] = 302454,
  [SMALL_STATE(7073)] = 302509,
  [SMALL_STATE(7074)] = 302564,
  [SMALL_STATE(7075)] = 302619,
  [SMALL_STATE(7076)] = 302674,
  [SMALL_STATE(7077)] = 302729,
  [SMALL_STATE(7078)] = 302784,
  [SMALL_STATE(7079)] = 302839,
  [SMALL_STATE(7080)] = 302894,
  [SMALL_STATE(7081)] = 302949,
  [SMALL_STATE(7082)] = 303004,
  [SMALL_STATE(7083)] = 303059,
  [SMALL_STATE(7084)] = 303114,
  [SMALL_STATE(7085)] = 303169,
  [SMALL_STATE(7086)] = 303224,
  [SMALL_STATE(7087)] = 303279,
  [SMALL_STATE(7088)] = 303334,
  [SMALL_STATE(7089)] = 303389,
  [SMALL_STATE(7090)] = 303444,
  [SMALL_STATE(7091)] = 303499,
  [SMALL_STATE(7092)] = 303554,
  [SMALL_STATE(7093)] = 303609,
  [SMALL_STATE(7094)] = 303664,
  [SMALL_STATE(7095)] = 303719,
  [SMALL_STATE(7096)] = 303780,
  [SMALL_STATE(7097)] = 303835,
  [SMALL_STATE(7098)] = 303890,
  [SMALL_STATE(7099)] = 303945,
  [SMALL_STATE(7100)] = 304000,
  [SMALL_STATE(7101)] = 304055,
  [SMALL_STATE(7102)] = 304110,
  [SMALL_STATE(7103)] = 304165,
  [SMALL_STATE(7104)] = 304220,
  [SMALL_STATE(7105)] = 304275,
  [SMALL_STATE(7106)] = 304336,
  [SMALL_STATE(7107)] = 304391,
  [SMALL_STATE(7108)] = 304446,
  [SMALL_STATE(7109)] = 304501,
  [SMALL_STATE(7110)] = 304556,
  [SMALL_STATE(7111)] = 304611,
  [SMALL_STATE(7112)] = 304666,
  [SMALL_STATE(7113)] = 304721,
  [SMALL_STATE(7114)] = 304776,
  [SMALL_STATE(7115)] = 304831,
  [SMALL_STATE(7116)] = 304886,
  [SMALL_STATE(7117)] = 304941,
  [SMALL_STATE(7118)] = 304996,
  [SMALL_STATE(7119)] = 305051,
  [SMALL_STATE(7120)] = 305106,
  [SMALL_STATE(7121)] = 305161,
  [SMALL_STATE(7122)] = 305216,
  [SMALL_STATE(7123)] = 305271,
  [SMALL_STATE(7124)] = 305326,
  [SMALL_STATE(7125)] = 305381,
  [SMALL_STATE(7126)] = 305436,
  [SMALL_STATE(7127)] = 305491,
  [SMALL_STATE(7128)] = 305546,
  [SMALL_STATE(7129)] = 305603,
  [SMALL_STATE(7130)] = 305658,
  [SMALL_STATE(7131)] = 305713,
  [SMALL_STATE(7132)] = 305768,
  [SMALL_STATE(7133)] = 305825,
  [SMALL_STATE(7134)] = 305880,
  [SMALL_STATE(7135)] = 305935,
  [SMALL_STATE(7136)] = 305990,
  [SMALL_STATE(7137)] = 306047,
  [SMALL_STATE(7138)] = 306104,
  [SMALL_STATE(7139)] = 306159,
  [SMALL_STATE(7140)] = 306214,
  [SMALL_STATE(7141)] = 306269,
  [SMALL_STATE(7142)] = 306324,
  [SMALL_STATE(7143)] = 306381,
  [SMALL_STATE(7144)] = 306436,
  [SMALL_STATE(7145)] = 306491,
  [SMALL_STATE(7146)] = 306552,
  [SMALL_STATE(7147)] = 306609,
  [SMALL_STATE(7148)] = 306664,
  [SMALL_STATE(7149)] = 306721,
  [SMALL_STATE(7150)] = 306776,
  [SMALL_STATE(7151)] = 306831,
  [SMALL_STATE(7152)] = 306886,
  [SMALL_STATE(7153)] = 306947,
  [SMALL_STATE(7154)] = 307008,
  [SMALL_STATE(7155)] = 307069,
  [SMALL_STATE(7156)] = 307124,
  [SMALL_STATE(7157)] = 307179,
  [SMALL_STATE(7158)] = 307234,
  [SMALL_STATE(7159)] = 307289,
  [SMALL_STATE(7160)] = 307344,
  [SMALL_STATE(7161)] = 307399,
  [SMALL_STATE(7162)] = 307454,
  [SMALL_STATE(7163)] = 307509,
  [SMALL_STATE(7164)] = 307564,
  [SMALL_STATE(7165)] = 307619,
  [SMALL_STATE(7166)] = 307674,
  [SMALL_STATE(7167)] = 307729,
  [SMALL_STATE(7168)] = 307784,
  [SMALL_STATE(7169)] = 307839,
  [SMALL_STATE(7170)] = 307894,
  [SMALL_STATE(7171)] = 307949,
  [SMALL_STATE(7172)] = 308004,
  [SMALL_STATE(7173)] = 308059,
  [SMALL_STATE(7174)] = 308114,
  [SMALL_STATE(7175)] = 308169,
  [SMALL_STATE(7176)] = 308224,
  [SMALL_STATE(7177)] = 308279,
  [SMALL_STATE(7178)] = 308334,
  [SMALL_STATE(7179)] = 308389,
  [SMALL_STATE(7180)] = 308444,
  [SMALL_STATE(7181)] = 308499,
  [SMALL_STATE(7182)] = 308554,
  [SMALL_STATE(7183)] = 308609,
  [SMALL_STATE(7184)] = 308664,
  [SMALL_STATE(7185)] = 308719,
  [SMALL_STATE(7186)] = 308774,
  [SMALL_STATE(7187)] = 308829,
  [SMALL_STATE(7188)] = 308884,
  [SMALL_STATE(7189)] = 308941,
  [SMALL_STATE(7190)] = 308996,
  [SMALL_STATE(7191)] = 309051,
  [SMALL_STATE(7192)] = 309106,
  [SMALL_STATE(7193)] = 309161,
  [SMALL_STATE(7194)] = 309216,
  [SMALL_STATE(7195)] = 309271,
  [SMALL_STATE(7196)] = 309326,
  [SMALL_STATE(7197)] = 309381,
  [SMALL_STATE(7198)] = 309436,
  [SMALL_STATE(7199)] = 309491,
  [SMALL_STATE(7200)] = 309546,
  [SMALL_STATE(7201)] = 309601,
  [SMALL_STATE(7202)] = 309656,
  [SMALL_STATE(7203)] = 309711,
  [SMALL_STATE(7204)] = 309766,
  [SMALL_STATE(7205)] = 309821,
  [SMALL_STATE(7206)] = 309876,
  [SMALL_STATE(7207)] = 309931,
  [SMALL_STATE(7208)] = 309986,
  [SMALL_STATE(7209)] = 310041,
  [SMALL_STATE(7210)] = 310096,
  [SMALL_STATE(7211)] = 310151,
  [SMALL_STATE(7212)] = 310206,
  [SMALL_STATE(7213)] = 310261,
  [SMALL_STATE(7214)] = 310316,
  [SMALL_STATE(7215)] = 310371,
  [SMALL_STATE(7216)] = 310426,
  [SMALL_STATE(7217)] = 310487,
  [SMALL_STATE(7218)] = 310544,
  [SMALL_STATE(7219)] = 310599,
  [SMALL_STATE(7220)] = 310654,
  [SMALL_STATE(7221)] = 310709,
  [SMALL_STATE(7222)] = 310764,
  [SMALL_STATE(7223)] = 310819,
  [SMALL_STATE(7224)] = 310874,
  [SMALL_STATE(7225)] = 310929,
  [SMALL_STATE(7226)] = 310984,
  [SMALL_STATE(7227)] = 311039,
  [SMALL_STATE(7228)] = 311094,
  [SMALL_STATE(7229)] = 311149,
  [SMALL_STATE(7230)] = 311204,
  [SMALL_STATE(7231)] = 311259,
  [SMALL_STATE(7232)] = 311314,
  [SMALL_STATE(7233)] = 311369,
  [SMALL_STATE(7234)] = 311430,
  [SMALL_STATE(7235)] = 311485,
  [SMALL_STATE(7236)] = 311540,
  [SMALL_STATE(7237)] = 311595,
  [SMALL_STATE(7238)] = 311650,
  [SMALL_STATE(7239)] = 311705,
  [SMALL_STATE(7240)] = 311760,
  [SMALL_STATE(7241)] = 311815,
  [SMALL_STATE(7242)] = 311872,
  [SMALL_STATE(7243)] = 311927,
  [SMALL_STATE(7244)] = 311982,
  [SMALL_STATE(7245)] = 312037,
  [SMALL_STATE(7246)] = 312092,
  [SMALL_STATE(7247)] = 312147,
  [SMALL_STATE(7248)] = 312202,
  [SMALL_STATE(7249)] = 312257,
  [SMALL_STATE(7250)] = 312312,
  [SMALL_STATE(7251)] = 312367,
  [SMALL_STATE(7252)] = 312422,
  [SMALL_STATE(7253)] = 312477,
  [SMALL_STATE(7254)] = 312532,
  [SMALL_STATE(7255)] = 312587,
  [SMALL_STATE(7256)] = 312642,
  [SMALL_STATE(7257)] = 312697,
  [SMALL_STATE(7258)] = 312752,
  [SMALL_STATE(7259)] = 312807,
  [SMALL_STATE(7260)] = 312862,
  [SMALL_STATE(7261)] = 312917,
  [SMALL_STATE(7262)] = 312972,
  [SMALL_STATE(7263)] = 313027,
  [SMALL_STATE(7264)] = 313082,
  [SMALL_STATE(7265)] = 313137,
  [SMALL_STATE(7266)] = 313192,
  [SMALL_STATE(7267)] = 313247,
  [SMALL_STATE(7268)] = 313302,
  [SMALL_STATE(7269)] = 313357,
  [SMALL_STATE(7270)] = 313412,
  [SMALL_STATE(7271)] = 313467,
  [SMALL_STATE(7272)] = 313522,
  [SMALL_STATE(7273)] = 313577,
  [SMALL_STATE(7274)] = 313632,
  [SMALL_STATE(7275)] = 313687,
  [SMALL_STATE(7276)] = 313742,
  [SMALL_STATE(7277)] = 313797,
  [SMALL_STATE(7278)] = 313854,
  [SMALL_STATE(7279)] = 313909,
  [SMALL_STATE(7280)] = 313964,
  [SMALL_STATE(7281)] = 314019,
  [SMALL_STATE(7282)] = 314074,
  [SMALL_STATE(7283)] = 314129,
  [SMALL_STATE(7284)] = 314184,
  [SMALL_STATE(7285)] = 314239,
  [SMALL_STATE(7286)] = 314294,
  [SMALL_STATE(7287)] = 314349,
  [SMALL_STATE(7288)] = 314404,
  [SMALL_STATE(7289)] = 314459,
  [SMALL_STATE(7290)] = 314514,
  [SMALL_STATE(7291)] = 314569,
  [SMALL_STATE(7292)] = 314624,
  [SMALL_STATE(7293)] = 314681,
  [SMALL_STATE(7294)] = 314736,
  [SMALL_STATE(7295)] = 314791,
  [SMALL_STATE(7296)] = 314846,
  [SMALL_STATE(7297)] = 314901,
  [SMALL_STATE(7298)] = 314956,
  [SMALL_STATE(7299)] = 315011,
  [SMALL_STATE(7300)] = 315066,
  [SMALL_STATE(7301)] = 315121,
  [SMALL_STATE(7302)] = 315176,
  [SMALL_STATE(7303)] = 315231,
  [SMALL_STATE(7304)] = 315286,
  [SMALL_STATE(7305)] = 315341,
  [SMALL_STATE(7306)] = 315396,
  [SMALL_STATE(7307)] = 315451,
  [SMALL_STATE(7308)] = 315506,
  [SMALL_STATE(7309)] = 315561,
  [SMALL_STATE(7310)] = 315616,
  [SMALL_STATE(7311)] = 315671,
  [SMALL_STATE(7312)] = 315726,
  [SMALL_STATE(7313)] = 315781,
  [SMALL_STATE(7314)] = 315836,
  [SMALL_STATE(7315)] = 315891,
  [SMALL_STATE(7316)] = 315946,
  [SMALL_STATE(7317)] = 316001,
  [SMALL_STATE(7318)] = 316056,
  [SMALL_STATE(7319)] = 316111,
  [SMALL_STATE(7320)] = 316166,
  [SMALL_STATE(7321)] = 316221,
  [SMALL_STATE(7322)] = 316276,
  [SMALL_STATE(7323)] = 316331,
  [SMALL_STATE(7324)] = 316386,
  [SMALL_STATE(7325)] = 316441,
  [SMALL_STATE(7326)] = 316496,
  [SMALL_STATE(7327)] = 316551,
  [SMALL_STATE(7328)] = 316606,
  [SMALL_STATE(7329)] = 316661,
  [SMALL_STATE(7330)] = 316716,
  [SMALL_STATE(7331)] = 316771,
  [SMALL_STATE(7332)] = 316826,
  [SMALL_STATE(7333)] = 316881,
  [SMALL_STATE(7334)] = 316936,
  [SMALL_STATE(7335)] = 316991,
  [SMALL_STATE(7336)] = 317046,
  [SMALL_STATE(7337)] = 317101,
  [SMALL_STATE(7338)] = 317158,
  [SMALL_STATE(7339)] = 317213,
  [SMALL_STATE(7340)] = 317268,
  [SMALL_STATE(7341)] = 317323,
  [SMALL_STATE(7342)] = 317378,
  [SMALL_STATE(7343)] = 317433,
  [SMALL_STATE(7344)] = 317488,
  [SMALL_STATE(7345)] = 317543,
  [SMALL_STATE(7346)] = 317598,
  [SMALL_STATE(7347)] = 317653,
  [SMALL_STATE(7348)] = 317708,
  [SMALL_STATE(7349)] = 317763,
  [SMALL_STATE(7350)] = 317818,
  [SMALL_STATE(7351)] = 317873,
  [SMALL_STATE(7352)] = 317928,
  [SMALL_STATE(7353)] = 317983,
  [SMALL_STATE(7354)] = 318038,
  [SMALL_STATE(7355)] = 318093,
  [SMALL_STATE(7356)] = 318154,
  [SMALL_STATE(7357)] = 318211,
  [SMALL_STATE(7358)] = 318266,
  [SMALL_STATE(7359)] = 318321,
  [SMALL_STATE(7360)] = 318376,
  [SMALL_STATE(7361)] = 318431,
  [SMALL_STATE(7362)] = 318486,
  [SMALL_STATE(7363)] = 318541,
  [SMALL_STATE(7364)] = 318596,
  [SMALL_STATE(7365)] = 318651,
  [SMALL_STATE(7366)] = 318706,
  [SMALL_STATE(7367)] = 318761,
  [SMALL_STATE(7368)] = 318816,
  [SMALL_STATE(7369)] = 318871,
  [SMALL_STATE(7370)] = 318926,
  [SMALL_STATE(7371)] = 318981,
  [SMALL_STATE(7372)] = 319036,
  [SMALL_STATE(7373)] = 319091,
  [SMALL_STATE(7374)] = 319146,
  [SMALL_STATE(7375)] = 319201,
  [SMALL_STATE(7376)] = 319256,
  [SMALL_STATE(7377)] = 319311,
  [SMALL_STATE(7378)] = 319366,
  [SMALL_STATE(7379)] = 319421,
  [SMALL_STATE(7380)] = 319476,
  [SMALL_STATE(7381)] = 319531,
  [SMALL_STATE(7382)] = 319586,
  [SMALL_STATE(7383)] = 319641,
  [SMALL_STATE(7384)] = 319696,
  [SMALL_STATE(7385)] = 319751,
  [SMALL_STATE(7386)] = 319806,
  [SMALL_STATE(7387)] = 319863,
  [SMALL_STATE(7388)] = 319918,
  [SMALL_STATE(7389)] = 319973,
  [SMALL_STATE(7390)] = 320028,
  [SMALL_STATE(7391)] = 320083,
  [SMALL_STATE(7392)] = 320138,
  [SMALL_STATE(7393)] = 320193,
  [SMALL_STATE(7394)] = 320248,
  [SMALL_STATE(7395)] = 320303,
  [SMALL_STATE(7396)] = 320358,
  [SMALL_STATE(7397)] = 320413,
  [SMALL_STATE(7398)] = 320468,
  [SMALL_STATE(7399)] = 320523,
  [SMALL_STATE(7400)] = 320578,
  [SMALL_STATE(7401)] = 320633,
  [SMALL_STATE(7402)] = 320688,
  [SMALL_STATE(7403)] = 320743,
  [SMALL_STATE(7404)] = 320798,
  [SMALL_STATE(7405)] = 320853,
  [SMALL_STATE(7406)] = 320908,
  [SMALL_STATE(7407)] = 320963,
  [SMALL_STATE(7408)] = 321018,
  [SMALL_STATE(7409)] = 321073,
  [SMALL_STATE(7410)] = 321128,
  [SMALL_STATE(7411)] = 321183,
  [SMALL_STATE(7412)] = 321238,
  [SMALL_STATE(7413)] = 321293,
  [SMALL_STATE(7414)] = 321348,
  [SMALL_STATE(7415)] = 321403,
  [SMALL_STATE(7416)] = 321458,
  [SMALL_STATE(7417)] = 321513,
  [SMALL_STATE(7418)] = 321568,
  [SMALL_STATE(7419)] = 321623,
  [SMALL_STATE(7420)] = 321678,
  [SMALL_STATE(7421)] = 321735,
  [SMALL_STATE(7422)] = 321792,
  [SMALL_STATE(7423)] = 321847,
  [SMALL_STATE(7424)] = 321902,
  [SMALL_STATE(7425)] = 321963,
  [SMALL_STATE(7426)] = 322018,
  [SMALL_STATE(7427)] = 322073,
  [SMALL_STATE(7428)] = 322128,
  [SMALL_STATE(7429)] = 322183,
  [SMALL_STATE(7430)] = 322238,
  [SMALL_STATE(7431)] = 322293,
  [SMALL_STATE(7432)] = 322348,
  [SMALL_STATE(7433)] = 322403,
  [SMALL_STATE(7434)] = 322464,
  [SMALL_STATE(7435)] = 322519,
  [SMALL_STATE(7436)] = 322574,
  [SMALL_STATE(7437)] = 322629,
  [SMALL_STATE(7438)] = 322684,
  [SMALL_STATE(7439)] = 322739,
  [SMALL_STATE(7440)] = 322794,
  [SMALL_STATE(7441)] = 322849,
  [SMALL_STATE(7442)] = 322904,
  [SMALL_STATE(7443)] = 322959,
  [SMALL_STATE(7444)] = 323014,
  [SMALL_STATE(7445)] = 323069,
  [SMALL_STATE(7446)] = 323124,
  [SMALL_STATE(7447)] = 323179,
  [SMALL_STATE(7448)] = 323236,
  [SMALL_STATE(7449)] = 323291,
  [SMALL_STATE(7450)] = 323346,
  [SMALL_STATE(7451)] = 323401,
  [SMALL_STATE(7452)] = 323456,
  [SMALL_STATE(7453)] = 323511,
  [SMALL_STATE(7454)] = 323566,
  [SMALL_STATE(7455)] = 323621,
  [SMALL_STATE(7456)] = 323676,
  [SMALL_STATE(7457)] = 323731,
  [SMALL_STATE(7458)] = 323786,
  [SMALL_STATE(7459)] = 323841,
  [SMALL_STATE(7460)] = 323896,
  [SMALL_STATE(7461)] = 323951,
  [SMALL_STATE(7462)] = 324006,
  [SMALL_STATE(7463)] = 324063,
  [SMALL_STATE(7464)] = 324118,
  [SMALL_STATE(7465)] = 324173,
  [SMALL_STATE(7466)] = 324228,
  [SMALL_STATE(7467)] = 324283,
  [SMALL_STATE(7468)] = 324338,
  [SMALL_STATE(7469)] = 324393,
  [SMALL_STATE(7470)] = 324448,
  [SMALL_STATE(7471)] = 324503,
  [SMALL_STATE(7472)] = 324558,
  [SMALL_STATE(7473)] = 324613,
  [SMALL_STATE(7474)] = 324668,
  [SMALL_STATE(7475)] = 324723,
  [SMALL_STATE(7476)] = 324778,
  [SMALL_STATE(7477)] = 324833,
  [SMALL_STATE(7478)] = 324888,
  [SMALL_STATE(7479)] = 324949,
  [SMALL_STATE(7480)] = 325004,
  [SMALL_STATE(7481)] = 325059,
  [SMALL_STATE(7482)] = 325114,
  [SMALL_STATE(7483)] = 325169,
  [SMALL_STATE(7484)] = 325224,
  [SMALL_STATE(7485)] = 325279,
  [SMALL_STATE(7486)] = 325334,
  [SMALL_STATE(7487)] = 325389,
  [SMALL_STATE(7488)] = 325444,
  [SMALL_STATE(7489)] = 325499,
  [SMALL_STATE(7490)] = 325554,
  [SMALL_STATE(7491)] = 325609,
  [SMALL_STATE(7492)] = 325664,
  [SMALL_STATE(7493)] = 325719,
  [SMALL_STATE(7494)] = 325774,
  [SMALL_STATE(7495)] = 325829,
  [SMALL_STATE(7496)] = 325886,
  [SMALL_STATE(7497)] = 325941,
  [SMALL_STATE(7498)] = 325996,
  [SMALL_STATE(7499)] = 326051,
  [SMALL_STATE(7500)] = 326106,
  [SMALL_STATE(7501)] = 326161,
  [SMALL_STATE(7502)] = 326216,
  [SMALL_STATE(7503)] = 326271,
  [SMALL_STATE(7504)] = 326326,
  [SMALL_STATE(7505)] = 326381,
  [SMALL_STATE(7506)] = 326436,
  [SMALL_STATE(7507)] = 326491,
  [SMALL_STATE(7508)] = 326546,
  [SMALL_STATE(7509)] = 326601,
  [SMALL_STATE(7510)] = 326656,
  [SMALL_STATE(7511)] = 326711,
  [SMALL_STATE(7512)] = 326766,
  [SMALL_STATE(7513)] = 326823,
  [SMALL_STATE(7514)] = 326878,
  [SMALL_STATE(7515)] = 326935,
  [SMALL_STATE(7516)] = 326990,
  [SMALL_STATE(7517)] = 327045,
  [SMALL_STATE(7518)] = 327100,
  [SMALL_STATE(7519)] = 327154,
  [SMALL_STATE(7520)] = 327208,
  [SMALL_STATE(7521)] = 327262,
  [SMALL_STATE(7522)] = 327316,
  [SMALL_STATE(7523)] = 327370,
  [SMALL_STATE(7524)] = 327424,
  [SMALL_STATE(7525)] = 327478,
  [SMALL_STATE(7526)] = 327532,
  [SMALL_STATE(7527)] = 327586,
  [SMALL_STATE(7528)] = 327640,
  [SMALL_STATE(7529)] = 327694,
  [SMALL_STATE(7530)] = 327748,
  [SMALL_STATE(7531)] = 327802,
  [SMALL_STATE(7532)] = 327856,
  [SMALL_STATE(7533)] = 327910,
  [SMALL_STATE(7534)] = 327964,
  [SMALL_STATE(7535)] = 328018,
  [SMALL_STATE(7536)] = 328072,
  [SMALL_STATE(7537)] = 328126,
  [SMALL_STATE(7538)] = 328180,
  [SMALL_STATE(7539)] = 328234,
  [SMALL_STATE(7540)] = 328288,
  [SMALL_STATE(7541)] = 328342,
  [SMALL_STATE(7542)] = 328396,
  [SMALL_STATE(7543)] = 328450,
  [SMALL_STATE(7544)] = 328504,
  [SMALL_STATE(7545)] = 328558,
  [SMALL_STATE(7546)] = 328614,
  [SMALL_STATE(7547)] = 328668,
  [SMALL_STATE(7548)] = 328722,
  [SMALL_STATE(7549)] = 328776,
  [SMALL_STATE(7550)] = 328830,
  [SMALL_STATE(7551)] = 328884,
  [SMALL_STATE(7552)] = 328938,
  [SMALL_STATE(7553)] = 328992,
  [SMALL_STATE(7554)] = 329046,
  [SMALL_STATE(7555)] = 329100,
  [SMALL_STATE(7556)] = 329154,
  [SMALL_STATE(7557)] = 329208,
  [SMALL_STATE(7558)] = 329262,
  [SMALL_STATE(7559)] = 329316,
  [SMALL_STATE(7560)] = 329372,
  [SMALL_STATE(7561)] = 329426,
  [SMALL_STATE(7562)] = 329482,
  [SMALL_STATE(7563)] = 329536,
  [SMALL_STATE(7564)] = 329592,
  [SMALL_STATE(7565)] = 329646,
  [SMALL_STATE(7566)] = 329700,
  [SMALL_STATE(7567)] = 329754,
  [SMALL_STATE(7568)] = 329808,
  [SMALL_STATE(7569)] = 329862,
  [SMALL_STATE(7570)] = 329916,
  [SMALL_STATE(7571)] = 329970,
  [SMALL_STATE(7572)] = 330026,
  [SMALL_STATE(7573)] = 330080,
  [SMALL_STATE(7574)] = 330134,
  [SMALL_STATE(7575)] = 330188,
  [SMALL_STATE(7576)] = 330244,
  [SMALL_STATE(7577)] = 330298,
  [SMALL_STATE(7578)] = 330352,
  [SMALL_STATE(7579)] = 330406,
  [SMALL_STATE(7580)] = 330460,
  [SMALL_STATE(7581)] = 330514,
  [SMALL_STATE(7582)] = 330568,
  [SMALL_STATE(7583)] = 330622,
  [SMALL_STATE(7584)] = 330676,
  [SMALL_STATE(7585)] = 330732,
  [SMALL_STATE(7586)] = 330788,
  [SMALL_STATE(7587)] = 330844,
  [SMALL_STATE(7588)] = 330898,
  [SMALL_STATE(7589)] = 330952,
  [SMALL_STATE(7590)] = 331008,
  [SMALL_STATE(7591)] = 331062,
  [SMALL_STATE(7592)] = 331118,
  [SMALL_STATE(7593)] = 331172,
  [SMALL_STATE(7594)] = 331226,
  [SMALL_STATE(7595)] = 331280,
  [SMALL_STATE(7596)] = 331334,
  [SMALL_STATE(7597)] = 331388,
  [SMALL_STATE(7598)] = 331442,
  [SMALL_STATE(7599)] = 331496,
  [SMALL_STATE(7600)] = 331550,
  [SMALL_STATE(7601)] = 331604,
  [SMALL_STATE(7602)] = 331658,
  [SMALL_STATE(7603)] = 331712,
  [SMALL_STATE(7604)] = 331766,
  [SMALL_STATE(7605)] = 331820,
  [SMALL_STATE(7606)] = 331874,
  [SMALL_STATE(7607)] = 331928,
  [SMALL_STATE(7608)] = 331982,
  [SMALL_STATE(7609)] = 332036,
  [SMALL_STATE(7610)] = 332090,
  [SMALL_STATE(7611)] = 332144,
  [SMALL_STATE(7612)] = 332198,
  [SMALL_STATE(7613)] = 332252,
  [SMALL_STATE(7614)] = 332306,
  [SMALL_STATE(7615)] = 332360,
  [SMALL_STATE(7616)] = 332414,
  [SMALL_STATE(7617)] = 332468,
  [SMALL_STATE(7618)] = 332522,
  [SMALL_STATE(7619)] = 332578,
  [SMALL_STATE(7620)] = 332634,
  [SMALL_STATE(7621)] = 332688,
  [SMALL_STATE(7622)] = 332742,
  [SMALL_STATE(7623)] = 332796,
  [SMALL_STATE(7624)] = 332850,
  [SMALL_STATE(7625)] = 332904,
  [SMALL_STATE(7626)] = 332958,
  [SMALL_STATE(7627)] = 333012,
  [SMALL_STATE(7628)] = 333066,
  [SMALL_STATE(7629)] = 333120,
  [SMALL_STATE(7630)] = 333174,
  [SMALL_STATE(7631)] = 333228,
  [SMALL_STATE(7632)] = 333282,
  [SMALL_STATE(7633)] = 333336,
  [SMALL_STATE(7634)] = 333392,
  [SMALL_STATE(7635)] = 333446,
  [SMALL_STATE(7636)] = 333500,
  [SMALL_STATE(7637)] = 333554,
  [SMALL_STATE(7638)] = 333608,
  [SMALL_STATE(7639)] = 333662,
  [SMALL_STATE(7640)] = 333716,
  [SMALL_STATE(7641)] = 333770,
  [SMALL_STATE(7642)] = 333824,
  [SMALL_STATE(7643)] = 333878,
  [SMALL_STATE(7644)] = 333932,
  [SMALL_STATE(7645)] = 333986,
  [SMALL_STATE(7646)] = 334040,
  [SMALL_STATE(7647)] = 334094,
  [SMALL_STATE(7648)] = 334148,
  [SMALL_STATE(7649)] = 334202,
  [SMALL_STATE(7650)] = 334256,
  [SMALL_STATE(7651)] = 334310,
  [SMALL_STATE(7652)] = 334364,
  [SMALL_STATE(7653)] = 334418,
  [SMALL_STATE(7654)] = 334472,
  [SMALL_STATE(7655)] = 334526,
  [SMALL_STATE(7656)] = 334580,
  [SMALL_STATE(7657)] = 334634,
  [SMALL_STATE(7658)] = 334690,
  [SMALL_STATE(7659)] = 334744,
  [SMALL_STATE(7660)] = 334798,
  [SMALL_STATE(7661)] = 334852,
  [SMALL_STATE(7662)] = 334906,
  [SMALL_STATE(7663)] = 334960,
  [SMALL_STATE(7664)] = 335014,
  [SMALL_STATE(7665)] = 335068,
  [SMALL_STATE(7666)] = 335122,
  [SMALL_STATE(7667)] = 335176,
  [SMALL_STATE(7668)] = 335230,
  [SMALL_STATE(7669)] = 335284,
  [SMALL_STATE(7670)] = 335338,
  [SMALL_STATE(7671)] = 335392,
  [SMALL_STATE(7672)] = 335446,
  [SMALL_STATE(7673)] = 335500,
  [SMALL_STATE(7674)] = 335554,
  [SMALL_STATE(7675)] = 335608,
  [SMALL_STATE(7676)] = 335662,
  [SMALL_STATE(7677)] = 335716,
  [SMALL_STATE(7678)] = 335770,
  [SMALL_STATE(7679)] = 335824,
  [SMALL_STATE(7680)] = 335878,
  [SMALL_STATE(7681)] = 335932,
  [SMALL_STATE(7682)] = 335986,
  [SMALL_STATE(7683)] = 336040,
  [SMALL_STATE(7684)] = 336094,
  [SMALL_STATE(7685)] = 336148,
  [SMALL_STATE(7686)] = 336202,
  [SMALL_STATE(7687)] = 336256,
  [SMALL_STATE(7688)] = 336310,
  [SMALL_STATE(7689)] = 336364,
  [SMALL_STATE(7690)] = 336418,
  [SMALL_STATE(7691)] = 336472,
  [SMALL_STATE(7692)] = 336526,
  [SMALL_STATE(7693)] = 336580,
  [SMALL_STATE(7694)] = 336634,
  [SMALL_STATE(7695)] = 336688,
  [SMALL_STATE(7696)] = 336742,
  [SMALL_STATE(7697)] = 336796,
  [SMALL_STATE(7698)] = 336850,
  [SMALL_STATE(7699)] = 336904,
  [SMALL_STATE(7700)] = 336958,
  [SMALL_STATE(7701)] = 337012,
  [SMALL_STATE(7702)] = 337066,
  [SMALL_STATE(7703)] = 337120,
  [SMALL_STATE(7704)] = 337176,
  [SMALL_STATE(7705)] = 337230,
  [SMALL_STATE(7706)] = 337284,
  [SMALL_STATE(7707)] = 337338,
  [SMALL_STATE(7708)] = 337392,
  [SMALL_STATE(7709)] = 337446,
  [SMALL_STATE(7710)] = 337500,
  [SMALL_STATE(7711)] = 337554,
  [SMALL_STATE(7712)] = 337608,
  [SMALL_STATE(7713)] = 337662,
  [SMALL_STATE(7714)] = 337716,
  [SMALL_STATE(7715)] = 337770,
  [SMALL_STATE(7716)] = 337824,
  [SMALL_STATE(7717)] = 337878,
  [SMALL_STATE(7718)] = 337932,
  [SMALL_STATE(7719)] = 337986,
  [SMALL_STATE(7720)] = 338041,
  [SMALL_STATE(7721)] = 338094,
  [SMALL_STATE(7722)] = 338195,
  [SMALL_STATE(7723)] = 338248,
  [SMALL_STATE(7724)] = 338349,
  [SMALL_STATE(7725)] = 338402,
  [SMALL_STATE(7726)] = 338455,
  [SMALL_STATE(7727)] = 338508,
  [SMALL_STATE(7728)] = 338609,
  [SMALL_STATE(7729)] = 338662,
  [SMALL_STATE(7730)] = 338715,
  [SMALL_STATE(7731)] = 338768,
  [SMALL_STATE(7732)] = 338821,
  [SMALL_STATE(7733)] = 338874,
  [SMALL_STATE(7734)] = 338927,
  [SMALL_STATE(7735)] = 338980,
  [SMALL_STATE(7736)] = 339081,
  [SMALL_STATE(7737)] = 339134,
  [SMALL_STATE(7738)] = 339187,
  [SMALL_STATE(7739)] = 339240,
  [SMALL_STATE(7740)] = 339293,
  [SMALL_STATE(7741)] = 339346,
  [SMALL_STATE(7742)] = 339399,
  [SMALL_STATE(7743)] = 339452,
  [SMALL_STATE(7744)] = 339505,
  [SMALL_STATE(7745)] = 339558,
  [SMALL_STATE(7746)] = 339613,
  [SMALL_STATE(7747)] = 339714,
  [SMALL_STATE(7748)] = 339767,
  [SMALL_STATE(7749)] = 339820,
  [SMALL_STATE(7750)] = 339873,
  [SMALL_STATE(7751)] = 339926,
  [SMALL_STATE(7752)] = 339979,
  [SMALL_STATE(7753)] = 340032,
  [SMALL_STATE(7754)] = 340085,
  [SMALL_STATE(7755)] = 340138,
  [SMALL_STATE(7756)] = 340191,
  [SMALL_STATE(7757)] = 340244,
  [SMALL_STATE(7758)] = 340297,
  [SMALL_STATE(7759)] = 340350,
  [SMALL_STATE(7760)] = 340451,
  [SMALL_STATE(7761)] = 340504,
  [SMALL_STATE(7762)] = 340557,
  [SMALL_STATE(7763)] = 340610,
  [SMALL_STATE(7764)] = 340663,
  [SMALL_STATE(7765)] = 340716,
  [SMALL_STATE(7766)] = 340769,
  [SMALL_STATE(7767)] = 340822,
  [SMALL_STATE(7768)] = 340875,
  [SMALL_STATE(7769)] = 340928,
  [SMALL_STATE(7770)] = 340981,
  [SMALL_STATE(7771)] = 341034,
  [SMALL_STATE(7772)] = 341135,
  [SMALL_STATE(7773)] = 341188,
  [SMALL_STATE(7774)] = 341241,
  [SMALL_STATE(7775)] = 341296,
  [SMALL_STATE(7776)] = 341349,
  [SMALL_STATE(7777)] = 341402,
  [SMALL_STATE(7778)] = 341455,
  [SMALL_STATE(7779)] = 341508,
  [SMALL_STATE(7780)] = 341609,
  [SMALL_STATE(7781)] = 341662,
  [SMALL_STATE(7782)] = 341715,
  [SMALL_STATE(7783)] = 341768,
  [SMALL_STATE(7784)] = 341821,
  [SMALL_STATE(7785)] = 341922,
  [SMALL_STATE(7786)] = 341975,
  [SMALL_STATE(7787)] = 342028,
  [SMALL_STATE(7788)] = 342081,
  [SMALL_STATE(7789)] = 342134,
  [SMALL_STATE(7790)] = 342187,
  [SMALL_STATE(7791)] = 342240,
  [SMALL_STATE(7792)] = 342293,
  [SMALL_STATE(7793)] = 342346,
  [SMALL_STATE(7794)] = 342399,
  [SMALL_STATE(7795)] = 342452,
  [SMALL_STATE(7796)] = 342505,
  [SMALL_STATE(7797)] = 342558,
  [SMALL_STATE(7798)] = 342611,
  [SMALL_STATE(7799)] = 342664,
  [SMALL_STATE(7800)] = 342717,
  [SMALL_STATE(7801)] = 342770,
  [SMALL_STATE(7802)] = 342823,
  [SMALL_STATE(7803)] = 342876,
  [SMALL_STATE(7804)] = 342977,
  [SMALL_STATE(7805)] = 343078,
  [SMALL_STATE(7806)] = 343131,
  [SMALL_STATE(7807)] = 343184,
  [SMALL_STATE(7808)] = 343237,
  [SMALL_STATE(7809)] = 343290,
  [SMALL_STATE(7810)] = 343343,
  [SMALL_STATE(7811)] = 343396,
  [SMALL_STATE(7812)] = 343449,
  [SMALL_STATE(7813)] = 343502,
  [SMALL_STATE(7814)] = 343555,
  [SMALL_STATE(7815)] = 343608,
  [SMALL_STATE(7816)] = 343661,
  [SMALL_STATE(7817)] = 343762,
  [SMALL_STATE(7818)] = 343815,
  [SMALL_STATE(7819)] = 343874,
  [SMALL_STATE(7820)] = 343927,
  [SMALL_STATE(7821)] = 343980,
  [SMALL_STATE(7822)] = 344033,
  [SMALL_STATE(7823)] = 344086,
  [SMALL_STATE(7824)] = 344139,
  [SMALL_STATE(7825)] = 344192,
  [SMALL_STATE(7826)] = 344245,
  [SMALL_STATE(7827)] = 344298,
  [SMALL_STATE(7828)] = 344351,
  [SMALL_STATE(7829)] = 344452,
  [SMALL_STATE(7830)] = 344505,
  [SMALL_STATE(7831)] = 344606,
  [SMALL_STATE(7832)] = 344659,
  [SMALL_STATE(7833)] = 344760,
  [SMALL_STATE(7834)] = 344861,
  [SMALL_STATE(7835)] = 344914,
  [SMALL_STATE(7836)] = 344967,
  [SMALL_STATE(7837)] = 345068,
  [SMALL_STATE(7838)] = 345121,
  [SMALL_STATE(7839)] = 345174,
  [SMALL_STATE(7840)] = 345227,
  [SMALL_STATE(7841)] = 345280,
  [SMALL_STATE(7842)] = 345333,
  [SMALL_STATE(7843)] = 345434,
  [SMALL_STATE(7844)] = 345487,
  [SMALL_STATE(7845)] = 345540,
  [SMALL_STATE(7846)] = 345593,
  [SMALL_STATE(7847)] = 345646,
  [SMALL_STATE(7848)] = 345699,
  [SMALL_STATE(7849)] = 345752,
  [SMALL_STATE(7850)] = 345805,
  [SMALL_STATE(7851)] = 345858,
  [SMALL_STATE(7852)] = 345911,
  [SMALL_STATE(7853)] = 346012,
  [SMALL_STATE(7854)] = 346065,
  [SMALL_STATE(7855)] = 346118,
  [SMALL_STATE(7856)] = 346173,
  [SMALL_STATE(7857)] = 346274,
  [SMALL_STATE(7858)] = 346375,
  [SMALL_STATE(7859)] = 346428,
  [SMALL_STATE(7860)] = 346481,
  [SMALL_STATE(7861)] = 346540,
  [SMALL_STATE(7862)] = 346593,
  [SMALL_STATE(7863)] = 346646,
  [SMALL_STATE(7864)] = 346699,
  [SMALL_STATE(7865)] = 346752,
  [SMALL_STATE(7866)] = 346805,
  [SMALL_STATE(7867)] = 346864,
  [SMALL_STATE(7868)] = 346965,
  [SMALL_STATE(7869)] = 347018,
  [SMALL_STATE(7870)] = 347119,
  [SMALL_STATE(7871)] = 347172,
  [SMALL_STATE(7872)] = 347231,
  [SMALL_STATE(7873)] = 347284,
  [SMALL_STATE(7874)] = 347343,
  [SMALL_STATE(7875)] = 347396,
  [SMALL_STATE(7876)] = 347449,
  [SMALL_STATE(7877)] = 347502,
  [SMALL_STATE(7878)] = 347555,
  [SMALL_STATE(7879)] = 347608,
  [SMALL_STATE(7880)] = 347667,
  [SMALL_STATE(7881)] = 347720,
  [SMALL_STATE(7882)] = 347773,
  [SMALL_STATE(7883)] = 347826,
  [SMALL_STATE(7884)] = 347879,
  [SMALL_STATE(7885)] = 347932,
  [SMALL_STATE(7886)] = 347985,
  [SMALL_STATE(7887)] = 348038,
  [SMALL_STATE(7888)] = 348091,
  [SMALL_STATE(7889)] = 348144,
  [SMALL_STATE(7890)] = 348197,
  [SMALL_STATE(7891)] = 348250,
  [SMALL_STATE(7892)] = 348303,
  [SMALL_STATE(7893)] = 348358,
  [SMALL_STATE(7894)] = 348413,
  [SMALL_STATE(7895)] = 348466,
  [SMALL_STATE(7896)] = 348519,
  [SMALL_STATE(7897)] = 348578,
  [SMALL_STATE(7898)] = 348631,
  [SMALL_STATE(7899)] = 348684,
  [SMALL_STATE(7900)] = 348737,
  [SMALL_STATE(7901)] = 348790,
  [SMALL_STATE(7902)] = 348843,
  [SMALL_STATE(7903)] = 348896,
  [SMALL_STATE(7904)] = 348949,
  [SMALL_STATE(7905)] = 349002,
  [SMALL_STATE(7906)] = 349055,
  [SMALL_STATE(7907)] = 349108,
  [SMALL_STATE(7908)] = 349161,
  [SMALL_STATE(7909)] = 349214,
  [SMALL_STATE(7910)] = 349267,
  [SMALL_STATE(7911)] = 349322,
  [SMALL_STATE(7912)] = 349375,
  [SMALL_STATE(7913)] = 349428,
  [SMALL_STATE(7914)] = 349481,
  [SMALL_STATE(7915)] = 349534,
  [SMALL_STATE(7916)] = 349587,
  [SMALL_STATE(7917)] = 349640,
  [SMALL_STATE(7918)] = 349693,
  [SMALL_STATE(7919)] = 349746,
  [SMALL_STATE(7920)] = 349799,
  [SMALL_STATE(7921)] = 349852,
  [SMALL_STATE(7922)] = 349905,
  [SMALL_STATE(7923)] = 349958,
  [SMALL_STATE(7924)] = 350059,
  [SMALL_STATE(7925)] = 350112,
  [SMALL_STATE(7926)] = 350165,
  [SMALL_STATE(7927)] = 350218,
  [SMALL_STATE(7928)] = 350271,
  [SMALL_STATE(7929)] = 350326,
  [SMALL_STATE(7930)] = 350379,
  [SMALL_STATE(7931)] = 350432,
  [SMALL_STATE(7932)] = 350485,
  [SMALL_STATE(7933)] = 350586,
  [SMALL_STATE(7934)] = 350639,
  [SMALL_STATE(7935)] = 350692,
  [SMALL_STATE(7936)] = 350745,
  [SMALL_STATE(7937)] = 350798,
  [SMALL_STATE(7938)] = 350851,
  [SMALL_STATE(7939)] = 350904,
  [SMALL_STATE(7940)] = 350957,
  [SMALL_STATE(7941)] = 351010,
  [SMALL_STATE(7942)] = 351063,
  [SMALL_STATE(7943)] = 351122,
  [SMALL_STATE(7944)] = 351175,
  [SMALL_STATE(7945)] = 351228,
  [SMALL_STATE(7946)] = 351281,
  [SMALL_STATE(7947)] = 351334,
  [SMALL_STATE(7948)] = 351387,
  [SMALL_STATE(7949)] = 351442,
  [SMALL_STATE(7950)] = 351495,
  [SMALL_STATE(7951)] = 351548,
  [SMALL_STATE(7952)] = 351601,
  [SMALL_STATE(7953)] = 351654,
  [SMALL_STATE(7954)] = 351707,
  [SMALL_STATE(7955)] = 351760,
  [SMALL_STATE(7956)] = 351813,
  [SMALL_STATE(7957)] = 351866,
  [SMALL_STATE(7958)] = 351919,
  [SMALL_STATE(7959)] = 351972,
  [SMALL_STATE(7960)] = 352025,
  [SMALL_STATE(7961)] = 352080,
  [SMALL_STATE(7962)] = 352133,
  [SMALL_STATE(7963)] = 352186,
  [SMALL_STATE(7964)] = 352239,
  [SMALL_STATE(7965)] = 352292,
  [SMALL_STATE(7966)] = 352345,
  [SMALL_STATE(7967)] = 352398,
  [SMALL_STATE(7968)] = 352451,
  [SMALL_STATE(7969)] = 352504,
  [SMALL_STATE(7970)] = 352557,
  [SMALL_STATE(7971)] = 352610,
  [SMALL_STATE(7972)] = 352663,
  [SMALL_STATE(7973)] = 352716,
  [SMALL_STATE(7974)] = 352769,
  [SMALL_STATE(7975)] = 352822,
  [SMALL_STATE(7976)] = 352875,
  [SMALL_STATE(7977)] = 352928,
  [SMALL_STATE(7978)] = 352981,
  [SMALL_STATE(7979)] = 353034,
  [SMALL_STATE(7980)] = 353087,
  [SMALL_STATE(7981)] = 353140,
  [SMALL_STATE(7982)] = 353195,
  [SMALL_STATE(7983)] = 353248,
  [SMALL_STATE(7984)] = 353301,
  [SMALL_STATE(7985)] = 353354,
  [SMALL_STATE(7986)] = 353407,
  [SMALL_STATE(7987)] = 353460,
  [SMALL_STATE(7988)] = 353513,
  [SMALL_STATE(7989)] = 353566,
  [SMALL_STATE(7990)] = 353621,
  [SMALL_STATE(7991)] = 353722,
  [SMALL_STATE(7992)] = 353775,
  [SMALL_STATE(7993)] = 353828,
  [SMALL_STATE(7994)] = 353881,
  [SMALL_STATE(7995)] = 353934,
  [SMALL_STATE(7996)] = 353987,
  [SMALL_STATE(7997)] = 354040,
  [SMALL_STATE(7998)] = 354093,
  [SMALL_STATE(7999)] = 354152,
  [SMALL_STATE(8000)] = 354205,
  [SMALL_STATE(8001)] = 354258,
  [SMALL_STATE(8002)] = 354311,
  [SMALL_STATE(8003)] = 354364,
  [SMALL_STATE(8004)] = 354417,
  [SMALL_STATE(8005)] = 354470,
  [SMALL_STATE(8006)] = 354523,
  [SMALL_STATE(8007)] = 354576,
  [SMALL_STATE(8008)] = 354629,
  [SMALL_STATE(8009)] = 354682,
  [SMALL_STATE(8010)] = 354735,
  [SMALL_STATE(8011)] = 354790,
  [SMALL_STATE(8012)] = 354843,
  [SMALL_STATE(8013)] = 354896,
  [SMALL_STATE(8014)] = 354949,
  [SMALL_STATE(8015)] = 355002,
  [SMALL_STATE(8016)] = 355061,
  [SMALL_STATE(8017)] = 355114,
  [SMALL_STATE(8018)] = 355167,
  [SMALL_STATE(8019)] = 355219,
  [SMALL_STATE(8020)] = 355271,
  [SMALL_STATE(8021)] = 355323,
  [SMALL_STATE(8022)] = 355375,
  [SMALL_STATE(8023)] = 355473,
  [SMALL_STATE(8024)] = 355571,
  [SMALL_STATE(8025)] = 355669,
  [SMALL_STATE(8026)] = 355721,
  [SMALL_STATE(8027)] = 355773,
  [SMALL_STATE(8028)] = 355873,
  [SMALL_STATE(8029)] = 355925,
  [SMALL_STATE(8030)] = 355977,
  [SMALL_STATE(8031)] = 356029,
  [SMALL_STATE(8032)] = 356127,
  [SMALL_STATE(8033)] = 356225,
  [SMALL_STATE(8034)] = 356323,
  [SMALL_STATE(8035)] = 356423,
  [SMALL_STATE(8036)] = 356475,
  [SMALL_STATE(8037)] = 356573,
  [SMALL_STATE(8038)] = 356625,
  [SMALL_STATE(8039)] = 356677,
  [SMALL_STATE(8040)] = 356775,
  [SMALL_STATE(8041)] = 356827,
  [SMALL_STATE(8042)] = 356879,
  [SMALL_STATE(8043)] = 356931,
  [SMALL_STATE(8044)] = 357029,
  [SMALL_STATE(8045)] = 357127,
  [SMALL_STATE(8046)] = 357179,
  [SMALL_STATE(8047)] = 357277,
  [SMALL_STATE(8048)] = 357329,
  [SMALL_STATE(8049)] = 357427,
  [SMALL_STATE(8050)] = 357525,
  [SMALL_STATE(8051)] = 357623,
  [SMALL_STATE(8052)] = 357675,
  [SMALL_STATE(8053)] = 357727,
  [SMALL_STATE(8054)] = 357825,
  [SMALL_STATE(8055)] = 357877,
  [SMALL_STATE(8056)] = 357975,
  [SMALL_STATE(8057)] = 358073,
  [SMALL_STATE(8058)] = 358171,
  [SMALL_STATE(8059)] = 358269,
  [SMALL_STATE(8060)] = 358321,
  [SMALL_STATE(8061)] = 358419,
  [SMALL_STATE(8062)] = 358517,
  [SMALL_STATE(8063)] = 358615,
  [SMALL_STATE(8064)] = 358713,
  [SMALL_STATE(8065)] = 358765,
  [SMALL_STATE(8066)] = 358817,
  [SMALL_STATE(8067)] = 358869,
  [SMALL_STATE(8068)] = 358921,
  [SMALL_STATE(8069)] = 359019,
  [SMALL_STATE(8070)] = 359117,
  [SMALL_STATE(8071)] = 359169,
  [SMALL_STATE(8072)] = 359267,
  [SMALL_STATE(8073)] = 359319,
  [SMALL_STATE(8074)] = 359417,
  [SMALL_STATE(8075)] = 359469,
  [SMALL_STATE(8076)] = 359567,
  [SMALL_STATE(8077)] = 359665,
  [SMALL_STATE(8078)] = 359717,
  [SMALL_STATE(8079)] = 359815,
  [SMALL_STATE(8080)] = 359867,
  [SMALL_STATE(8081)] = 359919,
  [SMALL_STATE(8082)] = 359971,
  [SMALL_STATE(8083)] = 360023,
  [SMALL_STATE(8084)] = 360121,
  [SMALL_STATE(8085)] = 360173,
  [SMALL_STATE(8086)] = 360225,
  [SMALL_STATE(8087)] = 360277,
  [SMALL_STATE(8088)] = 360329,
  [SMALL_STATE(8089)] = 360427,
  [SMALL_STATE(8090)] = 360525,
  [SMALL_STATE(8091)] = 360623,
  [SMALL_STATE(8092)] = 360721,
  [SMALL_STATE(8093)] = 360819,
  [SMALL_STATE(8094)] = 360917,
  [SMALL_STATE(8095)] = 361015,
  [SMALL_STATE(8096)] = 361115,
  [SMALL_STATE(8097)] = 361167,
  [SMALL_STATE(8098)] = 361219,
  [SMALL_STATE(8099)] = 361271,
  [SMALL_STATE(8100)] = 361323,
  [SMALL_STATE(8101)] = 361421,
  [SMALL_STATE(8102)] = 361521,
  [SMALL_STATE(8103)] = 361619,
  [SMALL_STATE(8104)] = 361671,
  [SMALL_STATE(8105)] = 361723,
  [SMALL_STATE(8106)] = 361775,
  [SMALL_STATE(8107)] = 361827,
  [SMALL_STATE(8108)] = 361925,
  [SMALL_STATE(8109)] = 361977,
  [SMALL_STATE(8110)] = 362029,
  [SMALL_STATE(8111)] = 362081,
  [SMALL_STATE(8112)] = 362133,
  [SMALL_STATE(8113)] = 362185,
  [SMALL_STATE(8114)] = 362237,
  [SMALL_STATE(8115)] = 362335,
  [SMALL_STATE(8116)] = 362433,
  [SMALL_STATE(8117)] = 362485,
  [SMALL_STATE(8118)] = 362583,
  [SMALL_STATE(8119)] = 362681,
  [SMALL_STATE(8120)] = 362779,
  [SMALL_STATE(8121)] = 362831,
  [SMALL_STATE(8122)] = 362883,
  [SMALL_STATE(8123)] = 362937,
  [SMALL_STATE(8124)] = 362989,
  [SMALL_STATE(8125)] = 363043,
  [SMALL_STATE(8126)] = 363141,
  [SMALL_STATE(8127)] = 363239,
  [SMALL_STATE(8128)] = 363337,
  [SMALL_STATE(8129)] = 363389,
  [SMALL_STATE(8130)] = 363443,
  [SMALL_STATE(8131)] = 363541,
  [SMALL_STATE(8132)] = 363639,
  [SMALL_STATE(8133)] = 363737,
  [SMALL_STATE(8134)] = 363837,
  [SMALL_STATE(8135)] = 363935,
  [SMALL_STATE(8136)] = 363987,
  [SMALL_STATE(8137)] = 364039,
  [SMALL_STATE(8138)] = 364137,
  [SMALL_STATE(8139)] = 364189,
  [SMALL_STATE(8140)] = 364241,
  [SMALL_STATE(8141)] = 364339,
  [SMALL_STATE(8142)] = 364437,
  [SMALL_STATE(8143)] = 364535,
  [SMALL_STATE(8144)] = 364587,
  [SMALL_STATE(8145)] = 364639,
  [SMALL_STATE(8146)] = 364691,
  [SMALL_STATE(8147)] = 364789,
  [SMALL_STATE(8148)] = 364841,
  [SMALL_STATE(8149)] = 364893,
  [SMALL_STATE(8150)] = 364991,
  [SMALL_STATE(8151)] = 365043,
  [SMALL_STATE(8152)] = 365095,
  [SMALL_STATE(8153)] = 365193,
  [SMALL_STATE(8154)] = 365245,
  [SMALL_STATE(8155)] = 365297,
  [SMALL_STATE(8156)] = 365349,
  [SMALL_STATE(8157)] = 365447,
  [SMALL_STATE(8158)] = 365499,
  [SMALL_STATE(8159)] = 365597,
  [SMALL_STATE(8160)] = 365695,
  [SMALL_STATE(8161)] = 365747,
  [SMALL_STATE(8162)] = 365845,
  [SMALL_STATE(8163)] = 365897,
  [SMALL_STATE(8164)] = 365949,
  [SMALL_STATE(8165)] = 366047,
  [SMALL_STATE(8166)] = 366103,
  [SMALL_STATE(8167)] = 366157,
  [SMALL_STATE(8168)] = 366213,
  [SMALL_STATE(8169)] = 366265,
  [SMALL_STATE(8170)] = 366317,
  [SMALL_STATE(8171)] = 366415,
  [SMALL_STATE(8172)] = 366513,
  [SMALL_STATE(8173)] = 366565,
  [SMALL_STATE(8174)] = 366665,
  [SMALL_STATE(8175)] = 366763,
  [SMALL_STATE(8176)] = 366815,
  [SMALL_STATE(8177)] = 366866,
  [SMALL_STATE(8178)] = 366957,
  [SMALL_STATE(8179)] = 367008,
  [SMALL_STATE(8180)] = 367059,
  [SMALL_STATE(8181)] = 367110,
  [SMALL_STATE(8182)] = 367163,
  [SMALL_STATE(8183)] = 367214,
  [SMALL_STATE(8184)] = 367265,
  [SMALL_STATE(8185)] = 367360,
  [SMALL_STATE(8186)] = 367455,
  [SMALL_STATE(8187)] = 367506,
  [SMALL_STATE(8188)] = 367601,
  [SMALL_STATE(8189)] = 367652,
  [SMALL_STATE(8190)] = 367703,
  [SMALL_STATE(8191)] = 367754,
  [SMALL_STATE(8192)] = 367833,
  [SMALL_STATE(8193)] = 367884,
  [SMALL_STATE(8194)] = 367935,
  [SMALL_STATE(8195)] = 367992,
  [SMALL_STATE(8196)] = 368043,
  [SMALL_STATE(8197)] = 368094,
  [SMALL_STATE(8198)] = 368145,
  [SMALL_STATE(8199)] = 368196,
  [SMALL_STATE(8200)] = 368247,
  [SMALL_STATE(8201)] = 368298,
  [SMALL_STATE(8202)] = 368349,
  [SMALL_STATE(8203)] = 368400,
  [SMALL_STATE(8204)] = 368451,
  [SMALL_STATE(8205)] = 368504,
  [SMALL_STATE(8206)] = 368555,
  [SMALL_STATE(8207)] = 368606,
  [SMALL_STATE(8208)] = 368657,
  [SMALL_STATE(8209)] = 368708,
  [SMALL_STATE(8210)] = 368759,
  [SMALL_STATE(8211)] = 368810,
  [SMALL_STATE(8212)] = 368861,
  [SMALL_STATE(8213)] = 368956,
  [SMALL_STATE(8214)] = 369051,
  [SMALL_STATE(8215)] = 369146,
  [SMALL_STATE(8216)] = 369199,
  [SMALL_STATE(8217)] = 369250,
  [SMALL_STATE(8218)] = 369301,
  [SMALL_STATE(8219)] = 369352,
  [SMALL_STATE(8220)] = 369447,
  [SMALL_STATE(8221)] = 369542,
  [SMALL_STATE(8222)] = 369593,
  [SMALL_STATE(8223)] = 369684,
  [SMALL_STATE(8224)] = 369779,
  [SMALL_STATE(8225)] = 369830,
  [SMALL_STATE(8226)] = 369921,
  [SMALL_STATE(8227)] = 369974,
  [SMALL_STATE(8228)] = 370025,
  [SMALL_STATE(8229)] = 370076,
  [SMALL_STATE(8230)] = 370171,
  [SMALL_STATE(8231)] = 370266,
  [SMALL_STATE(8232)] = 370361,
  [SMALL_STATE(8233)] = 370412,
  [SMALL_STATE(8234)] = 370463,
  [SMALL_STATE(8235)] = 370514,
  [SMALL_STATE(8236)] = 370609,
  [SMALL_STATE(8237)] = 370704,
  [SMALL_STATE(8238)] = 370799,
  [SMALL_STATE(8239)] = 370850,
  [SMALL_STATE(8240)] = 370945,
  [SMALL_STATE(8241)] = 371040,
  [SMALL_STATE(8242)] = 371135,
  [SMALL_STATE(8243)] = 371186,
  [SMALL_STATE(8244)] = 371277,
  [SMALL_STATE(8245)] = 371328,
  [SMALL_STATE(8246)] = 371423,
  [SMALL_STATE(8247)] = 371518,
  [SMALL_STATE(8248)] = 371613,
  [SMALL_STATE(8249)] = 371708,
  [SMALL_STATE(8250)] = 371803,
  [SMALL_STATE(8251)] = 371854,
  [SMALL_STATE(8252)] = 371949,
  [SMALL_STATE(8253)] = 372044,
  [SMALL_STATE(8254)] = 372139,
  [SMALL_STATE(8255)] = 372234,
  [SMALL_STATE(8256)] = 372285,
  [SMALL_STATE(8257)] = 372376,
  [SMALL_STATE(8258)] = 372471,
  [SMALL_STATE(8259)] = 372566,
  [SMALL_STATE(8260)] = 372617,
  [SMALL_STATE(8261)] = 372712,
  [SMALL_STATE(8262)] = 372803,
  [SMALL_STATE(8263)] = 372854,
  [SMALL_STATE(8264)] = 372905,
  [SMALL_STATE(8265)] = 372956,
  [SMALL_STATE(8266)] = 373007,
  [SMALL_STATE(8267)] = 373102,
  [SMALL_STATE(8268)] = 373197,
  [SMALL_STATE(8269)] = 373292,
  [SMALL_STATE(8270)] = 373343,
  [SMALL_STATE(8271)] = 373394,
  [SMALL_STATE(8272)] = 373445,
  [SMALL_STATE(8273)] = 373540,
  [SMALL_STATE(8274)] = 373635,
  [SMALL_STATE(8275)] = 373686,
  [SMALL_STATE(8276)] = 373737,
  [SMALL_STATE(8277)] = 373832,
  [SMALL_STATE(8278)] = 373883,
  [SMALL_STATE(8279)] = 373978,
  [SMALL_STATE(8280)] = 374073,
  [SMALL_STATE(8281)] = 374124,
  [SMALL_STATE(8282)] = 374219,
  [SMALL_STATE(8283)] = 374314,
  [SMALL_STATE(8284)] = 374409,
  [SMALL_STATE(8285)] = 374504,
  [SMALL_STATE(8286)] = 374599,
  [SMALL_STATE(8287)] = 374650,
  [SMALL_STATE(8288)] = 374701,
  [SMALL_STATE(8289)] = 374796,
  [SMALL_STATE(8290)] = 374891,
  [SMALL_STATE(8291)] = 374986,
  [SMALL_STATE(8292)] = 375037,
  [SMALL_STATE(8293)] = 375132,
  [SMALL_STATE(8294)] = 375183,
  [SMALL_STATE(8295)] = 375234,
  [SMALL_STATE(8296)] = 375325,
  [SMALL_STATE(8297)] = 375420,
  [SMALL_STATE(8298)] = 375515,
  [SMALL_STATE(8299)] = 375610,
  [SMALL_STATE(8300)] = 375705,
  [SMALL_STATE(8301)] = 375800,
  [SMALL_STATE(8302)] = 375851,
  [SMALL_STATE(8303)] = 375946,
  [SMALL_STATE(8304)] = 375997,
  [SMALL_STATE(8305)] = 376092,
  [SMALL_STATE(8306)] = 376187,
  [SMALL_STATE(8307)] = 376282,
  [SMALL_STATE(8308)] = 376333,
  [SMALL_STATE(8309)] = 376384,
  [SMALL_STATE(8310)] = 376479,
  [SMALL_STATE(8311)] = 376574,
  [SMALL_STATE(8312)] = 376653,
  [SMALL_STATE(8313)] = 376704,
  [SMALL_STATE(8314)] = 376755,
  [SMALL_STATE(8315)] = 376850,
  [SMALL_STATE(8316)] = 376945,
  [SMALL_STATE(8317)] = 377040,
  [SMALL_STATE(8318)] = 377091,
  [SMALL_STATE(8319)] = 377142,
  [SMALL_STATE(8320)] = 377193,
  [SMALL_STATE(8321)] = 377288,
  [SMALL_STATE(8322)] = 377383,
  [SMALL_STATE(8323)] = 377434,
  [SMALL_STATE(8324)] = 377529,
  [SMALL_STATE(8325)] = 377580,
  [SMALL_STATE(8326)] = 377631,
  [SMALL_STATE(8327)] = 377682,
  [SMALL_STATE(8328)] = 377733,
  [SMALL_STATE(8329)] = 377784,
  [SMALL_STATE(8330)] = 377835,
  [SMALL_STATE(8331)] = 377886,
  [SMALL_STATE(8332)] = 377937,
  [SMALL_STATE(8333)] = 377988,
  [SMALL_STATE(8334)] = 378039,
  [SMALL_STATE(8335)] = 378092,
  [SMALL_STATE(8336)] = 378143,
  [SMALL_STATE(8337)] = 378194,
  [SMALL_STATE(8338)] = 378245,
  [SMALL_STATE(8339)] = 378296,
  [SMALL_STATE(8340)] = 378347,
  [SMALL_STATE(8341)] = 378400,
  [SMALL_STATE(8342)] = 378451,
  [SMALL_STATE(8343)] = 378502,
  [SMALL_STATE(8344)] = 378553,
  [SMALL_STATE(8345)] = 378604,
  [SMALL_STATE(8346)] = 378655,
  [SMALL_STATE(8347)] = 378706,
  [SMALL_STATE(8348)] = 378757,
  [SMALL_STATE(8349)] = 378808,
  [SMALL_STATE(8350)] = 378859,
  [SMALL_STATE(8351)] = 378910,
  [SMALL_STATE(8352)] = 378961,
  [SMALL_STATE(8353)] = 379012,
  [SMALL_STATE(8354)] = 379063,
  [SMALL_STATE(8355)] = 379114,
  [SMALL_STATE(8356)] = 379165,
  [SMALL_STATE(8357)] = 379216,
  [SMALL_STATE(8358)] = 379267,
  [SMALL_STATE(8359)] = 379318,
  [SMALL_STATE(8360)] = 379369,
  [SMALL_STATE(8361)] = 379420,
  [SMALL_STATE(8362)] = 379471,
  [SMALL_STATE(8363)] = 379522,
  [SMALL_STATE(8364)] = 379573,
  [SMALL_STATE(8365)] = 379624,
  [SMALL_STATE(8366)] = 379675,
  [SMALL_STATE(8367)] = 379726,
  [SMALL_STATE(8368)] = 379777,
  [SMALL_STATE(8369)] = 379828,
  [SMALL_STATE(8370)] = 379879,
  [SMALL_STATE(8371)] = 379974,
  [SMALL_STATE(8372)] = 380025,
  [SMALL_STATE(8373)] = 380076,
  [SMALL_STATE(8374)] = 380127,
  [SMALL_STATE(8375)] = 380222,
  [SMALL_STATE(8376)] = 380273,
  [SMALL_STATE(8377)] = 380324,
  [SMALL_STATE(8378)] = 380375,
  [SMALL_STATE(8379)] = 380426,
  [SMALL_STATE(8380)] = 380477,
  [SMALL_STATE(8381)] = 380528,
  [SMALL_STATE(8382)] = 380579,
  [SMALL_STATE(8383)] = 380630,
  [SMALL_STATE(8384)] = 380681,
  [SMALL_STATE(8385)] = 380732,
  [SMALL_STATE(8386)] = 380783,
  [SMALL_STATE(8387)] = 380834,
  [SMALL_STATE(8388)] = 380885,
  [SMALL_STATE(8389)] = 380936,
  [SMALL_STATE(8390)] = 380987,
  [SMALL_STATE(8391)] = 381038,
  [SMALL_STATE(8392)] = 381089,
  [SMALL_STATE(8393)] = 381140,
  [SMALL_STATE(8394)] = 381231,
  [SMALL_STATE(8395)] = 381288,
  [SMALL_STATE(8396)] = 381339,
  [SMALL_STATE(8397)] = 381390,
  [SMALL_STATE(8398)] = 381441,
  [SMALL_STATE(8399)] = 381492,
  [SMALL_STATE(8400)] = 381543,
  [SMALL_STATE(8401)] = 381594,
  [SMALL_STATE(8402)] = 381645,
  [SMALL_STATE(8403)] = 381696,
  [SMALL_STATE(8404)] = 381747,
  [SMALL_STATE(8405)] = 381798,
  [SMALL_STATE(8406)] = 381849,
  [SMALL_STATE(8407)] = 381900,
  [SMALL_STATE(8408)] = 381951,
  [SMALL_STATE(8409)] = 382002,
  [SMALL_STATE(8410)] = 382093,
  [SMALL_STATE(8411)] = 382144,
  [SMALL_STATE(8412)] = 382195,
  [SMALL_STATE(8413)] = 382246,
  [SMALL_STATE(8414)] = 382297,
  [SMALL_STATE(8415)] = 382348,
  [SMALL_STATE(8416)] = 382399,
  [SMALL_STATE(8417)] = 382450,
  [SMALL_STATE(8418)] = 382501,
  [SMALL_STATE(8419)] = 382552,
  [SMALL_STATE(8420)] = 382603,
  [SMALL_STATE(8421)] = 382654,
  [SMALL_STATE(8422)] = 382705,
  [SMALL_STATE(8423)] = 382756,
  [SMALL_STATE(8424)] = 382807,
  [SMALL_STATE(8425)] = 382858,
  [SMALL_STATE(8426)] = 382909,
  [SMALL_STATE(8427)] = 382960,
  [SMALL_STATE(8428)] = 383051,
  [SMALL_STATE(8429)] = 383102,
  [SMALL_STATE(8430)] = 383153,
  [SMALL_STATE(8431)] = 383204,
  [SMALL_STATE(8432)] = 383255,
  [SMALL_STATE(8433)] = 383306,
  [SMALL_STATE(8434)] = 383357,
  [SMALL_STATE(8435)] = 383408,
  [SMALL_STATE(8436)] = 383459,
  [SMALL_STATE(8437)] = 383554,
  [SMALL_STATE(8438)] = 383604,
  [SMALL_STATE(8439)] = 383676,
  [SMALL_STATE(8440)] = 383728,
  [SMALL_STATE(8441)] = 383778,
  [SMALL_STATE(8442)] = 383834,
  [SMALL_STATE(8443)] = 383906,
  [SMALL_STATE(8444)] = 383956,
  [SMALL_STATE(8445)] = 384006,
  [SMALL_STATE(8446)] = 384060,
  [SMALL_STATE(8447)] = 384132,
  [SMALL_STATE(8448)] = 384224,
  [SMALL_STATE(8449)] = 384274,
  [SMALL_STATE(8450)] = 384324,
  [SMALL_STATE(8451)] = 384374,
  [SMALL_STATE(8452)] = 384424,
  [SMALL_STATE(8453)] = 384474,
  [SMALL_STATE(8454)] = 384524,
  [SMALL_STATE(8455)] = 384574,
  [SMALL_STATE(8456)] = 384624,
  [SMALL_STATE(8457)] = 384674,
  [SMALL_STATE(8458)] = 384748,
  [SMALL_STATE(8459)] = 384798,
  [SMALL_STATE(8460)] = 384852,
  [SMALL_STATE(8461)] = 384944,
  [SMALL_STATE(8462)] = 384998,
  [SMALL_STATE(8463)] = 385048,
  [SMALL_STATE(8464)] = 385098,
  [SMALL_STATE(8465)] = 385148,
  [SMALL_STATE(8466)] = 385198,
  [SMALL_STATE(8467)] = 385252,
  [SMALL_STATE(8468)] = 385302,
  [SMALL_STATE(8469)] = 385352,
  [SMALL_STATE(8470)] = 385402,
  [SMALL_STATE(8471)] = 385494,
  [SMALL_STATE(8472)] = 385544,
  [SMALL_STATE(8473)] = 385594,
  [SMALL_STATE(8474)] = 385644,
  [SMALL_STATE(8475)] = 385694,
  [SMALL_STATE(8476)] = 385744,
  [SMALL_STATE(8477)] = 385794,
  [SMALL_STATE(8478)] = 385848,
  [SMALL_STATE(8479)] = 385898,
  [SMALL_STATE(8480)] = 385968,
  [SMALL_STATE(8481)] = 386018,
  [SMALL_STATE(8482)] = 386078,
  [SMALL_STATE(8483)] = 386128,
  [SMALL_STATE(8484)] = 386178,
  [SMALL_STATE(8485)] = 386228,
  [SMALL_STATE(8486)] = 386278,
  [SMALL_STATE(8487)] = 386328,
  [SMALL_STATE(8488)] = 386382,
  [SMALL_STATE(8489)] = 386456,
  [SMALL_STATE(8490)] = 386506,
  [SMALL_STATE(8491)] = 386556,
  [SMALL_STATE(8492)] = 386608,
  [SMALL_STATE(8493)] = 386658,
  [SMALL_STATE(8494)] = 386712,
  [SMALL_STATE(8495)] = 386774,
  [SMALL_STATE(8496)] = 386836,
  [SMALL_STATE(8497)] = 386902,
  [SMALL_STATE(8498)] = 386956,
  [SMALL_STATE(8499)] = 387030,
  [SMALL_STATE(8500)] = 387102,
  [SMALL_STATE(8501)] = 387170,
  [SMALL_STATE(8502)] = 387220,
  [SMALL_STATE(8503)] = 387270,
  [SMALL_STATE(8504)] = 387344,
  [SMALL_STATE(8505)] = 387416,
  [SMALL_STATE(8506)] = 387472,
  [SMALL_STATE(8507)] = 387524,
  [SMALL_STATE(8508)] = 387596,
  [SMALL_STATE(8509)] = 387646,
  [SMALL_STATE(8510)] = 387696,
  [SMALL_STATE(8511)] = 387746,
  [SMALL_STATE(8512)] = 387796,
  [SMALL_STATE(8513)] = 387846,
  [SMALL_STATE(8514)] = 387896,
  [SMALL_STATE(8515)] = 387946,
  [SMALL_STATE(8516)] = 387996,
  [SMALL_STATE(8517)] = 388046,
  [SMALL_STATE(8518)] = 388100,
  [SMALL_STATE(8519)] = 388150,
  [SMALL_STATE(8520)] = 388200,
  [SMALL_STATE(8521)] = 388250,
  [SMALL_STATE(8522)] = 388300,
  [SMALL_STATE(8523)] = 388372,
  [SMALL_STATE(8524)] = 388426,
  [SMALL_STATE(8525)] = 388498,
  [SMALL_STATE(8526)] = 388552,
  [SMALL_STATE(8527)] = 388604,
  [SMALL_STATE(8528)] = 388674,
  [SMALL_STATE(8529)] = 388724,
  [SMALL_STATE(8530)] = 388774,
  [SMALL_STATE(8531)] = 388824,
  [SMALL_STATE(8532)] = 388874,
  [SMALL_STATE(8533)] = 388934,
  [SMALL_STATE(8534)] = 388988,
  [SMALL_STATE(8535)] = 389038,
  [SMALL_STATE(8536)] = 389088,
  [SMALL_STATE(8537)] = 389142,
  [SMALL_STATE(8538)] = 389216,
  [SMALL_STATE(8539)] = 389266,
  [SMALL_STATE(8540)] = 389320,
  [SMALL_STATE(8541)] = 389372,
  [SMALL_STATE(8542)] = 389422,
  [SMALL_STATE(8543)] = 389496,
  [SMALL_STATE(8544)] = 389546,
  [SMALL_STATE(8545)] = 389600,
  [SMALL_STATE(8546)] = 389650,
  [SMALL_STATE(8547)] = 389704,
  [SMALL_STATE(8548)] = 389766,
  [SMALL_STATE(8549)] = 389820,
  [SMALL_STATE(8550)] = 389882,
  [SMALL_STATE(8551)] = 389932,
  [SMALL_STATE(8552)] = 389982,
  [SMALL_STATE(8553)] = 390032,
  [SMALL_STATE(8554)] = 390082,
  [SMALL_STATE(8555)] = 390132,
  [SMALL_STATE(8556)] = 390182,
  [SMALL_STATE(8557)] = 390236,
  [SMALL_STATE(8558)] = 390286,
  [SMALL_STATE(8559)] = 390338,
  [SMALL_STATE(8560)] = 390388,
  [SMALL_STATE(8561)] = 390438,
  [SMALL_STATE(8562)] = 390492,
  [SMALL_STATE(8563)] = 390558,
  [SMALL_STATE(8564)] = 390608,
  [SMALL_STATE(8565)] = 390658,
  [SMALL_STATE(8566)] = 390712,
  [SMALL_STATE(8567)] = 390762,
  [SMALL_STATE(8568)] = 390830,
  [SMALL_STATE(8569)] = 390922,
  [SMALL_STATE(8570)] = 390972,
  [SMALL_STATE(8571)] = 391022,
  [SMALL_STATE(8572)] = 391093,
  [SMALL_STATE(8573)] = 391152,
  [SMALL_STATE(8574)] = 391205,
  [SMALL_STATE(8575)] = 391258,
  [SMALL_STATE(8576)] = 391319,
  [SMALL_STATE(8577)] = 391380,
  [SMALL_STATE(8578)] = 391445,
  [SMALL_STATE(8579)] = 391512,
  [SMALL_STATE(8580)] = 391563,
  [SMALL_STATE(8581)] = 391634,
  [SMALL_STATE(8582)] = 391687,
  [SMALL_STATE(8583)] = 391740,
  [SMALL_STATE(8584)] = 391791,
  [SMALL_STATE(8585)] = 391864,
  [SMALL_STATE(8586)] = 391925,
  [SMALL_STATE(8587)] = 391996,
  [SMALL_STATE(8588)] = 392049,
  [SMALL_STATE(8589)] = 392102,
  [SMALL_STATE(8590)] = 392153,
  [SMALL_STATE(8591)] = 392222,
  [SMALL_STATE(8592)] = 392281,
  [SMALL_STATE(8593)] = 392334,
  [SMALL_STATE(8594)] = 392407,
  [SMALL_STATE(8595)] = 392462,
  [SMALL_STATE(8596)] = 392515,
  [SMALL_STATE(8597)] = 392568,
  [SMALL_STATE(8598)] = 392639,
  [SMALL_STATE(8599)] = 392700,
  [SMALL_STATE(8600)] = 392753,
  [SMALL_STATE(8601)] = 392814,
  [SMALL_STATE(8602)] = 392875,
  [SMALL_STATE(8603)] = 392940,
  [SMALL_STATE(8604)] = 393007,
  [SMALL_STATE(8605)] = 393078,
  [SMALL_STATE(8606)] = 393133,
  [SMALL_STATE(8607)] = 393204,
  [SMALL_STATE(8608)] = 393257,
  [SMALL_STATE(8609)] = 393328,
  [SMALL_STATE(8610)] = 393381,
  [SMALL_STATE(8611)] = 393434,
  [SMALL_STATE(8612)] = 393487,
  [SMALL_STATE(8613)] = 393540,
  [SMALL_STATE(8614)] = 393605,
  [SMALL_STATE(8615)] = 393656,
  [SMALL_STATE(8616)] = 393707,
  [SMALL_STATE(8617)] = 393760,
  [SMALL_STATE(8618)] = 393813,
  [SMALL_STATE(8619)] = 393866,
  [SMALL_STATE(8620)] = 393919,
  [SMALL_STATE(8621)] = 393972,
  [SMALL_STATE(8622)] = 394023,
  [SMALL_STATE(8623)] = 394096,
  [SMALL_STATE(8624)] = 394149,
  [SMALL_STATE(8625)] = 394220,
  [SMALL_STATE(8626)] = 394273,
  [SMALL_STATE(8627)] = 394324,
  [SMALL_STATE(8628)] = 394393,
  [SMALL_STATE(8629)] = 394452,
  [SMALL_STATE(8630)] = 394525,
  [SMALL_STATE(8631)] = 394578,
  [SMALL_STATE(8632)] = 394631,
  [SMALL_STATE(8633)] = 394692,
  [SMALL_STATE(8634)] = 394753,
  [SMALL_STATE(8635)] = 394818,
  [SMALL_STATE(8636)] = 394885,
  [SMALL_STATE(8637)] = 394956,
  [SMALL_STATE(8638)] = 395011,
  [SMALL_STATE(8639)] = 395082,
  [SMALL_STATE(8640)] = 395135,
  [SMALL_STATE(8641)] = 395206,
  [SMALL_STATE(8642)] = 395279,
  [SMALL_STATE(8643)] = 395352,
  [SMALL_STATE(8644)] = 395405,
  [SMALL_STATE(8645)] = 395472,
  [SMALL_STATE(8646)] = 395543,
  [SMALL_STATE(8647)] = 395594,
  [SMALL_STATE(8648)] = 395645,
  [SMALL_STATE(8649)] = 395698,
  [SMALL_STATE(8650)] = 395751,
  [SMALL_STATE(8651)] = 395822,
  [SMALL_STATE(8652)] = 395873,
  [SMALL_STATE(8653)] = 395926,
  [SMALL_STATE(8654)] = 395999,
  [SMALL_STATE(8655)] = 396052,
  [SMALL_STATE(8656)] = 396107,
  [SMALL_STATE(8657)] = 396178,
  [SMALL_STATE(8658)] = 396251,
  [SMALL_STATE(8659)] = 396324,
  [SMALL_STATE(8660)] = 396375,
  [SMALL_STATE(8661)] = 396448,
  [SMALL_STATE(8662)] = 396521,
  [SMALL_STATE(8663)] = 396590,
  [SMALL_STATE(8664)] = 396663,
  [SMALL_STATE(8665)] = 396714,
  [SMALL_STATE(8666)] = 396765,
  [SMALL_STATE(8667)] = 396834,
  [SMALL_STATE(8668)] = 396887,
  [SMALL_STATE(8669)] = 396946,
  [SMALL_STATE(8670)] = 396999,
  [SMALL_STATE(8671)] = 397085,
  [SMALL_STATE(8672)] = 397171,
  [SMALL_STATE(8673)] = 397257,
  [SMALL_STATE(8674)] = 397343,
  [SMALL_STATE(8675)] = 397415,
  [SMALL_STATE(8676)] = 397501,
  [SMALL_STATE(8677)] = 397587,
  [SMALL_STATE(8678)] = 397673,
  [SMALL_STATE(8679)] = 397745,
  [SMALL_STATE(8680)] = 397831,
  [SMALL_STATE(8681)] = 397901,
  [SMALL_STATE(8682)] = 397987,
  [SMALL_STATE(8683)] = 398073,
  [SMALL_STATE(8684)] = 398141,
  [SMALL_STATE(8685)] = 398227,
  [SMALL_STATE(8686)] = 398313,
  [SMALL_STATE(8687)] = 398399,
  [SMALL_STATE(8688)] = 398485,
  [SMALL_STATE(8689)] = 398571,
  [SMALL_STATE(8690)] = 398623,
  [SMALL_STATE(8691)] = 398709,
  [SMALL_STATE(8692)] = 398757,
  [SMALL_STATE(8693)] = 398843,
  [SMALL_STATE(8694)] = 398893,
  [SMALL_STATE(8695)] = 398943,
  [SMALL_STATE(8696)] = 399025,
  [SMALL_STATE(8697)] = 399111,
  [SMALL_STATE(8698)] = 399195,
  [SMALL_STATE(8699)] = 399247,
  [SMALL_STATE(8700)] = 399297,
  [SMALL_STATE(8701)] = 399369,
  [SMALL_STATE(8702)] = 399453,
  [SMALL_STATE(8703)] = 399539,
  [SMALL_STATE(8704)] = 399623,
  [SMALL_STATE(8705)] = 399709,
  [SMALL_STATE(8706)] = 399795,
  [SMALL_STATE(8707)] = 399881,
  [SMALL_STATE(8708)] = 399967,
  [SMALL_STATE(8709)] = 400051,
  [SMALL_STATE(8710)] = 400137,
  [SMALL_STATE(8711)] = 400187,
  [SMALL_STATE(8712)] = 400271,
  [SMALL_STATE(8713)] = 400357,
  [SMALL_STATE(8714)] = 400415,
  [SMALL_STATE(8715)] = 400499,
  [SMALL_STATE(8716)] = 400551,
  [SMALL_STATE(8717)] = 400637,
  [SMALL_STATE(8718)] = 400723,
  [SMALL_STATE(8719)] = 400809,
  [SMALL_STATE(8720)] = 400881,
  [SMALL_STATE(8721)] = 400967,
  [SMALL_STATE(8722)] = 401053,
  [SMALL_STATE(8723)] = 401139,
  [SMALL_STATE(8724)] = 401191,
  [SMALL_STATE(8725)] = 401251,
  [SMALL_STATE(8726)] = 401311,
  [SMALL_STATE(8727)] = 401375,
  [SMALL_STATE(8728)] = 401425,
  [SMALL_STATE(8729)] = 401491,
  [SMALL_STATE(8730)] = 401563,
  [SMALL_STATE(8731)] = 401635,
  [SMALL_STATE(8732)] = 401707,
  [SMALL_STATE(8733)] = 401793,
  [SMALL_STATE(8734)] = 401863,
  [SMALL_STATE(8735)] = 401949,
  [SMALL_STATE(8736)] = 402035,
  [SMALL_STATE(8737)] = 402089,
  [SMALL_STATE(8738)] = 402137,
  [SMALL_STATE(8739)] = 402219,
  [SMALL_STATE(8740)] = 402291,
  [SMALL_STATE(8741)] = 402377,
  [SMALL_STATE(8742)] = 402463,
  [SMALL_STATE(8743)] = 402549,
  [SMALL_STATE(8744)] = 402607,
  [SMALL_STATE(8745)] = 402693,
  [SMALL_STATE(8746)] = 402779,
  [SMALL_STATE(8747)] = 402827,
  [SMALL_STATE(8748)] = 402913,
  [SMALL_STATE(8749)] = 402961,
  [SMALL_STATE(8750)] = 403047,
  [SMALL_STATE(8751)] = 403133,
  [SMALL_STATE(8752)] = 403219,
  [SMALL_STATE(8753)] = 403305,
  [SMALL_STATE(8754)] = 403355,
  [SMALL_STATE(8755)] = 403427,
  [SMALL_STATE(8756)] = 403479,
  [SMALL_STATE(8757)] = 403531,
  [SMALL_STATE(8758)] = 403581,
  [SMALL_STATE(8759)] = 403629,
  [SMALL_STATE(8760)] = 403715,
  [SMALL_STATE(8761)] = 403801,
  [SMALL_STATE(8762)] = 403873,
  [SMALL_STATE(8763)] = 403921,
  [SMALL_STATE(8764)] = 403969,
  [SMALL_STATE(8765)] = 404055,
  [SMALL_STATE(8766)] = 404139,
  [SMALL_STATE(8767)] = 404209,
  [SMALL_STATE(8768)] = 404277,
  [SMALL_STATE(8769)] = 404363,
  [SMALL_STATE(8770)] = 404449,
  [SMALL_STATE(8771)] = 404535,
  [SMALL_STATE(8772)] = 404585,
  [SMALL_STATE(8773)] = 404657,
  [SMALL_STATE(8774)] = 404741,
  [SMALL_STATE(8775)] = 404799,
  [SMALL_STATE(8776)] = 404851,
  [SMALL_STATE(8777)] = 404903,
  [SMALL_STATE(8778)] = 404989,
  [SMALL_STATE(8779)] = 405039,
  [SMALL_STATE(8780)] = 405109,
  [SMALL_STATE(8781)] = 405195,
  [SMALL_STATE(8782)] = 405247,
  [SMALL_STATE(8783)] = 405295,
  [SMALL_STATE(8784)] = 405381,
  [SMALL_STATE(8785)] = 405433,
  [SMALL_STATE(8786)] = 405481,
  [SMALL_STATE(8787)] = 405533,
  [SMALL_STATE(8788)] = 405593,
  [SMALL_STATE(8789)] = 405653,
  [SMALL_STATE(8790)] = 405717,
  [SMALL_STATE(8791)] = 405769,
  [SMALL_STATE(8792)] = 405855,
  [SMALL_STATE(8793)] = 405903,
  [SMALL_STATE(8794)] = 405969,
  [SMALL_STATE(8795)] = 406039,
  [SMALL_STATE(8796)] = 406125,
  [SMALL_STATE(8797)] = 406179,
  [SMALL_STATE(8798)] = 406229,
  [SMALL_STATE(8799)] = 406277,
  [SMALL_STATE(8800)] = 406347,
  [SMALL_STATE(8801)] = 406419,
  [SMALL_STATE(8802)] = 406502,
  [SMALL_STATE(8803)] = 406585,
  [SMALL_STATE(8804)] = 406668,
  [SMALL_STATE(8805)] = 406731,
  [SMALL_STATE(8806)] = 406796,
  [SMALL_STATE(8807)] = 406879,
  [SMALL_STATE(8808)] = 406962,
  [SMALL_STATE(8809)] = 407045,
  [SMALL_STATE(8810)] = 407128,
  [SMALL_STATE(8811)] = 407211,
  [SMALL_STATE(8812)] = 407280,
  [SMALL_STATE(8813)] = 407333,
  [SMALL_STATE(8814)] = 407402,
  [SMALL_STATE(8815)] = 407485,
  [SMALL_STATE(8816)] = 407568,
  [SMALL_STATE(8817)] = 407651,
  [SMALL_STATE(8818)] = 407734,
  [SMALL_STATE(8819)] = 407817,
  [SMALL_STATE(8820)] = 407900,
  [SMALL_STATE(8821)] = 407983,
  [SMALL_STATE(8822)] = 408066,
  [SMALL_STATE(8823)] = 408149,
  [SMALL_STATE(8824)] = 408232,
  [SMALL_STATE(8825)] = 408283,
  [SMALL_STATE(8826)] = 408366,
  [SMALL_STATE(8827)] = 408449,
  [SMALL_STATE(8828)] = 408532,
  [SMALL_STATE(8829)] = 408583,
  [SMALL_STATE(8830)] = 408666,
  [SMALL_STATE(8831)] = 408749,
  [SMALL_STATE(8832)] = 408832,
  [SMALL_STATE(8833)] = 408915,
  [SMALL_STATE(8834)] = 408998,
  [SMALL_STATE(8835)] = 409081,
  [SMALL_STATE(8836)] = 409164,
  [SMALL_STATE(8837)] = 409247,
  [SMALL_STATE(8838)] = 409330,
  [SMALL_STATE(8839)] = 409413,
  [SMALL_STATE(8840)] = 409496,
  [SMALL_STATE(8841)] = 409579,
  [SMALL_STATE(8842)] = 409662,
  [SMALL_STATE(8843)] = 409711,
  [SMALL_STATE(8844)] = 409794,
  [SMALL_STATE(8845)] = 409877,
  [SMALL_STATE(8846)] = 409944,
  [SMALL_STATE(8847)] = 410027,
  [SMALL_STATE(8848)] = 410110,
  [SMALL_STATE(8849)] = 410179,
  [SMALL_STATE(8850)] = 410262,
  [SMALL_STATE(8851)] = 410345,
  [SMALL_STATE(8852)] = 410428,
  [SMALL_STATE(8853)] = 410511,
  [SMALL_STATE(8854)] = 410594,
  [SMALL_STATE(8855)] = 410677,
  [SMALL_STATE(8856)] = 410734,
  [SMALL_STATE(8857)] = 410785,
  [SMALL_STATE(8858)] = 410836,
  [SMALL_STATE(8859)] = 410895,
  [SMALL_STATE(8860)] = 410954,
  [SMALL_STATE(8861)] = 411037,
  [SMALL_STATE(8862)] = 411100,
  [SMALL_STATE(8863)] = 411165,
  [SMALL_STATE(8864)] = 411248,
  [SMALL_STATE(8865)] = 411331,
  [SMALL_STATE(8866)] = 411414,
  [SMALL_STATE(8867)] = 411497,
  [SMALL_STATE(8868)] = 411580,
  [SMALL_STATE(8869)] = 411663,
  [SMALL_STATE(8870)] = 411714,
  [SMALL_STATE(8871)] = 411783,
  [SMALL_STATE(8872)] = 411866,
  [SMALL_STATE(8873)] = 411949,
  [SMALL_STATE(8874)] = 412032,
  [SMALL_STATE(8875)] = 412085,
  [SMALL_STATE(8876)] = 412168,
  [SMALL_STATE(8877)] = 412251,
  [SMALL_STATE(8878)] = 412302,
  [SMALL_STATE(8879)] = 412385,
  [SMALL_STATE(8880)] = 412434,
  [SMALL_STATE(8881)] = 412517,
  [SMALL_STATE(8882)] = 412600,
  [SMALL_STATE(8883)] = 412683,
  [SMALL_STATE(8884)] = 412752,
  [SMALL_STATE(8885)] = 412835,
  [SMALL_STATE(8886)] = 412918,
  [SMALL_STATE(8887)] = 413001,
  [SMALL_STATE(8888)] = 413072,
  [SMALL_STATE(8889)] = 413155,
  [SMALL_STATE(8890)] = 413238,
  [SMALL_STATE(8891)] = 413321,
  [SMALL_STATE(8892)] = 413368,
  [SMALL_STATE(8893)] = 413451,
  [SMALL_STATE(8894)] = 413534,
  [SMALL_STATE(8895)] = 413605,
  [SMALL_STATE(8896)] = 413654,
  [SMALL_STATE(8897)] = 413737,
  [SMALL_STATE(8898)] = 413820,
  [SMALL_STATE(8899)] = 413903,
  [SMALL_STATE(8900)] = 413954,
  [SMALL_STATE(8901)] = 414037,
  [SMALL_STATE(8902)] = 414120,
  [SMALL_STATE(8903)] = 414203,
  [SMALL_STATE(8904)] = 414286,
  [SMALL_STATE(8905)] = 414369,
  [SMALL_STATE(8906)] = 414438,
  [SMALL_STATE(8907)] = 414521,
  [SMALL_STATE(8908)] = 414604,
  [SMALL_STATE(8909)] = 414687,
  [SMALL_STATE(8910)] = 414756,
  [SMALL_STATE(8911)] = 414807,
  [SMALL_STATE(8912)] = 414890,
  [SMALL_STATE(8913)] = 414961,
  [SMALL_STATE(8914)] = 415044,
  [SMALL_STATE(8915)] = 415127,
  [SMALL_STATE(8916)] = 415210,
  [SMALL_STATE(8917)] = 415293,
  [SMALL_STATE(8918)] = 415376,
  [SMALL_STATE(8919)] = 415459,
  [SMALL_STATE(8920)] = 415542,
  [SMALL_STATE(8921)] = 415625,
  [SMALL_STATE(8922)] = 415708,
  [SMALL_STATE(8923)] = 415791,
  [SMALL_STATE(8924)] = 415874,
  [SMALL_STATE(8925)] = 415957,
  [SMALL_STATE(8926)] = 416006,
  [SMALL_STATE(8927)] = 416077,
  [SMALL_STATE(8928)] = 416160,
  [SMALL_STATE(8929)] = 416243,
  [SMALL_STATE(8930)] = 416314,
  [SMALL_STATE(8931)] = 416397,
  [SMALL_STATE(8932)] = 416480,
  [SMALL_STATE(8933)] = 416563,
  [SMALL_STATE(8934)] = 416646,
  [SMALL_STATE(8935)] = 416729,
  [SMALL_STATE(8936)] = 416812,
  [SMALL_STATE(8937)] = 416895,
  [SMALL_STATE(8938)] = 416978,
  [SMALL_STATE(8939)] = 417061,
  [SMALL_STATE(8940)] = 417144,
  [SMALL_STATE(8941)] = 417193,
  [SMALL_STATE(8942)] = 417276,
  [SMALL_STATE(8943)] = 417359,
  [SMALL_STATE(8944)] = 417442,
  [SMALL_STATE(8945)] = 417525,
  [SMALL_STATE(8946)] = 417574,
  [SMALL_STATE(8947)] = 417657,
  [SMALL_STATE(8948)] = 417740,
  [SMALL_STATE(8949)] = 417791,
  [SMALL_STATE(8950)] = 417874,
  [SMALL_STATE(8951)] = 417925,
  [SMALL_STATE(8952)] = 418008,
  [SMALL_STATE(8953)] = 418057,
  [SMALL_STATE(8954)] = 418140,
  [SMALL_STATE(8955)] = 418223,
  [SMALL_STATE(8956)] = 418306,
  [SMALL_STATE(8957)] = 418389,
  [SMALL_STATE(8958)] = 418472,
  [SMALL_STATE(8959)] = 418543,
  [SMALL_STATE(8960)] = 418626,
  [SMALL_STATE(8961)] = 418709,
  [SMALL_STATE(8962)] = 418792,
  [SMALL_STATE(8963)] = 418875,
  [SMALL_STATE(8964)] = 418922,
  [SMALL_STATE(8965)] = 419005,
  [SMALL_STATE(8966)] = 419088,
  [SMALL_STATE(8967)] = 419171,
  [SMALL_STATE(8968)] = 419254,
  [SMALL_STATE(8969)] = 419337,
  [SMALL_STATE(8970)] = 419420,
  [SMALL_STATE(8971)] = 419503,
  [SMALL_STATE(8972)] = 419586,
  [SMALL_STATE(8973)] = 419669,
  [SMALL_STATE(8974)] = 419752,
  [SMALL_STATE(8975)] = 419835,
  [SMALL_STATE(8976)] = 419918,
  [SMALL_STATE(8977)] = 420001,
  [SMALL_STATE(8978)] = 420084,
  [SMALL_STATE(8979)] = 420167,
  [SMALL_STATE(8980)] = 420250,
  [SMALL_STATE(8981)] = 420333,
  [SMALL_STATE(8982)] = 420416,
  [SMALL_STATE(8983)] = 420499,
  [SMALL_STATE(8984)] = 420570,
  [SMALL_STATE(8985)] = 420653,
  [SMALL_STATE(8986)] = 420736,
  [SMALL_STATE(8987)] = 420819,
  [SMALL_STATE(8988)] = 420902,
  [SMALL_STATE(8989)] = 420985,
  [SMALL_STATE(8990)] = 421068,
  [SMALL_STATE(8991)] = 421151,
  [SMALL_STATE(8992)] = 421234,
  [SMALL_STATE(8993)] = 421317,
  [SMALL_STATE(8994)] = 421368,
  [SMALL_STATE(8995)] = 421451,
  [SMALL_STATE(8996)] = 421502,
  [SMALL_STATE(8997)] = 421585,
  [SMALL_STATE(8998)] = 421668,
  [SMALL_STATE(8999)] = 421717,
  [SMALL_STATE(9000)] = 421800,
  [SMALL_STATE(9001)] = 421883,
  [SMALL_STATE(9002)] = 421954,
  [SMALL_STATE(9003)] = 422037,
  [SMALL_STATE(9004)] = 422120,
  [SMALL_STATE(9005)] = 422171,
  [SMALL_STATE(9006)] = 422240,
  [SMALL_STATE(9007)] = 422323,
  [SMALL_STATE(9008)] = 422406,
  [SMALL_STATE(9009)] = 422455,
  [SMALL_STATE(9010)] = 422538,
  [SMALL_STATE(9011)] = 422589,
  [SMALL_STATE(9012)] = 422672,
  [SMALL_STATE(9013)] = 422755,
  [SMALL_STATE(9014)] = 422806,
  [SMALL_STATE(9015)] = 422853,
  [SMALL_STATE(9016)] = 422936,
  [SMALL_STATE(9017)] = 423019,
  [SMALL_STATE(9018)] = 423102,
  [SMALL_STATE(9019)] = 423185,
  [SMALL_STATE(9020)] = 423268,
  [SMALL_STATE(9021)] = 423319,
  [SMALL_STATE(9022)] = 423402,
  [SMALL_STATE(9023)] = 423485,
  [SMALL_STATE(9024)] = 423568,
  [SMALL_STATE(9025)] = 423651,
  [SMALL_STATE(9026)] = 423708,
  [SMALL_STATE(9027)] = 423775,
  [SMALL_STATE(9028)] = 423822,
  [SMALL_STATE(9029)] = 423905,
  [SMALL_STATE(9030)] = 423988,
  [SMALL_STATE(9031)] = 424071,
  [SMALL_STATE(9032)] = 424154,
  [SMALL_STATE(9033)] = 424203,
  [SMALL_STATE(9034)] = 424286,
  [SMALL_STATE(9035)] = 424369,
  [SMALL_STATE(9036)] = 424426,
  [SMALL_STATE(9037)] = 424509,
  [SMALL_STATE(9038)] = 424580,
  [SMALL_STATE(9039)] = 424631,
  [SMALL_STATE(9040)] = 424680,
  [SMALL_STATE(9041)] = 424731,
  [SMALL_STATE(9042)] = 424814,
  [SMALL_STATE(9043)] = 424885,
  [SMALL_STATE(9044)] = 424936,
  [SMALL_STATE(9045)] = 425019,
  [SMALL_STATE(9046)] = 425102,
  [SMALL_STATE(9047)] = 425149,
  [SMALL_STATE(9048)] = 425208,
  [SMALL_STATE(9049)] = 425291,
  [SMALL_STATE(9050)] = 425374,
  [SMALL_STATE(9051)] = 425445,
  [SMALL_STATE(9052)] = 425528,
  [SMALL_STATE(9053)] = 425587,
  [SMALL_STATE(9054)] = 425670,
  [SMALL_STATE(9055)] = 425753,
  [SMALL_STATE(9056)] = 425836,
  [SMALL_STATE(9057)] = 425887,
  [SMALL_STATE(9058)] = 425970,
  [SMALL_STATE(9059)] = 426041,
  [SMALL_STATE(9060)] = 426124,
  [SMALL_STATE(9061)] = 426170,
  [SMALL_STATE(9062)] = 426220,
  [SMALL_STATE(9063)] = 426266,
  [SMALL_STATE(9064)] = 426316,
  [SMALL_STATE(9065)] = 426362,
  [SMALL_STATE(9066)] = 426408,
  [SMALL_STATE(9067)] = 426478,
  [SMALL_STATE(9068)] = 426548,
  [SMALL_STATE(9069)] = 426610,
  [SMALL_STATE(9070)] = 426660,
  [SMALL_STATE(9071)] = 426710,
  [SMALL_STATE(9072)] = 426756,
  [SMALL_STATE(9073)] = 426802,
  [SMALL_STATE(9074)] = 426860,
  [SMALL_STATE(9075)] = 426918,
  [SMALL_STATE(9076)] = 426980,
  [SMALL_STATE(9077)] = 427044,
  [SMALL_STATE(9078)] = 427090,
  [SMALL_STATE(9079)] = 427158,
  [SMALL_STATE(9080)] = 427214,
  [SMALL_STATE(9081)] = 427260,
  [SMALL_STATE(9082)] = 427306,
  [SMALL_STATE(9083)] = 427370,
  [SMALL_STATE(9084)] = 427416,
  [SMALL_STATE(9085)] = 427466,
  [SMALL_STATE(9086)] = 427532,
  [SMALL_STATE(9087)] = 427600,
  [SMALL_STATE(9088)] = 427652,
  [SMALL_STATE(9089)] = 427720,
  [SMALL_STATE(9090)] = 427768,
  [SMALL_STATE(9091)] = 427814,
  [SMALL_STATE(9092)] = 427870,
  [SMALL_STATE(9093)] = 427926,
  [SMALL_STATE(9094)] = 427972,
  [SMALL_STATE(9095)] = 428018,
  [SMALL_STATE(9096)] = 428074,
  [SMALL_STATE(9097)] = 428120,
  [SMALL_STATE(9098)] = 428166,
  [SMALL_STATE(9099)] = 428212,
  [SMALL_STATE(9100)] = 428258,
  [SMALL_STATE(9101)] = 428304,
  [SMALL_STATE(9102)] = 428350,
  [SMALL_STATE(9103)] = 428402,
  [SMALL_STATE(9104)] = 428452,
  [SMALL_STATE(9105)] = 428498,
  [SMALL_STATE(9106)] = 428564,
  [SMALL_STATE(9107)] = 428610,
  [SMALL_STATE(9108)] = 428656,
  [SMALL_STATE(9109)] = 428702,
  [SMALL_STATE(9110)] = 428748,
  [SMALL_STATE(9111)] = 428794,
  [SMALL_STATE(9112)] = 428840,
  [SMALL_STATE(9113)] = 428910,
  [SMALL_STATE(9114)] = 428956,
  [SMALL_STATE(9115)] = 429002,
  [SMALL_STATE(9116)] = 429048,
  [SMALL_STATE(9117)] = 429094,
  [SMALL_STATE(9118)] = 429162,
  [SMALL_STATE(9119)] = 429208,
  [SMALL_STATE(9120)] = 429254,
  [SMALL_STATE(9121)] = 429304,
  [SMALL_STATE(9122)] = 429352,
  [SMALL_STATE(9123)] = 429398,
  [SMALL_STATE(9124)] = 429446,
  [SMALL_STATE(9125)] = 429516,
  [SMALL_STATE(9126)] = 429562,
  [SMALL_STATE(9127)] = 429610,
  [SMALL_STATE(9128)] = 429658,
  [SMALL_STATE(9129)] = 429704,
  [SMALL_STATE(9130)] = 429750,
  [SMALL_STATE(9131)] = 429798,
  [SMALL_STATE(9132)] = 429844,
  [SMALL_STATE(9133)] = 429894,
  [SMALL_STATE(9134)] = 429962,
  [SMALL_STATE(9135)] = 430020,
  [SMALL_STATE(9136)] = 430090,
  [SMALL_STATE(9137)] = 430136,
  [SMALL_STATE(9138)] = 430194,
  [SMALL_STATE(9139)] = 430240,
  [SMALL_STATE(9140)] = 430286,
  [SMALL_STATE(9141)] = 430332,
  [SMALL_STATE(9142)] = 430378,
  [SMALL_STATE(9143)] = 430424,
  [SMALL_STATE(9144)] = 430470,
  [SMALL_STATE(9145)] = 430516,
  [SMALL_STATE(9146)] = 430562,
  [SMALL_STATE(9147)] = 430608,
  [SMALL_STATE(9148)] = 430654,
  [SMALL_STATE(9149)] = 430700,
  [SMALL_STATE(9150)] = 430746,
  [SMALL_STATE(9151)] = 430796,
  [SMALL_STATE(9152)] = 430842,
  [SMALL_STATE(9153)] = 430890,
  [SMALL_STATE(9154)] = 430936,
  [SMALL_STATE(9155)] = 430982,
  [SMALL_STATE(9156)] = 431028,
  [SMALL_STATE(9157)] = 431076,
  [SMALL_STATE(9158)] = 431122,
  [SMALL_STATE(9159)] = 431168,
  [SMALL_STATE(9160)] = 431236,
  [SMALL_STATE(9161)] = 431282,
  [SMALL_STATE(9162)] = 431330,
  [SMALL_STATE(9163)] = 431380,
  [SMALL_STATE(9164)] = 431426,
  [SMALL_STATE(9165)] = 431474,
  [SMALL_STATE(9166)] = 431520,
  [SMALL_STATE(9167)] = 431566,
  [SMALL_STATE(9168)] = 431612,
  [SMALL_STATE(9169)] = 431658,
  [SMALL_STATE(9170)] = 431704,
  [SMALL_STATE(9171)] = 431750,
  [SMALL_STATE(9172)] = 431796,
  [SMALL_STATE(9173)] = 431842,
  [SMALL_STATE(9174)] = 431888,
  [SMALL_STATE(9175)] = 431934,
  [SMALL_STATE(9176)] = 431980,
  [SMALL_STATE(9177)] = 432026,
  [SMALL_STATE(9178)] = 432072,
  [SMALL_STATE(9179)] = 432122,
  [SMALL_STATE(9180)] = 432168,
  [SMALL_STATE(9181)] = 432214,
  [SMALL_STATE(9182)] = 432260,
  [SMALL_STATE(9183)] = 432306,
  [SMALL_STATE(9184)] = 432352,
  [SMALL_STATE(9185)] = 432402,
  [SMALL_STATE(9186)] = 432448,
  [SMALL_STATE(9187)] = 432494,
  [SMALL_STATE(9188)] = 432540,
  [SMALL_STATE(9189)] = 432588,
  [SMALL_STATE(9190)] = 432658,
  [SMALL_STATE(9191)] = 432704,
  [SMALL_STATE(9192)] = 432750,
  [SMALL_STATE(9193)] = 432795,
  [SMALL_STATE(9194)] = 432840,
  [SMALL_STATE(9195)] = 432885,
  [SMALL_STATE(9196)] = 432930,
  [SMALL_STATE(9197)] = 432975,
  [SMALL_STATE(9198)] = 433020,
  [SMALL_STATE(9199)] = 433067,
  [SMALL_STATE(9200)] = 433112,
  [SMALL_STATE(9201)] = 433157,
  [SMALL_STATE(9202)] = 433202,
  [SMALL_STATE(9203)] = 433271,
  [SMALL_STATE(9204)] = 433316,
  [SMALL_STATE(9205)] = 433361,
  [SMALL_STATE(9206)] = 433408,
  [SMALL_STATE(9207)] = 433453,
  [SMALL_STATE(9208)] = 433498,
  [SMALL_STATE(9209)] = 433543,
  [SMALL_STATE(9210)] = 433588,
  [SMALL_STATE(9211)] = 433633,
  [SMALL_STATE(9212)] = 433678,
  [SMALL_STATE(9213)] = 433723,
  [SMALL_STATE(9214)] = 433792,
  [SMALL_STATE(9215)] = 433837,
  [SMALL_STATE(9216)] = 433882,
  [SMALL_STATE(9217)] = 433959,
  [SMALL_STATE(9218)] = 434004,
  [SMALL_STATE(9219)] = 434049,
  [SMALL_STATE(9220)] = 434094,
  [SMALL_STATE(9221)] = 434139,
  [SMALL_STATE(9222)] = 434184,
  [SMALL_STATE(9223)] = 434233,
  [SMALL_STATE(9224)] = 434278,
  [SMALL_STATE(9225)] = 434323,
  [SMALL_STATE(9226)] = 434368,
  [SMALL_STATE(9227)] = 434413,
  [SMALL_STATE(9228)] = 434458,
  [SMALL_STATE(9229)] = 434503,
  [SMALL_STATE(9230)] = 434554,
  [SMALL_STATE(9231)] = 434599,
  [SMALL_STATE(9232)] = 434644,
  [SMALL_STATE(9233)] = 434689,
  [SMALL_STATE(9234)] = 434734,
  [SMALL_STATE(9235)] = 434779,
  [SMALL_STATE(9236)] = 434824,
  [SMALL_STATE(9237)] = 434869,
  [SMALL_STATE(9238)] = 434916,
  [SMALL_STATE(9239)] = 434961,
  [SMALL_STATE(9240)] = 435006,
  [SMALL_STATE(9241)] = 435051,
  [SMALL_STATE(9242)] = 435096,
  [SMALL_STATE(9243)] = 435141,
  [SMALL_STATE(9244)] = 435186,
  [SMALL_STATE(9245)] = 435255,
  [SMALL_STATE(9246)] = 435306,
  [SMALL_STATE(9247)] = 435351,
  [SMALL_STATE(9248)] = 435396,
  [SMALL_STATE(9249)] = 435447,
  [SMALL_STATE(9250)] = 435492,
  [SMALL_STATE(9251)] = 435537,
  [SMALL_STATE(9252)] = 435582,
  [SMALL_STATE(9253)] = 435633,
  [SMALL_STATE(9254)] = 435678,
  [SMALL_STATE(9255)] = 435723,
  [SMALL_STATE(9256)] = 435768,
  [SMALL_STATE(9257)] = 435813,
  [SMALL_STATE(9258)] = 435858,
  [SMALL_STATE(9259)] = 435903,
  [SMALL_STATE(9260)] = 435972,
  [SMALL_STATE(9261)] = 436041,
  [SMALL_STATE(9262)] = 436118,
  [SMALL_STATE(9263)] = 436163,
  [SMALL_STATE(9264)] = 436208,
  [SMALL_STATE(9265)] = 436253,
  [SMALL_STATE(9266)] = 436298,
  [SMALL_STATE(9267)] = 436343,
  [SMALL_STATE(9268)] = 436388,
  [SMALL_STATE(9269)] = 436435,
  [SMALL_STATE(9270)] = 436486,
  [SMALL_STATE(9271)] = 436531,
  [SMALL_STATE(9272)] = 436576,
  [SMALL_STATE(9273)] = 436621,
  [SMALL_STATE(9274)] = 436666,
  [SMALL_STATE(9275)] = 436711,
  [SMALL_STATE(9276)] = 436756,
  [SMALL_STATE(9277)] = 436801,
  [SMALL_STATE(9278)] = 436870,
  [SMALL_STATE(9279)] = 436921,
  [SMALL_STATE(9280)] = 436981,
  [SMALL_STATE(9281)] = 437041,
  [SMALL_STATE(9282)] = 437115,
  [SMALL_STATE(9283)] = 437169,
  [SMALL_STATE(9284)] = 437243,
  [SMALL_STATE(9285)] = 437315,
  [SMALL_STATE(9286)] = 437375,
  [SMALL_STATE(9287)] = 437431,
  [SMALL_STATE(9288)] = 437503,
  [SMALL_STATE(9289)] = 437563,
  [SMALL_STATE(9290)] = 437621,
  [SMALL_STATE(9291)] = 437693,
  [SMALL_STATE(9292)] = 437749,
  [SMALL_STATE(9293)] = 437809,
  [SMALL_STATE(9294)] = 437883,
  [SMALL_STATE(9295)] = 437927,
  [SMALL_STATE(9296)] = 437987,
  [SMALL_STATE(9297)] = 438041,
  [SMALL_STATE(9298)] = 438099,
  [SMALL_STATE(9299)] = 438153,
  [SMALL_STATE(9300)] = 438207,
  [SMALL_STATE(9301)] = 438284,
  [SMALL_STATE(9302)] = 438341,
  [SMALL_STATE(9303)] = 438418,
  [SMALL_STATE(9304)] = 438463,
  [SMALL_STATE(9305)] = 438540,
  [SMALL_STATE(9306)] = 438617,
  [SMALL_STATE(9307)] = 438694,
  [SMALL_STATE(9308)] = 438739,
  [SMALL_STATE(9309)] = 438796,
  [SMALL_STATE(9310)] = 438855,
  [SMALL_STATE(9311)] = 438914,
  [SMALL_STATE(9312)] = 438959,
  [SMALL_STATE(9313)] = 439004,
  [SMALL_STATE(9314)] = 439049,
  [SMALL_STATE(9315)] = 439126,
  [SMALL_STATE(9316)] = 439203,
  [SMALL_STATE(9317)] = 439256,
  [SMALL_STATE(9318)] = 439309,
  [SMALL_STATE(9319)] = 439352,
  [SMALL_STATE(9320)] = 439423,
  [SMALL_STATE(9321)] = 439480,
  [SMALL_STATE(9322)] = 439537,
  [SMALL_STATE(9323)] = 439580,
  [SMALL_STATE(9324)] = 439657,
  [SMALL_STATE(9325)] = 439734,
  [SMALL_STATE(9326)] = 439811,
  [SMALL_STATE(9327)] = 439864,
  [SMALL_STATE(9328)] = 439935,
  [SMALL_STATE(9329)] = 440012,
  [SMALL_STATE(9330)] = 440089,
  [SMALL_STATE(9331)] = 440166,
  [SMALL_STATE(9332)] = 440225,
  [SMALL_STATE(9333)] = 440302,
  [SMALL_STATE(9334)] = 440379,
  [SMALL_STATE(9335)] = 440456,
  [SMALL_STATE(9336)] = 440533,
  [SMALL_STATE(9337)] = 440610,
  [SMALL_STATE(9338)] = 440687,
  [SMALL_STATE(9339)] = 440730,
  [SMALL_STATE(9340)] = 440789,
  [SMALL_STATE(9341)] = 440866,
  [SMALL_STATE(9342)] = 440943,
  [SMALL_STATE(9343)] = 441020,
  [SMALL_STATE(9344)] = 441097,
  [SMALL_STATE(9345)] = 441168,
  [SMALL_STATE(9346)] = 441245,
  [SMALL_STATE(9347)] = 441304,
  [SMALL_STATE(9348)] = 441361,
  [SMALL_STATE(9349)] = 441438,
  [SMALL_STATE(9350)] = 441491,
  [SMALL_STATE(9351)] = 441568,
  [SMALL_STATE(9352)] = 441645,
  [SMALL_STATE(9353)] = 441722,
  [SMALL_STATE(9354)] = 441799,
  [SMALL_STATE(9355)] = 441876,
  [SMALL_STATE(9356)] = 441921,
  [SMALL_STATE(9357)] = 441992,
  [SMALL_STATE(9358)] = 442037,
  [SMALL_STATE(9359)] = 442114,
  [SMALL_STATE(9360)] = 442191,
  [SMALL_STATE(9361)] = 442268,
  [SMALL_STATE(9362)] = 442311,
  [SMALL_STATE(9363)] = 442356,
  [SMALL_STATE(9364)] = 442433,
  [SMALL_STATE(9365)] = 442510,
  [SMALL_STATE(9366)] = 442587,
  [SMALL_STATE(9367)] = 442632,
  [SMALL_STATE(9368)] = 442703,
  [SMALL_STATE(9369)] = 442748,
  [SMALL_STATE(9370)] = 442825,
  [SMALL_STATE(9371)] = 442902,
  [SMALL_STATE(9372)] = 442945,
  [SMALL_STATE(9373)] = 442992,
  [SMALL_STATE(9374)] = 443047,
  [SMALL_STATE(9375)] = 443104,
  [SMALL_STATE(9376)] = 443149,
  [SMALL_STATE(9377)] = 443194,
  [SMALL_STATE(9378)] = 443271,
  [SMALL_STATE(9379)] = 443328,
  [SMALL_STATE(9380)] = 443399,
  [SMALL_STATE(9381)] = 443441,
  [SMALL_STATE(9382)] = 443513,
  [SMALL_STATE(9383)] = 443585,
  [SMALL_STATE(9384)] = 443657,
  [SMALL_STATE(9385)] = 443715,
  [SMALL_STATE(9386)] = 443769,
  [SMALL_STATE(9387)] = 443811,
  [SMALL_STATE(9388)] = 443883,
  [SMALL_STATE(9389)] = 443955,
  [SMALL_STATE(9390)] = 443997,
  [SMALL_STATE(9391)] = 444049,
  [SMALL_STATE(9392)] = 444091,
  [SMALL_STATE(9393)] = 444145,
  [SMALL_STATE(9394)] = 444203,
  [SMALL_STATE(9395)] = 444255,
  [SMALL_STATE(9396)] = 444297,
  [SMALL_STATE(9397)] = 444339,
  [SMALL_STATE(9398)] = 444381,
  [SMALL_STATE(9399)] = 444423,
  [SMALL_STATE(9400)] = 444495,
  [SMALL_STATE(9401)] = 444537,
  [SMALL_STATE(9402)] = 444609,
  [SMALL_STATE(9403)] = 444651,
  [SMALL_STATE(9404)] = 444693,
  [SMALL_STATE(9405)] = 444735,
  [SMALL_STATE(9406)] = 444777,
  [SMALL_STATE(9407)] = 444819,
  [SMALL_STATE(9408)] = 444861,
  [SMALL_STATE(9409)] = 444903,
  [SMALL_STATE(9410)] = 444945,
  [SMALL_STATE(9411)] = 444987,
  [SMALL_STATE(9412)] = 445029,
  [SMALL_STATE(9413)] = 445071,
  [SMALL_STATE(9414)] = 445113,
  [SMALL_STATE(9415)] = 445155,
  [SMALL_STATE(9416)] = 445227,
  [SMALL_STATE(9417)] = 445269,
  [SMALL_STATE(9418)] = 445311,
  [SMALL_STATE(9419)] = 445353,
  [SMALL_STATE(9420)] = 445395,
  [SMALL_STATE(9421)] = 445437,
  [SMALL_STATE(9422)] = 445479,
  [SMALL_STATE(9423)] = 445551,
  [SMALL_STATE(9424)] = 445593,
  [SMALL_STATE(9425)] = 445635,
  [SMALL_STATE(9426)] = 445677,
  [SMALL_STATE(9427)] = 445719,
  [SMALL_STATE(9428)] = 445761,
  [SMALL_STATE(9429)] = 445803,
  [SMALL_STATE(9430)] = 445845,
  [SMALL_STATE(9431)] = 445887,
  [SMALL_STATE(9432)] = 445929,
  [SMALL_STATE(9433)] = 445971,
  [SMALL_STATE(9434)] = 446023,
  [SMALL_STATE(9435)] = 446065,
  [SMALL_STATE(9436)] = 446107,
  [SMALL_STATE(9437)] = 446149,
  [SMALL_STATE(9438)] = 446191,
  [SMALL_STATE(9439)] = 446263,
  [SMALL_STATE(9440)] = 446305,
  [SMALL_STATE(9441)] = 446347,
  [SMALL_STATE(9442)] = 446389,
  [SMALL_STATE(9443)] = 446431,
  [SMALL_STATE(9444)] = 446473,
  [SMALL_STATE(9445)] = 446515,
  [SMALL_STATE(9446)] = 446557,
  [SMALL_STATE(9447)] = 446599,
  [SMALL_STATE(9448)] = 446641,
  [SMALL_STATE(9449)] = 446713,
  [SMALL_STATE(9450)] = 446755,
  [SMALL_STATE(9451)] = 446797,
  [SMALL_STATE(9452)] = 446839,
  [SMALL_STATE(9453)] = 446881,
  [SMALL_STATE(9454)] = 446953,
  [SMALL_STATE(9455)] = 446995,
  [SMALL_STATE(9456)] = 447037,
  [SMALL_STATE(9457)] = 447079,
  [SMALL_STATE(9458)] = 447121,
  [SMALL_STATE(9459)] = 447163,
  [SMALL_STATE(9460)] = 447205,
  [SMALL_STATE(9461)] = 447247,
  [SMALL_STATE(9462)] = 447289,
  [SMALL_STATE(9463)] = 447331,
  [SMALL_STATE(9464)] = 447373,
  [SMALL_STATE(9465)] = 447415,
  [SMALL_STATE(9466)] = 447487,
  [SMALL_STATE(9467)] = 447559,
  [SMALL_STATE(9468)] = 447601,
  [SMALL_STATE(9469)] = 447643,
  [SMALL_STATE(9470)] = 447685,
  [SMALL_STATE(9471)] = 447757,
  [SMALL_STATE(9472)] = 447799,
  [SMALL_STATE(9473)] = 447841,
  [SMALL_STATE(9474)] = 447913,
  [SMALL_STATE(9475)] = 447955,
  [SMALL_STATE(9476)] = 448027,
  [SMALL_STATE(9477)] = 448071,
  [SMALL_STATE(9478)] = 448143,
  [SMALL_STATE(9479)] = 448211,
  [SMALL_STATE(9480)] = 448283,
  [SMALL_STATE(9481)] = 448329,
  [SMALL_STATE(9482)] = 448385,
  [SMALL_STATE(9483)] = 448457,
  [SMALL_STATE(9484)] = 448499,
  [SMALL_STATE(9485)] = 448557,
  [SMALL_STATE(9486)] = 448615,
  [SMALL_STATE(9487)] = 448673,
  [SMALL_STATE(9488)] = 448715,
  [SMALL_STATE(9489)] = 448787,
  [SMALL_STATE(9490)] = 448859,
  [SMALL_STATE(9491)] = 448931,
  [SMALL_STATE(9492)] = 448973,
  [SMALL_STATE(9493)] = 449029,
  [SMALL_STATE(9494)] = 449085,
  [SMALL_STATE(9495)] = 449157,
  [SMALL_STATE(9496)] = 449229,
  [SMALL_STATE(9497)] = 449271,
  [SMALL_STATE(9498)] = 449343,
  [SMALL_STATE(9499)] = 449415,
  [SMALL_STATE(9500)] = 449487,
  [SMALL_STATE(9501)] = 449559,
  [SMALL_STATE(9502)] = 449631,
  [SMALL_STATE(9503)] = 449703,
  [SMALL_STATE(9504)] = 449745,
  [SMALL_STATE(9505)] = 449787,
  [SMALL_STATE(9506)] = 449859,
  [SMALL_STATE(9507)] = 449931,
  [SMALL_STATE(9508)] = 450003,
  [SMALL_STATE(9509)] = 450075,
  [SMALL_STATE(9510)] = 450147,
  [SMALL_STATE(9511)] = 450205,
  [SMALL_STATE(9512)] = 450277,
  [SMALL_STATE(9513)] = 450349,
  [SMALL_STATE(9514)] = 450421,
  [SMALL_STATE(9515)] = 450493,
  [SMALL_STATE(9516)] = 450565,
  [SMALL_STATE(9517)] = 450637,
  [SMALL_STATE(9518)] = 450709,
  [SMALL_STATE(9519)] = 450751,
  [SMALL_STATE(9520)] = 450807,
  [SMALL_STATE(9521)] = 450879,
  [SMALL_STATE(9522)] = 450951,
  [SMALL_STATE(9523)] = 451023,
  [SMALL_STATE(9524)] = 451081,
  [SMALL_STATE(9525)] = 451139,
  [SMALL_STATE(9526)] = 451211,
  [SMALL_STATE(9527)] = 451281,
  [SMALL_STATE(9528)] = 451353,
  [SMALL_STATE(9529)] = 451425,
  [SMALL_STATE(9530)] = 451483,
  [SMALL_STATE(9531)] = 451555,
  [SMALL_STATE(9532)] = 451627,
  [SMALL_STATE(9533)] = 451669,
  [SMALL_STATE(9534)] = 451741,
  [SMALL_STATE(9535)] = 451813,
  [SMALL_STATE(9536)] = 451885,
  [SMALL_STATE(9537)] = 451957,
  [SMALL_STATE(9538)] = 452029,
  [SMALL_STATE(9539)] = 452071,
  [SMALL_STATE(9540)] = 452113,
  [SMALL_STATE(9541)] = 452165,
  [SMALL_STATE(9542)] = 452237,
  [SMALL_STATE(9543)] = 452309,
  [SMALL_STATE(9544)] = 452357,
  [SMALL_STATE(9545)] = 452429,
  [SMALL_STATE(9546)] = 452501,
  [SMALL_STATE(9547)] = 452573,
  [SMALL_STATE(9548)] = 452645,
  [SMALL_STATE(9549)] = 452717,
  [SMALL_STATE(9550)] = 452789,
  [SMALL_STATE(9551)] = 452843,
  [SMALL_STATE(9552)] = 452915,
  [SMALL_STATE(9553)] = 452973,
  [SMALL_STATE(9554)] = 453045,
  [SMALL_STATE(9555)] = 453117,
  [SMALL_STATE(9556)] = 453189,
  [SMALL_STATE(9557)] = 453261,
  [SMALL_STATE(9558)] = 453305,
  [SMALL_STATE(9559)] = 453377,
  [SMALL_STATE(9560)] = 453449,
  [SMALL_STATE(9561)] = 453521,
  [SMALL_STATE(9562)] = 453593,
  [SMALL_STATE(9563)] = 453665,
  [SMALL_STATE(9564)] = 453737,
  [SMALL_STATE(9565)] = 453809,
  [SMALL_STATE(9566)] = 453867,
  [SMALL_STATE(9567)] = 453909,
  [SMALL_STATE(9568)] = 453981,
  [SMALL_STATE(9569)] = 454053,
  [SMALL_STATE(9570)] = 454125,
  [SMALL_STATE(9571)] = 454167,
  [SMALL_STATE(9572)] = 454239,
  [SMALL_STATE(9573)] = 454297,
  [SMALL_STATE(9574)] = 454369,
  [SMALL_STATE(9575)] = 454441,
  [SMALL_STATE(9576)] = 454513,
  [SMALL_STATE(9577)] = 454585,
  [SMALL_STATE(9578)] = 454657,
  [SMALL_STATE(9579)] = 454705,
  [SMALL_STATE(9580)] = 454749,
  [SMALL_STATE(9581)] = 454791,
  [SMALL_STATE(9582)] = 454863,
  [SMALL_STATE(9583)] = 454935,
  [SMALL_STATE(9584)] = 454977,
  [SMALL_STATE(9585)] = 455049,
  [SMALL_STATE(9586)] = 455091,
  [SMALL_STATE(9587)] = 455163,
  [SMALL_STATE(9588)] = 455205,
  [SMALL_STATE(9589)] = 455277,
  [SMALL_STATE(9590)] = 455349,
  [SMALL_STATE(9591)] = 455421,
  [SMALL_STATE(9592)] = 455493,
  [SMALL_STATE(9593)] = 455565,
  [SMALL_STATE(9594)] = 455617,
  [SMALL_STATE(9595)] = 455659,
  [SMALL_STATE(9596)] = 455731,
  [SMALL_STATE(9597)] = 455803,
  [SMALL_STATE(9598)] = 455845,
  [SMALL_STATE(9599)] = 455917,
  [SMALL_STATE(9600)] = 455989,
  [SMALL_STATE(9601)] = 456061,
  [SMALL_STATE(9602)] = 456133,
  [SMALL_STATE(9603)] = 456201,
  [SMALL_STATE(9604)] = 456273,
  [SMALL_STATE(9605)] = 456345,
  [SMALL_STATE(9606)] = 456417,
  [SMALL_STATE(9607)] = 456489,
  [SMALL_STATE(9608)] = 456561,
  [SMALL_STATE(9609)] = 456603,
  [SMALL_STATE(9610)] = 456645,
  [SMALL_STATE(9611)] = 456687,
  [SMALL_STATE(9612)] = 456729,
  [SMALL_STATE(9613)] = 456801,
  [SMALL_STATE(9614)] = 456873,
  [SMALL_STATE(9615)] = 456945,
  [SMALL_STATE(9616)] = 457017,
  [SMALL_STATE(9617)] = 457059,
  [SMALL_STATE(9618)] = 457131,
  [SMALL_STATE(9619)] = 457203,
  [SMALL_STATE(9620)] = 457259,
  [SMALL_STATE(9621)] = 457331,
  [SMALL_STATE(9622)] = 457403,
  [SMALL_STATE(9623)] = 457475,
  [SMALL_STATE(9624)] = 457517,
  [SMALL_STATE(9625)] = 457559,
  [SMALL_STATE(9626)] = 457627,
  [SMALL_STATE(9627)] = 457699,
  [SMALL_STATE(9628)] = 457769,
  [SMALL_STATE(9629)] = 457811,
  [SMALL_STATE(9630)] = 457853,
  [SMALL_STATE(9631)] = 457925,
  [SMALL_STATE(9632)] = 457997,
  [SMALL_STATE(9633)] = 458067,
  [SMALL_STATE(9634)] = 458139,
  [SMALL_STATE(9635)] = 458211,
  [SMALL_STATE(9636)] = 458283,
  [SMALL_STATE(9637)] = 458325,
  [SMALL_STATE(9638)] = 458367,
  [SMALL_STATE(9639)] = 458439,
  [SMALL_STATE(9640)] = 458481,
  [SMALL_STATE(9641)] = 458523,
  [SMALL_STATE(9642)] = 458595,
  [SMALL_STATE(9643)] = 458637,
  [SMALL_STATE(9644)] = 458679,
  [SMALL_STATE(9645)] = 458721,
  [SMALL_STATE(9646)] = 458793,
  [SMALL_STATE(9647)] = 458835,
  [SMALL_STATE(9648)] = 458877,
  [SMALL_STATE(9649)] = 458919,
  [SMALL_STATE(9650)] = 458961,
  [SMALL_STATE(9651)] = 459003,
  [SMALL_STATE(9652)] = 459045,
  [SMALL_STATE(9653)] = 459087,
  [SMALL_STATE(9654)] = 459143,
  [SMALL_STATE(9655)] = 459215,
  [SMALL_STATE(9656)] = 459287,
  [SMALL_STATE(9657)] = 459359,
  [SMALL_STATE(9658)] = 459431,
  [SMALL_STATE(9659)] = 459473,
  [SMALL_STATE(9660)] = 459515,
  [SMALL_STATE(9661)] = 459557,
  [SMALL_STATE(9662)] = 459629,
  [SMALL_STATE(9663)] = 459671,
  [SMALL_STATE(9664)] = 459743,
  [SMALL_STATE(9665)] = 459785,
  [SMALL_STATE(9666)] = 459827,
  [SMALL_STATE(9667)] = 459869,
  [SMALL_STATE(9668)] = 459911,
  [SMALL_STATE(9669)] = 459955,
  [SMALL_STATE(9670)] = 459997,
  [SMALL_STATE(9671)] = 460039,
  [SMALL_STATE(9672)] = 460111,
  [SMALL_STATE(9673)] = 460153,
  [SMALL_STATE(9674)] = 460195,
  [SMALL_STATE(9675)] = 460237,
  [SMALL_STATE(9676)] = 460279,
  [SMALL_STATE(9677)] = 460321,
  [SMALL_STATE(9678)] = 460363,
  [SMALL_STATE(9679)] = 460405,
  [SMALL_STATE(9680)] = 460477,
  [SMALL_STATE(9681)] = 460519,
  [SMALL_STATE(9682)] = 460591,
  [SMALL_STATE(9683)] = 460633,
  [SMALL_STATE(9684)] = 460675,
  [SMALL_STATE(9685)] = 460717,
  [SMALL_STATE(9686)] = 460759,
  [SMALL_STATE(9687)] = 460801,
  [SMALL_STATE(9688)] = 460843,
  [SMALL_STATE(9689)] = 460885,
  [SMALL_STATE(9690)] = 460957,
  [SMALL_STATE(9691)] = 461029,
  [SMALL_STATE(9692)] = 461071,
  [SMALL_STATE(9693)] = 461113,
  [SMALL_STATE(9694)] = 461155,
  [SMALL_STATE(9695)] = 461197,
  [SMALL_STATE(9696)] = 461239,
  [SMALL_STATE(9697)] = 461281,
  [SMALL_STATE(9698)] = 461323,
  [SMALL_STATE(9699)] = 461365,
  [SMALL_STATE(9700)] = 461407,
  [SMALL_STATE(9701)] = 461479,
  [SMALL_STATE(9702)] = 461551,
  [SMALL_STATE(9703)] = 461593,
  [SMALL_STATE(9704)] = 461635,
  [SMALL_STATE(9705)] = 461677,
  [SMALL_STATE(9706)] = 461719,
  [SMALL_STATE(9707)] = 461791,
  [SMALL_STATE(9708)] = 461863,
  [SMALL_STATE(9709)] = 461935,
  [SMALL_STATE(9710)] = 461977,
  [SMALL_STATE(9711)] = 462049,
  [SMALL_STATE(9712)] = 462121,
  [SMALL_STATE(9713)] = 462193,
  [SMALL_STATE(9714)] = 462241,
  [SMALL_STATE(9715)] = 462289,
  [SMALL_STATE(9716)] = 462337,
  [SMALL_STATE(9717)] = 462385,
  [SMALL_STATE(9718)] = 462433,
  [SMALL_STATE(9719)] = 462505,
  [SMALL_STATE(9720)] = 462577,
  [SMALL_STATE(9721)] = 462646,
  [SMALL_STATE(9722)] = 462715,
  [SMALL_STATE(9723)] = 462784,
  [SMALL_STATE(9724)] = 462825,
  [SMALL_STATE(9725)] = 462882,
  [SMALL_STATE(9726)] = 462923,
  [SMALL_STATE(9727)] = 462980,
  [SMALL_STATE(9728)] = 463021,
  [SMALL_STATE(9729)] = 463062,
  [SMALL_STATE(9730)] = 463103,
  [SMALL_STATE(9731)] = 463144,
  [SMALL_STATE(9732)] = 463185,
  [SMALL_STATE(9733)] = 463254,
  [SMALL_STATE(9734)] = 463323,
  [SMALL_STATE(9735)] = 463364,
  [SMALL_STATE(9736)] = 463433,
  [SMALL_STATE(9737)] = 463474,
  [SMALL_STATE(9738)] = 463531,
  [SMALL_STATE(9739)] = 463572,
  [SMALL_STATE(9740)] = 463613,
  [SMALL_STATE(9741)] = 463654,
  [SMALL_STATE(9742)] = 463695,
  [SMALL_STATE(9743)] = 463736,
  [SMALL_STATE(9744)] = 463793,
  [SMALL_STATE(9745)] = 463834,
  [SMALL_STATE(9746)] = 463891,
  [SMALL_STATE(9747)] = 463932,
  [SMALL_STATE(9748)] = 463993,
  [SMALL_STATE(9749)] = 464034,
  [SMALL_STATE(9750)] = 464103,
  [SMALL_STATE(9751)] = 464160,
  [SMALL_STATE(9752)] = 464217,
  [SMALL_STATE(9753)] = 464276,
  [SMALL_STATE(9754)] = 464317,
  [SMALL_STATE(9755)] = 464358,
  [SMALL_STATE(9756)] = 464399,
  [SMALL_STATE(9757)] = 464440,
  [SMALL_STATE(9758)] = 464481,
  [SMALL_STATE(9759)] = 464550,
  [SMALL_STATE(9760)] = 464619,
  [SMALL_STATE(9761)] = 464660,
  [SMALL_STATE(9762)] = 464729,
  [SMALL_STATE(9763)] = 464770,
  [SMALL_STATE(9764)] = 464811,
  [SMALL_STATE(9765)] = 464852,
  [SMALL_STATE(9766)] = 464893,
  [SMALL_STATE(9767)] = 464934,
  [SMALL_STATE(9768)] = 464975,
  [SMALL_STATE(9769)] = 465044,
  [SMALL_STATE(9770)] = 465085,
  [SMALL_STATE(9771)] = 465150,
  [SMALL_STATE(9772)] = 465215,
  [SMALL_STATE(9773)] = 465272,
  [SMALL_STATE(9774)] = 465317,
  [SMALL_STATE(9775)] = 465374,
  [SMALL_STATE(9776)] = 465415,
  [SMALL_STATE(9777)] = 465456,
  [SMALL_STATE(9778)] = 465525,
  [SMALL_STATE(9779)] = 465566,
  [SMALL_STATE(9780)] = 465607,
  [SMALL_STATE(9781)] = 465668,
  [SMALL_STATE(9782)] = 465737,
  [SMALL_STATE(9783)] = 465778,
  [SMALL_STATE(9784)] = 465819,
  [SMALL_STATE(9785)] = 465888,
  [SMALL_STATE(9786)] = 465957,
  [SMALL_STATE(9787)] = 466026,
  [SMALL_STATE(9788)] = 466095,
  [SMALL_STATE(9789)] = 466152,
  [SMALL_STATE(9790)] = 466193,
  [SMALL_STATE(9791)] = 466234,
  [SMALL_STATE(9792)] = 466275,
  [SMALL_STATE(9793)] = 466344,
  [SMALL_STATE(9794)] = 466395,
  [SMALL_STATE(9795)] = 466436,
  [SMALL_STATE(9796)] = 466477,
  [SMALL_STATE(9797)] = 466518,
  [SMALL_STATE(9798)] = 466583,
  [SMALL_STATE(9799)] = 466624,
  [SMALL_STATE(9800)] = 466695,
  [SMALL_STATE(9801)] = 466736,
  [SMALL_STATE(9802)] = 466777,
  [SMALL_STATE(9803)] = 466838,
  [SMALL_STATE(9804)] = 466883,
  [SMALL_STATE(9805)] = 466940,
  [SMALL_STATE(9806)] = 466997,
  [SMALL_STATE(9807)] = 467038,
  [SMALL_STATE(9808)] = 467079,
  [SMALL_STATE(9809)] = 467122,
  [SMALL_STATE(9810)] = 467163,
  [SMALL_STATE(9811)] = 467204,
  [SMALL_STATE(9812)] = 467273,
  [SMALL_STATE(9813)] = 467342,
  [SMALL_STATE(9814)] = 467399,
  [SMALL_STATE(9815)] = 467440,
  [SMALL_STATE(9816)] = 467509,
  [SMALL_STATE(9817)] = 467550,
  [SMALL_STATE(9818)] = 467591,
  [SMALL_STATE(9819)] = 467632,
  [SMALL_STATE(9820)] = 467673,
  [SMALL_STATE(9821)] = 467714,
  [SMALL_STATE(9822)] = 467755,
  [SMALL_STATE(9823)] = 467824,
  [SMALL_STATE(9824)] = 467865,
  [SMALL_STATE(9825)] = 467926,
  [SMALL_STATE(9826)] = 467985,
  [SMALL_STATE(9827)] = 468054,
  [SMALL_STATE(9828)] = 468095,
  [SMALL_STATE(9829)] = 468136,
  [SMALL_STATE(9830)] = 468205,
  [SMALL_STATE(9831)] = 468274,
  [SMALL_STATE(9832)] = 468343,
  [SMALL_STATE(9833)] = 468398,
  [SMALL_STATE(9834)] = 468467,
  [SMALL_STATE(9835)] = 468536,
  [SMALL_STATE(9836)] = 468605,
  [SMALL_STATE(9837)] = 468646,
  [SMALL_STATE(9838)] = 468687,
  [SMALL_STATE(9839)] = 468756,
  [SMALL_STATE(9840)] = 468825,
  [SMALL_STATE(9841)] = 468880,
  [SMALL_STATE(9842)] = 468921,
  [SMALL_STATE(9843)] = 468990,
  [SMALL_STATE(9844)] = 469031,
  [SMALL_STATE(9845)] = 469072,
  [SMALL_STATE(9846)] = 469115,
  [SMALL_STATE(9847)] = 469156,
  [SMALL_STATE(9848)] = 469197,
  [SMALL_STATE(9849)] = 469260,
  [SMALL_STATE(9850)] = 469329,
  [SMALL_STATE(9851)] = 469370,
  [SMALL_STATE(9852)] = 469431,
  [SMALL_STATE(9853)] = 469482,
  [SMALL_STATE(9854)] = 469527,
  [SMALL_STATE(9855)] = 469572,
  [SMALL_STATE(9856)] = 469625,
  [SMALL_STATE(9857)] = 469678,
  [SMALL_STATE(9858)] = 469735,
  [SMALL_STATE(9859)] = 469794,
  [SMALL_STATE(9860)] = 469857,
  [SMALL_STATE(9861)] = 469926,
  [SMALL_STATE(9862)] = 469973,
  [SMALL_STATE(9863)] = 470042,
  [SMALL_STATE(9864)] = 470105,
  [SMALL_STATE(9865)] = 470150,
  [SMALL_STATE(9866)] = 470193,
  [SMALL_STATE(9867)] = 470256,
  [SMALL_STATE(9868)] = 470325,
  [SMALL_STATE(9869)] = 470366,
  [SMALL_STATE(9870)] = 470435,
  [SMALL_STATE(9871)] = 470478,
  [SMALL_STATE(9872)] = 470537,
  [SMALL_STATE(9873)] = 470578,
  [SMALL_STATE(9874)] = 470619,
  [SMALL_STATE(9875)] = 470660,
  [SMALL_STATE(9876)] = 470701,
  [SMALL_STATE(9877)] = 470742,
  [SMALL_STATE(9878)] = 470783,
  [SMALL_STATE(9879)] = 470824,
  [SMALL_STATE(9880)] = 470865,
  [SMALL_STATE(9881)] = 470908,
  [SMALL_STATE(9882)] = 470953,
  [SMALL_STATE(9883)] = 471012,
  [SMALL_STATE(9884)] = 471053,
  [SMALL_STATE(9885)] = 471122,
  [SMALL_STATE(9886)] = 471177,
  [SMALL_STATE(9887)] = 471220,
  [SMALL_STATE(9888)] = 471261,
  [SMALL_STATE(9889)] = 471302,
  [SMALL_STATE(9890)] = 471343,
  [SMALL_STATE(9891)] = 471384,
  [SMALL_STATE(9892)] = 471425,
  [SMALL_STATE(9893)] = 471466,
  [SMALL_STATE(9894)] = 471507,
  [SMALL_STATE(9895)] = 471548,
  [SMALL_STATE(9896)] = 471589,
  [SMALL_STATE(9897)] = 471658,
  [SMALL_STATE(9898)] = 471699,
  [SMALL_STATE(9899)] = 471752,
  [SMALL_STATE(9900)] = 471793,
  [SMALL_STATE(9901)] = 471862,
  [SMALL_STATE(9902)] = 471931,
  [SMALL_STATE(9903)] = 471988,
  [SMALL_STATE(9904)] = 472029,
  [SMALL_STATE(9905)] = 472070,
  [SMALL_STATE(9906)] = 472113,
  [SMALL_STATE(9907)] = 472154,
  [SMALL_STATE(9908)] = 472195,
  [SMALL_STATE(9909)] = 472236,
  [SMALL_STATE(9910)] = 472279,
  [SMALL_STATE(9911)] = 472336,
  [SMALL_STATE(9912)] = 472405,
  [SMALL_STATE(9913)] = 472446,
  [SMALL_STATE(9914)] = 472491,
  [SMALL_STATE(9915)] = 472532,
  [SMALL_STATE(9916)] = 472573,
  [SMALL_STATE(9917)] = 472630,
  [SMALL_STATE(9918)] = 472699,
  [SMALL_STATE(9919)] = 472740,
  [SMALL_STATE(9920)] = 472781,
  [SMALL_STATE(9921)] = 472822,
  [SMALL_STATE(9922)] = 472867,
  [SMALL_STATE(9923)] = 472912,
  [SMALL_STATE(9924)] = 472957,
  [SMALL_STATE(9925)] = 473002,
  [SMALL_STATE(9926)] = 473045,
  [SMALL_STATE(9927)] = 473096,
  [SMALL_STATE(9928)] = 473137,
  [SMALL_STATE(9929)] = 473206,
  [SMALL_STATE(9930)] = 473275,
  [SMALL_STATE(9931)] = 473344,
  [SMALL_STATE(9932)] = 473413,
  [SMALL_STATE(9933)] = 473454,
  [SMALL_STATE(9934)] = 473495,
  [SMALL_STATE(9935)] = 473536,
  [SMALL_STATE(9936)] = 473577,
  [SMALL_STATE(9937)] = 473618,
  [SMALL_STATE(9938)] = 473675,
  [SMALL_STATE(9939)] = 473716,
  [SMALL_STATE(9940)] = 473785,
  [SMALL_STATE(9941)] = 473828,
  [SMALL_STATE(9942)] = 473869,
  [SMALL_STATE(9943)] = 473926,
  [SMALL_STATE(9944)] = 473967,
  [SMALL_STATE(9945)] = 474013,
  [SMALL_STATE(9946)] = 474053,
  [SMALL_STATE(9947)] = 474099,
  [SMALL_STATE(9948)] = 474139,
  [SMALL_STATE(9949)] = 474179,
  [SMALL_STATE(9950)] = 474219,
  [SMALL_STATE(9951)] = 474275,
  [SMALL_STATE(9952)] = 474341,
  [SMALL_STATE(9953)] = 474381,
  [SMALL_STATE(9954)] = 474421,
  [SMALL_STATE(9955)] = 474489,
  [SMALL_STATE(9956)] = 474557,
  [SMALL_STATE(9957)] = 474597,
  [SMALL_STATE(9958)] = 474637,
  [SMALL_STATE(9959)] = 474677,
  [SMALL_STATE(9960)] = 474717,
  [SMALL_STATE(9961)] = 474761,
  [SMALL_STATE(9962)] = 474805,
  [SMALL_STATE(9963)] = 474849,
  [SMALL_STATE(9964)] = 474893,
  [SMALL_STATE(9965)] = 474935,
  [SMALL_STATE(9966)] = 474991,
  [SMALL_STATE(9967)] = 475031,
  [SMALL_STATE(9968)] = 475071,
  [SMALL_STATE(9969)] = 475139,
  [SMALL_STATE(9970)] = 475179,
  [SMALL_STATE(9971)] = 475219,
  [SMALL_STATE(9972)] = 475259,
  [SMALL_STATE(9973)] = 475299,
  [SMALL_STATE(9974)] = 475339,
  [SMALL_STATE(9975)] = 475407,
  [SMALL_STATE(9976)] = 475475,
  [SMALL_STATE(9977)] = 475515,
  [SMALL_STATE(9978)] = 475555,
  [SMALL_STATE(9979)] = 475595,
  [SMALL_STATE(9980)] = 475637,
  [SMALL_STATE(9981)] = 475677,
  [SMALL_STATE(9982)] = 475745,
  [SMALL_STATE(9983)] = 475785,
  [SMALL_STATE(9984)] = 475825,
  [SMALL_STATE(9985)] = 475893,
  [SMALL_STATE(9986)] = 475939,
  [SMALL_STATE(9987)] = 475985,
  [SMALL_STATE(9988)] = 476031,
  [SMALL_STATE(9989)] = 476071,
  [SMALL_STATE(9990)] = 476113,
  [SMALL_STATE(9991)] = 476153,
  [SMALL_STATE(9992)] = 476193,
  [SMALL_STATE(9993)] = 476247,
  [SMALL_STATE(9994)] = 476307,
  [SMALL_STATE(9995)] = 476357,
  [SMALL_STATE(9996)] = 476407,
  [SMALL_STATE(9997)] = 476451,
  [SMALL_STATE(9998)] = 476491,
  [SMALL_STATE(9999)] = 476531,
  [SMALL_STATE(10000)] = 476571,
  [SMALL_STATE(10001)] = 476611,
  [SMALL_STATE(10002)] = 476669,
  [SMALL_STATE(10003)] = 476713,
  [SMALL_STATE(10004)] = 476765,
  [SMALL_STATE(10005)] = 476817,
  [SMALL_STATE(10006)] = 476873,
  [SMALL_STATE(10007)] = 476931,
  [SMALL_STATE(10008)] = 476993,
  [SMALL_STATE(10009)] = 477039,
  [SMALL_STATE(10010)] = 477101,
  [SMALL_STATE(10011)] = 477141,
  [SMALL_STATE(10012)] = 477183,
  [SMALL_STATE(10013)] = 477223,
  [SMALL_STATE(10014)] = 477287,
  [SMALL_STATE(10015)] = 477327,
  [SMALL_STATE(10016)] = 477367,
  [SMALL_STATE(10017)] = 477429,
  [SMALL_STATE(10018)] = 477469,
  [SMALL_STATE(10019)] = 477509,
  [SMALL_STATE(10020)] = 477549,
  [SMALL_STATE(10021)] = 477605,
  [SMALL_STATE(10022)] = 477645,
  [SMALL_STATE(10023)] = 477685,
  [SMALL_STATE(10024)] = 477753,
  [SMALL_STATE(10025)] = 477793,
  [SMALL_STATE(10026)] = 477861,
  [SMALL_STATE(10027)] = 477929,
  [SMALL_STATE(10028)] = 477997,
  [SMALL_STATE(10029)] = 478065,
  [SMALL_STATE(10030)] = 478105,
  [SMALL_STATE(10031)] = 478173,
  [SMALL_STATE(10032)] = 478213,
  [SMALL_STATE(10033)] = 478255,
  [SMALL_STATE(10034)] = 478323,
  [SMALL_STATE(10035)] = 478363,
  [SMALL_STATE(10036)] = 478403,
  [SMALL_STATE(10037)] = 478471,
  [SMALL_STATE(10038)] = 478511,
  [SMALL_STATE(10039)] = 478551,
  [SMALL_STATE(10040)] = 478591,
  [SMALL_STATE(10041)] = 478631,
  [SMALL_STATE(10042)] = 478671,
  [SMALL_STATE(10043)] = 478739,
  [SMALL_STATE(10044)] = 478779,
  [SMALL_STATE(10045)] = 478847,
  [SMALL_STATE(10046)] = 478897,
  [SMALL_STATE(10047)] = 478937,
  [SMALL_STATE(10048)] = 478977,
  [SMALL_STATE(10049)] = 479017,
  [SMALL_STATE(10050)] = 479073,
  [SMALL_STATE(10051)] = 479129,
  [SMALL_STATE(10052)] = 479197,
  [SMALL_STATE(10053)] = 479265,
  [SMALL_STATE(10054)] = 479305,
  [SMALL_STATE(10055)] = 479345,
  [SMALL_STATE(10056)] = 479385,
  [SMALL_STATE(10057)] = 479425,
  [SMALL_STATE(10058)] = 479481,
  [SMALL_STATE(10059)] = 479539,
  [SMALL_STATE(10060)] = 479589,
  [SMALL_STATE(10061)] = 479657,
  [SMALL_STATE(10062)] = 479697,
  [SMALL_STATE(10063)] = 479737,
  [SMALL_STATE(10064)] = 479777,
  [SMALL_STATE(10065)] = 479817,
  [SMALL_STATE(10066)] = 479857,
  [SMALL_STATE(10067)] = 479925,
  [SMALL_STATE(10068)] = 479993,
  [SMALL_STATE(10069)] = 480033,
  [SMALL_STATE(10070)] = 480073,
  [SMALL_STATE(10071)] = 480113,
  [SMALL_STATE(10072)] = 480153,
  [SMALL_STATE(10073)] = 480193,
  [SMALL_STATE(10074)] = 480233,
  [SMALL_STATE(10075)] = 480273,
  [SMALL_STATE(10076)] = 480329,
  [SMALL_STATE(10077)] = 480369,
  [SMALL_STATE(10078)] = 480409,
  [SMALL_STATE(10079)] = 480449,
  [SMALL_STATE(10080)] = 480489,
  [SMALL_STATE(10081)] = 480545,
  [SMALL_STATE(10082)] = 480585,
  [SMALL_STATE(10083)] = 480625,
  [SMALL_STATE(10084)] = 480665,
  [SMALL_STATE(10085)] = 480705,
  [SMALL_STATE(10086)] = 480773,
  [SMALL_STATE(10087)] = 480841,
  [SMALL_STATE(10088)] = 480881,
  [SMALL_STATE(10089)] = 480921,
  [SMALL_STATE(10090)] = 480985,
  [SMALL_STATE(10091)] = 481049,
  [SMALL_STATE(10092)] = 481095,
  [SMALL_STATE(10093)] = 481141,
  [SMALL_STATE(10094)] = 481181,
  [SMALL_STATE(10095)] = 481249,
  [SMALL_STATE(10096)] = 481317,
  [SMALL_STATE(10097)] = 481369,
  [SMALL_STATE(10098)] = 481437,
  [SMALL_STATE(10099)] = 481477,
  [SMALL_STATE(10100)] = 481517,
  [SMALL_STATE(10101)] = 481557,
  [SMALL_STATE(10102)] = 481597,
  [SMALL_STATE(10103)] = 481657,
  [SMALL_STATE(10104)] = 481697,
  [SMALL_STATE(10105)] = 481747,
  [SMALL_STATE(10106)] = 481791,
  [SMALL_STATE(10107)] = 481859,
  [SMALL_STATE(10108)] = 481903,
  [SMALL_STATE(10109)] = 481955,
  [SMALL_STATE(10110)] = 482007,
  [SMALL_STATE(10111)] = 482047,
  [SMALL_STATE(10112)] = 482115,
  [SMALL_STATE(10113)] = 482155,
  [SMALL_STATE(10114)] = 482195,
  [SMALL_STATE(10115)] = 482251,
  [SMALL_STATE(10116)] = 482309,
  [SMALL_STATE(10117)] = 482371,
  [SMALL_STATE(10118)] = 482417,
  [SMALL_STATE(10119)] = 482459,
  [SMALL_STATE(10120)] = 482503,
  [SMALL_STATE(10121)] = 482565,
  [SMALL_STATE(10122)] = 482609,
  [SMALL_STATE(10123)] = 482671,
  [SMALL_STATE(10124)] = 482711,
  [SMALL_STATE(10125)] = 482779,
  [SMALL_STATE(10126)] = 482847,
  [SMALL_STATE(10127)] = 482887,
  [SMALL_STATE(10128)] = 482927,
  [SMALL_STATE(10129)] = 482969,
  [SMALL_STATE(10130)] = 483009,
  [SMALL_STATE(10131)] = 483049,
  [SMALL_STATE(10132)] = 483117,
  [SMALL_STATE(10133)] = 483161,
  [SMALL_STATE(10134)] = 483229,
  [SMALL_STATE(10135)] = 483297,
  [SMALL_STATE(10136)] = 483337,
  [SMALL_STATE(10137)] = 483377,
  [SMALL_STATE(10138)] = 483417,
  [SMALL_STATE(10139)] = 483457,
  [SMALL_STATE(10140)] = 483503,
  [SMALL_STATE(10141)] = 483543,
  [SMALL_STATE(10142)] = 483611,
  [SMALL_STATE(10143)] = 483679,
  [SMALL_STATE(10144)] = 483733,
  [SMALL_STATE(10145)] = 483773,
  [SMALL_STATE(10146)] = 483813,
  [SMALL_STATE(10147)] = 483869,
  [SMALL_STATE(10148)] = 483923,
  [SMALL_STATE(10149)] = 483991,
  [SMALL_STATE(10150)] = 484059,
  [SMALL_STATE(10151)] = 484099,
  [SMALL_STATE(10152)] = 484139,
  [SMALL_STATE(10153)] = 484207,
  [SMALL_STATE(10154)] = 484275,
  [SMALL_STATE(10155)] = 484343,
  [SMALL_STATE(10156)] = 484411,
  [SMALL_STATE(10157)] = 484479,
  [SMALL_STATE(10158)] = 484519,
  [SMALL_STATE(10159)] = 484587,
  [SMALL_STATE(10160)] = 484627,
  [SMALL_STATE(10161)] = 484695,
  [SMALL_STATE(10162)] = 484763,
  [SMALL_STATE(10163)] = 484831,
  [SMALL_STATE(10164)] = 484871,
  [SMALL_STATE(10165)] = 484911,
  [SMALL_STATE(10166)] = 484951,
  [SMALL_STATE(10167)] = 485019,
  [SMALL_STATE(10168)] = 485059,
  [SMALL_STATE(10169)] = 485099,
  [SMALL_STATE(10170)] = 485139,
  [SMALL_STATE(10171)] = 485207,
  [SMALL_STATE(10172)] = 485247,
  [SMALL_STATE(10173)] = 485301,
  [SMALL_STATE(10174)] = 485341,
  [SMALL_STATE(10175)] = 485381,
  [SMALL_STATE(10176)] = 485449,
  [SMALL_STATE(10177)] = 485489,
  [SMALL_STATE(10178)] = 485529,
  [SMALL_STATE(10179)] = 485597,
  [SMALL_STATE(10180)] = 485665,
  [SMALL_STATE(10181)] = 485733,
  [SMALL_STATE(10182)] = 485785,
  [SMALL_STATE(10183)] = 485853,
  [SMALL_STATE(10184)] = 485921,
  [SMALL_STATE(10185)] = 485961,
  [SMALL_STATE(10186)] = 486001,
  [SMALL_STATE(10187)] = 486041,
  [SMALL_STATE(10188)] = 486081,
  [SMALL_STATE(10189)] = 486121,
  [SMALL_STATE(10190)] = 486189,
  [SMALL_STATE(10191)] = 486257,
  [SMALL_STATE(10192)] = 486325,
  [SMALL_STATE(10193)] = 486393,
  [SMALL_STATE(10194)] = 486461,
  [SMALL_STATE(10195)] = 486501,
  [SMALL_STATE(10196)] = 486541,
  [SMALL_STATE(10197)] = 486609,
  [SMALL_STATE(10198)] = 486661,
  [SMALL_STATE(10199)] = 486729,
  [SMALL_STATE(10200)] = 486769,
  [SMALL_STATE(10201)] = 486837,
  [SMALL_STATE(10202)] = 486905,
  [SMALL_STATE(10203)] = 486973,
  [SMALL_STATE(10204)] = 487041,
  [SMALL_STATE(10205)] = 487081,
  [SMALL_STATE(10206)] = 487149,
  [SMALL_STATE(10207)] = 487217,
  [SMALL_STATE(10208)] = 487285,
  [SMALL_STATE(10209)] = 487341,
  [SMALL_STATE(10210)] = 487397,
  [SMALL_STATE(10211)] = 487465,
  [SMALL_STATE(10212)] = 487533,
  [SMALL_STATE(10213)] = 487601,
  [SMALL_STATE(10214)] = 487669,
  [SMALL_STATE(10215)] = 487737,
  [SMALL_STATE(10216)] = 487777,
  [SMALL_STATE(10217)] = 487817,
  [SMALL_STATE(10218)] = 487857,
  [SMALL_STATE(10219)] = 487897,
  [SMALL_STATE(10220)] = 487937,
  [SMALL_STATE(10221)] = 488005,
  [SMALL_STATE(10222)] = 488073,
  [SMALL_STATE(10223)] = 488141,
  [SMALL_STATE(10224)] = 488209,
  [SMALL_STATE(10225)] = 488253,
  [SMALL_STATE(10226)] = 488321,
  [SMALL_STATE(10227)] = 488389,
  [SMALL_STATE(10228)] = 488429,
  [SMALL_STATE(10229)] = 488491,
  [SMALL_STATE(10230)] = 488531,
  [SMALL_STATE(10231)] = 488599,
  [SMALL_STATE(10232)] = 488639,
  [SMALL_STATE(10233)] = 488679,
  [SMALL_STATE(10234)] = 488719,
  [SMALL_STATE(10235)] = 488759,
  [SMALL_STATE(10236)] = 488799,
  [SMALL_STATE(10237)] = 488841,
  [SMALL_STATE(10238)] = 488887,
  [SMALL_STATE(10239)] = 488927,
  [SMALL_STATE(10240)] = 488967,
  [SMALL_STATE(10241)] = 489035,
  [SMALL_STATE(10242)] = 489081,
  [SMALL_STATE(10243)] = 489149,
  [SMALL_STATE(10244)] = 489217,
  [SMALL_STATE(10245)] = 489285,
  [SMALL_STATE(10246)] = 489325,
  [SMALL_STATE(10247)] = 489393,
  [SMALL_STATE(10248)] = 489433,
  [SMALL_STATE(10249)] = 489473,
  [SMALL_STATE(10250)] = 489541,
  [SMALL_STATE(10251)] = 489581,
  [SMALL_STATE(10252)] = 489621,
  [SMALL_STATE(10253)] = 489689,
  [SMALL_STATE(10254)] = 489729,
  [SMALL_STATE(10255)] = 489779,
  [SMALL_STATE(10256)] = 489847,
  [SMALL_STATE(10257)] = 489915,
  [SMALL_STATE(10258)] = 489983,
  [SMALL_STATE(10259)] = 490051,
  [SMALL_STATE(10260)] = 490119,
  [SMALL_STATE(10261)] = 490187,
  [SMALL_STATE(10262)] = 490227,
  [SMALL_STATE(10263)] = 490295,
  [SMALL_STATE(10264)] = 490337,
  [SMALL_STATE(10265)] = 490379,
  [SMALL_STATE(10266)] = 490447,
  [SMALL_STATE(10267)] = 490489,
  [SMALL_STATE(10268)] = 490557,
  [SMALL_STATE(10269)] = 490625,
  [SMALL_STATE(10270)] = 490693,
  [SMALL_STATE(10271)] = 490757,
  [SMALL_STATE(10272)] = 490825,
  [SMALL_STATE(10273)] = 490865,
  [SMALL_STATE(10274)] = 490933,
  [SMALL_STATE(10275)] = 490973,
  [SMALL_STATE(10276)] = 491029,
  [SMALL_STATE(10277)] = 491097,
  [SMALL_STATE(10278)] = 491137,
  [SMALL_STATE(10279)] = 491205,
  [SMALL_STATE(10280)] = 491245,
  [SMALL_STATE(10281)] = 491285,
  [SMALL_STATE(10282)] = 491327,
  [SMALL_STATE(10283)] = 491383,
  [SMALL_STATE(10284)] = 491423,
  [SMALL_STATE(10285)] = 491473,
  [SMALL_STATE(10286)] = 491541,
  [SMALL_STATE(10287)] = 491581,
  [SMALL_STATE(10288)] = 491627,
  [SMALL_STATE(10289)] = 491667,
  [SMALL_STATE(10290)] = 491707,
  [SMALL_STATE(10291)] = 491747,
  [SMALL_STATE(10292)] = 491787,
  [SMALL_STATE(10293)] = 491827,
  [SMALL_STATE(10294)] = 491891,
  [SMALL_STATE(10295)] = 491931,
  [SMALL_STATE(10296)] = 491987,
  [SMALL_STATE(10297)] = 492033,
  [SMALL_STATE(10298)] = 492073,
  [SMALL_STATE(10299)] = 492115,
  [SMALL_STATE(10300)] = 492155,
  [SMALL_STATE(10301)] = 492219,
  [SMALL_STATE(10302)] = 492259,
  [SMALL_STATE(10303)] = 492301,
  [SMALL_STATE(10304)] = 492347,
  [SMALL_STATE(10305)] = 492387,
  [SMALL_STATE(10306)] = 492427,
  [SMALL_STATE(10307)] = 492467,
  [SMALL_STATE(10308)] = 492507,
  [SMALL_STATE(10309)] = 492575,
  [SMALL_STATE(10310)] = 492638,
  [SMALL_STATE(10311)] = 492687,
  [SMALL_STATE(10312)] = 492750,
  [SMALL_STATE(10313)] = 492799,
  [SMALL_STATE(10314)] = 492854,
  [SMALL_STATE(10315)] = 492903,
  [SMALL_STATE(10316)] = 492952,
  [SMALL_STATE(10317)] = 493015,
  [SMALL_STATE(10318)] = 493078,
  [SMALL_STATE(10319)] = 493117,
  [SMALL_STATE(10320)] = 493180,
  [SMALL_STATE(10321)] = 493221,
  [SMALL_STATE(10322)] = 493260,
  [SMALL_STATE(10323)] = 493323,
  [SMALL_STATE(10324)] = 493362,
  [SMALL_STATE(10325)] = 493417,
  [SMALL_STATE(10326)] = 493456,
  [SMALL_STATE(10327)] = 493495,
  [SMALL_STATE(10328)] = 493534,
  [SMALL_STATE(10329)] = 493573,
  [SMALL_STATE(10330)] = 493612,
  [SMALL_STATE(10331)] = 493655,
  [SMALL_STATE(10332)] = 493716,
  [SMALL_STATE(10333)] = 493755,
  [SMALL_STATE(10334)] = 493806,
  [SMALL_STATE(10335)] = 493861,
  [SMALL_STATE(10336)] = 493900,
  [SMALL_STATE(10337)] = 493963,
  [SMALL_STATE(10338)] = 494018,
  [SMALL_STATE(10339)] = 494069,
  [SMALL_STATE(10340)] = 494110,
  [SMALL_STATE(10341)] = 494149,
  [SMALL_STATE(10342)] = 494212,
  [SMALL_STATE(10343)] = 494275,
  [SMALL_STATE(10344)] = 494338,
  [SMALL_STATE(10345)] = 494401,
  [SMALL_STATE(10346)] = 494456,
  [SMALL_STATE(10347)] = 494519,
  [SMALL_STATE(10348)] = 494582,
  [SMALL_STATE(10349)] = 494645,
  [SMALL_STATE(10350)] = 494702,
  [SMALL_STATE(10351)] = 494765,
  [SMALL_STATE(10352)] = 494828,
  [SMALL_STATE(10353)] = 494867,
  [SMALL_STATE(10354)] = 494930,
  [SMALL_STATE(10355)] = 494981,
  [SMALL_STATE(10356)] = 495044,
  [SMALL_STATE(10357)] = 495093,
  [SMALL_STATE(10358)] = 495156,
  [SMALL_STATE(10359)] = 495219,
  [SMALL_STATE(10360)] = 495282,
  [SMALL_STATE(10361)] = 495321,
  [SMALL_STATE(10362)] = 495384,
  [SMALL_STATE(10363)] = 495427,
  [SMALL_STATE(10364)] = 495490,
  [SMALL_STATE(10365)] = 495539,
  [SMALL_STATE(10366)] = 495578,
  [SMALL_STATE(10367)] = 495619,
  [SMALL_STATE(10368)] = 495682,
  [SMALL_STATE(10369)] = 495745,
  [SMALL_STATE(10370)] = 495808,
  [SMALL_STATE(10371)] = 495847,
  [SMALL_STATE(10372)] = 495890,
  [SMALL_STATE(10373)] = 495953,
  [SMALL_STATE(10374)] = 496016,
  [SMALL_STATE(10375)] = 496061,
  [SMALL_STATE(10376)] = 496124,
  [SMALL_STATE(10377)] = 496163,
  [SMALL_STATE(10378)] = 496206,
  [SMALL_STATE(10379)] = 496269,
  [SMALL_STATE(10380)] = 496322,
  [SMALL_STATE(10381)] = 496361,
  [SMALL_STATE(10382)] = 496400,
  [SMALL_STATE(10383)] = 496463,
  [SMALL_STATE(10384)] = 496504,
  [SMALL_STATE(10385)] = 496543,
  [SMALL_STATE(10386)] = 496606,
  [SMALL_STATE(10387)] = 496669,
  [SMALL_STATE(10388)] = 496726,
  [SMALL_STATE(10389)] = 496765,
  [SMALL_STATE(10390)] = 496820,
  [SMALL_STATE(10391)] = 496859,
  [SMALL_STATE(10392)] = 496898,
  [SMALL_STATE(10393)] = 496961,
  [SMALL_STATE(10394)] = 497024,
  [SMALL_STATE(10395)] = 497087,
  [SMALL_STATE(10396)] = 497142,
  [SMALL_STATE(10397)] = 497205,
  [SMALL_STATE(10398)] = 497268,
  [SMALL_STATE(10399)] = 497331,
  [SMALL_STATE(10400)] = 497372,
  [SMALL_STATE(10401)] = 497435,
  [SMALL_STATE(10402)] = 497476,
  [SMALL_STATE(10403)] = 497539,
  [SMALL_STATE(10404)] = 497594,
  [SMALL_STATE(10405)] = 497657,
  [SMALL_STATE(10406)] = 497720,
  [SMALL_STATE(10407)] = 497783,
  [SMALL_STATE(10408)] = 497822,
  [SMALL_STATE(10409)] = 497885,
  [SMALL_STATE(10410)] = 497924,
  [SMALL_STATE(10411)] = 497963,
  [SMALL_STATE(10412)] = 498018,
  [SMALL_STATE(10413)] = 498081,
  [SMALL_STATE(10414)] = 498136,
  [SMALL_STATE(10415)] = 498199,
  [SMALL_STATE(10416)] = 498254,
  [SMALL_STATE(10417)] = 498317,
  [SMALL_STATE(10418)] = 498380,
  [SMALL_STATE(10419)] = 498443,
  [SMALL_STATE(10420)] = 498506,
  [SMALL_STATE(10421)] = 498569,
  [SMALL_STATE(10422)] = 498632,
  [SMALL_STATE(10423)] = 498683,
  [SMALL_STATE(10424)] = 498746,
  [SMALL_STATE(10425)] = 498809,
  [SMALL_STATE(10426)] = 498872,
  [SMALL_STATE(10427)] = 498935,
  [SMALL_STATE(10428)] = 498998,
  [SMALL_STATE(10429)] = 499061,
  [SMALL_STATE(10430)] = 499124,
  [SMALL_STATE(10431)] = 499179,
  [SMALL_STATE(10432)] = 499238,
  [SMALL_STATE(10433)] = 499301,
  [SMALL_STATE(10434)] = 499364,
  [SMALL_STATE(10435)] = 499427,
  [SMALL_STATE(10436)] = 499466,
  [SMALL_STATE(10437)] = 499529,
  [SMALL_STATE(10438)] = 499592,
  [SMALL_STATE(10439)] = 499655,
  [SMALL_STATE(10440)] = 499694,
  [SMALL_STATE(10441)] = 499757,
  [SMALL_STATE(10442)] = 499820,
  [SMALL_STATE(10443)] = 499869,
  [SMALL_STATE(10444)] = 499932,
  [SMALL_STATE(10445)] = 499971,
  [SMALL_STATE(10446)] = 500022,
  [SMALL_STATE(10447)] = 500085,
  [SMALL_STATE(10448)] = 500148,
  [SMALL_STATE(10449)] = 500203,
  [SMALL_STATE(10450)] = 500266,
  [SMALL_STATE(10451)] = 500329,
  [SMALL_STATE(10452)] = 500392,
  [SMALL_STATE(10453)] = 500431,
  [SMALL_STATE(10454)] = 500494,
  [SMALL_STATE(10455)] = 500557,
  [SMALL_STATE(10456)] = 500596,
  [SMALL_STATE(10457)] = 500653,
  [SMALL_STATE(10458)] = 500692,
  [SMALL_STATE(10459)] = 500755,
  [SMALL_STATE(10460)] = 500810,
  [SMALL_STATE(10461)] = 500873,
  [SMALL_STATE(10462)] = 500936,
  [SMALL_STATE(10463)] = 500999,
  [SMALL_STATE(10464)] = 501038,
  [SMALL_STATE(10465)] = 501077,
  [SMALL_STATE(10466)] = 501116,
  [SMALL_STATE(10467)] = 501179,
  [SMALL_STATE(10468)] = 501218,
  [SMALL_STATE(10469)] = 501273,
  [SMALL_STATE(10470)] = 501334,
  [SMALL_STATE(10471)] = 501397,
  [SMALL_STATE(10472)] = 501446,
  [SMALL_STATE(10473)] = 501495,
  [SMALL_STATE(10474)] = 501534,
  [SMALL_STATE(10475)] = 501573,
  [SMALL_STATE(10476)] = 501616,
  [SMALL_STATE(10477)] = 501665,
  [SMALL_STATE(10478)] = 501704,
  [SMALL_STATE(10479)] = 501753,
  [SMALL_STATE(10480)] = 501804,
  [SMALL_STATE(10481)] = 501847,
  [SMALL_STATE(10482)] = 501910,
  [SMALL_STATE(10483)] = 501973,
  [SMALL_STATE(10484)] = 502012,
  [SMALL_STATE(10485)] = 502075,
  [SMALL_STATE(10486)] = 502128,
  [SMALL_STATE(10487)] = 502191,
  [SMALL_STATE(10488)] = 502254,
  [SMALL_STATE(10489)] = 502317,
  [SMALL_STATE(10490)] = 502356,
  [SMALL_STATE(10491)] = 502395,
  [SMALL_STATE(10492)] = 502458,
  [SMALL_STATE(10493)] = 502521,
  [SMALL_STATE(10494)] = 502584,
  [SMALL_STATE(10495)] = 502623,
  [SMALL_STATE(10496)] = 502686,
  [SMALL_STATE(10497)] = 502735,
  [SMALL_STATE(10498)] = 502780,
  [SMALL_STATE(10499)] = 502821,
  [SMALL_STATE(10500)] = 502884,
  [SMALL_STATE(10501)] = 502947,
  [SMALL_STATE(10502)] = 502986,
  [SMALL_STATE(10503)] = 503027,
  [SMALL_STATE(10504)] = 503090,
  [SMALL_STATE(10505)] = 503151,
  [SMALL_STATE(10506)] = 503214,
  [SMALL_STATE(10507)] = 503253,
  [SMALL_STATE(10508)] = 503302,
  [SMALL_STATE(10509)] = 503365,
  [SMALL_STATE(10510)] = 503404,
  [SMALL_STATE(10511)] = 503467,
  [SMALL_STATE(10512)] = 503530,
  [SMALL_STATE(10513)] = 503585,
  [SMALL_STATE(10514)] = 503640,
  [SMALL_STATE(10515)] = 503703,
  [SMALL_STATE(10516)] = 503742,
  [SMALL_STATE(10517)] = 503805,
  [SMALL_STATE(10518)] = 503868,
  [SMALL_STATE(10519)] = 503931,
  [SMALL_STATE(10520)] = 503980,
  [SMALL_STATE(10521)] = 504019,
  [SMALL_STATE(10522)] = 504064,
  [SMALL_STATE(10523)] = 504127,
  [SMALL_STATE(10524)] = 504190,
  [SMALL_STATE(10525)] = 504239,
  [SMALL_STATE(10526)] = 504278,
  [SMALL_STATE(10527)] = 504341,
  [SMALL_STATE(10528)] = 504404,
  [SMALL_STATE(10529)] = 504467,
  [SMALL_STATE(10530)] = 504530,
  [SMALL_STATE(10531)] = 504569,
  [SMALL_STATE(10532)] = 504632,
  [SMALL_STATE(10533)] = 504695,
  [SMALL_STATE(10534)] = 504758,
  [SMALL_STATE(10535)] = 504799,
  [SMALL_STATE(10536)] = 504840,
  [SMALL_STATE(10537)] = 504879,
  [SMALL_STATE(10538)] = 504928,
  [SMALL_STATE(10539)] = 504983,
  [SMALL_STATE(10540)] = 505022,
  [SMALL_STATE(10541)] = 505077,
  [SMALL_STATE(10542)] = 505118,
  [SMALL_STATE(10543)] = 505167,
  [SMALL_STATE(10544)] = 505206,
  [SMALL_STATE(10545)] = 505257,
  [SMALL_STATE(10546)] = 505320,
  [SMALL_STATE(10547)] = 505365,
  [SMALL_STATE(10548)] = 505410,
  [SMALL_STATE(10549)] = 505455,
  [SMALL_STATE(10550)] = 505500,
  [SMALL_STATE(10551)] = 505545,
  [SMALL_STATE(10552)] = 505590,
  [SMALL_STATE(10553)] = 505635,
  [SMALL_STATE(10554)] = 505680,
  [SMALL_STATE(10555)] = 505735,
  [SMALL_STATE(10556)] = 505790,
  [SMALL_STATE(10557)] = 505853,
  [SMALL_STATE(10558)] = 505892,
  [SMALL_STATE(10559)] = 505930,
  [SMALL_STATE(10560)] = 505996,
  [SMALL_STATE(10561)] = 506062,
  [SMALL_STATE(10562)] = 506104,
  [SMALL_STATE(10563)] = 506142,
  [SMALL_STATE(10564)] = 506208,
  [SMALL_STATE(10565)] = 506256,
  [SMALL_STATE(10566)] = 506294,
  [SMALL_STATE(10567)] = 506332,
  [SMALL_STATE(10568)] = 506370,
  [SMALL_STATE(10569)] = 506408,
  [SMALL_STATE(10570)] = 506474,
  [SMALL_STATE(10571)] = 506512,
  [SMALL_STATE(10572)] = 506564,
  [SMALL_STATE(10573)] = 506602,
  [SMALL_STATE(10574)] = 506640,
  [SMALL_STATE(10575)] = 506706,
  [SMALL_STATE(10576)] = 506744,
  [SMALL_STATE(10577)] = 506782,
  [SMALL_STATE(10578)] = 506820,
  [SMALL_STATE(10579)] = 506858,
  [SMALL_STATE(10580)] = 506896,
  [SMALL_STATE(10581)] = 506934,
  [SMALL_STATE(10582)] = 506972,
  [SMALL_STATE(10583)] = 507012,
  [SMALL_STATE(10584)] = 507050,
  [SMALL_STATE(10585)] = 507088,
  [SMALL_STATE(10586)] = 507154,
  [SMALL_STATE(10587)] = 507192,
  [SMALL_STATE(10588)] = 507230,
  [SMALL_STATE(10589)] = 507268,
  [SMALL_STATE(10590)] = 507306,
  [SMALL_STATE(10591)] = 507344,
  [SMALL_STATE(10592)] = 507410,
  [SMALL_STATE(10593)] = 507458,
  [SMALL_STATE(10594)] = 507496,
  [SMALL_STATE(10595)] = 507562,
  [SMALL_STATE(10596)] = 507600,
  [SMALL_STATE(10597)] = 507638,
  [SMALL_STATE(10598)] = 507676,
  [SMALL_STATE(10599)] = 507716,
  [SMALL_STATE(10600)] = 507756,
  [SMALL_STATE(10601)] = 507822,
  [SMALL_STATE(10602)] = 507860,
  [SMALL_STATE(10603)] = 507912,
  [SMALL_STATE(10604)] = 507964,
  [SMALL_STATE(10605)] = 508002,
  [SMALL_STATE(10606)] = 508040,
  [SMALL_STATE(10607)] = 508078,
  [SMALL_STATE(10608)] = 508116,
  [SMALL_STATE(10609)] = 508154,
  [SMALL_STATE(10610)] = 508220,
  [SMALL_STATE(10611)] = 508258,
  [SMALL_STATE(10612)] = 508312,
  [SMALL_STATE(10613)] = 508360,
  [SMALL_STATE(10614)] = 508398,
  [SMALL_STATE(10615)] = 508464,
  [SMALL_STATE(10616)] = 508502,
  [SMALL_STATE(10617)] = 508550,
  [SMALL_STATE(10618)] = 508598,
  [SMALL_STATE(10619)] = 508640,
  [SMALL_STATE(10620)] = 508688,
  [SMALL_STATE(10621)] = 508738,
  [SMALL_STATE(10622)] = 508776,
  [SMALL_STATE(10623)] = 508814,
  [SMALL_STATE(10624)] = 508880,
  [SMALL_STATE(10625)] = 508922,
  [SMALL_STATE(10626)] = 508960,
  [SMALL_STATE(10627)] = 508998,
  [SMALL_STATE(10628)] = 509060,
  [SMALL_STATE(10629)] = 509120,
  [SMALL_STATE(10630)] = 509168,
  [SMALL_STATE(10631)] = 509234,
  [SMALL_STATE(10632)] = 509274,
  [SMALL_STATE(10633)] = 509312,
  [SMALL_STATE(10634)] = 509354,
  [SMALL_STATE(10635)] = 509402,
  [SMALL_STATE(10636)] = 509444,
  [SMALL_STATE(10637)] = 509510,
  [SMALL_STATE(10638)] = 509558,
  [SMALL_STATE(10639)] = 509596,
  [SMALL_STATE(10640)] = 509638,
  [SMALL_STATE(10641)] = 509704,
  [SMALL_STATE(10642)] = 509742,
  [SMALL_STATE(10643)] = 509790,
  [SMALL_STATE(10644)] = 509838,
  [SMALL_STATE(10645)] = 509876,
  [SMALL_STATE(10646)] = 509914,
  [SMALL_STATE(10647)] = 509980,
  [SMALL_STATE(10648)] = 510034,
  [SMALL_STATE(10649)] = 510072,
  [SMALL_STATE(10650)] = 510110,
  [SMALL_STATE(10651)] = 510176,
  [SMALL_STATE(10652)] = 510214,
  [SMALL_STATE(10653)] = 510252,
  [SMALL_STATE(10654)] = 510294,
  [SMALL_STATE(10655)] = 510332,
  [SMALL_STATE(10656)] = 510370,
  [SMALL_STATE(10657)] = 510408,
  [SMALL_STATE(10658)] = 510446,
  [SMALL_STATE(10659)] = 510484,
  [SMALL_STATE(10660)] = 510522,
  [SMALL_STATE(10661)] = 510570,
  [SMALL_STATE(10662)] = 510608,
  [SMALL_STATE(10663)] = 510662,
  [SMALL_STATE(10664)] = 510716,
  [SMALL_STATE(10665)] = 510764,
  [SMALL_STATE(10666)] = 510812,
  [SMALL_STATE(10667)] = 510850,
  [SMALL_STATE(10668)] = 510888,
  [SMALL_STATE(10669)] = 510936,
  [SMALL_STATE(10670)] = 510974,
  [SMALL_STATE(10671)] = 511018,
  [SMALL_STATE(10672)] = 511056,
  [SMALL_STATE(10673)] = 511094,
  [SMALL_STATE(10674)] = 511142,
  [SMALL_STATE(10675)] = 511180,
  [SMALL_STATE(10676)] = 511218,
  [SMALL_STATE(10677)] = 511262,
  [SMALL_STATE(10678)] = 511300,
  [SMALL_STATE(10679)] = 511338,
  [SMALL_STATE(10680)] = 511376,
  [SMALL_STATE(10681)] = 511414,
  [SMALL_STATE(10682)] = 511462,
  [SMALL_STATE(10683)] = 511528,
  [SMALL_STATE(10684)] = 511566,
  [SMALL_STATE(10685)] = 511604,
  [SMALL_STATE(10686)] = 511642,
  [SMALL_STATE(10687)] = 511680,
  [SMALL_STATE(10688)] = 511718,
  [SMALL_STATE(10689)] = 511756,
  [SMALL_STATE(10690)] = 511794,
  [SMALL_STATE(10691)] = 511834,
  [SMALL_STATE(10692)] = 511878,
  [SMALL_STATE(10693)] = 511936,
  [SMALL_STATE(10694)] = 511984,
  [SMALL_STATE(10695)] = 512032,
  [SMALL_STATE(10696)] = 512074,
  [SMALL_STATE(10697)] = 512116,
  [SMALL_STATE(10698)] = 512166,
  [SMALL_STATE(10699)] = 512216,
  [SMALL_STATE(10700)] = 512264,
  [SMALL_STATE(10701)] = 512312,
  [SMALL_STATE(10702)] = 512366,
  [SMALL_STATE(10703)] = 512422,
  [SMALL_STATE(10704)] = 512482,
  [SMALL_STATE(10705)] = 512526,
  [SMALL_STATE(10706)] = 512586,
  [SMALL_STATE(10707)] = 512624,
  [SMALL_STATE(10708)] = 512664,
  [SMALL_STATE(10709)] = 512706,
  [SMALL_STATE(10710)] = 512744,
  [SMALL_STATE(10711)] = 512804,
  [SMALL_STATE(10712)] = 512852,
  [SMALL_STATE(10713)] = 512900,
  [SMALL_STATE(10714)] = 512940,
  [SMALL_STATE(10715)] = 512978,
  [SMALL_STATE(10716)] = 513016,
  [SMALL_STATE(10717)] = 513054,
  [SMALL_STATE(10718)] = 513102,
  [SMALL_STATE(10719)] = 513144,
  [SMALL_STATE(10720)] = 513182,
  [SMALL_STATE(10721)] = 513222,
  [SMALL_STATE(10722)] = 513260,
  [SMALL_STATE(10723)] = 513304,
  [SMALL_STATE(10724)] = 513356,
  [SMALL_STATE(10725)] = 513422,
  [SMALL_STATE(10726)] = 513488,
  [SMALL_STATE(10727)] = 513528,
  [SMALL_STATE(10728)] = 513578,
  [SMALL_STATE(10729)] = 513630,
  [SMALL_STATE(10730)] = 513684,
  [SMALL_STATE(10731)] = 513736,
  [SMALL_STATE(10732)] = 513798,
  [SMALL_STATE(10733)] = 513848,
  [SMALL_STATE(10734)] = 513900,
  [SMALL_STATE(10735)] = 513942,
  [SMALL_STATE(10736)] = 513980,
  [SMALL_STATE(10737)] = 514018,
  [SMALL_STATE(10738)] = 514056,
  [SMALL_STATE(10739)] = 514094,
  [SMALL_STATE(10740)] = 514132,
  [SMALL_STATE(10741)] = 514170,
  [SMALL_STATE(10742)] = 514208,
  [SMALL_STATE(10743)] = 514246,
  [SMALL_STATE(10744)] = 514312,
  [SMALL_STATE(10745)] = 514350,
  [SMALL_STATE(10746)] = 514388,
  [SMALL_STATE(10747)] = 514436,
  [SMALL_STATE(10748)] = 514476,
  [SMALL_STATE(10749)] = 514514,
  [SMALL_STATE(10750)] = 514552,
  [SMALL_STATE(10751)] = 514590,
  [SMALL_STATE(10752)] = 514628,
  [SMALL_STATE(10753)] = 514690,
  [SMALL_STATE(10754)] = 514728,
  [SMALL_STATE(10755)] = 514782,
  [SMALL_STATE(10756)] = 514834,
  [SMALL_STATE(10757)] = 514872,
  [SMALL_STATE(10758)] = 514910,
  [SMALL_STATE(10759)] = 514948,
  [SMALL_STATE(10760)] = 515014,
  [SMALL_STATE(10761)] = 515052,
  [SMALL_STATE(10762)] = 515090,
  [SMALL_STATE(10763)] = 515128,
  [SMALL_STATE(10764)] = 515176,
  [SMALL_STATE(10765)] = 515214,
  [SMALL_STATE(10766)] = 515252,
  [SMALL_STATE(10767)] = 515290,
  [SMALL_STATE(10768)] = 515328,
  [SMALL_STATE(10769)] = 515366,
  [SMALL_STATE(10770)] = 515432,
  [SMALL_STATE(10771)] = 515470,
  [SMALL_STATE(10772)] = 515512,
  [SMALL_STATE(10773)] = 515550,
  [SMALL_STATE(10774)] = 515588,
  [SMALL_STATE(10775)] = 515630,
  [SMALL_STATE(10776)] = 515672,
  [SMALL_STATE(10777)] = 515710,
  [SMALL_STATE(10778)] = 515752,
  [SMALL_STATE(10779)] = 515794,
  [SMALL_STATE(10780)] = 515834,
  [SMALL_STATE(10781)] = 515872,
  [SMALL_STATE(10782)] = 515910,
  [SMALL_STATE(10783)] = 515948,
  [SMALL_STATE(10784)] = 515992,
  [SMALL_STATE(10785)] = 516030,
  [SMALL_STATE(10786)] = 516068,
  [SMALL_STATE(10787)] = 516108,
  [SMALL_STATE(10788)] = 516146,
  [SMALL_STATE(10789)] = 516212,
  [SMALL_STATE(10790)] = 516278,
  [SMALL_STATE(10791)] = 516316,
  [SMALL_STATE(10792)] = 516354,
  [SMALL_STATE(10793)] = 516392,
  [SMALL_STATE(10794)] = 516430,
  [SMALL_STATE(10795)] = 516468,
  [SMALL_STATE(10796)] = 516506,
  [SMALL_STATE(10797)] = 516572,
  [SMALL_STATE(10798)] = 516610,
  [SMALL_STATE(10799)] = 516659,
  [SMALL_STATE(10800)] = 516702,
  [SMALL_STATE(10801)] = 516745,
  [SMALL_STATE(10802)] = 516808,
  [SMALL_STATE(10803)] = 516851,
  [SMALL_STATE(10804)] = 516888,
  [SMALL_STATE(10805)] = 516927,
  [SMALL_STATE(10806)] = 516964,
  [SMALL_STATE(10807)] = 517005,
  [SMALL_STATE(10808)] = 517048,
  [SMALL_STATE(10809)] = 517087,
  [SMALL_STATE(10810)] = 517130,
  [SMALL_STATE(10811)] = 517167,
  [SMALL_STATE(10812)] = 517210,
  [SMALL_STATE(10813)] = 517253,
  [SMALL_STATE(10814)] = 517316,
  [SMALL_STATE(10815)] = 517359,
  [SMALL_STATE(10816)] = 517402,
  [SMALL_STATE(10817)] = 517445,
  [SMALL_STATE(10818)] = 517488,
  [SMALL_STATE(10819)] = 517551,
  [SMALL_STATE(10820)] = 517588,
  [SMALL_STATE(10821)] = 517627,
  [SMALL_STATE(10822)] = 517666,
  [SMALL_STATE(10823)] = 517709,
  [SMALL_STATE(10824)] = 517746,
  [SMALL_STATE(10825)] = 517803,
  [SMALL_STATE(10826)] = 517850,
  [SMALL_STATE(10827)] = 517891,
  [SMALL_STATE(10828)] = 517932,
  [SMALL_STATE(10829)] = 517981,
  [SMALL_STATE(10830)] = 518030,
  [SMALL_STATE(10831)] = 518083,
  [SMALL_STATE(10832)] = 518124,
  [SMALL_STATE(10833)] = 518179,
  [SMALL_STATE(10834)] = 518238,
  [SMALL_STATE(10835)] = 518281,
  [SMALL_STATE(10836)] = 518340,
  [SMALL_STATE(10837)] = 518387,
  [SMALL_STATE(10838)] = 518434,
  [SMALL_STATE(10839)] = 518497,
  [SMALL_STATE(10840)] = 518534,
  [SMALL_STATE(10841)] = 518575,
  [SMALL_STATE(10842)] = 518618,
  [SMALL_STATE(10843)] = 518681,
  [SMALL_STATE(10844)] = 518724,
  [SMALL_STATE(10845)] = 518761,
  [SMALL_STATE(10846)] = 518802,
  [SMALL_STATE(10847)] = 518839,
  [SMALL_STATE(10848)] = 518882,
  [SMALL_STATE(10849)] = 518941,
  [SMALL_STATE(10850)] = 519004,
  [SMALL_STATE(10851)] = 519047,
  [SMALL_STATE(10852)] = 519090,
  [SMALL_STATE(10853)] = 519153,
  [SMALL_STATE(10854)] = 519196,
  [SMALL_STATE(10855)] = 519245,
  [SMALL_STATE(10856)] = 519282,
  [SMALL_STATE(10857)] = 519345,
  [SMALL_STATE(10858)] = 519408,
  [SMALL_STATE(10859)] = 519445,
  [SMALL_STATE(10860)] = 519482,
  [SMALL_STATE(10861)] = 519529,
  [SMALL_STATE(10862)] = 519572,
  [SMALL_STATE(10863)] = 519631,
  [SMALL_STATE(10864)] = 519674,
  [SMALL_STATE(10865)] = 519717,
  [SMALL_STATE(10866)] = 519760,
  [SMALL_STATE(10867)] = 519797,
  [SMALL_STATE(10868)] = 519838,
  [SMALL_STATE(10869)] = 519901,
  [SMALL_STATE(10870)] = 519948,
  [SMALL_STATE(10871)] = 520011,
  [SMALL_STATE(10872)] = 520054,
  [SMALL_STATE(10873)] = 520093,
  [SMALL_STATE(10874)] = 520140,
  [SMALL_STATE(10875)] = 520183,
  [SMALL_STATE(10876)] = 520226,
  [SMALL_STATE(10877)] = 520263,
  [SMALL_STATE(10878)] = 520300,
  [SMALL_STATE(10879)] = 520363,
  [SMALL_STATE(10880)] = 520406,
  [SMALL_STATE(10881)] = 520469,
  [SMALL_STATE(10882)] = 520506,
  [SMALL_STATE(10883)] = 520549,
  [SMALL_STATE(10884)] = 520592,
  [SMALL_STATE(10885)] = 520631,
  [SMALL_STATE(10886)] = 520694,
  [SMALL_STATE(10887)] = 520731,
  [SMALL_STATE(10888)] = 520774,
  [SMALL_STATE(10889)] = 520811,
  [SMALL_STATE(10890)] = 520854,
  [SMALL_STATE(10891)] = 520891,
  [SMALL_STATE(10892)] = 520928,
  [SMALL_STATE(10893)] = 520991,
  [SMALL_STATE(10894)] = 521052,
  [SMALL_STATE(10895)] = 521089,
  [SMALL_STATE(10896)] = 521152,
  [SMALL_STATE(10897)] = 521195,
  [SMALL_STATE(10898)] = 521242,
  [SMALL_STATE(10899)] = 521285,
  [SMALL_STATE(10900)] = 521348,
  [SMALL_STATE(10901)] = 521389,
  [SMALL_STATE(10902)] = 521426,
  [SMALL_STATE(10903)] = 521469,
  [SMALL_STATE(10904)] = 521512,
  [SMALL_STATE(10905)] = 521559,
  [SMALL_STATE(10906)] = 521602,
  [SMALL_STATE(10907)] = 521639,
  [SMALL_STATE(10908)] = 521682,
  [SMALL_STATE(10909)] = 521725,
  [SMALL_STATE(10910)] = 521768,
  [SMALL_STATE(10911)] = 521811,
  [SMALL_STATE(10912)] = 521854,
  [SMALL_STATE(10913)] = 521897,
  [SMALL_STATE(10914)] = 521934,
  [SMALL_STATE(10915)] = 521977,
  [SMALL_STATE(10916)] = 522040,
  [SMALL_STATE(10917)] = 522083,
  [SMALL_STATE(10918)] = 522120,
  [SMALL_STATE(10919)] = 522163,
  [SMALL_STATE(10920)] = 522206,
  [SMALL_STATE(10921)] = 522249,
  [SMALL_STATE(10922)] = 522312,
  [SMALL_STATE(10923)] = 522355,
  [SMALL_STATE(10924)] = 522398,
  [SMALL_STATE(10925)] = 522437,
  [SMALL_STATE(10926)] = 522480,
  [SMALL_STATE(10927)] = 522523,
  [SMALL_STATE(10928)] = 522566,
  [SMALL_STATE(10929)] = 522603,
  [SMALL_STATE(10930)] = 522642,
  [SMALL_STATE(10931)] = 522679,
  [SMALL_STATE(10932)] = 522742,
  [SMALL_STATE(10933)] = 522785,
  [SMALL_STATE(10934)] = 522828,
  [SMALL_STATE(10935)] = 522871,
  [SMALL_STATE(10936)] = 522928,
  [SMALL_STATE(10937)] = 522971,
  [SMALL_STATE(10938)] = 523014,
  [SMALL_STATE(10939)] = 523061,
  [SMALL_STATE(10940)] = 523104,
  [SMALL_STATE(10941)] = 523145,
  [SMALL_STATE(10942)] = 523188,
  [SMALL_STATE(10943)] = 523231,
  [SMALL_STATE(10944)] = 523274,
  [SMALL_STATE(10945)] = 523317,
  [SMALL_STATE(10946)] = 523360,
  [SMALL_STATE(10947)] = 523421,
  [SMALL_STATE(10948)] = 523464,
  [SMALL_STATE(10949)] = 523505,
  [SMALL_STATE(10950)] = 523552,
  [SMALL_STATE(10951)] = 523601,
  [SMALL_STATE(10952)] = 523644,
  [SMALL_STATE(10953)] = 523693,
  [SMALL_STATE(10954)] = 523746,
  [SMALL_STATE(10955)] = 523801,
  [SMALL_STATE(10956)] = 523854,
  [SMALL_STATE(10957)] = 523907,
  [SMALL_STATE(10958)] = 523966,
  [SMALL_STATE(10959)] = 524009,
  [SMALL_STATE(10960)] = 524068,
  [SMALL_STATE(10961)] = 524117,
  [SMALL_STATE(10962)] = 524164,
  [SMALL_STATE(10963)] = 524207,
  [SMALL_STATE(10964)] = 524244,
  [SMALL_STATE(10965)] = 524281,
  [SMALL_STATE(10966)] = 524332,
  [SMALL_STATE(10967)] = 524375,
  [SMALL_STATE(10968)] = 524418,
  [SMALL_STATE(10969)] = 524461,
  [SMALL_STATE(10970)] = 524504,
  [SMALL_STATE(10971)] = 524567,
  [SMALL_STATE(10972)] = 524610,
  [SMALL_STATE(10973)] = 524673,
  [SMALL_STATE(10974)] = 524710,
  [SMALL_STATE(10975)] = 524747,
  [SMALL_STATE(10976)] = 524784,
  [SMALL_STATE(10977)] = 524847,
  [SMALL_STATE(10978)] = 524884,
  [SMALL_STATE(10979)] = 524921,
  [SMALL_STATE(10980)] = 524964,
  [SMALL_STATE(10981)] = 525005,
  [SMALL_STATE(10982)] = 525054,
  [SMALL_STATE(10983)] = 525101,
  [SMALL_STATE(10984)] = 525152,
  [SMALL_STATE(10985)] = 525191,
  [SMALL_STATE(10986)] = 525240,
  [SMALL_STATE(10987)] = 525289,
  [SMALL_STATE(10988)] = 525338,
  [SMALL_STATE(10989)] = 525385,
  [SMALL_STATE(10990)] = 525434,
  [SMALL_STATE(10991)] = 525471,
  [SMALL_STATE(10992)] = 525520,
  [SMALL_STATE(10993)] = 525569,
  [SMALL_STATE(10994)] = 525618,
  [SMALL_STATE(10995)] = 525667,
  [SMALL_STATE(10996)] = 525716,
  [SMALL_STATE(10997)] = 525765,
  [SMALL_STATE(10998)] = 525814,
  [SMALL_STATE(10999)] = 525863,
  [SMALL_STATE(11000)] = 525912,
  [SMALL_STATE(11001)] = 525961,
  [SMALL_STATE(11002)] = 526010,
  [SMALL_STATE(11003)] = 526059,
  [SMALL_STATE(11004)] = 526108,
  [SMALL_STATE(11005)] = 526157,
  [SMALL_STATE(11006)] = 526206,
  [SMALL_STATE(11007)] = 526255,
  [SMALL_STATE(11008)] = 526304,
  [SMALL_STATE(11009)] = 526353,
  [SMALL_STATE(11010)] = 526390,
  [SMALL_STATE(11011)] = 526439,
  [SMALL_STATE(11012)] = 526488,
  [SMALL_STATE(11013)] = 526537,
  [SMALL_STATE(11014)] = 526586,
  [SMALL_STATE(11015)] = 526635,
  [SMALL_STATE(11016)] = 526684,
  [SMALL_STATE(11017)] = 526733,
  [SMALL_STATE(11018)] = 526782,
  [SMALL_STATE(11019)] = 526831,
  [SMALL_STATE(11020)] = 526880,
  [SMALL_STATE(11021)] = 526929,
  [SMALL_STATE(11022)] = 526978,
  [SMALL_STATE(11023)] = 527027,
  [SMALL_STATE(11024)] = 527064,
  [SMALL_STATE(11025)] = 527107,
  [SMALL_STATE(11026)] = 527170,
  [SMALL_STATE(11027)] = 527211,
  [SMALL_STATE(11028)] = 527274,
  [SMALL_STATE(11029)] = 527333,
  [SMALL_STATE(11030)] = 527376,
  [SMALL_STATE(11031)] = 527425,
  [SMALL_STATE(11032)] = 527488,
  [SMALL_STATE(11033)] = 527525,
  [SMALL_STATE(11034)] = 527574,
  [SMALL_STATE(11035)] = 527623,
  [SMALL_STATE(11036)] = 527666,
  [SMALL_STATE(11037)] = 527715,
  [SMALL_STATE(11038)] = 527764,
  [SMALL_STATE(11039)] = 527813,
  [SMALL_STATE(11040)] = 527862,
  [SMALL_STATE(11041)] = 527911,
  [SMALL_STATE(11042)] = 527960,
  [SMALL_STATE(11043)] = 528009,
  [SMALL_STATE(11044)] = 528058,
  [SMALL_STATE(11045)] = 528107,
  [SMALL_STATE(11046)] = 528156,
  [SMALL_STATE(11047)] = 528205,
  [SMALL_STATE(11048)] = 528254,
  [SMALL_STATE(11049)] = 528303,
  [SMALL_STATE(11050)] = 528352,
  [SMALL_STATE(11051)] = 528395,
  [SMALL_STATE(11052)] = 528444,
  [SMALL_STATE(11053)] = 528493,
  [SMALL_STATE(11054)] = 528542,
  [SMALL_STATE(11055)] = 528591,
  [SMALL_STATE(11056)] = 528640,
  [SMALL_STATE(11057)] = 528677,
  [SMALL_STATE(11058)] = 528726,
  [SMALL_STATE(11059)] = 528775,
  [SMALL_STATE(11060)] = 528824,
  [SMALL_STATE(11061)] = 528873,
  [SMALL_STATE(11062)] = 528922,
  [SMALL_STATE(11063)] = 528971,
  [SMALL_STATE(11064)] = 529020,
  [SMALL_STATE(11065)] = 529069,
  [SMALL_STATE(11066)] = 529118,
  [SMALL_STATE(11067)] = 529167,
  [SMALL_STATE(11068)] = 529216,
  [SMALL_STATE(11069)] = 529265,
  [SMALL_STATE(11070)] = 529314,
  [SMALL_STATE(11071)] = 529367,
  [SMALL_STATE(11072)] = 529404,
  [SMALL_STATE(11073)] = 529453,
  [SMALL_STATE(11074)] = 529516,
  [SMALL_STATE(11075)] = 529557,
  [SMALL_STATE(11076)] = 529596,
  [SMALL_STATE(11077)] = 529639,
  [SMALL_STATE(11078)] = 529682,
  [SMALL_STATE(11079)] = 529725,
  [SMALL_STATE(11080)] = 529768,
  [SMALL_STATE(11081)] = 529809,
  [SMALL_STATE(11082)] = 529848,
  [SMALL_STATE(11083)] = 529891,
  [SMALL_STATE(11084)] = 529934,
  [SMALL_STATE(11085)] = 529977,
  [SMALL_STATE(11086)] = 530020,
  [SMALL_STATE(11087)] = 530063,
  [SMALL_STATE(11088)] = 530106,
  [SMALL_STATE(11089)] = 530149,
  [SMALL_STATE(11090)] = 530192,
  [SMALL_STATE(11091)] = 530235,
  [SMALL_STATE(11092)] = 530272,
  [SMALL_STATE(11093)] = 530309,
  [SMALL_STATE(11094)] = 530350,
  [SMALL_STATE(11095)] = 530413,
  [SMALL_STATE(11096)] = 530450,
  [SMALL_STATE(11097)] = 530487,
  [SMALL_STATE(11098)] = 530530,
  [SMALL_STATE(11099)] = 530573,
  [SMALL_STATE(11100)] = 530616,
  [SMALL_STATE(11101)] = 530659,
  [SMALL_STATE(11102)] = 530702,
  [SMALL_STATE(11103)] = 530739,
  [SMALL_STATE(11104)] = 530782,
  [SMALL_STATE(11105)] = 530825,
  [SMALL_STATE(11106)] = 530862,
  [SMALL_STATE(11107)] = 530925,
  [SMALL_STATE(11108)] = 530972,
  [SMALL_STATE(11109)] = 531025,
  [SMALL_STATE(11110)] = 531062,
  [SMALL_STATE(11111)] = 531115,
  [SMALL_STATE(11112)] = 531158,
  [SMALL_STATE(11113)] = 531221,
  [SMALL_STATE(11114)] = 531264,
  [SMALL_STATE(11115)] = 531301,
  [SMALL_STATE(11116)] = 531344,
  [SMALL_STATE(11117)] = 531387,
  [SMALL_STATE(11118)] = 531430,
  [SMALL_STATE(11119)] = 531467,
  [SMALL_STATE(11120)] = 531504,
  [SMALL_STATE(11121)] = 531551,
  [SMALL_STATE(11122)] = 531612,
  [SMALL_STATE(11123)] = 531675,
  [SMALL_STATE(11124)] = 531712,
  [SMALL_STATE(11125)] = 531753,
  [SMALL_STATE(11126)] = 531790,
  [SMALL_STATE(11127)] = 531853,
  [SMALL_STATE(11128)] = 531914,
  [SMALL_STATE(11129)] = 531957,
  [SMALL_STATE(11130)] = 532018,
  [SMALL_STATE(11131)] = 532081,
  [SMALL_STATE(11132)] = 532124,
  [SMALL_STATE(11133)] = 532165,
  [SMALL_STATE(11134)] = 532202,
  [SMALL_STATE(11135)] = 532241,
  [SMALL_STATE(11136)] = 532284,
  [SMALL_STATE(11137)] = 532331,
  [SMALL_STATE(11138)] = 532370,
  [SMALL_STATE(11139)] = 532413,
  [SMALL_STATE(11140)] = 532476,
  [SMALL_STATE(11141)] = 532519,
  [SMALL_STATE(11142)] = 532562,
  [SMALL_STATE(11143)] = 532605,
  [SMALL_STATE(11144)] = 532648,
  [SMALL_STATE(11145)] = 532691,
  [SMALL_STATE(11146)] = 532728,
  [SMALL_STATE(11147)] = 532765,
  [SMALL_STATE(11148)] = 532802,
  [SMALL_STATE(11149)] = 532839,
  [SMALL_STATE(11150)] = 532876,
  [SMALL_STATE(11151)] = 532913,
  [SMALL_STATE(11152)] = 532956,
  [SMALL_STATE(11153)] = 532999,
  [SMALL_STATE(11154)] = 533062,
  [SMALL_STATE(11155)] = 533105,
  [SMALL_STATE(11156)] = 533148,
  [SMALL_STATE(11157)] = 533191,
  [SMALL_STATE(11158)] = 533228,
  [SMALL_STATE(11159)] = 533271,
  [SMALL_STATE(11160)] = 533314,
  [SMALL_STATE(11161)] = 533357,
  [SMALL_STATE(11162)] = 533400,
  [SMALL_STATE(11163)] = 533443,
  [SMALL_STATE(11164)] = 533490,
  [SMALL_STATE(11165)] = 533543,
  [SMALL_STATE(11166)] = 533586,
  [SMALL_STATE(11167)] = 533649,
  [SMALL_STATE(11168)] = 533692,
  [SMALL_STATE(11169)] = 533729,
  [SMALL_STATE(11170)] = 533770,
  [SMALL_STATE(11171)] = 533809,
  [SMALL_STATE(11172)] = 533872,
  [SMALL_STATE(11173)] = 533913,
  [SMALL_STATE(11174)] = 533950,
  [SMALL_STATE(11175)] = 533993,
  [SMALL_STATE(11176)] = 534040,
  [SMALL_STATE(11177)] = 534083,
  [SMALL_STATE(11178)] = 534122,
  [SMALL_STATE(11179)] = 534159,
  [SMALL_STATE(11180)] = 534220,
  [SMALL_STATE(11181)] = 534257,
  [SMALL_STATE(11182)] = 534294,
  [SMALL_STATE(11183)] = 534331,
  [SMALL_STATE(11184)] = 534378,
  [SMALL_STATE(11185)] = 534441,
  [SMALL_STATE(11186)] = 534478,
  [SMALL_STATE(11187)] = 534515,
  [SMALL_STATE(11188)] = 534552,
  [SMALL_STATE(11189)] = 534589,
  [SMALL_STATE(11190)] = 534626,
  [SMALL_STATE(11191)] = 534669,
  [SMALL_STATE(11192)] = 534706,
  [SMALL_STATE(11193)] = 534749,
  [SMALL_STATE(11194)] = 534792,
  [SMALL_STATE(11195)] = 534835,
  [SMALL_STATE(11196)] = 534878,
  [SMALL_STATE(11197)] = 534921,
  [SMALL_STATE(11198)] = 534984,
  [SMALL_STATE(11199)] = 535025,
  [SMALL_STATE(11200)] = 535068,
  [SMALL_STATE(11201)] = 535111,
  [SMALL_STATE(11202)] = 535154,
  [SMALL_STATE(11203)] = 535191,
  [SMALL_STATE(11204)] = 535228,
  [SMALL_STATE(11205)] = 535265,
  [SMALL_STATE(11206)] = 535308,
  [SMALL_STATE(11207)] = 535345,
  [SMALL_STATE(11208)] = 535382,
  [SMALL_STATE(11209)] = 535419,
  [SMALL_STATE(11210)] = 535482,
  [SMALL_STATE(11211)] = 535525,
  [SMALL_STATE(11212)] = 535562,
  [SMALL_STATE(11213)] = 535605,
  [SMALL_STATE(11214)] = 535648,
  [SMALL_STATE(11215)] = 535685,
  [SMALL_STATE(11216)] = 535728,
  [SMALL_STATE(11217)] = 535771,
  [SMALL_STATE(11218)] = 535834,
  [SMALL_STATE(11219)] = 535877,
  [SMALL_STATE(11220)] = 535920,
  [SMALL_STATE(11221)] = 535959,
  [SMALL_STATE(11222)] = 536002,
  [SMALL_STATE(11223)] = 536045,
  [SMALL_STATE(11224)] = 536088,
  [SMALL_STATE(11225)] = 536131,
  [SMALL_STATE(11226)] = 536168,
  [SMALL_STATE(11227)] = 536231,
  [SMALL_STATE(11228)] = 536274,
  [SMALL_STATE(11229)] = 536311,
  [SMALL_STATE(11230)] = 536354,
  [SMALL_STATE(11231)] = 536397,
  [SMALL_STATE(11232)] = 536440,
  [SMALL_STATE(11233)] = 536483,
  [SMALL_STATE(11234)] = 536530,
  [SMALL_STATE(11235)] = 536593,
  [SMALL_STATE(11236)] = 536640,
  [SMALL_STATE(11237)] = 536683,
  [SMALL_STATE(11238)] = 536726,
  [SMALL_STATE(11239)] = 536769,
  [SMALL_STATE(11240)] = 536812,
  [SMALL_STATE(11241)] = 536855,
  [SMALL_STATE(11242)] = 536896,
  [SMALL_STATE(11243)] = 536959,
  [SMALL_STATE(11244)] = 537000,
  [SMALL_STATE(11245)] = 537039,
  [SMALL_STATE(11246)] = 537082,
  [SMALL_STATE(11247)] = 537125,
  [SMALL_STATE(11248)] = 537166,
  [SMALL_STATE(11249)] = 537215,
  [SMALL_STATE(11250)] = 537275,
  [SMALL_STATE(11251)] = 537335,
  [SMALL_STATE(11252)] = 537371,
  [SMALL_STATE(11253)] = 537407,
  [SMALL_STATE(11254)] = 537453,
  [SMALL_STATE(11255)] = 537489,
  [SMALL_STATE(11256)] = 537525,
  [SMALL_STATE(11257)] = 537561,
  [SMALL_STATE(11258)] = 537597,
  [SMALL_STATE(11259)] = 537657,
  [SMALL_STATE(11260)] = 537703,
  [SMALL_STATE(11261)] = 537739,
  [SMALL_STATE(11262)] = 537777,
  [SMALL_STATE(11263)] = 537813,
  [SMALL_STATE(11264)] = 537871,
  [SMALL_STATE(11265)] = 537931,
  [SMALL_STATE(11266)] = 537967,
  [SMALL_STATE(11267)] = 538013,
  [SMALL_STATE(11268)] = 538057,
  [SMALL_STATE(11269)] = 538117,
  [SMALL_STATE(11270)] = 538177,
  [SMALL_STATE(11271)] = 538213,
  [SMALL_STATE(11272)] = 538259,
  [SMALL_STATE(11273)] = 538295,
  [SMALL_STATE(11274)] = 538331,
  [SMALL_STATE(11275)] = 538367,
  [SMALL_STATE(11276)] = 538409,
  [SMALL_STATE(11277)] = 538445,
  [SMALL_STATE(11278)] = 538491,
  [SMALL_STATE(11279)] = 538527,
  [SMALL_STATE(11280)] = 538563,
  [SMALL_STATE(11281)] = 538599,
  [SMALL_STATE(11282)] = 538635,
  [SMALL_STATE(11283)] = 538695,
  [SMALL_STATE(11284)] = 538737,
  [SMALL_STATE(11285)] = 538773,
  [SMALL_STATE(11286)] = 538827,
  [SMALL_STATE(11287)] = 538873,
  [SMALL_STATE(11288)] = 538909,
  [SMALL_STATE(11289)] = 538955,
  [SMALL_STATE(11290)] = 538997,
  [SMALL_STATE(11291)] = 539039,
  [SMALL_STATE(11292)] = 539085,
  [SMALL_STATE(11293)] = 539145,
  [SMALL_STATE(11294)] = 539185,
  [SMALL_STATE(11295)] = 539245,
  [SMALL_STATE(11296)] = 539281,
  [SMALL_STATE(11297)] = 539341,
  [SMALL_STATE(11298)] = 539381,
  [SMALL_STATE(11299)] = 539423,
  [SMALL_STATE(11300)] = 539483,
  [SMALL_STATE(11301)] = 539519,
  [SMALL_STATE(11302)] = 539561,
  [SMALL_STATE(11303)] = 539597,
  [SMALL_STATE(11304)] = 539639,
  [SMALL_STATE(11305)] = 539679,
  [SMALL_STATE(11306)] = 539719,
  [SMALL_STATE(11307)] = 539755,
  [SMALL_STATE(11308)] = 539797,
  [SMALL_STATE(11309)] = 539833,
  [SMALL_STATE(11310)] = 539879,
  [SMALL_STATE(11311)] = 539939,
  [SMALL_STATE(11312)] = 539975,
  [SMALL_STATE(11313)] = 540011,
  [SMALL_STATE(11314)] = 540047,
  [SMALL_STATE(11315)] = 540083,
  [SMALL_STATE(11316)] = 540119,
  [SMALL_STATE(11317)] = 540155,
  [SMALL_STATE(11318)] = 540215,
  [SMALL_STATE(11319)] = 540275,
  [SMALL_STATE(11320)] = 540311,
  [SMALL_STATE(11321)] = 540347,
  [SMALL_STATE(11322)] = 540395,
  [SMALL_STATE(11323)] = 540431,
  [SMALL_STATE(11324)] = 540467,
  [SMALL_STATE(11325)] = 540503,
  [SMALL_STATE(11326)] = 540551,
  [SMALL_STATE(11327)] = 540587,
  [SMALL_STATE(11328)] = 540623,
  [SMALL_STATE(11329)] = 540659,
  [SMALL_STATE(11330)] = 540695,
  [SMALL_STATE(11331)] = 540737,
  [SMALL_STATE(11332)] = 540789,
  [SMALL_STATE(11333)] = 540825,
  [SMALL_STATE(11334)] = 540863,
  [SMALL_STATE(11335)] = 540899,
  [SMALL_STATE(11336)] = 540959,
  [SMALL_STATE(11337)] = 540995,
  [SMALL_STATE(11338)] = 541031,
  [SMALL_STATE(11339)] = 541077,
  [SMALL_STATE(11340)] = 541123,
  [SMALL_STATE(11341)] = 541169,
  [SMALL_STATE(11342)] = 541205,
  [SMALL_STATE(11343)] = 541265,
  [SMALL_STATE(11344)] = 541325,
  [SMALL_STATE(11345)] = 541361,
  [SMALL_STATE(11346)] = 541407,
  [SMALL_STATE(11347)] = 541443,
  [SMALL_STATE(11348)] = 541479,
  [SMALL_STATE(11349)] = 541525,
  [SMALL_STATE(11350)] = 541561,
  [SMALL_STATE(11351)] = 541597,
  [SMALL_STATE(11352)] = 541633,
  [SMALL_STATE(11353)] = 541675,
  [SMALL_STATE(11354)] = 541711,
  [SMALL_STATE(11355)] = 541771,
  [SMALL_STATE(11356)] = 541807,
  [SMALL_STATE(11357)] = 541843,
  [SMALL_STATE(11358)] = 541879,
  [SMALL_STATE(11359)] = 541923,
  [SMALL_STATE(11360)] = 541959,
  [SMALL_STATE(11361)] = 542019,
  [SMALL_STATE(11362)] = 542055,
  [SMALL_STATE(11363)] = 542091,
  [SMALL_STATE(11364)] = 542127,
  [SMALL_STATE(11365)] = 542163,
  [SMALL_STATE(11366)] = 542199,
  [SMALL_STATE(11367)] = 542259,
  [SMALL_STATE(11368)] = 542305,
  [SMALL_STATE(11369)] = 542353,
  [SMALL_STATE(11370)] = 542413,
  [SMALL_STATE(11371)] = 542459,
  [SMALL_STATE(11372)] = 542501,
  [SMALL_STATE(11373)] = 542561,
  [SMALL_STATE(11374)] = 542621,
  [SMALL_STATE(11375)] = 542657,
  [SMALL_STATE(11376)] = 542703,
  [SMALL_STATE(11377)] = 542739,
  [SMALL_STATE(11378)] = 542775,
  [SMALL_STATE(11379)] = 542835,
  [SMALL_STATE(11380)] = 542895,
  [SMALL_STATE(11381)] = 542931,
  [SMALL_STATE(11382)] = 542967,
  [SMALL_STATE(11383)] = 543013,
  [SMALL_STATE(11384)] = 543051,
  [SMALL_STATE(11385)] = 543087,
  [SMALL_STATE(11386)] = 543123,
  [SMALL_STATE(11387)] = 543161,
  [SMALL_STATE(11388)] = 543199,
  [SMALL_STATE(11389)] = 543235,
  [SMALL_STATE(11390)] = 543273,
  [SMALL_STATE(11391)] = 543319,
  [SMALL_STATE(11392)] = 543365,
  [SMALL_STATE(11393)] = 543411,
  [SMALL_STATE(11394)] = 543447,
  [SMALL_STATE(11395)] = 543507,
  [SMALL_STATE(11396)] = 543565,
  [SMALL_STATE(11397)] = 543607,
  [SMALL_STATE(11398)] = 543649,
  [SMALL_STATE(11399)] = 543685,
  [SMALL_STATE(11400)] = 543721,
  [SMALL_STATE(11401)] = 543781,
  [SMALL_STATE(11402)] = 543817,
  [SMALL_STATE(11403)] = 543877,
  [SMALL_STATE(11404)] = 543937,
  [SMALL_STATE(11405)] = 543997,
  [SMALL_STATE(11406)] = 544039,
  [SMALL_STATE(11407)] = 544075,
  [SMALL_STATE(11408)] = 544121,
  [SMALL_STATE(11409)] = 544157,
  [SMALL_STATE(11410)] = 544203,
  [SMALL_STATE(11411)] = 544263,
  [SMALL_STATE(11412)] = 544309,
  [SMALL_STATE(11413)] = 544355,
  [SMALL_STATE(11414)] = 544415,
  [SMALL_STATE(11415)] = 544461,
  [SMALL_STATE(11416)] = 544497,
  [SMALL_STATE(11417)] = 544533,
  [SMALL_STATE(11418)] = 544579,
  [SMALL_STATE(11419)] = 544617,
  [SMALL_STATE(11420)] = 544663,
  [SMALL_STATE(11421)] = 544709,
  [SMALL_STATE(11422)] = 544755,
  [SMALL_STATE(11423)] = 544815,
  [SMALL_STATE(11424)] = 544861,
  [SMALL_STATE(11425)] = 544909,
  [SMALL_STATE(11426)] = 544969,
  [SMALL_STATE(11427)] = 545009,
  [SMALL_STATE(11428)] = 545055,
  [SMALL_STATE(11429)] = 545091,
  [SMALL_STATE(11430)] = 545127,
  [SMALL_STATE(11431)] = 545165,
  [SMALL_STATE(11432)] = 545211,
  [SMALL_STATE(11433)] = 545247,
  [SMALL_STATE(11434)] = 545283,
  [SMALL_STATE(11435)] = 545325,
  [SMALL_STATE(11436)] = 545385,
  [SMALL_STATE(11437)] = 545445,
  [SMALL_STATE(11438)] = 545481,
  [SMALL_STATE(11439)] = 545517,
  [SMALL_STATE(11440)] = 545553,
  [SMALL_STATE(11441)] = 545595,
  [SMALL_STATE(11442)] = 545655,
  [SMALL_STATE(11443)] = 545701,
  [SMALL_STATE(11444)] = 545747,
  [SMALL_STATE(11445)] = 545783,
  [SMALL_STATE(11446)] = 545819,
  [SMALL_STATE(11447)] = 545861,
  [SMALL_STATE(11448)] = 545897,
  [SMALL_STATE(11449)] = 545957,
  [SMALL_STATE(11450)] = 546003,
  [SMALL_STATE(11451)] = 546049,
  [SMALL_STATE(11452)] = 546085,
  [SMALL_STATE(11453)] = 546125,
  [SMALL_STATE(11454)] = 546161,
  [SMALL_STATE(11455)] = 546207,
  [SMALL_STATE(11456)] = 546249,
  [SMALL_STATE(11457)] = 546295,
  [SMALL_STATE(11458)] = 546345,
  [SMALL_STATE(11459)] = 546383,
  [SMALL_STATE(11460)] = 546419,
  [SMALL_STATE(11461)] = 546465,
  [SMALL_STATE(11462)] = 546505,
  [SMALL_STATE(11463)] = 546541,
  [SMALL_STATE(11464)] = 546577,
  [SMALL_STATE(11465)] = 546637,
  [SMALL_STATE(11466)] = 546673,
  [SMALL_STATE(11467)] = 546733,
  [SMALL_STATE(11468)] = 546793,
  [SMALL_STATE(11469)] = 546829,
  [SMALL_STATE(11470)] = 546865,
  [SMALL_STATE(11471)] = 546901,
  [SMALL_STATE(11472)] = 546937,
  [SMALL_STATE(11473)] = 546973,
  [SMALL_STATE(11474)] = 547019,
  [SMALL_STATE(11475)] = 547055,
  [SMALL_STATE(11476)] = 547115,
  [SMALL_STATE(11477)] = 547161,
  [SMALL_STATE(11478)] = 547197,
  [SMALL_STATE(11479)] = 547233,
  [SMALL_STATE(11480)] = 547275,
  [SMALL_STATE(11481)] = 547311,
  [SMALL_STATE(11482)] = 547351,
  [SMALL_STATE(11483)] = 547387,
  [SMALL_STATE(11484)] = 547427,
  [SMALL_STATE(11485)] = 547467,
  [SMALL_STATE(11486)] = 547503,
  [SMALL_STATE(11487)] = 547543,
  [SMALL_STATE(11488)] = 547589,
  [SMALL_STATE(11489)] = 547635,
  [SMALL_STATE(11490)] = 547677,
  [SMALL_STATE(11491)] = 547713,
  [SMALL_STATE(11492)] = 547749,
  [SMALL_STATE(11493)] = 547795,
  [SMALL_STATE(11494)] = 547841,
  [SMALL_STATE(11495)] = 547901,
  [SMALL_STATE(11496)] = 547961,
  [SMALL_STATE(11497)] = 548007,
  [SMALL_STATE(11498)] = 548067,
  [SMALL_STATE(11499)] = 548103,
  [SMALL_STATE(11500)] = 548149,
  [SMALL_STATE(11501)] = 548195,
  [SMALL_STATE(11502)] = 548235,
  [SMALL_STATE(11503)] = 548295,
  [SMALL_STATE(11504)] = 548331,
  [SMALL_STATE(11505)] = 548377,
  [SMALL_STATE(11506)] = 548413,
  [SMALL_STATE(11507)] = 548459,
  [SMALL_STATE(11508)] = 548495,
  [SMALL_STATE(11509)] = 548531,
  [SMALL_STATE(11510)] = 548567,
  [SMALL_STATE(11511)] = 548627,
  [SMALL_STATE(11512)] = 548685,
  [SMALL_STATE(11513)] = 548723,
  [SMALL_STATE(11514)] = 548783,
  [SMALL_STATE(11515)] = 548821,
  [SMALL_STATE(11516)] = 548863,
  [SMALL_STATE(11517)] = 548903,
  [SMALL_STATE(11518)] = 548949,
  [SMALL_STATE(11519)] = 548985,
  [SMALL_STATE(11520)] = 549041,
  [SMALL_STATE(11521)] = 549077,
  [SMALL_STATE(11522)] = 549113,
  [SMALL_STATE(11523)] = 549159,
  [SMALL_STATE(11524)] = 549195,
  [SMALL_STATE(11525)] = 549241,
  [SMALL_STATE(11526)] = 549301,
  [SMALL_STATE(11527)] = 549361,
  [SMALL_STATE(11528)] = 549407,
  [SMALL_STATE(11529)] = 549449,
  [SMALL_STATE(11530)] = 549485,
  [SMALL_STATE(11531)] = 549545,
  [SMALL_STATE(11532)] = 549605,
  [SMALL_STATE(11533)] = 549647,
  [SMALL_STATE(11534)] = 549683,
  [SMALL_STATE(11535)] = 549719,
  [SMALL_STATE(11536)] = 549755,
  [SMALL_STATE(11537)] = 549815,
  [SMALL_STATE(11538)] = 549875,
  [SMALL_STATE(11539)] = 549911,
  [SMALL_STATE(11540)] = 549971,
  [SMALL_STATE(11541)] = 550031,
  [SMALL_STATE(11542)] = 550091,
  [SMALL_STATE(11543)] = 550151,
  [SMALL_STATE(11544)] = 550211,
  [SMALL_STATE(11545)] = 550251,
  [SMALL_STATE(11546)] = 550291,
  [SMALL_STATE(11547)] = 550331,
  [SMALL_STATE(11548)] = 550371,
  [SMALL_STATE(11549)] = 550411,
  [SMALL_STATE(11550)] = 550471,
  [SMALL_STATE(11551)] = 550531,
  [SMALL_STATE(11552)] = 550591,
  [SMALL_STATE(11553)] = 550651,
  [SMALL_STATE(11554)] = 550687,
  [SMALL_STATE(11555)] = 550723,
  [SMALL_STATE(11556)] = 550783,
  [SMALL_STATE(11557)] = 550843,
  [SMALL_STATE(11558)] = 550903,
  [SMALL_STATE(11559)] = 550963,
  [SMALL_STATE(11560)] = 551023,
  [SMALL_STATE(11561)] = 551083,
  [SMALL_STATE(11562)] = 551143,
  [SMALL_STATE(11563)] = 551203,
  [SMALL_STATE(11564)] = 551263,
  [SMALL_STATE(11565)] = 551323,
  [SMALL_STATE(11566)] = 551361,
  [SMALL_STATE(11567)] = 551421,
  [SMALL_STATE(11568)] = 551481,
  [SMALL_STATE(11569)] = 551527,
  [SMALL_STATE(11570)] = 551566,
  [SMALL_STATE(11571)] = 551611,
  [SMALL_STATE(11572)] = 551654,
  [SMALL_STATE(11573)] = 551699,
  [SMALL_STATE(11574)] = 551756,
  [SMALL_STATE(11575)] = 551801,
  [SMALL_STATE(11576)] = 551838,
  [SMALL_STATE(11577)] = 551873,
  [SMALL_STATE(11578)] = 551908,
  [SMALL_STATE(11579)] = 551947,
  [SMALL_STATE(11580)] = 551992,
  [SMALL_STATE(11581)] = 552037,
  [SMALL_STATE(11582)] = 552082,
  [SMALL_STATE(11583)] = 552117,
  [SMALL_STATE(11584)] = 552162,
  [SMALL_STATE(11585)] = 552207,
  [SMALL_STATE(11586)] = 552242,
  [SMALL_STATE(11587)] = 552287,
  [SMALL_STATE(11588)] = 552332,
  [SMALL_STATE(11589)] = 552375,
  [SMALL_STATE(11590)] = 552432,
  [SMALL_STATE(11591)] = 552483,
  [SMALL_STATE(11592)] = 552536,
  [SMALL_STATE(11593)] = 552593,
  [SMALL_STATE(11594)] = 552634,
  [SMALL_STATE(11595)] = 552691,
  [SMALL_STATE(11596)] = 552748,
  [SMALL_STATE(11597)] = 552785,
  [SMALL_STATE(11598)] = 552820,
  [SMALL_STATE(11599)] = 552877,
  [SMALL_STATE(11600)] = 552934,
  [SMALL_STATE(11601)] = 552977,
  [SMALL_STATE(11602)] = 553034,
  [SMALL_STATE(11603)] = 553073,
  [SMALL_STATE(11604)] = 553130,
  [SMALL_STATE(11605)] = 553175,
  [SMALL_STATE(11606)] = 553232,
  [SMALL_STATE(11607)] = 553267,
  [SMALL_STATE(11608)] = 553324,
  [SMALL_STATE(11609)] = 553365,
  [SMALL_STATE(11610)] = 553404,
  [SMALL_STATE(11611)] = 553461,
  [SMALL_STATE(11612)] = 553508,
  [SMALL_STATE(11613)] = 553549,
  [SMALL_STATE(11614)] = 553584,
  [SMALL_STATE(11615)] = 553641,
  [SMALL_STATE(11616)] = 553698,
  [SMALL_STATE(11617)] = 553737,
  [SMALL_STATE(11618)] = 553782,
  [SMALL_STATE(11619)] = 553839,
  [SMALL_STATE(11620)] = 553878,
  [SMALL_STATE(11621)] = 553917,
  [SMALL_STATE(11622)] = 553956,
  [SMALL_STATE(11623)] = 554013,
  [SMALL_STATE(11624)] = 554052,
  [SMALL_STATE(11625)] = 554089,
  [SMALL_STATE(11626)] = 554124,
  [SMALL_STATE(11627)] = 554159,
  [SMALL_STATE(11628)] = 554198,
  [SMALL_STATE(11629)] = 554235,
  [SMALL_STATE(11630)] = 554274,
  [SMALL_STATE(11631)] = 554331,
  [SMALL_STATE(11632)] = 554366,
  [SMALL_STATE(11633)] = 554423,
  [SMALL_STATE(11634)] = 554468,
  [SMALL_STATE(11635)] = 554509,
  [SMALL_STATE(11636)] = 554552,
  [SMALL_STATE(11637)] = 554611,
  [SMALL_STATE(11638)] = 554668,
  [SMALL_STATE(11639)] = 554703,
  [SMALL_STATE(11640)] = 554746,
  [SMALL_STATE(11641)] = 554803,
  [SMALL_STATE(11642)] = 554860,
  [SMALL_STATE(11643)] = 554917,
  [SMALL_STATE(11644)] = 554974,
  [SMALL_STATE(11645)] = 555009,
  [SMALL_STATE(11646)] = 555066,
  [SMALL_STATE(11647)] = 555101,
  [SMALL_STATE(11648)] = 555158,
  [SMALL_STATE(11649)] = 555193,
  [SMALL_STATE(11650)] = 555232,
  [SMALL_STATE(11651)] = 555289,
  [SMALL_STATE(11652)] = 555324,
  [SMALL_STATE(11653)] = 555363,
  [SMALL_STATE(11654)] = 555406,
  [SMALL_STATE(11655)] = 555449,
  [SMALL_STATE(11656)] = 555484,
  [SMALL_STATE(11657)] = 555521,
  [SMALL_STATE(11658)] = 555578,
  [SMALL_STATE(11659)] = 555633,
  [SMALL_STATE(11660)] = 555690,
  [SMALL_STATE(11661)] = 555733,
  [SMALL_STATE(11662)] = 555778,
  [SMALL_STATE(11663)] = 555821,
  [SMALL_STATE(11664)] = 555878,
  [SMALL_STATE(11665)] = 555919,
  [SMALL_STATE(11666)] = 555958,
  [SMALL_STATE(11667)] = 555997,
  [SMALL_STATE(11668)] = 556034,
  [SMALL_STATE(11669)] = 556073,
  [SMALL_STATE(11670)] = 556108,
  [SMALL_STATE(11671)] = 556165,
  [SMALL_STATE(11672)] = 556202,
  [SMALL_STATE(11673)] = 556247,
  [SMALL_STATE(11674)] = 556282,
  [SMALL_STATE(11675)] = 556317,
  [SMALL_STATE(11676)] = 556352,
  [SMALL_STATE(11677)] = 556391,
  [SMALL_STATE(11678)] = 556426,
  [SMALL_STATE(11679)] = 556471,
  [SMALL_STATE(11680)] = 556508,
  [SMALL_STATE(11681)] = 556551,
  [SMALL_STATE(11682)] = 556596,
  [SMALL_STATE(11683)] = 556631,
  [SMALL_STATE(11684)] = 556666,
  [SMALL_STATE(11685)] = 556701,
  [SMALL_STATE(11686)] = 556746,
  [SMALL_STATE(11687)] = 556787,
  [SMALL_STATE(11688)] = 556826,
  [SMALL_STATE(11689)] = 556883,
  [SMALL_STATE(11690)] = 556922,
  [SMALL_STATE(11691)] = 556959,
  [SMALL_STATE(11692)] = 557016,
  [SMALL_STATE(11693)] = 557061,
  [SMALL_STATE(11694)] = 557106,
  [SMALL_STATE(11695)] = 557151,
  [SMALL_STATE(11696)] = 557186,
  [SMALL_STATE(11697)] = 557225,
  [SMALL_STATE(11698)] = 557270,
  [SMALL_STATE(11699)] = 557313,
  [SMALL_STATE(11700)] = 557370,
  [SMALL_STATE(11701)] = 557415,
  [SMALL_STATE(11702)] = 557472,
  [SMALL_STATE(11703)] = 557529,
  [SMALL_STATE(11704)] = 557572,
  [SMALL_STATE(11705)] = 557615,
  [SMALL_STATE(11706)] = 557656,
  [SMALL_STATE(11707)] = 557695,
  [SMALL_STATE(11708)] = 557744,
  [SMALL_STATE(11709)] = 557779,
  [SMALL_STATE(11710)] = 557836,
  [SMALL_STATE(11711)] = 557893,
  [SMALL_STATE(11712)] = 557928,
  [SMALL_STATE(11713)] = 557963,
  [SMALL_STATE(11714)] = 558000,
  [SMALL_STATE(11715)] = 558057,
  [SMALL_STATE(11716)] = 558092,
  [SMALL_STATE(11717)] = 558127,
  [SMALL_STATE(11718)] = 558170,
  [SMALL_STATE(11719)] = 558227,
  [SMALL_STATE(11720)] = 558264,
  [SMALL_STATE(11721)] = 558303,
  [SMALL_STATE(11722)] = 558342,
  [SMALL_STATE(11723)] = 558385,
  [SMALL_STATE(11724)] = 558444,
  [SMALL_STATE(11725)] = 558479,
  [SMALL_STATE(11726)] = 558514,
  [SMALL_STATE(11727)] = 558549,
  [SMALL_STATE(11728)] = 558584,
  [SMALL_STATE(11729)] = 558629,
  [SMALL_STATE(11730)] = 558674,
  [SMALL_STATE(11731)] = 558711,
  [SMALL_STATE(11732)] = 558756,
  [SMALL_STATE(11733)] = 558799,
  [SMALL_STATE(11734)] = 558838,
  [SMALL_STATE(11735)] = 558873,
  [SMALL_STATE(11736)] = 558932,
  [SMALL_STATE(11737)] = 558977,
  [SMALL_STATE(11738)] = 559016,
  [SMALL_STATE(11739)] = 559051,
  [SMALL_STATE(11740)] = 559108,
  [SMALL_STATE(11741)] = 559165,
  [SMALL_STATE(11742)] = 559204,
  [SMALL_STATE(11743)] = 559247,
  [SMALL_STATE(11744)] = 559286,
  [SMALL_STATE(11745)] = 559331,
  [SMALL_STATE(11746)] = 559388,
  [SMALL_STATE(11747)] = 559433,
  [SMALL_STATE(11748)] = 559478,
  [SMALL_STATE(11749)] = 559523,
  [SMALL_STATE(11750)] = 559566,
  [SMALL_STATE(11751)] = 559611,
  [SMALL_STATE(11752)] = 559654,
  [SMALL_STATE(11753)] = 559711,
  [SMALL_STATE(11754)] = 559756,
  [SMALL_STATE(11755)] = 559813,
  [SMALL_STATE(11756)] = 559852,
  [SMALL_STATE(11757)] = 559887,
  [SMALL_STATE(11758)] = 559926,
  [SMALL_STATE(11759)] = 559969,
  [SMALL_STATE(11760)] = 560012,
  [SMALL_STATE(11761)] = 560059,
  [SMALL_STATE(11762)] = 560104,
  [SMALL_STATE(11763)] = 560139,
  [SMALL_STATE(11764)] = 560184,
  [SMALL_STATE(11765)] = 560227,
  [SMALL_STATE(11766)] = 560262,
  [SMALL_STATE(11767)] = 560307,
  [SMALL_STATE(11768)] = 560352,
  [SMALL_STATE(11769)] = 560409,
  [SMALL_STATE(11770)] = 560454,
  [SMALL_STATE(11771)] = 560499,
  [SMALL_STATE(11772)] = 560556,
  [SMALL_STATE(11773)] = 560601,
  [SMALL_STATE(11774)] = 560646,
  [SMALL_STATE(11775)] = 560691,
  [SMALL_STATE(11776)] = 560736,
  [SMALL_STATE(11777)] = 560793,
  [SMALL_STATE(11778)] = 560850,
  [SMALL_STATE(11779)] = 560907,
  [SMALL_STATE(11780)] = 560946,
  [SMALL_STATE(11781)] = 560991,
  [SMALL_STATE(11782)] = 561036,
  [SMALL_STATE(11783)] = 561081,
  [SMALL_STATE(11784)] = 561126,
  [SMALL_STATE(11785)] = 561165,
  [SMALL_STATE(11786)] = 561210,
  [SMALL_STATE(11787)] = 561255,
  [SMALL_STATE(11788)] = 561312,
  [SMALL_STATE(11789)] = 561369,
  [SMALL_STATE(11790)] = 561412,
  [SMALL_STATE(11791)] = 561455,
  [SMALL_STATE(11792)] = 561502,
  [SMALL_STATE(11793)] = 561547,
  [SMALL_STATE(11794)] = 561586,
  [SMALL_STATE(11795)] = 561626,
  [SMALL_STATE(11796)] = 561680,
  [SMALL_STATE(11797)] = 561734,
  [SMALL_STATE(11798)] = 561788,
  [SMALL_STATE(11799)] = 561842,
  [SMALL_STATE(11800)] = 561896,
  [SMALL_STATE(11801)] = 561950,
  [SMALL_STATE(11802)] = 562004,
  [SMALL_STATE(11803)] = 562058,
  [SMALL_STATE(11804)] = 562112,
  [SMALL_STATE(11805)] = 562166,
  [SMALL_STATE(11806)] = 562220,
  [SMALL_STATE(11807)] = 562274,
  [SMALL_STATE(11808)] = 562328,
  [SMALL_STATE(11809)] = 562382,
  [SMALL_STATE(11810)] = 562436,
  [SMALL_STATE(11811)] = 562490,
  [SMALL_STATE(11812)] = 562544,
  [SMALL_STATE(11813)] = 562598,
  [SMALL_STATE(11814)] = 562652,
  [SMALL_STATE(11815)] = 562706,
  [SMALL_STATE(11816)] = 562760,
  [SMALL_STATE(11817)] = 562814,
  [SMALL_STATE(11818)] = 562872,
  [SMALL_STATE(11819)] = 562926,
  [SMALL_STATE(11820)] = 562964,
  [SMALL_STATE(11821)] = 563018,
  [SMALL_STATE(11822)] = 563076,
  [SMALL_STATE(11823)] = 563130,
  [SMALL_STATE(11824)] = 563170,
  [SMALL_STATE(11825)] = 563224,
  [SMALL_STATE(11826)] = 563278,
  [SMALL_STATE(11827)] = 563332,
  [SMALL_STATE(11828)] = 563386,
  [SMALL_STATE(11829)] = 563440,
  [SMALL_STATE(11830)] = 563494,
  [SMALL_STATE(11831)] = 563548,
  [SMALL_STATE(11832)] = 563606,
  [SMALL_STATE(11833)] = 563660,
  [SMALL_STATE(11834)] = 563712,
  [SMALL_STATE(11835)] = 563766,
  [SMALL_STATE(11836)] = 563802,
  [SMALL_STATE(11837)] = 563856,
  [SMALL_STATE(11838)] = 563896,
  [SMALL_STATE(11839)] = 563936,
  [SMALL_STATE(11840)] = 563990,
  [SMALL_STATE(11841)] = 564044,
  [SMALL_STATE(11842)] = 564098,
  [SMALL_STATE(11843)] = 564152,
  [SMALL_STATE(11844)] = 564206,
  [SMALL_STATE(11845)] = 564260,
  [SMALL_STATE(11846)] = 564314,
  [SMALL_STATE(11847)] = 564368,
  [SMALL_STATE(11848)] = 564422,
  [SMALL_STATE(11849)] = 564480,
  [SMALL_STATE(11850)] = 564522,
  [SMALL_STATE(11851)] = 564576,
  [SMALL_STATE(11852)] = 564630,
  [SMALL_STATE(11853)] = 564684,
  [SMALL_STATE(11854)] = 564738,
  [SMALL_STATE(11855)] = 564792,
  [SMALL_STATE(11856)] = 564846,
  [SMALL_STATE(11857)] = 564900,
  [SMALL_STATE(11858)] = 564954,
  [SMALL_STATE(11859)] = 565008,
  [SMALL_STATE(11860)] = 565062,
  [SMALL_STATE(11861)] = 565116,
  [SMALL_STATE(11862)] = 565170,
  [SMALL_STATE(11863)] = 565224,
  [SMALL_STATE(11864)] = 565278,
  [SMALL_STATE(11865)] = 565332,
  [SMALL_STATE(11866)] = 565368,
  [SMALL_STATE(11867)] = 565422,
  [SMALL_STATE(11868)] = 565476,
  [SMALL_STATE(11869)] = 565530,
  [SMALL_STATE(11870)] = 565584,
  [SMALL_STATE(11871)] = 565638,
  [SMALL_STATE(11872)] = 565692,
  [SMALL_STATE(11873)] = 565746,
  [SMALL_STATE(11874)] = 565800,
  [SMALL_STATE(11875)] = 565854,
  [SMALL_STATE(11876)] = 565908,
  [SMALL_STATE(11877)] = 565962,
  [SMALL_STATE(11878)] = 566016,
  [SMALL_STATE(11879)] = 566070,
  [SMALL_STATE(11880)] = 566124,
  [SMALL_STATE(11881)] = 566178,
  [SMALL_STATE(11882)] = 566232,
  [SMALL_STATE(11883)] = 566286,
  [SMALL_STATE(11884)] = 566340,
  [SMALL_STATE(11885)] = 566394,
  [SMALL_STATE(11886)] = 566434,
  [SMALL_STATE(11887)] = 566488,
  [SMALL_STATE(11888)] = 566542,
  [SMALL_STATE(11889)] = 566596,
  [SMALL_STATE(11890)] = 566650,
  [SMALL_STATE(11891)] = 566704,
  [SMALL_STATE(11892)] = 566758,
  [SMALL_STATE(11893)] = 566812,
  [SMALL_STATE(11894)] = 566866,
  [SMALL_STATE(11895)] = 566920,
  [SMALL_STATE(11896)] = 566974,
  [SMALL_STATE(11897)] = 567028,
  [SMALL_STATE(11898)] = 567082,
  [SMALL_STATE(11899)] = 567136,
  [SMALL_STATE(11900)] = 567190,
  [SMALL_STATE(11901)] = 567244,
  [SMALL_STATE(11902)] = 567298,
  [SMALL_STATE(11903)] = 567352,
  [SMALL_STATE(11904)] = 567406,
  [SMALL_STATE(11905)] = 567460,
  [SMALL_STATE(11906)] = 567514,
  [SMALL_STATE(11907)] = 567568,
  [SMALL_STATE(11908)] = 567622,
  [SMALL_STATE(11909)] = 567676,
  [SMALL_STATE(11910)] = 567730,
  [SMALL_STATE(11911)] = 567770,
  [SMALL_STATE(11912)] = 567824,
  [SMALL_STATE(11913)] = 567862,
  [SMALL_STATE(11914)] = 567916,
  [SMALL_STATE(11915)] = 567956,
  [SMALL_STATE(11916)] = 568010,
  [SMALL_STATE(11917)] = 568064,
  [SMALL_STATE(11918)] = 568118,
  [SMALL_STATE(11919)] = 568172,
  [SMALL_STATE(11920)] = 568226,
  [SMALL_STATE(11921)] = 568280,
  [SMALL_STATE(11922)] = 568334,
  [SMALL_STATE(11923)] = 568388,
  [SMALL_STATE(11924)] = 568442,
  [SMALL_STATE(11925)] = 568496,
  [SMALL_STATE(11926)] = 568550,
  [SMALL_STATE(11927)] = 568604,
  [SMALL_STATE(11928)] = 568658,
  [SMALL_STATE(11929)] = 568712,
  [SMALL_STATE(11930)] = 568766,
  [SMALL_STATE(11931)] = 568820,
  [SMALL_STATE(11932)] = 568874,
  [SMALL_STATE(11933)] = 568928,
  [SMALL_STATE(11934)] = 568982,
  [SMALL_STATE(11935)] = 569036,
  [SMALL_STATE(11936)] = 569090,
  [SMALL_STATE(11937)] = 569144,
  [SMALL_STATE(11938)] = 569198,
  [SMALL_STATE(11939)] = 569252,
  [SMALL_STATE(11940)] = 569306,
  [SMALL_STATE(11941)] = 569360,
  [SMALL_STATE(11942)] = 569414,
  [SMALL_STATE(11943)] = 569468,
  [SMALL_STATE(11944)] = 569508,
  [SMALL_STATE(11945)] = 569562,
  [SMALL_STATE(11946)] = 569616,
  [SMALL_STATE(11947)] = 569670,
  [SMALL_STATE(11948)] = 569724,
  [SMALL_STATE(11949)] = 569778,
  [SMALL_STATE(11950)] = 569832,
  [SMALL_STATE(11951)] = 569886,
  [SMALL_STATE(11952)] = 569940,
  [SMALL_STATE(11953)] = 569994,
  [SMALL_STATE(11954)] = 570048,
  [SMALL_STATE(11955)] = 570102,
  [SMALL_STATE(11956)] = 570156,
  [SMALL_STATE(11957)] = 570210,
  [SMALL_STATE(11958)] = 570264,
  [SMALL_STATE(11959)] = 570318,
  [SMALL_STATE(11960)] = 570372,
  [SMALL_STATE(11961)] = 570426,
  [SMALL_STATE(11962)] = 570480,
  [SMALL_STATE(11963)] = 570534,
  [SMALL_STATE(11964)] = 570588,
  [SMALL_STATE(11965)] = 570642,
  [SMALL_STATE(11966)] = 570696,
  [SMALL_STATE(11967)] = 570750,
  [SMALL_STATE(11968)] = 570804,
  [SMALL_STATE(11969)] = 570858,
  [SMALL_STATE(11970)] = 570912,
  [SMALL_STATE(11971)] = 570966,
  [SMALL_STATE(11972)] = 571004,
  [SMALL_STATE(11973)] = 571042,
  [SMALL_STATE(11974)] = 571096,
  [SMALL_STATE(11975)] = 571150,
  [SMALL_STATE(11976)] = 571190,
  [SMALL_STATE(11977)] = 571244,
  [SMALL_STATE(11978)] = 571298,
  [SMALL_STATE(11979)] = 571352,
  [SMALL_STATE(11980)] = 571406,
  [SMALL_STATE(11981)] = 571460,
  [SMALL_STATE(11982)] = 571514,
  [SMALL_STATE(11983)] = 571568,
  [SMALL_STATE(11984)] = 571622,
  [SMALL_STATE(11985)] = 571662,
  [SMALL_STATE(11986)] = 571702,
  [SMALL_STATE(11987)] = 571756,
  [SMALL_STATE(11988)] = 571810,
  [SMALL_STATE(11989)] = 571864,
  [SMALL_STATE(11990)] = 571918,
  [SMALL_STATE(11991)] = 571972,
  [SMALL_STATE(11992)] = 572026,
  [SMALL_STATE(11993)] = 572080,
  [SMALL_STATE(11994)] = 572134,
  [SMALL_STATE(11995)] = 572188,
  [SMALL_STATE(11996)] = 572242,
  [SMALL_STATE(11997)] = 572278,
  [SMALL_STATE(11998)] = 572332,
  [SMALL_STATE(11999)] = 572386,
  [SMALL_STATE(12000)] = 572440,
  [SMALL_STATE(12001)] = 572494,
  [SMALL_STATE(12002)] = 572548,
  [SMALL_STATE(12003)] = 572602,
  [SMALL_STATE(12004)] = 572656,
  [SMALL_STATE(12005)] = 572710,
  [SMALL_STATE(12006)] = 572764,
  [SMALL_STATE(12007)] = 572818,
  [SMALL_STATE(12008)] = 572872,
  [SMALL_STATE(12009)] = 572926,
  [SMALL_STATE(12010)] = 572980,
  [SMALL_STATE(12011)] = 573034,
  [SMALL_STATE(12012)] = 573088,
  [SMALL_STATE(12013)] = 573142,
  [SMALL_STATE(12014)] = 573196,
  [SMALL_STATE(12015)] = 573250,
  [SMALL_STATE(12016)] = 573304,
  [SMALL_STATE(12017)] = 573358,
  [SMALL_STATE(12018)] = 573412,
  [SMALL_STATE(12019)] = 573452,
  [SMALL_STATE(12020)] = 573506,
  [SMALL_STATE(12021)] = 573560,
  [SMALL_STATE(12022)] = 573614,
  [SMALL_STATE(12023)] = 573668,
  [SMALL_STATE(12024)] = 573722,
  [SMALL_STATE(12025)] = 573776,
  [SMALL_STATE(12026)] = 573830,
  [SMALL_STATE(12027)] = 573884,
  [SMALL_STATE(12028)] = 573938,
  [SMALL_STATE(12029)] = 573992,
  [SMALL_STATE(12030)] = 574046,
  [SMALL_STATE(12031)] = 574088,
  [SMALL_STATE(12032)] = 574142,
  [SMALL_STATE(12033)] = 574196,
  [SMALL_STATE(12034)] = 574250,
  [SMALL_STATE(12035)] = 574304,
  [SMALL_STATE(12036)] = 574358,
  [SMALL_STATE(12037)] = 574412,
  [SMALL_STATE(12038)] = 574466,
  [SMALL_STATE(12039)] = 574520,
  [SMALL_STATE(12040)] = 574574,
  [SMALL_STATE(12041)] = 574620,
  [SMALL_STATE(12042)] = 574674,
  [SMALL_STATE(12043)] = 574728,
  [SMALL_STATE(12044)] = 574782,
  [SMALL_STATE(12045)] = 574836,
  [SMALL_STATE(12046)] = 574890,
  [SMALL_STATE(12047)] = 574944,
  [SMALL_STATE(12048)] = 574998,
  [SMALL_STATE(12049)] = 575052,
  [SMALL_STATE(12050)] = 575106,
  [SMALL_STATE(12051)] = 575160,
  [SMALL_STATE(12052)] = 575214,
  [SMALL_STATE(12053)] = 575268,
  [SMALL_STATE(12054)] = 575322,
  [SMALL_STATE(12055)] = 575376,
  [SMALL_STATE(12056)] = 575430,
  [SMALL_STATE(12057)] = 575484,
  [SMALL_STATE(12058)] = 575538,
  [SMALL_STATE(12059)] = 575592,
  [SMALL_STATE(12060)] = 575646,
  [SMALL_STATE(12061)] = 575700,
  [SMALL_STATE(12062)] = 575754,
  [SMALL_STATE(12063)] = 575808,
  [SMALL_STATE(12064)] = 575862,
  [SMALL_STATE(12065)] = 575916,
  [SMALL_STATE(12066)] = 575970,
  [SMALL_STATE(12067)] = 576024,
  [SMALL_STATE(12068)] = 576078,
  [SMALL_STATE(12069)] = 576132,
  [SMALL_STATE(12070)] = 576186,
  [SMALL_STATE(12071)] = 576240,
  [SMALL_STATE(12072)] = 576294,
  [SMALL_STATE(12073)] = 576348,
  [SMALL_STATE(12074)] = 576402,
  [SMALL_STATE(12075)] = 576456,
  [SMALL_STATE(12076)] = 576510,
  [SMALL_STATE(12077)] = 576564,
  [SMALL_STATE(12078)] = 576618,
  [SMALL_STATE(12079)] = 576672,
  [SMALL_STATE(12080)] = 576726,
  [SMALL_STATE(12081)] = 576780,
  [SMALL_STATE(12082)] = 576820,
  [SMALL_STATE(12083)] = 576874,
  [SMALL_STATE(12084)] = 576928,
  [SMALL_STATE(12085)] = 576982,
  [SMALL_STATE(12086)] = 577036,
  [SMALL_STATE(12087)] = 577090,
  [SMALL_STATE(12088)] = 577144,
  [SMALL_STATE(12089)] = 577198,
  [SMALL_STATE(12090)] = 577252,
  [SMALL_STATE(12091)] = 577306,
  [SMALL_STATE(12092)] = 577360,
  [SMALL_STATE(12093)] = 577414,
  [SMALL_STATE(12094)] = 577468,
  [SMALL_STATE(12095)] = 577522,
  [SMALL_STATE(12096)] = 577576,
  [SMALL_STATE(12097)] = 577630,
  [SMALL_STATE(12098)] = 577684,
  [SMALL_STATE(12099)] = 577738,
  [SMALL_STATE(12100)] = 577792,
  [SMALL_STATE(12101)] = 577846,
  [SMALL_STATE(12102)] = 577900,
  [SMALL_STATE(12103)] = 577954,
  [SMALL_STATE(12104)] = 578008,
  [SMALL_STATE(12105)] = 578062,
  [SMALL_STATE(12106)] = 578116,
  [SMALL_STATE(12107)] = 578170,
  [SMALL_STATE(12108)] = 578224,
  [SMALL_STATE(12109)] = 578278,
  [SMALL_STATE(12110)] = 578332,
  [SMALL_STATE(12111)] = 578386,
  [SMALL_STATE(12112)] = 578440,
  [SMALL_STATE(12113)] = 578474,
  [SMALL_STATE(12114)] = 578528,
  [SMALL_STATE(12115)] = 578586,
  [SMALL_STATE(12116)] = 578644,
  [SMALL_STATE(12117)] = 578698,
  [SMALL_STATE(12118)] = 578752,
  [SMALL_STATE(12119)] = 578806,
  [SMALL_STATE(12120)] = 578860,
  [SMALL_STATE(12121)] = 578914,
  [SMALL_STATE(12122)] = 578968,
  [SMALL_STATE(12123)] = 579022,
  [SMALL_STATE(12124)] = 579076,
  [SMALL_STATE(12125)] = 579130,
  [SMALL_STATE(12126)] = 579184,
  [SMALL_STATE(12127)] = 579238,
  [SMALL_STATE(12128)] = 579278,
  [SMALL_STATE(12129)] = 579332,
  [SMALL_STATE(12130)] = 579386,
  [SMALL_STATE(12131)] = 579440,
  [SMALL_STATE(12132)] = 579494,
  [SMALL_STATE(12133)] = 579548,
  [SMALL_STATE(12134)] = 579602,
  [SMALL_STATE(12135)] = 579656,
  [SMALL_STATE(12136)] = 579710,
  [SMALL_STATE(12137)] = 579764,
  [SMALL_STATE(12138)] = 579818,
  [SMALL_STATE(12139)] = 579872,
  [SMALL_STATE(12140)] = 579926,
  [SMALL_STATE(12141)] = 579980,
  [SMALL_STATE(12142)] = 580034,
  [SMALL_STATE(12143)] = 580088,
  [SMALL_STATE(12144)] = 580142,
  [SMALL_STATE(12145)] = 580196,
  [SMALL_STATE(12146)] = 580250,
  [SMALL_STATE(12147)] = 580304,
  [SMALL_STATE(12148)] = 580358,
  [SMALL_STATE(12149)] = 580412,
  [SMALL_STATE(12150)] = 580466,
  [SMALL_STATE(12151)] = 580520,
  [SMALL_STATE(12152)] = 580574,
  [SMALL_STATE(12153)] = 580628,
  [SMALL_STATE(12154)] = 580682,
  [SMALL_STATE(12155)] = 580736,
  [SMALL_STATE(12156)] = 580790,
  [SMALL_STATE(12157)] = 580844,
  [SMALL_STATE(12158)] = 580898,
  [SMALL_STATE(12159)] = 580952,
  [SMALL_STATE(12160)] = 581006,
  [SMALL_STATE(12161)] = 581044,
  [SMALL_STATE(12162)] = 581098,
  [SMALL_STATE(12163)] = 581152,
  [SMALL_STATE(12164)] = 581206,
  [SMALL_STATE(12165)] = 581260,
  [SMALL_STATE(12166)] = 581314,
  [SMALL_STATE(12167)] = 581368,
  [SMALL_STATE(12168)] = 581422,
  [SMALL_STATE(12169)] = 581476,
  [SMALL_STATE(12170)] = 581530,
  [SMALL_STATE(12171)] = 581584,
  [SMALL_STATE(12172)] = 581638,
  [SMALL_STATE(12173)] = 581692,
  [SMALL_STATE(12174)] = 581746,
  [SMALL_STATE(12175)] = 581800,
  [SMALL_STATE(12176)] = 581854,
  [SMALL_STATE(12177)] = 581908,
  [SMALL_STATE(12178)] = 581962,
  [SMALL_STATE(12179)] = 582016,
  [SMALL_STATE(12180)] = 582070,
  [SMALL_STATE(12181)] = 582124,
  [SMALL_STATE(12182)] = 582178,
  [SMALL_STATE(12183)] = 582232,
  [SMALL_STATE(12184)] = 582286,
  [SMALL_STATE(12185)] = 582340,
  [SMALL_STATE(12186)] = 582394,
  [SMALL_STATE(12187)] = 582448,
  [SMALL_STATE(12188)] = 582502,
  [SMALL_STATE(12189)] = 582556,
  [SMALL_STATE(12190)] = 582610,
  [SMALL_STATE(12191)] = 582664,
  [SMALL_STATE(12192)] = 582718,
  [SMALL_STATE(12193)] = 582772,
  [SMALL_STATE(12194)] = 582826,
  [SMALL_STATE(12195)] = 582880,
  [SMALL_STATE(12196)] = 582934,
  [SMALL_STATE(12197)] = 582988,
  [SMALL_STATE(12198)] = 583042,
  [SMALL_STATE(12199)] = 583096,
  [SMALL_STATE(12200)] = 583150,
  [SMALL_STATE(12201)] = 583204,
  [SMALL_STATE(12202)] = 583258,
  [SMALL_STATE(12203)] = 583312,
  [SMALL_STATE(12204)] = 583366,
  [SMALL_STATE(12205)] = 583420,
  [SMALL_STATE(12206)] = 583474,
  [SMALL_STATE(12207)] = 583528,
  [SMALL_STATE(12208)] = 583582,
  [SMALL_STATE(12209)] = 583636,
  [SMALL_STATE(12210)] = 583690,
  [SMALL_STATE(12211)] = 583744,
  [SMALL_STATE(12212)] = 583798,
  [SMALL_STATE(12213)] = 583852,
  [SMALL_STATE(12214)] = 583906,
  [SMALL_STATE(12215)] = 583960,
  [SMALL_STATE(12216)] = 584014,
  [SMALL_STATE(12217)] = 584068,
  [SMALL_STATE(12218)] = 584122,
  [SMALL_STATE(12219)] = 584176,
  [SMALL_STATE(12220)] = 584230,
  [SMALL_STATE(12221)] = 584288,
  [SMALL_STATE(12222)] = 584328,
  [SMALL_STATE(12223)] = 584368,
  [SMALL_STATE(12224)] = 584408,
  [SMALL_STATE(12225)] = 584448,
  [SMALL_STATE(12226)] = 584502,
  [SMALL_STATE(12227)] = 584556,
  [SMALL_STATE(12228)] = 584594,
  [SMALL_STATE(12229)] = 584634,
  [SMALL_STATE(12230)] = 584668,
  [SMALL_STATE(12231)] = 584722,
  [SMALL_STATE(12232)] = 584776,
  [SMALL_STATE(12233)] = 584830,
  [SMALL_STATE(12234)] = 584884,
  [SMALL_STATE(12235)] = 584938,
  [SMALL_STATE(12236)] = 584992,
  [SMALL_STATE(12237)] = 585046,
  [SMALL_STATE(12238)] = 585100,
  [SMALL_STATE(12239)] = 585144,
  [SMALL_STATE(12240)] = 585182,
  [SMALL_STATE(12241)] = 585220,
  [SMALL_STATE(12242)] = 585266,
  [SMALL_STATE(12243)] = 585312,
  [SMALL_STATE(12244)] = 585362,
  [SMALL_STATE(12245)] = 585414,
  [SMALL_STATE(12246)] = 585470,
  [SMALL_STATE(12247)] = 585510,
  [SMALL_STATE(12248)] = 585566,
  [SMALL_STATE(12249)] = 585622,
  [SMALL_STATE(12250)] = 585662,
  [SMALL_STATE(12251)] = 585704,
  [SMALL_STATE(12252)] = 585738,
  [SMALL_STATE(12253)] = 585776,
  [SMALL_STATE(12254)] = 585814,
  [SMALL_STATE(12255)] = 585868,
  [SMALL_STATE(12256)] = 585922,
  [SMALL_STATE(12257)] = 585962,
  [SMALL_STATE(12258)] = 586002,
  [SMALL_STATE(12259)] = 586056,
  [SMALL_STATE(12260)] = 586100,
  [SMALL_STATE(12261)] = 586138,
  [SMALL_STATE(12262)] = 586176,
  [SMALL_STATE(12263)] = 586222,
  [SMALL_STATE(12264)] = 586268,
  [SMALL_STATE(12265)] = 586318,
  [SMALL_STATE(12266)] = 586370,
  [SMALL_STATE(12267)] = 586426,
  [SMALL_STATE(12268)] = 586466,
  [SMALL_STATE(12269)] = 586522,
  [SMALL_STATE(12270)] = 586560,
  [SMALL_STATE(12271)] = 586616,
  [SMALL_STATE(12272)] = 586670,
  [SMALL_STATE(12273)] = 586724,
  [SMALL_STATE(12274)] = 586780,
  [SMALL_STATE(12275)] = 586816,
  [SMALL_STATE(12276)] = 586852,
  [SMALL_STATE(12277)] = 586890,
  [SMALL_STATE(12278)] = 586930,
  [SMALL_STATE(12279)] = 586970,
  [SMALL_STATE(12280)] = 587010,
  [SMALL_STATE(12281)] = 587064,
  [SMALL_STATE(12282)] = 587102,
  [SMALL_STATE(12283)] = 587140,
  [SMALL_STATE(12284)] = 587178,
  [SMALL_STATE(12285)] = 587216,
  [SMALL_STATE(12286)] = 587252,
  [SMALL_STATE(12287)] = 587306,
  [SMALL_STATE(12288)] = 587344,
  [SMALL_STATE(12289)] = 587380,
  [SMALL_STATE(12290)] = 587434,
  [SMALL_STATE(12291)] = 587488,
  [SMALL_STATE(12292)] = 587542,
  [SMALL_STATE(12293)] = 587596,
  [SMALL_STATE(12294)] = 587650,
  [SMALL_STATE(12295)] = 587704,
  [SMALL_STATE(12296)] = 587758,
  [SMALL_STATE(12297)] = 587812,
  [SMALL_STATE(12298)] = 587866,
  [SMALL_STATE(12299)] = 587920,
  [SMALL_STATE(12300)] = 587974,
  [SMALL_STATE(12301)] = 588008,
  [SMALL_STATE(12302)] = 588062,
  [SMALL_STATE(12303)] = 588100,
  [SMALL_STATE(12304)] = 588154,
  [SMALL_STATE(12305)] = 588190,
  [SMALL_STATE(12306)] = 588226,
  [SMALL_STATE(12307)] = 588280,
  [SMALL_STATE(12308)] = 588334,
  [SMALL_STATE(12309)] = 588374,
  [SMALL_STATE(12310)] = 588414,
  [SMALL_STATE(12311)] = 588468,
  [SMALL_STATE(12312)] = 588508,
  [SMALL_STATE(12313)] = 588548,
  [SMALL_STATE(12314)] = 588588,
  [SMALL_STATE(12315)] = 588642,
  [SMALL_STATE(12316)] = 588696,
  [SMALL_STATE(12317)] = 588750,
  [SMALL_STATE(12318)] = 588804,
  [SMALL_STATE(12319)] = 588858,
  [SMALL_STATE(12320)] = 588912,
  [SMALL_STATE(12321)] = 588966,
  [SMALL_STATE(12322)] = 589020,
  [SMALL_STATE(12323)] = 589074,
  [SMALL_STATE(12324)] = 589128,
  [SMALL_STATE(12325)] = 589182,
  [SMALL_STATE(12326)] = 589236,
  [SMALL_STATE(12327)] = 589290,
  [SMALL_STATE(12328)] = 589344,
  [SMALL_STATE(12329)] = 589398,
  [SMALL_STATE(12330)] = 589452,
  [SMALL_STATE(12331)] = 589506,
  [SMALL_STATE(12332)] = 589560,
  [SMALL_STATE(12333)] = 589614,
  [SMALL_STATE(12334)] = 589668,
  [SMALL_STATE(12335)] = 589722,
  [SMALL_STATE(12336)] = 589776,
  [SMALL_STATE(12337)] = 589830,
  [SMALL_STATE(12338)] = 589884,
  [SMALL_STATE(12339)] = 589938,
  [SMALL_STATE(12340)] = 589992,
  [SMALL_STATE(12341)] = 590046,
  [SMALL_STATE(12342)] = 590086,
  [SMALL_STATE(12343)] = 590140,
  [SMALL_STATE(12344)] = 590194,
  [SMALL_STATE(12345)] = 590248,
  [SMALL_STATE(12346)] = 590302,
  [SMALL_STATE(12347)] = 590356,
  [SMALL_STATE(12348)] = 590410,
  [SMALL_STATE(12349)] = 590448,
  [SMALL_STATE(12350)] = 590502,
  [SMALL_STATE(12351)] = 590538,
  [SMALL_STATE(12352)] = 590592,
  [SMALL_STATE(12353)] = 590628,
  [SMALL_STATE(12354)] = 590682,
  [SMALL_STATE(12355)] = 590736,
  [SMALL_STATE(12356)] = 590790,
  [SMALL_STATE(12357)] = 590844,
  [SMALL_STATE(12358)] = 590898,
  [SMALL_STATE(12359)] = 590952,
  [SMALL_STATE(12360)] = 591006,
  [SMALL_STATE(12361)] = 591060,
  [SMALL_STATE(12362)] = 591114,
  [SMALL_STATE(12363)] = 591168,
  [SMALL_STATE(12364)] = 591206,
  [SMALL_STATE(12365)] = 591244,
  [SMALL_STATE(12366)] = 591280,
  [SMALL_STATE(12367)] = 591334,
  [SMALL_STATE(12368)] = 591388,
  [SMALL_STATE(12369)] = 591442,
  [SMALL_STATE(12370)] = 591480,
  [SMALL_STATE(12371)] = 591518,
  [SMALL_STATE(12372)] = 591572,
  [SMALL_STATE(12373)] = 591626,
  [SMALL_STATE(12374)] = 591680,
  [SMALL_STATE(12375)] = 591734,
  [SMALL_STATE(12376)] = 591774,
  [SMALL_STATE(12377)] = 591808,
  [SMALL_STATE(12378)] = 591850,
  [SMALL_STATE(12379)] = 591894,
  [SMALL_STATE(12380)] = 591938,
  [SMALL_STATE(12381)] = 591978,
  [SMALL_STATE(12382)] = 592018,
  [SMALL_STATE(12383)] = 592058,
  [SMALL_STATE(12384)] = 592098,
  [SMALL_STATE(12385)] = 592136,
  [SMALL_STATE(12386)] = 592174,
  [SMALL_STATE(12387)] = 592210,
  [SMALL_STATE(12388)] = 592248,
  [SMALL_STATE(12389)] = 592292,
  [SMALL_STATE(12390)] = 592330,
  [SMALL_STATE(12391)] = 592384,
  [SMALL_STATE(12392)] = 592428,
  [SMALL_STATE(12393)] = 592472,
  [SMALL_STATE(12394)] = 592526,
  [SMALL_STATE(12395)] = 592570,
  [SMALL_STATE(12396)] = 592624,
  [SMALL_STATE(12397)] = 592678,
  [SMALL_STATE(12398)] = 592732,
  [SMALL_STATE(12399)] = 592786,
  [SMALL_STATE(12400)] = 592840,
  [SMALL_STATE(12401)] = 592894,
  [SMALL_STATE(12402)] = 592948,
  [SMALL_STATE(12403)] = 593002,
  [SMALL_STATE(12404)] = 593056,
  [SMALL_STATE(12405)] = 593096,
  [SMALL_STATE(12406)] = 593134,
  [SMALL_STATE(12407)] = 593172,
  [SMALL_STATE(12408)] = 593210,
  [SMALL_STATE(12409)] = 593248,
  [SMALL_STATE(12410)] = 593306,
  [SMALL_STATE(12411)] = 593364,
  [SMALL_STATE(12412)] = 593402,
  [SMALL_STATE(12413)] = 593436,
  [SMALL_STATE(12414)] = 593490,
  [SMALL_STATE(12415)] = 593523,
  [SMALL_STATE(12416)] = 593560,
  [SMALL_STATE(12417)] = 593611,
  [SMALL_STATE(12418)] = 593650,
  [SMALL_STATE(12419)] = 593701,
  [SMALL_STATE(12420)] = 593756,
  [SMALL_STATE(12421)] = 593791,
  [SMALL_STATE(12422)] = 593848,
  [SMALL_STATE(12423)] = 593881,
  [SMALL_STATE(12424)] = 593914,
  [SMALL_STATE(12425)] = 593947,
  [SMALL_STATE(12426)] = 593982,
  [SMALL_STATE(12427)] = 594037,
  [SMALL_STATE(12428)] = 594070,
  [SMALL_STATE(12429)] = 594103,
  [SMALL_STATE(12430)] = 594154,
  [SMALL_STATE(12431)] = 594187,
  [SMALL_STATE(12432)] = 594220,
  [SMALL_STATE(12433)] = 594253,
  [SMALL_STATE(12434)] = 594292,
  [SMALL_STATE(12435)] = 594345,
  [SMALL_STATE(12436)] = 594402,
  [SMALL_STATE(12437)] = 594439,
  [SMALL_STATE(12438)] = 594496,
  [SMALL_STATE(12439)] = 594533,
  [SMALL_STATE(12440)] = 594572,
  [SMALL_STATE(12441)] = 594615,
  [SMALL_STATE(12442)] = 594652,
  [SMALL_STATE(12443)] = 594689,
  [SMALL_STATE(12444)] = 594724,
  [SMALL_STATE(12445)] = 594763,
  [SMALL_STATE(12446)] = 594802,
  [SMALL_STATE(12447)] = 594835,
  [SMALL_STATE(12448)] = 594868,
  [SMALL_STATE(12449)] = 594901,
  [SMALL_STATE(12450)] = 594934,
  [SMALL_STATE(12451)] = 594977,
  [SMALL_STATE(12452)] = 595014,
  [SMALL_STATE(12453)] = 595053,
  [SMALL_STATE(12454)] = 595092,
  [SMALL_STATE(12455)] = 595125,
  [SMALL_STATE(12456)] = 595158,
  [SMALL_STATE(12457)] = 595191,
  [SMALL_STATE(12458)] = 595224,
  [SMALL_STATE(12459)] = 595257,
  [SMALL_STATE(12460)] = 595290,
  [SMALL_STATE(12461)] = 595329,
  [SMALL_STATE(12462)] = 595362,
  [SMALL_STATE(12463)] = 595395,
  [SMALL_STATE(12464)] = 595450,
  [SMALL_STATE(12465)] = 595483,
  [SMALL_STATE(12466)] = 595516,
  [SMALL_STATE(12467)] = 595549,
  [SMALL_STATE(12468)] = 595588,
  [SMALL_STATE(12469)] = 595627,
  [SMALL_STATE(12470)] = 595666,
  [SMALL_STATE(12471)] = 595705,
  [SMALL_STATE(12472)] = 595744,
  [SMALL_STATE(12473)] = 595797,
  [SMALL_STATE(12474)] = 595836,
  [SMALL_STATE(12475)] = 595875,
  [SMALL_STATE(12476)] = 595926,
  [SMALL_STATE(12477)] = 595963,
  [SMALL_STATE(12478)] = 596000,
  [SMALL_STATE(12479)] = 596037,
  [SMALL_STATE(12480)] = 596074,
  [SMALL_STATE(12481)] = 596111,
  [SMALL_STATE(12482)] = 596146,
  [SMALL_STATE(12483)] = 596197,
  [SMALL_STATE(12484)] = 596248,
  [SMALL_STATE(12485)] = 596283,
  [SMALL_STATE(12486)] = 596326,
  [SMALL_STATE(12487)] = 596369,
  [SMALL_STATE(12488)] = 596402,
  [SMALL_STATE(12489)] = 596439,
  [SMALL_STATE(12490)] = 596476,
  [SMALL_STATE(12491)] = 596509,
  [SMALL_STATE(12492)] = 596546,
  [SMALL_STATE(12493)] = 596581,
  [SMALL_STATE(12494)] = 596618,
  [SMALL_STATE(12495)] = 596653,
  [SMALL_STATE(12496)] = 596690,
  [SMALL_STATE(12497)] = 596725,
  [SMALL_STATE(12498)] = 596764,
  [SMALL_STATE(12499)] = 596797,
  [SMALL_STATE(12500)] = 596834,
  [SMALL_STATE(12501)] = 596885,
  [SMALL_STATE(12502)] = 596930,
  [SMALL_STATE(12503)] = 596975,
  [SMALL_STATE(12504)] = 597024,
  [SMALL_STATE(12505)] = 597081,
  [SMALL_STATE(12506)] = 597118,
  [SMALL_STATE(12507)] = 597169,
  [SMALL_STATE(12508)] = 597208,
  [SMALL_STATE(12509)] = 597245,
  [SMALL_STATE(12510)] = 597282,
  [SMALL_STATE(12511)] = 597317,
  [SMALL_STATE(12512)] = 597354,
  [SMALL_STATE(12513)] = 597397,
  [SMALL_STATE(12514)] = 597452,
  [SMALL_STATE(12515)] = 597509,
  [SMALL_STATE(12516)] = 597546,
  [SMALL_STATE(12517)] = 597583,
  [SMALL_STATE(12518)] = 597620,
  [SMALL_STATE(12519)] = 597657,
  [SMALL_STATE(12520)] = 597692,
  [SMALL_STATE(12521)] = 597735,
  [SMALL_STATE(12522)] = 597788,
  [SMALL_STATE(12523)] = 597821,
  [SMALL_STATE(12524)] = 597864,
  [SMALL_STATE(12525)] = 597907,
  [SMALL_STATE(12526)] = 597944,
  [SMALL_STATE(12527)] = 597981,
  [SMALL_STATE(12528)] = 598026,
  [SMALL_STATE(12529)] = 598071,
  [SMALL_STATE(12530)] = 598120,
  [SMALL_STATE(12531)] = 598171,
  [SMALL_STATE(12532)] = 598226,
  [SMALL_STATE(12533)] = 598265,
  [SMALL_STATE(12534)] = 598320,
  [SMALL_STATE(12535)] = 598357,
  [SMALL_STATE(12536)] = 598414,
  [SMALL_STATE(12537)] = 598465,
  [SMALL_STATE(12538)] = 598516,
  [SMALL_STATE(12539)] = 598571,
  [SMALL_STATE(12540)] = 598610,
  [SMALL_STATE(12541)] = 598667,
  [SMALL_STATE(12542)] = 598706,
  [SMALL_STATE(12543)] = 598749,
  [SMALL_STATE(12544)] = 598786,
  [SMALL_STATE(12545)] = 598825,
  [SMALL_STATE(12546)] = 598858,
  [SMALL_STATE(12547)] = 598897,
  [SMALL_STATE(12548)] = 598940,
  [SMALL_STATE(12549)] = 598979,
  [SMALL_STATE(12550)] = 599014,
  [SMALL_STATE(12551)] = 599071,
  [SMALL_STATE(12552)] = 599114,
  [SMALL_STATE(12553)] = 599155,
  [SMALL_STATE(12554)] = 599192,
  [SMALL_STATE(12555)] = 599229,
  [SMALL_STATE(12556)] = 599266,
  [SMALL_STATE(12557)] = 599307,
  [SMALL_STATE(12558)] = 599348,
  [SMALL_STATE(12559)] = 599385,
  [SMALL_STATE(12560)] = 599422,
  [SMALL_STATE(12561)] = 599457,
  [SMALL_STATE(12562)] = 599496,
  [SMALL_STATE(12563)] = 599553,
  [SMALL_STATE(12564)] = 599590,
  [SMALL_STATE(12565)] = 599623,
  [SMALL_STATE(12566)] = 599656,
  [SMALL_STATE(12567)] = 599699,
  [SMALL_STATE(12568)] = 599740,
  [SMALL_STATE(12569)] = 599773,
  [SMALL_STATE(12570)] = 599812,
  [SMALL_STATE(12571)] = 599851,
  [SMALL_STATE(12572)] = 599884,
  [SMALL_STATE(12573)] = 599921,
  [SMALL_STATE(12574)] = 599975,
  [SMALL_STATE(12575)] = 600011,
  [SMALL_STATE(12576)] = 600047,
  [SMALL_STATE(12577)] = 600081,
  [SMALL_STATE(12578)] = 600129,
  [SMALL_STATE(12579)] = 600177,
  [SMALL_STATE(12580)] = 600225,
  [SMALL_STATE(12581)] = 600267,
  [SMALL_STATE(12582)] = 600301,
  [SMALL_STATE(12583)] = 600355,
  [SMALL_STATE(12584)] = 600407,
  [SMALL_STATE(12585)] = 600449,
  [SMALL_STATE(12586)] = 600485,
  [SMALL_STATE(12587)] = 600521,
  [SMALL_STATE(12588)] = 600565,
  [SMALL_STATE(12589)] = 600609,
  [SMALL_STATE(12590)] = 600657,
  [SMALL_STATE(12591)] = 600707,
  [SMALL_STATE(12592)] = 600761,
  [SMALL_STATE(12593)] = 600799,
  [SMALL_STATE(12594)] = 600853,
  [SMALL_STATE(12595)] = 600889,
  [SMALL_STATE(12596)] = 600943,
  [SMALL_STATE(12597)] = 600977,
  [SMALL_STATE(12598)] = 601035,
  [SMALL_STATE(12599)] = 601067,
  [SMALL_STATE(12600)] = 601101,
  [SMALL_STATE(12601)] = 601133,
  [SMALL_STATE(12602)] = 601189,
  [SMALL_STATE(12603)] = 601245,
  [SMALL_STATE(12604)] = 601301,
  [SMALL_STATE(12605)] = 601357,
  [SMALL_STATE(12606)] = 601413,
  [SMALL_STATE(12607)] = 601469,
  [SMALL_STATE(12608)] = 601525,
  [SMALL_STATE(12609)] = 601581,
  [SMALL_STATE(12610)] = 601617,
  [SMALL_STATE(12611)] = 601651,
  [SMALL_STATE(12612)] = 601683,
  [SMALL_STATE(12613)] = 601721,
  [SMALL_STATE(12614)] = 601769,
  [SMALL_STATE(12615)] = 601801,
  [SMALL_STATE(12616)] = 601857,
  [SMALL_STATE(12617)] = 601913,
  [SMALL_STATE(12618)] = 601963,
  [SMALL_STATE(12619)] = 602011,
  [SMALL_STATE(12620)] = 602047,
  [SMALL_STATE(12621)] = 602103,
  [SMALL_STATE(12622)] = 602151,
  [SMALL_STATE(12623)] = 602199,
  [SMALL_STATE(12624)] = 602235,
  [SMALL_STATE(12625)] = 602269,
  [SMALL_STATE(12626)] = 602305,
  [SMALL_STATE(12627)] = 602353,
  [SMALL_STATE(12628)] = 602401,
  [SMALL_STATE(12629)] = 602449,
  [SMALL_STATE(12630)] = 602497,
  [SMALL_STATE(12631)] = 602545,
  [SMALL_STATE(12632)] = 602593,
  [SMALL_STATE(12633)] = 602629,
  [SMALL_STATE(12634)] = 602677,
  [SMALL_STATE(12635)] = 602725,
  [SMALL_STATE(12636)] = 602757,
  [SMALL_STATE(12637)] = 602805,
  [SMALL_STATE(12638)] = 602837,
  [SMALL_STATE(12639)] = 602869,
  [SMALL_STATE(12640)] = 602905,
  [SMALL_STATE(12641)] = 602953,
  [SMALL_STATE(12642)] = 602989,
  [SMALL_STATE(12643)] = 603025,
  [SMALL_STATE(12644)] = 603079,
  [SMALL_STATE(12645)] = 603115,
  [SMALL_STATE(12646)] = 603151,
  [SMALL_STATE(12647)] = 603185,
  [SMALL_STATE(12648)] = 603221,
  [SMALL_STATE(12649)] = 603257,
  [SMALL_STATE(12650)] = 603293,
  [SMALL_STATE(12651)] = 603329,
  [SMALL_STATE(12652)] = 603363,
  [SMALL_STATE(12653)] = 603399,
  [SMALL_STATE(12654)] = 603435,
  [SMALL_STATE(12655)] = 603467,
  [SMALL_STATE(12656)] = 603523,
  [SMALL_STATE(12657)] = 603579,
  [SMALL_STATE(12658)] = 603615,
  [SMALL_STATE(12659)] = 603649,
  [SMALL_STATE(12660)] = 603685,
  [SMALL_STATE(12661)] = 603737,
  [SMALL_STATE(12662)] = 603779,
  [SMALL_STATE(12663)] = 603815,
  [SMALL_STATE(12664)] = 603851,
  [SMALL_STATE(12665)] = 603895,
  [SMALL_STATE(12666)] = 603939,
  [SMALL_STATE(12667)] = 603987,
  [SMALL_STATE(12668)] = 604037,
  [SMALL_STATE(12669)] = 604075,
  [SMALL_STATE(12670)] = 604129,
  [SMALL_STATE(12671)] = 604161,
  [SMALL_STATE(12672)] = 604197,
  [SMALL_STATE(12673)] = 604251,
  [SMALL_STATE(12674)] = 604285,
  [SMALL_STATE(12675)] = 604333,
  [SMALL_STATE(12676)] = 604389,
  [SMALL_STATE(12677)] = 604445,
  [SMALL_STATE(12678)] = 604497,
  [SMALL_STATE(12679)] = 604539,
  [SMALL_STATE(12680)] = 604575,
  [SMALL_STATE(12681)] = 604611,
  [SMALL_STATE(12682)] = 604655,
  [SMALL_STATE(12683)] = 604699,
  [SMALL_STATE(12684)] = 604747,
  [SMALL_STATE(12685)] = 604797,
  [SMALL_STATE(12686)] = 604851,
  [SMALL_STATE(12687)] = 604889,
  [SMALL_STATE(12688)] = 604943,
  [SMALL_STATE(12689)] = 604979,
  [SMALL_STATE(12690)] = 605033,
  [SMALL_STATE(12691)] = 605067,
  [SMALL_STATE(12692)] = 605103,
  [SMALL_STATE(12693)] = 605149,
  [SMALL_STATE(12694)] = 605183,
  [SMALL_STATE(12695)] = 605235,
  [SMALL_STATE(12696)] = 605291,
  [SMALL_STATE(12697)] = 605333,
  [SMALL_STATE(12698)] = 605369,
  [SMALL_STATE(12699)] = 605405,
  [SMALL_STATE(12700)] = 605449,
  [SMALL_STATE(12701)] = 605493,
  [SMALL_STATE(12702)] = 605541,
  [SMALL_STATE(12703)] = 605591,
  [SMALL_STATE(12704)] = 605645,
  [SMALL_STATE(12705)] = 605681,
  [SMALL_STATE(12706)] = 605719,
  [SMALL_STATE(12707)] = 605773,
  [SMALL_STATE(12708)] = 605809,
  [SMALL_STATE(12709)] = 605843,
  [SMALL_STATE(12710)] = 605879,
  [SMALL_STATE(12711)] = 605927,
  [SMALL_STATE(12712)] = 605963,
  [SMALL_STATE(12713)] = 605999,
  [SMALL_STATE(12714)] = 606047,
  [SMALL_STATE(12715)] = 606095,
  [SMALL_STATE(12716)] = 606129,
  [SMALL_STATE(12717)] = 606165,
  [SMALL_STATE(12718)] = 606219,
  [SMALL_STATE(12719)] = 606255,
  [SMALL_STATE(12720)] = 606291,
  [SMALL_STATE(12721)] = 606327,
  [SMALL_STATE(12722)] = 606359,
  [SMALL_STATE(12723)] = 606395,
  [SMALL_STATE(12724)] = 606429,
  [SMALL_STATE(12725)] = 606461,
  [SMALL_STATE(12726)] = 606493,
  [SMALL_STATE(12727)] = 606545,
  [SMALL_STATE(12728)] = 606587,
  [SMALL_STATE(12729)] = 606623,
  [SMALL_STATE(12730)] = 606659,
  [SMALL_STATE(12731)] = 606703,
  [SMALL_STATE(12732)] = 606747,
  [SMALL_STATE(12733)] = 606795,
  [SMALL_STATE(12734)] = 606845,
  [SMALL_STATE(12735)] = 606899,
  [SMALL_STATE(12736)] = 606937,
  [SMALL_STATE(12737)] = 606991,
  [SMALL_STATE(12738)] = 607027,
  [SMALL_STATE(12739)] = 607081,
  [SMALL_STATE(12740)] = 607135,
  [SMALL_STATE(12741)] = 607183,
  [SMALL_STATE(12742)] = 607217,
  [SMALL_STATE(12743)] = 607253,
  [SMALL_STATE(12744)] = 607287,
  [SMALL_STATE(12745)] = 607323,
  [SMALL_STATE(12746)] = 607375,
  [SMALL_STATE(12747)] = 607417,
  [SMALL_STATE(12748)] = 607453,
  [SMALL_STATE(12749)] = 607489,
  [SMALL_STATE(12750)] = 607533,
  [SMALL_STATE(12751)] = 607577,
  [SMALL_STATE(12752)] = 607625,
  [SMALL_STATE(12753)] = 607675,
  [SMALL_STATE(12754)] = 607729,
  [SMALL_STATE(12755)] = 607767,
  [SMALL_STATE(12756)] = 607821,
  [SMALL_STATE(12757)] = 607857,
  [SMALL_STATE(12758)] = 607911,
  [SMALL_STATE(12759)] = 607947,
  [SMALL_STATE(12760)] = 607995,
  [SMALL_STATE(12761)] = 608043,
  [SMALL_STATE(12762)] = 608077,
  [SMALL_STATE(12763)] = 608113,
  [SMALL_STATE(12764)] = 608167,
  [SMALL_STATE(12765)] = 608211,
  [SMALL_STATE(12766)] = 608267,
  [SMALL_STATE(12767)] = 608317,
  [SMALL_STATE(12768)] = 608355,
  [SMALL_STATE(12769)] = 608393,
  [SMALL_STATE(12770)] = 608431,
  [SMALL_STATE(12771)] = 608479,
  [SMALL_STATE(12772)] = 608527,
  [SMALL_STATE(12773)] = 608575,
  [SMALL_STATE(12774)] = 608623,
  [SMALL_STATE(12775)] = 608659,
  [SMALL_STATE(12776)] = 608707,
  [SMALL_STATE(12777)] = 608745,
  [SMALL_STATE(12778)] = 608783,
  [SMALL_STATE(12779)] = 608821,
  [SMALL_STATE(12780)] = 608869,
  [SMALL_STATE(12781)] = 608917,
  [SMALL_STATE(12782)] = 608965,
  [SMALL_STATE(12783)] = 609013,
  [SMALL_STATE(12784)] = 609049,
  [SMALL_STATE(12785)] = 609085,
  [SMALL_STATE(12786)] = 609121,
  [SMALL_STATE(12787)] = 609157,
  [SMALL_STATE(12788)] = 609191,
  [SMALL_STATE(12789)] = 609225,
  [SMALL_STATE(12790)] = 609273,
  [SMALL_STATE(12791)] = 609307,
  [SMALL_STATE(12792)] = 609343,
  [SMALL_STATE(12793)] = 609379,
  [SMALL_STATE(12794)] = 609415,
  [SMALL_STATE(12795)] = 609451,
  [SMALL_STATE(12796)] = 609485,
  [SMALL_STATE(12797)] = 609527,
  [SMALL_STATE(12798)] = 609561,
  [SMALL_STATE(12799)] = 609597,
  [SMALL_STATE(12800)] = 609645,
  [SMALL_STATE(12801)] = 609701,
  [SMALL_STATE(12802)] = 609737,
  [SMALL_STATE(12803)] = 609795,
  [SMALL_STATE(12804)] = 609827,
  [SMALL_STATE(12805)] = 609863,
  [SMALL_STATE(12806)] = 609899,
  [SMALL_STATE(12807)] = 609935,
  [SMALL_STATE(12808)] = 609971,
  [SMALL_STATE(12809)] = 610005,
  [SMALL_STATE(12810)] = 610043,
  [SMALL_STATE(12811)] = 610091,
  [SMALL_STATE(12812)] = 610139,
  [SMALL_STATE(12813)] = 610175,
  [SMALL_STATE(12814)] = 610211,
  [SMALL_STATE(12815)] = 610247,
  [SMALL_STATE(12816)] = 610283,
  [SMALL_STATE(12817)] = 610317,
  [SMALL_STATE(12818)] = 610351,
  [SMALL_STATE(12819)] = 610399,
  [SMALL_STATE(12820)] = 610447,
  [SMALL_STATE(12821)] = 610495,
  [SMALL_STATE(12822)] = 610533,
  [SMALL_STATE(12823)] = 610581,
  [SMALL_STATE(12824)] = 610629,
  [SMALL_STATE(12825)] = 610681,
  [SMALL_STATE(12826)] = 610729,
  [SMALL_STATE(12827)] = 610771,
  [SMALL_STATE(12828)] = 610819,
  [SMALL_STATE(12829)] = 610855,
  [SMALL_STATE(12830)] = 610891,
  [SMALL_STATE(12831)] = 610935,
  [SMALL_STATE(12832)] = 610979,
  [SMALL_STATE(12833)] = 611027,
  [SMALL_STATE(12834)] = 611075,
  [SMALL_STATE(12835)] = 611125,
  [SMALL_STATE(12836)] = 611179,
  [SMALL_STATE(12837)] = 611217,
  [SMALL_STATE(12838)] = 611271,
  [SMALL_STATE(12839)] = 611319,
  [SMALL_STATE(12840)] = 611367,
  [SMALL_STATE(12841)] = 611415,
  [SMALL_STATE(12842)] = 611465,
  [SMALL_STATE(12843)] = 611513,
  [SMALL_STATE(12844)] = 611561,
  [SMALL_STATE(12845)] = 611597,
  [SMALL_STATE(12846)] = 611645,
  [SMALL_STATE(12847)] = 611693,
  [SMALL_STATE(12848)] = 611741,
  [SMALL_STATE(12849)] = 611789,
  [SMALL_STATE(12850)] = 611837,
  [SMALL_STATE(12851)] = 611885,
  [SMALL_STATE(12852)] = 611941,
  [SMALL_STATE(12853)] = 611977,
  [SMALL_STATE(12854)] = 612011,
  [SMALL_STATE(12855)] = 612059,
  [SMALL_STATE(12856)] = 612093,
  [SMALL_STATE(12857)] = 612141,
  [SMALL_STATE(12858)] = 612195,
  [SMALL_STATE(12859)] = 612243,
  [SMALL_STATE(12860)] = 612291,
  [SMALL_STATE(12861)] = 612339,
  [SMALL_STATE(12862)] = 612387,
  [SMALL_STATE(12863)] = 612423,
  [SMALL_STATE(12864)] = 612471,
  [SMALL_STATE(12865)] = 612507,
  [SMALL_STATE(12866)] = 612555,
  [SMALL_STATE(12867)] = 612603,
  [SMALL_STATE(12868)] = 612651,
  [SMALL_STATE(12869)] = 612699,
  [SMALL_STATE(12870)] = 612747,
  [SMALL_STATE(12871)] = 612795,
  [SMALL_STATE(12872)] = 612843,
  [SMALL_STATE(12873)] = 612891,
  [SMALL_STATE(12874)] = 612951,
  [SMALL_STATE(12875)] = 612987,
  [SMALL_STATE(12876)] = 613023,
  [SMALL_STATE(12877)] = 613059,
  [SMALL_STATE(12878)] = 613095,
  [SMALL_STATE(12879)] = 613129,
  [SMALL_STATE(12880)] = 613165,
  [SMALL_STATE(12881)] = 613201,
  [SMALL_STATE(12882)] = 613237,
  [SMALL_STATE(12883)] = 613285,
  [SMALL_STATE(12884)] = 613321,
  [SMALL_STATE(12885)] = 613375,
  [SMALL_STATE(12886)] = 613435,
  [SMALL_STATE(12887)] = 613471,
  [SMALL_STATE(12888)] = 613507,
  [SMALL_STATE(12889)] = 613541,
  [SMALL_STATE(12890)] = 613601,
  [SMALL_STATE(12891)] = 613637,
  [SMALL_STATE(12892)] = 613673,
  [SMALL_STATE(12893)] = 613707,
  [SMALL_STATE(12894)] = 613763,
  [SMALL_STATE(12895)] = 613799,
  [SMALL_STATE(12896)] = 613855,
  [SMALL_STATE(12897)] = 613887,
  [SMALL_STATE(12898)] = 613935,
  [SMALL_STATE(12899)] = 613995,
  [SMALL_STATE(12900)] = 614043,
  [SMALL_STATE(12901)] = 614079,
  [SMALL_STATE(12902)] = 614113,
  [SMALL_STATE(12903)] = 614147,
  [SMALL_STATE(12904)] = 614183,
  [SMALL_STATE(12905)] = 614219,
  [SMALL_STATE(12906)] = 614255,
  [SMALL_STATE(12907)] = 614303,
  [SMALL_STATE(12908)] = 614339,
  [SMALL_STATE(12909)] = 614375,
  [SMALL_STATE(12910)] = 614411,
  [SMALL_STATE(12911)] = 614443,
  [SMALL_STATE(12912)] = 614479,
  [SMALL_STATE(12913)] = 614515,
  [SMALL_STATE(12914)] = 614551,
  [SMALL_STATE(12915)] = 614585,
  [SMALL_STATE(12916)] = 614621,
  [SMALL_STATE(12917)] = 614657,
  [SMALL_STATE(12918)] = 614693,
  [SMALL_STATE(12919)] = 614747,
  [SMALL_STATE(12920)] = 614794,
  [SMALL_STATE(12921)] = 614829,
  [SMALL_STATE(12922)] = 614872,
  [SMALL_STATE(12923)] = 614915,
  [SMALL_STATE(12924)] = 614962,
  [SMALL_STATE(12925)] = 615009,
  [SMALL_STATE(12926)] = 615060,
  [SMALL_STATE(12927)] = 615097,
  [SMALL_STATE(12928)] = 615148,
  [SMALL_STATE(12929)] = 615181,
  [SMALL_STATE(12930)] = 615236,
  [SMALL_STATE(12931)] = 615271,
  [SMALL_STATE(12932)] = 615324,
  [SMALL_STATE(12933)] = 615375,
  [SMALL_STATE(12934)] = 615430,
  [SMALL_STATE(12935)] = 615485,
  [SMALL_STATE(12936)] = 615518,
  [SMALL_STATE(12937)] = 615549,
  [SMALL_STATE(12938)] = 615596,
  [SMALL_STATE(12939)] = 615643,
  [SMALL_STATE(12940)] = 615684,
  [SMALL_STATE(12941)] = 615735,
  [SMALL_STATE(12942)] = 615772,
  [SMALL_STATE(12943)] = 615823,
  [SMALL_STATE(12944)] = 615856,
  [SMALL_STATE(12945)] = 615909,
  [SMALL_STATE(12946)] = 615964,
  [SMALL_STATE(12947)] = 616005,
  [SMALL_STATE(12948)] = 616060,
  [SMALL_STATE(12949)] = 616093,
  [SMALL_STATE(12950)] = 616134,
  [SMALL_STATE(12951)] = 616189,
  [SMALL_STATE(12952)] = 616220,
  [SMALL_STATE(12953)] = 616253,
  [SMALL_STATE(12954)] = 616306,
  [SMALL_STATE(12955)] = 616361,
  [SMALL_STATE(12956)] = 616416,
  [SMALL_STATE(12957)] = 616447,
  [SMALL_STATE(12958)] = 616488,
  [SMALL_STATE(12959)] = 616529,
  [SMALL_STATE(12960)] = 616584,
  [SMALL_STATE(12961)] = 616619,
  [SMALL_STATE(12962)] = 616654,
  [SMALL_STATE(12963)] = 616689,
  [SMALL_STATE(12964)] = 616724,
  [SMALL_STATE(12965)] = 616757,
  [SMALL_STATE(12966)] = 616798,
  [SMALL_STATE(12967)] = 616853,
  [SMALL_STATE(12968)] = 616908,
  [SMALL_STATE(12969)] = 616961,
  [SMALL_STATE(12970)] = 616992,
  [SMALL_STATE(12971)] = 617023,
  [SMALL_STATE(12972)] = 617054,
  [SMALL_STATE(12973)] = 617095,
  [SMALL_STATE(12974)] = 617150,
  [SMALL_STATE(12975)] = 617191,
  [SMALL_STATE(12976)] = 617222,
  [SMALL_STATE(12977)] = 617277,
  [SMALL_STATE(12978)] = 617332,
  [SMALL_STATE(12979)] = 617367,
  [SMALL_STATE(12980)] = 617422,
  [SMALL_STATE(12981)] = 617453,
  [SMALL_STATE(12982)] = 617506,
  [SMALL_STATE(12983)] = 617539,
  [SMALL_STATE(12984)] = 617574,
  [SMALL_STATE(12985)] = 617629,
  [SMALL_STATE(12986)] = 617660,
  [SMALL_STATE(12987)] = 617713,
  [SMALL_STATE(12988)] = 617768,
  [SMALL_STATE(12989)] = 617799,
  [SMALL_STATE(12990)] = 617854,
  [SMALL_STATE(12991)] = 617895,
  [SMALL_STATE(12992)] = 617950,
  [SMALL_STATE(12993)] = 617991,
  [SMALL_STATE(12994)] = 618046,
  [SMALL_STATE(12995)] = 618101,
  [SMALL_STATE(12996)] = 618156,
  [SMALL_STATE(12997)] = 618191,
  [SMALL_STATE(12998)] = 618246,
  [SMALL_STATE(12999)] = 618301,
  [SMALL_STATE(13000)] = 618356,
  [SMALL_STATE(13001)] = 618387,
  [SMALL_STATE(13002)] = 618438,
  [SMALL_STATE(13003)] = 618493,
  [SMALL_STATE(13004)] = 618548,
  [SMALL_STATE(13005)] = 618589,
  [SMALL_STATE(13006)] = 618622,
  [SMALL_STATE(13007)] = 618657,
  [SMALL_STATE(13008)] = 618692,
  [SMALL_STATE(13009)] = 618727,
  [SMALL_STATE(13010)] = 618762,
  [SMALL_STATE(13011)] = 618795,
  [SMALL_STATE(13012)] = 618850,
  [SMALL_STATE(13013)] = 618905,
  [SMALL_STATE(13014)] = 618936,
  [SMALL_STATE(13015)] = 618971,
  [SMALL_STATE(13016)] = 619004,
  [SMALL_STATE(13017)] = 619057,
  [SMALL_STATE(13018)] = 619108,
  [SMALL_STATE(13019)] = 619149,
  [SMALL_STATE(13020)] = 619190,
  [SMALL_STATE(13021)] = 619221,
  [SMALL_STATE(13022)] = 619254,
  [SMALL_STATE(13023)] = 619289,
  [SMALL_STATE(13024)] = 619334,
  [SMALL_STATE(13025)] = 619365,
  [SMALL_STATE(13026)] = 619406,
  [SMALL_STATE(13027)] = 619447,
  [SMALL_STATE(13028)] = 619502,
  [SMALL_STATE(13029)] = 619557,
  [SMALL_STATE(13030)] = 619612,
  [SMALL_STATE(13031)] = 619665,
  [SMALL_STATE(13032)] = 619696,
  [SMALL_STATE(13033)] = 619737,
  [SMALL_STATE(13034)] = 619792,
  [SMALL_STATE(13035)] = 619825,
  [SMALL_STATE(13036)] = 619880,
  [SMALL_STATE(13037)] = 619935,
  [SMALL_STATE(13038)] = 619970,
  [SMALL_STATE(13039)] = 620005,
  [SMALL_STATE(13040)] = 620060,
  [SMALL_STATE(13041)] = 620103,
  [SMALL_STATE(13042)] = 620146,
  [SMALL_STATE(13043)] = 620193,
  [SMALL_STATE(13044)] = 620242,
  [SMALL_STATE(13045)] = 620295,
  [SMALL_STATE(13046)] = 620336,
  [SMALL_STATE(13047)] = 620373,
  [SMALL_STATE(13048)] = 620426,
  [SMALL_STATE(13049)] = 620461,
  [SMALL_STATE(13050)] = 620496,
  [SMALL_STATE(13051)] = 620531,
  [SMALL_STATE(13052)] = 620566,
  [SMALL_STATE(13053)] = 620599,
  [SMALL_STATE(13054)] = 620654,
  [SMALL_STATE(13055)] = 620709,
  [SMALL_STATE(13056)] = 620764,
  [SMALL_STATE(13057)] = 620819,
  [SMALL_STATE(13058)] = 620854,
  [SMALL_STATE(13059)] = 620887,
  [SMALL_STATE(13060)] = 620918,
  [SMALL_STATE(13061)] = 620973,
  [SMALL_STATE(13062)] = 621006,
  [SMALL_STATE(13063)] = 621061,
  [SMALL_STATE(13064)] = 621102,
  [SMALL_STATE(13065)] = 621155,
  [SMALL_STATE(13066)] = 621186,
  [SMALL_STATE(13067)] = 621227,
  [SMALL_STATE(13068)] = 621282,
  [SMALL_STATE(13069)] = 621323,
  [SMALL_STATE(13070)] = 621378,
  [SMALL_STATE(13071)] = 621433,
  [SMALL_STATE(13072)] = 621474,
  [SMALL_STATE(13073)] = 621505,
  [SMALL_STATE(13074)] = 621546,
  [SMALL_STATE(13075)] = 621587,
  [SMALL_STATE(13076)] = 621628,
  [SMALL_STATE(13077)] = 621669,
  [SMALL_STATE(13078)] = 621710,
  [SMALL_STATE(13079)] = 621743,
  [SMALL_STATE(13080)] = 621784,
  [SMALL_STATE(13081)] = 621815,
  [SMALL_STATE(13082)] = 621846,
  [SMALL_STATE(13083)] = 621887,
  [SMALL_STATE(13084)] = 621940,
  [SMALL_STATE(13085)] = 621981,
  [SMALL_STATE(13086)] = 622022,
  [SMALL_STATE(13087)] = 622063,
  [SMALL_STATE(13088)] = 622104,
  [SMALL_STATE(13089)] = 622145,
  [SMALL_STATE(13090)] = 622200,
  [SMALL_STATE(13091)] = 622233,
  [SMALL_STATE(13092)] = 622274,
  [SMALL_STATE(13093)] = 622329,
  [SMALL_STATE(13094)] = 622362,
  [SMALL_STATE(13095)] = 622397,
  [SMALL_STATE(13096)] = 622428,
  [SMALL_STATE(13097)] = 622471,
  [SMALL_STATE(13098)] = 622506,
  [SMALL_STATE(13099)] = 622561,
  [SMALL_STATE(13100)] = 622616,
  [SMALL_STATE(13101)] = 622649,
  [SMALL_STATE(13102)] = 622684,
  [SMALL_STATE(13103)] = 622737,
  [SMALL_STATE(13104)] = 622788,
  [SMALL_STATE(13105)] = 622829,
  [SMALL_STATE(13106)] = 622870,
  [SMALL_STATE(13107)] = 622901,
  [SMALL_STATE(13108)] = 622956,
  [SMALL_STATE(13109)] = 622989,
  [SMALL_STATE(13110)] = 623038,
  [SMALL_STATE(13111)] = 623093,
  [SMALL_STATE(13112)] = 623126,
  [SMALL_STATE(13113)] = 623167,
  [SMALL_STATE(13114)] = 623202,
  [SMALL_STATE(13115)] = 623237,
  [SMALL_STATE(13116)] = 623280,
  [SMALL_STATE(13117)] = 623313,
  [SMALL_STATE(13118)] = 623344,
  [SMALL_STATE(13119)] = 623399,
  [SMALL_STATE(13120)] = 623434,
  [SMALL_STATE(13121)] = 623465,
  [SMALL_STATE(13122)] = 623518,
  [SMALL_STATE(13123)] = 623573,
  [SMALL_STATE(13124)] = 623604,
  [SMALL_STATE(13125)] = 623635,
  [SMALL_STATE(13126)] = 623690,
  [SMALL_STATE(13127)] = 623739,
  [SMALL_STATE(13128)] = 623780,
  [SMALL_STATE(13129)] = 623815,
  [SMALL_STATE(13130)] = 623850,
  [SMALL_STATE(13131)] = 623893,
  [SMALL_STATE(13132)] = 623936,
  [SMALL_STATE(13133)] = 623983,
  [SMALL_STATE(13134)] = 624030,
  [SMALL_STATE(13135)] = 624081,
  [SMALL_STATE(13136)] = 624118,
  [SMALL_STATE(13137)] = 624171,
  [SMALL_STATE(13138)] = 624214,
  [SMALL_STATE(13139)] = 624261,
  [SMALL_STATE(13140)] = 624316,
  [SMALL_STATE(13141)] = 624349,
  [SMALL_STATE(13142)] = 624400,
  [SMALL_STATE(13143)] = 624435,
  [SMALL_STATE(13144)] = 624486,
  [SMALL_STATE(13145)] = 624537,
  [SMALL_STATE(13146)] = 624584,
  [SMALL_STATE(13147)] = 624627,
  [SMALL_STATE(13148)] = 624658,
  [SMALL_STATE(13149)] = 624693,
  [SMALL_STATE(13150)] = 624724,
  [SMALL_STATE(13151)] = 624779,
  [SMALL_STATE(13152)] = 624820,
  [SMALL_STATE(13153)] = 624863,
  [SMALL_STATE(13154)] = 624898,
  [SMALL_STATE(13155)] = 624953,
  [SMALL_STATE(13156)] = 625004,
  [SMALL_STATE(13157)] = 625039,
  [SMALL_STATE(13158)] = 625080,
  [SMALL_STATE(13159)] = 625115,
  [SMALL_STATE(13160)] = 625150,
  [SMALL_STATE(13161)] = 625193,
  [SMALL_STATE(13162)] = 625236,
  [SMALL_STATE(13163)] = 625289,
  [SMALL_STATE(13164)] = 625332,
  [SMALL_STATE(13165)] = 625381,
  [SMALL_STATE(13166)] = 625434,
  [SMALL_STATE(13167)] = 625489,
  [SMALL_STATE(13168)] = 625522,
  [SMALL_STATE(13169)] = 625555,
  [SMALL_STATE(13170)] = 625592,
  [SMALL_STATE(13171)] = 625647,
  [SMALL_STATE(13172)] = 625680,
  [SMALL_STATE(13173)] = 625717,
  [SMALL_STATE(13174)] = 625770,
  [SMALL_STATE(13175)] = 625821,
  [SMALL_STATE(13176)] = 625854,
  [SMALL_STATE(13177)] = 625907,
  [SMALL_STATE(13178)] = 625940,
  [SMALL_STATE(13179)] = 625981,
  [SMALL_STATE(13180)] = 626032,
  [SMALL_STATE(13181)] = 626073,
  [SMALL_STATE(13182)] = 626106,
  [SMALL_STATE(13183)] = 626141,
  [SMALL_STATE(13184)] = 626172,
  [SMALL_STATE(13185)] = 626207,
  [SMALL_STATE(13186)] = 626250,
  [SMALL_STATE(13187)] = 626293,
  [SMALL_STATE(13188)] = 626340,
  [SMALL_STATE(13189)] = 626389,
  [SMALL_STATE(13190)] = 626442,
  [SMALL_STATE(13191)] = 626479,
  [SMALL_STATE(13192)] = 626532,
  [SMALL_STATE(13193)] = 626567,
  [SMALL_STATE(13194)] = 626622,
  [SMALL_STATE(13195)] = 626677,
  [SMALL_STATE(13196)] = 626728,
  [SMALL_STATE(13197)] = 626781,
  [SMALL_STATE(13198)] = 626812,
  [SMALL_STATE(13199)] = 626865,
  [SMALL_STATE(13200)] = 626904,
  [SMALL_STATE(13201)] = 626935,
  [SMALL_STATE(13202)] = 626976,
  [SMALL_STATE(13203)] = 627031,
  [SMALL_STATE(13204)] = 627062,
  [SMALL_STATE(13205)] = 627117,
  [SMALL_STATE(13206)] = 627172,
  [SMALL_STATE(13207)] = 627223,
  [SMALL_STATE(13208)] = 627276,
  [SMALL_STATE(13209)] = 627311,
  [SMALL_STATE(13210)] = 627352,
  [SMALL_STATE(13211)] = 627387,
  [SMALL_STATE(13212)] = 627438,
  [SMALL_STATE(13213)] = 627489,
  [SMALL_STATE(13214)] = 627522,
  [SMALL_STATE(13215)] = 627577,
  [SMALL_STATE(13216)] = 627610,
  [SMALL_STATE(13217)] = 627641,
  [SMALL_STATE(13218)] = 627696,
  [SMALL_STATE(13219)] = 627751,
  [SMALL_STATE(13220)] = 627802,
  [SMALL_STATE(13221)] = 627843,
  [SMALL_STATE(13222)] = 627878,
  [SMALL_STATE(13223)] = 627913,
  [SMALL_STATE(13224)] = 627954,
  [SMALL_STATE(13225)] = 627985,
  [SMALL_STATE(13226)] = 628016,
  [SMALL_STATE(13227)] = 628069,
  [SMALL_STATE(13228)] = 628124,
  [SMALL_STATE(13229)] = 628159,
  [SMALL_STATE(13230)] = 628202,
  [SMALL_STATE(13231)] = 628245,
  [SMALL_STATE(13232)] = 628292,
  [SMALL_STATE(13233)] = 628323,
  [SMALL_STATE(13234)] = 628372,
  [SMALL_STATE(13235)] = 628425,
  [SMALL_STATE(13236)] = 628462,
  [SMALL_STATE(13237)] = 628515,
  [SMALL_STATE(13238)] = 628558,
  [SMALL_STATE(13239)] = 628591,
  [SMALL_STATE(13240)] = 628632,
  [SMALL_STATE(13241)] = 628665,
  [SMALL_STATE(13242)] = 628696,
  [SMALL_STATE(13243)] = 628727,
  [SMALL_STATE(13244)] = 628768,
  [SMALL_STATE(13245)] = 628809,
  [SMALL_STATE(13246)] = 628864,
  [SMALL_STATE(13247)] = 628919,
  [SMALL_STATE(13248)] = 628954,
  [SMALL_STATE(13249)] = 629009,
  [SMALL_STATE(13250)] = 629050,
  [SMALL_STATE(13251)] = 629103,
  [SMALL_STATE(13252)] = 629158,
  [SMALL_STATE(13253)] = 629213,
  [SMALL_STATE(13254)] = 629268,
  [SMALL_STATE(13255)] = 629323,
  [SMALL_STATE(13256)] = 629378,
  [SMALL_STATE(13257)] = 629433,
  [SMALL_STATE(13258)] = 629466,
  [SMALL_STATE(13259)] = 629521,
  [SMALL_STATE(13260)] = 629554,
  [SMALL_STATE(13261)] = 629595,
  [SMALL_STATE(13262)] = 629636,
  [SMALL_STATE(13263)] = 629667,
  [SMALL_STATE(13264)] = 629700,
  [SMALL_STATE(13265)] = 629731,
  [SMALL_STATE(13266)] = 629786,
  [SMALL_STATE(13267)] = 629841,
  [SMALL_STATE(13268)] = 629872,
  [SMALL_STATE(13269)] = 629913,
  [SMALL_STATE(13270)] = 629946,
  [SMALL_STATE(13271)] = 629979,
  [SMALL_STATE(13272)] = 630034,
  [SMALL_STATE(13273)] = 630089,
  [SMALL_STATE(13274)] = 630128,
  [SMALL_STATE(13275)] = 630177,
  [SMALL_STATE(13276)] = 630232,
  [SMALL_STATE(13277)] = 630263,
  [SMALL_STATE(13278)] = 630298,
  [SMALL_STATE(13279)] = 630333,
  [SMALL_STATE(13280)] = 630368,
  [SMALL_STATE(13281)] = 630419,
  [SMALL_STATE(13282)] = 630450,
  [SMALL_STATE(13283)] = 630491,
  [SMALL_STATE(13284)] = 630532,
  [SMALL_STATE(13285)] = 630567,
  [SMALL_STATE(13286)] = 630602,
  [SMALL_STATE(13287)] = 630645,
  [SMALL_STATE(13288)] = 630688,
  [SMALL_STATE(13289)] = 630743,
  [SMALL_STATE(13290)] = 630778,
  [SMALL_STATE(13291)] = 630825,
  [SMALL_STATE(13292)] = 630858,
  [SMALL_STATE(13293)] = 630889,
  [SMALL_STATE(13294)] = 630944,
  [SMALL_STATE(13295)] = 630993,
  [SMALL_STATE(13296)] = 631024,
  [SMALL_STATE(13297)] = 631057,
  [SMALL_STATE(13298)] = 631112,
  [SMALL_STATE(13299)] = 631167,
  [SMALL_STATE(13300)] = 631220,
  [SMALL_STATE(13301)] = 631257,
  [SMALL_STATE(13302)] = 631292,
  [SMALL_STATE(13303)] = 631325,
  [SMALL_STATE(13304)] = 631366,
  [SMALL_STATE(13305)] = 631419,
  [SMALL_STATE(13306)] = 631450,
  [SMALL_STATE(13307)] = 631481,
  [SMALL_STATE(13308)] = 631536,
  [SMALL_STATE(13309)] = 631577,
  [SMALL_STATE(13310)] = 631618,
  [SMALL_STATE(13311)] = 631671,
  [SMALL_STATE(13312)] = 631712,
  [SMALL_STATE(13313)] = 631767,
  [SMALL_STATE(13314)] = 631822,
  [SMALL_STATE(13315)] = 631877,
  [SMALL_STATE(13316)] = 631918,
  [SMALL_STATE(13317)] = 631973,
  [SMALL_STATE(13318)] = 632006,
  [SMALL_STATE(13319)] = 632061,
  [SMALL_STATE(13320)] = 632116,
  [SMALL_STATE(13321)] = 632165,
  [SMALL_STATE(13322)] = 632206,
  [SMALL_STATE(13323)] = 632247,
  [SMALL_STATE(13324)] = 632278,
  [SMALL_STATE(13325)] = 632333,
  [SMALL_STATE(13326)] = 632368,
  [SMALL_STATE(13327)] = 632403,
  [SMALL_STATE(13328)] = 632436,
  [SMALL_STATE(13329)] = 632471,
  [SMALL_STATE(13330)] = 632512,
  [SMALL_STATE(13331)] = 632563,
  [SMALL_STATE(13332)] = 632618,
  [SMALL_STATE(13333)] = 632653,
  [SMALL_STATE(13334)] = 632694,
  [SMALL_STATE(13335)] = 632727,
  [SMALL_STATE(13336)] = 632762,
  [SMALL_STATE(13337)] = 632797,
  [SMALL_STATE(13338)] = 632840,
  [SMALL_STATE(13339)] = 632883,
  [SMALL_STATE(13340)] = 632918,
  [SMALL_STATE(13341)] = 632965,
  [SMALL_STATE(13342)] = 633020,
  [SMALL_STATE(13343)] = 633053,
  [SMALL_STATE(13344)] = 633094,
  [SMALL_STATE(13345)] = 633143,
  [SMALL_STATE(13346)] = 633196,
  [SMALL_STATE(13347)] = 633227,
  [SMALL_STATE(13348)] = 633268,
  [SMALL_STATE(13349)] = 633323,
  [SMALL_STATE(13350)] = 633360,
  [SMALL_STATE(13351)] = 633415,
  [SMALL_STATE(13352)] = 633470,
  [SMALL_STATE(13353)] = 633523,
  [SMALL_STATE(13354)] = 633554,
  [SMALL_STATE(13355)] = 633585,
  [SMALL_STATE(13356)] = 633616,
  [SMALL_STATE(13357)] = 633651,
  [SMALL_STATE(13358)] = 633694,
  [SMALL_STATE(13359)] = 633749,
  [SMALL_STATE(13360)] = 633790,
  [SMALL_STATE(13361)] = 633845,
  [SMALL_STATE(13362)] = 633880,
  [SMALL_STATE(13363)] = 633910,
  [SMALL_STATE(13364)] = 633952,
  [SMALL_STATE(13365)] = 634004,
  [SMALL_STATE(13366)] = 634056,
  [SMALL_STATE(13367)] = 634086,
  [SMALL_STATE(13368)] = 634138,
  [SMALL_STATE(13369)] = 634168,
  [SMALL_STATE(13370)] = 634198,
  [SMALL_STATE(13371)] = 634250,
  [SMALL_STATE(13372)] = 634280,
  [SMALL_STATE(13373)] = 634322,
  [SMALL_STATE(13374)] = 634370,
  [SMALL_STATE(13375)] = 634416,
  [SMALL_STATE(13376)] = 634462,
  [SMALL_STATE(13377)] = 634494,
  [SMALL_STATE(13378)] = 634544,
  [SMALL_STATE(13379)] = 634580,
  [SMALL_STATE(13380)] = 634626,
  [SMALL_STATE(13381)] = 634674,
  [SMALL_STATE(13382)] = 634708,
  [SMALL_STATE(13383)] = 634750,
  [SMALL_STATE(13384)] = 634804,
  [SMALL_STATE(13385)] = 634848,
  [SMALL_STATE(13386)] = 634890,
  [SMALL_STATE(13387)] = 634920,
  [SMALL_STATE(13388)] = 634972,
  [SMALL_STATE(13389)] = 635018,
  [SMALL_STATE(13390)] = 635048,
  [SMALL_STATE(13391)] = 635078,
  [SMALL_STATE(13392)] = 635108,
  [SMALL_STATE(13393)] = 635158,
  [SMALL_STATE(13394)] = 635188,
  [SMALL_STATE(13395)] = 635218,
  [SMALL_STATE(13396)] = 635248,
  [SMALL_STATE(13397)] = 635298,
  [SMALL_STATE(13398)] = 635346,
  [SMALL_STATE(13399)] = 635398,
  [SMALL_STATE(13400)] = 635444,
  [SMALL_STATE(13401)] = 635492,
  [SMALL_STATE(13402)] = 635526,
  [SMALL_STATE(13403)] = 635574,
  [SMALL_STATE(13404)] = 635620,
  [SMALL_STATE(13405)] = 635650,
  [SMALL_STATE(13406)] = 635698,
  [SMALL_STATE(13407)] = 635744,
  [SMALL_STATE(13408)] = 635790,
  [SMALL_STATE(13409)] = 635842,
  [SMALL_STATE(13410)] = 635888,
  [SMALL_STATE(13411)] = 635934,
  [SMALL_STATE(13412)] = 635980,
  [SMALL_STATE(13413)] = 636032,
  [SMALL_STATE(13414)] = 636080,
  [SMALL_STATE(13415)] = 636112,
  [SMALL_STATE(13416)] = 636162,
  [SMALL_STATE(13417)] = 636214,
  [SMALL_STATE(13418)] = 636246,
  [SMALL_STATE(13419)] = 636298,
  [SMALL_STATE(13420)] = 636348,
  [SMALL_STATE(13421)] = 636400,
  [SMALL_STATE(13422)] = 636428,
  [SMALL_STATE(13423)] = 636480,
  [SMALL_STATE(13424)] = 636512,
  [SMALL_STATE(13425)] = 636564,
  [SMALL_STATE(13426)] = 636612,
  [SMALL_STATE(13427)] = 636644,
  [SMALL_STATE(13428)] = 636692,
  [SMALL_STATE(13429)] = 636740,
  [SMALL_STATE(13430)] = 636772,
  [SMALL_STATE(13431)] = 636802,
  [SMALL_STATE(13432)] = 636832,
  [SMALL_STATE(13433)] = 636880,
  [SMALL_STATE(13434)] = 636916,
  [SMALL_STATE(13435)] = 636952,
  [SMALL_STATE(13436)] = 637002,
  [SMALL_STATE(13437)] = 637034,
  [SMALL_STATE(13438)] = 637084,
  [SMALL_STATE(13439)] = 637116,
  [SMALL_STATE(13440)] = 637164,
  [SMALL_STATE(13441)] = 637212,
  [SMALL_STATE(13442)] = 637264,
  [SMALL_STATE(13443)] = 637314,
  [SMALL_STATE(13444)] = 637344,
  [SMALL_STATE(13445)] = 637394,
  [SMALL_STATE(13446)] = 637424,
  [SMALL_STATE(13447)] = 637476,
  [SMALL_STATE(13448)] = 637528,
  [SMALL_STATE(13449)] = 637578,
  [SMALL_STATE(13450)] = 637626,
  [SMALL_STATE(13451)] = 637674,
  [SMALL_STATE(13452)] = 637706,
  [SMALL_STATE(13453)] = 637736,
  [SMALL_STATE(13454)] = 637784,
  [SMALL_STATE(13455)] = 637832,
  [SMALL_STATE(13456)] = 637872,
  [SMALL_STATE(13457)] = 637912,
  [SMALL_STATE(13458)] = 637942,
  [SMALL_STATE(13459)] = 637974,
  [SMALL_STATE(13460)] = 638020,
  [SMALL_STATE(13461)] = 638052,
  [SMALL_STATE(13462)] = 638088,
  [SMALL_STATE(13463)] = 638142,
  [SMALL_STATE(13464)] = 638188,
  [SMALL_STATE(13465)] = 638236,
  [SMALL_STATE(13466)] = 638284,
  [SMALL_STATE(13467)] = 638332,
  [SMALL_STATE(13468)] = 638380,
  [SMALL_STATE(13469)] = 638412,
  [SMALL_STATE(13470)] = 638442,
  [SMALL_STATE(13471)] = 638494,
  [SMALL_STATE(13472)] = 638526,
  [SMALL_STATE(13473)] = 638558,
  [SMALL_STATE(13474)] = 638604,
  [SMALL_STATE(13475)] = 638650,
  [SMALL_STATE(13476)] = 638702,
  [SMALL_STATE(13477)] = 638732,
  [SMALL_STATE(13478)] = 638780,
  [SMALL_STATE(13479)] = 638812,
  [SMALL_STATE(13480)] = 638842,
  [SMALL_STATE(13481)] = 638872,
  [SMALL_STATE(13482)] = 638922,
  [SMALL_STATE(13483)] = 638970,
  [SMALL_STATE(13484)] = 639018,
  [SMALL_STATE(13485)] = 639060,
  [SMALL_STATE(13486)] = 639090,
  [SMALL_STATE(13487)] = 639138,
  [SMALL_STATE(13488)] = 639168,
  [SMALL_STATE(13489)] = 639218,
  [SMALL_STATE(13490)] = 639248,
  [SMALL_STATE(13491)] = 639302,
  [SMALL_STATE(13492)] = 639334,
  [SMALL_STATE(13493)] = 639382,
  [SMALL_STATE(13494)] = 639430,
  [SMALL_STATE(13495)] = 639478,
  [SMALL_STATE(13496)] = 639526,
  [SMALL_STATE(13497)] = 639574,
  [SMALL_STATE(13498)] = 639622,
  [SMALL_STATE(13499)] = 639664,
  [SMALL_STATE(13500)] = 639716,
  [SMALL_STATE(13501)] = 639756,
  [SMALL_STATE(13502)] = 639790,
  [SMALL_STATE(13503)] = 639824,
  [SMALL_STATE(13504)] = 639866,
  [SMALL_STATE(13505)] = 639908,
  [SMALL_STATE(13506)] = 639954,
  [SMALL_STATE(13507)] = 640000,
  [SMALL_STATE(13508)] = 640050,
  [SMALL_STATE(13509)] = 640086,
  [SMALL_STATE(13510)] = 640136,
  [SMALL_STATE(13511)] = 640166,
  [SMALL_STATE(13512)] = 640196,
  [SMALL_STATE(13513)] = 640244,
  [SMALL_STATE(13514)] = 640292,
  [SMALL_STATE(13515)] = 640342,
  [SMALL_STATE(13516)] = 640382,
  [SMALL_STATE(13517)] = 640412,
  [SMALL_STATE(13518)] = 640444,
  [SMALL_STATE(13519)] = 640496,
  [SMALL_STATE(13520)] = 640526,
  [SMALL_STATE(13521)] = 640558,
  [SMALL_STATE(13522)] = 640604,
  [SMALL_STATE(13523)] = 640650,
  [SMALL_STATE(13524)] = 640698,
  [SMALL_STATE(13525)] = 640750,
  [SMALL_STATE(13526)] = 640796,
  [SMALL_STATE(13527)] = 640846,
  [SMALL_STATE(13528)] = 640878,
  [SMALL_STATE(13529)] = 640910,
  [SMALL_STATE(13530)] = 640956,
  [SMALL_STATE(13531)] = 641008,
  [SMALL_STATE(13532)] = 641056,
  [SMALL_STATE(13533)] = 641086,
  [SMALL_STATE(13534)] = 641138,
  [SMALL_STATE(13535)] = 641190,
  [SMALL_STATE(13536)] = 641222,
  [SMALL_STATE(13537)] = 641270,
  [SMALL_STATE(13538)] = 641300,
  [SMALL_STATE(13539)] = 641348,
  [SMALL_STATE(13540)] = 641376,
  [SMALL_STATE(13541)] = 641424,
  [SMALL_STATE(13542)] = 641474,
  [SMALL_STATE(13543)] = 641502,
  [SMALL_STATE(13544)] = 641532,
  [SMALL_STATE(13545)] = 641578,
  [SMALL_STATE(13546)] = 641626,
  [SMALL_STATE(13547)] = 641674,
  [SMALL_STATE(13548)] = 641706,
  [SMALL_STATE(13549)] = 641754,
  [SMALL_STATE(13550)] = 641806,
  [SMALL_STATE(13551)] = 641854,
  [SMALL_STATE(13552)] = 641882,
  [SMALL_STATE(13553)] = 641930,
  [SMALL_STATE(13554)] = 641982,
  [SMALL_STATE(13555)] = 642022,
  [SMALL_STATE(13556)] = 642056,
  [SMALL_STATE(13557)] = 642108,
  [SMALL_STATE(13558)] = 642142,
  [SMALL_STATE(13559)] = 642190,
  [SMALL_STATE(13560)] = 642244,
  [SMALL_STATE(13561)] = 642276,
  [SMALL_STATE(13562)] = 642324,
  [SMALL_STATE(13563)] = 642376,
  [SMALL_STATE(13564)] = 642408,
  [SMALL_STATE(13565)] = 642456,
  [SMALL_STATE(13566)] = 642488,
  [SMALL_STATE(13567)] = 642518,
  [SMALL_STATE(13568)] = 642550,
  [SMALL_STATE(13569)] = 642602,
  [SMALL_STATE(13570)] = 642654,
  [SMALL_STATE(13571)] = 642686,
  [SMALL_STATE(13572)] = 642718,
  [SMALL_STATE(13573)] = 642766,
  [SMALL_STATE(13574)] = 642798,
  [SMALL_STATE(13575)] = 642830,
  [SMALL_STATE(13576)] = 642878,
  [SMALL_STATE(13577)] = 642918,
  [SMALL_STATE(13578)] = 642950,
  [SMALL_STATE(13579)] = 642988,
  [SMALL_STATE(13580)] = 643022,
  [SMALL_STATE(13581)] = 643056,
  [SMALL_STATE(13582)] = 643098,
  [SMALL_STATE(13583)] = 643128,
  [SMALL_STATE(13584)] = 643179,
  [SMALL_STATE(13585)] = 643222,
  [SMALL_STATE(13586)] = 643265,
  [SMALL_STATE(13587)] = 643308,
  [SMALL_STATE(13588)] = 643345,
  [SMALL_STATE(13589)] = 643382,
  [SMALL_STATE(13590)] = 643433,
  [SMALL_STATE(13591)] = 643484,
  [SMALL_STATE(13592)] = 643535,
  [SMALL_STATE(13593)] = 643564,
  [SMALL_STATE(13594)] = 643615,
  [SMALL_STATE(13595)] = 643646,
  [SMALL_STATE(13596)] = 643697,
  [SMALL_STATE(13597)] = 643734,
  [SMALL_STATE(13598)] = 643765,
  [SMALL_STATE(13599)] = 643816,
  [SMALL_STATE(13600)] = 643859,
  [SMALL_STATE(13601)] = 643896,
  [SMALL_STATE(13602)] = 643939,
  [SMALL_STATE(13603)] = 643982,
  [SMALL_STATE(13604)] = 644019,
  [SMALL_STATE(13605)] = 644070,
  [SMALL_STATE(13606)] = 644121,
  [SMALL_STATE(13607)] = 644158,
  [SMALL_STATE(13608)] = 644189,
  [SMALL_STATE(13609)] = 644220,
  [SMALL_STATE(13610)] = 644257,
  [SMALL_STATE(13611)] = 644288,
  [SMALL_STATE(13612)] = 644339,
  [SMALL_STATE(13613)] = 644390,
  [SMALL_STATE(13614)] = 644427,
  [SMALL_STATE(13615)] = 644458,
  [SMALL_STATE(13616)] = 644495,
  [SMALL_STATE(13617)] = 644526,
  [SMALL_STATE(13618)] = 644577,
  [SMALL_STATE(13619)] = 644605,
  [SMALL_STATE(13620)] = 644639,
  [SMALL_STATE(13621)] = 644667,
  [SMALL_STATE(13622)] = 644715,
  [SMALL_STATE(13623)] = 644745,
  [SMALL_STATE(13624)] = 644773,
  [SMALL_STATE(13625)] = 644801,
  [SMALL_STATE(13626)] = 644829,
  [SMALL_STATE(13627)] = 644863,
  [SMALL_STATE(13628)] = 644891,
  [SMALL_STATE(13629)] = 644939,
  [SMALL_STATE(13630)] = 644967,
  [SMALL_STATE(13631)] = 644995,
  [SMALL_STATE(13632)] = 645023,
  [SMALL_STATE(13633)] = 645051,
  [SMALL_STATE(13634)] = 645085,
  [SMALL_STATE(13635)] = 645113,
  [SMALL_STATE(13636)] = 645141,
  [SMALL_STATE(13637)] = 645171,
  [SMALL_STATE(13638)] = 645213,
  [SMALL_STATE(13639)] = 645241,
  [SMALL_STATE(13640)] = 645269,
  [SMALL_STATE(13641)] = 645311,
  [SMALL_STATE(13642)] = 645339,
  [SMALL_STATE(13643)] = 645367,
  [SMALL_STATE(13644)] = 645415,
  [SMALL_STATE(13645)] = 645463,
  [SMALL_STATE(13646)] = 645491,
  [SMALL_STATE(13647)] = 645539,
  [SMALL_STATE(13648)] = 645567,
  [SMALL_STATE(13649)] = 645595,
  [SMALL_STATE(13650)] = 645623,
  [SMALL_STATE(13651)] = 645671,
  [SMALL_STATE(13652)] = 645699,
  [SMALL_STATE(13653)] = 645727,
  [SMALL_STATE(13654)] = 645761,
  [SMALL_STATE(13655)] = 645809,
  [SMALL_STATE(13656)] = 645857,
  [SMALL_STATE(13657)] = 645905,
  [SMALL_STATE(13658)] = 645933,
  [SMALL_STATE(13659)] = 645961,
  [SMALL_STATE(13660)] = 646009,
  [SMALL_STATE(13661)] = 646051,
  [SMALL_STATE(13662)] = 646085,
  [SMALL_STATE(13663)] = 646113,
  [SMALL_STATE(13664)] = 646161,
  [SMALL_STATE(13665)] = 646189,
  [SMALL_STATE(13666)] = 646237,
  [SMALL_STATE(13667)] = 646277,
  [SMALL_STATE(13668)] = 646311,
  [SMALL_STATE(13669)] = 646359,
  [SMALL_STATE(13670)] = 646387,
  [SMALL_STATE(13671)] = 646425,
  [SMALL_STATE(13672)] = 646463,
  [SMALL_STATE(13673)] = 646493,
  [SMALL_STATE(13674)] = 646535,
  [SMALL_STATE(13675)] = 646563,
  [SMALL_STATE(13676)] = 646591,
  [SMALL_STATE(13677)] = 646625,
  [SMALL_STATE(13678)] = 646653,
  [SMALL_STATE(13679)] = 646681,
  [SMALL_STATE(13680)] = 646709,
  [SMALL_STATE(13681)] = 646737,
  [SMALL_STATE(13682)] = 646765,
  [SMALL_STATE(13683)] = 646793,
  [SMALL_STATE(13684)] = 646841,
  [SMALL_STATE(13685)] = 646869,
  [SMALL_STATE(13686)] = 646897,
  [SMALL_STATE(13687)] = 646931,
  [SMALL_STATE(13688)] = 646959,
  [SMALL_STATE(13689)] = 646987,
  [SMALL_STATE(13690)] = 647015,
  [SMALL_STATE(13691)] = 647049,
  [SMALL_STATE(13692)] = 647077,
  [SMALL_STATE(13693)] = 647105,
  [SMALL_STATE(13694)] = 647150,
  [SMALL_STATE(13695)] = 647189,
  [SMALL_STATE(13696)] = 647216,
  [SMALL_STATE(13697)] = 647247,
  [SMALL_STATE(13698)] = 647286,
  [SMALL_STATE(13699)] = 647325,
  [SMALL_STATE(13700)] = 647356,
  [SMALL_STATE(13701)] = 647383,
  [SMALL_STATE(13702)] = 647410,
  [SMALL_STATE(13703)] = 647437,
  [SMALL_STATE(13704)] = 647476,
  [SMALL_STATE(13705)] = 647515,
  [SMALL_STATE(13706)] = 647554,
  [SMALL_STATE(13707)] = 647581,
  [SMALL_STATE(13708)] = 647608,
  [SMALL_STATE(13709)] = 647653,
  [SMALL_STATE(13710)] = 647684,
  [SMALL_STATE(13711)] = 647715,
  [SMALL_STATE(13712)] = 647754,
  [SMALL_STATE(13713)] = 647793,
  [SMALL_STATE(13714)] = 647824,
  [SMALL_STATE(13715)] = 647853,
  [SMALL_STATE(13716)] = 647884,
  [SMALL_STATE(13717)] = 647927,
  [SMALL_STATE(13718)] = 647958,
  [SMALL_STATE(13719)] = 647997,
  [SMALL_STATE(13720)] = 648028,
  [SMALL_STATE(13721)] = 648059,
  [SMALL_STATE(13722)] = 648086,
  [SMALL_STATE(13723)] = 648117,
  [SMALL_STATE(13724)] = 648148,
  [SMALL_STATE(13725)] = 648179,
  [SMALL_STATE(13726)] = 648218,
  [SMALL_STATE(13727)] = 648249,
  [SMALL_STATE(13728)] = 648288,
  [SMALL_STATE(13729)] = 648319,
  [SMALL_STATE(13730)] = 648344,
  [SMALL_STATE(13731)] = 648383,
  [SMALL_STATE(13732)] = 648408,
  [SMALL_STATE(13733)] = 648439,
  [SMALL_STATE(13734)] = 648464,
  [SMALL_STATE(13735)] = 648489,
  [SMALL_STATE(13736)] = 648528,
  [SMALL_STATE(13737)] = 648567,
  [SMALL_STATE(13738)] = 648606,
  [SMALL_STATE(13739)] = 648637,
  [SMALL_STATE(13740)] = 648676,
  [SMALL_STATE(13741)] = 648715,
  [SMALL_STATE(13742)] = 648746,
  [SMALL_STATE(13743)] = 648785,
  [SMALL_STATE(13744)] = 648816,
  [SMALL_STATE(13745)] = 648843,
  [SMALL_STATE(13746)] = 648874,
  [SMALL_STATE(13747)] = 648905,
  [SMALL_STATE(13748)] = 648936,
  [SMALL_STATE(13749)] = 648967,
  [SMALL_STATE(13750)] = 649006,
  [SMALL_STATE(13751)] = 649033,
  [SMALL_STATE(13752)] = 649072,
  [SMALL_STATE(13753)] = 649111,
  [SMALL_STATE(13754)] = 649150,
  [SMALL_STATE(13755)] = 649181,
  [SMALL_STATE(13756)] = 649212,
  [SMALL_STATE(13757)] = 649243,
  [SMALL_STATE(13758)] = 649274,
  [SMALL_STATE(13759)] = 649305,
  [SMALL_STATE(13760)] = 649336,
  [SMALL_STATE(13761)] = 649375,
  [SMALL_STATE(13762)] = 649406,
  [SMALL_STATE(13763)] = 649437,
  [SMALL_STATE(13764)] = 649464,
  [SMALL_STATE(13765)] = 649495,
  [SMALL_STATE(13766)] = 649522,
  [SMALL_STATE(13767)] = 649553,
  [SMALL_STATE(13768)] = 649592,
  [SMALL_STATE(13769)] = 649631,
  [SMALL_STATE(13770)] = 649662,
  [SMALL_STATE(13771)] = 649701,
  [SMALL_STATE(13772)] = 649740,
  [SMALL_STATE(13773)] = 649779,
  [SMALL_STATE(13774)] = 649810,
  [SMALL_STATE(13775)] = 649849,
  [SMALL_STATE(13776)] = 649880,
  [SMALL_STATE(13777)] = 649919,
  [SMALL_STATE(13778)] = 649958,
  [SMALL_STATE(13779)] = 649985,
  [SMALL_STATE(13780)] = 650024,
  [SMALL_STATE(13781)] = 650067,
  [SMALL_STATE(13782)] = 650098,
  [SMALL_STATE(13783)] = 650129,
  [SMALL_STATE(13784)] = 650158,
  [SMALL_STATE(13785)] = 650197,
  [SMALL_STATE(13786)] = 650238,
  [SMALL_STATE(13787)] = 650283,
  [SMALL_STATE(13788)] = 650310,
  [SMALL_STATE(13789)] = 650341,
  [SMALL_STATE(13790)] = 650380,
  [SMALL_STATE(13791)] = 650411,
  [SMALL_STATE(13792)] = 650450,
  [SMALL_STATE(13793)] = 650485,
  [SMALL_STATE(13794)] = 650530,
  [SMALL_STATE(13795)] = 650569,
  [SMALL_STATE(13796)] = 650608,
  [SMALL_STATE(13797)] = 650639,
  [SMALL_STATE(13798)] = 650678,
  [SMALL_STATE(13799)] = 650723,
  [SMALL_STATE(13800)] = 650748,
  [SMALL_STATE(13801)] = 650787,
  [SMALL_STATE(13802)] = 650818,
  [SMALL_STATE(13803)] = 650863,
  [SMALL_STATE(13804)] = 650892,
  [SMALL_STATE(13805)] = 650931,
  [SMALL_STATE(13806)] = 650962,
  [SMALL_STATE(13807)] = 650991,
  [SMALL_STATE(13808)] = 651022,
  [SMALL_STATE(13809)] = 651053,
  [SMALL_STATE(13810)] = 651092,
  [SMALL_STATE(13811)] = 651131,
  [SMALL_STATE(13812)] = 651162,
  [SMALL_STATE(13813)] = 651201,
  [SMALL_STATE(13814)] = 651228,
  [SMALL_STATE(13815)] = 651255,
  [SMALL_STATE(13816)] = 651294,
  [SMALL_STATE(13817)] = 651333,
  [SMALL_STATE(13818)] = 651360,
  [SMALL_STATE(13819)] = 651387,
  [SMALL_STATE(13820)] = 651414,
  [SMALL_STATE(13821)] = 651453,
  [SMALL_STATE(13822)] = 651484,
  [SMALL_STATE(13823)] = 651515,
  [SMALL_STATE(13824)] = 651546,
  [SMALL_STATE(13825)] = 651585,
  [SMALL_STATE(13826)] = 651624,
  [SMALL_STATE(13827)] = 651669,
  [SMALL_STATE(13828)] = 651700,
  [SMALL_STATE(13829)] = 651731,
  [SMALL_STATE(13830)] = 651758,
  [SMALL_STATE(13831)] = 651797,
  [SMALL_STATE(13832)] = 651836,
  [SMALL_STATE(13833)] = 651875,
  [SMALL_STATE(13834)] = 651914,
  [SMALL_STATE(13835)] = 651953,
  [SMALL_STATE(13836)] = 651984,
  [SMALL_STATE(13837)] = 652015,
  [SMALL_STATE(13838)] = 652046,
  [SMALL_STATE(13839)] = 652085,
  [SMALL_STATE(13840)] = 652116,
  [SMALL_STATE(13841)] = 652147,
  [SMALL_STATE(13842)] = 652176,
  [SMALL_STATE(13843)] = 652215,
  [SMALL_STATE(13844)] = 652254,
  [SMALL_STATE(13845)] = 652285,
  [SMALL_STATE(13846)] = 652316,
  [SMALL_STATE(13847)] = 652343,
  [SMALL_STATE(13848)] = 652370,
  [SMALL_STATE(13849)] = 652397,
  [SMALL_STATE(13850)] = 652424,
  [SMALL_STATE(13851)] = 652451,
  [SMALL_STATE(13852)] = 652478,
  [SMALL_STATE(13853)] = 652509,
  [SMALL_STATE(13854)] = 652536,
  [SMALL_STATE(13855)] = 652567,
  [SMALL_STATE(13856)] = 652592,
  [SMALL_STATE(13857)] = 652623,
  [SMALL_STATE(13858)] = 652654,
  [SMALL_STATE(13859)] = 652681,
  [SMALL_STATE(13860)] = 652720,
  [SMALL_STATE(13861)] = 652751,
  [SMALL_STATE(13862)] = 652778,
  [SMALL_STATE(13863)] = 652817,
  [SMALL_STATE(13864)] = 652856,
  [SMALL_STATE(13865)] = 652895,
  [SMALL_STATE(13866)] = 652934,
  [SMALL_STATE(13867)] = 652961,
  [SMALL_STATE(13868)] = 652988,
  [SMALL_STATE(13869)] = 653019,
  [SMALL_STATE(13870)] = 653058,
  [SMALL_STATE(13871)] = 653089,
  [SMALL_STATE(13872)] = 653120,
  [SMALL_STATE(13873)] = 653151,
  [SMALL_STATE(13874)] = 653190,
  [SMALL_STATE(13875)] = 653221,
  [SMALL_STATE(13876)] = 653260,
  [SMALL_STATE(13877)] = 653299,
  [SMALL_STATE(13878)] = 653338,
  [SMALL_STATE(13879)] = 653365,
  [SMALL_STATE(13880)] = 653392,
  [SMALL_STATE(13881)] = 653423,
  [SMALL_STATE(13882)] = 653462,
  [SMALL_STATE(13883)] = 653493,
  [SMALL_STATE(13884)] = 653532,
  [SMALL_STATE(13885)] = 653571,
  [SMALL_STATE(13886)] = 653602,
  [SMALL_STATE(13887)] = 653633,
  [SMALL_STATE(13888)] = 653672,
  [SMALL_STATE(13889)] = 653699,
  [SMALL_STATE(13890)] = 653738,
  [SMALL_STATE(13891)] = 653765,
  [SMALL_STATE(13892)] = 653804,
  [SMALL_STATE(13893)] = 653843,
  [SMALL_STATE(13894)] = 653882,
  [SMALL_STATE(13895)] = 653913,
  [SMALL_STATE(13896)] = 653940,
  [SMALL_STATE(13897)] = 653967,
  [SMALL_STATE(13898)] = 654006,
  [SMALL_STATE(13899)] = 654033,
  [SMALL_STATE(13900)] = 654078,
  [SMALL_STATE(13901)] = 654109,
  [SMALL_STATE(13902)] = 654140,
  [SMALL_STATE(13903)] = 654179,
  [SMALL_STATE(13904)] = 654218,
  [SMALL_STATE(13905)] = 654257,
  [SMALL_STATE(13906)] = 654288,
  [SMALL_STATE(13907)] = 654327,
  [SMALL_STATE(13908)] = 654366,
  [SMALL_STATE(13909)] = 654397,
  [SMALL_STATE(13910)] = 654436,
  [SMALL_STATE(13911)] = 654463,
  [SMALL_STATE(13912)] = 654494,
  [SMALL_STATE(13913)] = 654521,
  [SMALL_STATE(13914)] = 654560,
  [SMALL_STATE(13915)] = 654599,
  [SMALL_STATE(13916)] = 654626,
  [SMALL_STATE(13917)] = 654665,
  [SMALL_STATE(13918)] = 654704,
  [SMALL_STATE(13919)] = 654743,
  [SMALL_STATE(13920)] = 654770,
  [SMALL_STATE(13921)] = 654801,
  [SMALL_STATE(13922)] = 654832,
  [SMALL_STATE(13923)] = 654863,
  [SMALL_STATE(13924)] = 654894,
  [SMALL_STATE(13925)] = 654921,
  [SMALL_STATE(13926)] = 654960,
  [SMALL_STATE(13927)] = 654986,
  [SMALL_STATE(13928)] = 655014,
  [SMALL_STATE(13929)] = 655038,
  [SMALL_STATE(13930)] = 655064,
  [SMALL_STATE(13931)] = 655094,
  [SMALL_STATE(13932)] = 655124,
  [SMALL_STATE(13933)] = 655152,
  [SMALL_STATE(13934)] = 655178,
  [SMALL_STATE(13935)] = 655204,
  [SMALL_STATE(13936)] = 655234,
  [SMALL_STATE(13937)] = 655260,
  [SMALL_STATE(13938)] = 655286,
  [SMALL_STATE(13939)] = 655312,
  [SMALL_STATE(13940)] = 655342,
  [SMALL_STATE(13941)] = 655368,
  [SMALL_STATE(13942)] = 655394,
  [SMALL_STATE(13943)] = 655424,
  [SMALL_STATE(13944)] = 655450,
  [SMALL_STATE(13945)] = 655476,
  [SMALL_STATE(13946)] = 655502,
  [SMALL_STATE(13947)] = 655528,
  [SMALL_STATE(13948)] = 655554,
  [SMALL_STATE(13949)] = 655584,
  [SMALL_STATE(13950)] = 655614,
  [SMALL_STATE(13951)] = 655640,
  [SMALL_STATE(13952)] = 655670,
  [SMALL_STATE(13953)] = 655696,
  [SMALL_STATE(13954)] = 655722,
  [SMALL_STATE(13955)] = 655752,
  [SMALL_STATE(13956)] = 655778,
  [SMALL_STATE(13957)] = 655804,
  [SMALL_STATE(13958)] = 655830,
  [SMALL_STATE(13959)] = 655856,
  [SMALL_STATE(13960)] = 655886,
  [SMALL_STATE(13961)] = 655916,
  [SMALL_STATE(13962)] = 655942,
  [SMALL_STATE(13963)] = 655968,
  [SMALL_STATE(13964)] = 655994,
  [SMALL_STATE(13965)] = 656018,
  [SMALL_STATE(13966)] = 656044,
  [SMALL_STATE(13967)] = 656070,
  [SMALL_STATE(13968)] = 656096,
  [SMALL_STATE(13969)] = 656122,
  [SMALL_STATE(13970)] = 656150,
  [SMALL_STATE(13971)] = 656176,
  [SMALL_STATE(13972)] = 656200,
  [SMALL_STATE(13973)] = 656226,
  [SMALL_STATE(13974)] = 656256,
  [SMALL_STATE(13975)] = 656282,
  [SMALL_STATE(13976)] = 656308,
  [SMALL_STATE(13977)] = 656334,
  [SMALL_STATE(13978)] = 656360,
  [SMALL_STATE(13979)] = 656385,
  [SMALL_STATE(13980)] = 656408,
  [SMALL_STATE(13981)] = 656437,
  [SMALL_STATE(13982)] = 656464,
  [SMALL_STATE(13983)] = 656495,
  [SMALL_STATE(13984)] = 656534,
  [SMALL_STATE(13985)] = 656557,
  [SMALL_STATE(13986)] = 656580,
  [SMALL_STATE(13987)] = 656621,
  [SMALL_STATE(13988)] = 656660,
  [SMALL_STATE(13989)] = 656683,
  [SMALL_STATE(13990)] = 656708,
  [SMALL_STATE(13991)] = 656735,
  [SMALL_STATE(13992)] = 656774,
  [SMALL_STATE(13993)] = 656797,
  [SMALL_STATE(13994)] = 656820,
  [SMALL_STATE(13995)] = 656845,
  [SMALL_STATE(13996)] = 656868,
  [SMALL_STATE(13997)] = 656891,
  [SMALL_STATE(13998)] = 656920,
  [SMALL_STATE(13999)] = 656961,
  [SMALL_STATE(14000)] = 657002,
  [SMALL_STATE(14001)] = 657041,
  [SMALL_STATE(14002)] = 657064,
  [SMALL_STATE(14003)] = 657105,
  [SMALL_STATE(14004)] = 657128,
  [SMALL_STATE(14005)] = 657153,
  [SMALL_STATE(14006)] = 657192,
  [SMALL_STATE(14007)] = 657221,
  [SMALL_STATE(14008)] = 657248,
  [SMALL_STATE(14009)] = 657287,
  [SMALL_STATE(14010)] = 657326,
  [SMALL_STATE(14011)] = 657349,
  [SMALL_STATE(14012)] = 657390,
  [SMALL_STATE(14013)] = 657413,
  [SMALL_STATE(14014)] = 657452,
  [SMALL_STATE(14015)] = 657475,
  [SMALL_STATE(14016)] = 657504,
  [SMALL_STATE(14017)] = 657527,
  [SMALL_STATE(14018)] = 657550,
  [SMALL_STATE(14019)] = 657591,
  [SMALL_STATE(14020)] = 657614,
  [SMALL_STATE(14021)] = 657641,
  [SMALL_STATE(14022)] = 657664,
  [SMALL_STATE(14023)] = 657697,
  [SMALL_STATE(14024)] = 657730,
  [SMALL_STATE(14025)] = 657755,
  [SMALL_STATE(14026)] = 657784,
  [SMALL_STATE(14027)] = 657822,
  [SMALL_STATE(14028)] = 657860,
  [SMALL_STATE(14029)] = 657884,
  [SMALL_STATE(14030)] = 657922,
  [SMALL_STATE(14031)] = 657946,
  [SMALL_STATE(14032)] = 657970,
  [SMALL_STATE(14033)] = 658008,
  [SMALL_STATE(14034)] = 658046,
  [SMALL_STATE(14035)] = 658070,
  [SMALL_STATE(14036)] = 658094,
  [SMALL_STATE(14037)] = 658132,
  [SMALL_STATE(14038)] = 658166,
  [SMALL_STATE(14039)] = 658196,
  [SMALL_STATE(14040)] = 658220,
  [SMALL_STATE(14041)] = 658258,
  [SMALL_STATE(14042)] = 658296,
  [SMALL_STATE(14043)] = 658334,
  [SMALL_STATE(14044)] = 658368,
  [SMALL_STATE(14045)] = 658406,
  [SMALL_STATE(14046)] = 658430,
  [SMALL_STATE(14047)] = 658452,
  [SMALL_STATE(14048)] = 658486,
  [SMALL_STATE(14049)] = 658524,
  [SMALL_STATE(14050)] = 658554,
  [SMALL_STATE(14051)] = 658588,
  [SMALL_STATE(14052)] = 658622,
  [SMALL_STATE(14053)] = 658652,
  [SMALL_STATE(14054)] = 658686,
  [SMALL_STATE(14055)] = 658716,
  [SMALL_STATE(14056)] = 658740,
  [SMALL_STATE(14057)] = 658778,
  [SMALL_STATE(14058)] = 658816,
  [SMALL_STATE(14059)] = 658846,
  [SMALL_STATE(14060)] = 658884,
  [SMALL_STATE(14061)] = 658906,
  [SMALL_STATE(14062)] = 658940,
  [SMALL_STATE(14063)] = 658970,
  [SMALL_STATE(14064)] = 658994,
  [SMALL_STATE(14065)] = 659032,
  [SMALL_STATE(14066)] = 659056,
  [SMALL_STATE(14067)] = 659078,
  [SMALL_STATE(14068)] = 659108,
  [SMALL_STATE(14069)] = 659146,
  [SMALL_STATE(14070)] = 659170,
  [SMALL_STATE(14071)] = 659194,
  [SMALL_STATE(14072)] = 659232,
  [SMALL_STATE(14073)] = 659256,
  [SMALL_STATE(14074)] = 659280,
  [SMALL_STATE(14075)] = 659304,
  [SMALL_STATE(14076)] = 659328,
  [SMALL_STATE(14077)] = 659358,
  [SMALL_STATE(14078)] = 659396,
  [SMALL_STATE(14079)] = 659426,
  [SMALL_STATE(14080)] = 659464,
  [SMALL_STATE(14081)] = 659502,
  [SMALL_STATE(14082)] = 659532,
  [SMALL_STATE(14083)] = 659556,
  [SMALL_STATE(14084)] = 659578,
  [SMALL_STATE(14085)] = 659608,
  [SMALL_STATE(14086)] = 659638,
  [SMALL_STATE(14087)] = 659676,
  [SMALL_STATE(14088)] = 659706,
  [SMALL_STATE(14089)] = 659740,
  [SMALL_STATE(14090)] = 659770,
  [SMALL_STATE(14091)] = 659804,
  [SMALL_STATE(14092)] = 659834,
  [SMALL_STATE(14093)] = 659872,
  [SMALL_STATE(14094)] = 659902,
  [SMALL_STATE(14095)] = 659938,
  [SMALL_STATE(14096)] = 659968,
  [SMALL_STATE(14097)] = 659992,
  [SMALL_STATE(14098)] = 660016,
  [SMALL_STATE(14099)] = 660050,
  [SMALL_STATE(14100)] = 660080,
  [SMALL_STATE(14101)] = 660118,
  [SMALL_STATE(14102)] = 660148,
  [SMALL_STATE(14103)] = 660178,
  [SMALL_STATE(14104)] = 660200,
  [SMALL_STATE(14105)] = 660236,
  [SMALL_STATE(14106)] = 660266,
  [SMALL_STATE(14107)] = 660296,
  [SMALL_STATE(14108)] = 660326,
  [SMALL_STATE(14109)] = 660364,
  [SMALL_STATE(14110)] = 660394,
  [SMALL_STATE(14111)] = 660428,
  [SMALL_STATE(14112)] = 660462,
  [SMALL_STATE(14113)] = 660492,
  [SMALL_STATE(14114)] = 660530,
  [SMALL_STATE(14115)] = 660568,
  [SMALL_STATE(14116)] = 660598,
  [SMALL_STATE(14117)] = 660628,
  [SMALL_STATE(14118)] = 660658,
  [SMALL_STATE(14119)] = 660692,
  [SMALL_STATE(14120)] = 660722,
  [SMALL_STATE(14121)] = 660752,
  [SMALL_STATE(14122)] = 660774,
  [SMALL_STATE(14123)] = 660800,
  [SMALL_STATE(14124)] = 660830,
  [SMALL_STATE(14125)] = 660864,
  [SMALL_STATE(14126)] = 660894,
  [SMALL_STATE(14127)] = 660918,
  [SMALL_STATE(14128)] = 660948,
  [SMALL_STATE(14129)] = 660978,
  [SMALL_STATE(14130)] = 661002,
  [SMALL_STATE(14131)] = 661032,
  [SMALL_STATE(14132)] = 661070,
  [SMALL_STATE(14133)] = 661100,
  [SMALL_STATE(14134)] = 661138,
  [SMALL_STATE(14135)] = 661162,
  [SMALL_STATE(14136)] = 661200,
  [SMALL_STATE(14137)] = 661230,
  [SMALL_STATE(14138)] = 661268,
  [SMALL_STATE(14139)] = 661298,
  [SMALL_STATE(14140)] = 661334,
  [SMALL_STATE(14141)] = 661358,
  [SMALL_STATE(14142)] = 661388,
  [SMALL_STATE(14143)] = 661422,
  [SMALL_STATE(14144)] = 661446,
  [SMALL_STATE(14145)] = 661480,
  [SMALL_STATE(14146)] = 661510,
  [SMALL_STATE(14147)] = 661540,
  [SMALL_STATE(14148)] = 661562,
  [SMALL_STATE(14149)] = 661592,
  [SMALL_STATE(14150)] = 661622,
  [SMALL_STATE(14151)] = 661652,
  [SMALL_STATE(14152)] = 661682,
  [SMALL_STATE(14153)] = 661712,
  [SMALL_STATE(14154)] = 661742,
  [SMALL_STATE(14155)] = 661772,
  [SMALL_STATE(14156)] = 661802,
  [SMALL_STATE(14157)] = 661832,
  [SMALL_STATE(14158)] = 661862,
  [SMALL_STATE(14159)] = 661892,
  [SMALL_STATE(14160)] = 661922,
  [SMALL_STATE(14161)] = 661952,
  [SMALL_STATE(14162)] = 661982,
  [SMALL_STATE(14163)] = 662018,
  [SMALL_STATE(14164)] = 662052,
  [SMALL_STATE(14165)] = 662090,
  [SMALL_STATE(14166)] = 662114,
  [SMALL_STATE(14167)] = 662138,
  [SMALL_STATE(14168)] = 662174,
  [SMALL_STATE(14169)] = 662210,
  [SMALL_STATE(14170)] = 662248,
  [SMALL_STATE(14171)] = 662272,
  [SMALL_STATE(14172)] = 662296,
  [SMALL_STATE(14173)] = 662332,
  [SMALL_STATE(14174)] = 662356,
  [SMALL_STATE(14175)] = 662394,
  [SMALL_STATE(14176)] = 662418,
  [SMALL_STATE(14177)] = 662456,
  [SMALL_STATE(14178)] = 662480,
  [SMALL_STATE(14179)] = 662516,
  [SMALL_STATE(14180)] = 662540,
  [SMALL_STATE(14181)] = 662576,
  [SMALL_STATE(14182)] = 662610,
  [SMALL_STATE(14183)] = 662646,
  [SMALL_STATE(14184)] = 662684,
  [SMALL_STATE(14185)] = 662718,
  [SMALL_STATE(14186)] = 662742,
  [SMALL_STATE(14187)] = 662780,
  [SMALL_STATE(14188)] = 662816,
  [SMALL_STATE(14189)] = 662840,
  [SMALL_STATE(14190)] = 662864,
  [SMALL_STATE(14191)] = 662902,
  [SMALL_STATE(14192)] = 662938,
  [SMALL_STATE(14193)] = 662962,
  [SMALL_STATE(14194)] = 663000,
  [SMALL_STATE(14195)] = 663030,
  [SMALL_STATE(14196)] = 663066,
  [SMALL_STATE(14197)] = 663092,
  [SMALL_STATE(14198)] = 663126,
  [SMALL_STATE(14199)] = 663164,
  [SMALL_STATE(14200)] = 663198,
  [SMALL_STATE(14201)] = 663232,
  [SMALL_STATE(14202)] = 663266,
  [SMALL_STATE(14203)] = 663304,
  [SMALL_STATE(14204)] = 663338,
  [SMALL_STATE(14205)] = 663362,
  [SMALL_STATE(14206)] = 663386,
  [SMALL_STATE(14207)] = 663422,
  [SMALL_STATE(14208)] = 663446,
  [SMALL_STATE(14209)] = 663484,
  [SMALL_STATE(14210)] = 663508,
  [SMALL_STATE(14211)] = 663532,
  [SMALL_STATE(14212)] = 663556,
  [SMALL_STATE(14213)] = 663594,
  [SMALL_STATE(14214)] = 663624,
  [SMALL_STATE(14215)] = 663648,
  [SMALL_STATE(14216)] = 663686,
  [SMALL_STATE(14217)] = 663710,
  [SMALL_STATE(14218)] = 663732,
  [SMALL_STATE(14219)] = 663770,
  [SMALL_STATE(14220)] = 663794,
  [SMALL_STATE(14221)] = 663822,
  [SMALL_STATE(14222)] = 663857,
  [SMALL_STATE(14223)] = 663890,
  [SMALL_STATE(14224)] = 663915,
  [SMALL_STATE(14225)] = 663938,
  [SMALL_STATE(14226)] = 663973,
  [SMALL_STATE(14227)] = 663994,
  [SMALL_STATE(14228)] = 664017,
  [SMALL_STATE(14229)] = 664040,
  [SMALL_STATE(14230)] = 664075,
  [SMALL_STATE(14231)] = 664100,
  [SMALL_STATE(14232)] = 664135,
  [SMALL_STATE(14233)] = 664168,
  [SMALL_STATE(14234)] = 664203,
  [SMALL_STATE(14235)] = 664236,
  [SMALL_STATE(14236)] = 664271,
  [SMALL_STATE(14237)] = 664304,
  [SMALL_STATE(14238)] = 664339,
  [SMALL_STATE(14239)] = 664374,
  [SMALL_STATE(14240)] = 664409,
  [SMALL_STATE(14241)] = 664444,
  [SMALL_STATE(14242)] = 664479,
  [SMALL_STATE(14243)] = 664514,
  [SMALL_STATE(14244)] = 664547,
  [SMALL_STATE(14245)] = 664580,
  [SMALL_STATE(14246)] = 664605,
  [SMALL_STATE(14247)] = 664638,
  [SMALL_STATE(14248)] = 664673,
  [SMALL_STATE(14249)] = 664694,
  [SMALL_STATE(14250)] = 664729,
  [SMALL_STATE(14251)] = 664764,
  [SMALL_STATE(14252)] = 664799,
  [SMALL_STATE(14253)] = 664826,
  [SMALL_STATE(14254)] = 664859,
  [SMALL_STATE(14255)] = 664894,
  [SMALL_STATE(14256)] = 664915,
  [SMALL_STATE(14257)] = 664950,
  [SMALL_STATE(14258)] = 664983,
  [SMALL_STATE(14259)] = 665018,
  [SMALL_STATE(14260)] = 665043,
  [SMALL_STATE(14261)] = 665078,
  [SMALL_STATE(14262)] = 665111,
  [SMALL_STATE(14263)] = 665134,
  [SMALL_STATE(14264)] = 665159,
  [SMALL_STATE(14265)] = 665184,
  [SMALL_STATE(14266)] = 665217,
  [SMALL_STATE(14267)] = 665250,
  [SMALL_STATE(14268)] = 665283,
  [SMALL_STATE(14269)] = 665316,
  [SMALL_STATE(14270)] = 665349,
  [SMALL_STATE(14271)] = 665384,
  [SMALL_STATE(14272)] = 665419,
  [SMALL_STATE(14273)] = 665454,
  [SMALL_STATE(14274)] = 665487,
  [SMALL_STATE(14275)] = 665520,
  [SMALL_STATE(14276)] = 665553,
  [SMALL_STATE(14277)] = 665586,
  [SMALL_STATE(14278)] = 665621,
  [SMALL_STATE(14279)] = 665654,
  [SMALL_STATE(14280)] = 665681,
  [SMALL_STATE(14281)] = 665708,
  [SMALL_STATE(14282)] = 665735,
  [SMALL_STATE(14283)] = 665762,
  [SMALL_STATE(14284)] = 665797,
  [SMALL_STATE(14285)] = 665832,
  [SMALL_STATE(14286)] = 665865,
  [SMALL_STATE(14287)] = 665898,
  [SMALL_STATE(14288)] = 665933,
  [SMALL_STATE(14289)] = 665968,
  [SMALL_STATE(14290)] = 666001,
  [SMALL_STATE(14291)] = 666034,
  [SMALL_STATE(14292)] = 666067,
  [SMALL_STATE(14293)] = 666100,
  [SMALL_STATE(14294)] = 666133,
  [SMALL_STATE(14295)] = 666166,
  [SMALL_STATE(14296)] = 666190,
  [SMALL_STATE(14297)] = 666220,
  [SMALL_STATE(14298)] = 666252,
  [SMALL_STATE(14299)] = 666276,
  [SMALL_STATE(14300)] = 666296,
  [SMALL_STATE(14301)] = 666328,
  [SMALL_STATE(14302)] = 666350,
  [SMALL_STATE(14303)] = 666370,
  [SMALL_STATE(14304)] = 666402,
  [SMALL_STATE(14305)] = 666434,
  [SMALL_STATE(14306)] = 666466,
  [SMALL_STATE(14307)] = 666498,
  [SMALL_STATE(14308)] = 666530,
  [SMALL_STATE(14309)] = 666562,
  [SMALL_STATE(14310)] = 666594,
  [SMALL_STATE(14311)] = 666626,
  [SMALL_STATE(14312)] = 666658,
  [SMALL_STATE(14313)] = 666684,
  [SMALL_STATE(14314)] = 666716,
  [SMALL_STATE(14315)] = 666748,
  [SMALL_STATE(14316)] = 666778,
  [SMALL_STATE(14317)] = 666810,
  [SMALL_STATE(14318)] = 666842,
  [SMALL_STATE(14319)] = 666874,
  [SMALL_STATE(14320)] = 666906,
  [SMALL_STATE(14321)] = 666928,
  [SMALL_STATE(14322)] = 666950,
  [SMALL_STATE(14323)] = 666982,
  [SMALL_STATE(14324)] = 667014,
  [SMALL_STATE(14325)] = 667046,
  [SMALL_STATE(14326)] = 667078,
  [SMALL_STATE(14327)] = 667110,
  [SMALL_STATE(14328)] = 667142,
  [SMALL_STATE(14329)] = 667174,
  [SMALL_STATE(14330)] = 667206,
  [SMALL_STATE(14331)] = 667238,
  [SMALL_STATE(14332)] = 667270,
  [SMALL_STATE(14333)] = 667302,
  [SMALL_STATE(14334)] = 667332,
  [SMALL_STATE(14335)] = 667364,
  [SMALL_STATE(14336)] = 667396,
  [SMALL_STATE(14337)] = 667428,
  [SMALL_STATE(14338)] = 667460,
  [SMALL_STATE(14339)] = 667492,
  [SMALL_STATE(14340)] = 667524,
  [SMALL_STATE(14341)] = 667556,
  [SMALL_STATE(14342)] = 667588,
  [SMALL_STATE(14343)] = 667620,
  [SMALL_STATE(14344)] = 667652,
  [SMALL_STATE(14345)] = 667684,
  [SMALL_STATE(14346)] = 667716,
  [SMALL_STATE(14347)] = 667748,
  [SMALL_STATE(14348)] = 667780,
  [SMALL_STATE(14349)] = 667812,
  [SMALL_STATE(14350)] = 667844,
  [SMALL_STATE(14351)] = 667876,
  [SMALL_STATE(14352)] = 667908,
  [SMALL_STATE(14353)] = 667940,
  [SMALL_STATE(14354)] = 667970,
  [SMALL_STATE(14355)] = 668002,
  [SMALL_STATE(14356)] = 668034,
  [SMALL_STATE(14357)] = 668066,
  [SMALL_STATE(14358)] = 668098,
  [SMALL_STATE(14359)] = 668122,
  [SMALL_STATE(14360)] = 668154,
  [SMALL_STATE(14361)] = 668186,
  [SMALL_STATE(14362)] = 668218,
  [SMALL_STATE(14363)] = 668250,
  [SMALL_STATE(14364)] = 668282,
  [SMALL_STATE(14365)] = 668314,
  [SMALL_STATE(14366)] = 668346,
  [SMALL_STATE(14367)] = 668378,
  [SMALL_STATE(14368)] = 668400,
  [SMALL_STATE(14369)] = 668424,
  [SMALL_STATE(14370)] = 668454,
  [SMALL_STATE(14371)] = 668486,
  [SMALL_STATE(14372)] = 668518,
  [SMALL_STATE(14373)] = 668550,
  [SMALL_STATE(14374)] = 668580,
  [SMALL_STATE(14375)] = 668602,
  [SMALL_STATE(14376)] = 668624,
  [SMALL_STATE(14377)] = 668656,
  [SMALL_STATE(14378)] = 668688,
  [SMALL_STATE(14379)] = 668712,
  [SMALL_STATE(14380)] = 668744,
  [SMALL_STATE(14381)] = 668776,
  [SMALL_STATE(14382)] = 668808,
  [SMALL_STATE(14383)] = 668840,
  [SMALL_STATE(14384)] = 668872,
  [SMALL_STATE(14385)] = 668902,
  [SMALL_STATE(14386)] = 668934,
  [SMALL_STATE(14387)] = 668956,
  [SMALL_STATE(14388)] = 668988,
  [SMALL_STATE(14389)] = 669020,
  [SMALL_STATE(14390)] = 669052,
  [SMALL_STATE(14391)] = 669084,
  [SMALL_STATE(14392)] = 669116,
  [SMALL_STATE(14393)] = 669148,
  [SMALL_STATE(14394)] = 669180,
  [SMALL_STATE(14395)] = 669208,
  [SMALL_STATE(14396)] = 669230,
  [SMALL_STATE(14397)] = 669254,
  [SMALL_STATE(14398)] = 669276,
  [SMALL_STATE(14399)] = 669302,
  [SMALL_STATE(14400)] = 669324,
  [SMALL_STATE(14401)] = 669356,
  [SMALL_STATE(14402)] = 669388,
  [SMALL_STATE(14403)] = 669420,
  [SMALL_STATE(14404)] = 669450,
  [SMALL_STATE(14405)] = 669482,
  [SMALL_STATE(14406)] = 669514,
  [SMALL_STATE(14407)] = 669546,
  [SMALL_STATE(14408)] = 669578,
  [SMALL_STATE(14409)] = 669602,
  [SMALL_STATE(14410)] = 669634,
  [SMALL_STATE(14411)] = 669664,
  [SMALL_STATE(14412)] = 669696,
  [SMALL_STATE(14413)] = 669718,
  [SMALL_STATE(14414)] = 669750,
  [SMALL_STATE(14415)] = 669782,
  [SMALL_STATE(14416)] = 669814,
  [SMALL_STATE(14417)] = 669846,
  [SMALL_STATE(14418)] = 669868,
  [SMALL_STATE(14419)] = 669900,
  [SMALL_STATE(14420)] = 669932,
  [SMALL_STATE(14421)] = 669954,
  [SMALL_STATE(14422)] = 669986,
  [SMALL_STATE(14423)] = 670018,
  [SMALL_STATE(14424)] = 670050,
  [SMALL_STATE(14425)] = 670082,
  [SMALL_STATE(14426)] = 670114,
  [SMALL_STATE(14427)] = 670146,
  [SMALL_STATE(14428)] = 670178,
  [SMALL_STATE(14429)] = 670202,
  [SMALL_STATE(14430)] = 670224,
  [SMALL_STATE(14431)] = 670256,
  [SMALL_STATE(14432)] = 670288,
  [SMALL_STATE(14433)] = 670314,
  [SMALL_STATE(14434)] = 670344,
  [SMALL_STATE(14435)] = 670366,
  [SMALL_STATE(14436)] = 670390,
  [SMALL_STATE(14437)] = 670422,
  [SMALL_STATE(14438)] = 670454,
  [SMALL_STATE(14439)] = 670486,
  [SMALL_STATE(14440)] = 670506,
  [SMALL_STATE(14441)] = 670538,
  [SMALL_STATE(14442)] = 670560,
  [SMALL_STATE(14443)] = 670592,
  [SMALL_STATE(14444)] = 670624,
  [SMALL_STATE(14445)] = 670656,
  [SMALL_STATE(14446)] = 670688,
  [SMALL_STATE(14447)] = 670720,
  [SMALL_STATE(14448)] = 670742,
  [SMALL_STATE(14449)] = 670774,
  [SMALL_STATE(14450)] = 670806,
  [SMALL_STATE(14451)] = 670838,
  [SMALL_STATE(14452)] = 670870,
  [SMALL_STATE(14453)] = 670902,
  [SMALL_STATE(14454)] = 670934,
  [SMALL_STATE(14455)] = 670966,
  [SMALL_STATE(14456)] = 670998,
  [SMALL_STATE(14457)] = 671030,
  [SMALL_STATE(14458)] = 671062,
  [SMALL_STATE(14459)] = 671094,
  [SMALL_STATE(14460)] = 671126,
  [SMALL_STATE(14461)] = 671158,
  [SMALL_STATE(14462)] = 671190,
  [SMALL_STATE(14463)] = 671222,
  [SMALL_STATE(14464)] = 671254,
  [SMALL_STATE(14465)] = 671286,
  [SMALL_STATE(14466)] = 671318,
  [SMALL_STATE(14467)] = 671350,
  [SMALL_STATE(14468)] = 671374,
  [SMALL_STATE(14469)] = 671406,
  [SMALL_STATE(14470)] = 671438,
  [SMALL_STATE(14471)] = 671470,
  [SMALL_STATE(14472)] = 671490,
  [SMALL_STATE(14473)] = 671522,
  [SMALL_STATE(14474)] = 671554,
  [SMALL_STATE(14475)] = 671586,
  [SMALL_STATE(14476)] = 671618,
  [SMALL_STATE(14477)] = 671650,
  [SMALL_STATE(14478)] = 671682,
  [SMALL_STATE(14479)] = 671714,
  [SMALL_STATE(14480)] = 671734,
  [SMALL_STATE(14481)] = 671766,
  [SMALL_STATE(14482)] = 671798,
  [SMALL_STATE(14483)] = 671830,
  [SMALL_STATE(14484)] = 671862,
  [SMALL_STATE(14485)] = 671894,
  [SMALL_STATE(14486)] = 671918,
  [SMALL_STATE(14487)] = 671948,
  [SMALL_STATE(14488)] = 671970,
  [SMALL_STATE(14489)] = 672002,
  [SMALL_STATE(14490)] = 672024,
  [SMALL_STATE(14491)] = 672056,
  [SMALL_STATE(14492)] = 672088,
  [SMALL_STATE(14493)] = 672120,
  [SMALL_STATE(14494)] = 672142,
  [SMALL_STATE(14495)] = 672174,
  [SMALL_STATE(14496)] = 672206,
  [SMALL_STATE(14497)] = 672228,
  [SMALL_STATE(14498)] = 672260,
  [SMALL_STATE(14499)] = 672292,
  [SMALL_STATE(14500)] = 672324,
  [SMALL_STATE(14501)] = 672356,
  [SMALL_STATE(14502)] = 672388,
  [SMALL_STATE(14503)] = 672412,
  [SMALL_STATE(14504)] = 672444,
  [SMALL_STATE(14505)] = 672476,
  [SMALL_STATE(14506)] = 672508,
  [SMALL_STATE(14507)] = 672540,
  [SMALL_STATE(14508)] = 672560,
  [SMALL_STATE(14509)] = 672592,
  [SMALL_STATE(14510)] = 672622,
  [SMALL_STATE(14511)] = 672654,
  [SMALL_STATE(14512)] = 672686,
  [SMALL_STATE(14513)] = 672718,
  [SMALL_STATE(14514)] = 672748,
  [SMALL_STATE(14515)] = 672780,
  [SMALL_STATE(14516)] = 672812,
  [SMALL_STATE(14517)] = 672844,
  [SMALL_STATE(14518)] = 672872,
  [SMALL_STATE(14519)] = 672902,
  [SMALL_STATE(14520)] = 672934,
  [SMALL_STATE(14521)] = 672966,
  [SMALL_STATE(14522)] = 672998,
  [SMALL_STATE(14523)] = 673030,
  [SMALL_STATE(14524)] = 673054,
  [SMALL_STATE(14525)] = 673074,
  [SMALL_STATE(14526)] = 673106,
  [SMALL_STATE(14527)] = 673138,
  [SMALL_STATE(14528)] = 673170,
  [SMALL_STATE(14529)] = 673202,
  [SMALL_STATE(14530)] = 673234,
  [SMALL_STATE(14531)] = 673264,
  [SMALL_STATE(14532)] = 673294,
  [SMALL_STATE(14533)] = 673326,
  [SMALL_STATE(14534)] = 673356,
  [SMALL_STATE(14535)] = 673388,
  [SMALL_STATE(14536)] = 673420,
  [SMALL_STATE(14537)] = 673450,
  [SMALL_STATE(14538)] = 673480,
  [SMALL_STATE(14539)] = 673510,
  [SMALL_STATE(14540)] = 673542,
  [SMALL_STATE(14541)] = 673574,
  [SMALL_STATE(14542)] = 673606,
  [SMALL_STATE(14543)] = 673638,
  [SMALL_STATE(14544)] = 673668,
  [SMALL_STATE(14545)] = 673690,
  [SMALL_STATE(14546)] = 673720,
  [SMALL_STATE(14547)] = 673744,
  [SMALL_STATE(14548)] = 673774,
  [SMALL_STATE(14549)] = 673806,
  [SMALL_STATE(14550)] = 673828,
  [SMALL_STATE(14551)] = 673858,
  [SMALL_STATE(14552)] = 673888,
  [SMALL_STATE(14553)] = 673910,
  [SMALL_STATE(14554)] = 673942,
  [SMALL_STATE(14555)] = 673972,
  [SMALL_STATE(14556)] = 674004,
  [SMALL_STATE(14557)] = 674036,
  [SMALL_STATE(14558)] = 674058,
  [SMALL_STATE(14559)] = 674090,
  [SMALL_STATE(14560)] = 674120,
  [SMALL_STATE(14561)] = 674152,
  [SMALL_STATE(14562)] = 674184,
  [SMALL_STATE(14563)] = 674216,
  [SMALL_STATE(14564)] = 674240,
  [SMALL_STATE(14565)] = 674262,
  [SMALL_STATE(14566)] = 674292,
  [SMALL_STATE(14567)] = 674314,
  [SMALL_STATE(14568)] = 674336,
  [SMALL_STATE(14569)] = 674368,
  [SMALL_STATE(14570)] = 674390,
  [SMALL_STATE(14571)] = 674422,
  [SMALL_STATE(14572)] = 674444,
  [SMALL_STATE(14573)] = 674476,
  [SMALL_STATE(14574)] = 674498,
  [SMALL_STATE(14575)] = 674530,
  [SMALL_STATE(14576)] = 674552,
  [SMALL_STATE(14577)] = 674584,
  [SMALL_STATE(14578)] = 674606,
  [SMALL_STATE(14579)] = 674638,
  [SMALL_STATE(14580)] = 674670,
  [SMALL_STATE(14581)] = 674702,
  [SMALL_STATE(14582)] = 674734,
  [SMALL_STATE(14583)] = 674766,
  [SMALL_STATE(14584)] = 674798,
  [SMALL_STATE(14585)] = 674830,
  [SMALL_STATE(14586)] = 674862,
  [SMALL_STATE(14587)] = 674884,
  [SMALL_STATE(14588)] = 674916,
  [SMALL_STATE(14589)] = 674948,
  [SMALL_STATE(14590)] = 674980,
  [SMALL_STATE(14591)] = 675012,
  [SMALL_STATE(14592)] = 675044,
  [SMALL_STATE(14593)] = 675064,
  [SMALL_STATE(14594)] = 675096,
  [SMALL_STATE(14595)] = 675128,
  [SMALL_STATE(14596)] = 675148,
  [SMALL_STATE(14597)] = 675180,
  [SMALL_STATE(14598)] = 675200,
  [SMALL_STATE(14599)] = 675232,
  [SMALL_STATE(14600)] = 675264,
  [SMALL_STATE(14601)] = 675296,
  [SMALL_STATE(14602)] = 675326,
  [SMALL_STATE(14603)] = 675348,
  [SMALL_STATE(14604)] = 675370,
  [SMALL_STATE(14605)] = 675392,
  [SMALL_STATE(14606)] = 675424,
  [SMALL_STATE(14607)] = 675456,
  [SMALL_STATE(14608)] = 675488,
  [SMALL_STATE(14609)] = 675518,
  [SMALL_STATE(14610)] = 675550,
  [SMALL_STATE(14611)] = 675582,
  [SMALL_STATE(14612)] = 675614,
  [SMALL_STATE(14613)] = 675646,
  [SMALL_STATE(14614)] = 675678,
  [SMALL_STATE(14615)] = 675710,
  [SMALL_STATE(14616)] = 675732,
  [SMALL_STATE(14617)] = 675762,
  [SMALL_STATE(14618)] = 675784,
  [SMALL_STATE(14619)] = 675806,
  [SMALL_STATE(14620)] = 675828,
  [SMALL_STATE(14621)] = 675850,
  [SMALL_STATE(14622)] = 675872,
  [SMALL_STATE(14623)] = 675904,
  [SMALL_STATE(14624)] = 675936,
  [SMALL_STATE(14625)] = 675968,
  [SMALL_STATE(14626)] = 675990,
  [SMALL_STATE(14627)] = 676020,
  [SMALL_STATE(14628)] = 676052,
  [SMALL_STATE(14629)] = 676082,
  [SMALL_STATE(14630)] = 676104,
  [SMALL_STATE(14631)] = 676134,
  [SMALL_STATE(14632)] = 676158,
  [SMALL_STATE(14633)] = 676190,
  [SMALL_STATE(14634)] = 676220,
  [SMALL_STATE(14635)] = 676250,
  [SMALL_STATE(14636)] = 676282,
  [SMALL_STATE(14637)] = 676311,
  [SMALL_STATE(14638)] = 676332,
  [SMALL_STATE(14639)] = 676361,
  [SMALL_STATE(14640)] = 676388,
  [SMALL_STATE(14641)] = 676409,
  [SMALL_STATE(14642)] = 676434,
  [SMALL_STATE(14643)] = 676455,
  [SMALL_STATE(14644)] = 676478,
  [SMALL_STATE(14645)] = 676499,
  [SMALL_STATE(14646)] = 676524,
  [SMALL_STATE(14647)] = 676545,
  [SMALL_STATE(14648)] = 676566,
  [SMALL_STATE(14649)] = 676589,
  [SMALL_STATE(14650)] = 676618,
  [SMALL_STATE(14651)] = 676639,
  [SMALL_STATE(14652)] = 676668,
  [SMALL_STATE(14653)] = 676689,
  [SMALL_STATE(14654)] = 676710,
  [SMALL_STATE(14655)] = 676739,
  [SMALL_STATE(14656)] = 676760,
  [SMALL_STATE(14657)] = 676781,
  [SMALL_STATE(14658)] = 676810,
  [SMALL_STATE(14659)] = 676839,
  [SMALL_STATE(14660)] = 676868,
  [SMALL_STATE(14661)] = 676897,
  [SMALL_STATE(14662)] = 676926,
  [SMALL_STATE(14663)] = 676947,
  [SMALL_STATE(14664)] = 676976,
  [SMALL_STATE(14665)] = 677005,
  [SMALL_STATE(14666)] = 677034,
  [SMALL_STATE(14667)] = 677063,
  [SMALL_STATE(14668)] = 677084,
  [SMALL_STATE(14669)] = 677105,
  [SMALL_STATE(14670)] = 677134,
  [SMALL_STATE(14671)] = 677155,
  [SMALL_STATE(14672)] = 677184,
  [SMALL_STATE(14673)] = 677213,
  [SMALL_STATE(14674)] = 677242,
  [SMALL_STATE(14675)] = 677263,
  [SMALL_STATE(14676)] = 677292,
  [SMALL_STATE(14677)] = 677321,
  [SMALL_STATE(14678)] = 677350,
  [SMALL_STATE(14679)] = 677379,
  [SMALL_STATE(14680)] = 677408,
  [SMALL_STATE(14681)] = 677437,
  [SMALL_STATE(14682)] = 677466,
  [SMALL_STATE(14683)] = 677487,
  [SMALL_STATE(14684)] = 677516,
  [SMALL_STATE(14685)] = 677545,
  [SMALL_STATE(14686)] = 677566,
  [SMALL_STATE(14687)] = 677593,
  [SMALL_STATE(14688)] = 677622,
  [SMALL_STATE(14689)] = 677643,
  [SMALL_STATE(14690)] = 677664,
  [SMALL_STATE(14691)] = 677693,
  [SMALL_STATE(14692)] = 677722,
  [SMALL_STATE(14693)] = 677751,
  [SMALL_STATE(14694)] = 677780,
  [SMALL_STATE(14695)] = 677809,
  [SMALL_STATE(14696)] = 677830,
  [SMALL_STATE(14697)] = 677857,
  [SMALL_STATE(14698)] = 677886,
  [SMALL_STATE(14699)] = 677915,
  [SMALL_STATE(14700)] = 677944,
  [SMALL_STATE(14701)] = 677973,
  [SMALL_STATE(14702)] = 678002,
  [SMALL_STATE(14703)] = 678031,
  [SMALL_STATE(14704)] = 678060,
  [SMALL_STATE(14705)] = 678089,
  [SMALL_STATE(14706)] = 678118,
  [SMALL_STATE(14707)] = 678147,
  [SMALL_STATE(14708)] = 678176,
  [SMALL_STATE(14709)] = 678205,
  [SMALL_STATE(14710)] = 678234,
  [SMALL_STATE(14711)] = 678263,
  [SMALL_STATE(14712)] = 678292,
  [SMALL_STATE(14713)] = 678321,
  [SMALL_STATE(14714)] = 678350,
  [SMALL_STATE(14715)] = 678379,
  [SMALL_STATE(14716)] = 678408,
  [SMALL_STATE(14717)] = 678437,
  [SMALL_STATE(14718)] = 678466,
  [SMALL_STATE(14719)] = 678495,
  [SMALL_STATE(14720)] = 678524,
  [SMALL_STATE(14721)] = 678553,
  [SMALL_STATE(14722)] = 678582,
  [SMALL_STATE(14723)] = 678603,
  [SMALL_STATE(14724)] = 678632,
  [SMALL_STATE(14725)] = 678661,
  [SMALL_STATE(14726)] = 678682,
  [SMALL_STATE(14727)] = 678705,
  [SMALL_STATE(14728)] = 678734,
  [SMALL_STATE(14729)] = 678755,
  [SMALL_STATE(14730)] = 678780,
  [SMALL_STATE(14731)] = 678809,
  [SMALL_STATE(14732)] = 678830,
  [SMALL_STATE(14733)] = 678859,
  [SMALL_STATE(14734)] = 678888,
  [SMALL_STATE(14735)] = 678917,
  [SMALL_STATE(14736)] = 678946,
  [SMALL_STATE(14737)] = 678975,
  [SMALL_STATE(14738)] = 679004,
  [SMALL_STATE(14739)] = 679033,
  [SMALL_STATE(14740)] = 679062,
  [SMALL_STATE(14741)] = 679091,
  [SMALL_STATE(14742)] = 679112,
  [SMALL_STATE(14743)] = 679141,
  [SMALL_STATE(14744)] = 679170,
  [SMALL_STATE(14745)] = 679195,
  [SMALL_STATE(14746)] = 679224,
  [SMALL_STATE(14747)] = 679253,
  [SMALL_STATE(14748)] = 679282,
  [SMALL_STATE(14749)] = 679303,
  [SMALL_STATE(14750)] = 679324,
  [SMALL_STATE(14751)] = 679353,
  [SMALL_STATE(14752)] = 679382,
  [SMALL_STATE(14753)] = 679411,
  [SMALL_STATE(14754)] = 679440,
  [SMALL_STATE(14755)] = 679461,
  [SMALL_STATE(14756)] = 679490,
  [SMALL_STATE(14757)] = 679519,
  [SMALL_STATE(14758)] = 679540,
  [SMALL_STATE(14759)] = 679563,
  [SMALL_STATE(14760)] = 679592,
  [SMALL_STATE(14761)] = 679613,
  [SMALL_STATE(14762)] = 679634,
  [SMALL_STATE(14763)] = 679655,
  [SMALL_STATE(14764)] = 679684,
  [SMALL_STATE(14765)] = 679713,
  [SMALL_STATE(14766)] = 679734,
  [SMALL_STATE(14767)] = 679755,
  [SMALL_STATE(14768)] = 679776,
  [SMALL_STATE(14769)] = 679805,
  [SMALL_STATE(14770)] = 679834,
  [SMALL_STATE(14771)] = 679855,
  [SMALL_STATE(14772)] = 679884,
  [SMALL_STATE(14773)] = 679905,
  [SMALL_STATE(14774)] = 679926,
  [SMALL_STATE(14775)] = 679947,
  [SMALL_STATE(14776)] = 679976,
  [SMALL_STATE(14777)] = 679997,
  [SMALL_STATE(14778)] = 680026,
  [SMALL_STATE(14779)] = 680047,
  [SMALL_STATE(14780)] = 680076,
  [SMALL_STATE(14781)] = 680105,
  [SMALL_STATE(14782)] = 680134,
  [SMALL_STATE(14783)] = 680161,
  [SMALL_STATE(14784)] = 680182,
  [SMALL_STATE(14785)] = 680203,
  [SMALL_STATE(14786)] = 680232,
  [SMALL_STATE(14787)] = 680261,
  [SMALL_STATE(14788)] = 680290,
  [SMALL_STATE(14789)] = 680319,
  [SMALL_STATE(14790)] = 680348,
  [SMALL_STATE(14791)] = 680377,
  [SMALL_STATE(14792)] = 680406,
  [SMALL_STATE(14793)] = 680435,
  [SMALL_STATE(14794)] = 680464,
  [SMALL_STATE(14795)] = 680493,
  [SMALL_STATE(14796)] = 680522,
  [SMALL_STATE(14797)] = 680551,
  [SMALL_STATE(14798)] = 680580,
  [SMALL_STATE(14799)] = 680601,
  [SMALL_STATE(14800)] = 680630,
  [SMALL_STATE(14801)] = 680659,
  [SMALL_STATE(14802)] = 680686,
  [SMALL_STATE(14803)] = 680715,
  [SMALL_STATE(14804)] = 680744,
  [SMALL_STATE(14805)] = 680769,
  [SMALL_STATE(14806)] = 680798,
  [SMALL_STATE(14807)] = 680827,
  [SMALL_STATE(14808)] = 680854,
  [SMALL_STATE(14809)] = 680883,
  [SMALL_STATE(14810)] = 680910,
  [SMALL_STATE(14811)] = 680931,
  [SMALL_STATE(14812)] = 680952,
  [SMALL_STATE(14813)] = 680981,
  [SMALL_STATE(14814)] = 681004,
  [SMALL_STATE(14815)] = 681025,
  [SMALL_STATE(14816)] = 681052,
  [SMALL_STATE(14817)] = 681079,
  [SMALL_STATE(14818)] = 681108,
  [SMALL_STATE(14819)] = 681137,
  [SMALL_STATE(14820)] = 681166,
  [SMALL_STATE(14821)] = 681187,
  [SMALL_STATE(14822)] = 681208,
  [SMALL_STATE(14823)] = 681229,
  [SMALL_STATE(14824)] = 681258,
  [SMALL_STATE(14825)] = 681287,
  [SMALL_STATE(14826)] = 681308,
  [SMALL_STATE(14827)] = 681337,
  [SMALL_STATE(14828)] = 681366,
  [SMALL_STATE(14829)] = 681395,
  [SMALL_STATE(14830)] = 681424,
  [SMALL_STATE(14831)] = 681453,
  [SMALL_STATE(14832)] = 681482,
  [SMALL_STATE(14833)] = 681503,
  [SMALL_STATE(14834)] = 681532,
  [SMALL_STATE(14835)] = 681561,
  [SMALL_STATE(14836)] = 681582,
  [SMALL_STATE(14837)] = 681611,
  [SMALL_STATE(14838)] = 681636,
  [SMALL_STATE(14839)] = 681663,
  [SMALL_STATE(14840)] = 681684,
  [SMALL_STATE(14841)] = 681713,
  [SMALL_STATE(14842)] = 681742,
  [SMALL_STATE(14843)] = 681771,
  [SMALL_STATE(14844)] = 681800,
  [SMALL_STATE(14845)] = 681821,
  [SMALL_STATE(14846)] = 681850,
  [SMALL_STATE(14847)] = 681871,
  [SMALL_STATE(14848)] = 681900,
  [SMALL_STATE(14849)] = 681921,
  [SMALL_STATE(14850)] = 681950,
  [SMALL_STATE(14851)] = 681979,
  [SMALL_STATE(14852)] = 682008,
  [SMALL_STATE(14853)] = 682029,
  [SMALL_STATE(14854)] = 682050,
  [SMALL_STATE(14855)] = 682079,
  [SMALL_STATE(14856)] = 682108,
  [SMALL_STATE(14857)] = 682137,
  [SMALL_STATE(14858)] = 682166,
  [SMALL_STATE(14859)] = 682195,
  [SMALL_STATE(14860)] = 682216,
  [SMALL_STATE(14861)] = 682237,
  [SMALL_STATE(14862)] = 682258,
  [SMALL_STATE(14863)] = 682287,
  [SMALL_STATE(14864)] = 682316,
  [SMALL_STATE(14865)] = 682345,
  [SMALL_STATE(14866)] = 682372,
  [SMALL_STATE(14867)] = 682401,
  [SMALL_STATE(14868)] = 682428,
  [SMALL_STATE(14869)] = 682457,
  [SMALL_STATE(14870)] = 682484,
  [SMALL_STATE(14871)] = 682511,
  [SMALL_STATE(14872)] = 682532,
  [SMALL_STATE(14873)] = 682559,
  [SMALL_STATE(14874)] = 682580,
  [SMALL_STATE(14875)] = 682603,
  [SMALL_STATE(14876)] = 682632,
  [SMALL_STATE(14877)] = 682661,
  [SMALL_STATE(14878)] = 682688,
  [SMALL_STATE(14879)] = 682717,
  [SMALL_STATE(14880)] = 682738,
  [SMALL_STATE(14881)] = 682759,
  [SMALL_STATE(14882)] = 682788,
  [SMALL_STATE(14883)] = 682817,
  [SMALL_STATE(14884)] = 682838,
  [SMALL_STATE(14885)] = 682867,
  [SMALL_STATE(14886)] = 682888,
  [SMALL_STATE(14887)] = 682909,
  [SMALL_STATE(14888)] = 682930,
  [SMALL_STATE(14889)] = 682959,
  [SMALL_STATE(14890)] = 682980,
  [SMALL_STATE(14891)] = 683009,
  [SMALL_STATE(14892)] = 683038,
  [SMALL_STATE(14893)] = 683067,
  [SMALL_STATE(14894)] = 683096,
  [SMALL_STATE(14895)] = 683125,
  [SMALL_STATE(14896)] = 683154,
  [SMALL_STATE(14897)] = 683183,
  [SMALL_STATE(14898)] = 683212,
  [SMALL_STATE(14899)] = 683241,
  [SMALL_STATE(14900)] = 683262,
  [SMALL_STATE(14901)] = 683291,
  [SMALL_STATE(14902)] = 683320,
  [SMALL_STATE(14903)] = 683349,
  [SMALL_STATE(14904)] = 683376,
  [SMALL_STATE(14905)] = 683397,
  [SMALL_STATE(14906)] = 683426,
  [SMALL_STATE(14907)] = 683455,
  [SMALL_STATE(14908)] = 683482,
  [SMALL_STATE(14909)] = 683509,
  [SMALL_STATE(14910)] = 683538,
  [SMALL_STATE(14911)] = 683567,
  [SMALL_STATE(14912)] = 683596,
  [SMALL_STATE(14913)] = 683623,
  [SMALL_STATE(14914)] = 683650,
  [SMALL_STATE(14915)] = 683671,
  [SMALL_STATE(14916)] = 683700,
  [SMALL_STATE(14917)] = 683729,
  [SMALL_STATE(14918)] = 683758,
  [SMALL_STATE(14919)] = 683779,
  [SMALL_STATE(14920)] = 683808,
  [SMALL_STATE(14921)] = 683829,
  [SMALL_STATE(14922)] = 683850,
  [SMALL_STATE(14923)] = 683879,
  [SMALL_STATE(14924)] = 683908,
  [SMALL_STATE(14925)] = 683937,
  [SMALL_STATE(14926)] = 683964,
  [SMALL_STATE(14927)] = 683985,
  [SMALL_STATE(14928)] = 684014,
  [SMALL_STATE(14929)] = 684041,
  [SMALL_STATE(14930)] = 684068,
  [SMALL_STATE(14931)] = 684095,
  [SMALL_STATE(14932)] = 684124,
  [SMALL_STATE(14933)] = 684153,
  [SMALL_STATE(14934)] = 684174,
  [SMALL_STATE(14935)] = 684201,
  [SMALL_STATE(14936)] = 684228,
  [SMALL_STATE(14937)] = 684249,
  [SMALL_STATE(14938)] = 684278,
  [SMALL_STATE(14939)] = 684299,
  [SMALL_STATE(14940)] = 684320,
  [SMALL_STATE(14941)] = 684349,
  [SMALL_STATE(14942)] = 684374,
  [SMALL_STATE(14943)] = 684403,
  [SMALL_STATE(14944)] = 684424,
  [SMALL_STATE(14945)] = 684453,
  [SMALL_STATE(14946)] = 684474,
  [SMALL_STATE(14947)] = 684497,
  [SMALL_STATE(14948)] = 684526,
  [SMALL_STATE(14949)] = 684547,
  [SMALL_STATE(14950)] = 684568,
  [SMALL_STATE(14951)] = 684589,
  [SMALL_STATE(14952)] = 684618,
  [SMALL_STATE(14953)] = 684647,
  [SMALL_STATE(14954)] = 684676,
  [SMALL_STATE(14955)] = 684705,
  [SMALL_STATE(14956)] = 684734,
  [SMALL_STATE(14957)] = 684763,
  [SMALL_STATE(14958)] = 684792,
  [SMALL_STATE(14959)] = 684821,
  [SMALL_STATE(14960)] = 684850,
  [SMALL_STATE(14961)] = 684879,
  [SMALL_STATE(14962)] = 684906,
  [SMALL_STATE(14963)] = 684927,
  [SMALL_STATE(14964)] = 684956,
  [SMALL_STATE(14965)] = 684985,
  [SMALL_STATE(14966)] = 685014,
  [SMALL_STATE(14967)] = 685043,
  [SMALL_STATE(14968)] = 685072,
  [SMALL_STATE(14969)] = 685101,
  [SMALL_STATE(14970)] = 685130,
  [SMALL_STATE(14971)] = 685157,
  [SMALL_STATE(14972)] = 685178,
  [SMALL_STATE(14973)] = 685207,
  [SMALL_STATE(14974)] = 685236,
  [SMALL_STATE(14975)] = 685265,
  [SMALL_STATE(14976)] = 685292,
  [SMALL_STATE(14977)] = 685321,
  [SMALL_STATE(14978)] = 685350,
  [SMALL_STATE(14979)] = 685379,
  [SMALL_STATE(14980)] = 685400,
  [SMALL_STATE(14981)] = 685429,
  [SMALL_STATE(14982)] = 685458,
  [SMALL_STATE(14983)] = 685483,
  [SMALL_STATE(14984)] = 685512,
  [SMALL_STATE(14985)] = 685541,
  [SMALL_STATE(14986)] = 685570,
  [SMALL_STATE(14987)] = 685597,
  [SMALL_STATE(14988)] = 685626,
  [SMALL_STATE(14989)] = 685655,
  [SMALL_STATE(14990)] = 685678,
  [SMALL_STATE(14991)] = 685705,
  [SMALL_STATE(14992)] = 685732,
  [SMALL_STATE(14993)] = 685759,
  [SMALL_STATE(14994)] = 685780,
  [SMALL_STATE(14995)] = 685806,
  [SMALL_STATE(14996)] = 685830,
  [SMALL_STATE(14997)] = 685856,
  [SMALL_STATE(14998)] = 685882,
  [SMALL_STATE(14999)] = 685908,
  [SMALL_STATE(15000)] = 685926,
  [SMALL_STATE(15001)] = 685952,
  [SMALL_STATE(15002)] = 685978,
  [SMALL_STATE(15003)] = 686004,
  [SMALL_STATE(15004)] = 686030,
  [SMALL_STATE(15005)] = 686056,
  [SMALL_STATE(15006)] = 686082,
  [SMALL_STATE(15007)] = 686108,
  [SMALL_STATE(15008)] = 686134,
  [SMALL_STATE(15009)] = 686156,
  [SMALL_STATE(15010)] = 686180,
  [SMALL_STATE(15011)] = 686206,
  [SMALL_STATE(15012)] = 686232,
  [SMALL_STATE(15013)] = 686258,
  [SMALL_STATE(15014)] = 686284,
  [SMALL_STATE(15015)] = 686310,
  [SMALL_STATE(15016)] = 686336,
  [SMALL_STATE(15017)] = 686360,
  [SMALL_STATE(15018)] = 686386,
  [SMALL_STATE(15019)] = 686404,
  [SMALL_STATE(15020)] = 686430,
  [SMALL_STATE(15021)] = 686456,
  [SMALL_STATE(15022)] = 686482,
  [SMALL_STATE(15023)] = 686506,
  [SMALL_STATE(15024)] = 686532,
  [SMALL_STATE(15025)] = 686556,
  [SMALL_STATE(15026)] = 686582,
  [SMALL_STATE(15027)] = 686608,
  [SMALL_STATE(15028)] = 686634,
  [SMALL_STATE(15029)] = 686660,
  [SMALL_STATE(15030)] = 686686,
  [SMALL_STATE(15031)] = 686712,
  [SMALL_STATE(15032)] = 686738,
  [SMALL_STATE(15033)] = 686764,
  [SMALL_STATE(15034)] = 686790,
  [SMALL_STATE(15035)] = 686816,
  [SMALL_STATE(15036)] = 686842,
  [SMALL_STATE(15037)] = 686868,
  [SMALL_STATE(15038)] = 686894,
  [SMALL_STATE(15039)] = 686920,
  [SMALL_STATE(15040)] = 686946,
  [SMALL_STATE(15041)] = 686964,
  [SMALL_STATE(15042)] = 686990,
  [SMALL_STATE(15043)] = 687016,
  [SMALL_STATE(15044)] = 687042,
  [SMALL_STATE(15045)] = 687068,
  [SMALL_STATE(15046)] = 687094,
  [SMALL_STATE(15047)] = 687120,
  [SMALL_STATE(15048)] = 687142,
  [SMALL_STATE(15049)] = 687168,
  [SMALL_STATE(15050)] = 687190,
  [SMALL_STATE(15051)] = 687216,
  [SMALL_STATE(15052)] = 687242,
  [SMALL_STATE(15053)] = 687266,
  [SMALL_STATE(15054)] = 687292,
  [SMALL_STATE(15055)] = 687318,
  [SMALL_STATE(15056)] = 687344,
  [SMALL_STATE(15057)] = 687368,
  [SMALL_STATE(15058)] = 687394,
  [SMALL_STATE(15059)] = 687420,
  [SMALL_STATE(15060)] = 687446,
  [SMALL_STATE(15061)] = 687470,
  [SMALL_STATE(15062)] = 687496,
  [SMALL_STATE(15063)] = 687522,
  [SMALL_STATE(15064)] = 687548,
  [SMALL_STATE(15065)] = 687574,
  [SMALL_STATE(15066)] = 687600,
  [SMALL_STATE(15067)] = 687626,
  [SMALL_STATE(15068)] = 687644,
  [SMALL_STATE(15069)] = 687670,
  [SMALL_STATE(15070)] = 687694,
  [SMALL_STATE(15071)] = 687720,
  [SMALL_STATE(15072)] = 687742,
  [SMALL_STATE(15073)] = 687764,
  [SMALL_STATE(15074)] = 687790,
  [SMALL_STATE(15075)] = 687816,
  [SMALL_STATE(15076)] = 687842,
  [SMALL_STATE(15077)] = 687868,
  [SMALL_STATE(15078)] = 687894,
  [SMALL_STATE(15079)] = 687920,
  [SMALL_STATE(15080)] = 687940,
  [SMALL_STATE(15081)] = 687960,
  [SMALL_STATE(15082)] = 687986,
  [SMALL_STATE(15083)] = 688012,
  [SMALL_STATE(15084)] = 688038,
  [SMALL_STATE(15085)] = 688056,
  [SMALL_STATE(15086)] = 688082,
  [SMALL_STATE(15087)] = 688108,
  [SMALL_STATE(15088)] = 688134,
  [SMALL_STATE(15089)] = 688160,
  [SMALL_STATE(15090)] = 688186,
  [SMALL_STATE(15091)] = 688212,
  [SMALL_STATE(15092)] = 688236,
  [SMALL_STATE(15093)] = 688254,
  [SMALL_STATE(15094)] = 688276,
  [SMALL_STATE(15095)] = 688302,
  [SMALL_STATE(15096)] = 688328,
  [SMALL_STATE(15097)] = 688354,
  [SMALL_STATE(15098)] = 688380,
  [SMALL_STATE(15099)] = 688406,
  [SMALL_STATE(15100)] = 688430,
  [SMALL_STATE(15101)] = 688456,
  [SMALL_STATE(15102)] = 688482,
  [SMALL_STATE(15103)] = 688508,
  [SMALL_STATE(15104)] = 688534,
  [SMALL_STATE(15105)] = 688558,
  [SMALL_STATE(15106)] = 688584,
  [SMALL_STATE(15107)] = 688610,
  [SMALL_STATE(15108)] = 688634,
  [SMALL_STATE(15109)] = 688660,
  [SMALL_STATE(15110)] = 688686,
  [SMALL_STATE(15111)] = 688712,
  [SMALL_STATE(15112)] = 688738,
  [SMALL_STATE(15113)] = 688764,
  [SMALL_STATE(15114)] = 688790,
  [SMALL_STATE(15115)] = 688816,
  [SMALL_STATE(15116)] = 688842,
  [SMALL_STATE(15117)] = 688864,
  [SMALL_STATE(15118)] = 688890,
  [SMALL_STATE(15119)] = 688916,
  [SMALL_STATE(15120)] = 688942,
  [SMALL_STATE(15121)] = 688964,
  [SMALL_STATE(15122)] = 688986,
  [SMALL_STATE(15123)] = 689012,
  [SMALL_STATE(15124)] = 689038,
  [SMALL_STATE(15125)] = 689062,
  [SMALL_STATE(15126)] = 689088,
  [SMALL_STATE(15127)] = 689110,
  [SMALL_STATE(15128)] = 689136,
  [SMALL_STATE(15129)] = 689162,
  [SMALL_STATE(15130)] = 689188,
  [SMALL_STATE(15131)] = 689210,
  [SMALL_STATE(15132)] = 689236,
  [SMALL_STATE(15133)] = 689262,
  [SMALL_STATE(15134)] = 689288,
  [SMALL_STATE(15135)] = 689314,
  [SMALL_STATE(15136)] = 689340,
  [SMALL_STATE(15137)] = 689366,
  [SMALL_STATE(15138)] = 689388,
  [SMALL_STATE(15139)] = 689410,
  [SMALL_STATE(15140)] = 689436,
  [SMALL_STATE(15141)] = 689462,
  [SMALL_STATE(15142)] = 689488,
  [SMALL_STATE(15143)] = 689514,
  [SMALL_STATE(15144)] = 689538,
  [SMALL_STATE(15145)] = 689560,
  [SMALL_STATE(15146)] = 689586,
  [SMALL_STATE(15147)] = 689612,
  [SMALL_STATE(15148)] = 689634,
  [SMALL_STATE(15149)] = 689658,
  [SMALL_STATE(15150)] = 689684,
  [SMALL_STATE(15151)] = 689710,
  [SMALL_STATE(15152)] = 689736,
  [SMALL_STATE(15153)] = 689762,
  [SMALL_STATE(15154)] = 689788,
  [SMALL_STATE(15155)] = 689810,
  [SMALL_STATE(15156)] = 689834,
  [SMALL_STATE(15157)] = 689858,
  [SMALL_STATE(15158)] = 689884,
  [SMALL_STATE(15159)] = 689906,
  [SMALL_STATE(15160)] = 689932,
  [SMALL_STATE(15161)] = 689958,
  [SMALL_STATE(15162)] = 689984,
  [SMALL_STATE(15163)] = 690010,
  [SMALL_STATE(15164)] = 690034,
  [SMALL_STATE(15165)] = 690052,
  [SMALL_STATE(15166)] = 690078,
  [SMALL_STATE(15167)] = 690104,
  [SMALL_STATE(15168)] = 690130,
  [SMALL_STATE(15169)] = 690156,
  [SMALL_STATE(15170)] = 690182,
  [SMALL_STATE(15171)] = 690208,
  [SMALL_STATE(15172)] = 690234,
  [SMALL_STATE(15173)] = 690260,
  [SMALL_STATE(15174)] = 690282,
  [SMALL_STATE(15175)] = 690308,
  [SMALL_STATE(15176)] = 690332,
  [SMALL_STATE(15177)] = 690358,
  [SMALL_STATE(15178)] = 690384,
  [SMALL_STATE(15179)] = 690410,
  [SMALL_STATE(15180)] = 690436,
  [SMALL_STATE(15181)] = 690462,
  [SMALL_STATE(15182)] = 690488,
  [SMALL_STATE(15183)] = 690514,
  [SMALL_STATE(15184)] = 690538,
  [SMALL_STATE(15185)] = 690564,
  [SMALL_STATE(15186)] = 690586,
  [SMALL_STATE(15187)] = 690612,
  [SMALL_STATE(15188)] = 690638,
  [SMALL_STATE(15189)] = 690664,
  [SMALL_STATE(15190)] = 690688,
  [SMALL_STATE(15191)] = 690714,
  [SMALL_STATE(15192)] = 690740,
  [SMALL_STATE(15193)] = 690766,
  [SMALL_STATE(15194)] = 690792,
  [SMALL_STATE(15195)] = 690818,
  [SMALL_STATE(15196)] = 690840,
  [SMALL_STATE(15197)] = 690864,
  [SMALL_STATE(15198)] = 690890,
  [SMALL_STATE(15199)] = 690916,
  [SMALL_STATE(15200)] = 690942,
  [SMALL_STATE(15201)] = 690965,
  [SMALL_STATE(15202)] = 690984,
  [SMALL_STATE(15203)] = 691005,
  [SMALL_STATE(15204)] = 691028,
  [SMALL_STATE(15205)] = 691051,
  [SMALL_STATE(15206)] = 691074,
  [SMALL_STATE(15207)] = 691097,
  [SMALL_STATE(15208)] = 691120,
  [SMALL_STATE(15209)] = 691143,
  [SMALL_STATE(15210)] = 691166,
  [SMALL_STATE(15211)] = 691189,
  [SMALL_STATE(15212)] = 691212,
  [SMALL_STATE(15213)] = 691235,
  [SMALL_STATE(15214)] = 691258,
  [SMALL_STATE(15215)] = 691281,
  [SMALL_STATE(15216)] = 691304,
  [SMALL_STATE(15217)] = 691327,
  [SMALL_STATE(15218)] = 691350,
  [SMALL_STATE(15219)] = 691373,
  [SMALL_STATE(15220)] = 691396,
  [SMALL_STATE(15221)] = 691419,
  [SMALL_STATE(15222)] = 691442,
  [SMALL_STATE(15223)] = 691465,
  [SMALL_STATE(15224)] = 691488,
  [SMALL_STATE(15225)] = 691511,
  [SMALL_STATE(15226)] = 691534,
  [SMALL_STATE(15227)] = 691557,
  [SMALL_STATE(15228)] = 691580,
  [SMALL_STATE(15229)] = 691603,
  [SMALL_STATE(15230)] = 691626,
  [SMALL_STATE(15231)] = 691649,
  [SMALL_STATE(15232)] = 691672,
  [SMALL_STATE(15233)] = 691695,
  [SMALL_STATE(15234)] = 691718,
  [SMALL_STATE(15235)] = 691741,
  [SMALL_STATE(15236)] = 691764,
  [SMALL_STATE(15237)] = 691787,
  [SMALL_STATE(15238)] = 691810,
  [SMALL_STATE(15239)] = 691833,
  [SMALL_STATE(15240)] = 691856,
  [SMALL_STATE(15241)] = 691879,
  [SMALL_STATE(15242)] = 691902,
  [SMALL_STATE(15243)] = 691925,
  [SMALL_STATE(15244)] = 691948,
  [SMALL_STATE(15245)] = 691971,
  [SMALL_STATE(15246)] = 691994,
  [SMALL_STATE(15247)] = 692017,
  [SMALL_STATE(15248)] = 692040,
  [SMALL_STATE(15249)] = 692063,
  [SMALL_STATE(15250)] = 692086,
  [SMALL_STATE(15251)] = 692109,
  [SMALL_STATE(15252)] = 692132,
  [SMALL_STATE(15253)] = 692155,
  [SMALL_STATE(15254)] = 692178,
  [SMALL_STATE(15255)] = 692201,
  [SMALL_STATE(15256)] = 692224,
  [SMALL_STATE(15257)] = 692247,
  [SMALL_STATE(15258)] = 692270,
  [SMALL_STATE(15259)] = 692293,
  [SMALL_STATE(15260)] = 692316,
  [SMALL_STATE(15261)] = 692339,
  [SMALL_STATE(15262)] = 692358,
  [SMALL_STATE(15263)] = 692381,
  [SMALL_STATE(15264)] = 692404,
  [SMALL_STATE(15265)] = 692427,
  [SMALL_STATE(15266)] = 692450,
  [SMALL_STATE(15267)] = 692473,
  [SMALL_STATE(15268)] = 692496,
  [SMALL_STATE(15269)] = 692519,
  [SMALL_STATE(15270)] = 692542,
  [SMALL_STATE(15271)] = 692565,
  [SMALL_STATE(15272)] = 692588,
  [SMALL_STATE(15273)] = 692611,
  [SMALL_STATE(15274)] = 692634,
  [SMALL_STATE(15275)] = 692657,
  [SMALL_STATE(15276)] = 692680,
  [SMALL_STATE(15277)] = 692703,
  [SMALL_STATE(15278)] = 692726,
  [SMALL_STATE(15279)] = 692749,
  [SMALL_STATE(15280)] = 692772,
  [SMALL_STATE(15281)] = 692795,
  [SMALL_STATE(15282)] = 692816,
  [SMALL_STATE(15283)] = 692839,
  [SMALL_STATE(15284)] = 692862,
  [SMALL_STATE(15285)] = 692885,
  [SMALL_STATE(15286)] = 692908,
  [SMALL_STATE(15287)] = 692931,
  [SMALL_STATE(15288)] = 692954,
  [SMALL_STATE(15289)] = 692977,
  [SMALL_STATE(15290)] = 693000,
  [SMALL_STATE(15291)] = 693023,
  [SMALL_STATE(15292)] = 693046,
  [SMALL_STATE(15293)] = 693069,
  [SMALL_STATE(15294)] = 693092,
  [SMALL_STATE(15295)] = 693115,
  [SMALL_STATE(15296)] = 693138,
  [SMALL_STATE(15297)] = 693161,
  [SMALL_STATE(15298)] = 693184,
  [SMALL_STATE(15299)] = 693207,
  [SMALL_STATE(15300)] = 693230,
  [SMALL_STATE(15301)] = 693253,
  [SMALL_STATE(15302)] = 693276,
  [SMALL_STATE(15303)] = 693299,
  [SMALL_STATE(15304)] = 693322,
  [SMALL_STATE(15305)] = 693345,
  [SMALL_STATE(15306)] = 693368,
  [SMALL_STATE(15307)] = 693391,
  [SMALL_STATE(15308)] = 693414,
  [SMALL_STATE(15309)] = 693437,
  [SMALL_STATE(15310)] = 693460,
  [SMALL_STATE(15311)] = 693479,
  [SMALL_STATE(15312)] = 693502,
  [SMALL_STATE(15313)] = 693525,
  [SMALL_STATE(15314)] = 693548,
  [SMALL_STATE(15315)] = 693571,
  [SMALL_STATE(15316)] = 693594,
  [SMALL_STATE(15317)] = 693617,
  [SMALL_STATE(15318)] = 693640,
  [SMALL_STATE(15319)] = 693663,
  [SMALL_STATE(15320)] = 693686,
  [SMALL_STATE(15321)] = 693709,
  [SMALL_STATE(15322)] = 693732,
  [SMALL_STATE(15323)] = 693755,
  [SMALL_STATE(15324)] = 693778,
  [SMALL_STATE(15325)] = 693801,
  [SMALL_STATE(15326)] = 693824,
  [SMALL_STATE(15327)] = 693847,
  [SMALL_STATE(15328)] = 693870,
  [SMALL_STATE(15329)] = 693893,
  [SMALL_STATE(15330)] = 693914,
  [SMALL_STATE(15331)] = 693937,
  [SMALL_STATE(15332)] = 693960,
  [SMALL_STATE(15333)] = 693983,
  [SMALL_STATE(15334)] = 694006,
  [SMALL_STATE(15335)] = 694029,
  [SMALL_STATE(15336)] = 694052,
  [SMALL_STATE(15337)] = 694075,
  [SMALL_STATE(15338)] = 694098,
  [SMALL_STATE(15339)] = 694121,
  [SMALL_STATE(15340)] = 694144,
  [SMALL_STATE(15341)] = 694167,
  [SMALL_STATE(15342)] = 694190,
  [SMALL_STATE(15343)] = 694213,
  [SMALL_STATE(15344)] = 694236,
  [SMALL_STATE(15345)] = 694259,
  [SMALL_STATE(15346)] = 694282,
  [SMALL_STATE(15347)] = 694305,
  [SMALL_STATE(15348)] = 694328,
  [SMALL_STATE(15349)] = 694351,
  [SMALL_STATE(15350)] = 694374,
  [SMALL_STATE(15351)] = 694397,
  [SMALL_STATE(15352)] = 694420,
  [SMALL_STATE(15353)] = 694443,
  [SMALL_STATE(15354)] = 694464,
  [SMALL_STATE(15355)] = 694487,
  [SMALL_STATE(15356)] = 694510,
  [SMALL_STATE(15357)] = 694533,
  [SMALL_STATE(15358)] = 694556,
  [SMALL_STATE(15359)] = 694579,
  [SMALL_STATE(15360)] = 694602,
  [SMALL_STATE(15361)] = 694625,
  [SMALL_STATE(15362)] = 694648,
  [SMALL_STATE(15363)] = 694671,
  [SMALL_STATE(15364)] = 694694,
  [SMALL_STATE(15365)] = 694717,
  [SMALL_STATE(15366)] = 694740,
  [SMALL_STATE(15367)] = 694763,
  [SMALL_STATE(15368)] = 694784,
  [SMALL_STATE(15369)] = 694805,
  [SMALL_STATE(15370)] = 694828,
  [SMALL_STATE(15371)] = 694849,
  [SMALL_STATE(15372)] = 694872,
  [SMALL_STATE(15373)] = 694895,
  [SMALL_STATE(15374)] = 694916,
  [SMALL_STATE(15375)] = 694939,
  [SMALL_STATE(15376)] = 694962,
  [SMALL_STATE(15377)] = 694985,
  [SMALL_STATE(15378)] = 695008,
  [SMALL_STATE(15379)] = 695031,
  [SMALL_STATE(15380)] = 695054,
  [SMALL_STATE(15381)] = 695077,
  [SMALL_STATE(15382)] = 695100,
  [SMALL_STATE(15383)] = 695123,
  [SMALL_STATE(15384)] = 695144,
  [SMALL_STATE(15385)] = 695167,
  [SMALL_STATE(15386)] = 695190,
  [SMALL_STATE(15387)] = 695213,
  [SMALL_STATE(15388)] = 695236,
  [SMALL_STATE(15389)] = 695259,
  [SMALL_STATE(15390)] = 695282,
  [SMALL_STATE(15391)] = 695305,
  [SMALL_STATE(15392)] = 695328,
  [SMALL_STATE(15393)] = 695351,
  [SMALL_STATE(15394)] = 695374,
  [SMALL_STATE(15395)] = 695397,
  [SMALL_STATE(15396)] = 695420,
  [SMALL_STATE(15397)] = 695443,
  [SMALL_STATE(15398)] = 695466,
  [SMALL_STATE(15399)] = 695489,
  [SMALL_STATE(15400)] = 695512,
  [SMALL_STATE(15401)] = 695535,
  [SMALL_STATE(15402)] = 695556,
  [SMALL_STATE(15403)] = 695579,
  [SMALL_STATE(15404)] = 695602,
  [SMALL_STATE(15405)] = 695625,
  [SMALL_STATE(15406)] = 695648,
  [SMALL_STATE(15407)] = 695671,
  [SMALL_STATE(15408)] = 695694,
  [SMALL_STATE(15409)] = 695717,
  [SMALL_STATE(15410)] = 695740,
  [SMALL_STATE(15411)] = 695763,
  [SMALL_STATE(15412)] = 695786,
  [SMALL_STATE(15413)] = 695809,
  [SMALL_STATE(15414)] = 695832,
  [SMALL_STATE(15415)] = 695855,
  [SMALL_STATE(15416)] = 695878,
  [SMALL_STATE(15417)] = 695901,
  [SMALL_STATE(15418)] = 695924,
  [SMALL_STATE(15419)] = 695947,
  [SMALL_STATE(15420)] = 695970,
  [SMALL_STATE(15421)] = 695993,
  [SMALL_STATE(15422)] = 696016,
  [SMALL_STATE(15423)] = 696039,
  [SMALL_STATE(15424)] = 696062,
  [SMALL_STATE(15425)] = 696085,
  [SMALL_STATE(15426)] = 696108,
  [SMALL_STATE(15427)] = 696131,
  [SMALL_STATE(15428)] = 696154,
  [SMALL_STATE(15429)] = 696173,
  [SMALL_STATE(15430)] = 696196,
  [SMALL_STATE(15431)] = 696219,
  [SMALL_STATE(15432)] = 696242,
  [SMALL_STATE(15433)] = 696265,
  [SMALL_STATE(15434)] = 696288,
  [SMALL_STATE(15435)] = 696311,
  [SMALL_STATE(15436)] = 696334,
  [SMALL_STATE(15437)] = 696357,
  [SMALL_STATE(15438)] = 696380,
  [SMALL_STATE(15439)] = 696403,
  [SMALL_STATE(15440)] = 696422,
  [SMALL_STATE(15441)] = 696445,
  [SMALL_STATE(15442)] = 696468,
  [SMALL_STATE(15443)] = 696491,
  [SMALL_STATE(15444)] = 696514,
  [SMALL_STATE(15445)] = 696537,
  [SMALL_STATE(15446)] = 696560,
  [SMALL_STATE(15447)] = 696583,
  [SMALL_STATE(15448)] = 696604,
  [SMALL_STATE(15449)] = 696627,
  [SMALL_STATE(15450)] = 696650,
  [SMALL_STATE(15451)] = 696673,
  [SMALL_STATE(15452)] = 696696,
  [SMALL_STATE(15453)] = 696719,
  [SMALL_STATE(15454)] = 696742,
  [SMALL_STATE(15455)] = 696765,
  [SMALL_STATE(15456)] = 696788,
  [SMALL_STATE(15457)] = 696811,
  [SMALL_STATE(15458)] = 696834,
  [SMALL_STATE(15459)] = 696857,
  [SMALL_STATE(15460)] = 696880,
  [SMALL_STATE(15461)] = 696903,
  [SMALL_STATE(15462)] = 696924,
  [SMALL_STATE(15463)] = 696947,
  [SMALL_STATE(15464)] = 696970,
  [SMALL_STATE(15465)] = 696993,
  [SMALL_STATE(15466)] = 697016,
  [SMALL_STATE(15467)] = 697039,
  [SMALL_STATE(15468)] = 697062,
  [SMALL_STATE(15469)] = 697085,
  [SMALL_STATE(15470)] = 697108,
  [SMALL_STATE(15471)] = 697131,
  [SMALL_STATE(15472)] = 697154,
  [SMALL_STATE(15473)] = 697173,
  [SMALL_STATE(15474)] = 697196,
  [SMALL_STATE(15475)] = 697217,
  [SMALL_STATE(15476)] = 697240,
  [SMALL_STATE(15477)] = 697263,
  [SMALL_STATE(15478)] = 697286,
  [SMALL_STATE(15479)] = 697309,
  [SMALL_STATE(15480)] = 697332,
  [SMALL_STATE(15481)] = 697355,
  [SMALL_STATE(15482)] = 697378,
  [SMALL_STATE(15483)] = 697401,
  [SMALL_STATE(15484)] = 697420,
  [SMALL_STATE(15485)] = 697443,
  [SMALL_STATE(15486)] = 697466,
  [SMALL_STATE(15487)] = 697489,
  [SMALL_STATE(15488)] = 697508,
  [SMALL_STATE(15489)] = 697531,
  [SMALL_STATE(15490)] = 697554,
  [SMALL_STATE(15491)] = 697577,
  [SMALL_STATE(15492)] = 697600,
  [SMALL_STATE(15493)] = 697623,
  [SMALL_STATE(15494)] = 697646,
  [SMALL_STATE(15495)] = 697669,
  [SMALL_STATE(15496)] = 697692,
  [SMALL_STATE(15497)] = 697715,
  [SMALL_STATE(15498)] = 697736,
  [SMALL_STATE(15499)] = 697759,
  [SMALL_STATE(15500)] = 697782,
  [SMALL_STATE(15501)] = 697805,
  [SMALL_STATE(15502)] = 697828,
  [SMALL_STATE(15503)] = 697851,
  [SMALL_STATE(15504)] = 697874,
  [SMALL_STATE(15505)] = 697897,
  [SMALL_STATE(15506)] = 697920,
  [SMALL_STATE(15507)] = 697943,
  [SMALL_STATE(15508)] = 697966,
  [SMALL_STATE(15509)] = 697989,
  [SMALL_STATE(15510)] = 698012,
  [SMALL_STATE(15511)] = 698035,
  [SMALL_STATE(15512)] = 698058,
  [SMALL_STATE(15513)] = 698081,
  [SMALL_STATE(15514)] = 698104,
  [SMALL_STATE(15515)] = 698127,
  [SMALL_STATE(15516)] = 698150,
  [SMALL_STATE(15517)] = 698173,
  [SMALL_STATE(15518)] = 698196,
  [SMALL_STATE(15519)] = 698219,
  [SMALL_STATE(15520)] = 698242,
  [SMALL_STATE(15521)] = 698265,
  [SMALL_STATE(15522)] = 698286,
  [SMALL_STATE(15523)] = 698309,
  [SMALL_STATE(15524)] = 698332,
  [SMALL_STATE(15525)] = 698355,
  [SMALL_STATE(15526)] = 698378,
  [SMALL_STATE(15527)] = 698401,
  [SMALL_STATE(15528)] = 698424,
  [SMALL_STATE(15529)] = 698447,
  [SMALL_STATE(15530)] = 698470,
  [SMALL_STATE(15531)] = 698493,
  [SMALL_STATE(15532)] = 698516,
  [SMALL_STATE(15533)] = 698539,
  [SMALL_STATE(15534)] = 698562,
  [SMALL_STATE(15535)] = 698585,
  [SMALL_STATE(15536)] = 698608,
  [SMALL_STATE(15537)] = 698631,
  [SMALL_STATE(15538)] = 698654,
  [SMALL_STATE(15539)] = 698677,
  [SMALL_STATE(15540)] = 698698,
  [SMALL_STATE(15541)] = 698721,
  [SMALL_STATE(15542)] = 698744,
  [SMALL_STATE(15543)] = 698767,
  [SMALL_STATE(15544)] = 698790,
  [SMALL_STATE(15545)] = 698813,
  [SMALL_STATE(15546)] = 698836,
  [SMALL_STATE(15547)] = 698859,
  [SMALL_STATE(15548)] = 698882,
  [SMALL_STATE(15549)] = 698905,
  [SMALL_STATE(15550)] = 698926,
  [SMALL_STATE(15551)] = 698949,
  [SMALL_STATE(15552)] = 698972,
  [SMALL_STATE(15553)] = 698995,
  [SMALL_STATE(15554)] = 699018,
  [SMALL_STATE(15555)] = 699041,
  [SMALL_STATE(15556)] = 699064,
  [SMALL_STATE(15557)] = 699087,
  [SMALL_STATE(15558)] = 699110,
  [SMALL_STATE(15559)] = 699133,
  [SMALL_STATE(15560)] = 699156,
  [SMALL_STATE(15561)] = 699179,
  [SMALL_STATE(15562)] = 699202,
  [SMALL_STATE(15563)] = 699223,
  [SMALL_STATE(15564)] = 699246,
  [SMALL_STATE(15565)] = 699269,
  [SMALL_STATE(15566)] = 699292,
  [SMALL_STATE(15567)] = 699315,
  [SMALL_STATE(15568)] = 699338,
  [SMALL_STATE(15569)] = 699357,
  [SMALL_STATE(15570)] = 699380,
  [SMALL_STATE(15571)] = 699401,
  [SMALL_STATE(15572)] = 699424,
  [SMALL_STATE(15573)] = 699447,
  [SMALL_STATE(15574)] = 699470,
  [SMALL_STATE(15575)] = 699493,
  [SMALL_STATE(15576)] = 699516,
  [SMALL_STATE(15577)] = 699539,
  [SMALL_STATE(15578)] = 699560,
  [SMALL_STATE(15579)] = 699583,
  [SMALL_STATE(15580)] = 699606,
  [SMALL_STATE(15581)] = 699629,
  [SMALL_STATE(15582)] = 699652,
  [SMALL_STATE(15583)] = 699675,
  [SMALL_STATE(15584)] = 699698,
  [SMALL_STATE(15585)] = 699721,
  [SMALL_STATE(15586)] = 699744,
  [SMALL_STATE(15587)] = 699767,
  [SMALL_STATE(15588)] = 699790,
  [SMALL_STATE(15589)] = 699813,
  [SMALL_STATE(15590)] = 699836,
  [SMALL_STATE(15591)] = 699857,
  [SMALL_STATE(15592)] = 699880,
  [SMALL_STATE(15593)] = 699903,
  [SMALL_STATE(15594)] = 699926,
  [SMALL_STATE(15595)] = 699949,
  [SMALL_STATE(15596)] = 699972,
  [SMALL_STATE(15597)] = 699993,
  [SMALL_STATE(15598)] = 700016,
  [SMALL_STATE(15599)] = 700039,
  [SMALL_STATE(15600)] = 700062,
  [SMALL_STATE(15601)] = 700085,
  [SMALL_STATE(15602)] = 700108,
  [SMALL_STATE(15603)] = 700131,
  [SMALL_STATE(15604)] = 700154,
  [SMALL_STATE(15605)] = 700173,
  [SMALL_STATE(15606)] = 700196,
  [SMALL_STATE(15607)] = 700217,
  [SMALL_STATE(15608)] = 700238,
  [SMALL_STATE(15609)] = 700259,
  [SMALL_STATE(15610)] = 700282,
  [SMALL_STATE(15611)] = 700301,
  [SMALL_STATE(15612)] = 700324,
  [SMALL_STATE(15613)] = 700347,
  [SMALL_STATE(15614)] = 700370,
  [SMALL_STATE(15615)] = 700393,
  [SMALL_STATE(15616)] = 700416,
  [SMALL_STATE(15617)] = 700439,
  [SMALL_STATE(15618)] = 700458,
  [SMALL_STATE(15619)] = 700481,
  [SMALL_STATE(15620)] = 700504,
  [SMALL_STATE(15621)] = 700527,
  [SMALL_STATE(15622)] = 700550,
  [SMALL_STATE(15623)] = 700573,
  [SMALL_STATE(15624)] = 700596,
  [SMALL_STATE(15625)] = 700619,
  [SMALL_STATE(15626)] = 700642,
  [SMALL_STATE(15627)] = 700665,
  [SMALL_STATE(15628)] = 700688,
  [SMALL_STATE(15629)] = 700711,
  [SMALL_STATE(15630)] = 700734,
  [SMALL_STATE(15631)] = 700757,
  [SMALL_STATE(15632)] = 700780,
  [SMALL_STATE(15633)] = 700803,
  [SMALL_STATE(15634)] = 700826,
  [SMALL_STATE(15635)] = 700849,
  [SMALL_STATE(15636)] = 700872,
  [SMALL_STATE(15637)] = 700895,
  [SMALL_STATE(15638)] = 700918,
  [SMALL_STATE(15639)] = 700941,
  [SMALL_STATE(15640)] = 700964,
  [SMALL_STATE(15641)] = 700987,
  [SMALL_STATE(15642)] = 701010,
  [SMALL_STATE(15643)] = 701033,
  [SMALL_STATE(15644)] = 701056,
  [SMALL_STATE(15645)] = 701079,
  [SMALL_STATE(15646)] = 701102,
  [SMALL_STATE(15647)] = 701125,
  [SMALL_STATE(15648)] = 701148,
  [SMALL_STATE(15649)] = 701171,
  [SMALL_STATE(15650)] = 701194,
  [SMALL_STATE(15651)] = 701217,
  [SMALL_STATE(15652)] = 701240,
  [SMALL_STATE(15653)] = 701263,
  [SMALL_STATE(15654)] = 701286,
  [SMALL_STATE(15655)] = 701309,
  [SMALL_STATE(15656)] = 701332,
  [SMALL_STATE(15657)] = 701355,
  [SMALL_STATE(15658)] = 701378,
  [SMALL_STATE(15659)] = 701401,
  [SMALL_STATE(15660)] = 701424,
  [SMALL_STATE(15661)] = 701447,
  [SMALL_STATE(15662)] = 701470,
  [SMALL_STATE(15663)] = 701493,
  [SMALL_STATE(15664)] = 701516,
  [SMALL_STATE(15665)] = 701539,
  [SMALL_STATE(15666)] = 701562,
  [SMALL_STATE(15667)] = 701585,
  [SMALL_STATE(15668)] = 701608,
  [SMALL_STATE(15669)] = 701631,
  [SMALL_STATE(15670)] = 701654,
  [SMALL_STATE(15671)] = 701677,
  [SMALL_STATE(15672)] = 701700,
  [SMALL_STATE(15673)] = 701723,
  [SMALL_STATE(15674)] = 701746,
  [SMALL_STATE(15675)] = 701769,
  [SMALL_STATE(15676)] = 701790,
  [SMALL_STATE(15677)] = 701813,
  [SMALL_STATE(15678)] = 701836,
  [SMALL_STATE(15679)] = 701859,
  [SMALL_STATE(15680)] = 701882,
  [SMALL_STATE(15681)] = 701905,
  [SMALL_STATE(15682)] = 701928,
  [SMALL_STATE(15683)] = 701949,
  [SMALL_STATE(15684)] = 701972,
  [SMALL_STATE(15685)] = 701995,
  [SMALL_STATE(15686)] = 702016,
  [SMALL_STATE(15687)] = 702037,
  [SMALL_STATE(15688)] = 702058,
  [SMALL_STATE(15689)] = 702081,
  [SMALL_STATE(15690)] = 702104,
  [SMALL_STATE(15691)] = 702123,
  [SMALL_STATE(15692)] = 702146,
  [SMALL_STATE(15693)] = 702169,
  [SMALL_STATE(15694)] = 702192,
  [SMALL_STATE(15695)] = 702215,
  [SMALL_STATE(15696)] = 702238,
  [SMALL_STATE(15697)] = 702261,
  [SMALL_STATE(15698)] = 702284,
  [SMALL_STATE(15699)] = 702307,
  [SMALL_STATE(15700)] = 702330,
  [SMALL_STATE(15701)] = 702353,
  [SMALL_STATE(15702)] = 702376,
  [SMALL_STATE(15703)] = 702399,
  [SMALL_STATE(15704)] = 702422,
  [SMALL_STATE(15705)] = 702441,
  [SMALL_STATE(15706)] = 702460,
  [SMALL_STATE(15707)] = 702483,
  [SMALL_STATE(15708)] = 702506,
  [SMALL_STATE(15709)] = 702529,
  [SMALL_STATE(15710)] = 702548,
  [SMALL_STATE(15711)] = 702571,
  [SMALL_STATE(15712)] = 702594,
  [SMALL_STATE(15713)] = 702617,
  [SMALL_STATE(15714)] = 702640,
  [SMALL_STATE(15715)] = 702663,
  [SMALL_STATE(15716)] = 702686,
  [SMALL_STATE(15717)] = 702709,
  [SMALL_STATE(15718)] = 702732,
  [SMALL_STATE(15719)] = 702755,
  [SMALL_STATE(15720)] = 702778,
  [SMALL_STATE(15721)] = 702801,
  [SMALL_STATE(15722)] = 702824,
  [SMALL_STATE(15723)] = 702847,
  [SMALL_STATE(15724)] = 702870,
  [SMALL_STATE(15725)] = 702891,
  [SMALL_STATE(15726)] = 702914,
  [SMALL_STATE(15727)] = 702937,
  [SMALL_STATE(15728)] = 702960,
  [SMALL_STATE(15729)] = 702983,
  [SMALL_STATE(15730)] = 703006,
  [SMALL_STATE(15731)] = 703029,
  [SMALL_STATE(15732)] = 703052,
  [SMALL_STATE(15733)] = 703075,
  [SMALL_STATE(15734)] = 703098,
  [SMALL_STATE(15735)] = 703121,
  [SMALL_STATE(15736)] = 703144,
  [SMALL_STATE(15737)] = 703167,
  [SMALL_STATE(15738)] = 703190,
  [SMALL_STATE(15739)] = 703213,
  [SMALL_STATE(15740)] = 703236,
  [SMALL_STATE(15741)] = 703259,
  [SMALL_STATE(15742)] = 703282,
  [SMALL_STATE(15743)] = 703305,
  [SMALL_STATE(15744)] = 703328,
  [SMALL_STATE(15745)] = 703351,
  [SMALL_STATE(15746)] = 703374,
  [SMALL_STATE(15747)] = 703397,
  [SMALL_STATE(15748)] = 703420,
  [SMALL_STATE(15749)] = 703443,
  [SMALL_STATE(15750)] = 703466,
  [SMALL_STATE(15751)] = 703489,
  [SMALL_STATE(15752)] = 703512,
  [SMALL_STATE(15753)] = 703535,
  [SMALL_STATE(15754)] = 703558,
  [SMALL_STATE(15755)] = 703581,
  [SMALL_STATE(15756)] = 703604,
  [SMALL_STATE(15757)] = 703627,
  [SMALL_STATE(15758)] = 703650,
  [SMALL_STATE(15759)] = 703673,
  [SMALL_STATE(15760)] = 703696,
  [SMALL_STATE(15761)] = 703719,
  [SMALL_STATE(15762)] = 703742,
  [SMALL_STATE(15763)] = 703765,
  [SMALL_STATE(15764)] = 703788,
  [SMALL_STATE(15765)] = 703811,
  [SMALL_STATE(15766)] = 703834,
  [SMALL_STATE(15767)] = 703857,
  [SMALL_STATE(15768)] = 703880,
  [SMALL_STATE(15769)] = 703903,
  [SMALL_STATE(15770)] = 703926,
  [SMALL_STATE(15771)] = 703949,
  [SMALL_STATE(15772)] = 703972,
  [SMALL_STATE(15773)] = 703991,
  [SMALL_STATE(15774)] = 704014,
  [SMALL_STATE(15775)] = 704037,
  [SMALL_STATE(15776)] = 704060,
  [SMALL_STATE(15777)] = 704083,
  [SMALL_STATE(15778)] = 704106,
  [SMALL_STATE(15779)] = 704129,
  [SMALL_STATE(15780)] = 704152,
  [SMALL_STATE(15781)] = 704175,
  [SMALL_STATE(15782)] = 704198,
  [SMALL_STATE(15783)] = 704221,
  [SMALL_STATE(15784)] = 704244,
  [SMALL_STATE(15785)] = 704267,
  [SMALL_STATE(15786)] = 704290,
  [SMALL_STATE(15787)] = 704313,
  [SMALL_STATE(15788)] = 704336,
  [SMALL_STATE(15789)] = 704359,
  [SMALL_STATE(15790)] = 704382,
  [SMALL_STATE(15791)] = 704405,
  [SMALL_STATE(15792)] = 704428,
  [SMALL_STATE(15793)] = 704451,
  [SMALL_STATE(15794)] = 704474,
  [SMALL_STATE(15795)] = 704497,
  [SMALL_STATE(15796)] = 704520,
  [SMALL_STATE(15797)] = 704543,
  [SMALL_STATE(15798)] = 704566,
  [SMALL_STATE(15799)] = 704589,
  [SMALL_STATE(15800)] = 704612,
  [SMALL_STATE(15801)] = 704635,
  [SMALL_STATE(15802)] = 704658,
  [SMALL_STATE(15803)] = 704681,
  [SMALL_STATE(15804)] = 704704,
  [SMALL_STATE(15805)] = 704727,
  [SMALL_STATE(15806)] = 704750,
  [SMALL_STATE(15807)] = 704773,
  [SMALL_STATE(15808)] = 704796,
  [SMALL_STATE(15809)] = 704819,
  [SMALL_STATE(15810)] = 704842,
  [SMALL_STATE(15811)] = 704863,
  [SMALL_STATE(15812)] = 704886,
  [SMALL_STATE(15813)] = 704909,
  [SMALL_STATE(15814)] = 704932,
  [SMALL_STATE(15815)] = 704955,
  [SMALL_STATE(15816)] = 704978,
  [SMALL_STATE(15817)] = 705001,
  [SMALL_STATE(15818)] = 705024,
  [SMALL_STATE(15819)] = 705047,
  [SMALL_STATE(15820)] = 705070,
  [SMALL_STATE(15821)] = 705093,
  [SMALL_STATE(15822)] = 705116,
  [SMALL_STATE(15823)] = 705139,
  [SMALL_STATE(15824)] = 705162,
  [SMALL_STATE(15825)] = 705185,
  [SMALL_STATE(15826)] = 705208,
  [SMALL_STATE(15827)] = 705231,
  [SMALL_STATE(15828)] = 705254,
  [SMALL_STATE(15829)] = 705277,
  [SMALL_STATE(15830)] = 705300,
  [SMALL_STATE(15831)] = 705323,
  [SMALL_STATE(15832)] = 705346,
  [SMALL_STATE(15833)] = 705369,
  [SMALL_STATE(15834)] = 705392,
  [SMALL_STATE(15835)] = 705415,
  [SMALL_STATE(15836)] = 705438,
  [SMALL_STATE(15837)] = 705461,
  [SMALL_STATE(15838)] = 705484,
  [SMALL_STATE(15839)] = 705507,
  [SMALL_STATE(15840)] = 705530,
  [SMALL_STATE(15841)] = 705553,
  [SMALL_STATE(15842)] = 705576,
  [SMALL_STATE(15843)] = 705599,
  [SMALL_STATE(15844)] = 705622,
  [SMALL_STATE(15845)] = 705645,
  [SMALL_STATE(15846)] = 705668,
  [SMALL_STATE(15847)] = 705691,
  [SMALL_STATE(15848)] = 705714,
  [SMALL_STATE(15849)] = 705737,
  [SMALL_STATE(15850)] = 705760,
  [SMALL_STATE(15851)] = 705783,
  [SMALL_STATE(15852)] = 705806,
  [SMALL_STATE(15853)] = 705829,
  [SMALL_STATE(15854)] = 705852,
  [SMALL_STATE(15855)] = 705875,
  [SMALL_STATE(15856)] = 705898,
  [SMALL_STATE(15857)] = 705921,
  [SMALL_STATE(15858)] = 705944,
  [SMALL_STATE(15859)] = 705967,
  [SMALL_STATE(15860)] = 705990,
  [SMALL_STATE(15861)] = 706013,
  [SMALL_STATE(15862)] = 706036,
  [SMALL_STATE(15863)] = 706059,
  [SMALL_STATE(15864)] = 706082,
  [SMALL_STATE(15865)] = 706103,
  [SMALL_STATE(15866)] = 706126,
  [SMALL_STATE(15867)] = 706149,
  [SMALL_STATE(15868)] = 706170,
  [SMALL_STATE(15869)] = 706193,
  [SMALL_STATE(15870)] = 706216,
  [SMALL_STATE(15871)] = 706237,
  [SMALL_STATE(15872)] = 706260,
  [SMALL_STATE(15873)] = 706279,
  [SMALL_STATE(15874)] = 706302,
  [SMALL_STATE(15875)] = 706325,
  [SMALL_STATE(15876)] = 706348,
  [SMALL_STATE(15877)] = 706371,
  [SMALL_STATE(15878)] = 706394,
  [SMALL_STATE(15879)] = 706415,
  [SMALL_STATE(15880)] = 706434,
  [SMALL_STATE(15881)] = 706457,
  [SMALL_STATE(15882)] = 706480,
  [SMALL_STATE(15883)] = 706503,
  [SMALL_STATE(15884)] = 706524,
  [SMALL_STATE(15885)] = 706547,
  [SMALL_STATE(15886)] = 706570,
  [SMALL_STATE(15887)] = 706593,
  [SMALL_STATE(15888)] = 706614,
  [SMALL_STATE(15889)] = 706637,
  [SMALL_STATE(15890)] = 706660,
  [SMALL_STATE(15891)] = 706683,
  [SMALL_STATE(15892)] = 706706,
  [SMALL_STATE(15893)] = 706729,
  [SMALL_STATE(15894)] = 706750,
  [SMALL_STATE(15895)] = 706773,
  [SMALL_STATE(15896)] = 706796,
  [SMALL_STATE(15897)] = 706819,
  [SMALL_STATE(15898)] = 706840,
  [SMALL_STATE(15899)] = 706863,
  [SMALL_STATE(15900)] = 706886,
  [SMALL_STATE(15901)] = 706909,
  [SMALL_STATE(15902)] = 706932,
  [SMALL_STATE(15903)] = 706953,
  [SMALL_STATE(15904)] = 706976,
  [SMALL_STATE(15905)] = 706997,
  [SMALL_STATE(15906)] = 707020,
  [SMALL_STATE(15907)] = 707041,
  [SMALL_STATE(15908)] = 707064,
  [SMALL_STATE(15909)] = 707087,
  [SMALL_STATE(15910)] = 707110,
  [SMALL_STATE(15911)] = 707130,
  [SMALL_STATE(15912)] = 707150,
  [SMALL_STATE(15913)] = 707170,
  [SMALL_STATE(15914)] = 707190,
  [SMALL_STATE(15915)] = 707210,
  [SMALL_STATE(15916)] = 707230,
  [SMALL_STATE(15917)] = 707250,
  [SMALL_STATE(15918)] = 707270,
  [SMALL_STATE(15919)] = 707290,
  [SMALL_STATE(15920)] = 707306,
  [SMALL_STATE(15921)] = 707322,
  [SMALL_STATE(15922)] = 707342,
  [SMALL_STATE(15923)] = 707362,
  [SMALL_STATE(15924)] = 707382,
  [SMALL_STATE(15925)] = 707402,
  [SMALL_STATE(15926)] = 707422,
  [SMALL_STATE(15927)] = 707442,
  [SMALL_STATE(15928)] = 707462,
  [SMALL_STATE(15929)] = 707482,
  [SMALL_STATE(15930)] = 707502,
  [SMALL_STATE(15931)] = 707522,
  [SMALL_STATE(15932)] = 707542,
  [SMALL_STATE(15933)] = 707562,
  [SMALL_STATE(15934)] = 707582,
  [SMALL_STATE(15935)] = 707602,
  [SMALL_STATE(15936)] = 707622,
  [SMALL_STATE(15937)] = 707640,
  [SMALL_STATE(15938)] = 707660,
  [SMALL_STATE(15939)] = 707678,
  [SMALL_STATE(15940)] = 707698,
  [SMALL_STATE(15941)] = 707718,
  [SMALL_STATE(15942)] = 707738,
  [SMALL_STATE(15943)] = 707758,
  [SMALL_STATE(15944)] = 707778,
  [SMALL_STATE(15945)] = 707798,
  [SMALL_STATE(15946)] = 707818,
  [SMALL_STATE(15947)] = 707838,
  [SMALL_STATE(15948)] = 707858,
  [SMALL_STATE(15949)] = 707878,
  [SMALL_STATE(15950)] = 707898,
  [SMALL_STATE(15951)] = 707918,
  [SMALL_STATE(15952)] = 707938,
  [SMALL_STATE(15953)] = 707958,
  [SMALL_STATE(15954)] = 707978,
  [SMALL_STATE(15955)] = 707998,
  [SMALL_STATE(15956)] = 708018,
  [SMALL_STATE(15957)] = 708038,
  [SMALL_STATE(15958)] = 708058,
  [SMALL_STATE(15959)] = 708078,
  [SMALL_STATE(15960)] = 708098,
  [SMALL_STATE(15961)] = 708118,
  [SMALL_STATE(15962)] = 708136,
  [SMALL_STATE(15963)] = 708156,
  [SMALL_STATE(15964)] = 708176,
  [SMALL_STATE(15965)] = 708196,
  [SMALL_STATE(15966)] = 708216,
  [SMALL_STATE(15967)] = 708236,
  [SMALL_STATE(15968)] = 708256,
  [SMALL_STATE(15969)] = 708274,
  [SMALL_STATE(15970)] = 708294,
  [SMALL_STATE(15971)] = 708314,
  [SMALL_STATE(15972)] = 708334,
  [SMALL_STATE(15973)] = 708354,
  [SMALL_STATE(15974)] = 708374,
  [SMALL_STATE(15975)] = 708394,
  [SMALL_STATE(15976)] = 708414,
  [SMALL_STATE(15977)] = 708434,
  [SMALL_STATE(15978)] = 708454,
  [SMALL_STATE(15979)] = 708474,
  [SMALL_STATE(15980)] = 708494,
  [SMALL_STATE(15981)] = 708514,
  [SMALL_STATE(15982)] = 708534,
  [SMALL_STATE(15983)] = 708554,
  [SMALL_STATE(15984)] = 708574,
  [SMALL_STATE(15985)] = 708594,
  [SMALL_STATE(15986)] = 708614,
  [SMALL_STATE(15987)] = 708634,
  [SMALL_STATE(15988)] = 708654,
  [SMALL_STATE(15989)] = 708674,
  [SMALL_STATE(15990)] = 708694,
  [SMALL_STATE(15991)] = 708714,
  [SMALL_STATE(15992)] = 708734,
  [SMALL_STATE(15993)] = 708754,
  [SMALL_STATE(15994)] = 708774,
  [SMALL_STATE(15995)] = 708794,
  [SMALL_STATE(15996)] = 708814,
  [SMALL_STATE(15997)] = 708834,
  [SMALL_STATE(15998)] = 708852,
  [SMALL_STATE(15999)] = 708872,
  [SMALL_STATE(16000)] = 708892,
  [SMALL_STATE(16001)] = 708912,
  [SMALL_STATE(16002)] = 708932,
  [SMALL_STATE(16003)] = 708952,
  [SMALL_STATE(16004)] = 708972,
  [SMALL_STATE(16005)] = 708992,
  [SMALL_STATE(16006)] = 709012,
  [SMALL_STATE(16007)] = 709032,
  [SMALL_STATE(16008)] = 709052,
  [SMALL_STATE(16009)] = 709072,
  [SMALL_STATE(16010)] = 709092,
  [SMALL_STATE(16011)] = 709112,
  [SMALL_STATE(16012)] = 709132,
  [SMALL_STATE(16013)] = 709152,
  [SMALL_STATE(16014)] = 709170,
  [SMALL_STATE(16015)] = 709190,
  [SMALL_STATE(16016)] = 709210,
  [SMALL_STATE(16017)] = 709230,
  [SMALL_STATE(16018)] = 709250,
  [SMALL_STATE(16019)] = 709270,
  [SMALL_STATE(16020)] = 709290,
  [SMALL_STATE(16021)] = 709310,
  [SMALL_STATE(16022)] = 709330,
  [SMALL_STATE(16023)] = 709348,
  [SMALL_STATE(16024)] = 709368,
  [SMALL_STATE(16025)] = 709388,
  [SMALL_STATE(16026)] = 709408,
  [SMALL_STATE(16027)] = 709428,
  [SMALL_STATE(16028)] = 709448,
  [SMALL_STATE(16029)] = 709468,
  [SMALL_STATE(16030)] = 709488,
  [SMALL_STATE(16031)] = 709508,
  [SMALL_STATE(16032)] = 709528,
  [SMALL_STATE(16033)] = 709548,
  [SMALL_STATE(16034)] = 709568,
  [SMALL_STATE(16035)] = 709588,
  [SMALL_STATE(16036)] = 709608,
  [SMALL_STATE(16037)] = 709628,
  [SMALL_STATE(16038)] = 709648,
  [SMALL_STATE(16039)] = 709668,
  [SMALL_STATE(16040)] = 709688,
  [SMALL_STATE(16041)] = 709708,
  [SMALL_STATE(16042)] = 709728,
  [SMALL_STATE(16043)] = 709746,
  [SMALL_STATE(16044)] = 709766,
  [SMALL_STATE(16045)] = 709786,
  [SMALL_STATE(16046)] = 709806,
  [SMALL_STATE(16047)] = 709826,
  [SMALL_STATE(16048)] = 709846,
  [SMALL_STATE(16049)] = 709866,
  [SMALL_STATE(16050)] = 709886,
  [SMALL_STATE(16051)] = 709904,
  [SMALL_STATE(16052)] = 709924,
  [SMALL_STATE(16053)] = 709944,
  [SMALL_STATE(16054)] = 709964,
  [SMALL_STATE(16055)] = 709984,
  [SMALL_STATE(16056)] = 710004,
  [SMALL_STATE(16057)] = 710024,
  [SMALL_STATE(16058)] = 710044,
  [SMALL_STATE(16059)] = 710064,
  [SMALL_STATE(16060)] = 710084,
  [SMALL_STATE(16061)] = 710104,
  [SMALL_STATE(16062)] = 710124,
  [SMALL_STATE(16063)] = 710144,
  [SMALL_STATE(16064)] = 710164,
  [SMALL_STATE(16065)] = 710184,
  [SMALL_STATE(16066)] = 710204,
  [SMALL_STATE(16067)] = 710224,
  [SMALL_STATE(16068)] = 710244,
  [SMALL_STATE(16069)] = 710264,
  [SMALL_STATE(16070)] = 710284,
  [SMALL_STATE(16071)] = 710304,
  [SMALL_STATE(16072)] = 710324,
  [SMALL_STATE(16073)] = 710344,
  [SMALL_STATE(16074)] = 710364,
  [SMALL_STATE(16075)] = 710384,
  [SMALL_STATE(16076)] = 710404,
  [SMALL_STATE(16077)] = 710424,
  [SMALL_STATE(16078)] = 710442,
  [SMALL_STATE(16079)] = 710462,
  [SMALL_STATE(16080)] = 710482,
  [SMALL_STATE(16081)] = 710502,
  [SMALL_STATE(16082)] = 710522,
  [SMALL_STATE(16083)] = 710542,
  [SMALL_STATE(16084)] = 710562,
  [SMALL_STATE(16085)] = 710582,
  [SMALL_STATE(16086)] = 710602,
  [SMALL_STATE(16087)] = 710622,
  [SMALL_STATE(16088)] = 710642,
  [SMALL_STATE(16089)] = 710662,
  [SMALL_STATE(16090)] = 710682,
  [SMALL_STATE(16091)] = 710702,
  [SMALL_STATE(16092)] = 710720,
  [SMALL_STATE(16093)] = 710740,
  [SMALL_STATE(16094)] = 710760,
  [SMALL_STATE(16095)] = 710780,
  [SMALL_STATE(16096)] = 710800,
  [SMALL_STATE(16097)] = 710820,
  [SMALL_STATE(16098)] = 710840,
  [SMALL_STATE(16099)] = 710860,
  [SMALL_STATE(16100)] = 710880,
  [SMALL_STATE(16101)] = 710898,
  [SMALL_STATE(16102)] = 710918,
  [SMALL_STATE(16103)] = 710938,
  [SMALL_STATE(16104)] = 710958,
  [SMALL_STATE(16105)] = 710978,
  [SMALL_STATE(16106)] = 710998,
  [SMALL_STATE(16107)] = 711018,
  [SMALL_STATE(16108)] = 711038,
  [SMALL_STATE(16109)] = 711058,
  [SMALL_STATE(16110)] = 711078,
  [SMALL_STATE(16111)] = 711098,
  [SMALL_STATE(16112)] = 711118,
  [SMALL_STATE(16113)] = 711136,
  [SMALL_STATE(16114)] = 711156,
  [SMALL_STATE(16115)] = 711172,
  [SMALL_STATE(16116)] = 711192,
  [SMALL_STATE(16117)] = 711212,
  [SMALL_STATE(16118)] = 711232,
  [SMALL_STATE(16119)] = 711252,
  [SMALL_STATE(16120)] = 711272,
  [SMALL_STATE(16121)] = 711292,
  [SMALL_STATE(16122)] = 711312,
  [SMALL_STATE(16123)] = 711332,
  [SMALL_STATE(16124)] = 711352,
  [SMALL_STATE(16125)] = 711372,
  [SMALL_STATE(16126)] = 711392,
  [SMALL_STATE(16127)] = 711412,
  [SMALL_STATE(16128)] = 711432,
  [SMALL_STATE(16129)] = 711452,
  [SMALL_STATE(16130)] = 711472,
  [SMALL_STATE(16131)] = 711492,
  [SMALL_STATE(16132)] = 711512,
  [SMALL_STATE(16133)] = 711532,
  [SMALL_STATE(16134)] = 711552,
  [SMALL_STATE(16135)] = 711572,
  [SMALL_STATE(16136)] = 711592,
  [SMALL_STATE(16137)] = 711612,
  [SMALL_STATE(16138)] = 711630,
  [SMALL_STATE(16139)] = 711650,
  [SMALL_STATE(16140)] = 711670,
  [SMALL_STATE(16141)] = 711690,
  [SMALL_STATE(16142)] = 711710,
  [SMALL_STATE(16143)] = 711730,
  [SMALL_STATE(16144)] = 711750,
  [SMALL_STATE(16145)] = 711770,
  [SMALL_STATE(16146)] = 711790,
  [SMALL_STATE(16147)] = 711810,
  [SMALL_STATE(16148)] = 711830,
  [SMALL_STATE(16149)] = 711850,
  [SMALL_STATE(16150)] = 711870,
  [SMALL_STATE(16151)] = 711890,
  [SMALL_STATE(16152)] = 711910,
  [SMALL_STATE(16153)] = 711930,
  [SMALL_STATE(16154)] = 711950,
  [SMALL_STATE(16155)] = 711970,
  [SMALL_STATE(16156)] = 711990,
  [SMALL_STATE(16157)] = 712010,
  [SMALL_STATE(16158)] = 712028,
  [SMALL_STATE(16159)] = 712048,
  [SMALL_STATE(16160)] = 712066,
  [SMALL_STATE(16161)] = 712086,
  [SMALL_STATE(16162)] = 712106,
  [SMALL_STATE(16163)] = 712126,
  [SMALL_STATE(16164)] = 712146,
  [SMALL_STATE(16165)] = 712166,
  [SMALL_STATE(16166)] = 712186,
  [SMALL_STATE(16167)] = 712206,
  [SMALL_STATE(16168)] = 712226,
  [SMALL_STATE(16169)] = 712246,
  [SMALL_STATE(16170)] = 712266,
  [SMALL_STATE(16171)] = 712286,
  [SMALL_STATE(16172)] = 712306,
  [SMALL_STATE(16173)] = 712326,
  [SMALL_STATE(16174)] = 712346,
  [SMALL_STATE(16175)] = 712366,
  [SMALL_STATE(16176)] = 712386,
  [SMALL_STATE(16177)] = 712406,
  [SMALL_STATE(16178)] = 712426,
  [SMALL_STATE(16179)] = 712446,
  [SMALL_STATE(16180)] = 712466,
  [SMALL_STATE(16181)] = 712486,
  [SMALL_STATE(16182)] = 712506,
  [SMALL_STATE(16183)] = 712526,
  [SMALL_STATE(16184)] = 712546,
  [SMALL_STATE(16185)] = 712566,
  [SMALL_STATE(16186)] = 712586,
  [SMALL_STATE(16187)] = 712606,
  [SMALL_STATE(16188)] = 712626,
  [SMALL_STATE(16189)] = 712646,
  [SMALL_STATE(16190)] = 712666,
  [SMALL_STATE(16191)] = 712686,
  [SMALL_STATE(16192)] = 712704,
  [SMALL_STATE(16193)] = 712724,
  [SMALL_STATE(16194)] = 712744,
  [SMALL_STATE(16195)] = 712764,
  [SMALL_STATE(16196)] = 712784,
  [SMALL_STATE(16197)] = 712804,
  [SMALL_STATE(16198)] = 712824,
  [SMALL_STATE(16199)] = 712844,
  [SMALL_STATE(16200)] = 712864,
  [SMALL_STATE(16201)] = 712884,
  [SMALL_STATE(16202)] = 712904,
  [SMALL_STATE(16203)] = 712924,
  [SMALL_STATE(16204)] = 712944,
  [SMALL_STATE(16205)] = 712964,
  [SMALL_STATE(16206)] = 712984,
  [SMALL_STATE(16207)] = 713004,
  [SMALL_STATE(16208)] = 713024,
  [SMALL_STATE(16209)] = 713044,
  [SMALL_STATE(16210)] = 713064,
  [SMALL_STATE(16211)] = 713084,
  [SMALL_STATE(16212)] = 713102,
  [SMALL_STATE(16213)] = 713122,
  [SMALL_STATE(16214)] = 713142,
  [SMALL_STATE(16215)] = 713162,
  [SMALL_STATE(16216)] = 713182,
  [SMALL_STATE(16217)] = 713202,
  [SMALL_STATE(16218)] = 713222,
  [SMALL_STATE(16219)] = 713240,
  [SMALL_STATE(16220)] = 713258,
  [SMALL_STATE(16221)] = 713278,
  [SMALL_STATE(16222)] = 713298,
  [SMALL_STATE(16223)] = 713318,
  [SMALL_STATE(16224)] = 713336,
  [SMALL_STATE(16225)] = 713356,
  [SMALL_STATE(16226)] = 713376,
  [SMALL_STATE(16227)] = 713396,
  [SMALL_STATE(16228)] = 713416,
  [SMALL_STATE(16229)] = 713436,
  [SMALL_STATE(16230)] = 713452,
  [SMALL_STATE(16231)] = 713472,
  [SMALL_STATE(16232)] = 713492,
  [SMALL_STATE(16233)] = 713512,
  [SMALL_STATE(16234)] = 713532,
  [SMALL_STATE(16235)] = 713552,
  [SMALL_STATE(16236)] = 713570,
  [SMALL_STATE(16237)] = 713588,
  [SMALL_STATE(16238)] = 713608,
  [SMALL_STATE(16239)] = 713628,
  [SMALL_STATE(16240)] = 713646,
  [SMALL_STATE(16241)] = 713666,
  [SMALL_STATE(16242)] = 713686,
  [SMALL_STATE(16243)] = 713706,
  [SMALL_STATE(16244)] = 713726,
  [SMALL_STATE(16245)] = 713746,
  [SMALL_STATE(16246)] = 713766,
  [SMALL_STATE(16247)] = 713786,
  [SMALL_STATE(16248)] = 713806,
  [SMALL_STATE(16249)] = 713826,
  [SMALL_STATE(16250)] = 713846,
  [SMALL_STATE(16251)] = 713864,
  [SMALL_STATE(16252)] = 713884,
  [SMALL_STATE(16253)] = 713904,
  [SMALL_STATE(16254)] = 713924,
  [SMALL_STATE(16255)] = 713944,
  [SMALL_STATE(16256)] = 713964,
  [SMALL_STATE(16257)] = 713984,
  [SMALL_STATE(16258)] = 714004,
  [SMALL_STATE(16259)] = 714024,
  [SMALL_STATE(16260)] = 714044,
  [SMALL_STATE(16261)] = 714064,
  [SMALL_STATE(16262)] = 714084,
  [SMALL_STATE(16263)] = 714104,
  [SMALL_STATE(16264)] = 714120,
  [SMALL_STATE(16265)] = 714138,
  [SMALL_STATE(16266)] = 714158,
  [SMALL_STATE(16267)] = 714178,
  [SMALL_STATE(16268)] = 714198,
  [SMALL_STATE(16269)] = 714218,
  [SMALL_STATE(16270)] = 714238,
  [SMALL_STATE(16271)] = 714258,
  [SMALL_STATE(16272)] = 714276,
  [SMALL_STATE(16273)] = 714296,
  [SMALL_STATE(16274)] = 714316,
  [SMALL_STATE(16275)] = 714336,
  [SMALL_STATE(16276)] = 714356,
  [SMALL_STATE(16277)] = 714376,
  [SMALL_STATE(16278)] = 714396,
  [SMALL_STATE(16279)] = 714416,
  [SMALL_STATE(16280)] = 714436,
  [SMALL_STATE(16281)] = 714456,
  [SMALL_STATE(16282)] = 714476,
  [SMALL_STATE(16283)] = 714496,
  [SMALL_STATE(16284)] = 714516,
  [SMALL_STATE(16285)] = 714536,
  [SMALL_STATE(16286)] = 714556,
  [SMALL_STATE(16287)] = 714576,
  [SMALL_STATE(16288)] = 714596,
  [SMALL_STATE(16289)] = 714616,
  [SMALL_STATE(16290)] = 714636,
  [SMALL_STATE(16291)] = 714656,
  [SMALL_STATE(16292)] = 714676,
  [SMALL_STATE(16293)] = 714696,
  [SMALL_STATE(16294)] = 714714,
  [SMALL_STATE(16295)] = 714734,
  [SMALL_STATE(16296)] = 714754,
  [SMALL_STATE(16297)] = 714774,
  [SMALL_STATE(16298)] = 714794,
  [SMALL_STATE(16299)] = 714814,
  [SMALL_STATE(16300)] = 714832,
  [SMALL_STATE(16301)] = 714848,
  [SMALL_STATE(16302)] = 714868,
  [SMALL_STATE(16303)] = 714888,
  [SMALL_STATE(16304)] = 714908,
  [SMALL_STATE(16305)] = 714928,
  [SMALL_STATE(16306)] = 714948,
  [SMALL_STATE(16307)] = 714966,
  [SMALL_STATE(16308)] = 714986,
  [SMALL_STATE(16309)] = 715006,
  [SMALL_STATE(16310)] = 715026,
  [SMALL_STATE(16311)] = 715046,
  [SMALL_STATE(16312)] = 715066,
  [SMALL_STATE(16313)] = 715086,
  [SMALL_STATE(16314)] = 715106,
  [SMALL_STATE(16315)] = 715126,
  [SMALL_STATE(16316)] = 715142,
  [SMALL_STATE(16317)] = 715162,
  [SMALL_STATE(16318)] = 715182,
  [SMALL_STATE(16319)] = 715202,
  [SMALL_STATE(16320)] = 715222,
  [SMALL_STATE(16321)] = 715242,
  [SMALL_STATE(16322)] = 715262,
  [SMALL_STATE(16323)] = 715282,
  [SMALL_STATE(16324)] = 715302,
  [SMALL_STATE(16325)] = 715322,
  [SMALL_STATE(16326)] = 715340,
  [SMALL_STATE(16327)] = 715358,
  [SMALL_STATE(16328)] = 715378,
  [SMALL_STATE(16329)] = 715398,
  [SMALL_STATE(16330)] = 715418,
  [SMALL_STATE(16331)] = 715438,
  [SMALL_STATE(16332)] = 715458,
  [SMALL_STATE(16333)] = 715478,
  [SMALL_STATE(16334)] = 715498,
  [SMALL_STATE(16335)] = 715518,
  [SMALL_STATE(16336)] = 715538,
  [SMALL_STATE(16337)] = 715558,
  [SMALL_STATE(16338)] = 715578,
  [SMALL_STATE(16339)] = 715598,
  [SMALL_STATE(16340)] = 715618,
  [SMALL_STATE(16341)] = 715638,
  [SMALL_STATE(16342)] = 715658,
  [SMALL_STATE(16343)] = 715676,
  [SMALL_STATE(16344)] = 715696,
  [SMALL_STATE(16345)] = 715716,
  [SMALL_STATE(16346)] = 715736,
  [SMALL_STATE(16347)] = 715756,
  [SMALL_STATE(16348)] = 715776,
  [SMALL_STATE(16349)] = 715796,
  [SMALL_STATE(16350)] = 715816,
  [SMALL_STATE(16351)] = 715836,
  [SMALL_STATE(16352)] = 715856,
  [SMALL_STATE(16353)] = 715876,
  [SMALL_STATE(16354)] = 715896,
  [SMALL_STATE(16355)] = 715916,
  [SMALL_STATE(16356)] = 715936,
  [SMALL_STATE(16357)] = 715956,
  [SMALL_STATE(16358)] = 715976,
  [SMALL_STATE(16359)] = 715996,
  [SMALL_STATE(16360)] = 716014,
  [SMALL_STATE(16361)] = 716034,
  [SMALL_STATE(16362)] = 716054,
  [SMALL_STATE(16363)] = 716074,
  [SMALL_STATE(16364)] = 716094,
  [SMALL_STATE(16365)] = 716114,
  [SMALL_STATE(16366)] = 716134,
  [SMALL_STATE(16367)] = 716154,
  [SMALL_STATE(16368)] = 716174,
  [SMALL_STATE(16369)] = 716194,
  [SMALL_STATE(16370)] = 716214,
  [SMALL_STATE(16371)] = 716234,
  [SMALL_STATE(16372)] = 716254,
  [SMALL_STATE(16373)] = 716274,
  [SMALL_STATE(16374)] = 716294,
  [SMALL_STATE(16375)] = 716314,
  [SMALL_STATE(16376)] = 716334,
  [SMALL_STATE(16377)] = 716354,
  [SMALL_STATE(16378)] = 716374,
  [SMALL_STATE(16379)] = 716392,
  [SMALL_STATE(16380)] = 716412,
  [SMALL_STATE(16381)] = 716430,
  [SMALL_STATE(16382)] = 716450,
  [SMALL_STATE(16383)] = 716470,
  [SMALL_STATE(16384)] = 716490,
  [SMALL_STATE(16385)] = 716510,
  [SMALL_STATE(16386)] = 716530,
  [SMALL_STATE(16387)] = 716550,
  [SMALL_STATE(16388)] = 716570,
  [SMALL_STATE(16389)] = 716590,
  [SMALL_STATE(16390)] = 716610,
  [SMALL_STATE(16391)] = 716630,
  [SMALL_STATE(16392)] = 716650,
  [SMALL_STATE(16393)] = 716670,
  [SMALL_STATE(16394)] = 716690,
  [SMALL_STATE(16395)] = 716708,
  [SMALL_STATE(16396)] = 716728,
  [SMALL_STATE(16397)] = 716748,
  [SMALL_STATE(16398)] = 716768,
  [SMALL_STATE(16399)] = 716788,
  [SMALL_STATE(16400)] = 716808,
  [SMALL_STATE(16401)] = 716828,
  [SMALL_STATE(16402)] = 716846,
  [SMALL_STATE(16403)] = 716866,
  [SMALL_STATE(16404)] = 716886,
  [SMALL_STATE(16405)] = 716906,
  [SMALL_STATE(16406)] = 716926,
  [SMALL_STATE(16407)] = 716946,
  [SMALL_STATE(16408)] = 716966,
  [SMALL_STATE(16409)] = 716986,
  [SMALL_STATE(16410)] = 717006,
  [SMALL_STATE(16411)] = 717024,
  [SMALL_STATE(16412)] = 717044,
  [SMALL_STATE(16413)] = 717064,
  [SMALL_STATE(16414)] = 717084,
  [SMALL_STATE(16415)] = 717104,
  [SMALL_STATE(16416)] = 717124,
  [SMALL_STATE(16417)] = 717144,
  [SMALL_STATE(16418)] = 717164,
  [SMALL_STATE(16419)] = 717182,
  [SMALL_STATE(16420)] = 717202,
  [SMALL_STATE(16421)] = 717222,
  [SMALL_STATE(16422)] = 717242,
  [SMALL_STATE(16423)] = 717262,
  [SMALL_STATE(16424)] = 717282,
  [SMALL_STATE(16425)] = 717302,
  [SMALL_STATE(16426)] = 717322,
  [SMALL_STATE(16427)] = 717342,
  [SMALL_STATE(16428)] = 717360,
  [SMALL_STATE(16429)] = 717380,
  [SMALL_STATE(16430)] = 717400,
  [SMALL_STATE(16431)] = 717420,
  [SMALL_STATE(16432)] = 717440,
  [SMALL_STATE(16433)] = 717458,
  [SMALL_STATE(16434)] = 717478,
  [SMALL_STATE(16435)] = 717498,
  [SMALL_STATE(16436)] = 717518,
  [SMALL_STATE(16437)] = 717538,
  [SMALL_STATE(16438)] = 717558,
  [SMALL_STATE(16439)] = 717578,
  [SMALL_STATE(16440)] = 717596,
  [SMALL_STATE(16441)] = 717616,
  [SMALL_STATE(16442)] = 717636,
  [SMALL_STATE(16443)] = 717656,
  [SMALL_STATE(16444)] = 717676,
  [SMALL_STATE(16445)] = 717694,
  [SMALL_STATE(16446)] = 717714,
  [SMALL_STATE(16447)] = 717734,
  [SMALL_STATE(16448)] = 717754,
  [SMALL_STATE(16449)] = 717774,
  [SMALL_STATE(16450)] = 717794,
  [SMALL_STATE(16451)] = 717814,
  [SMALL_STATE(16452)] = 717834,
  [SMALL_STATE(16453)] = 717854,
  [SMALL_STATE(16454)] = 717874,
  [SMALL_STATE(16455)] = 717894,
  [SMALL_STATE(16456)] = 717912,
  [SMALL_STATE(16457)] = 717932,
  [SMALL_STATE(16458)] = 717952,
  [SMALL_STATE(16459)] = 717972,
  [SMALL_STATE(16460)] = 717990,
  [SMALL_STATE(16461)] = 718010,
  [SMALL_STATE(16462)] = 718028,
  [SMALL_STATE(16463)] = 718048,
  [SMALL_STATE(16464)] = 718066,
  [SMALL_STATE(16465)] = 718084,
  [SMALL_STATE(16466)] = 718104,
  [SMALL_STATE(16467)] = 718124,
  [SMALL_STATE(16468)] = 718142,
  [SMALL_STATE(16469)] = 718162,
  [SMALL_STATE(16470)] = 718182,
  [SMALL_STATE(16471)] = 718202,
  [SMALL_STATE(16472)] = 718222,
  [SMALL_STATE(16473)] = 718242,
  [SMALL_STATE(16474)] = 718260,
  [SMALL_STATE(16475)] = 718280,
  [SMALL_STATE(16476)] = 718298,
  [SMALL_STATE(16477)] = 718318,
  [SMALL_STATE(16478)] = 718338,
  [SMALL_STATE(16479)] = 718358,
  [SMALL_STATE(16480)] = 718376,
  [SMALL_STATE(16481)] = 718396,
  [SMALL_STATE(16482)] = 718416,
  [SMALL_STATE(16483)] = 718436,
  [SMALL_STATE(16484)] = 718456,
  [SMALL_STATE(16485)] = 718476,
  [SMALL_STATE(16486)] = 718496,
  [SMALL_STATE(16487)] = 718514,
  [SMALL_STATE(16488)] = 718534,
  [SMALL_STATE(16489)] = 718554,
  [SMALL_STATE(16490)] = 718574,
  [SMALL_STATE(16491)] = 718594,
  [SMALL_STATE(16492)] = 718614,
  [SMALL_STATE(16493)] = 718634,
  [SMALL_STATE(16494)] = 718652,
  [SMALL_STATE(16495)] = 718672,
  [SMALL_STATE(16496)] = 718690,
  [SMALL_STATE(16497)] = 718710,
  [SMALL_STATE(16498)] = 718730,
  [SMALL_STATE(16499)] = 718750,
  [SMALL_STATE(16500)] = 718770,
  [SMALL_STATE(16501)] = 718786,
  [SMALL_STATE(16502)] = 718806,
  [SMALL_STATE(16503)] = 718824,
  [SMALL_STATE(16504)] = 718842,
  [SMALL_STATE(16505)] = 718862,
  [SMALL_STATE(16506)] = 718882,
  [SMALL_STATE(16507)] = 718900,
  [SMALL_STATE(16508)] = 718920,
  [SMALL_STATE(16509)] = 718940,
  [SMALL_STATE(16510)] = 718960,
  [SMALL_STATE(16511)] = 718980,
  [SMALL_STATE(16512)] = 718998,
  [SMALL_STATE(16513)] = 719016,
  [SMALL_STATE(16514)] = 719036,
  [SMALL_STATE(16515)] = 719056,
  [SMALL_STATE(16516)] = 719076,
  [SMALL_STATE(16517)] = 719094,
  [SMALL_STATE(16518)] = 719114,
  [SMALL_STATE(16519)] = 719134,
  [SMALL_STATE(16520)] = 719154,
  [SMALL_STATE(16521)] = 719174,
  [SMALL_STATE(16522)] = 719192,
  [SMALL_STATE(16523)] = 719212,
  [SMALL_STATE(16524)] = 719232,
  [SMALL_STATE(16525)] = 719252,
  [SMALL_STATE(16526)] = 719272,
  [SMALL_STATE(16527)] = 719292,
  [SMALL_STATE(16528)] = 719310,
  [SMALL_STATE(16529)] = 719330,
  [SMALL_STATE(16530)] = 719350,
  [SMALL_STATE(16531)] = 719370,
  [SMALL_STATE(16532)] = 719390,
  [SMALL_STATE(16533)] = 719410,
  [SMALL_STATE(16534)] = 719430,
  [SMALL_STATE(16535)] = 719448,
  [SMALL_STATE(16536)] = 719468,
  [SMALL_STATE(16537)] = 719488,
  [SMALL_STATE(16538)] = 719508,
  [SMALL_STATE(16539)] = 719528,
  [SMALL_STATE(16540)] = 719546,
  [SMALL_STATE(16541)] = 719564,
  [SMALL_STATE(16542)] = 719584,
  [SMALL_STATE(16543)] = 719604,
  [SMALL_STATE(16544)] = 719624,
  [SMALL_STATE(16545)] = 719644,
  [SMALL_STATE(16546)] = 719662,
  [SMALL_STATE(16547)] = 719680,
  [SMALL_STATE(16548)] = 719700,
  [SMALL_STATE(16549)] = 719718,
  [SMALL_STATE(16550)] = 719738,
  [SMALL_STATE(16551)] = 719758,
  [SMALL_STATE(16552)] = 719778,
  [SMALL_STATE(16553)] = 719798,
  [SMALL_STATE(16554)] = 719818,
  [SMALL_STATE(16555)] = 719838,
  [SMALL_STATE(16556)] = 719858,
  [SMALL_STATE(16557)] = 719878,
  [SMALL_STATE(16558)] = 719896,
  [SMALL_STATE(16559)] = 719916,
  [SMALL_STATE(16560)] = 719936,
  [SMALL_STATE(16561)] = 719956,
  [SMALL_STATE(16562)] = 719976,
  [SMALL_STATE(16563)] = 719996,
  [SMALL_STATE(16564)] = 720016,
  [SMALL_STATE(16565)] = 720036,
  [SMALL_STATE(16566)] = 720056,
  [SMALL_STATE(16567)] = 720076,
  [SMALL_STATE(16568)] = 720096,
  [SMALL_STATE(16569)] = 720116,
  [SMALL_STATE(16570)] = 720134,
  [SMALL_STATE(16571)] = 720154,
  [SMALL_STATE(16572)] = 720174,
  [SMALL_STATE(16573)] = 720192,
  [SMALL_STATE(16574)] = 720212,
  [SMALL_STATE(16575)] = 720232,
  [SMALL_STATE(16576)] = 720252,
  [SMALL_STATE(16577)] = 720272,
  [SMALL_STATE(16578)] = 720292,
  [SMALL_STATE(16579)] = 720312,
  [SMALL_STATE(16580)] = 720330,
  [SMALL_STATE(16581)] = 720350,
  [SMALL_STATE(16582)] = 720370,
  [SMALL_STATE(16583)] = 720390,
  [SMALL_STATE(16584)] = 720410,
  [SMALL_STATE(16585)] = 720430,
  [SMALL_STATE(16586)] = 720450,
  [SMALL_STATE(16587)] = 720468,
  [SMALL_STATE(16588)] = 720488,
  [SMALL_STATE(16589)] = 720508,
  [SMALL_STATE(16590)] = 720528,
  [SMALL_STATE(16591)] = 720546,
  [SMALL_STATE(16592)] = 720566,
  [SMALL_STATE(16593)] = 720584,
  [SMALL_STATE(16594)] = 720604,
  [SMALL_STATE(16595)] = 720624,
  [SMALL_STATE(16596)] = 720644,
  [SMALL_STATE(16597)] = 720662,
  [SMALL_STATE(16598)] = 720682,
  [SMALL_STATE(16599)] = 720702,
  [SMALL_STATE(16600)] = 720722,
  [SMALL_STATE(16601)] = 720740,
  [SMALL_STATE(16602)] = 720760,
  [SMALL_STATE(16603)] = 720780,
  [SMALL_STATE(16604)] = 720798,
  [SMALL_STATE(16605)] = 720818,
  [SMALL_STATE(16606)] = 720836,
  [SMALL_STATE(16607)] = 720856,
  [SMALL_STATE(16608)] = 720876,
  [SMALL_STATE(16609)] = 720894,
  [SMALL_STATE(16610)] = 720914,
  [SMALL_STATE(16611)] = 720932,
  [SMALL_STATE(16612)] = 720952,
  [SMALL_STATE(16613)] = 720970,
  [SMALL_STATE(16614)] = 720990,
  [SMALL_STATE(16615)] = 721010,
  [SMALL_STATE(16616)] = 721028,
  [SMALL_STATE(16617)] = 721048,
  [SMALL_STATE(16618)] = 721068,
  [SMALL_STATE(16619)] = 721086,
  [SMALL_STATE(16620)] = 721106,
  [SMALL_STATE(16621)] = 721126,
  [SMALL_STATE(16622)] = 721144,
  [SMALL_STATE(16623)] = 721164,
  [SMALL_STATE(16624)] = 721182,
  [SMALL_STATE(16625)] = 721202,
  [SMALL_STATE(16626)] = 721222,
  [SMALL_STATE(16627)] = 721240,
  [SMALL_STATE(16628)] = 721260,
  [SMALL_STATE(16629)] = 721278,
  [SMALL_STATE(16630)] = 721298,
  [SMALL_STATE(16631)] = 721318,
  [SMALL_STATE(16632)] = 721338,
  [SMALL_STATE(16633)] = 721356,
  [SMALL_STATE(16634)] = 721376,
  [SMALL_STATE(16635)] = 721394,
  [SMALL_STATE(16636)] = 721414,
  [SMALL_STATE(16637)] = 721432,
  [SMALL_STATE(16638)] = 721452,
  [SMALL_STATE(16639)] = 721470,
  [SMALL_STATE(16640)] = 721490,
  [SMALL_STATE(16641)] = 721508,
  [SMALL_STATE(16642)] = 721528,
  [SMALL_STATE(16643)] = 721546,
  [SMALL_STATE(16644)] = 721566,
  [SMALL_STATE(16645)] = 721584,
  [SMALL_STATE(16646)] = 721604,
  [SMALL_STATE(16647)] = 721622,
  [SMALL_STATE(16648)] = 721642,
  [SMALL_STATE(16649)] = 721660,
  [SMALL_STATE(16650)] = 721680,
  [SMALL_STATE(16651)] = 721698,
  [SMALL_STATE(16652)] = 721718,
  [SMALL_STATE(16653)] = 721736,
  [SMALL_STATE(16654)] = 721756,
  [SMALL_STATE(16655)] = 721774,
  [SMALL_STATE(16656)] = 721794,
  [SMALL_STATE(16657)] = 721812,
  [SMALL_STATE(16658)] = 721832,
  [SMALL_STATE(16659)] = 721850,
  [SMALL_STATE(16660)] = 721870,
  [SMALL_STATE(16661)] = 721888,
  [SMALL_STATE(16662)] = 721908,
  [SMALL_STATE(16663)] = 721926,
  [SMALL_STATE(16664)] = 721946,
  [SMALL_STATE(16665)] = 721964,
  [SMALL_STATE(16666)] = 721984,
  [SMALL_STATE(16667)] = 722002,
  [SMALL_STATE(16668)] = 722022,
  [SMALL_STATE(16669)] = 722040,
  [SMALL_STATE(16670)] = 722060,
  [SMALL_STATE(16671)] = 722078,
  [SMALL_STATE(16672)] = 722098,
  [SMALL_STATE(16673)] = 722116,
  [SMALL_STATE(16674)] = 722136,
  [SMALL_STATE(16675)] = 722156,
  [SMALL_STATE(16676)] = 722176,
  [SMALL_STATE(16677)] = 722196,
  [SMALL_STATE(16678)] = 722216,
  [SMALL_STATE(16679)] = 722236,
  [SMALL_STATE(16680)] = 722254,
  [SMALL_STATE(16681)] = 722274,
  [SMALL_STATE(16682)] = 722292,
  [SMALL_STATE(16683)] = 722312,
  [SMALL_STATE(16684)] = 722332,
  [SMALL_STATE(16685)] = 722352,
  [SMALL_STATE(16686)] = 722372,
  [SMALL_STATE(16687)] = 722392,
  [SMALL_STATE(16688)] = 722412,
  [SMALL_STATE(16689)] = 722432,
  [SMALL_STATE(16690)] = 722450,
  [SMALL_STATE(16691)] = 722468,
  [SMALL_STATE(16692)] = 722488,
  [SMALL_STATE(16693)] = 722508,
  [SMALL_STATE(16694)] = 722526,
  [SMALL_STATE(16695)] = 722546,
  [SMALL_STATE(16696)] = 722566,
  [SMALL_STATE(16697)] = 722586,
  [SMALL_STATE(16698)] = 722606,
  [SMALL_STATE(16699)] = 722626,
  [SMALL_STATE(16700)] = 722646,
  [SMALL_STATE(16701)] = 722666,
  [SMALL_STATE(16702)] = 722686,
  [SMALL_STATE(16703)] = 722706,
  [SMALL_STATE(16704)] = 722726,
  [SMALL_STATE(16705)] = 722744,
  [SMALL_STATE(16706)] = 722764,
  [SMALL_STATE(16707)] = 722784,
  [SMALL_STATE(16708)] = 722804,
  [SMALL_STATE(16709)] = 722824,
  [SMALL_STATE(16710)] = 722844,
  [SMALL_STATE(16711)] = 722864,
  [SMALL_STATE(16712)] = 722884,
  [SMALL_STATE(16713)] = 722904,
  [SMALL_STATE(16714)] = 722924,
  [SMALL_STATE(16715)] = 722944,
  [SMALL_STATE(16716)] = 722964,
  [SMALL_STATE(16717)] = 722984,
  [SMALL_STATE(16718)] = 723004,
  [SMALL_STATE(16719)] = 723024,
  [SMALL_STATE(16720)] = 723044,
  [SMALL_STATE(16721)] = 723064,
  [SMALL_STATE(16722)] = 723082,
  [SMALL_STATE(16723)] = 723102,
  [SMALL_STATE(16724)] = 723122,
  [SMALL_STATE(16725)] = 723142,
  [SMALL_STATE(16726)] = 723162,
  [SMALL_STATE(16727)] = 723182,
  [SMALL_STATE(16728)] = 723202,
  [SMALL_STATE(16729)] = 723222,
  [SMALL_STATE(16730)] = 723242,
  [SMALL_STATE(16731)] = 723262,
  [SMALL_STATE(16732)] = 723282,
  [SMALL_STATE(16733)] = 723302,
  [SMALL_STATE(16734)] = 723320,
  [SMALL_STATE(16735)] = 723340,
  [SMALL_STATE(16736)] = 723360,
  [SMALL_STATE(16737)] = 723380,
  [SMALL_STATE(16738)] = 723400,
  [SMALL_STATE(16739)] = 723420,
  [SMALL_STATE(16740)] = 723438,
  [SMALL_STATE(16741)] = 723458,
  [SMALL_STATE(16742)] = 723478,
  [SMALL_STATE(16743)] = 723496,
  [SMALL_STATE(16744)] = 723514,
  [SMALL_STATE(16745)] = 723534,
  [SMALL_STATE(16746)] = 723554,
  [SMALL_STATE(16747)] = 723574,
  [SMALL_STATE(16748)] = 723594,
  [SMALL_STATE(16749)] = 723614,
  [SMALL_STATE(16750)] = 723632,
  [SMALL_STATE(16751)] = 723652,
  [SMALL_STATE(16752)] = 723672,
  [SMALL_STATE(16753)] = 723692,
  [SMALL_STATE(16754)] = 723712,
  [SMALL_STATE(16755)] = 723732,
  [SMALL_STATE(16756)] = 723752,
  [SMALL_STATE(16757)] = 723770,
  [SMALL_STATE(16758)] = 723790,
  [SMALL_STATE(16759)] = 723810,
  [SMALL_STATE(16760)] = 723830,
  [SMALL_STATE(16761)] = 723850,
  [SMALL_STATE(16762)] = 723868,
  [SMALL_STATE(16763)] = 723888,
  [SMALL_STATE(16764)] = 723908,
  [SMALL_STATE(16765)] = 723928,
  [SMALL_STATE(16766)] = 723948,
  [SMALL_STATE(16767)] = 723968,
  [SMALL_STATE(16768)] = 723988,
  [SMALL_STATE(16769)] = 724006,
  [SMALL_STATE(16770)] = 724026,
  [SMALL_STATE(16771)] = 724046,
  [SMALL_STATE(16772)] = 724066,
  [SMALL_STATE(16773)] = 724086,
  [SMALL_STATE(16774)] = 724104,
  [SMALL_STATE(16775)] = 724124,
  [SMALL_STATE(16776)] = 724144,
  [SMALL_STATE(16777)] = 724164,
  [SMALL_STATE(16778)] = 724184,
  [SMALL_STATE(16779)] = 724204,
  [SMALL_STATE(16780)] = 724224,
  [SMALL_STATE(16781)] = 724244,
  [SMALL_STATE(16782)] = 724264,
  [SMALL_STATE(16783)] = 724284,
  [SMALL_STATE(16784)] = 724302,
  [SMALL_STATE(16785)] = 724320,
  [SMALL_STATE(16786)] = 724340,
  [SMALL_STATE(16787)] = 724360,
  [SMALL_STATE(16788)] = 724380,
  [SMALL_STATE(16789)] = 724400,
  [SMALL_STATE(16790)] = 724420,
  [SMALL_STATE(16791)] = 724440,
  [SMALL_STATE(16792)] = 724460,
  [SMALL_STATE(16793)] = 724478,
  [SMALL_STATE(16794)] = 724498,
  [SMALL_STATE(16795)] = 724518,
  [SMALL_STATE(16796)] = 724538,
  [SMALL_STATE(16797)] = 724558,
  [SMALL_STATE(16798)] = 724578,
  [SMALL_STATE(16799)] = 724598,
  [SMALL_STATE(16800)] = 724618,
  [SMALL_STATE(16801)] = 724638,
  [SMALL_STATE(16802)] = 724658,
  [SMALL_STATE(16803)] = 724678,
  [SMALL_STATE(16804)] = 724696,
  [SMALL_STATE(16805)] = 724716,
  [SMALL_STATE(16806)] = 724736,
  [SMALL_STATE(16807)] = 724756,
  [SMALL_STATE(16808)] = 724776,
  [SMALL_STATE(16809)] = 724796,
  [SMALL_STATE(16810)] = 724816,
  [SMALL_STATE(16811)] = 724836,
  [SMALL_STATE(16812)] = 724856,
  [SMALL_STATE(16813)] = 724874,
  [SMALL_STATE(16814)] = 724892,
  [SMALL_STATE(16815)] = 724912,
  [SMALL_STATE(16816)] = 724932,
  [SMALL_STATE(16817)] = 724952,
  [SMALL_STATE(16818)] = 724972,
  [SMALL_STATE(16819)] = 724992,
  [SMALL_STATE(16820)] = 725012,
  [SMALL_STATE(16821)] = 725030,
  [SMALL_STATE(16822)] = 725050,
  [SMALL_STATE(16823)] = 725068,
  [SMALL_STATE(16824)] = 725088,
  [SMALL_STATE(16825)] = 725108,
  [SMALL_STATE(16826)] = 725126,
  [SMALL_STATE(16827)] = 725146,
  [SMALL_STATE(16828)] = 725166,
  [SMALL_STATE(16829)] = 725186,
  [SMALL_STATE(16830)] = 725204,
  [SMALL_STATE(16831)] = 725224,
  [SMALL_STATE(16832)] = 725244,
  [SMALL_STATE(16833)] = 725264,
  [SMALL_STATE(16834)] = 725282,
  [SMALL_STATE(16835)] = 725302,
  [SMALL_STATE(16836)] = 725322,
  [SMALL_STATE(16837)] = 725342,
  [SMALL_STATE(16838)] = 725362,
  [SMALL_STATE(16839)] = 725380,
  [SMALL_STATE(16840)] = 725400,
  [SMALL_STATE(16841)] = 725420,
  [SMALL_STATE(16842)] = 725438,
  [SMALL_STATE(16843)] = 725458,
  [SMALL_STATE(16844)] = 725476,
  [SMALL_STATE(16845)] = 725496,
  [SMALL_STATE(16846)] = 725516,
  [SMALL_STATE(16847)] = 725536,
  [SMALL_STATE(16848)] = 725556,
  [SMALL_STATE(16849)] = 725576,
  [SMALL_STATE(16850)] = 725594,
  [SMALL_STATE(16851)] = 725614,
  [SMALL_STATE(16852)] = 725634,
  [SMALL_STATE(16853)] = 725654,
  [SMALL_STATE(16854)] = 725674,
  [SMALL_STATE(16855)] = 725694,
  [SMALL_STATE(16856)] = 725712,
  [SMALL_STATE(16857)] = 725732,
  [SMALL_STATE(16858)] = 725752,
  [SMALL_STATE(16859)] = 725772,
  [SMALL_STATE(16860)] = 725792,
  [SMALL_STATE(16861)] = 725812,
  [SMALL_STATE(16862)] = 725832,
  [SMALL_STATE(16863)] = 725850,
  [SMALL_STATE(16864)] = 725870,
  [SMALL_STATE(16865)] = 725890,
  [SMALL_STATE(16866)] = 725910,
  [SMALL_STATE(16867)] = 725930,
  [SMALL_STATE(16868)] = 725948,
  [SMALL_STATE(16869)] = 725968,
  [SMALL_STATE(16870)] = 725988,
  [SMALL_STATE(16871)] = 726008,
  [SMALL_STATE(16872)] = 726026,
  [SMALL_STATE(16873)] = 726046,
  [SMALL_STATE(16874)] = 726066,
  [SMALL_STATE(16875)] = 726086,
  [SMALL_STATE(16876)] = 726106,
  [SMALL_STATE(16877)] = 726126,
  [SMALL_STATE(16878)] = 726146,
  [SMALL_STATE(16879)] = 726164,
  [SMALL_STATE(16880)] = 726184,
  [SMALL_STATE(16881)] = 726204,
  [SMALL_STATE(16882)] = 726224,
  [SMALL_STATE(16883)] = 726244,
  [SMALL_STATE(16884)] = 726264,
  [SMALL_STATE(16885)] = 726282,
  [SMALL_STATE(16886)] = 726302,
  [SMALL_STATE(16887)] = 726322,
  [SMALL_STATE(16888)] = 726342,
  [SMALL_STATE(16889)] = 726362,
  [SMALL_STATE(16890)] = 726382,
  [SMALL_STATE(16891)] = 726402,
  [SMALL_STATE(16892)] = 726422,
  [SMALL_STATE(16893)] = 726440,
  [SMALL_STATE(16894)] = 726460,
  [SMALL_STATE(16895)] = 726476,
  [SMALL_STATE(16896)] = 726496,
  [SMALL_STATE(16897)] = 726516,
  [SMALL_STATE(16898)] = 726534,
  [SMALL_STATE(16899)] = 726554,
  [SMALL_STATE(16900)] = 726574,
  [SMALL_STATE(16901)] = 726594,
  [SMALL_STATE(16902)] = 726614,
  [SMALL_STATE(16903)] = 726634,
  [SMALL_STATE(16904)] = 726654,
  [SMALL_STATE(16905)] = 726674,
  [SMALL_STATE(16906)] = 726692,
  [SMALL_STATE(16907)] = 726712,
  [SMALL_STATE(16908)] = 726732,
  [SMALL_STATE(16909)] = 726752,
  [SMALL_STATE(16910)] = 726772,
  [SMALL_STATE(16911)] = 726792,
  [SMALL_STATE(16912)] = 726810,
  [SMALL_STATE(16913)] = 726830,
  [SMALL_STATE(16914)] = 726850,
  [SMALL_STATE(16915)] = 726870,
  [SMALL_STATE(16916)] = 726890,
  [SMALL_STATE(16917)] = 726910,
  [SMALL_STATE(16918)] = 726928,
  [SMALL_STATE(16919)] = 726948,
  [SMALL_STATE(16920)] = 726968,
  [SMALL_STATE(16921)] = 726988,
  [SMALL_STATE(16922)] = 727008,
  [SMALL_STATE(16923)] = 727028,
  [SMALL_STATE(16924)] = 727046,
  [SMALL_STATE(16925)] = 727066,
  [SMALL_STATE(16926)] = 727084,
  [SMALL_STATE(16927)] = 727104,
  [SMALL_STATE(16928)] = 727124,
  [SMALL_STATE(16929)] = 727144,
  [SMALL_STATE(16930)] = 727164,
  [SMALL_STATE(16931)] = 727182,
  [SMALL_STATE(16932)] = 727202,
  [SMALL_STATE(16933)] = 727222,
  [SMALL_STATE(16934)] = 727242,
  [SMALL_STATE(16935)] = 727262,
  [SMALL_STATE(16936)] = 727282,
  [SMALL_STATE(16937)] = 727302,
  [SMALL_STATE(16938)] = 727320,
  [SMALL_STATE(16939)] = 727340,
  [SMALL_STATE(16940)] = 727360,
  [SMALL_STATE(16941)] = 727380,
  [SMALL_STATE(16942)] = 727400,
  [SMALL_STATE(16943)] = 727420,
  [SMALL_STATE(16944)] = 727438,
  [SMALL_STATE(16945)] = 727458,
  [SMALL_STATE(16946)] = 727478,
  [SMALL_STATE(16947)] = 727498,
  [SMALL_STATE(16948)] = 727518,
  [SMALL_STATE(16949)] = 727538,
  [SMALL_STATE(16950)] = 727558,
  [SMALL_STATE(16951)] = 727578,
  [SMALL_STATE(16952)] = 727598,
  [SMALL_STATE(16953)] = 727616,
  [SMALL_STATE(16954)] = 727636,
  [SMALL_STATE(16955)] = 727656,
  [SMALL_STATE(16956)] = 727676,
  [SMALL_STATE(16957)] = 727696,
  [SMALL_STATE(16958)] = 727716,
  [SMALL_STATE(16959)] = 727736,
  [SMALL_STATE(16960)] = 727756,
  [SMALL_STATE(16961)] = 727774,
  [SMALL_STATE(16962)] = 727794,
  [SMALL_STATE(16963)] = 727814,
  [SMALL_STATE(16964)] = 727832,
  [SMALL_STATE(16965)] = 727852,
  [SMALL_STATE(16966)] = 727872,
  [SMALL_STATE(16967)] = 727892,
  [SMALL_STATE(16968)] = 727912,
  [SMALL_STATE(16969)] = 727930,
  [SMALL_STATE(16970)] = 727948,
  [SMALL_STATE(16971)] = 727968,
  [SMALL_STATE(16972)] = 727988,
  [SMALL_STATE(16973)] = 728008,
  [SMALL_STATE(16974)] = 728028,
  [SMALL_STATE(16975)] = 728046,
  [SMALL_STATE(16976)] = 728066,
  [SMALL_STATE(16977)] = 728086,
  [SMALL_STATE(16978)] = 728106,
  [SMALL_STATE(16979)] = 728126,
  [SMALL_STATE(16980)] = 728144,
  [SMALL_STATE(16981)] = 728164,
  [SMALL_STATE(16982)] = 728184,
  [SMALL_STATE(16983)] = 728204,
  [SMALL_STATE(16984)] = 728224,
  [SMALL_STATE(16985)] = 728244,
  [SMALL_STATE(16986)] = 728262,
  [SMALL_STATE(16987)] = 728282,
  [SMALL_STATE(16988)] = 728302,
  [SMALL_STATE(16989)] = 728322,
  [SMALL_STATE(16990)] = 728342,
  [SMALL_STATE(16991)] = 728360,
  [SMALL_STATE(16992)] = 728380,
  [SMALL_STATE(16993)] = 728400,
  [SMALL_STATE(16994)] = 728420,
  [SMALL_STATE(16995)] = 728440,
  [SMALL_STATE(16996)] = 728460,
  [SMALL_STATE(16997)] = 728480,
  [SMALL_STATE(16998)] = 728500,
  [SMALL_STATE(16999)] = 728520,
  [SMALL_STATE(17000)] = 728538,
  [SMALL_STATE(17001)] = 728558,
  [SMALL_STATE(17002)] = 728578,
  [SMALL_STATE(17003)] = 728598,
  [SMALL_STATE(17004)] = 728618,
  [SMALL_STATE(17005)] = 728638,
  [SMALL_STATE(17006)] = 728656,
  [SMALL_STATE(17007)] = 728676,
  [SMALL_STATE(17008)] = 728696,
  [SMALL_STATE(17009)] = 728716,
  [SMALL_STATE(17010)] = 728734,
  [SMALL_STATE(17011)] = 728754,
  [SMALL_STATE(17012)] = 728774,
  [SMALL_STATE(17013)] = 728794,
  [SMALL_STATE(17014)] = 728814,
  [SMALL_STATE(17015)] = 728832,
  [SMALL_STATE(17016)] = 728852,
  [SMALL_STATE(17017)] = 728872,
  [SMALL_STATE(17018)] = 728892,
  [SMALL_STATE(17019)] = 728912,
  [SMALL_STATE(17020)] = 728932,
  [SMALL_STATE(17021)] = 728952,
  [SMALL_STATE(17022)] = 728970,
  [SMALL_STATE(17023)] = 728990,
  [SMALL_STATE(17024)] = 729010,
  [SMALL_STATE(17025)] = 729030,
  [SMALL_STATE(17026)] = 729050,
  [SMALL_STATE(17027)] = 729070,
  [SMALL_STATE(17028)] = 729088,
  [SMALL_STATE(17029)] = 729108,
  [SMALL_STATE(17030)] = 729128,
  [SMALL_STATE(17031)] = 729148,
  [SMALL_STATE(17032)] = 729168,
  [SMALL_STATE(17033)] = 729188,
  [SMALL_STATE(17034)] = 729206,
  [SMALL_STATE(17035)] = 729226,
  [SMALL_STATE(17036)] = 729244,
  [SMALL_STATE(17037)] = 729264,
  [SMALL_STATE(17038)] = 729284,
  [SMALL_STATE(17039)] = 729302,
  [SMALL_STATE(17040)] = 729322,
  [SMALL_STATE(17041)] = 729342,
  [SMALL_STATE(17042)] = 729362,
  [SMALL_STATE(17043)] = 729382,
  [SMALL_STATE(17044)] = 729402,
  [SMALL_STATE(17045)] = 729422,
  [SMALL_STATE(17046)] = 729442,
  [SMALL_STATE(17047)] = 729460,
  [SMALL_STATE(17048)] = 729478,
  [SMALL_STATE(17049)] = 729498,
  [SMALL_STATE(17050)] = 729516,
  [SMALL_STATE(17051)] = 729536,
  [SMALL_STATE(17052)] = 729556,
  [SMALL_STATE(17053)] = 729574,
  [SMALL_STATE(17054)] = 729594,
  [SMALL_STATE(17055)] = 729612,
  [SMALL_STATE(17056)] = 729630,
  [SMALL_STATE(17057)] = 729650,
  [SMALL_STATE(17058)] = 729668,
  [SMALL_STATE(17059)] = 729686,
  [SMALL_STATE(17060)] = 729706,
  [SMALL_STATE(17061)] = 729726,
  [SMALL_STATE(17062)] = 729744,
  [SMALL_STATE(17063)] = 729764,
  [SMALL_STATE(17064)] = 729782,
  [SMALL_STATE(17065)] = 729802,
  [SMALL_STATE(17066)] = 729820,
  [SMALL_STATE(17067)] = 729840,
  [SMALL_STATE(17068)] = 729858,
  [SMALL_STATE(17069)] = 729878,
  [SMALL_STATE(17070)] = 729896,
  [SMALL_STATE(17071)] = 729916,
  [SMALL_STATE(17072)] = 729934,
  [SMALL_STATE(17073)] = 729954,
  [SMALL_STATE(17074)] = 729972,
  [SMALL_STATE(17075)] = 729992,
  [SMALL_STATE(17076)] = 730010,
  [SMALL_STATE(17077)] = 730030,
  [SMALL_STATE(17078)] = 730048,
  [SMALL_STATE(17079)] = 730068,
  [SMALL_STATE(17080)] = 730086,
  [SMALL_STATE(17081)] = 730106,
  [SMALL_STATE(17082)] = 730124,
  [SMALL_STATE(17083)] = 730144,
  [SMALL_STATE(17084)] = 730162,
  [SMALL_STATE(17085)] = 730182,
  [SMALL_STATE(17086)] = 730200,
  [SMALL_STATE(17087)] = 730218,
  [SMALL_STATE(17088)] = 730236,
  [SMALL_STATE(17089)] = 730254,
  [SMALL_STATE(17090)] = 730272,
  [SMALL_STATE(17091)] = 730290,
  [SMALL_STATE(17092)] = 730308,
  [SMALL_STATE(17093)] = 730326,
  [SMALL_STATE(17094)] = 730344,
  [SMALL_STATE(17095)] = 730362,
  [SMALL_STATE(17096)] = 730380,
  [SMALL_STATE(17097)] = 730398,
  [SMALL_STATE(17098)] = 730416,
  [SMALL_STATE(17099)] = 730434,
  [SMALL_STATE(17100)] = 730452,
  [SMALL_STATE(17101)] = 730470,
  [SMALL_STATE(17102)] = 730488,
  [SMALL_STATE(17103)] = 730506,
  [SMALL_STATE(17104)] = 730524,
  [SMALL_STATE(17105)] = 730542,
  [SMALL_STATE(17106)] = 730560,
  [SMALL_STATE(17107)] = 730578,
  [SMALL_STATE(17108)] = 730596,
  [SMALL_STATE(17109)] = 730614,
  [SMALL_STATE(17110)] = 730634,
  [SMALL_STATE(17111)] = 730652,
  [SMALL_STATE(17112)] = 730672,
  [SMALL_STATE(17113)] = 730692,
  [SMALL_STATE(17114)] = 730712,
  [SMALL_STATE(17115)] = 730732,
  [SMALL_STATE(17116)] = 730752,
  [SMALL_STATE(17117)] = 730772,
  [SMALL_STATE(17118)] = 730792,
  [SMALL_STATE(17119)] = 730812,
  [SMALL_STATE(17120)] = 730832,
  [SMALL_STATE(17121)] = 730852,
  [SMALL_STATE(17122)] = 730872,
  [SMALL_STATE(17123)] = 730892,
  [SMALL_STATE(17124)] = 730912,
  [SMALL_STATE(17125)] = 730932,
  [SMALL_STATE(17126)] = 730952,
  [SMALL_STATE(17127)] = 730972,
  [SMALL_STATE(17128)] = 730992,
  [SMALL_STATE(17129)] = 731008,
  [SMALL_STATE(17130)] = 731028,
  [SMALL_STATE(17131)] = 731048,
  [SMALL_STATE(17132)] = 731068,
  [SMALL_STATE(17133)] = 731088,
  [SMALL_STATE(17134)] = 731108,
  [SMALL_STATE(17135)] = 731128,
  [SMALL_STATE(17136)] = 731148,
  [SMALL_STATE(17137)] = 731168,
  [SMALL_STATE(17138)] = 731188,
  [SMALL_STATE(17139)] = 731208,
  [SMALL_STATE(17140)] = 731228,
  [SMALL_STATE(17141)] = 731248,
  [SMALL_STATE(17142)] = 731268,
  [SMALL_STATE(17143)] = 731288,
  [SMALL_STATE(17144)] = 731308,
  [SMALL_STATE(17145)] = 731326,
  [SMALL_STATE(17146)] = 731346,
  [SMALL_STATE(17147)] = 731366,
  [SMALL_STATE(17148)] = 731384,
  [SMALL_STATE(17149)] = 731404,
  [SMALL_STATE(17150)] = 731422,
  [SMALL_STATE(17151)] = 731440,
  [SMALL_STATE(17152)] = 731460,
  [SMALL_STATE(17153)] = 731480,
  [SMALL_STATE(17154)] = 731500,
  [SMALL_STATE(17155)] = 731520,
  [SMALL_STATE(17156)] = 731540,
  [SMALL_STATE(17157)] = 731560,
  [SMALL_STATE(17158)] = 731576,
  [SMALL_STATE(17159)] = 731596,
  [SMALL_STATE(17160)] = 731616,
  [SMALL_STATE(17161)] = 731636,
  [SMALL_STATE(17162)] = 731654,
  [SMALL_STATE(17163)] = 731674,
  [SMALL_STATE(17164)] = 731692,
  [SMALL_STATE(17165)] = 731712,
  [SMALL_STATE(17166)] = 731730,
  [SMALL_STATE(17167)] = 731750,
  [SMALL_STATE(17168)] = 731770,
  [SMALL_STATE(17169)] = 731790,
  [SMALL_STATE(17170)] = 731808,
  [SMALL_STATE(17171)] = 731828,
  [SMALL_STATE(17172)] = 731848,
  [SMALL_STATE(17173)] = 731868,
  [SMALL_STATE(17174)] = 731888,
  [SMALL_STATE(17175)] = 731908,
  [SMALL_STATE(17176)] = 731928,
  [SMALL_STATE(17177)] = 731948,
  [SMALL_STATE(17178)] = 731968,
  [SMALL_STATE(17179)] = 731988,
  [SMALL_STATE(17180)] = 732008,
  [SMALL_STATE(17181)] = 732028,
  [SMALL_STATE(17182)] = 732048,
  [SMALL_STATE(17183)] = 732066,
  [SMALL_STATE(17184)] = 732086,
  [SMALL_STATE(17185)] = 732106,
  [SMALL_STATE(17186)] = 732126,
  [SMALL_STATE(17187)] = 732146,
  [SMALL_STATE(17188)] = 732166,
  [SMALL_STATE(17189)] = 732186,
  [SMALL_STATE(17190)] = 732204,
  [SMALL_STATE(17191)] = 732221,
  [SMALL_STATE(17192)] = 732238,
  [SMALL_STATE(17193)] = 732253,
  [SMALL_STATE(17194)] = 732270,
  [SMALL_STATE(17195)] = 732287,
  [SMALL_STATE(17196)] = 732302,
  [SMALL_STATE(17197)] = 732319,
  [SMALL_STATE(17198)] = 732336,
  [SMALL_STATE(17199)] = 732351,
  [SMALL_STATE(17200)] = 732368,
  [SMALL_STATE(17201)] = 732385,
  [SMALL_STATE(17202)] = 732402,
  [SMALL_STATE(17203)] = 732419,
  [SMALL_STATE(17204)] = 732434,
  [SMALL_STATE(17205)] = 732451,
  [SMALL_STATE(17206)] = 732468,
  [SMALL_STATE(17207)] = 732485,
  [SMALL_STATE(17208)] = 732502,
  [SMALL_STATE(17209)] = 732519,
  [SMALL_STATE(17210)] = 732536,
  [SMALL_STATE(17211)] = 732553,
  [SMALL_STATE(17212)] = 732570,
  [SMALL_STATE(17213)] = 732587,
  [SMALL_STATE(17214)] = 732602,
  [SMALL_STATE(17215)] = 732619,
  [SMALL_STATE(17216)] = 732636,
  [SMALL_STATE(17217)] = 732653,
  [SMALL_STATE(17218)] = 732668,
  [SMALL_STATE(17219)] = 732685,
  [SMALL_STATE(17220)] = 732702,
  [SMALL_STATE(17221)] = 732719,
  [SMALL_STATE(17222)] = 732736,
  [SMALL_STATE(17223)] = 732753,
  [SMALL_STATE(17224)] = 732770,
  [SMALL_STATE(17225)] = 732787,
  [SMALL_STATE(17226)] = 732804,
  [SMALL_STATE(17227)] = 732819,
  [SMALL_STATE(17228)] = 732836,
  [SMALL_STATE(17229)] = 732853,
  [SMALL_STATE(17230)] = 732870,
  [SMALL_STATE(17231)] = 732887,
  [SMALL_STATE(17232)] = 732904,
  [SMALL_STATE(17233)] = 732921,
  [SMALL_STATE(17234)] = 732938,
  [SMALL_STATE(17235)] = 732955,
  [SMALL_STATE(17236)] = 732972,
  [SMALL_STATE(17237)] = 732989,
  [SMALL_STATE(17238)] = 733006,
  [SMALL_STATE(17239)] = 733023,
  [SMALL_STATE(17240)] = 733040,
  [SMALL_STATE(17241)] = 733055,
  [SMALL_STATE(17242)] = 733072,
  [SMALL_STATE(17243)] = 733089,
  [SMALL_STATE(17244)] = 733106,
  [SMALL_STATE(17245)] = 733123,
  [SMALL_STATE(17246)] = 733138,
  [SMALL_STATE(17247)] = 733155,
  [SMALL_STATE(17248)] = 733172,
  [SMALL_STATE(17249)] = 733189,
  [SMALL_STATE(17250)] = 733206,
  [SMALL_STATE(17251)] = 733223,
  [SMALL_STATE(17252)] = 733240,
  [SMALL_STATE(17253)] = 733257,
  [SMALL_STATE(17254)] = 733274,
  [SMALL_STATE(17255)] = 733291,
  [SMALL_STATE(17256)] = 733306,
  [SMALL_STATE(17257)] = 733323,
  [SMALL_STATE(17258)] = 733340,
  [SMALL_STATE(17259)] = 733355,
  [SMALL_STATE(17260)] = 733370,
  [SMALL_STATE(17261)] = 733387,
  [SMALL_STATE(17262)] = 733404,
  [SMALL_STATE(17263)] = 733421,
  [SMALL_STATE(17264)] = 733438,
  [SMALL_STATE(17265)] = 733455,
  [SMALL_STATE(17266)] = 733472,
  [SMALL_STATE(17267)] = 733487,
  [SMALL_STATE(17268)] = 733504,
  [SMALL_STATE(17269)] = 733521,
  [SMALL_STATE(17270)] = 733538,
  [SMALL_STATE(17271)] = 733555,
  [SMALL_STATE(17272)] = 733572,
  [SMALL_STATE(17273)] = 733589,
  [SMALL_STATE(17274)] = 733606,
  [SMALL_STATE(17275)] = 733623,
  [SMALL_STATE(17276)] = 733640,
  [SMALL_STATE(17277)] = 733657,
  [SMALL_STATE(17278)] = 733674,
  [SMALL_STATE(17279)] = 733691,
  [SMALL_STATE(17280)] = 733708,
  [SMALL_STATE(17281)] = 733725,
  [SMALL_STATE(17282)] = 733742,
  [SMALL_STATE(17283)] = 733759,
  [SMALL_STATE(17284)] = 733774,
  [SMALL_STATE(17285)] = 733789,
  [SMALL_STATE(17286)] = 733806,
  [SMALL_STATE(17287)] = 733823,
  [SMALL_STATE(17288)] = 733840,
  [SMALL_STATE(17289)] = 733857,
  [SMALL_STATE(17290)] = 733874,
  [SMALL_STATE(17291)] = 733889,
  [SMALL_STATE(17292)] = 733904,
  [SMALL_STATE(17293)] = 733921,
  [SMALL_STATE(17294)] = 733938,
  [SMALL_STATE(17295)] = 733955,
  [SMALL_STATE(17296)] = 733972,
  [SMALL_STATE(17297)] = 733989,
  [SMALL_STATE(17298)] = 734006,
  [SMALL_STATE(17299)] = 734023,
  [SMALL_STATE(17300)] = 734040,
  [SMALL_STATE(17301)] = 734057,
  [SMALL_STATE(17302)] = 734074,
  [SMALL_STATE(17303)] = 734091,
  [SMALL_STATE(17304)] = 734108,
  [SMALL_STATE(17305)] = 734125,
  [SMALL_STATE(17306)] = 734142,
  [SMALL_STATE(17307)] = 734159,
  [SMALL_STATE(17308)] = 734174,
  [SMALL_STATE(17309)] = 734191,
  [SMALL_STATE(17310)] = 734208,
  [SMALL_STATE(17311)] = 734225,
  [SMALL_STATE(17312)] = 734240,
  [SMALL_STATE(17313)] = 734257,
  [SMALL_STATE(17314)] = 734274,
  [SMALL_STATE(17315)] = 734291,
  [SMALL_STATE(17316)] = 734308,
  [SMALL_STATE(17317)] = 734325,
  [SMALL_STATE(17318)] = 734342,
  [SMALL_STATE(17319)] = 734359,
  [SMALL_STATE(17320)] = 734376,
  [SMALL_STATE(17321)] = 734393,
  [SMALL_STATE(17322)] = 734410,
  [SMALL_STATE(17323)] = 734427,
  [SMALL_STATE(17324)] = 734444,
  [SMALL_STATE(17325)] = 734461,
  [SMALL_STATE(17326)] = 734478,
  [SMALL_STATE(17327)] = 734495,
  [SMALL_STATE(17328)] = 734512,
  [SMALL_STATE(17329)] = 734529,
  [SMALL_STATE(17330)] = 734546,
  [SMALL_STATE(17331)] = 734563,
  [SMALL_STATE(17332)] = 734580,
  [SMALL_STATE(17333)] = 734597,
  [SMALL_STATE(17334)] = 734614,
  [SMALL_STATE(17335)] = 734631,
  [SMALL_STATE(17336)] = 734646,
  [SMALL_STATE(17337)] = 734661,
  [SMALL_STATE(17338)] = 734678,
  [SMALL_STATE(17339)] = 734695,
  [SMALL_STATE(17340)] = 734712,
  [SMALL_STATE(17341)] = 734729,
  [SMALL_STATE(17342)] = 734746,
  [SMALL_STATE(17343)] = 734763,
  [SMALL_STATE(17344)] = 734780,
  [SMALL_STATE(17345)] = 734797,
  [SMALL_STATE(17346)] = 734814,
  [SMALL_STATE(17347)] = 734831,
  [SMALL_STATE(17348)] = 734848,
  [SMALL_STATE(17349)] = 734865,
  [SMALL_STATE(17350)] = 734882,
  [SMALL_STATE(17351)] = 734899,
  [SMALL_STATE(17352)] = 734916,
  [SMALL_STATE(17353)] = 734931,
  [SMALL_STATE(17354)] = 734948,
  [SMALL_STATE(17355)] = 734965,
  [SMALL_STATE(17356)] = 734982,
  [SMALL_STATE(17357)] = 734999,
  [SMALL_STATE(17358)] = 735014,
  [SMALL_STATE(17359)] = 735031,
  [SMALL_STATE(17360)] = 735046,
  [SMALL_STATE(17361)] = 735063,
  [SMALL_STATE(17362)] = 735080,
  [SMALL_STATE(17363)] = 735097,
  [SMALL_STATE(17364)] = 735114,
  [SMALL_STATE(17365)] = 735131,
  [SMALL_STATE(17366)] = 735148,
  [SMALL_STATE(17367)] = 735163,
  [SMALL_STATE(17368)] = 735180,
  [SMALL_STATE(17369)] = 735197,
  [SMALL_STATE(17370)] = 735214,
  [SMALL_STATE(17371)] = 735231,
  [SMALL_STATE(17372)] = 735248,
  [SMALL_STATE(17373)] = 735265,
  [SMALL_STATE(17374)] = 735280,
  [SMALL_STATE(17375)] = 735297,
  [SMALL_STATE(17376)] = 735314,
  [SMALL_STATE(17377)] = 735331,
  [SMALL_STATE(17378)] = 735348,
  [SMALL_STATE(17379)] = 735365,
  [SMALL_STATE(17380)] = 735382,
  [SMALL_STATE(17381)] = 735399,
  [SMALL_STATE(17382)] = 735416,
  [SMALL_STATE(17383)] = 735433,
  [SMALL_STATE(17384)] = 735450,
  [SMALL_STATE(17385)] = 735467,
  [SMALL_STATE(17386)] = 735484,
  [SMALL_STATE(17387)] = 735501,
  [SMALL_STATE(17388)] = 735518,
  [SMALL_STATE(17389)] = 735535,
  [SMALL_STATE(17390)] = 735552,
  [SMALL_STATE(17391)] = 735569,
  [SMALL_STATE(17392)] = 735586,
  [SMALL_STATE(17393)] = 735603,
  [SMALL_STATE(17394)] = 735620,
  [SMALL_STATE(17395)] = 735637,
  [SMALL_STATE(17396)] = 735654,
  [SMALL_STATE(17397)] = 735671,
  [SMALL_STATE(17398)] = 735688,
  [SMALL_STATE(17399)] = 735705,
  [SMALL_STATE(17400)] = 735722,
  [SMALL_STATE(17401)] = 735739,
  [SMALL_STATE(17402)] = 735756,
  [SMALL_STATE(17403)] = 735773,
  [SMALL_STATE(17404)] = 735790,
  [SMALL_STATE(17405)] = 735805,
  [SMALL_STATE(17406)] = 735822,
  [SMALL_STATE(17407)] = 735837,
  [SMALL_STATE(17408)] = 735854,
  [SMALL_STATE(17409)] = 735871,
  [SMALL_STATE(17410)] = 735888,
  [SMALL_STATE(17411)] = 735905,
  [SMALL_STATE(17412)] = 735922,
  [SMALL_STATE(17413)] = 735937,
  [SMALL_STATE(17414)] = 735954,
  [SMALL_STATE(17415)] = 735971,
  [SMALL_STATE(17416)] = 735988,
  [SMALL_STATE(17417)] = 736005,
  [SMALL_STATE(17418)] = 736022,
  [SMALL_STATE(17419)] = 736037,
  [SMALL_STATE(17420)] = 736054,
  [SMALL_STATE(17421)] = 736071,
  [SMALL_STATE(17422)] = 736088,
  [SMALL_STATE(17423)] = 736105,
  [SMALL_STATE(17424)] = 736122,
  [SMALL_STATE(17425)] = 736137,
  [SMALL_STATE(17426)] = 736154,
  [SMALL_STATE(17427)] = 736171,
  [SMALL_STATE(17428)] = 736188,
  [SMALL_STATE(17429)] = 736205,
  [SMALL_STATE(17430)] = 736222,
  [SMALL_STATE(17431)] = 736239,
  [SMALL_STATE(17432)] = 736256,
  [SMALL_STATE(17433)] = 736273,
  [SMALL_STATE(17434)] = 736290,
  [SMALL_STATE(17435)] = 736307,
  [SMALL_STATE(17436)] = 736324,
  [SMALL_STATE(17437)] = 736341,
  [SMALL_STATE(17438)] = 736358,
  [SMALL_STATE(17439)] = 736375,
  [SMALL_STATE(17440)] = 736392,
  [SMALL_STATE(17441)] = 736409,
  [SMALL_STATE(17442)] = 736426,
  [SMALL_STATE(17443)] = 736441,
  [SMALL_STATE(17444)] = 736458,
  [SMALL_STATE(17445)] = 736475,
  [SMALL_STATE(17446)] = 736492,
  [SMALL_STATE(17447)] = 736509,
  [SMALL_STATE(17448)] = 736524,
  [SMALL_STATE(17449)] = 736541,
  [SMALL_STATE(17450)] = 736558,
  [SMALL_STATE(17451)] = 736575,
  [SMALL_STATE(17452)] = 736592,
  [SMALL_STATE(17453)] = 736609,
  [SMALL_STATE(17454)] = 736626,
  [SMALL_STATE(17455)] = 736643,
  [SMALL_STATE(17456)] = 736658,
  [SMALL_STATE(17457)] = 736675,
  [SMALL_STATE(17458)] = 736692,
  [SMALL_STATE(17459)] = 736709,
  [SMALL_STATE(17460)] = 736726,
  [SMALL_STATE(17461)] = 736743,
  [SMALL_STATE(17462)] = 736760,
  [SMALL_STATE(17463)] = 736777,
  [SMALL_STATE(17464)] = 736794,
  [SMALL_STATE(17465)] = 736809,
  [SMALL_STATE(17466)] = 736826,
  [SMALL_STATE(17467)] = 736841,
  [SMALL_STATE(17468)] = 736858,
  [SMALL_STATE(17469)] = 736875,
  [SMALL_STATE(17470)] = 736890,
  [SMALL_STATE(17471)] = 736907,
  [SMALL_STATE(17472)] = 736924,
  [SMALL_STATE(17473)] = 736941,
  [SMALL_STATE(17474)] = 736958,
  [SMALL_STATE(17475)] = 736975,
  [SMALL_STATE(17476)] = 736992,
  [SMALL_STATE(17477)] = 737009,
  [SMALL_STATE(17478)] = 737026,
  [SMALL_STATE(17479)] = 737043,
  [SMALL_STATE(17480)] = 737060,
  [SMALL_STATE(17481)] = 737077,
  [SMALL_STATE(17482)] = 737092,
  [SMALL_STATE(17483)] = 737109,
  [SMALL_STATE(17484)] = 737126,
  [SMALL_STATE(17485)] = 737143,
  [SMALL_STATE(17486)] = 737160,
  [SMALL_STATE(17487)] = 737177,
  [SMALL_STATE(17488)] = 737194,
  [SMALL_STATE(17489)] = 737211,
  [SMALL_STATE(17490)] = 737228,
  [SMALL_STATE(17491)] = 737245,
  [SMALL_STATE(17492)] = 737262,
  [SMALL_STATE(17493)] = 737279,
  [SMALL_STATE(17494)] = 737296,
  [SMALL_STATE(17495)] = 737313,
  [SMALL_STATE(17496)] = 737330,
  [SMALL_STATE(17497)] = 737347,
  [SMALL_STATE(17498)] = 737364,
  [SMALL_STATE(17499)] = 737381,
  [SMALL_STATE(17500)] = 737398,
  [SMALL_STATE(17501)] = 737415,
  [SMALL_STATE(17502)] = 737432,
  [SMALL_STATE(17503)] = 737449,
  [SMALL_STATE(17504)] = 737466,
  [SMALL_STATE(17505)] = 737483,
  [SMALL_STATE(17506)] = 737500,
  [SMALL_STATE(17507)] = 737517,
  [SMALL_STATE(17508)] = 737534,
  [SMALL_STATE(17509)] = 737551,
  [SMALL_STATE(17510)] = 737568,
  [SMALL_STATE(17511)] = 737585,
  [SMALL_STATE(17512)] = 737600,
  [SMALL_STATE(17513)] = 737617,
  [SMALL_STATE(17514)] = 737634,
  [SMALL_STATE(17515)] = 737651,
  [SMALL_STATE(17516)] = 737668,
  [SMALL_STATE(17517)] = 737685,
  [SMALL_STATE(17518)] = 737702,
  [SMALL_STATE(17519)] = 737719,
  [SMALL_STATE(17520)] = 737736,
  [SMALL_STATE(17521)] = 737753,
  [SMALL_STATE(17522)] = 737770,
  [SMALL_STATE(17523)] = 737787,
  [SMALL_STATE(17524)] = 737804,
  [SMALL_STATE(17525)] = 737821,
  [SMALL_STATE(17526)] = 737838,
  [SMALL_STATE(17527)] = 737855,
  [SMALL_STATE(17528)] = 737872,
  [SMALL_STATE(17529)] = 737889,
  [SMALL_STATE(17530)] = 737906,
  [SMALL_STATE(17531)] = 737923,
  [SMALL_STATE(17532)] = 737940,
  [SMALL_STATE(17533)] = 737957,
  [SMALL_STATE(17534)] = 737972,
  [SMALL_STATE(17535)] = 737989,
  [SMALL_STATE(17536)] = 738006,
  [SMALL_STATE(17537)] = 738023,
  [SMALL_STATE(17538)] = 738040,
  [SMALL_STATE(17539)] = 738055,
  [SMALL_STATE(17540)] = 738072,
  [SMALL_STATE(17541)] = 738089,
  [SMALL_STATE(17542)] = 738106,
  [SMALL_STATE(17543)] = 738123,
  [SMALL_STATE(17544)] = 738138,
  [SMALL_STATE(17545)] = 738155,
  [SMALL_STATE(17546)] = 738172,
  [SMALL_STATE(17547)] = 738189,
  [SMALL_STATE(17548)] = 738206,
  [SMALL_STATE(17549)] = 738223,
  [SMALL_STATE(17550)] = 738240,
  [SMALL_STATE(17551)] = 738257,
  [SMALL_STATE(17552)] = 738274,
  [SMALL_STATE(17553)] = 738291,
  [SMALL_STATE(17554)] = 738308,
  [SMALL_STATE(17555)] = 738325,
  [SMALL_STATE(17556)] = 738342,
  [SMALL_STATE(17557)] = 738357,
  [SMALL_STATE(17558)] = 738374,
  [SMALL_STATE(17559)] = 738391,
  [SMALL_STATE(17560)] = 738406,
  [SMALL_STATE(17561)] = 738423,
  [SMALL_STATE(17562)] = 738440,
  [SMALL_STATE(17563)] = 738457,
  [SMALL_STATE(17564)] = 738474,
  [SMALL_STATE(17565)] = 738491,
  [SMALL_STATE(17566)] = 738508,
  [SMALL_STATE(17567)] = 738525,
  [SMALL_STATE(17568)] = 738542,
  [SMALL_STATE(17569)] = 738559,
  [SMALL_STATE(17570)] = 738576,
  [SMALL_STATE(17571)] = 738593,
  [SMALL_STATE(17572)] = 738610,
  [SMALL_STATE(17573)] = 738625,
  [SMALL_STATE(17574)] = 738642,
  [SMALL_STATE(17575)] = 738659,
  [SMALL_STATE(17576)] = 738676,
  [SMALL_STATE(17577)] = 738693,
  [SMALL_STATE(17578)] = 738708,
  [SMALL_STATE(17579)] = 738725,
  [SMALL_STATE(17580)] = 738742,
  [SMALL_STATE(17581)] = 738759,
  [SMALL_STATE(17582)] = 738776,
  [SMALL_STATE(17583)] = 738791,
  [SMALL_STATE(17584)] = 738808,
  [SMALL_STATE(17585)] = 738825,
  [SMALL_STATE(17586)] = 738842,
  [SMALL_STATE(17587)] = 738859,
  [SMALL_STATE(17588)] = 738876,
  [SMALL_STATE(17589)] = 738891,
  [SMALL_STATE(17590)] = 738908,
  [SMALL_STATE(17591)] = 738925,
  [SMALL_STATE(17592)] = 738942,
  [SMALL_STATE(17593)] = 738957,
  [SMALL_STATE(17594)] = 738974,
  [SMALL_STATE(17595)] = 738991,
  [SMALL_STATE(17596)] = 739008,
  [SMALL_STATE(17597)] = 739025,
  [SMALL_STATE(17598)] = 739042,
  [SMALL_STATE(17599)] = 739059,
  [SMALL_STATE(17600)] = 739076,
  [SMALL_STATE(17601)] = 739093,
  [SMALL_STATE(17602)] = 739108,
  [SMALL_STATE(17603)] = 739125,
  [SMALL_STATE(17604)] = 739142,
  [SMALL_STATE(17605)] = 739159,
  [SMALL_STATE(17606)] = 739176,
  [SMALL_STATE(17607)] = 739191,
  [SMALL_STATE(17608)] = 739208,
  [SMALL_STATE(17609)] = 739225,
  [SMALL_STATE(17610)] = 739242,
  [SMALL_STATE(17611)] = 739259,
  [SMALL_STATE(17612)] = 739276,
  [SMALL_STATE(17613)] = 739293,
  [SMALL_STATE(17614)] = 739310,
  [SMALL_STATE(17615)] = 739327,
  [SMALL_STATE(17616)] = 739344,
  [SMALL_STATE(17617)] = 739361,
  [SMALL_STATE(17618)] = 739376,
  [SMALL_STATE(17619)] = 739391,
  [SMALL_STATE(17620)] = 739408,
  [SMALL_STATE(17621)] = 739425,
  [SMALL_STATE(17622)] = 739440,
  [SMALL_STATE(17623)] = 739457,
  [SMALL_STATE(17624)] = 739474,
  [SMALL_STATE(17625)] = 739491,
  [SMALL_STATE(17626)] = 739508,
  [SMALL_STATE(17627)] = 739525,
  [SMALL_STATE(17628)] = 739542,
  [SMALL_STATE(17629)] = 739559,
  [SMALL_STATE(17630)] = 739574,
  [SMALL_STATE(17631)] = 739589,
  [SMALL_STATE(17632)] = 739606,
  [SMALL_STATE(17633)] = 739623,
  [SMALL_STATE(17634)] = 739640,
  [SMALL_STATE(17635)] = 739657,
  [SMALL_STATE(17636)] = 739674,
  [SMALL_STATE(17637)] = 739691,
  [SMALL_STATE(17638)] = 739708,
  [SMALL_STATE(17639)] = 739725,
  [SMALL_STATE(17640)] = 739742,
  [SMALL_STATE(17641)] = 739757,
  [SMALL_STATE(17642)] = 739772,
  [SMALL_STATE(17643)] = 739789,
  [SMALL_STATE(17644)] = 739806,
  [SMALL_STATE(17645)] = 739823,
  [SMALL_STATE(17646)] = 739840,
  [SMALL_STATE(17647)] = 739857,
  [SMALL_STATE(17648)] = 739874,
  [SMALL_STATE(17649)] = 739891,
  [SMALL_STATE(17650)] = 739908,
  [SMALL_STATE(17651)] = 739925,
  [SMALL_STATE(17652)] = 739940,
  [SMALL_STATE(17653)] = 739957,
  [SMALL_STATE(17654)] = 739974,
  [SMALL_STATE(17655)] = 739991,
  [SMALL_STATE(17656)] = 740008,
  [SMALL_STATE(17657)] = 740025,
  [SMALL_STATE(17658)] = 740042,
  [SMALL_STATE(17659)] = 740059,
  [SMALL_STATE(17660)] = 740076,
  [SMALL_STATE(17661)] = 740093,
  [SMALL_STATE(17662)] = 740110,
  [SMALL_STATE(17663)] = 740127,
  [SMALL_STATE(17664)] = 740144,
  [SMALL_STATE(17665)] = 740161,
  [SMALL_STATE(17666)] = 740178,
  [SMALL_STATE(17667)] = 740195,
  [SMALL_STATE(17668)] = 740212,
  [SMALL_STATE(17669)] = 740229,
  [SMALL_STATE(17670)] = 740246,
  [SMALL_STATE(17671)] = 740263,
  [SMALL_STATE(17672)] = 740280,
  [SMALL_STATE(17673)] = 740297,
  [SMALL_STATE(17674)] = 740314,
  [SMALL_STATE(17675)] = 740331,
  [SMALL_STATE(17676)] = 740348,
  [SMALL_STATE(17677)] = 740365,
  [SMALL_STATE(17678)] = 740382,
  [SMALL_STATE(17679)] = 740399,
  [SMALL_STATE(17680)] = 740416,
  [SMALL_STATE(17681)] = 740433,
  [SMALL_STATE(17682)] = 740450,
  [SMALL_STATE(17683)] = 740467,
  [SMALL_STATE(17684)] = 740484,
  [SMALL_STATE(17685)] = 740501,
  [SMALL_STATE(17686)] = 740518,
  [SMALL_STATE(17687)] = 740535,
  [SMALL_STATE(17688)] = 740552,
  [SMALL_STATE(17689)] = 740569,
  [SMALL_STATE(17690)] = 740586,
  [SMALL_STATE(17691)] = 740603,
  [SMALL_STATE(17692)] = 740620,
  [SMALL_STATE(17693)] = 740637,
  [SMALL_STATE(17694)] = 740654,
  [SMALL_STATE(17695)] = 740671,
  [SMALL_STATE(17696)] = 740688,
  [SMALL_STATE(17697)] = 740703,
  [SMALL_STATE(17698)] = 740720,
  [SMALL_STATE(17699)] = 740737,
  [SMALL_STATE(17700)] = 740754,
  [SMALL_STATE(17701)] = 740771,
  [SMALL_STATE(17702)] = 740788,
  [SMALL_STATE(17703)] = 740805,
  [SMALL_STATE(17704)] = 740822,
  [SMALL_STATE(17705)] = 740837,
  [SMALL_STATE(17706)] = 740854,
  [SMALL_STATE(17707)] = 740871,
  [SMALL_STATE(17708)] = 740888,
  [SMALL_STATE(17709)] = 740905,
  [SMALL_STATE(17710)] = 740922,
  [SMALL_STATE(17711)] = 740939,
  [SMALL_STATE(17712)] = 740956,
  [SMALL_STATE(17713)] = 740971,
  [SMALL_STATE(17714)] = 740988,
  [SMALL_STATE(17715)] = 741003,
  [SMALL_STATE(17716)] = 741020,
  [SMALL_STATE(17717)] = 741037,
  [SMALL_STATE(17718)] = 741054,
  [SMALL_STATE(17719)] = 741071,
  [SMALL_STATE(17720)] = 741086,
  [SMALL_STATE(17721)] = 741103,
  [SMALL_STATE(17722)] = 741120,
  [SMALL_STATE(17723)] = 741137,
  [SMALL_STATE(17724)] = 741154,
  [SMALL_STATE(17725)] = 741171,
  [SMALL_STATE(17726)] = 741188,
  [SMALL_STATE(17727)] = 741203,
  [SMALL_STATE(17728)] = 741220,
  [SMALL_STATE(17729)] = 741237,
  [SMALL_STATE(17730)] = 741254,
  [SMALL_STATE(17731)] = 741269,
  [SMALL_STATE(17732)] = 741284,
  [SMALL_STATE(17733)] = 741301,
  [SMALL_STATE(17734)] = 741318,
  [SMALL_STATE(17735)] = 741333,
  [SMALL_STATE(17736)] = 741350,
  [SMALL_STATE(17737)] = 741367,
  [SMALL_STATE(17738)] = 741384,
  [SMALL_STATE(17739)] = 741401,
  [SMALL_STATE(17740)] = 741418,
  [SMALL_STATE(17741)] = 741435,
  [SMALL_STATE(17742)] = 741450,
  [SMALL_STATE(17743)] = 741467,
  [SMALL_STATE(17744)] = 741484,
  [SMALL_STATE(17745)] = 741501,
  [SMALL_STATE(17746)] = 741518,
  [SMALL_STATE(17747)] = 741535,
  [SMALL_STATE(17748)] = 741552,
  [SMALL_STATE(17749)] = 741569,
  [SMALL_STATE(17750)] = 741586,
  [SMALL_STATE(17751)] = 741603,
  [SMALL_STATE(17752)] = 741620,
  [SMALL_STATE(17753)] = 741637,
  [SMALL_STATE(17754)] = 741654,
  [SMALL_STATE(17755)] = 741671,
  [SMALL_STATE(17756)] = 741688,
  [SMALL_STATE(17757)] = 741705,
  [SMALL_STATE(17758)] = 741722,
  [SMALL_STATE(17759)] = 741739,
  [SMALL_STATE(17760)] = 741756,
  [SMALL_STATE(17761)] = 741773,
  [SMALL_STATE(17762)] = 741790,
  [SMALL_STATE(17763)] = 741807,
  [SMALL_STATE(17764)] = 741824,
  [SMALL_STATE(17765)] = 741841,
  [SMALL_STATE(17766)] = 741858,
  [SMALL_STATE(17767)] = 741875,
  [SMALL_STATE(17768)] = 741892,
  [SMALL_STATE(17769)] = 741909,
  [SMALL_STATE(17770)] = 741926,
  [SMALL_STATE(17771)] = 741943,
  [SMALL_STATE(17772)] = 741960,
  [SMALL_STATE(17773)] = 741977,
  [SMALL_STATE(17774)] = 741994,
  [SMALL_STATE(17775)] = 742011,
  [SMALL_STATE(17776)] = 742028,
  [SMALL_STATE(17777)] = 742045,
  [SMALL_STATE(17778)] = 742062,
  [SMALL_STATE(17779)] = 742079,
  [SMALL_STATE(17780)] = 742096,
  [SMALL_STATE(17781)] = 742113,
  [SMALL_STATE(17782)] = 742130,
  [SMALL_STATE(17783)] = 742147,
  [SMALL_STATE(17784)] = 742164,
  [SMALL_STATE(17785)] = 742181,
  [SMALL_STATE(17786)] = 742198,
  [SMALL_STATE(17787)] = 742215,
  [SMALL_STATE(17788)] = 742232,
  [SMALL_STATE(17789)] = 742249,
  [SMALL_STATE(17790)] = 742266,
  [SMALL_STATE(17791)] = 742283,
  [SMALL_STATE(17792)] = 742300,
  [SMALL_STATE(17793)] = 742317,
  [SMALL_STATE(17794)] = 742334,
  [SMALL_STATE(17795)] = 742351,
  [SMALL_STATE(17796)] = 742368,
  [SMALL_STATE(17797)] = 742385,
  [SMALL_STATE(17798)] = 742402,
  [SMALL_STATE(17799)] = 742419,
  [SMALL_STATE(17800)] = 742436,
  [SMALL_STATE(17801)] = 742453,
  [SMALL_STATE(17802)] = 742470,
  [SMALL_STATE(17803)] = 742487,
  [SMALL_STATE(17804)] = 742504,
  [SMALL_STATE(17805)] = 742521,
  [SMALL_STATE(17806)] = 742538,
  [SMALL_STATE(17807)] = 742555,
  [SMALL_STATE(17808)] = 742572,
  [SMALL_STATE(17809)] = 742589,
  [SMALL_STATE(17810)] = 742606,
  [SMALL_STATE(17811)] = 742623,
  [SMALL_STATE(17812)] = 742640,
  [SMALL_STATE(17813)] = 742657,
  [SMALL_STATE(17814)] = 742674,
  [SMALL_STATE(17815)] = 742691,
  [SMALL_STATE(17816)] = 742708,
  [SMALL_STATE(17817)] = 742725,
  [SMALL_STATE(17818)] = 742742,
  [SMALL_STATE(17819)] = 742759,
  [SMALL_STATE(17820)] = 742776,
  [SMALL_STATE(17821)] = 742793,
  [SMALL_STATE(17822)] = 742810,
  [SMALL_STATE(17823)] = 742827,
  [SMALL_STATE(17824)] = 742844,
  [SMALL_STATE(17825)] = 742861,
  [SMALL_STATE(17826)] = 742878,
  [SMALL_STATE(17827)] = 742895,
  [SMALL_STATE(17828)] = 742910,
  [SMALL_STATE(17829)] = 742925,
  [SMALL_STATE(17830)] = 742942,
  [SMALL_STATE(17831)] = 742959,
  [SMALL_STATE(17832)] = 742976,
  [SMALL_STATE(17833)] = 742993,
  [SMALL_STATE(17834)] = 743010,
  [SMALL_STATE(17835)] = 743027,
  [SMALL_STATE(17836)] = 743044,
  [SMALL_STATE(17837)] = 743059,
  [SMALL_STATE(17838)] = 743076,
  [SMALL_STATE(17839)] = 743093,
  [SMALL_STATE(17840)] = 743110,
  [SMALL_STATE(17841)] = 743127,
  [SMALL_STATE(17842)] = 743144,
  [SMALL_STATE(17843)] = 743161,
  [SMALL_STATE(17844)] = 743176,
  [SMALL_STATE(17845)] = 743193,
  [SMALL_STATE(17846)] = 743208,
  [SMALL_STATE(17847)] = 743225,
  [SMALL_STATE(17848)] = 743242,
  [SMALL_STATE(17849)] = 743259,
  [SMALL_STATE(17850)] = 743276,
  [SMALL_STATE(17851)] = 743293,
  [SMALL_STATE(17852)] = 743310,
  [SMALL_STATE(17853)] = 743327,
  [SMALL_STATE(17854)] = 743344,
  [SMALL_STATE(17855)] = 743361,
  [SMALL_STATE(17856)] = 743378,
  [SMALL_STATE(17857)] = 743395,
  [SMALL_STATE(17858)] = 743412,
  [SMALL_STATE(17859)] = 743429,
  [SMALL_STATE(17860)] = 743446,
  [SMALL_STATE(17861)] = 743463,
  [SMALL_STATE(17862)] = 743480,
  [SMALL_STATE(17863)] = 743497,
  [SMALL_STATE(17864)] = 743514,
  [SMALL_STATE(17865)] = 743529,
  [SMALL_STATE(17866)] = 743546,
  [SMALL_STATE(17867)] = 743563,
  [SMALL_STATE(17868)] = 743578,
  [SMALL_STATE(17869)] = 743595,
  [SMALL_STATE(17870)] = 743612,
  [SMALL_STATE(17871)] = 743629,
  [SMALL_STATE(17872)] = 743646,
  [SMALL_STATE(17873)] = 743663,
  [SMALL_STATE(17874)] = 743680,
  [SMALL_STATE(17875)] = 743697,
  [SMALL_STATE(17876)] = 743714,
  [SMALL_STATE(17877)] = 743731,
  [SMALL_STATE(17878)] = 743748,
  [SMALL_STATE(17879)] = 743765,
  [SMALL_STATE(17880)] = 743782,
  [SMALL_STATE(17881)] = 743799,
  [SMALL_STATE(17882)] = 743816,
  [SMALL_STATE(17883)] = 743833,
  [SMALL_STATE(17884)] = 743850,
  [SMALL_STATE(17885)] = 743867,
  [SMALL_STATE(17886)] = 743884,
  [SMALL_STATE(17887)] = 743901,
  [SMALL_STATE(17888)] = 743918,
  [SMALL_STATE(17889)] = 743935,
  [SMALL_STATE(17890)] = 743952,
  [SMALL_STATE(17891)] = 743969,
  [SMALL_STATE(17892)] = 743986,
  [SMALL_STATE(17893)] = 744003,
  [SMALL_STATE(17894)] = 744020,
  [SMALL_STATE(17895)] = 744037,
  [SMALL_STATE(17896)] = 744054,
  [SMALL_STATE(17897)] = 744071,
  [SMALL_STATE(17898)] = 744088,
  [SMALL_STATE(17899)] = 744105,
  [SMALL_STATE(17900)] = 744122,
  [SMALL_STATE(17901)] = 744139,
  [SMALL_STATE(17902)] = 744156,
  [SMALL_STATE(17903)] = 744173,
  [SMALL_STATE(17904)] = 744190,
  [SMALL_STATE(17905)] = 744207,
  [SMALL_STATE(17906)] = 744224,
  [SMALL_STATE(17907)] = 744241,
  [SMALL_STATE(17908)] = 744258,
  [SMALL_STATE(17909)] = 744275,
  [SMALL_STATE(17910)] = 744292,
  [SMALL_STATE(17911)] = 744309,
  [SMALL_STATE(17912)] = 744326,
  [SMALL_STATE(17913)] = 744343,
  [SMALL_STATE(17914)] = 744360,
  [SMALL_STATE(17915)] = 744377,
  [SMALL_STATE(17916)] = 744392,
  [SMALL_STATE(17917)] = 744407,
  [SMALL_STATE(17918)] = 744424,
  [SMALL_STATE(17919)] = 744441,
  [SMALL_STATE(17920)] = 744458,
  [SMALL_STATE(17921)] = 744475,
  [SMALL_STATE(17922)] = 744492,
  [SMALL_STATE(17923)] = 744509,
  [SMALL_STATE(17924)] = 744524,
  [SMALL_STATE(17925)] = 744541,
  [SMALL_STATE(17926)] = 744558,
  [SMALL_STATE(17927)] = 744575,
  [SMALL_STATE(17928)] = 744592,
  [SMALL_STATE(17929)] = 744609,
  [SMALL_STATE(17930)] = 744626,
  [SMALL_STATE(17931)] = 744643,
  [SMALL_STATE(17932)] = 744658,
  [SMALL_STATE(17933)] = 744675,
  [SMALL_STATE(17934)] = 744692,
  [SMALL_STATE(17935)] = 744709,
  [SMALL_STATE(17936)] = 744726,
  [SMALL_STATE(17937)] = 744743,
  [SMALL_STATE(17938)] = 744760,
  [SMALL_STATE(17939)] = 744777,
  [SMALL_STATE(17940)] = 744792,
  [SMALL_STATE(17941)] = 744809,
  [SMALL_STATE(17942)] = 744826,
  [SMALL_STATE(17943)] = 744843,
  [SMALL_STATE(17944)] = 744860,
  [SMALL_STATE(17945)] = 744875,
  [SMALL_STATE(17946)] = 744892,
  [SMALL_STATE(17947)] = 744909,
  [SMALL_STATE(17948)] = 744926,
  [SMALL_STATE(17949)] = 744943,
  [SMALL_STATE(17950)] = 744960,
  [SMALL_STATE(17951)] = 744977,
  [SMALL_STATE(17952)] = 744994,
  [SMALL_STATE(17953)] = 745011,
  [SMALL_STATE(17954)] = 745028,
  [SMALL_STATE(17955)] = 745045,
  [SMALL_STATE(17956)] = 745062,
  [SMALL_STATE(17957)] = 745079,
  [SMALL_STATE(17958)] = 745096,
  [SMALL_STATE(17959)] = 745113,
  [SMALL_STATE(17960)] = 745130,
  [SMALL_STATE(17961)] = 745147,
  [SMALL_STATE(17962)] = 745164,
  [SMALL_STATE(17963)] = 745181,
  [SMALL_STATE(17964)] = 745196,
  [SMALL_STATE(17965)] = 745213,
  [SMALL_STATE(17966)] = 745230,
  [SMALL_STATE(17967)] = 745247,
  [SMALL_STATE(17968)] = 745264,
  [SMALL_STATE(17969)] = 745281,
  [SMALL_STATE(17970)] = 745298,
  [SMALL_STATE(17971)] = 745315,
  [SMALL_STATE(17972)] = 745332,
  [SMALL_STATE(17973)] = 745349,
  [SMALL_STATE(17974)] = 745366,
  [SMALL_STATE(17975)] = 745381,
  [SMALL_STATE(17976)] = 745398,
  [SMALL_STATE(17977)] = 745415,
  [SMALL_STATE(17978)] = 745432,
  [SMALL_STATE(17979)] = 745449,
  [SMALL_STATE(17980)] = 745466,
  [SMALL_STATE(17981)] = 745483,
  [SMALL_STATE(17982)] = 745500,
  [SMALL_STATE(17983)] = 745517,
  [SMALL_STATE(17984)] = 745534,
  [SMALL_STATE(17985)] = 745551,
  [SMALL_STATE(17986)] = 745568,
  [SMALL_STATE(17987)] = 745585,
  [SMALL_STATE(17988)] = 745602,
  [SMALL_STATE(17989)] = 745619,
  [SMALL_STATE(17990)] = 745636,
  [SMALL_STATE(17991)] = 745653,
  [SMALL_STATE(17992)] = 745670,
  [SMALL_STATE(17993)] = 745687,
  [SMALL_STATE(17994)] = 745704,
  [SMALL_STATE(17995)] = 745721,
  [SMALL_STATE(17996)] = 745738,
  [SMALL_STATE(17997)] = 745755,
  [SMALL_STATE(17998)] = 745772,
  [SMALL_STATE(17999)] = 745789,
  [SMALL_STATE(18000)] = 745806,
  [SMALL_STATE(18001)] = 745823,
  [SMALL_STATE(18002)] = 745840,
  [SMALL_STATE(18003)] = 745857,
  [SMALL_STATE(18004)] = 745874,
  [SMALL_STATE(18005)] = 745891,
  [SMALL_STATE(18006)] = 745908,
  [SMALL_STATE(18007)] = 745925,
  [SMALL_STATE(18008)] = 745942,
  [SMALL_STATE(18009)] = 745959,
  [SMALL_STATE(18010)] = 745976,
  [SMALL_STATE(18011)] = 745993,
  [SMALL_STATE(18012)] = 746010,
  [SMALL_STATE(18013)] = 746027,
  [SMALL_STATE(18014)] = 746044,
  [SMALL_STATE(18015)] = 746059,
  [SMALL_STATE(18016)] = 746076,
  [SMALL_STATE(18017)] = 746093,
  [SMALL_STATE(18018)] = 746110,
  [SMALL_STATE(18019)] = 746127,
  [SMALL_STATE(18020)] = 746144,
  [SMALL_STATE(18021)] = 746161,
  [SMALL_STATE(18022)] = 746178,
  [SMALL_STATE(18023)] = 746195,
  [SMALL_STATE(18024)] = 746212,
  [SMALL_STATE(18025)] = 746229,
  [SMALL_STATE(18026)] = 746246,
  [SMALL_STATE(18027)] = 746263,
  [SMALL_STATE(18028)] = 746280,
  [SMALL_STATE(18029)] = 746297,
  [SMALL_STATE(18030)] = 746314,
  [SMALL_STATE(18031)] = 746331,
  [SMALL_STATE(18032)] = 746348,
  [SMALL_STATE(18033)] = 746365,
  [SMALL_STATE(18034)] = 746382,
  [SMALL_STATE(18035)] = 746399,
  [SMALL_STATE(18036)] = 746416,
  [SMALL_STATE(18037)] = 746433,
  [SMALL_STATE(18038)] = 746450,
  [SMALL_STATE(18039)] = 746467,
  [SMALL_STATE(18040)] = 746484,
  [SMALL_STATE(18041)] = 746501,
  [SMALL_STATE(18042)] = 746518,
  [SMALL_STATE(18043)] = 746535,
  [SMALL_STATE(18044)] = 746552,
  [SMALL_STATE(18045)] = 746569,
  [SMALL_STATE(18046)] = 746586,
  [SMALL_STATE(18047)] = 746603,
  [SMALL_STATE(18048)] = 746620,
  [SMALL_STATE(18049)] = 746637,
  [SMALL_STATE(18050)] = 746654,
  [SMALL_STATE(18051)] = 746671,
  [SMALL_STATE(18052)] = 746688,
  [SMALL_STATE(18053)] = 746705,
  [SMALL_STATE(18054)] = 746722,
  [SMALL_STATE(18055)] = 746739,
  [SMALL_STATE(18056)] = 746756,
  [SMALL_STATE(18057)] = 746773,
  [SMALL_STATE(18058)] = 746790,
  [SMALL_STATE(18059)] = 746807,
  [SMALL_STATE(18060)] = 746824,
  [SMALL_STATE(18061)] = 746841,
  [SMALL_STATE(18062)] = 746858,
  [SMALL_STATE(18063)] = 746875,
  [SMALL_STATE(18064)] = 746892,
  [SMALL_STATE(18065)] = 746909,
  [SMALL_STATE(18066)] = 746926,
  [SMALL_STATE(18067)] = 746943,
  [SMALL_STATE(18068)] = 746960,
  [SMALL_STATE(18069)] = 746977,
  [SMALL_STATE(18070)] = 746994,
  [SMALL_STATE(18071)] = 747011,
  [SMALL_STATE(18072)] = 747028,
  [SMALL_STATE(18073)] = 747045,
  [SMALL_STATE(18074)] = 747062,
  [SMALL_STATE(18075)] = 747079,
  [SMALL_STATE(18076)] = 747096,
  [SMALL_STATE(18077)] = 747111,
  [SMALL_STATE(18078)] = 747128,
  [SMALL_STATE(18079)] = 747145,
  [SMALL_STATE(18080)] = 747162,
  [SMALL_STATE(18081)] = 747179,
  [SMALL_STATE(18082)] = 747196,
  [SMALL_STATE(18083)] = 747213,
  [SMALL_STATE(18084)] = 747230,
  [SMALL_STATE(18085)] = 747247,
  [SMALL_STATE(18086)] = 747264,
  [SMALL_STATE(18087)] = 747281,
  [SMALL_STATE(18088)] = 747298,
  [SMALL_STATE(18089)] = 747313,
  [SMALL_STATE(18090)] = 747330,
  [SMALL_STATE(18091)] = 747347,
  [SMALL_STATE(18092)] = 747364,
  [SMALL_STATE(18093)] = 747381,
  [SMALL_STATE(18094)] = 747398,
  [SMALL_STATE(18095)] = 747415,
  [SMALL_STATE(18096)] = 747432,
  [SMALL_STATE(18097)] = 747449,
  [SMALL_STATE(18098)] = 747466,
  [SMALL_STATE(18099)] = 747483,
  [SMALL_STATE(18100)] = 747498,
  [SMALL_STATE(18101)] = 747515,
  [SMALL_STATE(18102)] = 747532,
  [SMALL_STATE(18103)] = 747549,
  [SMALL_STATE(18104)] = 747566,
  [SMALL_STATE(18105)] = 747583,
  [SMALL_STATE(18106)] = 747600,
  [SMALL_STATE(18107)] = 747617,
  [SMALL_STATE(18108)] = 747634,
  [SMALL_STATE(18109)] = 747651,
  [SMALL_STATE(18110)] = 747666,
  [SMALL_STATE(18111)] = 747683,
  [SMALL_STATE(18112)] = 747700,
  [SMALL_STATE(18113)] = 747717,
  [SMALL_STATE(18114)] = 747734,
  [SMALL_STATE(18115)] = 747751,
  [SMALL_STATE(18116)] = 747768,
  [SMALL_STATE(18117)] = 747785,
  [SMALL_STATE(18118)] = 747802,
  [SMALL_STATE(18119)] = 747819,
  [SMALL_STATE(18120)] = 747834,
  [SMALL_STATE(18121)] = 747851,
  [SMALL_STATE(18122)] = 747866,
  [SMALL_STATE(18123)] = 747883,
  [SMALL_STATE(18124)] = 747900,
  [SMALL_STATE(18125)] = 747917,
  [SMALL_STATE(18126)] = 747934,
  [SMALL_STATE(18127)] = 747949,
  [SMALL_STATE(18128)] = 747966,
  [SMALL_STATE(18129)] = 747983,
  [SMALL_STATE(18130)] = 748000,
  [SMALL_STATE(18131)] = 748017,
  [SMALL_STATE(18132)] = 748032,
  [SMALL_STATE(18133)] = 748049,
  [SMALL_STATE(18134)] = 748066,
  [SMALL_STATE(18135)] = 748083,
  [SMALL_STATE(18136)] = 748098,
  [SMALL_STATE(18137)] = 748115,
  [SMALL_STATE(18138)] = 748132,
  [SMALL_STATE(18139)] = 748149,
  [SMALL_STATE(18140)] = 748166,
  [SMALL_STATE(18141)] = 748183,
  [SMALL_STATE(18142)] = 748200,
  [SMALL_STATE(18143)] = 748217,
  [SMALL_STATE(18144)] = 748234,
  [SMALL_STATE(18145)] = 748249,
  [SMALL_STATE(18146)] = 748266,
  [SMALL_STATE(18147)] = 748283,
  [SMALL_STATE(18148)] = 748298,
  [SMALL_STATE(18149)] = 748315,
  [SMALL_STATE(18150)] = 748332,
  [SMALL_STATE(18151)] = 748347,
  [SMALL_STATE(18152)] = 748364,
  [SMALL_STATE(18153)] = 748379,
  [SMALL_STATE(18154)] = 748396,
  [SMALL_STATE(18155)] = 748413,
  [SMALL_STATE(18156)] = 748430,
  [SMALL_STATE(18157)] = 748447,
  [SMALL_STATE(18158)] = 748462,
  [SMALL_STATE(18159)] = 748479,
  [SMALL_STATE(18160)] = 748496,
  [SMALL_STATE(18161)] = 748511,
  [SMALL_STATE(18162)] = 748528,
  [SMALL_STATE(18163)] = 748545,
  [SMALL_STATE(18164)] = 748562,
  [SMALL_STATE(18165)] = 748579,
  [SMALL_STATE(18166)] = 748596,
  [SMALL_STATE(18167)] = 748613,
  [SMALL_STATE(18168)] = 748628,
  [SMALL_STATE(18169)] = 748645,
  [SMALL_STATE(18170)] = 748660,
  [SMALL_STATE(18171)] = 748677,
  [SMALL_STATE(18172)] = 748694,
  [SMALL_STATE(18173)] = 748711,
  [SMALL_STATE(18174)] = 748728,
  [SMALL_STATE(18175)] = 748743,
  [SMALL_STATE(18176)] = 748760,
  [SMALL_STATE(18177)] = 748777,
  [SMALL_STATE(18178)] = 748794,
  [SMALL_STATE(18179)] = 748811,
  [SMALL_STATE(18180)] = 748828,
  [SMALL_STATE(18181)] = 748845,
  [SMALL_STATE(18182)] = 748860,
  [SMALL_STATE(18183)] = 748877,
  [SMALL_STATE(18184)] = 748894,
  [SMALL_STATE(18185)] = 748909,
  [SMALL_STATE(18186)] = 748926,
  [SMALL_STATE(18187)] = 748941,
  [SMALL_STATE(18188)] = 748956,
  [SMALL_STATE(18189)] = 748971,
  [SMALL_STATE(18190)] = 748988,
  [SMALL_STATE(18191)] = 749003,
  [SMALL_STATE(18192)] = 749018,
  [SMALL_STATE(18193)] = 749033,
  [SMALL_STATE(18194)] = 749050,
  [SMALL_STATE(18195)] = 749067,
  [SMALL_STATE(18196)] = 749084,
  [SMALL_STATE(18197)] = 749101,
  [SMALL_STATE(18198)] = 749118,
  [SMALL_STATE(18199)] = 749135,
  [SMALL_STATE(18200)] = 749152,
  [SMALL_STATE(18201)] = 749169,
  [SMALL_STATE(18202)] = 749184,
  [SMALL_STATE(18203)] = 749199,
  [SMALL_STATE(18204)] = 749216,
  [SMALL_STATE(18205)] = 749233,
  [SMALL_STATE(18206)] = 749250,
  [SMALL_STATE(18207)] = 749267,
  [SMALL_STATE(18208)] = 749284,
  [SMALL_STATE(18209)] = 749301,
  [SMALL_STATE(18210)] = 749316,
  [SMALL_STATE(18211)] = 749331,
  [SMALL_STATE(18212)] = 749346,
  [SMALL_STATE(18213)] = 749361,
  [SMALL_STATE(18214)] = 749378,
  [SMALL_STATE(18215)] = 749395,
  [SMALL_STATE(18216)] = 749412,
  [SMALL_STATE(18217)] = 749427,
  [SMALL_STATE(18218)] = 749444,
  [SMALL_STATE(18219)] = 749459,
  [SMALL_STATE(18220)] = 749474,
  [SMALL_STATE(18221)] = 749491,
  [SMALL_STATE(18222)] = 749508,
  [SMALL_STATE(18223)] = 749525,
  [SMALL_STATE(18224)] = 749542,
  [SMALL_STATE(18225)] = 749559,
  [SMALL_STATE(18226)] = 749576,
  [SMALL_STATE(18227)] = 749593,
  [SMALL_STATE(18228)] = 749608,
  [SMALL_STATE(18229)] = 749625,
  [SMALL_STATE(18230)] = 749642,
  [SMALL_STATE(18231)] = 749659,
  [SMALL_STATE(18232)] = 749676,
  [SMALL_STATE(18233)] = 749693,
  [SMALL_STATE(18234)] = 749710,
  [SMALL_STATE(18235)] = 749727,
  [SMALL_STATE(18236)] = 749742,
  [SMALL_STATE(18237)] = 749759,
  [SMALL_STATE(18238)] = 749774,
  [SMALL_STATE(18239)] = 749789,
  [SMALL_STATE(18240)] = 749806,
  [SMALL_STATE(18241)] = 749823,
  [SMALL_STATE(18242)] = 749840,
  [SMALL_STATE(18243)] = 749855,
  [SMALL_STATE(18244)] = 749872,
  [SMALL_STATE(18245)] = 749889,
  [SMALL_STATE(18246)] = 749906,
  [SMALL_STATE(18247)] = 749923,
  [SMALL_STATE(18248)] = 749940,
  [SMALL_STATE(18249)] = 749957,
  [SMALL_STATE(18250)] = 749974,
  [SMALL_STATE(18251)] = 749991,
  [SMALL_STATE(18252)] = 750008,
  [SMALL_STATE(18253)] = 750025,
  [SMALL_STATE(18254)] = 750040,
  [SMALL_STATE(18255)] = 750057,
  [SMALL_STATE(18256)] = 750072,
  [SMALL_STATE(18257)] = 750089,
  [SMALL_STATE(18258)] = 750106,
  [SMALL_STATE(18259)] = 750123,
  [SMALL_STATE(18260)] = 750140,
  [SMALL_STATE(18261)] = 750157,
  [SMALL_STATE(18262)] = 750174,
  [SMALL_STATE(18263)] = 750191,
  [SMALL_STATE(18264)] = 750208,
  [SMALL_STATE(18265)] = 750225,
  [SMALL_STATE(18266)] = 750240,
  [SMALL_STATE(18267)] = 750257,
  [SMALL_STATE(18268)] = 750274,
  [SMALL_STATE(18269)] = 750291,
  [SMALL_STATE(18270)] = 750308,
  [SMALL_STATE(18271)] = 750325,
  [SMALL_STATE(18272)] = 750340,
  [SMALL_STATE(18273)] = 750357,
  [SMALL_STATE(18274)] = 750374,
  [SMALL_STATE(18275)] = 750391,
  [SMALL_STATE(18276)] = 750408,
  [SMALL_STATE(18277)] = 750425,
  [SMALL_STATE(18278)] = 750442,
  [SMALL_STATE(18279)] = 750459,
  [SMALL_STATE(18280)] = 750476,
  [SMALL_STATE(18281)] = 750493,
  [SMALL_STATE(18282)] = 750510,
  [SMALL_STATE(18283)] = 750527,
  [SMALL_STATE(18284)] = 750544,
  [SMALL_STATE(18285)] = 750561,
  [SMALL_STATE(18286)] = 750578,
  [SMALL_STATE(18287)] = 750595,
  [SMALL_STATE(18288)] = 750610,
  [SMALL_STATE(18289)] = 750625,
  [SMALL_STATE(18290)] = 750642,
  [SMALL_STATE(18291)] = 750659,
  [SMALL_STATE(18292)] = 750676,
  [SMALL_STATE(18293)] = 750693,
  [SMALL_STATE(18294)] = 750710,
  [SMALL_STATE(18295)] = 750727,
  [SMALL_STATE(18296)] = 750744,
  [SMALL_STATE(18297)] = 750761,
  [SMALL_STATE(18298)] = 750778,
  [SMALL_STATE(18299)] = 750795,
  [SMALL_STATE(18300)] = 750812,
  [SMALL_STATE(18301)] = 750829,
  [SMALL_STATE(18302)] = 750846,
  [SMALL_STATE(18303)] = 750863,
  [SMALL_STATE(18304)] = 750880,
  [SMALL_STATE(18305)] = 750897,
  [SMALL_STATE(18306)] = 750914,
  [SMALL_STATE(18307)] = 750931,
  [SMALL_STATE(18308)] = 750946,
  [SMALL_STATE(18309)] = 750963,
  [SMALL_STATE(18310)] = 750980,
  [SMALL_STATE(18311)] = 750997,
  [SMALL_STATE(18312)] = 751014,
  [SMALL_STATE(18313)] = 751031,
  [SMALL_STATE(18314)] = 751048,
  [SMALL_STATE(18315)] = 751065,
  [SMALL_STATE(18316)] = 751082,
  [SMALL_STATE(18317)] = 751099,
  [SMALL_STATE(18318)] = 751116,
  [SMALL_STATE(18319)] = 751133,
  [SMALL_STATE(18320)] = 751150,
  [SMALL_STATE(18321)] = 751167,
  [SMALL_STATE(18322)] = 751184,
  [SMALL_STATE(18323)] = 751201,
  [SMALL_STATE(18324)] = 751218,
  [SMALL_STATE(18325)] = 751235,
  [SMALL_STATE(18326)] = 751252,
  [SMALL_STATE(18327)] = 751269,
  [SMALL_STATE(18328)] = 751286,
  [SMALL_STATE(18329)] = 751303,
  [SMALL_STATE(18330)] = 751320,
  [SMALL_STATE(18331)] = 751337,
  [SMALL_STATE(18332)] = 751354,
  [SMALL_STATE(18333)] = 751371,
  [SMALL_STATE(18334)] = 751388,
  [SMALL_STATE(18335)] = 751405,
  [SMALL_STATE(18336)] = 751422,
  [SMALL_STATE(18337)] = 751439,
  [SMALL_STATE(18338)] = 751456,
  [SMALL_STATE(18339)] = 751471,
  [SMALL_STATE(18340)] = 751488,
  [SMALL_STATE(18341)] = 751505,
  [SMALL_STATE(18342)] = 751522,
  [SMALL_STATE(18343)] = 751539,
  [SMALL_STATE(18344)] = 751554,
  [SMALL_STATE(18345)] = 751571,
  [SMALL_STATE(18346)] = 751588,
  [SMALL_STATE(18347)] = 751605,
  [SMALL_STATE(18348)] = 751620,
  [SMALL_STATE(18349)] = 751637,
  [SMALL_STATE(18350)] = 751654,
  [SMALL_STATE(18351)] = 751671,
  [SMALL_STATE(18352)] = 751688,
  [SMALL_STATE(18353)] = 751705,
  [SMALL_STATE(18354)] = 751722,
  [SMALL_STATE(18355)] = 751739,
  [SMALL_STATE(18356)] = 751756,
  [SMALL_STATE(18357)] = 751773,
  [SMALL_STATE(18358)] = 751790,
  [SMALL_STATE(18359)] = 751807,
  [SMALL_STATE(18360)] = 751824,
  [SMALL_STATE(18361)] = 751841,
  [SMALL_STATE(18362)] = 751858,
  [SMALL_STATE(18363)] = 751873,
  [SMALL_STATE(18364)] = 751890,
  [SMALL_STATE(18365)] = 751907,
  [SMALL_STATE(18366)] = 751924,
  [SMALL_STATE(18367)] = 751941,
  [SMALL_STATE(18368)] = 751958,
  [SMALL_STATE(18369)] = 751975,
  [SMALL_STATE(18370)] = 751992,
  [SMALL_STATE(18371)] = 752009,
  [SMALL_STATE(18372)] = 752026,
  [SMALL_STATE(18373)] = 752043,
  [SMALL_STATE(18374)] = 752058,
  [SMALL_STATE(18375)] = 752075,
  [SMALL_STATE(18376)] = 752092,
  [SMALL_STATE(18377)] = 752109,
  [SMALL_STATE(18378)] = 752126,
  [SMALL_STATE(18379)] = 752143,
  [SMALL_STATE(18380)] = 752160,
  [SMALL_STATE(18381)] = 752175,
  [SMALL_STATE(18382)] = 752192,
  [SMALL_STATE(18383)] = 752209,
  [SMALL_STATE(18384)] = 752226,
  [SMALL_STATE(18385)] = 752243,
  [SMALL_STATE(18386)] = 752258,
  [SMALL_STATE(18387)] = 752273,
  [SMALL_STATE(18388)] = 752290,
  [SMALL_STATE(18389)] = 752307,
  [SMALL_STATE(18390)] = 752324,
  [SMALL_STATE(18391)] = 752341,
  [SMALL_STATE(18392)] = 752358,
  [SMALL_STATE(18393)] = 752375,
  [SMALL_STATE(18394)] = 752392,
  [SMALL_STATE(18395)] = 752409,
  [SMALL_STATE(18396)] = 752424,
  [SMALL_STATE(18397)] = 752441,
  [SMALL_STATE(18398)] = 752458,
  [SMALL_STATE(18399)] = 752475,
  [SMALL_STATE(18400)] = 752492,
  [SMALL_STATE(18401)] = 752509,
  [SMALL_STATE(18402)] = 752526,
  [SMALL_STATE(18403)] = 752543,
  [SMALL_STATE(18404)] = 752560,
  [SMALL_STATE(18405)] = 752577,
  [SMALL_STATE(18406)] = 752594,
  [SMALL_STATE(18407)] = 752609,
  [SMALL_STATE(18408)] = 752626,
  [SMALL_STATE(18409)] = 752643,
  [SMALL_STATE(18410)] = 752660,
  [SMALL_STATE(18411)] = 752677,
  [SMALL_STATE(18412)] = 752694,
  [SMALL_STATE(18413)] = 752709,
  [SMALL_STATE(18414)] = 752726,
  [SMALL_STATE(18415)] = 752743,
  [SMALL_STATE(18416)] = 752758,
  [SMALL_STATE(18417)] = 752775,
  [SMALL_STATE(18418)] = 752792,
  [SMALL_STATE(18419)] = 752809,
  [SMALL_STATE(18420)] = 752824,
  [SMALL_STATE(18421)] = 752839,
  [SMALL_STATE(18422)] = 752854,
  [SMALL_STATE(18423)] = 752871,
  [SMALL_STATE(18424)] = 752888,
  [SMALL_STATE(18425)] = 752902,
  [SMALL_STATE(18426)] = 752916,
  [SMALL_STATE(18427)] = 752930,
  [SMALL_STATE(18428)] = 752944,
  [SMALL_STATE(18429)] = 752958,
  [SMALL_STATE(18430)] = 752972,
  [SMALL_STATE(18431)] = 752986,
  [SMALL_STATE(18432)] = 753000,
  [SMALL_STATE(18433)] = 753014,
  [SMALL_STATE(18434)] = 753028,
  [SMALL_STATE(18435)] = 753042,
  [SMALL_STATE(18436)] = 753056,
  [SMALL_STATE(18437)] = 753070,
  [SMALL_STATE(18438)] = 753084,
  [SMALL_STATE(18439)] = 753098,
  [SMALL_STATE(18440)] = 753112,
  [SMALL_STATE(18441)] = 753126,
  [SMALL_STATE(18442)] = 753140,
  [SMALL_STATE(18443)] = 753154,
  [SMALL_STATE(18444)] = 753168,
  [SMALL_STATE(18445)] = 753182,
  [SMALL_STATE(18446)] = 753196,
  [SMALL_STATE(18447)] = 753210,
  [SMALL_STATE(18448)] = 753224,
  [SMALL_STATE(18449)] = 753238,
  [SMALL_STATE(18450)] = 753252,
  [SMALL_STATE(18451)] = 753266,
  [SMALL_STATE(18452)] = 753280,
  [SMALL_STATE(18453)] = 753294,
  [SMALL_STATE(18454)] = 753308,
  [SMALL_STATE(18455)] = 753322,
  [SMALL_STATE(18456)] = 753336,
  [SMALL_STATE(18457)] = 753350,
  [SMALL_STATE(18458)] = 753364,
  [SMALL_STATE(18459)] = 753378,
  [SMALL_STATE(18460)] = 753392,
  [SMALL_STATE(18461)] = 753406,
  [SMALL_STATE(18462)] = 753420,
  [SMALL_STATE(18463)] = 753434,
  [SMALL_STATE(18464)] = 753448,
  [SMALL_STATE(18465)] = 753462,
  [SMALL_STATE(18466)] = 753476,
  [SMALL_STATE(18467)] = 753490,
  [SMALL_STATE(18468)] = 753504,
  [SMALL_STATE(18469)] = 753518,
  [SMALL_STATE(18470)] = 753532,
  [SMALL_STATE(18471)] = 753546,
  [SMALL_STATE(18472)] = 753560,
  [SMALL_STATE(18473)] = 753574,
  [SMALL_STATE(18474)] = 753588,
  [SMALL_STATE(18475)] = 753602,
  [SMALL_STATE(18476)] = 753616,
  [SMALL_STATE(18477)] = 753630,
  [SMALL_STATE(18478)] = 753644,
  [SMALL_STATE(18479)] = 753658,
  [SMALL_STATE(18480)] = 753672,
  [SMALL_STATE(18481)] = 753686,
  [SMALL_STATE(18482)] = 753700,
  [SMALL_STATE(18483)] = 753714,
  [SMALL_STATE(18484)] = 753728,
  [SMALL_STATE(18485)] = 753742,
  [SMALL_STATE(18486)] = 753756,
  [SMALL_STATE(18487)] = 753770,
  [SMALL_STATE(18488)] = 753784,
  [SMALL_STATE(18489)] = 753798,
  [SMALL_STATE(18490)] = 753812,
  [SMALL_STATE(18491)] = 753826,
  [SMALL_STATE(18492)] = 753840,
  [SMALL_STATE(18493)] = 753854,
  [SMALL_STATE(18494)] = 753868,
  [SMALL_STATE(18495)] = 753882,
  [SMALL_STATE(18496)] = 753896,
  [SMALL_STATE(18497)] = 753910,
  [SMALL_STATE(18498)] = 753924,
  [SMALL_STATE(18499)] = 753938,
  [SMALL_STATE(18500)] = 753952,
  [SMALL_STATE(18501)] = 753966,
  [SMALL_STATE(18502)] = 753980,
  [SMALL_STATE(18503)] = 753994,
  [SMALL_STATE(18504)] = 754008,
  [SMALL_STATE(18505)] = 754022,
  [SMALL_STATE(18506)] = 754036,
  [SMALL_STATE(18507)] = 754050,
  [SMALL_STATE(18508)] = 754064,
  [SMALL_STATE(18509)] = 754078,
  [SMALL_STATE(18510)] = 754092,
  [SMALL_STATE(18511)] = 754106,
  [SMALL_STATE(18512)] = 754120,
  [SMALL_STATE(18513)] = 754134,
  [SMALL_STATE(18514)] = 754148,
  [SMALL_STATE(18515)] = 754162,
  [SMALL_STATE(18516)] = 754176,
  [SMALL_STATE(18517)] = 754190,
  [SMALL_STATE(18518)] = 754204,
  [SMALL_STATE(18519)] = 754218,
  [SMALL_STATE(18520)] = 754232,
  [SMALL_STATE(18521)] = 754246,
  [SMALL_STATE(18522)] = 754260,
  [SMALL_STATE(18523)] = 754274,
  [SMALL_STATE(18524)] = 754288,
  [SMALL_STATE(18525)] = 754302,
  [SMALL_STATE(18526)] = 754316,
  [SMALL_STATE(18527)] = 754330,
  [SMALL_STATE(18528)] = 754344,
  [SMALL_STATE(18529)] = 754358,
  [SMALL_STATE(18530)] = 754372,
  [SMALL_STATE(18531)] = 754386,
  [SMALL_STATE(18532)] = 754400,
  [SMALL_STATE(18533)] = 754414,
  [SMALL_STATE(18534)] = 754428,
  [SMALL_STATE(18535)] = 754442,
  [SMALL_STATE(18536)] = 754456,
  [SMALL_STATE(18537)] = 754470,
  [SMALL_STATE(18538)] = 754484,
  [SMALL_STATE(18539)] = 754498,
  [SMALL_STATE(18540)] = 754512,
  [SMALL_STATE(18541)] = 754526,
  [SMALL_STATE(18542)] = 754540,
  [SMALL_STATE(18543)] = 754554,
  [SMALL_STATE(18544)] = 754568,
  [SMALL_STATE(18545)] = 754582,
  [SMALL_STATE(18546)] = 754596,
  [SMALL_STATE(18547)] = 754610,
  [SMALL_STATE(18548)] = 754624,
  [SMALL_STATE(18549)] = 754638,
  [SMALL_STATE(18550)] = 754652,
  [SMALL_STATE(18551)] = 754666,
  [SMALL_STATE(18552)] = 754680,
  [SMALL_STATE(18553)] = 754694,
  [SMALL_STATE(18554)] = 754708,
  [SMALL_STATE(18555)] = 754722,
  [SMALL_STATE(18556)] = 754736,
  [SMALL_STATE(18557)] = 754750,
  [SMALL_STATE(18558)] = 754764,
  [SMALL_STATE(18559)] = 754778,
  [SMALL_STATE(18560)] = 754792,
  [SMALL_STATE(18561)] = 754806,
  [SMALL_STATE(18562)] = 754820,
  [SMALL_STATE(18563)] = 754834,
  [SMALL_STATE(18564)] = 754848,
  [SMALL_STATE(18565)] = 754862,
  [SMALL_STATE(18566)] = 754876,
  [SMALL_STATE(18567)] = 754890,
  [SMALL_STATE(18568)] = 754904,
  [SMALL_STATE(18569)] = 754918,
  [SMALL_STATE(18570)] = 754932,
  [SMALL_STATE(18571)] = 754946,
  [SMALL_STATE(18572)] = 754960,
  [SMALL_STATE(18573)] = 754974,
  [SMALL_STATE(18574)] = 754988,
  [SMALL_STATE(18575)] = 755002,
  [SMALL_STATE(18576)] = 755016,
  [SMALL_STATE(18577)] = 755030,
  [SMALL_STATE(18578)] = 755044,
  [SMALL_STATE(18579)] = 755058,
  [SMALL_STATE(18580)] = 755072,
  [SMALL_STATE(18581)] = 755086,
  [SMALL_STATE(18582)] = 755100,
  [SMALL_STATE(18583)] = 755114,
  [SMALL_STATE(18584)] = 755128,
  [SMALL_STATE(18585)] = 755142,
  [SMALL_STATE(18586)] = 755156,
  [SMALL_STATE(18587)] = 755170,
  [SMALL_STATE(18588)] = 755184,
  [SMALL_STATE(18589)] = 755198,
  [SMALL_STATE(18590)] = 755212,
  [SMALL_STATE(18591)] = 755226,
  [SMALL_STATE(18592)] = 755240,
  [SMALL_STATE(18593)] = 755254,
  [SMALL_STATE(18594)] = 755268,
  [SMALL_STATE(18595)] = 755282,
  [SMALL_STATE(18596)] = 755296,
  [SMALL_STATE(18597)] = 755310,
  [SMALL_STATE(18598)] = 755324,
  [SMALL_STATE(18599)] = 755338,
  [SMALL_STATE(18600)] = 755352,
  [SMALL_STATE(18601)] = 755366,
  [SMALL_STATE(18602)] = 755380,
  [SMALL_STATE(18603)] = 755394,
  [SMALL_STATE(18604)] = 755408,
  [SMALL_STATE(18605)] = 755422,
  [SMALL_STATE(18606)] = 755436,
  [SMALL_STATE(18607)] = 755450,
  [SMALL_STATE(18608)] = 755464,
  [SMALL_STATE(18609)] = 755478,
  [SMALL_STATE(18610)] = 755492,
  [SMALL_STATE(18611)] = 755506,
  [SMALL_STATE(18612)] = 755520,
  [SMALL_STATE(18613)] = 755534,
  [SMALL_STATE(18614)] = 755548,
  [SMALL_STATE(18615)] = 755562,
  [SMALL_STATE(18616)] = 755576,
  [SMALL_STATE(18617)] = 755590,
  [SMALL_STATE(18618)] = 755604,
  [SMALL_STATE(18619)] = 755618,
  [SMALL_STATE(18620)] = 755632,
  [SMALL_STATE(18621)] = 755646,
  [SMALL_STATE(18622)] = 755660,
  [SMALL_STATE(18623)] = 755674,
  [SMALL_STATE(18624)] = 755688,
  [SMALL_STATE(18625)] = 755702,
  [SMALL_STATE(18626)] = 755716,
  [SMALL_STATE(18627)] = 755730,
  [SMALL_STATE(18628)] = 755744,
  [SMALL_STATE(18629)] = 755758,
  [SMALL_STATE(18630)] = 755772,
  [SMALL_STATE(18631)] = 755786,
  [SMALL_STATE(18632)] = 755800,
  [SMALL_STATE(18633)] = 755814,
  [SMALL_STATE(18634)] = 755828,
  [SMALL_STATE(18635)] = 755842,
  [SMALL_STATE(18636)] = 755856,
  [SMALL_STATE(18637)] = 755870,
  [SMALL_STATE(18638)] = 755884,
  [SMALL_STATE(18639)] = 755898,
  [SMALL_STATE(18640)] = 755912,
  [SMALL_STATE(18641)] = 755926,
  [SMALL_STATE(18642)] = 755940,
  [SMALL_STATE(18643)] = 755954,
  [SMALL_STATE(18644)] = 755968,
  [SMALL_STATE(18645)] = 755982,
  [SMALL_STATE(18646)] = 755996,
  [SMALL_STATE(18647)] = 756010,
  [SMALL_STATE(18648)] = 756024,
  [SMALL_STATE(18649)] = 756038,
  [SMALL_STATE(18650)] = 756052,
  [SMALL_STATE(18651)] = 756066,
  [SMALL_STATE(18652)] = 756080,
  [SMALL_STATE(18653)] = 756094,
  [SMALL_STATE(18654)] = 756108,
  [SMALL_STATE(18655)] = 756122,
  [SMALL_STATE(18656)] = 756136,
  [SMALL_STATE(18657)] = 756150,
  [SMALL_STATE(18658)] = 756164,
  [SMALL_STATE(18659)] = 756178,
  [SMALL_STATE(18660)] = 756192,
  [SMALL_STATE(18661)] = 756206,
  [SMALL_STATE(18662)] = 756220,
  [SMALL_STATE(18663)] = 756234,
  [SMALL_STATE(18664)] = 756248,
  [SMALL_STATE(18665)] = 756262,
  [SMALL_STATE(18666)] = 756276,
  [SMALL_STATE(18667)] = 756290,
  [SMALL_STATE(18668)] = 756304,
  [SMALL_STATE(18669)] = 756318,
  [SMALL_STATE(18670)] = 756332,
  [SMALL_STATE(18671)] = 756346,
  [SMALL_STATE(18672)] = 756360,
  [SMALL_STATE(18673)] = 756374,
  [SMALL_STATE(18674)] = 756388,
  [SMALL_STATE(18675)] = 756402,
  [SMALL_STATE(18676)] = 756416,
  [SMALL_STATE(18677)] = 756430,
  [SMALL_STATE(18678)] = 756444,
  [SMALL_STATE(18679)] = 756458,
  [SMALL_STATE(18680)] = 756472,
  [SMALL_STATE(18681)] = 756486,
  [SMALL_STATE(18682)] = 756500,
  [SMALL_STATE(18683)] = 756514,
  [SMALL_STATE(18684)] = 756528,
  [SMALL_STATE(18685)] = 756542,
  [SMALL_STATE(18686)] = 756556,
  [SMALL_STATE(18687)] = 756570,
  [SMALL_STATE(18688)] = 756584,
  [SMALL_STATE(18689)] = 756598,
  [SMALL_STATE(18690)] = 756612,
  [SMALL_STATE(18691)] = 756626,
  [SMALL_STATE(18692)] = 756640,
  [SMALL_STATE(18693)] = 756654,
  [SMALL_STATE(18694)] = 756668,
  [SMALL_STATE(18695)] = 756682,
  [SMALL_STATE(18696)] = 756696,
  [SMALL_STATE(18697)] = 756710,
  [SMALL_STATE(18698)] = 756724,
  [SMALL_STATE(18699)] = 756738,
  [SMALL_STATE(18700)] = 756752,
  [SMALL_STATE(18701)] = 756766,
  [SMALL_STATE(18702)] = 756780,
  [SMALL_STATE(18703)] = 756794,
  [SMALL_STATE(18704)] = 756808,
  [SMALL_STATE(18705)] = 756822,
  [SMALL_STATE(18706)] = 756836,
  [SMALL_STATE(18707)] = 756850,
  [SMALL_STATE(18708)] = 756864,
  [SMALL_STATE(18709)] = 756878,
  [SMALL_STATE(18710)] = 756892,
  [SMALL_STATE(18711)] = 756906,
  [SMALL_STATE(18712)] = 756920,
  [SMALL_STATE(18713)] = 756934,
  [SMALL_STATE(18714)] = 756948,
  [SMALL_STATE(18715)] = 756962,
  [SMALL_STATE(18716)] = 756976,
  [SMALL_STATE(18717)] = 756990,
  [SMALL_STATE(18718)] = 757004,
  [SMALL_STATE(18719)] = 757018,
  [SMALL_STATE(18720)] = 757032,
  [SMALL_STATE(18721)] = 757046,
  [SMALL_STATE(18722)] = 757060,
  [SMALL_STATE(18723)] = 757074,
  [SMALL_STATE(18724)] = 757088,
  [SMALL_STATE(18725)] = 757102,
  [SMALL_STATE(18726)] = 757116,
  [SMALL_STATE(18727)] = 757130,
  [SMALL_STATE(18728)] = 757144,
  [SMALL_STATE(18729)] = 757158,
  [SMALL_STATE(18730)] = 757172,
  [SMALL_STATE(18731)] = 757186,
  [SMALL_STATE(18732)] = 757200,
  [SMALL_STATE(18733)] = 757214,
  [SMALL_STATE(18734)] = 757228,
  [SMALL_STATE(18735)] = 757242,
  [SMALL_STATE(18736)] = 757256,
  [SMALL_STATE(18737)] = 757270,
  [SMALL_STATE(18738)] = 757284,
  [SMALL_STATE(18739)] = 757298,
  [SMALL_STATE(18740)] = 757312,
  [SMALL_STATE(18741)] = 757326,
  [SMALL_STATE(18742)] = 757340,
  [SMALL_STATE(18743)] = 757354,
  [SMALL_STATE(18744)] = 757368,
  [SMALL_STATE(18745)] = 757382,
  [SMALL_STATE(18746)] = 757396,
  [SMALL_STATE(18747)] = 757410,
  [SMALL_STATE(18748)] = 757424,
  [SMALL_STATE(18749)] = 757438,
  [SMALL_STATE(18750)] = 757452,
  [SMALL_STATE(18751)] = 757466,
  [SMALL_STATE(18752)] = 757480,
  [SMALL_STATE(18753)] = 757494,
  [SMALL_STATE(18754)] = 757508,
  [SMALL_STATE(18755)] = 757522,
  [SMALL_STATE(18756)] = 757536,
  [SMALL_STATE(18757)] = 757550,
  [SMALL_STATE(18758)] = 757564,
  [SMALL_STATE(18759)] = 757578,
  [SMALL_STATE(18760)] = 757592,
  [SMALL_STATE(18761)] = 757606,
  [SMALL_STATE(18762)] = 757620,
  [SMALL_STATE(18763)] = 757634,
  [SMALL_STATE(18764)] = 757648,
  [SMALL_STATE(18765)] = 757662,
  [SMALL_STATE(18766)] = 757676,
  [SMALL_STATE(18767)] = 757690,
  [SMALL_STATE(18768)] = 757704,
  [SMALL_STATE(18769)] = 757718,
  [SMALL_STATE(18770)] = 757732,
  [SMALL_STATE(18771)] = 757746,
  [SMALL_STATE(18772)] = 757760,
  [SMALL_STATE(18773)] = 757774,
  [SMALL_STATE(18774)] = 757788,
  [SMALL_STATE(18775)] = 757802,
  [SMALL_STATE(18776)] = 757816,
  [SMALL_STATE(18777)] = 757830,
  [SMALL_STATE(18778)] = 757844,
  [SMALL_STATE(18779)] = 757858,
  [SMALL_STATE(18780)] = 757872,
  [SMALL_STATE(18781)] = 757886,
  [SMALL_STATE(18782)] = 757900,
  [SMALL_STATE(18783)] = 757914,
  [SMALL_STATE(18784)] = 757928,
  [SMALL_STATE(18785)] = 757942,
  [SMALL_STATE(18786)] = 757956,
  [SMALL_STATE(18787)] = 757970,
  [SMALL_STATE(18788)] = 757984,
  [SMALL_STATE(18789)] = 757998,
  [SMALL_STATE(18790)] = 758012,
  [SMALL_STATE(18791)] = 758026,
  [SMALL_STATE(18792)] = 758040,
  [SMALL_STATE(18793)] = 758054,
  [SMALL_STATE(18794)] = 758068,
  [SMALL_STATE(18795)] = 758082,
  [SMALL_STATE(18796)] = 758096,
  [SMALL_STATE(18797)] = 758110,
  [SMALL_STATE(18798)] = 758124,
  [SMALL_STATE(18799)] = 758138,
  [SMALL_STATE(18800)] = 758152,
  [SMALL_STATE(18801)] = 758166,
  [SMALL_STATE(18802)] = 758180,
  [SMALL_STATE(18803)] = 758194,
  [SMALL_STATE(18804)] = 758208,
  [SMALL_STATE(18805)] = 758222,
  [SMALL_STATE(18806)] = 758236,
  [SMALL_STATE(18807)] = 758250,
  [SMALL_STATE(18808)] = 758264,
  [SMALL_STATE(18809)] = 758278,
  [SMALL_STATE(18810)] = 758292,
  [SMALL_STATE(18811)] = 758306,
  [SMALL_STATE(18812)] = 758320,
  [SMALL_STATE(18813)] = 758334,
  [SMALL_STATE(18814)] = 758348,
  [SMALL_STATE(18815)] = 758362,
  [SMALL_STATE(18816)] = 758376,
  [SMALL_STATE(18817)] = 758390,
  [SMALL_STATE(18818)] = 758404,
  [SMALL_STATE(18819)] = 758418,
  [SMALL_STATE(18820)] = 758432,
  [SMALL_STATE(18821)] = 758446,
  [SMALL_STATE(18822)] = 758460,
  [SMALL_STATE(18823)] = 758474,
  [SMALL_STATE(18824)] = 758488,
  [SMALL_STATE(18825)] = 758502,
  [SMALL_STATE(18826)] = 758516,
  [SMALL_STATE(18827)] = 758530,
  [SMALL_STATE(18828)] = 758544,
  [SMALL_STATE(18829)] = 758558,
  [SMALL_STATE(18830)] = 758572,
  [SMALL_STATE(18831)] = 758586,
  [SMALL_STATE(18832)] = 758600,
  [SMALL_STATE(18833)] = 758614,
  [SMALL_STATE(18834)] = 758628,
  [SMALL_STATE(18835)] = 758642,
  [SMALL_STATE(18836)] = 758656,
  [SMALL_STATE(18837)] = 758670,
  [SMALL_STATE(18838)] = 758684,
  [SMALL_STATE(18839)] = 758698,
  [SMALL_STATE(18840)] = 758712,
  [SMALL_STATE(18841)] = 758726,
  [SMALL_STATE(18842)] = 758740,
  [SMALL_STATE(18843)] = 758754,
  [SMALL_STATE(18844)] = 758768,
  [SMALL_STATE(18845)] = 758782,
  [SMALL_STATE(18846)] = 758796,
  [SMALL_STATE(18847)] = 758810,
  [SMALL_STATE(18848)] = 758824,
  [SMALL_STATE(18849)] = 758838,
  [SMALL_STATE(18850)] = 758852,
  [SMALL_STATE(18851)] = 758866,
  [SMALL_STATE(18852)] = 758880,
  [SMALL_STATE(18853)] = 758894,
  [SMALL_STATE(18854)] = 758908,
  [SMALL_STATE(18855)] = 758922,
  [SMALL_STATE(18856)] = 758936,
  [SMALL_STATE(18857)] = 758950,
  [SMALL_STATE(18858)] = 758964,
  [SMALL_STATE(18859)] = 758978,
  [SMALL_STATE(18860)] = 758992,
  [SMALL_STATE(18861)] = 759006,
  [SMALL_STATE(18862)] = 759020,
  [SMALL_STATE(18863)] = 759034,
  [SMALL_STATE(18864)] = 759048,
  [SMALL_STATE(18865)] = 759062,
  [SMALL_STATE(18866)] = 759076,
  [SMALL_STATE(18867)] = 759090,
  [SMALL_STATE(18868)] = 759104,
  [SMALL_STATE(18869)] = 759118,
  [SMALL_STATE(18870)] = 759132,
  [SMALL_STATE(18871)] = 759146,
  [SMALL_STATE(18872)] = 759160,
  [SMALL_STATE(18873)] = 759174,
  [SMALL_STATE(18874)] = 759188,
  [SMALL_STATE(18875)] = 759202,
  [SMALL_STATE(18876)] = 759216,
  [SMALL_STATE(18877)] = 759230,
  [SMALL_STATE(18878)] = 759244,
  [SMALL_STATE(18879)] = 759258,
  [SMALL_STATE(18880)] = 759272,
  [SMALL_STATE(18881)] = 759286,
  [SMALL_STATE(18882)] = 759300,
  [SMALL_STATE(18883)] = 759314,
  [SMALL_STATE(18884)] = 759328,
  [SMALL_STATE(18885)] = 759342,
  [SMALL_STATE(18886)] = 759356,
  [SMALL_STATE(18887)] = 759370,
  [SMALL_STATE(18888)] = 759384,
  [SMALL_STATE(18889)] = 759398,
  [SMALL_STATE(18890)] = 759412,
  [SMALL_STATE(18891)] = 759426,
  [SMALL_STATE(18892)] = 759440,
  [SMALL_STATE(18893)] = 759454,
  [SMALL_STATE(18894)] = 759468,
  [SMALL_STATE(18895)] = 759482,
  [SMALL_STATE(18896)] = 759496,
  [SMALL_STATE(18897)] = 759510,
  [SMALL_STATE(18898)] = 759524,
  [SMALL_STATE(18899)] = 759538,
  [SMALL_STATE(18900)] = 759552,
  [SMALL_STATE(18901)] = 759566,
  [SMALL_STATE(18902)] = 759580,
  [SMALL_STATE(18903)] = 759594,
  [SMALL_STATE(18904)] = 759608,
  [SMALL_STATE(18905)] = 759622,
  [SMALL_STATE(18906)] = 759636,
  [SMALL_STATE(18907)] = 759650,
  [SMALL_STATE(18908)] = 759664,
  [SMALL_STATE(18909)] = 759678,
  [SMALL_STATE(18910)] = 759692,
  [SMALL_STATE(18911)] = 759706,
  [SMALL_STATE(18912)] = 759720,
  [SMALL_STATE(18913)] = 759734,
  [SMALL_STATE(18914)] = 759748,
  [SMALL_STATE(18915)] = 759762,
  [SMALL_STATE(18916)] = 759776,
  [SMALL_STATE(18917)] = 759790,
  [SMALL_STATE(18918)] = 759804,
  [SMALL_STATE(18919)] = 759818,
  [SMALL_STATE(18920)] = 759832,
  [SMALL_STATE(18921)] = 759846,
  [SMALL_STATE(18922)] = 759860,
  [SMALL_STATE(18923)] = 759874,
  [SMALL_STATE(18924)] = 759888,
  [SMALL_STATE(18925)] = 759902,
  [SMALL_STATE(18926)] = 759916,
  [SMALL_STATE(18927)] = 759930,
  [SMALL_STATE(18928)] = 759944,
  [SMALL_STATE(18929)] = 759958,
  [SMALL_STATE(18930)] = 759972,
  [SMALL_STATE(18931)] = 759986,
  [SMALL_STATE(18932)] = 760000,
  [SMALL_STATE(18933)] = 760014,
  [SMALL_STATE(18934)] = 760028,
  [SMALL_STATE(18935)] = 760042,
  [SMALL_STATE(18936)] = 760056,
  [SMALL_STATE(18937)] = 760070,
  [SMALL_STATE(18938)] = 760084,
  [SMALL_STATE(18939)] = 760098,
  [SMALL_STATE(18940)] = 760112,
  [SMALL_STATE(18941)] = 760126,
  [SMALL_STATE(18942)] = 760140,
  [SMALL_STATE(18943)] = 760154,
  [SMALL_STATE(18944)] = 760168,
  [SMALL_STATE(18945)] = 760182,
  [SMALL_STATE(18946)] = 760196,
  [SMALL_STATE(18947)] = 760210,
  [SMALL_STATE(18948)] = 760224,
  [SMALL_STATE(18949)] = 760238,
  [SMALL_STATE(18950)] = 760252,
  [SMALL_STATE(18951)] = 760266,
  [SMALL_STATE(18952)] = 760280,
  [SMALL_STATE(18953)] = 760294,
  [SMALL_STATE(18954)] = 760308,
  [SMALL_STATE(18955)] = 760322,
  [SMALL_STATE(18956)] = 760336,
  [SMALL_STATE(18957)] = 760350,
  [SMALL_STATE(18958)] = 760364,
  [SMALL_STATE(18959)] = 760378,
  [SMALL_STATE(18960)] = 760392,
  [SMALL_STATE(18961)] = 760406,
  [SMALL_STATE(18962)] = 760420,
  [SMALL_STATE(18963)] = 760434,
  [SMALL_STATE(18964)] = 760448,
  [SMALL_STATE(18965)] = 760462,
  [SMALL_STATE(18966)] = 760476,
  [SMALL_STATE(18967)] = 760490,
  [SMALL_STATE(18968)] = 760504,
  [SMALL_STATE(18969)] = 760518,
  [SMALL_STATE(18970)] = 760532,
  [SMALL_STATE(18971)] = 760546,
  [SMALL_STATE(18972)] = 760560,
  [SMALL_STATE(18973)] = 760574,
  [SMALL_STATE(18974)] = 760588,
  [SMALL_STATE(18975)] = 760602,
  [SMALL_STATE(18976)] = 760616,
  [SMALL_STATE(18977)] = 760630,
  [SMALL_STATE(18978)] = 760644,
  [SMALL_STATE(18979)] = 760658,
  [SMALL_STATE(18980)] = 760672,
  [SMALL_STATE(18981)] = 760686,
  [SMALL_STATE(18982)] = 760700,
  [SMALL_STATE(18983)] = 760714,
  [SMALL_STATE(18984)] = 760728,
  [SMALL_STATE(18985)] = 760742,
  [SMALL_STATE(18986)] = 760756,
  [SMALL_STATE(18987)] = 760770,
  [SMALL_STATE(18988)] = 760784,
  [SMALL_STATE(18989)] = 760798,
  [SMALL_STATE(18990)] = 760812,
  [SMALL_STATE(18991)] = 760826,
  [SMALL_STATE(18992)] = 760840,
  [SMALL_STATE(18993)] = 760854,
  [SMALL_STATE(18994)] = 760868,
  [SMALL_STATE(18995)] = 760882,
  [SMALL_STATE(18996)] = 760896,
  [SMALL_STATE(18997)] = 760910,
  [SMALL_STATE(18998)] = 760924,
  [SMALL_STATE(18999)] = 760938,
  [SMALL_STATE(19000)] = 760952,
  [SMALL_STATE(19001)] = 760966,
  [SMALL_STATE(19002)] = 760980,
  [SMALL_STATE(19003)] = 760994,
  [SMALL_STATE(19004)] = 761008,
  [SMALL_STATE(19005)] = 761022,
  [SMALL_STATE(19006)] = 761036,
  [SMALL_STATE(19007)] = 761050,
  [SMALL_STATE(19008)] = 761064,
  [SMALL_STATE(19009)] = 761078,
  [SMALL_STATE(19010)] = 761092,
  [SMALL_STATE(19011)] = 761106,
  [SMALL_STATE(19012)] = 761120,
  [SMALL_STATE(19013)] = 761134,
  [SMALL_STATE(19014)] = 761148,
  [SMALL_STATE(19015)] = 761162,
  [SMALL_STATE(19016)] = 761176,
  [SMALL_STATE(19017)] = 761190,
  [SMALL_STATE(19018)] = 761204,
  [SMALL_STATE(19019)] = 761218,
  [SMALL_STATE(19020)] = 761232,
  [SMALL_STATE(19021)] = 761246,
  [SMALL_STATE(19022)] = 761260,
  [SMALL_STATE(19023)] = 761274,
  [SMALL_STATE(19024)] = 761288,
  [SMALL_STATE(19025)] = 761302,
  [SMALL_STATE(19026)] = 761316,
  [SMALL_STATE(19027)] = 761330,
  [SMALL_STATE(19028)] = 761344,
  [SMALL_STATE(19029)] = 761358,
  [SMALL_STATE(19030)] = 761372,
  [SMALL_STATE(19031)] = 761386,
  [SMALL_STATE(19032)] = 761400,
  [SMALL_STATE(19033)] = 761414,
  [SMALL_STATE(19034)] = 761428,
  [SMALL_STATE(19035)] = 761442,
  [SMALL_STATE(19036)] = 761456,
  [SMALL_STATE(19037)] = 761470,
  [SMALL_STATE(19038)] = 761484,
  [SMALL_STATE(19039)] = 761498,
  [SMALL_STATE(19040)] = 761512,
  [SMALL_STATE(19041)] = 761526,
  [SMALL_STATE(19042)] = 761540,
  [SMALL_STATE(19043)] = 761554,
  [SMALL_STATE(19044)] = 761568,
  [SMALL_STATE(19045)] = 761582,
  [SMALL_STATE(19046)] = 761596,
  [SMALL_STATE(19047)] = 761610,
  [SMALL_STATE(19048)] = 761624,
  [SMALL_STATE(19049)] = 761638,
  [SMALL_STATE(19050)] = 761652,
  [SMALL_STATE(19051)] = 761666,
  [SMALL_STATE(19052)] = 761680,
  [SMALL_STATE(19053)] = 761694,
  [SMALL_STATE(19054)] = 761708,
  [SMALL_STATE(19055)] = 761722,
  [SMALL_STATE(19056)] = 761736,
  [SMALL_STATE(19057)] = 761750,
  [SMALL_STATE(19058)] = 761764,
  [SMALL_STATE(19059)] = 761778,
  [SMALL_STATE(19060)] = 761792,
  [SMALL_STATE(19061)] = 761806,
  [SMALL_STATE(19062)] = 761820,
  [SMALL_STATE(19063)] = 761834,
  [SMALL_STATE(19064)] = 761848,
  [SMALL_STATE(19065)] = 761862,
  [SMALL_STATE(19066)] = 761876,
  [SMALL_STATE(19067)] = 761890,
  [SMALL_STATE(19068)] = 761904,
  [SMALL_STATE(19069)] = 761918,
  [SMALL_STATE(19070)] = 761932,
  [SMALL_STATE(19071)] = 761946,
  [SMALL_STATE(19072)] = 761960,
  [SMALL_STATE(19073)] = 761974,
  [SMALL_STATE(19074)] = 761988,
  [SMALL_STATE(19075)] = 762002,
  [SMALL_STATE(19076)] = 762016,
  [SMALL_STATE(19077)] = 762030,
  [SMALL_STATE(19078)] = 762044,
  [SMALL_STATE(19079)] = 762058,
  [SMALL_STATE(19080)] = 762072,
  [SMALL_STATE(19081)] = 762086,
  [SMALL_STATE(19082)] = 762100,
  [SMALL_STATE(19083)] = 762114,
  [SMALL_STATE(19084)] = 762128,
  [SMALL_STATE(19085)] = 762142,
  [SMALL_STATE(19086)] = 762156,
  [SMALL_STATE(19087)] = 762170,
  [SMALL_STATE(19088)] = 762184,
  [SMALL_STATE(19089)] = 762198,
  [SMALL_STATE(19090)] = 762212,
  [SMALL_STATE(19091)] = 762226,
  [SMALL_STATE(19092)] = 762240,
  [SMALL_STATE(19093)] = 762254,
  [SMALL_STATE(19094)] = 762268,
  [SMALL_STATE(19095)] = 762282,
  [SMALL_STATE(19096)] = 762296,
  [SMALL_STATE(19097)] = 762310,
  [SMALL_STATE(19098)] = 762324,
  [SMALL_STATE(19099)] = 762338,
  [SMALL_STATE(19100)] = 762352,
  [SMALL_STATE(19101)] = 762366,
  [SMALL_STATE(19102)] = 762380,
  [SMALL_STATE(19103)] = 762394,
  [SMALL_STATE(19104)] = 762408,
  [SMALL_STATE(19105)] = 762422,
  [SMALL_STATE(19106)] = 762436,
  [SMALL_STATE(19107)] = 762450,
  [SMALL_STATE(19108)] = 762464,
  [SMALL_STATE(19109)] = 762478,
  [SMALL_STATE(19110)] = 762492,
  [SMALL_STATE(19111)] = 762506,
  [SMALL_STATE(19112)] = 762520,
  [SMALL_STATE(19113)] = 762534,
  [SMALL_STATE(19114)] = 762548,
  [SMALL_STATE(19115)] = 762562,
  [SMALL_STATE(19116)] = 762576,
  [SMALL_STATE(19117)] = 762590,
  [SMALL_STATE(19118)] = 762604,
  [SMALL_STATE(19119)] = 762618,
  [SMALL_STATE(19120)] = 762632,
  [SMALL_STATE(19121)] = 762646,
  [SMALL_STATE(19122)] = 762660,
  [SMALL_STATE(19123)] = 762674,
  [SMALL_STATE(19124)] = 762688,
  [SMALL_STATE(19125)] = 762702,
  [SMALL_STATE(19126)] = 762716,
  [SMALL_STATE(19127)] = 762730,
  [SMALL_STATE(19128)] = 762744,
  [SMALL_STATE(19129)] = 762758,
  [SMALL_STATE(19130)] = 762772,
  [SMALL_STATE(19131)] = 762786,
  [SMALL_STATE(19132)] = 762800,
  [SMALL_STATE(19133)] = 762814,
  [SMALL_STATE(19134)] = 762828,
  [SMALL_STATE(19135)] = 762842,
  [SMALL_STATE(19136)] = 762856,
  [SMALL_STATE(19137)] = 762870,
  [SMALL_STATE(19138)] = 762884,
  [SMALL_STATE(19139)] = 762898,
  [SMALL_STATE(19140)] = 762912,
  [SMALL_STATE(19141)] = 762926,
  [SMALL_STATE(19142)] = 762940,
  [SMALL_STATE(19143)] = 762954,
  [SMALL_STATE(19144)] = 762968,
  [SMALL_STATE(19145)] = 762982,
  [SMALL_STATE(19146)] = 762996,
  [SMALL_STATE(19147)] = 763010,
  [SMALL_STATE(19148)] = 763024,
  [SMALL_STATE(19149)] = 763038,
  [SMALL_STATE(19150)] = 763052,
  [SMALL_STATE(19151)] = 763066,
  [SMALL_STATE(19152)] = 763080,
  [SMALL_STATE(19153)] = 763094,
  [SMALL_STATE(19154)] = 763108,
  [SMALL_STATE(19155)] = 763122,
  [SMALL_STATE(19156)] = 763136,
  [SMALL_STATE(19157)] = 763150,
  [SMALL_STATE(19158)] = 763164,
  [SMALL_STATE(19159)] = 763178,
  [SMALL_STATE(19160)] = 763192,
  [SMALL_STATE(19161)] = 763206,
  [SMALL_STATE(19162)] = 763220,
  [SMALL_STATE(19163)] = 763234,
  [SMALL_STATE(19164)] = 763248,
  [SMALL_STATE(19165)] = 763262,
  [SMALL_STATE(19166)] = 763276,
  [SMALL_STATE(19167)] = 763290,
  [SMALL_STATE(19168)] = 763304,
  [SMALL_STATE(19169)] = 763318,
  [SMALL_STATE(19170)] = 763332,
  [SMALL_STATE(19171)] = 763346,
  [SMALL_STATE(19172)] = 763360,
  [SMALL_STATE(19173)] = 763374,
  [SMALL_STATE(19174)] = 763388,
  [SMALL_STATE(19175)] = 763402,
  [SMALL_STATE(19176)] = 763416,
  [SMALL_STATE(19177)] = 763430,
  [SMALL_STATE(19178)] = 763444,
  [SMALL_STATE(19179)] = 763458,
  [SMALL_STATE(19180)] = 763472,
  [SMALL_STATE(19181)] = 763486,
  [SMALL_STATE(19182)] = 763500,
  [SMALL_STATE(19183)] = 763514,
  [SMALL_STATE(19184)] = 763528,
  [SMALL_STATE(19185)] = 763542,
  [SMALL_STATE(19186)] = 763556,
  [SMALL_STATE(19187)] = 763570,
  [SMALL_STATE(19188)] = 763584,
  [SMALL_STATE(19189)] = 763598,
  [SMALL_STATE(19190)] = 763612,
  [SMALL_STATE(19191)] = 763626,
  [SMALL_STATE(19192)] = 763640,
  [SMALL_STATE(19193)] = 763654,
  [SMALL_STATE(19194)] = 763668,
  [SMALL_STATE(19195)] = 763682,
  [SMALL_STATE(19196)] = 763696,
  [SMALL_STATE(19197)] = 763710,
  [SMALL_STATE(19198)] = 763724,
  [SMALL_STATE(19199)] = 763738,
  [SMALL_STATE(19200)] = 763752,
  [SMALL_STATE(19201)] = 763766,
  [SMALL_STATE(19202)] = 763780,
  [SMALL_STATE(19203)] = 763794,
  [SMALL_STATE(19204)] = 763808,
  [SMALL_STATE(19205)] = 763822,
  [SMALL_STATE(19206)] = 763836,
  [SMALL_STATE(19207)] = 763850,
  [SMALL_STATE(19208)] = 763864,
  [SMALL_STATE(19209)] = 763878,
  [SMALL_STATE(19210)] = 763892,
  [SMALL_STATE(19211)] = 763906,
  [SMALL_STATE(19212)] = 763920,
  [SMALL_STATE(19213)] = 763934,
  [SMALL_STATE(19214)] = 763948,
  [SMALL_STATE(19215)] = 763962,
  [SMALL_STATE(19216)] = 763976,
  [SMALL_STATE(19217)] = 763990,
  [SMALL_STATE(19218)] = 764004,
  [SMALL_STATE(19219)] = 764018,
  [SMALL_STATE(19220)] = 764032,
  [SMALL_STATE(19221)] = 764046,
  [SMALL_STATE(19222)] = 764060,
  [SMALL_STATE(19223)] = 764074,
  [SMALL_STATE(19224)] = 764088,
  [SMALL_STATE(19225)] = 764102,
  [SMALL_STATE(19226)] = 764116,
  [SMALL_STATE(19227)] = 764130,
  [SMALL_STATE(19228)] = 764144,
  [SMALL_STATE(19229)] = 764158,
  [SMALL_STATE(19230)] = 764172,
  [SMALL_STATE(19231)] = 764186,
  [SMALL_STATE(19232)] = 764200,
  [SMALL_STATE(19233)] = 764214,
  [SMALL_STATE(19234)] = 764228,
  [SMALL_STATE(19235)] = 764242,
  [SMALL_STATE(19236)] = 764256,
  [SMALL_STATE(19237)] = 764270,
  [SMALL_STATE(19238)] = 764284,
  [SMALL_STATE(19239)] = 764298,
  [SMALL_STATE(19240)] = 764312,
  [SMALL_STATE(19241)] = 764326,
  [SMALL_STATE(19242)] = 764340,
  [SMALL_STATE(19243)] = 764354,
  [SMALL_STATE(19244)] = 764368,
  [SMALL_STATE(19245)] = 764382,
  [SMALL_STATE(19246)] = 764396,
  [SMALL_STATE(19247)] = 764410,
  [SMALL_STATE(19248)] = 764424,
  [SMALL_STATE(19249)] = 764438,
  [SMALL_STATE(19250)] = 764452,
  [SMALL_STATE(19251)] = 764466,
  [SMALL_STATE(19252)] = 764480,
  [SMALL_STATE(19253)] = 764494,
  [SMALL_STATE(19254)] = 764508,
  [SMALL_STATE(19255)] = 764522,
  [SMALL_STATE(19256)] = 764536,
  [SMALL_STATE(19257)] = 764550,
  [SMALL_STATE(19258)] = 764564,
  [SMALL_STATE(19259)] = 764578,
  [SMALL_STATE(19260)] = 764592,
  [SMALL_STATE(19261)] = 764606,
  [SMALL_STATE(19262)] = 764620,
  [SMALL_STATE(19263)] = 764634,
  [SMALL_STATE(19264)] = 764648,
  [SMALL_STATE(19265)] = 764662,
  [SMALL_STATE(19266)] = 764676,
  [SMALL_STATE(19267)] = 764690,
  [SMALL_STATE(19268)] = 764704,
  [SMALL_STATE(19269)] = 764718,
  [SMALL_STATE(19270)] = 764732,
  [SMALL_STATE(19271)] = 764746,
  [SMALL_STATE(19272)] = 764760,
  [SMALL_STATE(19273)] = 764774,
  [SMALL_STATE(19274)] = 764788,
  [SMALL_STATE(19275)] = 764802,
  [SMALL_STATE(19276)] = 764816,
  [SMALL_STATE(19277)] = 764830,
  [SMALL_STATE(19278)] = 764844,
  [SMALL_STATE(19279)] = 764858,
  [SMALL_STATE(19280)] = 764872,
  [SMALL_STATE(19281)] = 764886,
  [SMALL_STATE(19282)] = 764900,
  [SMALL_STATE(19283)] = 764914,
  [SMALL_STATE(19284)] = 764928,
  [SMALL_STATE(19285)] = 764942,
  [SMALL_STATE(19286)] = 764956,
  [SMALL_STATE(19287)] = 764970,
  [SMALL_STATE(19288)] = 764984,
  [SMALL_STATE(19289)] = 764998,
  [SMALL_STATE(19290)] = 765012,
  [SMALL_STATE(19291)] = 765026,
  [SMALL_STATE(19292)] = 765040,
  [SMALL_STATE(19293)] = 765054,
  [SMALL_STATE(19294)] = 765068,
  [SMALL_STATE(19295)] = 765082,
  [SMALL_STATE(19296)] = 765096,
  [SMALL_STATE(19297)] = 765110,
  [SMALL_STATE(19298)] = 765124,
  [SMALL_STATE(19299)] = 765138,
  [SMALL_STATE(19300)] = 765152,
  [SMALL_STATE(19301)] = 765166,
  [SMALL_STATE(19302)] = 765180,
  [SMALL_STATE(19303)] = 765194,
  [SMALL_STATE(19304)] = 765208,
  [SMALL_STATE(19305)] = 765222,
  [SMALL_STATE(19306)] = 765236,
  [SMALL_STATE(19307)] = 765250,
  [SMALL_STATE(19308)] = 765264,
  [SMALL_STATE(19309)] = 765278,
  [SMALL_STATE(19310)] = 765292,
  [SMALL_STATE(19311)] = 765306,
  [SMALL_STATE(19312)] = 765320,
  [SMALL_STATE(19313)] = 765334,
  [SMALL_STATE(19314)] = 765348,
  [SMALL_STATE(19315)] = 765362,
  [SMALL_STATE(19316)] = 765376,
  [SMALL_STATE(19317)] = 765390,
  [SMALL_STATE(19318)] = 765404,
  [SMALL_STATE(19319)] = 765418,
  [SMALL_STATE(19320)] = 765432,
  [SMALL_STATE(19321)] = 765446,
  [SMALL_STATE(19322)] = 765460,
  [SMALL_STATE(19323)] = 765474,
  [SMALL_STATE(19324)] = 765488,
  [SMALL_STATE(19325)] = 765502,
  [SMALL_STATE(19326)] = 765516,
  [SMALL_STATE(19327)] = 765530,
  [SMALL_STATE(19328)] = 765544,
  [SMALL_STATE(19329)] = 765558,
  [SMALL_STATE(19330)] = 765572,
  [SMALL_STATE(19331)] = 765586,
  [SMALL_STATE(19332)] = 765600,
  [SMALL_STATE(19333)] = 765614,
  [SMALL_STATE(19334)] = 765628,
  [SMALL_STATE(19335)] = 765642,
  [SMALL_STATE(19336)] = 765656,
  [SMALL_STATE(19337)] = 765670,
  [SMALL_STATE(19338)] = 765684,
  [SMALL_STATE(19339)] = 765698,
  [SMALL_STATE(19340)] = 765712,
  [SMALL_STATE(19341)] = 765726,
  [SMALL_STATE(19342)] = 765740,
  [SMALL_STATE(19343)] = 765754,
  [SMALL_STATE(19344)] = 765768,
  [SMALL_STATE(19345)] = 765782,
  [SMALL_STATE(19346)] = 765796,
  [SMALL_STATE(19347)] = 765810,
  [SMALL_STATE(19348)] = 765824,
  [SMALL_STATE(19349)] = 765838,
  [SMALL_STATE(19350)] = 765852,
  [SMALL_STATE(19351)] = 765866,
  [SMALL_STATE(19352)] = 765880,
  [SMALL_STATE(19353)] = 765894,
  [SMALL_STATE(19354)] = 765908,
  [SMALL_STATE(19355)] = 765922,
  [SMALL_STATE(19356)] = 765936,
  [SMALL_STATE(19357)] = 765950,
  [SMALL_STATE(19358)] = 765964,
  [SMALL_STATE(19359)] = 765978,
  [SMALL_STATE(19360)] = 765992,
  [SMALL_STATE(19361)] = 766006,
  [SMALL_STATE(19362)] = 766020,
  [SMALL_STATE(19363)] = 766034,
  [SMALL_STATE(19364)] = 766048,
  [SMALL_STATE(19365)] = 766062,
  [SMALL_STATE(19366)] = 766076,
  [SMALL_STATE(19367)] = 766090,
  [SMALL_STATE(19368)] = 766104,
  [SMALL_STATE(19369)] = 766118,
  [SMALL_STATE(19370)] = 766132,
  [SMALL_STATE(19371)] = 766146,
  [SMALL_STATE(19372)] = 766160,
  [SMALL_STATE(19373)] = 766174,
  [SMALL_STATE(19374)] = 766188,
  [SMALL_STATE(19375)] = 766202,
  [SMALL_STATE(19376)] = 766216,
  [SMALL_STATE(19377)] = 766230,
  [SMALL_STATE(19378)] = 766244,
  [SMALL_STATE(19379)] = 766258,
  [SMALL_STATE(19380)] = 766272,
  [SMALL_STATE(19381)] = 766286,
  [SMALL_STATE(19382)] = 766300,
  [SMALL_STATE(19383)] = 766314,
  [SMALL_STATE(19384)] = 766328,
  [SMALL_STATE(19385)] = 766342,
  [SMALL_STATE(19386)] = 766356,
  [SMALL_STATE(19387)] = 766370,
  [SMALL_STATE(19388)] = 766384,
  [SMALL_STATE(19389)] = 766398,
  [SMALL_STATE(19390)] = 766412,
  [SMALL_STATE(19391)] = 766426,
  [SMALL_STATE(19392)] = 766440,
  [SMALL_STATE(19393)] = 766454,
  [SMALL_STATE(19394)] = 766468,
  [SMALL_STATE(19395)] = 766482,
  [SMALL_STATE(19396)] = 766496,
  [SMALL_STATE(19397)] = 766510,
  [SMALL_STATE(19398)] = 766524,
  [SMALL_STATE(19399)] = 766538,
  [SMALL_STATE(19400)] = 766552,
  [SMALL_STATE(19401)] = 766566,
  [SMALL_STATE(19402)] = 766580,
  [SMALL_STATE(19403)] = 766594,
  [SMALL_STATE(19404)] = 766608,
  [SMALL_STATE(19405)] = 766622,
  [SMALL_STATE(19406)] = 766636,
  [SMALL_STATE(19407)] = 766650,
  [SMALL_STATE(19408)] = 766664,
  [SMALL_STATE(19409)] = 766678,
  [SMALL_STATE(19410)] = 766692,
  [SMALL_STATE(19411)] = 766706,
  [SMALL_STATE(19412)] = 766720,
  [SMALL_STATE(19413)] = 766734,
  [SMALL_STATE(19414)] = 766748,
  [SMALL_STATE(19415)] = 766762,
  [SMALL_STATE(19416)] = 766776,
  [SMALL_STATE(19417)] = 766790,
  [SMALL_STATE(19418)] = 766804,
  [SMALL_STATE(19419)] = 766818,
  [SMALL_STATE(19420)] = 766832,
  [SMALL_STATE(19421)] = 766846,
  [SMALL_STATE(19422)] = 766860,
  [SMALL_STATE(19423)] = 766874,
  [SMALL_STATE(19424)] = 766888,
  [SMALL_STATE(19425)] = 766902,
  [SMALL_STATE(19426)] = 766916,
  [SMALL_STATE(19427)] = 766930,
  [SMALL_STATE(19428)] = 766944,
  [SMALL_STATE(19429)] = 766958,
  [SMALL_STATE(19430)] = 766972,
  [SMALL_STATE(19431)] = 766986,
  [SMALL_STATE(19432)] = 767000,
  [SMALL_STATE(19433)] = 767014,
  [SMALL_STATE(19434)] = 767028,
  [SMALL_STATE(19435)] = 767042,
  [SMALL_STATE(19436)] = 767056,
  [SMALL_STATE(19437)] = 767070,
  [SMALL_STATE(19438)] = 767084,
  [SMALL_STATE(19439)] = 767098,
  [SMALL_STATE(19440)] = 767112,
  [SMALL_STATE(19441)] = 767126,
  [SMALL_STATE(19442)] = 767140,
  [SMALL_STATE(19443)] = 767154,
  [SMALL_STATE(19444)] = 767168,
  [SMALL_STATE(19445)] = 767182,
  [SMALL_STATE(19446)] = 767196,
  [SMALL_STATE(19447)] = 767210,
  [SMALL_STATE(19448)] = 767224,
  [SMALL_STATE(19449)] = 767238,
  [SMALL_STATE(19450)] = 767252,
  [SMALL_STATE(19451)] = 767266,
  [SMALL_STATE(19452)] = 767280,
  [SMALL_STATE(19453)] = 767294,
  [SMALL_STATE(19454)] = 767308,
  [SMALL_STATE(19455)] = 767322,
  [SMALL_STATE(19456)] = 767336,
  [SMALL_STATE(19457)] = 767350,
  [SMALL_STATE(19458)] = 767364,
  [SMALL_STATE(19459)] = 767378,
  [SMALL_STATE(19460)] = 767392,
  [SMALL_STATE(19461)] = 767406,
  [SMALL_STATE(19462)] = 767420,
  [SMALL_STATE(19463)] = 767434,
  [SMALL_STATE(19464)] = 767448,
  [SMALL_STATE(19465)] = 767462,
  [SMALL_STATE(19466)] = 767476,
  [SMALL_STATE(19467)] = 767490,
  [SMALL_STATE(19468)] = 767504,
  [SMALL_STATE(19469)] = 767518,
  [SMALL_STATE(19470)] = 767532,
  [SMALL_STATE(19471)] = 767546,
  [SMALL_STATE(19472)] = 767560,
  [SMALL_STATE(19473)] = 767574,
  [SMALL_STATE(19474)] = 767588,
  [SMALL_STATE(19475)] = 767602,
  [SMALL_STATE(19476)] = 767616,
  [SMALL_STATE(19477)] = 767630,
  [SMALL_STATE(19478)] = 767644,
  [SMALL_STATE(19479)] = 767658,
  [SMALL_STATE(19480)] = 767672,
  [SMALL_STATE(19481)] = 767686,
  [SMALL_STATE(19482)] = 767700,
  [SMALL_STATE(19483)] = 767714,
  [SMALL_STATE(19484)] = 767728,
  [SMALL_STATE(19485)] = 767742,
  [SMALL_STATE(19486)] = 767756,
  [SMALL_STATE(19487)] = 767770,
  [SMALL_STATE(19488)] = 767784,
  [SMALL_STATE(19489)] = 767798,
  [SMALL_STATE(19490)] = 767812,
  [SMALL_STATE(19491)] = 767826,
  [SMALL_STATE(19492)] = 767840,
  [SMALL_STATE(19493)] = 767854,
  [SMALL_STATE(19494)] = 767868,
  [SMALL_STATE(19495)] = 767882,
  [SMALL_STATE(19496)] = 767896,
  [SMALL_STATE(19497)] = 767910,
  [SMALL_STATE(19498)] = 767924,
  [SMALL_STATE(19499)] = 767938,
  [SMALL_STATE(19500)] = 767952,
  [SMALL_STATE(19501)] = 767966,
  [SMALL_STATE(19502)] = 767980,
  [SMALL_STATE(19503)] = 767994,
  [SMALL_STATE(19504)] = 768008,
  [SMALL_STATE(19505)] = 768022,
  [SMALL_STATE(19506)] = 768036,
  [SMALL_STATE(19507)] = 768050,
  [SMALL_STATE(19508)] = 768064,
  [SMALL_STATE(19509)] = 768078,
  [SMALL_STATE(19510)] = 768092,
  [SMALL_STATE(19511)] = 768106,
  [SMALL_STATE(19512)] = 768120,
  [SMALL_STATE(19513)] = 768134,
  [SMALL_STATE(19514)] = 768148,
  [SMALL_STATE(19515)] = 768162,
  [SMALL_STATE(19516)] = 768176,
  [SMALL_STATE(19517)] = 768190,
  [SMALL_STATE(19518)] = 768204,
  [SMALL_STATE(19519)] = 768218,
  [SMALL_STATE(19520)] = 768232,
  [SMALL_STATE(19521)] = 768246,
  [SMALL_STATE(19522)] = 768260,
  [SMALL_STATE(19523)] = 768274,
  [SMALL_STATE(19524)] = 768288,
  [SMALL_STATE(19525)] = 768302,
  [SMALL_STATE(19526)] = 768316,
  [SMALL_STATE(19527)] = 768330,
  [SMALL_STATE(19528)] = 768344,
  [SMALL_STATE(19529)] = 768358,
  [SMALL_STATE(19530)] = 768372,
  [SMALL_STATE(19531)] = 768386,
  [SMALL_STATE(19532)] = 768400,
  [SMALL_STATE(19533)] = 768414,
  [SMALL_STATE(19534)] = 768428,
  [SMALL_STATE(19535)] = 768442,
  [SMALL_STATE(19536)] = 768456,
  [SMALL_STATE(19537)] = 768470,
  [SMALL_STATE(19538)] = 768484,
  [SMALL_STATE(19539)] = 768498,
  [SMALL_STATE(19540)] = 768512,
  [SMALL_STATE(19541)] = 768526,
  [SMALL_STATE(19542)] = 768540,
  [SMALL_STATE(19543)] = 768554,
  [SMALL_STATE(19544)] = 768568,
  [SMALL_STATE(19545)] = 768582,
  [SMALL_STATE(19546)] = 768596,
  [SMALL_STATE(19547)] = 768610,
  [SMALL_STATE(19548)] = 768624,
  [SMALL_STATE(19549)] = 768638,
  [SMALL_STATE(19550)] = 768652,
  [SMALL_STATE(19551)] = 768666,
  [SMALL_STATE(19552)] = 768680,
  [SMALL_STATE(19553)] = 768694,
  [SMALL_STATE(19554)] = 768708,
  [SMALL_STATE(19555)] = 768722,
  [SMALL_STATE(19556)] = 768736,
  [SMALL_STATE(19557)] = 768750,
  [SMALL_STATE(19558)] = 768764,
  [SMALL_STATE(19559)] = 768778,
  [SMALL_STATE(19560)] = 768792,
  [SMALL_STATE(19561)] = 768806,
  [SMALL_STATE(19562)] = 768820,
  [SMALL_STATE(19563)] = 768834,
  [SMALL_STATE(19564)] = 768848,
  [SMALL_STATE(19565)] = 768862,
  [SMALL_STATE(19566)] = 768876,
  [SMALL_STATE(19567)] = 768890,
  [SMALL_STATE(19568)] = 768904,
  [SMALL_STATE(19569)] = 768918,
  [SMALL_STATE(19570)] = 768932,
  [SMALL_STATE(19571)] = 768946,
  [SMALL_STATE(19572)] = 768960,
  [SMALL_STATE(19573)] = 768974,
  [SMALL_STATE(19574)] = 768988,
  [SMALL_STATE(19575)] = 769002,
  [SMALL_STATE(19576)] = 769016,
  [SMALL_STATE(19577)] = 769030,
  [SMALL_STATE(19578)] = 769044,
  [SMALL_STATE(19579)] = 769058,
  [SMALL_STATE(19580)] = 769072,
  [SMALL_STATE(19581)] = 769086,
  [SMALL_STATE(19582)] = 769100,
  [SMALL_STATE(19583)] = 769114,
  [SMALL_STATE(19584)] = 769128,
  [SMALL_STATE(19585)] = 769142,
  [SMALL_STATE(19586)] = 769156,
  [SMALL_STATE(19587)] = 769170,
  [SMALL_STATE(19588)] = 769184,
  [SMALL_STATE(19589)] = 769198,
  [SMALL_STATE(19590)] = 769212,
  [SMALL_STATE(19591)] = 769226,
  [SMALL_STATE(19592)] = 769240,
  [SMALL_STATE(19593)] = 769254,
  [SMALL_STATE(19594)] = 769268,
  [SMALL_STATE(19595)] = 769282,
  [SMALL_STATE(19596)] = 769296,
  [SMALL_STATE(19597)] = 769310,
  [SMALL_STATE(19598)] = 769324,
  [SMALL_STATE(19599)] = 769338,
  [SMALL_STATE(19600)] = 769352,
  [SMALL_STATE(19601)] = 769366,
  [SMALL_STATE(19602)] = 769380,
  [SMALL_STATE(19603)] = 769394,
  [SMALL_STATE(19604)] = 769408,
  [SMALL_STATE(19605)] = 769422,
  [SMALL_STATE(19606)] = 769436,
  [SMALL_STATE(19607)] = 769450,
  [SMALL_STATE(19608)] = 769464,
  [SMALL_STATE(19609)] = 769478,
  [SMALL_STATE(19610)] = 769492,
  [SMALL_STATE(19611)] = 769506,
  [SMALL_STATE(19612)] = 769520,
  [SMALL_STATE(19613)] = 769534,
  [SMALL_STATE(19614)] = 769548,
  [SMALL_STATE(19615)] = 769562,
  [SMALL_STATE(19616)] = 769576,
  [SMALL_STATE(19617)] = 769590,
  [SMALL_STATE(19618)] = 769604,
  [SMALL_STATE(19619)] = 769618,
  [SMALL_STATE(19620)] = 769632,
  [SMALL_STATE(19621)] = 769646,
  [SMALL_STATE(19622)] = 769660,
  [SMALL_STATE(19623)] = 769674,
  [SMALL_STATE(19624)] = 769688,
  [SMALL_STATE(19625)] = 769702,
  [SMALL_STATE(19626)] = 769716,
  [SMALL_STATE(19627)] = 769730,
  [SMALL_STATE(19628)] = 769744,
  [SMALL_STATE(19629)] = 769758,
  [SMALL_STATE(19630)] = 769772,
  [SMALL_STATE(19631)] = 769786,
  [SMALL_STATE(19632)] = 769800,
  [SMALL_STATE(19633)] = 769814,
  [SMALL_STATE(19634)] = 769828,
  [SMALL_STATE(19635)] = 769842,
  [SMALL_STATE(19636)] = 769856,
  [SMALL_STATE(19637)] = 769870,
  [SMALL_STATE(19638)] = 769884,
  [SMALL_STATE(19639)] = 769898,
  [SMALL_STATE(19640)] = 769912,
  [SMALL_STATE(19641)] = 769926,
  [SMALL_STATE(19642)] = 769940,
  [SMALL_STATE(19643)] = 769954,
  [SMALL_STATE(19644)] = 769968,
  [SMALL_STATE(19645)] = 769982,
  [SMALL_STATE(19646)] = 769996,
  [SMALL_STATE(19647)] = 770010,
  [SMALL_STATE(19648)] = 770024,
  [SMALL_STATE(19649)] = 770038,
  [SMALL_STATE(19650)] = 770052,
  [SMALL_STATE(19651)] = 770066,
  [SMALL_STATE(19652)] = 770080,
  [SMALL_STATE(19653)] = 770094,
  [SMALL_STATE(19654)] = 770108,
  [SMALL_STATE(19655)] = 770122,
  [SMALL_STATE(19656)] = 770136,
  [SMALL_STATE(19657)] = 770150,
  [SMALL_STATE(19658)] = 770164,
  [SMALL_STATE(19659)] = 770178,
  [SMALL_STATE(19660)] = 770192,
  [SMALL_STATE(19661)] = 770206,
  [SMALL_STATE(19662)] = 770220,
  [SMALL_STATE(19663)] = 770234,
  [SMALL_STATE(19664)] = 770248,
  [SMALL_STATE(19665)] = 770262,
  [SMALL_STATE(19666)] = 770276,
  [SMALL_STATE(19667)] = 770290,
  [SMALL_STATE(19668)] = 770304,
  [SMALL_STATE(19669)] = 770318,
  [SMALL_STATE(19670)] = 770332,
  [SMALL_STATE(19671)] = 770346,
  [SMALL_STATE(19672)] = 770360,
  [SMALL_STATE(19673)] = 770374,
  [SMALL_STATE(19674)] = 770388,
  [SMALL_STATE(19675)] = 770402,
  [SMALL_STATE(19676)] = 770416,
  [SMALL_STATE(19677)] = 770430,
  [SMALL_STATE(19678)] = 770444,
  [SMALL_STATE(19679)] = 770458,
  [SMALL_STATE(19680)] = 770472,
  [SMALL_STATE(19681)] = 770486,
  [SMALL_STATE(19682)] = 770500,
  [SMALL_STATE(19683)] = 770514,
  [SMALL_STATE(19684)] = 770528,
  [SMALL_STATE(19685)] = 770542,
  [SMALL_STATE(19686)] = 770556,
  [SMALL_STATE(19687)] = 770570,
  [SMALL_STATE(19688)] = 770584,
  [SMALL_STATE(19689)] = 770598,
  [SMALL_STATE(19690)] = 770612,
  [SMALL_STATE(19691)] = 770626,
  [SMALL_STATE(19692)] = 770640,
  [SMALL_STATE(19693)] = 770654,
  [SMALL_STATE(19694)] = 770668,
  [SMALL_STATE(19695)] = 770682,
  [SMALL_STATE(19696)] = 770696,
  [SMALL_STATE(19697)] = 770710,
  [SMALL_STATE(19698)] = 770724,
  [SMALL_STATE(19699)] = 770738,
  [SMALL_STATE(19700)] = 770752,
  [SMALL_STATE(19701)] = 770766,
  [SMALL_STATE(19702)] = 770780,
  [SMALL_STATE(19703)] = 770794,
  [SMALL_STATE(19704)] = 770808,
  [SMALL_STATE(19705)] = 770822,
  [SMALL_STATE(19706)] = 770836,
  [SMALL_STATE(19707)] = 770850,
  [SMALL_STATE(19708)] = 770864,
  [SMALL_STATE(19709)] = 770878,
  [SMALL_STATE(19710)] = 770892,
  [SMALL_STATE(19711)] = 770906,
  [SMALL_STATE(19712)] = 770920,
  [SMALL_STATE(19713)] = 770934,
  [SMALL_STATE(19714)] = 770948,
  [SMALL_STATE(19715)] = 770962,
  [SMALL_STATE(19716)] = 770976,
  [SMALL_STATE(19717)] = 770990,
  [SMALL_STATE(19718)] = 771004,
  [SMALL_STATE(19719)] = 771018,
  [SMALL_STATE(19720)] = 771032,
  [SMALL_STATE(19721)] = 771046,
  [SMALL_STATE(19722)] = 771060,
  [SMALL_STATE(19723)] = 771074,
  [SMALL_STATE(19724)] = 771088,
  [SMALL_STATE(19725)] = 771102,
  [SMALL_STATE(19726)] = 771116,
  [SMALL_STATE(19727)] = 771130,
  [SMALL_STATE(19728)] = 771144,
  [SMALL_STATE(19729)] = 771158,
  [SMALL_STATE(19730)] = 771172,
  [SMALL_STATE(19731)] = 771186,
  [SMALL_STATE(19732)] = 771200,
  [SMALL_STATE(19733)] = 771214,
  [SMALL_STATE(19734)] = 771228,
  [SMALL_STATE(19735)] = 771242,
  [SMALL_STATE(19736)] = 771256,
  [SMALL_STATE(19737)] = 771270,
  [SMALL_STATE(19738)] = 771284,
  [SMALL_STATE(19739)] = 771298,
  [SMALL_STATE(19740)] = 771312,
  [SMALL_STATE(19741)] = 771326,
  [SMALL_STATE(19742)] = 771340,
  [SMALL_STATE(19743)] = 771354,
  [SMALL_STATE(19744)] = 771368,
  [SMALL_STATE(19745)] = 771382,
  [SMALL_STATE(19746)] = 771396,
  [SMALL_STATE(19747)] = 771410,
  [SMALL_STATE(19748)] = 771424,
  [SMALL_STATE(19749)] = 771438,
  [SMALL_STATE(19750)] = 771452,
  [SMALL_STATE(19751)] = 771466,
  [SMALL_STATE(19752)] = 771480,
  [SMALL_STATE(19753)] = 771494,
  [SMALL_STATE(19754)] = 771508,
  [SMALL_STATE(19755)] = 771522,
  [SMALL_STATE(19756)] = 771536,
  [SMALL_STATE(19757)] = 771550,
  [SMALL_STATE(19758)] = 771564,
  [SMALL_STATE(19759)] = 771578,
  [SMALL_STATE(19760)] = 771592,
  [SMALL_STATE(19761)] = 771606,
  [SMALL_STATE(19762)] = 771620,
  [SMALL_STATE(19763)] = 771634,
  [SMALL_STATE(19764)] = 771648,
  [SMALL_STATE(19765)] = 771662,
  [SMALL_STATE(19766)] = 771676,
  [SMALL_STATE(19767)] = 771690,
  [SMALL_STATE(19768)] = 771704,
  [SMALL_STATE(19769)] = 771718,
  [SMALL_STATE(19770)] = 771732,
  [SMALL_STATE(19771)] = 771746,
  [SMALL_STATE(19772)] = 771760,
  [SMALL_STATE(19773)] = 771774,
  [SMALL_STATE(19774)] = 771788,
  [SMALL_STATE(19775)] = 771802,
  [SMALL_STATE(19776)] = 771816,
  [SMALL_STATE(19777)] = 771830,
  [SMALL_STATE(19778)] = 771844,
  [SMALL_STATE(19779)] = 771858,
  [SMALL_STATE(19780)] = 771872,
  [SMALL_STATE(19781)] = 771886,
  [SMALL_STATE(19782)] = 771900,
  [SMALL_STATE(19783)] = 771914,
  [SMALL_STATE(19784)] = 771928,
  [SMALL_STATE(19785)] = 771942,
  [SMALL_STATE(19786)] = 771956,
  [SMALL_STATE(19787)] = 771970,
  [SMALL_STATE(19788)] = 771984,
  [SMALL_STATE(19789)] = 771998,
  [SMALL_STATE(19790)] = 772012,
  [SMALL_STATE(19791)] = 772026,
  [SMALL_STATE(19792)] = 772040,
  [SMALL_STATE(19793)] = 772054,
  [SMALL_STATE(19794)] = 772068,
  [SMALL_STATE(19795)] = 772082,
  [SMALL_STATE(19796)] = 772096,
  [SMALL_STATE(19797)] = 772110,
  [SMALL_STATE(19798)] = 772124,
  [SMALL_STATE(19799)] = 772138,
  [SMALL_STATE(19800)] = 772152,
  [SMALL_STATE(19801)] = 772166,
  [SMALL_STATE(19802)] = 772180,
  [SMALL_STATE(19803)] = 772194,
  [SMALL_STATE(19804)] = 772208,
  [SMALL_STATE(19805)] = 772222,
  [SMALL_STATE(19806)] = 772236,
  [SMALL_STATE(19807)] = 772250,
  [SMALL_STATE(19808)] = 772264,
  [SMALL_STATE(19809)] = 772278,
  [SMALL_STATE(19810)] = 772292,
  [SMALL_STATE(19811)] = 772306,
  [SMALL_STATE(19812)] = 772320,
  [SMALL_STATE(19813)] = 772334,
  [SMALL_STATE(19814)] = 772348,
  [SMALL_STATE(19815)] = 772362,
  [SMALL_STATE(19816)] = 772376,
  [SMALL_STATE(19817)] = 772390,
  [SMALL_STATE(19818)] = 772404,
  [SMALL_STATE(19819)] = 772418,
  [SMALL_STATE(19820)] = 772432,
  [SMALL_STATE(19821)] = 772446,
  [SMALL_STATE(19822)] = 772460,
  [SMALL_STATE(19823)] = 772474,
  [SMALL_STATE(19824)] = 772488,
  [SMALL_STATE(19825)] = 772502,
  [SMALL_STATE(19826)] = 772516,
  [SMALL_STATE(19827)] = 772530,
  [SMALL_STATE(19828)] = 772544,
  [SMALL_STATE(19829)] = 772558,
  [SMALL_STATE(19830)] = 772572,
  [SMALL_STATE(19831)] = 772586,
  [SMALL_STATE(19832)] = 772600,
  [SMALL_STATE(19833)] = 772614,
  [SMALL_STATE(19834)] = 772628,
  [SMALL_STATE(19835)] = 772642,
  [SMALL_STATE(19836)] = 772656,
  [SMALL_STATE(19837)] = 772670,
  [SMALL_STATE(19838)] = 772684,
  [SMALL_STATE(19839)] = 772698,
  [SMALL_STATE(19840)] = 772712,
  [SMALL_STATE(19841)] = 772726,
  [SMALL_STATE(19842)] = 772740,
  [SMALL_STATE(19843)] = 772754,
  [SMALL_STATE(19844)] = 772768,
  [SMALL_STATE(19845)] = 772782,
  [SMALL_STATE(19846)] = 772796,
  [SMALL_STATE(19847)] = 772810,
  [SMALL_STATE(19848)] = 772824,
  [SMALL_STATE(19849)] = 772838,
  [SMALL_STATE(19850)] = 772852,
  [SMALL_STATE(19851)] = 772866,
  [SMALL_STATE(19852)] = 772880,
  [SMALL_STATE(19853)] = 772894,
  [SMALL_STATE(19854)] = 772908,
  [SMALL_STATE(19855)] = 772922,
  [SMALL_STATE(19856)] = 772936,
  [SMALL_STATE(19857)] = 772950,
  [SMALL_STATE(19858)] = 772964,
  [SMALL_STATE(19859)] = 772978,
  [SMALL_STATE(19860)] = 772992,
  [SMALL_STATE(19861)] = 773006,
  [SMALL_STATE(19862)] = 773020,
  [SMALL_STATE(19863)] = 773034,
  [SMALL_STATE(19864)] = 773048,
  [SMALL_STATE(19865)] = 773062,
  [SMALL_STATE(19866)] = 773076,
  [SMALL_STATE(19867)] = 773090,
  [SMALL_STATE(19868)] = 773104,
  [SMALL_STATE(19869)] = 773118,
  [SMALL_STATE(19870)] = 773132,
  [SMALL_STATE(19871)] = 773146,
  [SMALL_STATE(19872)] = 773160,
  [SMALL_STATE(19873)] = 773174,
  [SMALL_STATE(19874)] = 773188,
  [SMALL_STATE(19875)] = 773202,
  [SMALL_STATE(19876)] = 773216,
  [SMALL_STATE(19877)] = 773230,
  [SMALL_STATE(19878)] = 773244,
  [SMALL_STATE(19879)] = 773258,
  [SMALL_STATE(19880)] = 773272,
  [SMALL_STATE(19881)] = 773286,
  [SMALL_STATE(19882)] = 773300,
  [SMALL_STATE(19883)] = 773314,
  [SMALL_STATE(19884)] = 773328,
  [SMALL_STATE(19885)] = 773342,
  [SMALL_STATE(19886)] = 773356,
  [SMALL_STATE(19887)] = 773370,
  [SMALL_STATE(19888)] = 773384,
  [SMALL_STATE(19889)] = 773398,
  [SMALL_STATE(19890)] = 773412,
  [SMALL_STATE(19891)] = 773426,
  [SMALL_STATE(19892)] = 773440,
  [SMALL_STATE(19893)] = 773454,
  [SMALL_STATE(19894)] = 773468,
  [SMALL_STATE(19895)] = 773482,
  [SMALL_STATE(19896)] = 773496,
  [SMALL_STATE(19897)] = 773510,
  [SMALL_STATE(19898)] = 773524,
  [SMALL_STATE(19899)] = 773538,
  [SMALL_STATE(19900)] = 773552,
  [SMALL_STATE(19901)] = 773566,
  [SMALL_STATE(19902)] = 773580,
  [SMALL_STATE(19903)] = 773594,
  [SMALL_STATE(19904)] = 773608,
  [SMALL_STATE(19905)] = 773622,
  [SMALL_STATE(19906)] = 773636,
  [SMALL_STATE(19907)] = 773650,
  [SMALL_STATE(19908)] = 773664,
  [SMALL_STATE(19909)] = 773678,
  [SMALL_STATE(19910)] = 773692,
  [SMALL_STATE(19911)] = 773706,
  [SMALL_STATE(19912)] = 773720,
  [SMALL_STATE(19913)] = 773734,
  [SMALL_STATE(19914)] = 773748,
  [SMALL_STATE(19915)] = 773762,
  [SMALL_STATE(19916)] = 773776,
  [SMALL_STATE(19917)] = 773790,
  [SMALL_STATE(19918)] = 773804,
  [SMALL_STATE(19919)] = 773818,
  [SMALL_STATE(19920)] = 773832,
  [SMALL_STATE(19921)] = 773846,
  [SMALL_STATE(19922)] = 773860,
  [SMALL_STATE(19923)] = 773874,
  [SMALL_STATE(19924)] = 773888,
  [SMALL_STATE(19925)] = 773902,
  [SMALL_STATE(19926)] = 773916,
  [SMALL_STATE(19927)] = 773930,
  [SMALL_STATE(19928)] = 773944,
  [SMALL_STATE(19929)] = 773958,
  [SMALL_STATE(19930)] = 773972,
  [SMALL_STATE(19931)] = 773986,
  [SMALL_STATE(19932)] = 774000,
  [SMALL_STATE(19933)] = 774014,
  [SMALL_STATE(19934)] = 774028,
  [SMALL_STATE(19935)] = 774042,
  [SMALL_STATE(19936)] = 774056,
  [SMALL_STATE(19937)] = 774070,
  [SMALL_STATE(19938)] = 774084,
  [SMALL_STATE(19939)] = 774098,
  [SMALL_STATE(19940)] = 774112,
  [SMALL_STATE(19941)] = 774126,
  [SMALL_STATE(19942)] = 774140,
  [SMALL_STATE(19943)] = 774154,
  [SMALL_STATE(19944)] = 774168,
  [SMALL_STATE(19945)] = 774182,
  [SMALL_STATE(19946)] = 774196,
  [SMALL_STATE(19947)] = 774210,
  [SMALL_STATE(19948)] = 774224,
  [SMALL_STATE(19949)] = 774238,
  [SMALL_STATE(19950)] = 774252,
  [SMALL_STATE(19951)] = 774266,
  [SMALL_STATE(19952)] = 774280,
  [SMALL_STATE(19953)] = 774294,
  [SMALL_STATE(19954)] = 774308,
  [SMALL_STATE(19955)] = 774322,
  [SMALL_STATE(19956)] = 774336,
  [SMALL_STATE(19957)] = 774350,
  [SMALL_STATE(19958)] = 774364,
  [SMALL_STATE(19959)] = 774378,
  [SMALL_STATE(19960)] = 774392,
  [SMALL_STATE(19961)] = 774406,
  [SMALL_STATE(19962)] = 774420,
  [SMALL_STATE(19963)] = 774434,
  [SMALL_STATE(19964)] = 774448,
  [SMALL_STATE(19965)] = 774462,
  [SMALL_STATE(19966)] = 774476,
  [SMALL_STATE(19967)] = 774490,
  [SMALL_STATE(19968)] = 774504,
  [SMALL_STATE(19969)] = 774518,
  [SMALL_STATE(19970)] = 774532,
  [SMALL_STATE(19971)] = 774546,
  [SMALL_STATE(19972)] = 774560,
  [SMALL_STATE(19973)] = 774574,
  [SMALL_STATE(19974)] = 774588,
  [SMALL_STATE(19975)] = 774602,
  [SMALL_STATE(19976)] = 774616,
  [SMALL_STATE(19977)] = 774630,
  [SMALL_STATE(19978)] = 774644,
  [SMALL_STATE(19979)] = 774658,
  [SMALL_STATE(19980)] = 774672,
  [SMALL_STATE(19981)] = 774686,
  [SMALL_STATE(19982)] = 774700,
  [SMALL_STATE(19983)] = 774714,
  [SMALL_STATE(19984)] = 774728,
  [SMALL_STATE(19985)] = 774742,
  [SMALL_STATE(19986)] = 774756,
  [SMALL_STATE(19987)] = 774770,
  [SMALL_STATE(19988)] = 774784,
  [SMALL_STATE(19989)] = 774798,
  [SMALL_STATE(19990)] = 774812,
  [SMALL_STATE(19991)] = 774826,
  [SMALL_STATE(19992)] = 774840,
  [SMALL_STATE(19993)] = 774854,
  [SMALL_STATE(19994)] = 774868,
  [SMALL_STATE(19995)] = 774882,
  [SMALL_STATE(19996)] = 774896,
  [SMALL_STATE(19997)] = 774910,
  [SMALL_STATE(19998)] = 774924,
  [SMALL_STATE(19999)] = 774938,
  [SMALL_STATE(20000)] = 774952,
  [SMALL_STATE(20001)] = 774966,
  [SMALL_STATE(20002)] = 774980,
  [SMALL_STATE(20003)] = 774994,
  [SMALL_STATE(20004)] = 775008,
  [SMALL_STATE(20005)] = 775022,
  [SMALL_STATE(20006)] = 775036,
  [SMALL_STATE(20007)] = 775050,
  [SMALL_STATE(20008)] = 775064,
  [SMALL_STATE(20009)] = 775078,
  [SMALL_STATE(20010)] = 775092,
  [SMALL_STATE(20011)] = 775106,
  [SMALL_STATE(20012)] = 775120,
  [SMALL_STATE(20013)] = 775134,
  [SMALL_STATE(20014)] = 775148,
  [SMALL_STATE(20015)] = 775162,
  [SMALL_STATE(20016)] = 775176,
  [SMALL_STATE(20017)] = 775190,
  [SMALL_STATE(20018)] = 775204,
  [SMALL_STATE(20019)] = 775218,
  [SMALL_STATE(20020)] = 775232,
  [SMALL_STATE(20021)] = 775246,
  [SMALL_STATE(20022)] = 775260,
  [SMALL_STATE(20023)] = 775274,
  [SMALL_STATE(20024)] = 775288,
  [SMALL_STATE(20025)] = 775302,
  [SMALL_STATE(20026)] = 775316,
  [SMALL_STATE(20027)] = 775330,
  [SMALL_STATE(20028)] = 775344,
  [SMALL_STATE(20029)] = 775358,
  [SMALL_STATE(20030)] = 775372,
  [SMALL_STATE(20031)] = 775386,
  [SMALL_STATE(20032)] = 775400,
  [SMALL_STATE(20033)] = 775414,
  [SMALL_STATE(20034)] = 775428,
  [SMALL_STATE(20035)] = 775442,
  [SMALL_STATE(20036)] = 775456,
  [SMALL_STATE(20037)] = 775470,
  [SMALL_STATE(20038)] = 775484,
  [SMALL_STATE(20039)] = 775498,
  [SMALL_STATE(20040)] = 775512,
  [SMALL_STATE(20041)] = 775526,
  [SMALL_STATE(20042)] = 775540,
  [SMALL_STATE(20043)] = 775554,
  [SMALL_STATE(20044)] = 775568,
  [SMALL_STATE(20045)] = 775582,
  [SMALL_STATE(20046)] = 775596,
  [SMALL_STATE(20047)] = 775610,
  [SMALL_STATE(20048)] = 775624,
  [SMALL_STATE(20049)] = 775638,
  [SMALL_STATE(20050)] = 775652,
  [SMALL_STATE(20051)] = 775666,
  [SMALL_STATE(20052)] = 775680,
  [SMALL_STATE(20053)] = 775694,
  [SMALL_STATE(20054)] = 775708,
  [SMALL_STATE(20055)] = 775722,
  [SMALL_STATE(20056)] = 775736,
  [SMALL_STATE(20057)] = 775750,
  [SMALL_STATE(20058)] = 775764,
  [SMALL_STATE(20059)] = 775778,
  [SMALL_STATE(20060)] = 775792,
  [SMALL_STATE(20061)] = 775806,
  [SMALL_STATE(20062)] = 775820,
  [SMALL_STATE(20063)] = 775834,
  [SMALL_STATE(20064)] = 775848,
  [SMALL_STATE(20065)] = 775862,
  [SMALL_STATE(20066)] = 775876,
  [SMALL_STATE(20067)] = 775890,
  [SMALL_STATE(20068)] = 775904,
  [SMALL_STATE(20069)] = 775918,
  [SMALL_STATE(20070)] = 775932,
  [SMALL_STATE(20071)] = 775946,
  [SMALL_STATE(20072)] = 775960,
  [SMALL_STATE(20073)] = 775974,
  [SMALL_STATE(20074)] = 775988,
  [SMALL_STATE(20075)] = 776002,
  [SMALL_STATE(20076)] = 776016,
  [SMALL_STATE(20077)] = 776030,
  [SMALL_STATE(20078)] = 776044,
  [SMALL_STATE(20079)] = 776058,
  [SMALL_STATE(20080)] = 776072,
  [SMALL_STATE(20081)] = 776086,
  [SMALL_STATE(20082)] = 776100,
  [SMALL_STATE(20083)] = 776114,
  [SMALL_STATE(20084)] = 776128,
  [SMALL_STATE(20085)] = 776142,
  [SMALL_STATE(20086)] = 776156,
  [SMALL_STATE(20087)] = 776170,
  [SMALL_STATE(20088)] = 776184,
  [SMALL_STATE(20089)] = 776198,
  [SMALL_STATE(20090)] = 776212,
  [SMALL_STATE(20091)] = 776226,
  [SMALL_STATE(20092)] = 776240,
  [SMALL_STATE(20093)] = 776254,
  [SMALL_STATE(20094)] = 776268,
  [SMALL_STATE(20095)] = 776282,
  [SMALL_STATE(20096)] = 776296,
  [SMALL_STATE(20097)] = 776310,
  [SMALL_STATE(20098)] = 776324,
  [SMALL_STATE(20099)] = 776338,
  [SMALL_STATE(20100)] = 776352,
  [SMALL_STATE(20101)] = 776366,
  [SMALL_STATE(20102)] = 776380,
  [SMALL_STATE(20103)] = 776394,
  [SMALL_STATE(20104)] = 776408,
  [SMALL_STATE(20105)] = 776422,
  [SMALL_STATE(20106)] = 776436,
  [SMALL_STATE(20107)] = 776450,
  [SMALL_STATE(20108)] = 776464,
  [SMALL_STATE(20109)] = 776478,
  [SMALL_STATE(20110)] = 776492,
  [SMALL_STATE(20111)] = 776506,
  [SMALL_STATE(20112)] = 776520,
  [SMALL_STATE(20113)] = 776534,
  [SMALL_STATE(20114)] = 776548,
  [SMALL_STATE(20115)] = 776562,
  [SMALL_STATE(20116)] = 776576,
  [SMALL_STATE(20117)] = 776590,
  [SMALL_STATE(20118)] = 776604,
  [SMALL_STATE(20119)] = 776618,
  [SMALL_STATE(20120)] = 776632,
  [SMALL_STATE(20121)] = 776646,
  [SMALL_STATE(20122)] = 776660,
  [SMALL_STATE(20123)] = 776674,
  [SMALL_STATE(20124)] = 776688,
  [SMALL_STATE(20125)] = 776702,
  [SMALL_STATE(20126)] = 776716,
  [SMALL_STATE(20127)] = 776730,
  [SMALL_STATE(20128)] = 776744,
  [SMALL_STATE(20129)] = 776758,
  [SMALL_STATE(20130)] = 776772,
  [SMALL_STATE(20131)] = 776786,
  [SMALL_STATE(20132)] = 776800,
  [SMALL_STATE(20133)] = 776814,
  [SMALL_STATE(20134)] = 776828,
  [SMALL_STATE(20135)] = 776842,
  [SMALL_STATE(20136)] = 776856,
  [SMALL_STATE(20137)] = 776870,
  [SMALL_STATE(20138)] = 776884,
  [SMALL_STATE(20139)] = 776898,
  [SMALL_STATE(20140)] = 776912,
  [SMALL_STATE(20141)] = 776926,
  [SMALL_STATE(20142)] = 776940,
  [SMALL_STATE(20143)] = 776954,
  [SMALL_STATE(20144)] = 776968,
  [SMALL_STATE(20145)] = 776982,
  [SMALL_STATE(20146)] = 776996,
  [SMALL_STATE(20147)] = 777010,
  [SMALL_STATE(20148)] = 777024,
  [SMALL_STATE(20149)] = 777038,
  [SMALL_STATE(20150)] = 777052,
  [SMALL_STATE(20151)] = 777066,
  [SMALL_STATE(20152)] = 777080,
  [SMALL_STATE(20153)] = 777094,
  [SMALL_STATE(20154)] = 777108,
  [SMALL_STATE(20155)] = 777122,
  [SMALL_STATE(20156)] = 777136,
  [SMALL_STATE(20157)] = 777150,
  [SMALL_STATE(20158)] = 777164,
  [SMALL_STATE(20159)] = 777178,
  [SMALL_STATE(20160)] = 777192,
  [SMALL_STATE(20161)] = 777206,
  [SMALL_STATE(20162)] = 777220,
  [SMALL_STATE(20163)] = 777234,
  [SMALL_STATE(20164)] = 777248,
  [SMALL_STATE(20165)] = 777262,
  [SMALL_STATE(20166)] = 777276,
  [SMALL_STATE(20167)] = 777290,
  [SMALL_STATE(20168)] = 777304,
  [SMALL_STATE(20169)] = 777318,
  [SMALL_STATE(20170)] = 777332,
  [SMALL_STATE(20171)] = 777346,
  [SMALL_STATE(20172)] = 777360,
  [SMALL_STATE(20173)] = 777374,
  [SMALL_STATE(20174)] = 777388,
  [SMALL_STATE(20175)] = 777402,
  [SMALL_STATE(20176)] = 777416,
  [SMALL_STATE(20177)] = 777430,
  [SMALL_STATE(20178)] = 777444,
  [SMALL_STATE(20179)] = 777458,
  [SMALL_STATE(20180)] = 777472,
  [SMALL_STATE(20181)] = 777486,
  [SMALL_STATE(20182)] = 777500,
  [SMALL_STATE(20183)] = 777514,
  [SMALL_STATE(20184)] = 777528,
  [SMALL_STATE(20185)] = 777542,
  [SMALL_STATE(20186)] = 777556,
  [SMALL_STATE(20187)] = 777570,
  [SMALL_STATE(20188)] = 777584,
  [SMALL_STATE(20189)] = 777598,
  [SMALL_STATE(20190)] = 777612,
  [SMALL_STATE(20191)] = 777626,
  [SMALL_STATE(20192)] = 777640,
  [SMALL_STATE(20193)] = 777654,
  [SMALL_STATE(20194)] = 777668,
  [SMALL_STATE(20195)] = 777682,
  [SMALL_STATE(20196)] = 777696,
  [SMALL_STATE(20197)] = 777710,
  [SMALL_STATE(20198)] = 777724,
  [SMALL_STATE(20199)] = 777738,
  [SMALL_STATE(20200)] = 777752,
  [SMALL_STATE(20201)] = 777766,
  [SMALL_STATE(20202)] = 777780,
  [SMALL_STATE(20203)] = 777794,
  [SMALL_STATE(20204)] = 777808,
  [SMALL_STATE(20205)] = 777822,
  [SMALL_STATE(20206)] = 777836,
  [SMALL_STATE(20207)] = 777850,
  [SMALL_STATE(20208)] = 777864,
  [SMALL_STATE(20209)] = 777878,
  [SMALL_STATE(20210)] = 777892,
  [SMALL_STATE(20211)] = 777906,
  [SMALL_STATE(20212)] = 777920,
  [SMALL_STATE(20213)] = 777934,
  [SMALL_STATE(20214)] = 777948,
  [SMALL_STATE(20215)] = 777962,
  [SMALL_STATE(20216)] = 777976,
  [SMALL_STATE(20217)] = 777990,
  [SMALL_STATE(20218)] = 778004,
  [SMALL_STATE(20219)] = 778018,
  [SMALL_STATE(20220)] = 778032,
  [SMALL_STATE(20221)] = 778046,
  [SMALL_STATE(20222)] = 778060,
  [SMALL_STATE(20223)] = 778074,
  [SMALL_STATE(20224)] = 778088,
  [SMALL_STATE(20225)] = 778102,
  [SMALL_STATE(20226)] = 778116,
  [SMALL_STATE(20227)] = 778130,
  [SMALL_STATE(20228)] = 778144,
  [SMALL_STATE(20229)] = 778158,
  [SMALL_STATE(20230)] = 778172,
  [SMALL_STATE(20231)] = 778186,
  [SMALL_STATE(20232)] = 778200,
  [SMALL_STATE(20233)] = 778214,
  [SMALL_STATE(20234)] = 778228,
  [SMALL_STATE(20235)] = 778242,
  [SMALL_STATE(20236)] = 778256,
  [SMALL_STATE(20237)] = 778270,
  [SMALL_STATE(20238)] = 778284,
  [SMALL_STATE(20239)] = 778298,
  [SMALL_STATE(20240)] = 778312,
  [SMALL_STATE(20241)] = 778326,
  [SMALL_STATE(20242)] = 778340,
  [SMALL_STATE(20243)] = 778354,
  [SMALL_STATE(20244)] = 778368,
  [SMALL_STATE(20245)] = 778382,
  [SMALL_STATE(20246)] = 778396,
  [SMALL_STATE(20247)] = 778410,
  [SMALL_STATE(20248)] = 778424,
  [SMALL_STATE(20249)] = 778438,
  [SMALL_STATE(20250)] = 778452,
  [SMALL_STATE(20251)] = 778466,
  [SMALL_STATE(20252)] = 778480,
  [SMALL_STATE(20253)] = 778494,
  [SMALL_STATE(20254)] = 778508,
  [SMALL_STATE(20255)] = 778522,
  [SMALL_STATE(20256)] = 778536,
  [SMALL_STATE(20257)] = 778550,
  [SMALL_STATE(20258)] = 778564,
  [SMALL_STATE(20259)] = 778578,
  [SMALL_STATE(20260)] = 778592,
  [SMALL_STATE(20261)] = 778606,
  [SMALL_STATE(20262)] = 778620,
  [SMALL_STATE(20263)] = 778634,
  [SMALL_STATE(20264)] = 778648,
  [SMALL_STATE(20265)] = 778662,
  [SMALL_STATE(20266)] = 778676,
  [SMALL_STATE(20267)] = 778690,
  [SMALL_STATE(20268)] = 778704,
  [SMALL_STATE(20269)] = 778718,
  [SMALL_STATE(20270)] = 778732,
  [SMALL_STATE(20271)] = 778746,
  [SMALL_STATE(20272)] = 778760,
  [SMALL_STATE(20273)] = 778774,
  [SMALL_STATE(20274)] = 778788,
  [SMALL_STATE(20275)] = 778802,
  [SMALL_STATE(20276)] = 778816,
  [SMALL_STATE(20277)] = 778830,
  [SMALL_STATE(20278)] = 778844,
  [SMALL_STATE(20279)] = 778858,
  [SMALL_STATE(20280)] = 778872,
  [SMALL_STATE(20281)] = 778886,
  [SMALL_STATE(20282)] = 778900,
  [SMALL_STATE(20283)] = 778914,
  [SMALL_STATE(20284)] = 778928,
  [SMALL_STATE(20285)] = 778942,
  [SMALL_STATE(20286)] = 778956,
  [SMALL_STATE(20287)] = 778970,
  [SMALL_STATE(20288)] = 778984,
  [SMALL_STATE(20289)] = 778998,
  [SMALL_STATE(20290)] = 779012,
  [SMALL_STATE(20291)] = 779026,
  [SMALL_STATE(20292)] = 779040,
  [SMALL_STATE(20293)] = 779054,
  [SMALL_STATE(20294)] = 779068,
  [SMALL_STATE(20295)] = 779082,
  [SMALL_STATE(20296)] = 779096,
  [SMALL_STATE(20297)] = 779110,
  [SMALL_STATE(20298)] = 779124,
  [SMALL_STATE(20299)] = 779138,
  [SMALL_STATE(20300)] = 779152,
  [SMALL_STATE(20301)] = 779166,
  [SMALL_STATE(20302)] = 779180,
  [SMALL_STATE(20303)] = 779194,
  [SMALL_STATE(20304)] = 779208,
  [SMALL_STATE(20305)] = 779222,
  [SMALL_STATE(20306)] = 779236,
  [SMALL_STATE(20307)] = 779250,
  [SMALL_STATE(20308)] = 779264,
  [SMALL_STATE(20309)] = 779278,
  [SMALL_STATE(20310)] = 779292,
  [SMALL_STATE(20311)] = 779306,
  [SMALL_STATE(20312)] = 779320,
  [SMALL_STATE(20313)] = 779334,
  [SMALL_STATE(20314)] = 779348,
  [SMALL_STATE(20315)] = 779362,
  [SMALL_STATE(20316)] = 779376,
  [SMALL_STATE(20317)] = 779390,
  [SMALL_STATE(20318)] = 779404,
  [SMALL_STATE(20319)] = 779418,
  [SMALL_STATE(20320)] = 779432,
  [SMALL_STATE(20321)] = 779446,
  [SMALL_STATE(20322)] = 779460,
  [SMALL_STATE(20323)] = 779474,
  [SMALL_STATE(20324)] = 779488,
  [SMALL_STATE(20325)] = 779502,
  [SMALL_STATE(20326)] = 779516,
  [SMALL_STATE(20327)] = 779530,
  [SMALL_STATE(20328)] = 779544,
  [SMALL_STATE(20329)] = 779558,
  [SMALL_STATE(20330)] = 779572,
  [SMALL_STATE(20331)] = 779586,
  [SMALL_STATE(20332)] = 779600,
  [SMALL_STATE(20333)] = 779614,
  [SMALL_STATE(20334)] = 779628,
  [SMALL_STATE(20335)] = 779642,
  [SMALL_STATE(20336)] = 779656,
  [SMALL_STATE(20337)] = 779670,
  [SMALL_STATE(20338)] = 779684,
  [SMALL_STATE(20339)] = 779698,
  [SMALL_STATE(20340)] = 779712,
  [SMALL_STATE(20341)] = 779726,
  [SMALL_STATE(20342)] = 779740,
  [SMALL_STATE(20343)] = 779754,
  [SMALL_STATE(20344)] = 779768,
  [SMALL_STATE(20345)] = 779782,
  [SMALL_STATE(20346)] = 779796,
  [SMALL_STATE(20347)] = 779810,
  [SMALL_STATE(20348)] = 779824,
  [SMALL_STATE(20349)] = 779838,
  [SMALL_STATE(20350)] = 779852,
  [SMALL_STATE(20351)] = 779866,
  [SMALL_STATE(20352)] = 779880,
  [SMALL_STATE(20353)] = 779894,
  [SMALL_STATE(20354)] = 779908,
  [SMALL_STATE(20355)] = 779922,
  [SMALL_STATE(20356)] = 779936,
  [SMALL_STATE(20357)] = 779950,
  [SMALL_STATE(20358)] = 779964,
  [SMALL_STATE(20359)] = 779978,
  [SMALL_STATE(20360)] = 779992,
  [SMALL_STATE(20361)] = 780006,
  [SMALL_STATE(20362)] = 780020,
  [SMALL_STATE(20363)] = 780034,
  [SMALL_STATE(20364)] = 780048,
  [SMALL_STATE(20365)] = 780062,
  [SMALL_STATE(20366)] = 780076,
  [SMALL_STATE(20367)] = 780090,
  [SMALL_STATE(20368)] = 780104,
  [SMALL_STATE(20369)] = 780118,
  [SMALL_STATE(20370)] = 780132,
  [SMALL_STATE(20371)] = 780146,
  [SMALL_STATE(20372)] = 780160,
  [SMALL_STATE(20373)] = 780174,
  [SMALL_STATE(20374)] = 780188,
  [SMALL_STATE(20375)] = 780202,
  [SMALL_STATE(20376)] = 780216,
  [SMALL_STATE(20377)] = 780230,
  [SMALL_STATE(20378)] = 780244,
  [SMALL_STATE(20379)] = 780258,
  [SMALL_STATE(20380)] = 780272,
  [SMALL_STATE(20381)] = 780286,
  [SMALL_STATE(20382)] = 780300,
  [SMALL_STATE(20383)] = 780314,
  [SMALL_STATE(20384)] = 780328,
  [SMALL_STATE(20385)] = 780342,
  [SMALL_STATE(20386)] = 780356,
  [SMALL_STATE(20387)] = 780370,
  [SMALL_STATE(20388)] = 780384,
  [SMALL_STATE(20389)] = 780398,
  [SMALL_STATE(20390)] = 780412,
  [SMALL_STATE(20391)] = 780426,
  [SMALL_STATE(20392)] = 780440,
  [SMALL_STATE(20393)] = 780454,
  [SMALL_STATE(20394)] = 780468,
  [SMALL_STATE(20395)] = 780482,
  [SMALL_STATE(20396)] = 780496,
  [SMALL_STATE(20397)] = 780510,
  [SMALL_STATE(20398)] = 780524,
  [SMALL_STATE(20399)] = 780538,
  [SMALL_STATE(20400)] = 780552,
  [SMALL_STATE(20401)] = 780566,
  [SMALL_STATE(20402)] = 780580,
  [SMALL_STATE(20403)] = 780594,
  [SMALL_STATE(20404)] = 780608,
  [SMALL_STATE(20405)] = 780622,
  [SMALL_STATE(20406)] = 780636,
  [SMALL_STATE(20407)] = 780650,
  [SMALL_STATE(20408)] = 780664,
  [SMALL_STATE(20409)] = 780678,
  [SMALL_STATE(20410)] = 780692,
  [SMALL_STATE(20411)] = 780706,
  [SMALL_STATE(20412)] = 780720,
  [SMALL_STATE(20413)] = 780734,
  [SMALL_STATE(20414)] = 780748,
  [SMALL_STATE(20415)] = 780762,
  [SMALL_STATE(20416)] = 780776,
  [SMALL_STATE(20417)] = 780790,
  [SMALL_STATE(20418)] = 780804,
  [SMALL_STATE(20419)] = 780818,
  [SMALL_STATE(20420)] = 780832,
  [SMALL_STATE(20421)] = 780846,
  [SMALL_STATE(20422)] = 780860,
  [SMALL_STATE(20423)] = 780874,
  [SMALL_STATE(20424)] = 780888,
  [SMALL_STATE(20425)] = 780902,
  [SMALL_STATE(20426)] = 780916,
  [SMALL_STATE(20427)] = 780930,
  [SMALL_STATE(20428)] = 780944,
  [SMALL_STATE(20429)] = 780958,
  [SMALL_STATE(20430)] = 780972,
  [SMALL_STATE(20431)] = 780986,
  [SMALL_STATE(20432)] = 781000,
  [SMALL_STATE(20433)] = 781014,
  [SMALL_STATE(20434)] = 781028,
  [SMALL_STATE(20435)] = 781042,
  [SMALL_STATE(20436)] = 781056,
  [SMALL_STATE(20437)] = 781070,
  [SMALL_STATE(20438)] = 781084,
  [SMALL_STATE(20439)] = 781098,
  [SMALL_STATE(20440)] = 781112,
  [SMALL_STATE(20441)] = 781126,
  [SMALL_STATE(20442)] = 781140,
  [SMALL_STATE(20443)] = 781154,
  [SMALL_STATE(20444)] = 781168,
  [SMALL_STATE(20445)] = 781182,
  [SMALL_STATE(20446)] = 781196,
  [SMALL_STATE(20447)] = 781210,
  [SMALL_STATE(20448)] = 781224,
  [SMALL_STATE(20449)] = 781238,
  [SMALL_STATE(20450)] = 781252,
  [SMALL_STATE(20451)] = 781266,
  [SMALL_STATE(20452)] = 781280,
  [SMALL_STATE(20453)] = 781294,
  [SMALL_STATE(20454)] = 781308,
  [SMALL_STATE(20455)] = 781322,
  [SMALL_STATE(20456)] = 781336,
  [SMALL_STATE(20457)] = 781350,
  [SMALL_STATE(20458)] = 781364,
  [SMALL_STATE(20459)] = 781378,
  [SMALL_STATE(20460)] = 781392,
  [SMALL_STATE(20461)] = 781406,
  [SMALL_STATE(20462)] = 781420,
  [SMALL_STATE(20463)] = 781434,
  [SMALL_STATE(20464)] = 781448,
  [SMALL_STATE(20465)] = 781462,
  [SMALL_STATE(20466)] = 781476,
  [SMALL_STATE(20467)] = 781490,
  [SMALL_STATE(20468)] = 781504,
  [SMALL_STATE(20469)] = 781518,
  [SMALL_STATE(20470)] = 781532,
  [SMALL_STATE(20471)] = 781546,
  [SMALL_STATE(20472)] = 781560,
  [SMALL_STATE(20473)] = 781574,
  [SMALL_STATE(20474)] = 781588,
  [SMALL_STATE(20475)] = 781602,
  [SMALL_STATE(20476)] = 781616,
  [SMALL_STATE(20477)] = 781630,
  [SMALL_STATE(20478)] = 781644,
  [SMALL_STATE(20479)] = 781658,
  [SMALL_STATE(20480)] = 781672,
  [SMALL_STATE(20481)] = 781686,
  [SMALL_STATE(20482)] = 781700,
  [SMALL_STATE(20483)] = 781714,
  [SMALL_STATE(20484)] = 781728,
  [SMALL_STATE(20485)] = 781742,
  [SMALL_STATE(20486)] = 781756,
  [SMALL_STATE(20487)] = 781770,
  [SMALL_STATE(20488)] = 781784,
  [SMALL_STATE(20489)] = 781798,
  [SMALL_STATE(20490)] = 781812,
  [SMALL_STATE(20491)] = 781826,
  [SMALL_STATE(20492)] = 781840,
  [SMALL_STATE(20493)] = 781854,
  [SMALL_STATE(20494)] = 781868,
  [SMALL_STATE(20495)] = 781882,
  [SMALL_STATE(20496)] = 781896,
  [SMALL_STATE(20497)] = 781910,
  [SMALL_STATE(20498)] = 781924,
  [SMALL_STATE(20499)] = 781938,
  [SMALL_STATE(20500)] = 781952,
  [SMALL_STATE(20501)] = 781966,
  [SMALL_STATE(20502)] = 781980,
  [SMALL_STATE(20503)] = 781994,
  [SMALL_STATE(20504)] = 782008,
  [SMALL_STATE(20505)] = 782022,
  [SMALL_STATE(20506)] = 782036,
  [SMALL_STATE(20507)] = 782050,
  [SMALL_STATE(20508)] = 782064,
  [SMALL_STATE(20509)] = 782078,
  [SMALL_STATE(20510)] = 782092,
  [SMALL_STATE(20511)] = 782106,
  [SMALL_STATE(20512)] = 782120,
  [SMALL_STATE(20513)] = 782134,
  [SMALL_STATE(20514)] = 782148,
  [SMALL_STATE(20515)] = 782162,
  [SMALL_STATE(20516)] = 782176,
  [SMALL_STATE(20517)] = 782190,
  [SMALL_STATE(20518)] = 782204,
  [SMALL_STATE(20519)] = 782218,
  [SMALL_STATE(20520)] = 782232,
  [SMALL_STATE(20521)] = 782246,
  [SMALL_STATE(20522)] = 782260,
  [SMALL_STATE(20523)] = 782274,
  [SMALL_STATE(20524)] = 782288,
  [SMALL_STATE(20525)] = 782302,
  [SMALL_STATE(20526)] = 782316,
  [SMALL_STATE(20527)] = 782330,
  [SMALL_STATE(20528)] = 782344,
  [SMALL_STATE(20529)] = 782358,
  [SMALL_STATE(20530)] = 782372,
  [SMALL_STATE(20531)] = 782386,
  [SMALL_STATE(20532)] = 782400,
  [SMALL_STATE(20533)] = 782414,
  [SMALL_STATE(20534)] = 782428,
  [SMALL_STATE(20535)] = 782442,
  [SMALL_STATE(20536)] = 782456,
  [SMALL_STATE(20537)] = 782470,
  [SMALL_STATE(20538)] = 782484,
  [SMALL_STATE(20539)] = 782498,
  [SMALL_STATE(20540)] = 782512,
  [SMALL_STATE(20541)] = 782526,
  [SMALL_STATE(20542)] = 782540,
  [SMALL_STATE(20543)] = 782554,
  [SMALL_STATE(20544)] = 782568,
  [SMALL_STATE(20545)] = 782582,
  [SMALL_STATE(20546)] = 782596,
  [SMALL_STATE(20547)] = 782610,
  [SMALL_STATE(20548)] = 782624,
  [SMALL_STATE(20549)] = 782638,
  [SMALL_STATE(20550)] = 782652,
  [SMALL_STATE(20551)] = 782666,
  [SMALL_STATE(20552)] = 782680,
  [SMALL_STATE(20553)] = 782694,
  [SMALL_STATE(20554)] = 782708,
  [SMALL_STATE(20555)] = 782722,
  [SMALL_STATE(20556)] = 782736,
  [SMALL_STATE(20557)] = 782750,
  [SMALL_STATE(20558)] = 782764,
  [SMALL_STATE(20559)] = 782778,
  [SMALL_STATE(20560)] = 782792,
  [SMALL_STATE(20561)] = 782806,
  [SMALL_STATE(20562)] = 782820,
  [SMALL_STATE(20563)] = 782834,
  [SMALL_STATE(20564)] = 782848,
  [SMALL_STATE(20565)] = 782862,
  [SMALL_STATE(20566)] = 782876,
  [SMALL_STATE(20567)] = 782890,
  [SMALL_STATE(20568)] = 782904,
  [SMALL_STATE(20569)] = 782918,
  [SMALL_STATE(20570)] = 782932,
  [SMALL_STATE(20571)] = 782946,
  [SMALL_STATE(20572)] = 782960,
  [SMALL_STATE(20573)] = 782974,
  [SMALL_STATE(20574)] = 782988,
  [SMALL_STATE(20575)] = 783002,
  [SMALL_STATE(20576)] = 783016,
  [SMALL_STATE(20577)] = 783030,
  [SMALL_STATE(20578)] = 783044,
  [SMALL_STATE(20579)] = 783058,
  [SMALL_STATE(20580)] = 783072,
  [SMALL_STATE(20581)] = 783086,
  [SMALL_STATE(20582)] = 783100,
  [SMALL_STATE(20583)] = 783114,
  [SMALL_STATE(20584)] = 783128,
  [SMALL_STATE(20585)] = 783142,
  [SMALL_STATE(20586)] = 783156,
  [SMALL_STATE(20587)] = 783170,
  [SMALL_STATE(20588)] = 783184,
  [SMALL_STATE(20589)] = 783198,
  [SMALL_STATE(20590)] = 783212,
  [SMALL_STATE(20591)] = 783226,
  [SMALL_STATE(20592)] = 783240,
  [SMALL_STATE(20593)] = 783254,
  [SMALL_STATE(20594)] = 783268,
  [SMALL_STATE(20595)] = 783282,
  [SMALL_STATE(20596)] = 783296,
  [SMALL_STATE(20597)] = 783310,
  [SMALL_STATE(20598)] = 783324,
  [SMALL_STATE(20599)] = 783338,
  [SMALL_STATE(20600)] = 783352,
  [SMALL_STATE(20601)] = 783366,
  [SMALL_STATE(20602)] = 783380,
  [SMALL_STATE(20603)] = 783394,
  [SMALL_STATE(20604)] = 783408,
  [SMALL_STATE(20605)] = 783422,
  [SMALL_STATE(20606)] = 783436,
  [SMALL_STATE(20607)] = 783450,
  [SMALL_STATE(20608)] = 783464,
  [SMALL_STATE(20609)] = 783478,
  [SMALL_STATE(20610)] = 783492,
  [SMALL_STATE(20611)] = 783506,
  [SMALL_STATE(20612)] = 783520,
  [SMALL_STATE(20613)] = 783534,
  [SMALL_STATE(20614)] = 783548,
  [SMALL_STATE(20615)] = 783562,
  [SMALL_STATE(20616)] = 783576,
  [SMALL_STATE(20617)] = 783590,
  [SMALL_STATE(20618)] = 783604,
  [SMALL_STATE(20619)] = 783618,
  [SMALL_STATE(20620)] = 783632,
  [SMALL_STATE(20621)] = 783646,
  [SMALL_STATE(20622)] = 783660,
  [SMALL_STATE(20623)] = 783674,
  [SMALL_STATE(20624)] = 783688,
  [SMALL_STATE(20625)] = 783702,
  [SMALL_STATE(20626)] = 783716,
  [SMALL_STATE(20627)] = 783730,
  [SMALL_STATE(20628)] = 783744,
  [SMALL_STATE(20629)] = 783758,
  [SMALL_STATE(20630)] = 783772,
  [SMALL_STATE(20631)] = 783786,
  [SMALL_STATE(20632)] = 783800,
  [SMALL_STATE(20633)] = 783814,
  [SMALL_STATE(20634)] = 783828,
  [SMALL_STATE(20635)] = 783842,
  [SMALL_STATE(20636)] = 783856,
  [SMALL_STATE(20637)] = 783870,
  [SMALL_STATE(20638)] = 783884,
  [SMALL_STATE(20639)] = 783898,
  [SMALL_STATE(20640)] = 783912,
  [SMALL_STATE(20641)] = 783926,
  [SMALL_STATE(20642)] = 783940,
  [SMALL_STATE(20643)] = 783954,
  [SMALL_STATE(20644)] = 783968,
  [SMALL_STATE(20645)] = 783982,
  [SMALL_STATE(20646)] = 783996,
  [SMALL_STATE(20647)] = 784010,
  [SMALL_STATE(20648)] = 784024,
  [SMALL_STATE(20649)] = 784038,
  [SMALL_STATE(20650)] = 784052,
  [SMALL_STATE(20651)] = 784066,
  [SMALL_STATE(20652)] = 784080,
  [SMALL_STATE(20653)] = 784094,
  [SMALL_STATE(20654)] = 784108,
  [SMALL_STATE(20655)] = 784122,
  [SMALL_STATE(20656)] = 784136,
  [SMALL_STATE(20657)] = 784150,
  [SMALL_STATE(20658)] = 784164,
  [SMALL_STATE(20659)] = 784178,
  [SMALL_STATE(20660)] = 784192,
  [SMALL_STATE(20661)] = 784206,
  [SMALL_STATE(20662)] = 784220,
  [SMALL_STATE(20663)] = 784234,
  [SMALL_STATE(20664)] = 784248,
  [SMALL_STATE(20665)] = 784262,
  [SMALL_STATE(20666)] = 784276,
  [SMALL_STATE(20667)] = 784290,
  [SMALL_STATE(20668)] = 784304,
  [SMALL_STATE(20669)] = 784318,
  [SMALL_STATE(20670)] = 784332,
  [SMALL_STATE(20671)] = 784346,
  [SMALL_STATE(20672)] = 784360,
  [SMALL_STATE(20673)] = 784374,
  [SMALL_STATE(20674)] = 784388,
  [SMALL_STATE(20675)] = 784402,
  [SMALL_STATE(20676)] = 784416,
  [SMALL_STATE(20677)] = 784430,
  [SMALL_STATE(20678)] = 784444,
  [SMALL_STATE(20679)] = 784458,
  [SMALL_STATE(20680)] = 784472,
  [SMALL_STATE(20681)] = 784486,
  [SMALL_STATE(20682)] = 784500,
  [SMALL_STATE(20683)] = 784514,
  [SMALL_STATE(20684)] = 784528,
  [SMALL_STATE(20685)] = 784542,
  [SMALL_STATE(20686)] = 784556,
  [SMALL_STATE(20687)] = 784570,
  [SMALL_STATE(20688)] = 784584,
  [SMALL_STATE(20689)] = 784598,
  [SMALL_STATE(20690)] = 784612,
  [SMALL_STATE(20691)] = 784626,
  [SMALL_STATE(20692)] = 784640,
  [SMALL_STATE(20693)] = 784654,
  [SMALL_STATE(20694)] = 784668,
  [SMALL_STATE(20695)] = 784682,
  [SMALL_STATE(20696)] = 784696,
  [SMALL_STATE(20697)] = 784710,
  [SMALL_STATE(20698)] = 784724,
  [SMALL_STATE(20699)] = 784738,
  [SMALL_STATE(20700)] = 784752,
  [SMALL_STATE(20701)] = 784766,
  [SMALL_STATE(20702)] = 784780,
  [SMALL_STATE(20703)] = 784794,
  [SMALL_STATE(20704)] = 784808,
  [SMALL_STATE(20705)] = 784822,
  [SMALL_STATE(20706)] = 784836,
  [SMALL_STATE(20707)] = 784850,
  [SMALL_STATE(20708)] = 784864,
  [SMALL_STATE(20709)] = 784878,
  [SMALL_STATE(20710)] = 784892,
  [SMALL_STATE(20711)] = 784906,
  [SMALL_STATE(20712)] = 784920,
  [SMALL_STATE(20713)] = 784934,
  [SMALL_STATE(20714)] = 784948,
  [SMALL_STATE(20715)] = 784962,
  [SMALL_STATE(20716)] = 784976,
  [SMALL_STATE(20717)] = 784990,
  [SMALL_STATE(20718)] = 785004,
  [SMALL_STATE(20719)] = 785018,
  [SMALL_STATE(20720)] = 785032,
  [SMALL_STATE(20721)] = 785046,
  [SMALL_STATE(20722)] = 785060,
  [SMALL_STATE(20723)] = 785074,
  [SMALL_STATE(20724)] = 785088,
  [SMALL_STATE(20725)] = 785102,
  [SMALL_STATE(20726)] = 785116,
  [SMALL_STATE(20727)] = 785130,
  [SMALL_STATE(20728)] = 785144,
  [SMALL_STATE(20729)] = 785158,
  [SMALL_STATE(20730)] = 785172,
  [SMALL_STATE(20731)] = 785186,
  [SMALL_STATE(20732)] = 785200,
  [SMALL_STATE(20733)] = 785214,
  [SMALL_STATE(20734)] = 785228,
  [SMALL_STATE(20735)] = 785242,
  [SMALL_STATE(20736)] = 785256,
  [SMALL_STATE(20737)] = 785270,
  [SMALL_STATE(20738)] = 785284,
  [SMALL_STATE(20739)] = 785298,
  [SMALL_STATE(20740)] = 785312,
  [SMALL_STATE(20741)] = 785326,
  [SMALL_STATE(20742)] = 785340,
  [SMALL_STATE(20743)] = 785354,
  [SMALL_STATE(20744)] = 785368,
  [SMALL_STATE(20745)] = 785382,
  [SMALL_STATE(20746)] = 785396,
  [SMALL_STATE(20747)] = 785410,
  [SMALL_STATE(20748)] = 785424,
  [SMALL_STATE(20749)] = 785438,
  [SMALL_STATE(20750)] = 785452,
  [SMALL_STATE(20751)] = 785466,
  [SMALL_STATE(20752)] = 785480,
  [SMALL_STATE(20753)] = 785494,
  [SMALL_STATE(20754)] = 785508,
  [SMALL_STATE(20755)] = 785522,
  [SMALL_STATE(20756)] = 785536,
  [SMALL_STATE(20757)] = 785550,
  [SMALL_STATE(20758)] = 785564,
  [SMALL_STATE(20759)] = 785578,
  [SMALL_STATE(20760)] = 785592,
  [SMALL_STATE(20761)] = 785606,
  [SMALL_STATE(20762)] = 785620,
  [SMALL_STATE(20763)] = 785634,
  [SMALL_STATE(20764)] = 785648,
  [SMALL_STATE(20765)] = 785662,
  [SMALL_STATE(20766)] = 785676,
  [SMALL_STATE(20767)] = 785690,
  [SMALL_STATE(20768)] = 785704,
  [SMALL_STATE(20769)] = 785718,
  [SMALL_STATE(20770)] = 785732,
  [SMALL_STATE(20771)] = 785746,
  [SMALL_STATE(20772)] = 785760,
  [SMALL_STATE(20773)] = 785774,
  [SMALL_STATE(20774)] = 785788,
  [SMALL_STATE(20775)] = 785802,
  [SMALL_STATE(20776)] = 785816,
  [SMALL_STATE(20777)] = 785830,
  [SMALL_STATE(20778)] = 785844,
  [SMALL_STATE(20779)] = 785858,
  [SMALL_STATE(20780)] = 785872,
  [SMALL_STATE(20781)] = 785886,
  [SMALL_STATE(20782)] = 785900,
  [SMALL_STATE(20783)] = 785914,
  [SMALL_STATE(20784)] = 785928,
  [SMALL_STATE(20785)] = 785942,
  [SMALL_STATE(20786)] = 785956,
  [SMALL_STATE(20787)] = 785970,
  [SMALL_STATE(20788)] = 785984,
  [SMALL_STATE(20789)] = 785998,
  [SMALL_STATE(20790)] = 786012,
  [SMALL_STATE(20791)] = 786026,
  [SMALL_STATE(20792)] = 786040,
  [SMALL_STATE(20793)] = 786054,
  [SMALL_STATE(20794)] = 786068,
  [SMALL_STATE(20795)] = 786082,
  [SMALL_STATE(20796)] = 786096,
  [SMALL_STATE(20797)] = 786110,
  [SMALL_STATE(20798)] = 786124,
  [SMALL_STATE(20799)] = 786138,
  [SMALL_STATE(20800)] = 786152,
  [SMALL_STATE(20801)] = 786166,
  [SMALL_STATE(20802)] = 786180,
  [SMALL_STATE(20803)] = 786194,
  [SMALL_STATE(20804)] = 786208,
  [SMALL_STATE(20805)] = 786222,
  [SMALL_STATE(20806)] = 786236,
  [SMALL_STATE(20807)] = 786250,
  [SMALL_STATE(20808)] = 786264,
  [SMALL_STATE(20809)] = 786278,
  [SMALL_STATE(20810)] = 786292,
  [SMALL_STATE(20811)] = 786306,
  [SMALL_STATE(20812)] = 786320,
  [SMALL_STATE(20813)] = 786334,
  [SMALL_STATE(20814)] = 786348,
  [SMALL_STATE(20815)] = 786362,
  [SMALL_STATE(20816)] = 786376,
  [SMALL_STATE(20817)] = 786390,
  [SMALL_STATE(20818)] = 786404,
  [SMALL_STATE(20819)] = 786418,
  [SMALL_STATE(20820)] = 786432,
  [SMALL_STATE(20821)] = 786446,
  [SMALL_STATE(20822)] = 786460,
  [SMALL_STATE(20823)] = 786474,
  [SMALL_STATE(20824)] = 786488,
  [SMALL_STATE(20825)] = 786502,
  [SMALL_STATE(20826)] = 786516,
  [SMALL_STATE(20827)] = 786530,
  [SMALL_STATE(20828)] = 786544,
  [SMALL_STATE(20829)] = 786558,
  [SMALL_STATE(20830)] = 786572,
  [SMALL_STATE(20831)] = 786586,
  [SMALL_STATE(20832)] = 786600,
  [SMALL_STATE(20833)] = 786614,
  [SMALL_STATE(20834)] = 786628,
  [SMALL_STATE(20835)] = 786642,
  [SMALL_STATE(20836)] = 786656,
  [SMALL_STATE(20837)] = 786670,
  [SMALL_STATE(20838)] = 786684,
  [SMALL_STATE(20839)] = 786698,
  [SMALL_STATE(20840)] = 786712,
  [SMALL_STATE(20841)] = 786726,
  [SMALL_STATE(20842)] = 786740,
  [SMALL_STATE(20843)] = 786754,
  [SMALL_STATE(20844)] = 786768,
  [SMALL_STATE(20845)] = 786782,
  [SMALL_STATE(20846)] = 786796,
  [SMALL_STATE(20847)] = 786810,
  [SMALL_STATE(20848)] = 786824,
  [SMALL_STATE(20849)] = 786838,
  [SMALL_STATE(20850)] = 786852,
  [SMALL_STATE(20851)] = 786866,
  [SMALL_STATE(20852)] = 786880,
  [SMALL_STATE(20853)] = 786894,
  [SMALL_STATE(20854)] = 786908,
  [SMALL_STATE(20855)] = 786922,
  [SMALL_STATE(20856)] = 786936,
  [SMALL_STATE(20857)] = 786950,
  [SMALL_STATE(20858)] = 786964,
  [SMALL_STATE(20859)] = 786978,
  [SMALL_STATE(20860)] = 786992,
  [SMALL_STATE(20861)] = 787006,
  [SMALL_STATE(20862)] = 787020,
  [SMALL_STATE(20863)] = 787034,
  [SMALL_STATE(20864)] = 787048,
  [SMALL_STATE(20865)] = 787062,
  [SMALL_STATE(20866)] = 787076,
  [SMALL_STATE(20867)] = 787090,
  [SMALL_STATE(20868)] = 787104,
  [SMALL_STATE(20869)] = 787118,
  [SMALL_STATE(20870)] = 787132,
  [SMALL_STATE(20871)] = 787146,
  [SMALL_STATE(20872)] = 787160,
  [SMALL_STATE(20873)] = 787174,
  [SMALL_STATE(20874)] = 787188,
  [SMALL_STATE(20875)] = 787202,
  [SMALL_STATE(20876)] = 787216,
  [SMALL_STATE(20877)] = 787230,
  [SMALL_STATE(20878)] = 787244,
  [SMALL_STATE(20879)] = 787258,
  [SMALL_STATE(20880)] = 787272,
  [SMALL_STATE(20881)] = 787286,
  [SMALL_STATE(20882)] = 787300,
  [SMALL_STATE(20883)] = 787314,
  [SMALL_STATE(20884)] = 787328,
  [SMALL_STATE(20885)] = 787342,
  [SMALL_STATE(20886)] = 787356,
  [SMALL_STATE(20887)] = 787370,
  [SMALL_STATE(20888)] = 787384,
  [SMALL_STATE(20889)] = 787398,
  [SMALL_STATE(20890)] = 787412,
  [SMALL_STATE(20891)] = 787426,
  [SMALL_STATE(20892)] = 787440,
  [SMALL_STATE(20893)] = 787454,
  [SMALL_STATE(20894)] = 787468,
  [SMALL_STATE(20895)] = 787482,
  [SMALL_STATE(20896)] = 787496,
  [SMALL_STATE(20897)] = 787510,
  [SMALL_STATE(20898)] = 787524,
  [SMALL_STATE(20899)] = 787538,
  [SMALL_STATE(20900)] = 787552,
  [SMALL_STATE(20901)] = 787566,
  [SMALL_STATE(20902)] = 787580,
  [SMALL_STATE(20903)] = 787594,
  [SMALL_STATE(20904)] = 787608,
  [SMALL_STATE(20905)] = 787622,
  [SMALL_STATE(20906)] = 787636,
  [SMALL_STATE(20907)] = 787650,
  [SMALL_STATE(20908)] = 787664,
  [SMALL_STATE(20909)] = 787678,
  [SMALL_STATE(20910)] = 787692,
  [SMALL_STATE(20911)] = 787706,
  [SMALL_STATE(20912)] = 787720,
  [SMALL_STATE(20913)] = 787734,
  [SMALL_STATE(20914)] = 787748,
  [SMALL_STATE(20915)] = 787762,
  [SMALL_STATE(20916)] = 787776,
  [SMALL_STATE(20917)] = 787790,
  [SMALL_STATE(20918)] = 787804,
  [SMALL_STATE(20919)] = 787818,
  [SMALL_STATE(20920)] = 787832,
  [SMALL_STATE(20921)] = 787846,
  [SMALL_STATE(20922)] = 787860,
  [SMALL_STATE(20923)] = 787874,
  [SMALL_STATE(20924)] = 787888,
  [SMALL_STATE(20925)] = 787902,
  [SMALL_STATE(20926)] = 787916,
  [SMALL_STATE(20927)] = 787930,
  [SMALL_STATE(20928)] = 787944,
  [SMALL_STATE(20929)] = 787958,
  [SMALL_STATE(20930)] = 787972,
  [SMALL_STATE(20931)] = 787986,
  [SMALL_STATE(20932)] = 788000,
  [SMALL_STATE(20933)] = 788014,
  [SMALL_STATE(20934)] = 788028,
  [SMALL_STATE(20935)] = 788042,
  [SMALL_STATE(20936)] = 788056,
  [SMALL_STATE(20937)] = 788070,
  [SMALL_STATE(20938)] = 788084,
  [SMALL_STATE(20939)] = 788098,
  [SMALL_STATE(20940)] = 788112,
  [SMALL_STATE(20941)] = 788126,
  [SMALL_STATE(20942)] = 788140,
  [SMALL_STATE(20943)] = 788154,
  [SMALL_STATE(20944)] = 788168,
  [SMALL_STATE(20945)] = 788182,
  [SMALL_STATE(20946)] = 788196,
  [SMALL_STATE(20947)] = 788210,
  [SMALL_STATE(20948)] = 788224,
  [SMALL_STATE(20949)] = 788238,
  [SMALL_STATE(20950)] = 788252,
  [SMALL_STATE(20951)] = 788266,
  [SMALL_STATE(20952)] = 788280,
  [SMALL_STATE(20953)] = 788294,
  [SMALL_STATE(20954)] = 788308,
  [SMALL_STATE(20955)] = 788322,
  [SMALL_STATE(20956)] = 788336,
  [SMALL_STATE(20957)] = 788350,
  [SMALL_STATE(20958)] = 788364,
  [SMALL_STATE(20959)] = 788378,
  [SMALL_STATE(20960)] = 788392,
  [SMALL_STATE(20961)] = 788406,
  [SMALL_STATE(20962)] = 788420,
  [SMALL_STATE(20963)] = 788434,
  [SMALL_STATE(20964)] = 788448,
  [SMALL_STATE(20965)] = 788462,
  [SMALL_STATE(20966)] = 788476,
  [SMALL_STATE(20967)] = 788490,
  [SMALL_STATE(20968)] = 788504,
  [SMALL_STATE(20969)] = 788518,
  [SMALL_STATE(20970)] = 788532,
  [SMALL_STATE(20971)] = 788546,
  [SMALL_STATE(20972)] = 788560,
  [SMALL_STATE(20973)] = 788574,
  [SMALL_STATE(20974)] = 788588,
  [SMALL_STATE(20975)] = 788602,
  [SMALL_STATE(20976)] = 788616,
  [SMALL_STATE(20977)] = 788630,
  [SMALL_STATE(20978)] = 788644,
  [SMALL_STATE(20979)] = 788658,
  [SMALL_STATE(20980)] = 788672,
  [SMALL_STATE(20981)] = 788686,
  [SMALL_STATE(20982)] = 788700,
  [SMALL_STATE(20983)] = 788714,
  [SMALL_STATE(20984)] = 788728,
  [SMALL_STATE(20985)] = 788742,
  [SMALL_STATE(20986)] = 788756,
  [SMALL_STATE(20987)] = 788770,
  [SMALL_STATE(20988)] = 788784,
  [SMALL_STATE(20989)] = 788798,
  [SMALL_STATE(20990)] = 788812,
  [SMALL_STATE(20991)] = 788826,
  [SMALL_STATE(20992)] = 788840,
  [SMALL_STATE(20993)] = 788854,
  [SMALL_STATE(20994)] = 788868,
  [SMALL_STATE(20995)] = 788882,
  [SMALL_STATE(20996)] = 788896,
  [SMALL_STATE(20997)] = 788910,
  [SMALL_STATE(20998)] = 788924,
  [SMALL_STATE(20999)] = 788938,
  [SMALL_STATE(21000)] = 788952,
  [SMALL_STATE(21001)] = 788966,
  [SMALL_STATE(21002)] = 788980,
  [SMALL_STATE(21003)] = 788994,
  [SMALL_STATE(21004)] = 789008,
  [SMALL_STATE(21005)] = 789022,
  [SMALL_STATE(21006)] = 789036,
  [SMALL_STATE(21007)] = 789050,
  [SMALL_STATE(21008)] = 789064,
  [SMALL_STATE(21009)] = 789078,
  [SMALL_STATE(21010)] = 789092,
  [SMALL_STATE(21011)] = 789106,
  [SMALL_STATE(21012)] = 789120,
  [SMALL_STATE(21013)] = 789134,
  [SMALL_STATE(21014)] = 789148,
  [SMALL_STATE(21015)] = 789162,
  [SMALL_STATE(21016)] = 789176,
  [SMALL_STATE(21017)] = 789190,
  [SMALL_STATE(21018)] = 789204,
  [SMALL_STATE(21019)] = 789218,
  [SMALL_STATE(21020)] = 789232,
  [SMALL_STATE(21021)] = 789246,
  [SMALL_STATE(21022)] = 789260,
  [SMALL_STATE(21023)] = 789274,
  [SMALL_STATE(21024)] = 789288,
  [SMALL_STATE(21025)] = 789302,
  [SMALL_STATE(21026)] = 789316,
  [SMALL_STATE(21027)] = 789330,
  [SMALL_STATE(21028)] = 789344,
  [SMALL_STATE(21029)] = 789358,
  [SMALL_STATE(21030)] = 789372,
  [SMALL_STATE(21031)] = 789386,
  [SMALL_STATE(21032)] = 789400,
  [SMALL_STATE(21033)] = 789414,
  [SMALL_STATE(21034)] = 789428,
  [SMALL_STATE(21035)] = 789442,
  [SMALL_STATE(21036)] = 789456,
  [SMALL_STATE(21037)] = 789470,
  [SMALL_STATE(21038)] = 789484,
  [SMALL_STATE(21039)] = 789498,
  [SMALL_STATE(21040)] = 789512,
  [SMALL_STATE(21041)] = 789526,
  [SMALL_STATE(21042)] = 789540,
  [SMALL_STATE(21043)] = 789554,
  [SMALL_STATE(21044)] = 789568,
  [SMALL_STATE(21045)] = 789582,
  [SMALL_STATE(21046)] = 789596,
  [SMALL_STATE(21047)] = 789610,
  [SMALL_STATE(21048)] = 789624,
  [SMALL_STATE(21049)] = 789638,
  [SMALL_STATE(21050)] = 789652,
  [SMALL_STATE(21051)] = 789666,
  [SMALL_STATE(21052)] = 789680,
  [SMALL_STATE(21053)] = 789694,
  [SMALL_STATE(21054)] = 789708,
  [SMALL_STATE(21055)] = 789722,
  [SMALL_STATE(21056)] = 789736,
  [SMALL_STATE(21057)] = 789750,
  [SMALL_STATE(21058)] = 789764,
  [SMALL_STATE(21059)] = 789778,
  [SMALL_STATE(21060)] = 789792,
  [SMALL_STATE(21061)] = 789806,
  [SMALL_STATE(21062)] = 789820,
  [SMALL_STATE(21063)] = 789834,
  [SMALL_STATE(21064)] = 789848,
  [SMALL_STATE(21065)] = 789862,
  [SMALL_STATE(21066)] = 789876,
  [SMALL_STATE(21067)] = 789890,
  [SMALL_STATE(21068)] = 789904,
  [SMALL_STATE(21069)] = 789918,
  [SMALL_STATE(21070)] = 789932,
  [SMALL_STATE(21071)] = 789946,
  [SMALL_STATE(21072)] = 789960,
  [SMALL_STATE(21073)] = 789974,
  [SMALL_STATE(21074)] = 789988,
  [SMALL_STATE(21075)] = 790002,
  [SMALL_STATE(21076)] = 790016,
  [SMALL_STATE(21077)] = 790030,
  [SMALL_STATE(21078)] = 790044,
  [SMALL_STATE(21079)] = 790058,
  [SMALL_STATE(21080)] = 790072,
  [SMALL_STATE(21081)] = 790086,
  [SMALL_STATE(21082)] = 790100,
  [SMALL_STATE(21083)] = 790114,
  [SMALL_STATE(21084)] = 790128,
  [SMALL_STATE(21085)] = 790142,
  [SMALL_STATE(21086)] = 790156,
  [SMALL_STATE(21087)] = 790170,
  [SMALL_STATE(21088)] = 790184,
  [SMALL_STATE(21089)] = 790198,
  [SMALL_STATE(21090)] = 790212,
  [SMALL_STATE(21091)] = 790226,
  [SMALL_STATE(21092)] = 790240,
  [SMALL_STATE(21093)] = 790254,
  [SMALL_STATE(21094)] = 790268,
  [SMALL_STATE(21095)] = 790282,
  [SMALL_STATE(21096)] = 790296,
  [SMALL_STATE(21097)] = 790310,
  [SMALL_STATE(21098)] = 790324,
  [SMALL_STATE(21099)] = 790338,
  [SMALL_STATE(21100)] = 790352,
  [SMALL_STATE(21101)] = 790366,
  [SMALL_STATE(21102)] = 790380,
  [SMALL_STATE(21103)] = 790394,
  [SMALL_STATE(21104)] = 790408,
  [SMALL_STATE(21105)] = 790422,
  [SMALL_STATE(21106)] = 790436,
  [SMALL_STATE(21107)] = 790450,
  [SMALL_STATE(21108)] = 790464,
  [SMALL_STATE(21109)] = 790478,
  [SMALL_STATE(21110)] = 790492,
  [SMALL_STATE(21111)] = 790506,
  [SMALL_STATE(21112)] = 790520,
  [SMALL_STATE(21113)] = 790534,
  [SMALL_STATE(21114)] = 790548,
  [SMALL_STATE(21115)] = 790562,
  [SMALL_STATE(21116)] = 790576,
  [SMALL_STATE(21117)] = 790590,
  [SMALL_STATE(21118)] = 790604,
  [SMALL_STATE(21119)] = 790618,
  [SMALL_STATE(21120)] = 790632,
  [SMALL_STATE(21121)] = 790646,
  [SMALL_STATE(21122)] = 790660,
  [SMALL_STATE(21123)] = 790674,
  [SMALL_STATE(21124)] = 790688,
  [SMALL_STATE(21125)] = 790702,
  [SMALL_STATE(21126)] = 790716,
  [SMALL_STATE(21127)] = 790730,
  [SMALL_STATE(21128)] = 790744,
  [SMALL_STATE(21129)] = 790758,
  [SMALL_STATE(21130)] = 790772,
  [SMALL_STATE(21131)] = 790786,
  [SMALL_STATE(21132)] = 790800,
  [SMALL_STATE(21133)] = 790814,
  [SMALL_STATE(21134)] = 790828,
  [SMALL_STATE(21135)] = 790842,
  [SMALL_STATE(21136)] = 790856,
  [SMALL_STATE(21137)] = 790870,
  [SMALL_STATE(21138)] = 790884,
  [SMALL_STATE(21139)] = 790898,
  [SMALL_STATE(21140)] = 790912,
  [SMALL_STATE(21141)] = 790926,
  [SMALL_STATE(21142)] = 790940,
  [SMALL_STATE(21143)] = 790954,
  [SMALL_STATE(21144)] = 790968,
  [SMALL_STATE(21145)] = 790982,
  [SMALL_STATE(21146)] = 790996,
  [SMALL_STATE(21147)] = 791010,
  [SMALL_STATE(21148)] = 791024,
  [SMALL_STATE(21149)] = 791038,
  [SMALL_STATE(21150)] = 791052,
  [SMALL_STATE(21151)] = 791066,
  [SMALL_STATE(21152)] = 791080,
  [SMALL_STATE(21153)] = 791094,
  [SMALL_STATE(21154)] = 791108,
  [SMALL_STATE(21155)] = 791122,
  [SMALL_STATE(21156)] = 791136,
  [SMALL_STATE(21157)] = 791150,
  [SMALL_STATE(21158)] = 791164,
  [SMALL_STATE(21159)] = 791178,
  [SMALL_STATE(21160)] = 791192,
  [SMALL_STATE(21161)] = 791206,
  [SMALL_STATE(21162)] = 791220,
  [SMALL_STATE(21163)] = 791234,
  [SMALL_STATE(21164)] = 791248,
  [SMALL_STATE(21165)] = 791262,
  [SMALL_STATE(21166)] = 791276,
  [SMALL_STATE(21167)] = 791290,
  [SMALL_STATE(21168)] = 791304,
  [SMALL_STATE(21169)] = 791318,
  [SMALL_STATE(21170)] = 791332,
  [SMALL_STATE(21171)] = 791346,
  [SMALL_STATE(21172)] = 791360,
  [SMALL_STATE(21173)] = 791374,
  [SMALL_STATE(21174)] = 791388,
  [SMALL_STATE(21175)] = 791402,
  [SMALL_STATE(21176)] = 791416,
  [SMALL_STATE(21177)] = 791430,
  [SMALL_STATE(21178)] = 791444,
  [SMALL_STATE(21179)] = 791458,
  [SMALL_STATE(21180)] = 791472,
  [SMALL_STATE(21181)] = 791486,
  [SMALL_STATE(21182)] = 791500,
  [SMALL_STATE(21183)] = 791514,
  [SMALL_STATE(21184)] = 791528,
  [SMALL_STATE(21185)] = 791542,
  [SMALL_STATE(21186)] = 791556,
  [SMALL_STATE(21187)] = 791570,
  [SMALL_STATE(21188)] = 791584,
  [SMALL_STATE(21189)] = 791598,
  [SMALL_STATE(21190)] = 791612,
  [SMALL_STATE(21191)] = 791626,
  [SMALL_STATE(21192)] = 791640,
  [SMALL_STATE(21193)] = 791654,
  [SMALL_STATE(21194)] = 791668,
  [SMALL_STATE(21195)] = 791682,
  [SMALL_STATE(21196)] = 791696,
  [SMALL_STATE(21197)] = 791710,
  [SMALL_STATE(21198)] = 791724,
  [SMALL_STATE(21199)] = 791738,
  [SMALL_STATE(21200)] = 791752,
  [SMALL_STATE(21201)] = 791766,
  [SMALL_STATE(21202)] = 791780,
  [SMALL_STATE(21203)] = 791794,
  [SMALL_STATE(21204)] = 791808,
  [SMALL_STATE(21205)] = 791822,
  [SMALL_STATE(21206)] = 791836,
  [SMALL_STATE(21207)] = 791850,
  [SMALL_STATE(21208)] = 791864,
  [SMALL_STATE(21209)] = 791878,
  [SMALL_STATE(21210)] = 791892,
  [SMALL_STATE(21211)] = 791906,
  [SMALL_STATE(21212)] = 791920,
  [SMALL_STATE(21213)] = 791934,
  [SMALL_STATE(21214)] = 791948,
  [SMALL_STATE(21215)] = 791962,
  [SMALL_STATE(21216)] = 791976,
  [SMALL_STATE(21217)] = 791990,
  [SMALL_STATE(21218)] = 792004,
  [SMALL_STATE(21219)] = 792018,
  [SMALL_STATE(21220)] = 792032,
  [SMALL_STATE(21221)] = 792046,
  [SMALL_STATE(21222)] = 792060,
  [SMALL_STATE(21223)] = 792074,
  [SMALL_STATE(21224)] = 792088,
  [SMALL_STATE(21225)] = 792102,
  [SMALL_STATE(21226)] = 792116,
  [SMALL_STATE(21227)] = 792130,
  [SMALL_STATE(21228)] = 792144,
  [SMALL_STATE(21229)] = 792158,
  [SMALL_STATE(21230)] = 792172,
  [SMALL_STATE(21231)] = 792186,
  [SMALL_STATE(21232)] = 792200,
  [SMALL_STATE(21233)] = 792214,
  [SMALL_STATE(21234)] = 792228,
  [SMALL_STATE(21235)] = 792242,
  [SMALL_STATE(21236)] = 792256,
  [SMALL_STATE(21237)] = 792270,
  [SMALL_STATE(21238)] = 792284,
  [SMALL_STATE(21239)] = 792298,
  [SMALL_STATE(21240)] = 792312,
  [SMALL_STATE(21241)] = 792326,
  [SMALL_STATE(21242)] = 792340,
  [SMALL_STATE(21243)] = 792354,
  [SMALL_STATE(21244)] = 792368,
  [SMALL_STATE(21245)] = 792382,
  [SMALL_STATE(21246)] = 792396,
  [SMALL_STATE(21247)] = 792410,
  [SMALL_STATE(21248)] = 792424,
  [SMALL_STATE(21249)] = 792438,
  [SMALL_STATE(21250)] = 792452,
  [SMALL_STATE(21251)] = 792466,
  [SMALL_STATE(21252)] = 792480,
  [SMALL_STATE(21253)] = 792494,
  [SMALL_STATE(21254)] = 792508,
  [SMALL_STATE(21255)] = 792522,
  [SMALL_STATE(21256)] = 792536,
  [SMALL_STATE(21257)] = 792550,
  [SMALL_STATE(21258)] = 792564,
  [SMALL_STATE(21259)] = 792578,
  [SMALL_STATE(21260)] = 792592,
  [SMALL_STATE(21261)] = 792606,
  [SMALL_STATE(21262)] = 792620,
  [SMALL_STATE(21263)] = 792634,
  [SMALL_STATE(21264)] = 792648,
  [SMALL_STATE(21265)] = 792662,
  [SMALL_STATE(21266)] = 792676,
  [SMALL_STATE(21267)] = 792690,
  [SMALL_STATE(21268)] = 792704,
  [SMALL_STATE(21269)] = 792718,
  [SMALL_STATE(21270)] = 792732,
  [SMALL_STATE(21271)] = 792746,
  [SMALL_STATE(21272)] = 792760,
  [SMALL_STATE(21273)] = 792774,
  [SMALL_STATE(21274)] = 792788,
  [SMALL_STATE(21275)] = 792802,
  [SMALL_STATE(21276)] = 792816,
  [SMALL_STATE(21277)] = 792830,
  [SMALL_STATE(21278)] = 792844,
  [SMALL_STATE(21279)] = 792858,
  [SMALL_STATE(21280)] = 792872,
  [SMALL_STATE(21281)] = 792886,
  [SMALL_STATE(21282)] = 792900,
  [SMALL_STATE(21283)] = 792914,
  [SMALL_STATE(21284)] = 792928,
  [SMALL_STATE(21285)] = 792942,
  [SMALL_STATE(21286)] = 792956,
  [SMALL_STATE(21287)] = 792970,
  [SMALL_STATE(21288)] = 792984,
  [SMALL_STATE(21289)] = 792998,
  [SMALL_STATE(21290)] = 793012,
  [SMALL_STATE(21291)] = 793026,
  [SMALL_STATE(21292)] = 793040,
  [SMALL_STATE(21293)] = 793054,
  [SMALL_STATE(21294)] = 793068,
  [SMALL_STATE(21295)] = 793082,
  [SMALL_STATE(21296)] = 793096,
  [SMALL_STATE(21297)] = 793110,
  [SMALL_STATE(21298)] = 793124,
  [SMALL_STATE(21299)] = 793138,
  [SMALL_STATE(21300)] = 793152,
  [SMALL_STATE(21301)] = 793166,
  [SMALL_STATE(21302)] = 793180,
  [SMALL_STATE(21303)] = 793194,
  [SMALL_STATE(21304)] = 793208,
  [SMALL_STATE(21305)] = 793222,
  [SMALL_STATE(21306)] = 793236,
  [SMALL_STATE(21307)] = 793250,
  [SMALL_STATE(21308)] = 793264,
  [SMALL_STATE(21309)] = 793278,
  [SMALL_STATE(21310)] = 793292,
  [SMALL_STATE(21311)] = 793306,
  [SMALL_STATE(21312)] = 793320,
  [SMALL_STATE(21313)] = 793334,
  [SMALL_STATE(21314)] = 793348,
  [SMALL_STATE(21315)] = 793362,
  [SMALL_STATE(21316)] = 793376,
  [SMALL_STATE(21317)] = 793390,
  [SMALL_STATE(21318)] = 793404,
  [SMALL_STATE(21319)] = 793418,
  [SMALL_STATE(21320)] = 793432,
  [SMALL_STATE(21321)] = 793446,
  [SMALL_STATE(21322)] = 793460,
  [SMALL_STATE(21323)] = 793474,
  [SMALL_STATE(21324)] = 793488,
  [SMALL_STATE(21325)] = 793502,
  [SMALL_STATE(21326)] = 793516,
  [SMALL_STATE(21327)] = 793530,
  [SMALL_STATE(21328)] = 793544,
  [SMALL_STATE(21329)] = 793558,
  [SMALL_STATE(21330)] = 793572,
  [SMALL_STATE(21331)] = 793586,
  [SMALL_STATE(21332)] = 793600,
  [SMALL_STATE(21333)] = 793614,
  [SMALL_STATE(21334)] = 793628,
  [SMALL_STATE(21335)] = 793642,
  [SMALL_STATE(21336)] = 793656,
  [SMALL_STATE(21337)] = 793670,
  [SMALL_STATE(21338)] = 793684,
  [SMALL_STATE(21339)] = 793698,
  [SMALL_STATE(21340)] = 793712,
  [SMALL_STATE(21341)] = 793726,
  [SMALL_STATE(21342)] = 793740,
  [SMALL_STATE(21343)] = 793754,
  [SMALL_STATE(21344)] = 793768,
  [SMALL_STATE(21345)] = 793782,
  [SMALL_STATE(21346)] = 793796,
  [SMALL_STATE(21347)] = 793810,
  [SMALL_STATE(21348)] = 793824,
  [SMALL_STATE(21349)] = 793838,
  [SMALL_STATE(21350)] = 793852,
  [SMALL_STATE(21351)] = 793866,
  [SMALL_STATE(21352)] = 793880,
  [SMALL_STATE(21353)] = 793894,
  [SMALL_STATE(21354)] = 793908,
  [SMALL_STATE(21355)] = 793922,
  [SMALL_STATE(21356)] = 793936,
  [SMALL_STATE(21357)] = 793950,
  [SMALL_STATE(21358)] = 793964,
  [SMALL_STATE(21359)] = 793978,
  [SMALL_STATE(21360)] = 793992,
  [SMALL_STATE(21361)] = 794006,
  [SMALL_STATE(21362)] = 794020,
  [SMALL_STATE(21363)] = 794034,
  [SMALL_STATE(21364)] = 794048,
  [SMALL_STATE(21365)] = 794062,
  [SMALL_STATE(21366)] = 794076,
  [SMALL_STATE(21367)] = 794090,
  [SMALL_STATE(21368)] = 794104,
  [SMALL_STATE(21369)] = 794118,
  [SMALL_STATE(21370)] = 794132,
  [SMALL_STATE(21371)] = 794146,
  [SMALL_STATE(21372)] = 794160,
  [SMALL_STATE(21373)] = 794174,
  [SMALL_STATE(21374)] = 794188,
  [SMALL_STATE(21375)] = 794202,
  [SMALL_STATE(21376)] = 794216,
  [SMALL_STATE(21377)] = 794230,
  [SMALL_STATE(21378)] = 794244,
  [SMALL_STATE(21379)] = 794258,
  [SMALL_STATE(21380)] = 794272,
  [SMALL_STATE(21381)] = 794286,
  [SMALL_STATE(21382)] = 794300,
  [SMALL_STATE(21383)] = 794314,
  [SMALL_STATE(21384)] = 794328,
  [SMALL_STATE(21385)] = 794342,
  [SMALL_STATE(21386)] = 794356,
  [SMALL_STATE(21387)] = 794370,
  [SMALL_STATE(21388)] = 794384,
  [SMALL_STATE(21389)] = 794398,
  [SMALL_STATE(21390)] = 794412,
  [SMALL_STATE(21391)] = 794426,
  [SMALL_STATE(21392)] = 794440,
  [SMALL_STATE(21393)] = 794454,
  [SMALL_STATE(21394)] = 794468,
  [SMALL_STATE(21395)] = 794482,
  [SMALL_STATE(21396)] = 794496,
  [SMALL_STATE(21397)] = 794510,
  [SMALL_STATE(21398)] = 794524,
  [SMALL_STATE(21399)] = 794538,
  [SMALL_STATE(21400)] = 794552,
  [SMALL_STATE(21401)] = 794566,
  [SMALL_STATE(21402)] = 794580,
  [SMALL_STATE(21403)] = 794594,
  [SMALL_STATE(21404)] = 794608,
  [SMALL_STATE(21405)] = 794622,
  [SMALL_STATE(21406)] = 794636,
  [SMALL_STATE(21407)] = 794650,
  [SMALL_STATE(21408)] = 794664,
  [SMALL_STATE(21409)] = 794678,
  [SMALL_STATE(21410)] = 794692,
  [SMALL_STATE(21411)] = 794706,
  [SMALL_STATE(21412)] = 794720,
  [SMALL_STATE(21413)] = 794734,
  [SMALL_STATE(21414)] = 794748,
  [SMALL_STATE(21415)] = 794762,
  [SMALL_STATE(21416)] = 794776,
  [SMALL_STATE(21417)] = 794790,
  [SMALL_STATE(21418)] = 794804,
  [SMALL_STATE(21419)] = 794808,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16825),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13551),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14856),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12898),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14206),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14601),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11618),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10563),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14612),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14890),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16218),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16223),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16493),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4145),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5145),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2645),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17456),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3158),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14856),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12873),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1558),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5097),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4536),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2965),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3449),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14162),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14608),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11702),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12255),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14541),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10895),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4980),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14838),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2650),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3941),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3944),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14958),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15146),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4471),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16463),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16679),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8516),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14128),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13249),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4529),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8516),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4293),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4646),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18174),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18192),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13677),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7951),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10092),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10463),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21418),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4469),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11651),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4753),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16229),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8059),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15879),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5421),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12910),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10038),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10645),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7323),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7026),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7760),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7051),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10168),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11518),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5731),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6600),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10757),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10975),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8287),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9255),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7997),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8392),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5758),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7980),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5948),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8263),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9580),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9806),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11278),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7667),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10457),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9175),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7829),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7232),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6890),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9775),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11316),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7555),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10489),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4347),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10384),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11613),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11147),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13993),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6050),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5141),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5582),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6138),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12422),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6449),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6453),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10063),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6457),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6464),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6142),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3913),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9779),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4963),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13956),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13368),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3374),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6472),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6145),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10024),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5376),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3689),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9414),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9425),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13688),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4211),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5203),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2689),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12885),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1674),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4680),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3249),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14182),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14633),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14605),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14003),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10849),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4989),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(396),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2736),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14911),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15094),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4695),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17049),
  [345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16749),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4696),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14089),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13329),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4703),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4297),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4731),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18181),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18187),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9271),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3123),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_expression_anonymous, 2, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2707),
  [373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sequence_expression_anonymous, 2, 0, 0),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3456),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3434),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10818),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4952),
  [387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(417),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2660),
  [395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14843),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15152),
  [401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3250),
  [405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16650),
  [407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17097),
  [409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16236),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3459),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14154),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13077),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4572),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18135),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3114),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2711),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1697),
  [435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3490),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3438),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10921),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5001),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2663),
  [451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14691),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15013),
  [457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16656),
  [463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17100),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14157),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13084),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4626),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18169),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 1, 0, 0),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 3, 0, 0),
  [483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3484),
  [485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2656),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1761),
  [491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3796),
  [493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3378),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10972),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4981),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2677),
  [507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14709),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15123),
  [513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16475),
  [519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16979),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14106),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13239),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4547),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18126),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3347),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2669),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3802),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3393),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11171),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4959),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(405),
  [555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(431),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2731),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14842),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15170),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16569),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17038),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14119),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13178),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4727),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17404),
  [587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 4, 0, 0),
  [589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3485),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2723),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1733),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3615),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3444),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11139),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4934),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(488),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14693),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15003),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3632),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16664),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17104),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3626),
  [629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14160),
  [631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13087),
  [633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4698),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18210),
  [641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3488),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2724),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1746),
  [649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3571),
  [651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3445),
  [653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11166),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4935),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(426),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2670),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14858),
  [669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15106),
  [671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16666),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17105),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14161),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13088),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4717),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18227),
  [693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 2, 0, 0),
  [695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 3, 0, 0),
  [697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure, 4, 0, 0),
  [699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 1, 0, 0),
  [701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure, 2, 0, 0),
  [703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3761),
  [705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2700),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1605),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3854),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3423),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11184),
  [717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4924),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2657),
  [727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(462),
  [729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14830),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15128),
  [733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4014),
  [737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16640),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17092),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3855),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14150),
  [745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13073),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3856),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18088),
  [755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3719),
  [757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2698),
  [759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3834),
  [765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3419),
  [767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10899),
  [769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4902),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2651),
  [779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14818),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15161),
  [785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(258),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16636),
  [791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17090),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14148),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13068),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4459),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17963),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3992),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2659),
  [811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1548),
  [815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4357),
  [817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3381),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11112),
  [821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4906),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2705),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14675),
  [835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15160),
  [837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4163),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16539),
  [843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17021),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4358),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14112),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13223),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4712),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4373),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18380),
  [859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4070),
  [861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2672),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1712),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4256),
  [869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3397),
  [871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11226),
  [873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4971),
  [875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2692),
  [883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14636),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15186),
  [889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4323),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16596),
  [895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17063),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4310),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14120),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13260),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4462),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4285),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17741),
  [911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2680),
  [915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4841),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2644),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1645),
  [923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4933),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3430),
  [927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10970),
  [929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4936),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14991),
  [939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(491),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2649),
  [943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4035),
  [947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4036),
  [949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14790),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15041),
  [953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4942),
  [957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16644),
  [959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17094),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4900),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14153),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13076),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4567),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4901),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18131),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2702),
  [977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4938),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14975),
  [985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2671),
  [989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4105),
  [993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4106),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4946),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2706),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5124),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3372),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10868),
  [1011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4944),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(384),
  [1017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [1019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2709),
  [1021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14752),
  [1025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15028),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5054),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16427),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16937),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5034),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14093),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13105),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4420),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5060),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17373),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2647),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4947),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2646),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5217),
  [1065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [1067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5432),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3443),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11122),
  [1077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4907),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(477),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14701),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15065),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16825),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16662),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17103),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5433),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14159),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13086),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4677),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5459),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18201),
  [1117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5320),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2675),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1807),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5508),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3405),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10892),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5030),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [1139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2729),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [1143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14703),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15068),
  [1147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5554),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16618),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17079),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5514),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14130),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12965),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4590),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5538),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17258),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5110),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2674),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1789),
  [1177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5178),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3403),
  [1181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10885),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4999),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [1187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [1191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2655),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3966),
  [1197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3969),
  [1199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14878),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15029),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5255),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16615),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17077),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5182),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14127),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12949),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4544),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5186),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18406),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5222),
  [1227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2701),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5309),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3315),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10870),
  [1239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4943),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2693),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14956),
  [1253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15141),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5371),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16050),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16813),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5312),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14049),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13243),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4701),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5321),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17923),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16236),
  [1279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5638),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2726),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [1287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5859),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3441),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11025),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4937),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14990),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2648),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3962),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3964),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14892),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15053),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5762),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16660),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17102),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5861),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14158),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13085),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4648),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5863),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18184),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2712),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5027),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5768),
  [1347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2713),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [1353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5970),
  [1355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3401),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11031),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4898),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2699),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [1371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14771),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15014),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6059),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16612),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17075),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6056),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14125),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13359),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4430),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6049),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18253),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4504),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21191),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12403),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20348),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8334),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4167),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20324),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20795),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20277),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20795),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4001),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7648),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20135),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12271),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20304),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4255),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21355),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7327),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21261),
  [1441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12280),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20733),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4318),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21311),
  [1449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4098),
  [1451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7316),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7161),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21262),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12289),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21320),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4390),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18904),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7459),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21263),
  [1477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12291),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18894),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20608),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3830),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7173),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8001),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21264),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20451),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21139),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7041),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21265),
  [1509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12292),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18846),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4143),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18891),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7247),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7576),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21270),
  [1527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12299),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18872),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4294),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20454),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7679),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5038),
  [1543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21272),
  [1545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12303),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18435),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19311),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3870),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5053),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6690),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21277),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12306),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20335),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4159),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19244),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6503),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21278),
  [1581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12307),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20641),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4232),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19569),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3878),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8208),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21279),
  [1599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12314),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21220),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4299),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20090),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3886),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8356),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4389),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21281),
  [1617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12315),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20940),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4362),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20637),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3891),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4222),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7341),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21282),
  [1635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12316),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19315),
  [1639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [1641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21218),
  [1643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3896),
  [1645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7079),
  [1649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6930),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21283),
  [1653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12318),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18935),
  [1657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20699),
  [1661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3902),
  [1663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6572),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21284),
  [1671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12319),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20672),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4160),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20861),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3904),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [1685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4142),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21285),
  [1689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12320),
  [1691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21378),
  [1693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19299),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4364),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9640),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21286),
  [1707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12322),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18659),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4194),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18928),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [1717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9682),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6033),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21287),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12323),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19470),
  [1729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4215),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20652),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5962),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5190),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21288),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12324),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18784),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21376),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3925),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2673),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4987),
  [1759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5278),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5527),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21289),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12326),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19641),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4263),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19436),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5499),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6077),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21290),
  [1785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12327),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20779),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4283),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18777),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6199),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6588),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21291),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12331),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18578),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4306),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19640),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3934),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12654),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6728),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21292),
  [1821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12335),
  [1823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18881),
  [1825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4339),
  [1827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20768),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3939),
  [1831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6716),
  [1835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10216),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21293),
  [1839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12337),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19277),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4386),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18577),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10171),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6884),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21294),
  [1857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12338),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19645),
  [1861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4126),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18876),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [1869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6768),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7003),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21295),
  [1875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12339),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19829),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4141),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19275),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6822),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21296),
  [1893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12340),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19997),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [1899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19644),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3976),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6111),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21297),
  [1911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12342),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20020),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19828),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6302),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21298),
  [1929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12343),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20042),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19996),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4047),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7135),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21299),
  [1947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12344),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20064),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4204),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20018),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7397),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21300),
  [1965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12345),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20134),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4219),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20041),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6052),
  [1979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2710),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [1985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6125),
  [1987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3437),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10878),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4978),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [1995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [1997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(471),
  [1999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2734),
  [2001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(472),
  [2003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14974),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15168),
  [2007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6355),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16654),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17099),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6126),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14156),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13082),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4595),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6127),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18157),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7835),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4962),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21301),
  [2035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12346),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20168),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4244),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20062),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5008),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3464),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21302),
  [2053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12347),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20221),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20097),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3982),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3280),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6432),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21303),
  [2071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12349),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20255),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4268),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20130),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6975),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6130),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21304),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12351),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20303),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4296),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20167),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6378),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3460),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21305),
  [2107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12355),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20361),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4305),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20217),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3997),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3338),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5916),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21306),
  [2125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12356),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20413),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4324),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20251),
  [2133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5871),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5448),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21307),
  [2143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12357),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20456),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4351),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20302),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4436),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21226),
  [2159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12226),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18954),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4356),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18793),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [2171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5387),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3792),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21308),
  [2177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12358),
  [2179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20479),
  [2181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4374),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20359),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [2191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21309),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12359),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20487),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4392),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20399),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3559),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4564),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [2213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21259),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12254),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20531),
  [2219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4144),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19518),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4026),
  [2225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [2227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4638),
  [2229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5345),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6666),
  [2233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2676),
  [2235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5009),
  [2237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [2241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2686),
  [2243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [2247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6170),
  [2249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2717),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [2253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6683),
  [2257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3408),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11027),
  [2261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4916),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [2267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [2269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2704),
  [2271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14808),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15085),
  [2277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6686),
  [2281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16628),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17086),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6704),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14138),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13004),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4734),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6717),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17543),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6175),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2720),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1567),
  [2307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6997),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3416),
  [2311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10856),
  [2313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4930),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(485),
  [2321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2735),
  [2323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [2325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14868),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15036),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6791),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16634),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17089),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6998),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14146),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13063),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4432),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7000),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17845),
  [2351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6167),
  [2353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2716),
  [2355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1516),
  [2359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6538),
  [2361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3407),
  [2363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10842),
  [2365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4914),
  [2367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [2369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [2371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(479),
  [2373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2664),
  [2375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [2377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14747),
  [2379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15110),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6638),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16626),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17085),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6561),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14136),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12990),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4713),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6581),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17442),
  [2403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6264),
  [2405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2708),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [2409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1675),
  [2411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6427),
  [2413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3435),
  [2415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10857),
  [2417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4965),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [2421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [2425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2728),
  [2427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [2429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14922),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15088),
  [2433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6951),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16652),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17098),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6428),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14155),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13079),
  [2447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4580),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6429),
  [2453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18144),
  [2455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6152),
  [2457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2666),
  [2459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [2461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1632),
  [2463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6923),
  [2465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3386),
  [2467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11153),
  [2469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4941),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [2473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [2475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [2477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2691),
  [2479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [2481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14759),
  [2483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15151),
  [2485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(280),
  [2487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6549),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16557),
  [2491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17033),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6924),
  [2495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14117),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13091),
  [2499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4761),
  [2501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [2503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6926),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18288),
  [2507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6174),
  [2509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2718),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [2515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6877),
  [2517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3411),
  [2519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10931),
  [2521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4922),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [2525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [2527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [2529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2730),
  [2531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [2533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14827),
  [2535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15165),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [2539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6736),
  [2541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16632),
  [2543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17088),
  [2545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6878),
  [2547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14145),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13045),
  [2551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4425),
  [2553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [2555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6879),
  [2557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17731),
  [2559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2683),
  [2561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5028),
  [2563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [2565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [2567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2661),
  [2569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(448),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [2573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6523),
  [2575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2662),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [2581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7335),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3382),
  [2585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11130),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4920),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [2591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [2595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2654),
  [2597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(428),
  [2599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14981),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15179),
  [2603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7057),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16546),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17027),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14115),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12939),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4755),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7337),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18076),
  [2625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2681),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4919),
  [2629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [2631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(443),
  [2633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2658),
  [2635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(444),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [2639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2688),
  [2641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4949),
  [2643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [2645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(451),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2665),
  [2649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(452),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6607),
  [2655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [2659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1794),
  [2661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7318),
  [2663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3344),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10976),
  [2667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4990),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [2673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [2675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2653),
  [2677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [2679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14706),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15109),
  [2683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7186),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16159),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16841),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7320),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14054),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13343),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4519),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7128),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17336),
  [2705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6937),
  [2707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2690),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [2713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7274),
  [2715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3361),
  [2717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11094),
  [2719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4968),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [2723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [2725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(453),
  [2727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2722),
  [2729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14866),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15000),
  [2735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7511),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16211),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16855),
  [2743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7275),
  [2745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14062),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13025),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4499),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7495),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18338),
  [2757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6647),
  [2759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2684),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [2763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1569),
  [2765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7118),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3355),
  [2769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10813),
  [2771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4917),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [2775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [2777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [2779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2721),
  [2781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(450),
  [2783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14663),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14997),
  [2787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7419),
  [2791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16191),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16849),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7127),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14058),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13308),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4689),
  [2803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [2805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7277),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18235),
  [2809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7021),
  [2811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2697),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [2815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1809),
  [2817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7036),
  [2819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3368),
  [2821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11234),
  [2823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5000),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [2827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [2829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [2831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2715),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [2835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14966),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15153),
  [2839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7319),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16250),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16867),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7037),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14076),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13209),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4582),
  [2855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7038),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17719),
  [2861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2695),
  [2863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4985),
  [2865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(455),
  [2869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2668),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2727),
  [2877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4984),
  [2879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [2881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(403),
  [2883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2703),
  [2885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(404),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [2889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2733),
  [2891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5025),
  [2893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [2895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [2897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2732),
  [2899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(416),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [2903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2725),
  [2905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4960),
  [2907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [2909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [2911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2719),
  [2913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [2917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2685),
  [2919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4977),
  [2921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [2923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [2925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2679),
  [2927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(407),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [2931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2696),
  [2933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4905),
  [2935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [2937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [2939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2694),
  [2941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [2945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12654),
  [2947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9640),
  [2949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8001),
  [2951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6033),
  [2953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4504),
  [2955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5190),
  [2957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7327),
  [2959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5527),
  [2961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6077),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7041),
  [2965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6588),
  [2967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6728),
  [2969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10216),
  [2971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7576),
  [2973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6884),
  [2975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7003),
  [2977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3840),
  [2979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6111),
  [2981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5038),
  [2983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3860),
  [2985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4142),
  [2987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7915),
  [2989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6690),
  [2991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4962),
  [2993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3464),
  [2995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7161),
  [2997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6432),
  [2999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3514),
  [3001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6130),
  [3003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3460),
  [3005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8208),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5916),
  [3009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5448),
  [3011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4389),
  [3013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3792),
  [3015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4436),
  [3017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3556),
  [3019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7341),
  [3021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6930),
  [3023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7284),
  [3025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5353),
  [3027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3812),
  [3029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7135),
  [3031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8555),
  [3033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8553),
  [3035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16666),
  [3037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17105),
  [3039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17049),
  [3041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16749),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16636),
  [3045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17090),
  [3047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13080),
  [3049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10890),
  [3051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16656),
  [3053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17100),
  [3055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16644),
  [3057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17094),
  [3059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16475),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16979),
  [3063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16650),
  [3065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17097),
  [3067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16596),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17063),
  [3071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16427),
  [3073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16937),
  [3075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16640),
  [3077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17092),
  [3079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16539),
  [3081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17021),
  [3083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16664),
  [3085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17104),
  [3087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16463),
  [3089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16679),
  [3091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16569),
  [3093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17038),
  [3095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6343),
  [3097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6409),
  [3099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4970),
  [3101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [3103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5046),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3771),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5227),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4183),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9597),
  [3115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3450),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3742),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7817),
  [3121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4750),
  [3123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7231),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8193),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9731),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6100),
  [3131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7550),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5401),
  [3137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8570),
  [3141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6617),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6119),
  [3145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7018),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7249),
  [3151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8489),
  [3153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5535),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3466),
  [3159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7193),
  [3161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7934),
  [3163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6852),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7513),
  [3167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6010),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5798),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6623),
  [3175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5405),
  [3177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10219),
  [3179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10877),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7317),
  [3183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8391),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6995),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [3189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3360),
  [3191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [3193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [3195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18400),
  [3197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14208),
  [3199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20491),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4573),
  [3203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3439),
  [3205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18297),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14041),
  [3209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19862),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4627),
  [3213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5486),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5490),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7255),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5505),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5509),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5070),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6177),
  [3229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6178),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8250),
  [3233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8255),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5084),
  [3237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6194),
  [3239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6196),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7228),
  [3243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6203),
  [3245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6206),
  [3247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7215),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6641),
  [3251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6642),
  [3253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8344),
  [3255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8346),
  [3257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7238),
  [3259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8364),
  [3261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6661),
  [3263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6663),
  [3265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8368),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6670),
  [3269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6673),
  [3271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6691),
  [3273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6692),
  [3275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4720),
  [3277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5108),
  [3279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5117),
  [3281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7258),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6711),
  [3285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6713),
  [3287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5068),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6721),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6724),
  [3293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5094),
  [3295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10073),
  [3297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10074),
  [3299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [3301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [3303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10137),
  [3305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10159),
  [3307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [3309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10187),
  [3311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10217),
  [3313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6738),
  [3315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6739),
  [3317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4758),
  [3319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4517),
  [3321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6759),
  [3323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6765),
  [3325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [3327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6773),
  [3329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6777),
  [3331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [3333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6793),
  [3335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6795),
  [3337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7426),
  [3339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [3341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4230),
  [3343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6815),
  [3345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6818),
  [3347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7428),
  [3349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6826),
  [3351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6830),
  [3353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3883),
  [3355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [3357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7166),
  [3359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7169),
  [3361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [3365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7210),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3991),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7226),
  [3373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6279),
  [3375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6280),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6478),
  [3379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7058),
  [3381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7059),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6297),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6299),
  [3389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5391),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5394),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6307),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6310),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7353),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4015),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7207),
  [3405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3704),
  [3407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17383),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14064),
  [3411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18944),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4700),
  [3415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7074),
  [3417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7076),
  [3419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4518),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [3423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [3425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4044),
  [3427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3707),
  [3429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17462),
  [3431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14071),
  [3433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19368),
  [3435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4718),
  [3437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [3439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5305),
  [3441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [3443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7301),
  [3445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7368),
  [3447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7369),
  [3449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7083),
  [3451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7086),
  [3453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5346),
  [3455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7392),
  [3457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7394),
  [3459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7453),
  [3461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [3463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7401),
  [3465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7404),
  [3467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6550),
  [3469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7913),
  [3471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7921),
  [3473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6551),
  [3475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3663),
  [3477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18286),
  [3479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14027),
  [3481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20824),
  [3483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4729),
  [3485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6498),
  [3487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7777),
  [3489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7995),
  [3491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6500),
  [3493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7776),
  [3495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7872),
  [3497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7696),
  [3499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4966),
  [3501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4983),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6567),
  [3505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6569),
  [3507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6507),
  [3509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5002),
  [3511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5005),
  [3513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6576),
  [3515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5018),
  [3517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5021),
  [3519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6579),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [3525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6510),
  [3527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [3529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [3531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [3533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4437),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6952),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6953),
  [3541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4439),
  [3543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7698),
  [3545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6970),
  [3547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6972),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6979),
  [3551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6982),
  [3553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6356),
  [3555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6357),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [3559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [3561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6373),
  [3563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6375),
  [3565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4541),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6382),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6385),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4545),
  [3573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3314),
  [3577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [3579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3624),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3335),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [3587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [3589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5764),
  [3591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5765),
  [3593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4600),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4612),
  [3597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4326),
  [3599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5844),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5847),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5879),
  [3607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4565),
  [3609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7603),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5885),
  [3613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5311),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7610),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [3619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7456),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7592),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5327),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5367),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4526),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5457),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5298),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7653),
  [3635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3637),
  [3639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4354),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [3643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7637),
  [3645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [3649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7305),
  [3651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7641),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3766),
  [3655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [3657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4368),
  [3659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [3661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4371),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3549),
  [3667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [3669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7661),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7551),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [3677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7669),
  [3679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9646),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9648),
  [3683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7686),
  [3685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [3687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7470),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9674),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9677),
  [3695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7474),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9686),
  [3699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9691),
  [3701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3694),
  [3703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17831),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14033),
  [3707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19233),
  [3709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4548),
  [3711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5974),
  [3713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5977),
  [3715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [3717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [3719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6058),
  [3721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6017),
  [3723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [3725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5969),
  [3727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5975),
  [3729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [3731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5256),
  [3733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5257),
  [3735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7202),
  [3737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7346),
  [3739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5273),
  [3741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5275),
  [3743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5282),
  [3745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5285),
  [3747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5560),
  [3749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5564),
  [3751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7328),
  [3753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7330),
  [3755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [3757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3948),
  [3759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18274),
  [3761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14092),
  [3763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21329),
  [3765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4461),
  [3767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3989),
  [3769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18398),
  [3771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14133),
  [3773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21351),
  [3775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [3777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17295),
  [3779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18128),
  [3781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18162),
  [3783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18382),
  [3785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17310),
  [3787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3439),
  [3790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74),
  [3792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74),
  [3794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18297),
  [3797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(200),
  [3800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1697),
  [3803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3490),
  [3806] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3438),
  [3809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10921),
  [3812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1698),
  [3815] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14691),
  [3818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15013),
  [3821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(271),
  [3824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3312),
  [3827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16656),
  [3830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17100),
  [3833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3491),
  [3836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14157),
  [3839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13084),
  [3842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4626),
  [3845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3412),
  [3848] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18169),
  [3851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_application_expression, 2, 0, 39),
  [3853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_application_expression, 2, 0, 39),
  [3855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4217),
  [3857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17282),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14040),
  [3861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18969),
  [3863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4466),
  [3865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4409),
  [3867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17571),
  [3869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14131),
  [3871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18564),
  [3873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4714),
  [3875] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3360),
  [3878] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18400),
  [3881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(194),
  [3884] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1660),
  [3887] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3456),
  [3890] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3434),
  [3893] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10818),
  [3896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1661),
  [3899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14843),
  [3902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15152),
  [3905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(266),
  [3908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3250),
  [3911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16650),
  [3914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17097),
  [3917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3459),
  [3920] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14154),
  [3923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13077),
  [3926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4572),
  [3929] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3461),
  [3932] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18135),
  [3935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4683),
  [3937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17634),
  [3939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14114),
  [3941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18624),
  [3943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4473),
  [3945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3704),
  [3948] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17383),
  [3951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(207),
  [3954] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1733),
  [3957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3615),
  [3960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3444),
  [3963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11139),
  [3966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1734),
  [3969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14693),
  [3972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15003),
  [3975] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(276),
  [3978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3632),
  [3981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16664),
  [3984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17104),
  [3987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3626),
  [3990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14160),
  [3993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13087),
  [3996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4698),
  [3999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3758),
  [4002] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18210),
  [4005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3707),
  [4008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17462),
  [4011] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(209),
  [4014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1746),
  [4017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3571),
  [4020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3445),
  [4023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11166),
  [4026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1747),
  [4029] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14858),
  [4032] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15106),
  [4035] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(278),
  [4038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3522),
  [4041] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16666),
  [4044] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17105),
  [4047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3628),
  [4050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14161),
  [4053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13088),
  [4056] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4717),
  [4059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3773),
  [4062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18227),
  [4065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3694),
  [4068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17831),
  [4071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(146),
  [4074] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1761),
  [4077] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3796),
  [4080] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3378),
  [4083] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10972),
  [4086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1762),
  [4089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14709),
  [4092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15123),
  [4095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(269),
  [4098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3757),
  [4101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16475),
  [4104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16979),
  [4107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3798),
  [4110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14106),
  [4113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13239),
  [4116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4547),
  [4119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3770),
  [4122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18126),
  [4125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3663),
  [4128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18286),
  [4131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(156),
  [4134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1494),
  [4137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3802),
  [4140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3393),
  [4143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11171),
  [4146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1670),
  [4149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14842),
  [4152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15170),
  [4155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(284),
  [4158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3557),
  [4161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16569),
  [4164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17038),
  [4167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3804),
  [4170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14119),
  [4173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13178),
  [4176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4727),
  [4179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3806),
  [4182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17404),
  [4185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4501),
  [4187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17214),
  [4189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14068),
  [4191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20545),
  [4193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4456),
  [4195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3989),
  [4198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18398),
  [4201] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(185),
  [4204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1605),
  [4207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3854),
  [4210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3423),
  [4213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11184),
  [4216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1606),
  [4219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14830),
  [4222] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15128),
  [4225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(261),
  [4228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4014),
  [4231] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16640),
  [4234] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17092),
  [4237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3855),
  [4240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14150),
  [4243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13073),
  [4246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4503),
  [4249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3856),
  [4252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18088),
  [4255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3948),
  [4258] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18274),
  [4261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(181),
  [4264] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1579),
  [4267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3834),
  [4270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3419),
  [4273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10899),
  [4276] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1580),
  [4279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14818),
  [4282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15161),
  [4285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(258),
  [4288] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3882),
  [4291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16636),
  [4294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17090),
  [4297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3836),
  [4300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14148),
  [4303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13068),
  [4306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4459),
  [4309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3837),
  [4312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17963),
  [4315] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4409),
  [4318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17571),
  [4321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(150),
  [4324] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1548),
  [4327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4357),
  [4330] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3381),
  [4333] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11112),
  [4336] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1551),
  [4339] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14675),
  [4342] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15160),
  [4345] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(275),
  [4348] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4163),
  [4351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16539),
  [4354] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17021),
  [4357] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4358),
  [4360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14112),
  [4363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13223),
  [4366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4712),
  [4369] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4373),
  [4372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18380),
  [4375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4217),
  [4378] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17282),
  [4381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(158),
  [4384] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1712),
  [4387] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4256),
  [4390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3397),
  [4393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11226),
  [4396] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1715),
  [4399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14636),
  [4402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15186),
  [4405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(262),
  [4408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4323),
  [4411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16596),
  [4414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17063),
  [4417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4310),
  [4420] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14120),
  [4423] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13260),
  [4426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4462),
  [4429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4285),
  [4432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17741),
  [4435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4683),
  [4438] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17634),
  [4441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(128),
  [4444] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1558),
  [4447] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4536),
  [4450] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3449),
  [4453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10895),
  [4456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1729),
  [4459] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14958),
  [4462] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15146),
  [4465] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(246),
  [4468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4471),
  [4471] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16463),
  [4474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16679),
  [4477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4472),
  [4480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14128),
  [4483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13249),
  [4486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4529),
  [4489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4646),
  [4492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18192),
  [4495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4501),
  [4498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17214),
  [4501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(205),
  [4504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1674),
  [4507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4680),
  [4510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3249),
  [4513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10849),
  [4516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1677),
  [4519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14911),
  [4522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15094),
  [4525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(277),
  [4528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4695),
  [4531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17049),
  [4534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16749),
  [4537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4696),
  [4540] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14089),
  [4543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13329),
  [4546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4703),
  [4549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4731),
  [4552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18187),
  [4555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4955),
  [4557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17380),
  [4559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14198),
  [4561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20876),
  [4563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4568),
  [4565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5092),
  [4567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18331),
  [4569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14042),
  [4571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21182),
  [4573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4423),
  [4575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5236),
  [4577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17619),
  [4579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14108),
  [4581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20232),
  [4583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4555),
  [4585] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4955),
  [4588] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17380),
  [4591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(192),
  [4594] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1645),
  [4597] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4933),
  [4600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3430),
  [4603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10970),
  [4606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1646),
  [4609] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14790),
  [4612] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15041),
  [4615] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(265),
  [4618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4942),
  [4621] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16644),
  [4624] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17094),
  [4627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4900),
  [4630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14153),
  [4633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13076),
  [4636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4567),
  [4639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4901),
  [4642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18131),
  [4645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5359),
  [4647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17636),
  [4649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14044),
  [4651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18559),
  [4653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [4655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5388),
  [4657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17296),
  [4659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14056),
  [4661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18651),
  [4663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4678),
  [4665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5640),
  [4667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_binding_pattern, 1, 0, 0),
  [4669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_binding_pattern, 1, 0, 0),
  [4671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17906),
  [4673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [4675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4308),
  [4677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5464),
  [4679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14352),
  [4681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15615),
  [4683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [4685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3935),
  [4687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19562),
  [4689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16306),
  [4691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16884),
  [4693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5539),
  [4695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18586),
  [4697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14081),
  [4699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13268),
  [4701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [4703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18219),
  [4705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5521),
  [4707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17756),
  [4709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14135),
  [4711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18521),
  [4713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4592),
  [4715] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5092),
  [4718] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18331),
  [4721] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(142),
  [4724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1501),
  [4727] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5124),
  [4730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3372),
  [4733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10868),
  [4736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1506),
  [4739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14752),
  [4742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15028),
  [4745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(260),
  [4748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5054),
  [4751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16427),
  [4754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16937),
  [4757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5034),
  [4760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14093),
  [4763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13105),
  [4766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4420),
  [4769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5060),
  [4772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17373),
  [4775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5696),
  [4777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [4779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4187),
  [4781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5570),
  [4783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14458),
  [4785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15807),
  [4787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4188),
  [4789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4059),
  [4791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20684),
  [4793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15997),
  [4795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16803),
  [4797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5489),
  [4799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20704),
  [4801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14213),
  [4803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12958),
  [4805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [4807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17307),
  [4809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2557),
  [4811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11225),
  [4813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18229),
  [4815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [4817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8387),
  [4819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18414),
  [4821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3045),
  [4823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12635),
  [4825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21276),
  [4827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14351),
  [4829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2984),
  [4831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15596),
  [4833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15305),
  [4835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20095),
  [4837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [4839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2986),
  [4841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19539),
  [4843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5254),
  [4845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16733),
  [4847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16784),
  [4849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12637),
  [4851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17917),
  [4853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14038),
  [4855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13157),
  [4857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18869),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8651),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17630),
  [4863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14577),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21268),
  [4867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15539),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18563),
  [4871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19798),
  [4873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7763),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21271),
  [4877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15562),
  [4879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19948),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21213),
  [4883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8080),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21241),
  [4887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15687),
  [4889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21195),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20720),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7891),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21274),
  [4897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15577),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19250),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19936),
  [4903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [4905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5236),
  [4908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17619),
  [4911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(164),
  [4914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1789),
  [4917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5178),
  [4920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3403),
  [4923] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10885),
  [4926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1791),
  [4929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14878),
  [4932] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15029),
  [4935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(247),
  [4938] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5255),
  [4941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16615),
  [4944] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17077),
  [4947] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5182),
  [4950] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14127),
  [4953] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(12949),
  [4956] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4544),
  [4959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5186),
  [4962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18406),
  [4965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5860),
  [4967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [4969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4284),
  [4971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5734),
  [4973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14462),
  [4975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15647),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4317),
  [4979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3844),
  [4981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18962),
  [4983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16444),
  [4985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16960),
  [4987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21398),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14101),
  [4993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13019),
  [4995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [4997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17726),
  [4999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9116),
  [5001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21280),
  [5003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15608),
  [5005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20747),
  [5007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20332),
  [5009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10745),
  [5011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21260),
  [5013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15497),
  [5015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19428),
  [5017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20527),
  [5019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5921),
  [5021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [5023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4387),
  [5025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5683),
  [5027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14405),
  [5029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15846),
  [5031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4388),
  [5033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3829),
  [5035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21039),
  [5037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16432),
  [5039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16943),
  [5041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5684),
  [5043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20362),
  [5045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14095),
  [5047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13244),
  [5049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5470),
  [5051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17469),
  [5053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15474),
  [5055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19527),
  [5057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [5059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5388),
  [5062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17296),
  [5065] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(204),
  [5068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1721),
  [5071] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5432),
  [5074] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3443),
  [5077] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11122),
  [5080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1723),
  [5083] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14701),
  [5086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15065),
  [5089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(274),
  [5092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5398),
  [5095] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16662),
  [5098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17103),
  [5101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5433),
  [5104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14159),
  [5107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13086),
  [5110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4677),
  [5113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5459),
  [5116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18201),
  [5119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5359),
  [5122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17636),
  [5125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(212),
  [5128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1599),
  [5131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5309),
  [5134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3315),
  [5137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10870),
  [5140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1600),
  [5143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14956),
  [5146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15141),
  [5149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(283),
  [5152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5371),
  [5155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16050),
  [5158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16813),
  [5161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5312),
  [5164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14049),
  [5167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13243),
  [5170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4701),
  [5173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5321),
  [5176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17923),
  [5179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5924),
  [5181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17201),
  [5183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14048),
  [5185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21050),
  [5187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4649),
  [5189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [5191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5521),
  [5194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17756),
  [5197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(167),
  [5200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1807),
  [5203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5508),
  [5206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3405),
  [5209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10892),
  [5212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1808),
  [5215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14703),
  [5218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15068),
  [5221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(249),
  [5224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5554),
  [5227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16618),
  [5230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17079),
  [5233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5514),
  [5236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14130),
  [5239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(12965),
  [5242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4590),
  [5245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5538),
  [5248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17258),
  [5251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20098),
  [5253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20489),
  [5255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6053),
  [5257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17507),
  [5259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14079),
  [5261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19028),
  [5263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4434),
  [5265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6098),
  [5267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17838),
  [5269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14032),
  [5271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19033),
  [5273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4596),
  [5275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6637),
  [5277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17721),
  [5279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14202),
  [5281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18847),
  [5283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4762),
  [5285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5924),
  [5288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17201),
  [5291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(202),
  [5294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1708),
  [5297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5859),
  [5300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3441),
  [5303] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11025),
  [5306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1709),
  [5309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14892),
  [5312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15053),
  [5315] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(273),
  [5318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5762),
  [5321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16660),
  [5324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17102),
  [5327] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5861),
  [5330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14158),
  [5333] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13085),
  [5336] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4648),
  [5339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5863),
  [5342] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18184),
  [5345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6950),
  [5347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18205),
  [5349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14077),
  [5351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20784),
  [5353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4433),
  [5355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6921),
  [5357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17860),
  [5359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14193),
  [5361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19319),
  [5363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4715),
  [5365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6935),
  [5367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17966),
  [5369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14212),
  [5371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19671),
  [5373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4742),
  [5375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6681),
  [5377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17474),
  [5379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14218),
  [5381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20295),
  [5383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4581),
  [5385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6946),
  [5387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18140),
  [5389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14057),
  [5391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20383),
  [5393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4426),
  [5395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10706),
  [5397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 1, 0, 27),
  [5399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 1, 0, 27),
  [5401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8818),
  [5403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [5405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16818),
  [5407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [5409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4620),
  [5411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4706),
  [5413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3022),
  [5415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10784),
  [5417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8027),
  [5419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14560),
  [5421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15791),
  [5423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15489),
  [5425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4708),
  [5427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3024),
  [5429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18462),
  [5431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16479),
  [5433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16137),
  [5435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16833),
  [5437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10785),
  [5439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18468),
  [5441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14052),
  [5443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13315),
  [5445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8710),
  [5447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18395),
  [5449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11168),
  [5451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17906),
  [5453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2572),
  [5455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [5457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4138),
  [5459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21275),
  [5461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14561),
  [5463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15590),
  [5465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19577),
  [5467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [5469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4022),
  [5471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18430),
  [5473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7155),
  [5475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17301),
  [5477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14183),
  [5479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20475),
  [5481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4756),
  [5483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6053),
  [5486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17507),
  [5489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(162),
  [5492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1772),
  [5495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(5970),
  [5498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3401),
  [5501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11031),
  [5504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1774),
  [5507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14771),
  [5510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15014),
  [5513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(245),
  [5516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6059),
  [5519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16612),
  [5522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17075),
  [5525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6056),
  [5528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14125),
  [5531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13359),
  [5534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4430),
  [5537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6049),
  [5540] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18253),
  [5543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9065),
  [5545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21269),
  [5547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15549),
  [5549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19365),
  [5551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18541),
  [5553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7488),
  [5555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18256),
  [5557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14186),
  [5559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19398),
  [5561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4591),
  [5563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5572),
  [5565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21267),
  [5567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15521),
  [5569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19929),
  [5571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18738),
  [5573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7314),
  [5575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17372),
  [5577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14086),
  [5579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18683),
  [5581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4556),
  [5583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5686),
  [5585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21273),
  [5587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15570),
  [5589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18874),
  [5591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18866),
  [5593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7273),
  [5595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17971),
  [5597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14026),
  [5599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20638),
  [5601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4514),
  [5603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5566),
  [5605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21252),
  [5607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15401),
  [5609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18558),
  [5611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18546),
  [5613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8953),
  [5615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [5617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4575),
  [5619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4576),
  [5621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15274),
  [5623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4577),
  [5625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7115),
  [5627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17667),
  [5629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14137),
  [5631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19676),
  [5633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4728),
  [5635] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6237),
  [5638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17209),
  [5641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(183),
  [5644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1591),
  [5647] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6106),
  [5650] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3422),
  [5653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11126),
  [5656] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1592),
  [5659] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14854),
  [5662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15011),
  [5665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(259),
  [5668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6278),
  [5671] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16638),
  [5674] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17091),
  [5677] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6107),
  [5680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14149),
  [5683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13071),
  [5686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4496),
  [5689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6108),
  [5692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18014),
  [5695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6237),
  [5697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_application, 2, 0, 94),
  [5699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_application, 2, 0, 94),
  [5701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17209),
  [5703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [5705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [5707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6106),
  [5709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3422),
  [5711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11126),
  [5713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [5715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14854),
  [5717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15011),
  [5719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [5721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6278),
  [5723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16638),
  [5725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17091),
  [5727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6107),
  [5729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14149),
  [5731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13071),
  [5733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4496),
  [5735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6108),
  [5737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18014),
  [5739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8964),
  [5741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [5743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4664),
  [5745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4435),
  [5747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15818),
  [5749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4500),
  [5751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6098),
  [5754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17838),
  [5757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(198),
  [5760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1686),
  [5763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6125),
  [5766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3437),
  [5769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10878),
  [5772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1687),
  [5775] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14974),
  [5778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15168),
  [5781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(270),
  [5784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6355),
  [5787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16654),
  [5790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17099),
  [5793] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6126),
  [5796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14156),
  [5799] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13082),
  [5802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4595),
  [5805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6127),
  [5808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18157),
  [5811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6173),
  [5813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_expression, 1, 0, 0),
  [5815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_expression, 1, 0, 0),
  [5817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18300),
  [5819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [5821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1502),
  [5823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6072),
  [5825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3406),
  [5827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11217),
  [5829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [5831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14660),
  [5833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15112),
  [5835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [5837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6176),
  [5839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16621),
  [5841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17081),
  [5843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6073),
  [5845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14132),
  [5847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12972),
  [5849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4682),
  [5851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6074),
  [5853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17357),
  [5855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8972),
  [5857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [5859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4593),
  [5861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4601),
  [5863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15251),
  [5865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4623),
  [5867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6173),
  [5870] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18300),
  [5873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(169),
  [5876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1502),
  [5879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6072),
  [5882] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3406),
  [5885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11217),
  [5888] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1503),
  [5891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14660),
  [5894] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15112),
  [5897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(250),
  [5900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6176),
  [5903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16621),
  [5906] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17081),
  [5909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6073),
  [5912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14132),
  [5915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(12972),
  [5918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4682),
  [5921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6074),
  [5924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17357),
  [5927] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6540),
  [5930] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18082),
  [5933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(144),
  [5936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1593),
  [5939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6685),
  [5942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3375),
  [5945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10880),
  [5948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1596),
  [5951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14931),
  [5954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15102),
  [5957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(264),
  [5960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6477),
  [5963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16325),
  [5966] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16892),
  [5969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6687),
  [5972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14105),
  [5975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13201),
  [5978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4464),
  [5981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6639),
  [5984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17939),
  [5987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6921),
  [5990] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17860),
  [5993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(171),
  [5996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1516),
  [5999] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6538),
  [6002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3407),
  [6005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10842),
  [6008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1517),
  [6011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14747),
  [6014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15110),
  [6017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(252),
  [6020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6638),
  [6023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16626),
  [6026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17085),
  [6029] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6561),
  [6032] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14136),
  [6035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(12990),
  [6038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4713),
  [6041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6581),
  [6044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17442),
  [6047] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6935),
  [6050] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17966),
  [6053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(173),
  [6056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1530),
  [6059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6683),
  [6062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3408),
  [6065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11027),
  [6068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1531),
  [6071] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14808),
  [6074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15085),
  [6077] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(253),
  [6080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6686),
  [6083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16628),
  [6086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17086),
  [6089] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6704),
  [6092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14138),
  [6095] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13004),
  [6098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4734),
  [6101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6717),
  [6104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17543),
  [6107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6946),
  [6110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18140),
  [6113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(177),
  [6116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1555),
  [6119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6877),
  [6122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3411),
  [6125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10931),
  [6128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1556),
  [6131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14827),
  [6134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15165),
  [6137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(256),
  [6140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6736),
  [6143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16632),
  [6146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17088),
  [6149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6878),
  [6152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14145),
  [6155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13045),
  [6158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4425),
  [6161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6879),
  [6164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17731),
  [6167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6540),
  [6169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18082),
  [6171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [6173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1593),
  [6175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6685),
  [6177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3375),
  [6179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10880),
  [6181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [6183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14931),
  [6185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15102),
  [6187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [6189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6477),
  [6191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16325),
  [6193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16892),
  [6195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6687),
  [6197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14105),
  [6199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13201),
  [6201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4464),
  [6203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6639),
  [6205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17939),
  [6207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6950),
  [6210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18205),
  [6213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(179),
  [6216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1567),
  [6219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6997),
  [6222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3416),
  [6225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10856),
  [6228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1568),
  [6231] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14868),
  [6234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15036),
  [6237] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(257),
  [6240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6791),
  [6243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16634),
  [6246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17089),
  [6249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6998),
  [6252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14146),
  [6255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13063),
  [6258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4432),
  [6261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7000),
  [6264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17845),
  [6267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6681),
  [6270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17474),
  [6273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(196),
  [6276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1675),
  [6279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6427),
  [6282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3435),
  [6285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10857),
  [6288] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1676),
  [6291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14922),
  [6294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15088),
  [6297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(268),
  [6300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6951),
  [6303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16652),
  [6306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17098),
  [6309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6428),
  [6312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14155),
  [6315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13079),
  [6318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4580),
  [6321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6429),
  [6324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18144),
  [6327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6637),
  [6330] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17721),
  [6333] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(154),
  [6336] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1632),
  [6339] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6923),
  [6342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3386),
  [6345] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11153),
  [6348] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1635),
  [6351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14759),
  [6354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15151),
  [6357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(280),
  [6360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6549),
  [6363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16557),
  [6366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17033),
  [6369] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6924),
  [6372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14117),
  [6375] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13091),
  [6378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4761),
  [6381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(6926),
  [6384] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18288),
  [6387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7281),
  [6389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17384),
  [6391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [6393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1620),
  [6395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7129),
  [6397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3424),
  [6399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11106),
  [6401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [6403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14659),
  [6405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15048),
  [6407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [6409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7367),
  [6411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16605),
  [6413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17069),
  [6415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7130),
  [6417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14151),
  [6419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13074),
  [6421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4524),
  [6423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7132),
  [6425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18099),
  [6427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7115),
  [6430] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17667),
  [6433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(132),
  [6436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1569),
  [6439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7118),
  [6442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3355),
  [6445] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10813),
  [6448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1575),
  [6451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14663),
  [6454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14997),
  [6457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(267),
  [6460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7419),
  [6463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16191),
  [6466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16849),
  [6469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7127),
  [6472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14058),
  [6475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13308),
  [6478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4689),
  [6481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7277),
  [6484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18235),
  [6487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7488),
  [6490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18256),
  [6493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(138),
  [6496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1809),
  [6499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7036),
  [6502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3368),
  [6505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11234),
  [6508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1810),
  [6511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14966),
  [6514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15153),
  [6517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(251),
  [6520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7319),
  [6523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16250),
  [6526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16867),
  [6529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7037),
  [6532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14076),
  [6535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13209),
  [6538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4582),
  [6541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7038),
  [6544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17719),
  [6547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7314),
  [6550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17372),
  [6553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(130),
  [6556] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1794),
  [6559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7318),
  [6562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3344),
  [6565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10976),
  [6568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1607),
  [6571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14706),
  [6574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15109),
  [6577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(248),
  [6580] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7186),
  [6583] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16159),
  [6586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16841),
  [6589] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7320),
  [6592] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14054),
  [6595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13343),
  [6598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4519),
  [6601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7128),
  [6604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17336),
  [6607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7281),
  [6610] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17384),
  [6613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(187),
  [6616] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1620),
  [6619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7129),
  [6622] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3424),
  [6625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11106),
  [6628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1621),
  [6631] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14659),
  [6634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15048),
  [6637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(285),
  [6640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7367),
  [6643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16605),
  [6646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17069),
  [6649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7130),
  [6652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14151),
  [6655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13074),
  [6658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4524),
  [6661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7132),
  [6664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18099),
  [6667] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7155),
  [6670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17301),
  [6673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(152),
  [6676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1594),
  [6679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7335),
  [6682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3382),
  [6685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11130),
  [6688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1595),
  [6691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14981),
  [6694] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15179),
  [6697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(279),
  [6700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7057),
  [6703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16546),
  [6706] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17027),
  [6709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7336),
  [6712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14115),
  [6715] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(12939),
  [6718] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4755),
  [6721] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7337),
  [6724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18076),
  [6727] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7273),
  [6730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17971),
  [6733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(134),
  [6736] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1497),
  [6739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7274),
  [6742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3361),
  [6745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(11094),
  [6748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1510),
  [6751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14866),
  [6754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15000),
  [6757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(281),
  [6760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7511),
  [6763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16211),
  [6766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16855),
  [6769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7275),
  [6772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14062),
  [6775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13025),
  [6778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4499),
  [6781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(7495),
  [6784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18338),
  [6787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_pattern, 1, 0, 0),
  [6789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18229),
  [6791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [6793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_pattern, 1, 0, 0),
  [6795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15305),
  [6797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19592),
  [6799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8355),
  [6801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17978),
  [6803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [6805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [6807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8201),
  [6809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3379),
  [6811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10838),
  [6813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [6815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14983),
  [6817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15192),
  [6819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [6821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8227),
  [6823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16418),
  [6825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16930),
  [6827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8202),
  [6829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14107),
  [6831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13283),
  [6833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4651),
  [6835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8204),
  [6837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18191),
  [6839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7947),
  [6841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 125),
  [6843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 125),
  [6845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10198),
  [6847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17022),
  [6849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2485),
  [6851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3088),
  [6853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7750),
  [6855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8256),
  [6857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14303),
  [6859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15265),
  [6861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [6863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21405),
  [6865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16473),
  [6867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16410),
  [6869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16923),
  [6871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7758),
  [6873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21333),
  [6875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14091),
  [6877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13066),
  [6879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7571),
  [6881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17255),
  [6883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7868),
  [6885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 91),
  [6887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 91),
  [6889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10243),
  [6891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15923),
  [6893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [6895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3104),
  [6897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7885),
  [6899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8222),
  [6901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14404),
  [6903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15419),
  [6905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [6907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21380),
  [6909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16439),
  [6911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16952),
  [6913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7886),
  [6915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21092),
  [6917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14099),
  [6919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12974),
  [6921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7619),
  [6923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17592),
  [6925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 2, 0, 24),
  [6927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 2, 0, 24),
  [6929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10023),
  [6931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 1, 0, 10),
  [6933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 1, 0, 10),
  [6935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10111),
  [6937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 24),
  [6939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 24),
  [6941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10133),
  [6943] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(8355),
  [6946] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17978),
  [6949] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(148),
  [6952] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1504),
  [6955] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(8201),
  [6958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3379),
  [6961] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10838),
  [6964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1505),
  [6967] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14983),
  [6970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15192),
  [6973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(272),
  [6976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(8227),
  [6979] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16418),
  [6982] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16930),
  [6985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(8202),
  [6988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14107),
  [6991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13283),
  [6994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4651),
  [6997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(8204),
  [7000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(18191),
  [7003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 161),
  [7005] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 161),
  [7007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10262),
  [7009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 161),
  [7011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 161),
  [7013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10276),
  [7015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10160),
  [7017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 2, 0, 10),
  [7019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 2, 0, 10),
  [7021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10162),
  [7023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9968),
  [7025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10183),
  [7027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10190),
  [7029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 125),
  [7031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 125),
  [7033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10205),
  [7035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10210),
  [7037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10026),
  [7039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10246),
  [7041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 91),
  [7043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 91),
  [7045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10153),
  [7047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10220),
  [7049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10214),
  [7051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10260),
  [7053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8168),
  [7055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10155),
  [7057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17131),
  [7059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [7061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3040),
  [7063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8108),
  [7065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8427),
  [7067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14609),
  [7069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15569),
  [7071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [7073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20949),
  [7075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15936),
  [7077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16773),
  [7079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8150),
  [7081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21070),
  [7083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14194),
  [7085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12957),
  [7087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8010),
  [7089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17352),
  [7091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10222),
  [7093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10202),
  [7095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10028),
  [7097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9975),
  [7099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9954),
  [7101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10156),
  [7103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10030),
  [7105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10052),
  [7107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10106),
  [7109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9196),
  [7111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [7113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4314),
  [7115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9169),
  [7117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14304),
  [7119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15881),
  [7121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [7123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4116),
  [7125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21332),
  [7127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16394),
  [7129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16917),
  [7131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9181),
  [7133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20552),
  [7135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14085),
  [7137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12992),
  [7139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8925),
  [7141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17621),
  [7143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8435),
  [7145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10259),
  [7147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16258),
  [7149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [7151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3059),
  [7153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8384),
  [7155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8409),
  [7157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14461),
  [7159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15793),
  [7161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [7163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20511),
  [7165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16455),
  [7167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16968),
  [7169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8385),
  [7171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18982),
  [7173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14102),
  [7175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13104),
  [7177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8124),
  [7179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17836),
  [7181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10142),
  [7183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10094),
  [7185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10269),
  [7187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2979),
  [7189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15696),
  [7191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2982),
  [7193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5234),
  [7195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16091),
  [7197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16822),
  [7199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19592),
  [7201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10179),
  [7203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10180),
  [7205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10027),
  [7207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10244),
  [7209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10036),
  [7211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10249),
  [7213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7868),
  [7216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0),
  [7218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0),
  [7220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15923),
  [7223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2488),
  [7226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3104),
  [7229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7885),
  [7232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14404),
  [7235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15419),
  [7238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3107),
  [7241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(21380),
  [7244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16439),
  [7247] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16952),
  [7250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7886),
  [7253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(21092),
  [7256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14099),
  [7259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12974),
  [7262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7619),
  [7265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17592),
  [7268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [7270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14642),
  [7272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [7274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3076),
  [7276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14571),
  [7278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14623),
  [7280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2969),
  [7282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15796),
  [7284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3013),
  [7286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2980),
  [7288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20551),
  [7290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5237),
  [7292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16359),
  [7294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16905),
  [7296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14573),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19564),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14084),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12946),
  [7304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9303),
  [7306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17335),
  [7308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7947),
  [7311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17022),
  [7314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2485),
  [7317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3088),
  [7320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7750),
  [7323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14303),
  [7326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15265),
  [7329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3101),
  [7332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(21405),
  [7335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16410),
  [7338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16923),
  [7341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7758),
  [7344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(21333),
  [7347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14091),
  [7350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13066),
  [7353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(7571),
  [7356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17255),
  [7359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2508),
  [7361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8168),
  [7364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17131),
  [7367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2486),
  [7370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3040),
  [7373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8108),
  [7376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14609),
  [7379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15569),
  [7382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3042),
  [7385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(20949),
  [7388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15936),
  [7391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16773),
  [7394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8150),
  [7397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(21070),
  [7400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14194),
  [7403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(12957),
  [7406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8010),
  [7409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17352),
  [7412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4137),
  [7414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14187),
  [7416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14686),
  [7418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11710),
  [7420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16681),
  [7422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4158),
  [7424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15997),
  [7426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16803),
  [7428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3035),
  [7430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16502),
  [7432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [7434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [7436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [7438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [7440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [7442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [7444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3056),
  [7446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [7448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [7450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [7452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [7454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [7456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3086),
  [7458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [7460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [7462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [7464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3047),
  [7466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [7468] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8435),
  [7471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16258),
  [7474] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2483),
  [7477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3059),
  [7480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8384),
  [7483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14461),
  [7486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15793),
  [7489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3075),
  [7492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(20511),
  [7495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16455),
  [7498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16968),
  [7501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8385),
  [7504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18982),
  [7507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14102),
  [7510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13104),
  [7513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8124),
  [7516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17836),
  [7519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4300),
  [7521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16306),
  [7523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16884),
  [7525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [7527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [7529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2998),
  [7531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [7533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [7535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [7537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [7539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [7541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [7543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3006),
  [7545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3009),
  [7547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [7549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [7551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14595),
  [7553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [7555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4069),
  [7557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9100),
  [7559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [7561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16519),
  [7563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2492),
  [7565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3096),
  [7567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9104),
  [7569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8101),
  [7571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14506),
  [7573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 5, 0, 145),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15229),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [7579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19025),
  [7581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 145),
  [7583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16521),
  [7585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17009),
  [7587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9110),
  [7589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20512),
  [7591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14109),
  [7593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13322),
  [7595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8998),
  [7597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18255),
  [7599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [7601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 3, 0, 108),
  [7603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 3, 0, 108),
  [7605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [7607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 3, 0, 66),
  [7609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 3, 0, 66),
  [7611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [7613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 2, 0, 66),
  [7615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 2, 0, 66),
  [7617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [7619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 4, 0, 108),
  [7621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 108),
  [7623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [7625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 4, 0, 145),
  [7627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 145),
  [7629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8382),
  [7631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12581),
  [7633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21312),
  [7635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8740),
  [7637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12898),
  [7639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8022),
  [7641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_payload, 1, 0, 0),
  [7643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14195),
  [7645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14601),
  [7647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11618),
  [7649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10563),
  [7651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14612),
  [7653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14890),
  [7655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7932),
  [7657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8071),
  [7659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9689),
  [7661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15672),
  [7663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16091),
  [7665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16822),
  [7667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9361),
  [7669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17640),
  [7671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14921),
  [7673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8047),
  [7675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9111),
  [7677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13819),
  [7679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10656),
  [7681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8886),
  [7683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4746),
  [7687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4747),
  [7689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15712),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4748),
  [7693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15938),
  [7695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16137),
  [7697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16833),
  [7699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7801),
  [7701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14938),
  [7703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [7705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4249),
  [7707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14624),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4250),
  [7711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4096),
  [7713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8491),
  [7715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17213),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7930),
  [7719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9138),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7796),
  [7723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8198),
  [7725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14656),
  [7727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14728),
  [7729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8138),
  [7731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7974),
  [7733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(9594),
  [7736] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17236),
  [7739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(160),
  [7742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1758),
  [7745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(9636),
  [7748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(3400),
  [7751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(10915),
  [7754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(1759),
  [7757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14862),
  [7760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(15030),
  [7763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(243),
  [7766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(9642),
  [7769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16464),
  [7772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(16974),
  [7775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(9637),
  [7778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(14123),
  [7781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(13347),
  [7784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(4630),
  [7787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(8491),
  [7790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 2, 0, 74), SHIFT_REPEAT(17213),
  [7793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9166),
  [7795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7819),
  [7797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8025),
  [7799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10652),
  [7801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14822),
  [7803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8037),
  [7805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9093),
  [7807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7800),
  [7809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13814),
  [7811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10638),
  [7813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10641),
  [7815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [7817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8077),
  [7819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9594),
  [7821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17236),
  [7823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [7825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1758),
  [7827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9636),
  [7829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3400),
  [7831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10915),
  [7833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [7835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14862),
  [7837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15030),
  [7839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [7841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9642),
  [7843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16464),
  [7845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16974),
  [7847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9637),
  [7849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14123),
  [7851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13347),
  [7853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4630),
  [7855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10655),
  [7857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9143),
  [7859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8029),
  [7861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7821),
  [7863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8085),
  [7865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13818),
  [7867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13750),
  [7869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13849),
  [7871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13765),
  [7873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8196),
  [7875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8418),
  [7877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7918),
  [7879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9094),
  [7881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10677),
  [7883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8421),
  [7885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14810),
  [7887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14889),
  [7889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14920),
  [7891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7877),
  [7893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8379),
  [7895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8381),
  [7897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7927),
  [7899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7971),
  [7901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9136),
  [7903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7914),
  [7905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7881),
  [7907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8017),
  [7909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10679),
  [7911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13847),
  [7913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__value_name, 1, 0, 1),
  [7915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value_name, 1, 0, 1),
  [7917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__instance_variable_name, 1, 0, 11),
  [7919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0),
  [7921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0),
  [7923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [7925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18383),
  [7927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18176),
  [7929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [7931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_get_expression, 3, 0, 71),
  [7933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_get_expression, 3, 0, 71),
  [7935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_get_expression, 5, 0, 150),
  [7937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_get_expression, 5, 0, 150),
  [7939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_get_expression, 5, 0, 151),
  [7941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_get_expression, 5, 0, 151),
  [7943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bigarray_get_expression, 5, 0, 150),
  [7945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bigarray_get_expression, 5, 0, 150),
  [7947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_get_expression, 6, 0, 186),
  [7949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_get_expression, 6, 0, 186),
  [7951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_get_expression, 6, 0, 187),
  [7953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_get_expression, 6, 0, 187),
  [7955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bigarray_get_expression, 6, 0, 186),
  [7957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bigarray_get_expression, 6, 0, 186),
  [7959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_path, 1, 0, 35),
  [7961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path, 1, 0, 35),
  [7963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_path, 3, 0, 106),
  [7965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path, 3, 0, 106),
  [7967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18132),
  [7969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(9100),
  [7972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16519),
  [7975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2492),
  [7978] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3096),
  [7981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(9104),
  [7984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14506),
  [7987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15229),
  [7990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2992),
  [7993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(19025),
  [7996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16521),
  [7999] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(17009),
  [8002] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(9110),
  [8005] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(20512),
  [8008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14109),
  [8011] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13322),
  [8014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8998),
  [8017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18255),
  [8020] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_extension, 4, 0, 0),
  [8022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_extension, 4, 0, 0),
  [8024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14264),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [8028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [8030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3333),
  [8032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10801),
  [8034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [8036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14882),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15025),
  [8040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [8042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7597),
  [8044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4557),
  [8046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7512),
  [8048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18242),
  [8050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14116),
  [8052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 2, 0, 0),
  [8054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 2, 0, 0),
  [8056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 2, 0, 0),
  [8058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 2, 0, 0),
  [8060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 0),
  [8062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 0),
  [8064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 2, 0, 0),
  [8066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 2, 0, 0),
  [8068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [8070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [8072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [8074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [8076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefix_expression, 2, 0, 37),
  [8078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefix_expression, 2, 0, 37),
  [8080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_application_repeat1, 1, 0, 38),
  [8082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_application_repeat1, 1, 0, 38),
  [8084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 36),
  [8086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 36),
  [8088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 3, 0, 0),
  [8090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 3, 0, 0),
  [8092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 3, 0, 0),
  [8094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 3, 0, 0),
  [8096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 3, 0, 0),
  [8098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 3, 0, 0),
  [8100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 0),
  [8102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 0),
  [8104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 3, 0, 0),
  [8106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 3, 0, 0),
  [8108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 3, 0, 72),
  [8110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 3, 0, 72),
  [8112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_expression, 3, 0, 73),
  [8114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_expression, 3, 0, 73),
  [8116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_expression, 3, 0, 69),
  [8118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_expression, 3, 0, 69),
  [8120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 4, 0, 20),
  [8122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 4, 0, 20),
  [8124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_expression, 4, 0, 101),
  [8126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_expression, 4, 0, 101),
  [8128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 4, 0, 0),
  [8130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 4, 0, 0),
  [8132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 4, 0, 0),
  [8134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 4, 0, 0),
  [8136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 4, 0, 0),
  [8138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 4, 0, 0),
  [8140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 4, 0, 0),
  [8142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 4, 0, 0),
  [8144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 4, 0, 69),
  [8146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 4, 0, 69),
  [8148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_expression, 4, 0, 0),
  [8150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_expression, 4, 0, 0),
  [8152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 5, 0, 136),
  [8154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 5, 0, 136),
  [8156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 5, 0, 52),
  [8158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 5, 0, 52),
  [8160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_coercion_expression, 5, 0, 137),
  [8162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_coercion_expression, 5, 0, 137),
  [8164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_expression, 5, 0, 0),
  [8166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_expression, 5, 0, 0),
  [8168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 5, 0, 139),
  [8170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 5, 0, 139),
  [8172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 5, 0, 0),
  [8174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 5, 0, 0),
  [8176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 5, 0, 0),
  [8178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 5, 0, 0),
  [8180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_copy_expression, 5, 0, 0),
  [8182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_copy_expression, 5, 0, 0),
  [8184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_argument, 4, 0, 100),
  [8186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument, 4, 0, 100),
  [8188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_expression, 5, 0, 152),
  [8190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_expression, 5, 0, 152),
  [8192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_expression, 6, 0, 171),
  [8194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_expression, 6, 0, 171),
  [8196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_coercion_expression, 6, 0, 172),
  [8198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_coercion_expression, 6, 0, 172),
  [8200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 6, 0, 139),
  [8202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 6, 0, 139),
  [8204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_name, 3, 0, 48),
  [8206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_name, 3, 0, 48),
  [8208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_expression, 7, 0, 139),
  [8210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_expression, 7, 0, 139),
  [8212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_path, 1, 0, 0),
  [8214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_path, 1, 0, 0),
  [8216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_path, 3, 0, 0),
  [8218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_path, 3, 0, 0),
  [8220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 2, 0, 0),
  [8222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 2, 0, 0),
  [8224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_path, 1, 0, 10),
  [8226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_path, 1, 0, 10),
  [8228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 3, 0, 0),
  [8230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 3, 0, 0),
  [8232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 4, 0, 0),
  [8234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 4, 0, 0),
  [8236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_path, 3, 0, 111),
  [8238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_path, 3, 0, 111),
  [8240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 5, 0, 141),
  [8242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 5, 0, 141),
  [8244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 6, 0, 141),
  [8246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 6, 0, 141),
  [8248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 6, 0, 174),
  [8250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 6, 0, 174),
  [8252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 6, 0, 184),
  [8254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 6, 0, 184),
  [8256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 7, 0, 174),
  [8258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 7, 0, 174),
  [8260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 7, 0, 184),
  [8262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 7, 0, 184),
  [8264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 7, 0, 210),
  [8266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 7, 0, 210),
  [8268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_expression, 8, 0, 210),
  [8270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_expression, 8, 0, 210),
  [8272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4247),
  [8274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16432),
  [8276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16943),
  [8278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2360),
  [8280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constant, 1, 0, 0),
  [8282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constant, 1, 0, 0),
  [8284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__value_name, 1, 0, 0),
  [8286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value_name, 1, 0, 0),
  [8288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extension, 3, 0, 0),
  [8290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension, 3, 0, 0),
  [8292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extension, 4, 0, 0),
  [8294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension, 4, 0, 0),
  [8296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_extension, 5, 0, 0),
  [8298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_extension, 5, 0, 0),
  [8300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_name, 1, 0, 6),
  [8302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_name, 1, 0, 6),
  [8304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path, 1, 0, 5),
  [8306] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 3, 0, 0),
  [8308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 3, 0, 0),
  [8310] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 6, 0, 0),
  [8312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 6, 0, 0),
  [8314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 7, 0, 0),
  [8316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 7, 0, 0),
  [8318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 8, 0, 0),
  [8320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 8, 0, 0),
  [8322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_operator, 9, 0, 0),
  [8324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_operator, 9, 0, 0),
  [8326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag, 2, 0, 0),
  [8328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag, 2, 0, 0),
  [8330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [8332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [8334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_path, 1, 0, 0),
  [8336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_path, 1, 0, 0),
  [8338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [8340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [8342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unit, 2, 0, 0),
  [8344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 2, 0, 0),
  [8346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4313),
  [8348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16444),
  [8350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16960),
  [8352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_string, 3, 0, 0),
  [8354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_string, 3, 0, 0),
  [8356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_character, 3, 0, 0),
  [8358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character, 3, 0, 0),
  [8360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path, 3, 0, 46),
  [8362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_path, 3, 0, 0),
  [8364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_path, 3, 0, 0),
  [8366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2029),
  [8368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2251),
  [8370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2068),
  [8372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1932),
  [8374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2440),
  [8376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5773),
  [8378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14179),
  [8380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4129),
  [8382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7223),
  [8384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [8386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7977),
  [8388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3365),
  [8390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [8392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16235),
  [8394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16862),
  [8396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16820),
  [8398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7985),
  [8400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14067),
  [8402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13303),
  [8404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4704),
  [8406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5595),
  [8408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10012),
  [8410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [8412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1543),
  [8414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10195),
  [8416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3409),
  [8418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11242),
  [8420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [8422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14917),
  [8424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15081),
  [8426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [8428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10043),
  [8430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17189),
  [8432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17087),
  [8434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10204),
  [8436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14141),
  [8438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13026),
  [8440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4634),
  [8442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10011),
  [8444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17641),
  [8446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_argument, 2, 0, 34),
  [8448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument, 2, 0, 34),
  [8450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4675),
  [8452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7528),
  [8454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [8456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [8458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7569),
  [8460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3370),
  [8462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11209),
  [8464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [8466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14898),
  [8468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15103),
  [8470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [8472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7693),
  [8474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16378),
  [8476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16911),
  [8478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7570),
  [8480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14087),
  [8482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13032),
  [8484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4650),
  [8486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7561),
  [8488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18188),
  [8490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2264),
  [8492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5622),
  [8494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14950),
  [8496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4147),
  [8498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7807),
  [8500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [8502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1633),
  [8504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7907),
  [8506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3426),
  [8508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10852),
  [8510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [8512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14737),
  [8514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15064),
  [8516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [8518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7824),
  [8520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16527),
  [8522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17014),
  [8524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7911),
  [8526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14152),
  [8528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13075),
  [8530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4549),
  [8532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7981),
  [8534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18121),
  [8536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4260),
  [8538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [8540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4321),
  [8542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9210),
  [8544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4307),
  [8546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4724),
  [8548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4594),
  [8550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5945),
  [8552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4730),
  [8554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14171),
  [8556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14189),
  [8558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5724),
  [8560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5729),
  [8562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4447),
  [8564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14166),
  [8566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14177),
  [8568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_argument, 5, 0, 134),
  [8570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument, 5, 0, 134),
  [8572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14069),
  [8574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14074),
  [8576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4744),
  [8578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5677),
  [8580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5697),
  [8582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5707),
  [8584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5709),
  [8586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5895),
  [8588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5923),
  [8590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14844),
  [8592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14846),
  [8594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1894),
  [8596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5896),
  [8598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14945),
  [8600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14949),
  [8602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5934),
  [8604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14772),
  [8606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14776),
  [8608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1975),
  [8610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5783),
  [8612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5745),
  [8614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5672),
  [8616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5742),
  [8618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9258),
  [8620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9274),
  [8622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5816),
  [8624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5733),
  [8626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9251),
  [8628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [8630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9272),
  [8632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5601),
  [8634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9201),
  [8636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9207),
  [8638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4681),
  [8640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5796),
  [8642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5809),
  [8644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5918),
  [8646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5925),
  [8648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5870),
  [8650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5814),
  [8652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4566),
  [8654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16325),
  [8656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16892),
  [8658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16638),
  [8660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17091),
  [8662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18295),
  [8664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16605),
  [8666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17069),
  [8668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4571),
  [8670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17452),
  [8672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18248),
  [8674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17262),
  [8676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18284),
  [8678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16621),
  [8680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17081),
  [8682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16418),
  [8684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16930),
  [8686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17943),
  [8688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17333),
  [8690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17647),
  [8692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4732),
  [8694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4428),
  [8696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4621),
  [8698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4563),
  [8700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8975),
  [8702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [8704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(10706),
  [8707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16818),
  [8710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(2493),
  [8713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3022),
  [8716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(10784),
  [8719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14560),
  [8722] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(15489),
  [8725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(3024),
  [8728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18462),
  [8731] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16137),
  [8734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16833),
  [8737] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(10785),
  [8740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18468),
  [8743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(14052),
  [8746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(13315),
  [8749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8710),
  [8752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(18395),
  [8755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0),
  [8757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0),
  [8759] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(17538),
  [8762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8835),
  [8764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [8766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_id, 2, 0, 0),
  [8768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_id, 2, 0, 0),
  [8770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17538),
  [8772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_id, 1, 0, 0),
  [8774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_id, 1, 0, 0),
  [8776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8921),
  [8778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [8780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8966),
  [8782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [8784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8955),
  [8786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [8788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10319),
  [8790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [8792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18468),
  [8794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [8796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [8798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [8800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [8802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [8804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [8806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [8808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [8810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [8812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [8814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [8816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [8818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [8820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [8822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [8824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2191),
  [8826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [8828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [8830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [8832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [8834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [8836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [8838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [8840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [8842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [8844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [8846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [8848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [8850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [8852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [8854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [8856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [8858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [8860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [8862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [8864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [8866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [8868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [8870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [8872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [8874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [8876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [8878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [8880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [8882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [8884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [8886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [8888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [8890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [8892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [8894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [8896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [8898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [8900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [8902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [8904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [8906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [8908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [8910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [8912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [8914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [8916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [8918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [8920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [8922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [8924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [8926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [8928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [8930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [8932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [8934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [8936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [8938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [8940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [8942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [8944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [8946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [8948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [8950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [8952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [8954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [8956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [8958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [8960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [8962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [8964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [8966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [8968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [8970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [8972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [8974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [8976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [8978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [8980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [8982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10226),
  [8984] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0),
  [8986] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0), SHIFT_REPEAT(5203),
  [8989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0),
  [8991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10067),
  [8993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10207),
  [8995] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0), SHIFT_REPEAT(5145),
  [8998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10149),
  [9000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2238),
  [9002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10051),
  [9004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10170),
  [9006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat1, 1, 0, 0),
  [9008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 1, 0, 0),
  [9010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4578),
  [9012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [9014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2975),
  [9016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2413),
  [9018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2400),
  [9020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4658),
  [9022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_expression, 1, 0, 13),
  [9024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sequence_expression, 1, 0, 13),
  [9026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_signed_number, 2, 0, 0),
  [9028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signed_number, 2, 0, 0),
  [9030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_expression_anonymous, 4, 0, 0),
  [9032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sequence_expression_anonymous, 4, 0, 0),
  [9034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12537),
  [9036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_binding_pattern, 2, 0, 34),
  [9038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_binding_pattern, 2, 0, 34),
  [9040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6004),
  [9042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2041),
  [9044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__signed_constant, 1, 0, 0),
  [9046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signed_constant, 1, 0, 0),
  [9048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5993),
  [9050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_expression_anonymous, 3, 0, 0),
  [9052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sequence_expression_anonymous, 3, 0, 0),
  [9054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12483),
  [9056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4431),
  [9058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_pattern, 2, 0, 0),
  [9060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_pattern, 2, 0, 0),
  [9062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_binding_pattern, 1, 0, 32),
  [9064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_binding_pattern, 1, 0, 32),
  [9066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_binding_pattern, 1, 0, 33),
  [9068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_binding_pattern, 1, 0, 33),
  [9070] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 7, 0, 0),
  [9072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 7, 0, 0),
  [9074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 4, 0, 0),
  [9076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 4, 0, 0),
  [9078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 5, 0, 0),
  [9080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 5, 0, 0),
  [9082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_binding_pattern, 4, 0, 0),
  [9084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_binding_pattern, 4, 0, 0),
  [9086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 3, 0, 0),
  [9088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 3, 0, 0),
  [9090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 5, 0, 165),
  [9092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 5, 0, 165),
  [9094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 5, 0, 166),
  [9096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 5, 0, 166),
  [9098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 4, 0, 0),
  [9100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 4, 0, 0),
  [9102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 3, 0, 0),
  [9104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 3, 0, 0),
  [9106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_binding_pattern, 3, 0, 96),
  [9108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_binding_pattern, 3, 0, 96),
  [9110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__tuple_binding_pattern, 3, 0, 0),
  [9112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_binding_pattern, 3, 0, 0),
  [9114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_binding_pattern, 3, 0, 96),
  [9116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_binding_pattern, 3, 0, 96),
  [9118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_binding_pattern, 3, 0, 96),
  [9120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_binding_pattern, 3, 0, 96),
  [9122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 6, 0, 197),
  [9124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 6, 0, 197),
  [9126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6039),
  [9128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_binding_pattern, 3, 0, 0),
  [9130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_binding_pattern, 3, 0, 0),
  [9132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__or_binding_pattern_anonymous, 3, 0, 0),
  [9134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__or_binding_pattern_anonymous, 3, 0, 0),
  [9136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 3, 0, 0),
  [9138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 3, 0, 0),
  [9140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 5, 0, 0),
  [9142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 5, 0, 0),
  [9144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12536),
  [9146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 0),
  [9148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 0),
  [9150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, 0, 75),
  [9152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, 0, 75),
  [9154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_binding_pattern, 3, 0, 99),
  [9156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_binding_pattern, 3, 0, 99),
  [9158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cons_binding_pattern, 3, 0, 75),
  [9160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cons_binding_pattern, 3, 0, 75),
  [9162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [9164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_binding_pattern, 6, 0, 0),
  [9166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_binding_pattern, 6, 0, 0),
  [9168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6007),
  [9170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_binding_pattern, 4, 0, 128),
  [9172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_binding_pattern, 4, 0, 128),
  [9174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 29),
  [9176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 29),
  [9178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding_pattern, 1, 0, 30),
  [9180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding_pattern, 1, 0, 30),
  [9182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_constructor_path, 1, 0, 4),
  [9184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_constructor_path, 1, 0, 4),
  [9186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_binding_pattern, 5, 0, 168),
  [9188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_binding_pattern, 5, 0, 168),
  [9190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4716),
  [9192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12482),
  [9194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_binding_pattern, 5, 0, 134),
  [9196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_binding_pattern, 5, 0, 134),
  [9198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_binding_pattern, 1, 0, 31),
  [9200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_binding_pattern, 1, 0, 31),
  [9202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_pattern, 4, 0, 46),
  [9204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_pattern, 4, 0, 46),
  [9206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_binding_pattern, 2, 0, 0),
  [9208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_binding_pattern, 2, 0, 0),
  [9210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_binding_pattern, 2, 0, 59),
  [9212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_binding_pattern, 2, 0, 59),
  [9214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 5, 0, 0),
  [9216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 5, 0, 0),
  [9218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_binding_pattern, 2, 0, 59),
  [9220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_binding_pattern, 2, 0, 59),
  [9222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_constructor_path, 3, 0, 45),
  [9224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_constructor_path, 3, 0, 45),
  [9226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag_binding_pattern, 2, 0, 59),
  [9228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_binding_pattern, 2, 0, 59),
  [9230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 2, 0, 0),
  [9232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 2, 0, 0),
  [9234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4521),
  [9236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_binding_pattern, 4, 0, 129),
  [9238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_binding_pattern, 4, 0, 129),
  [9240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_binding_pattern, 4, 0, 0),
  [9242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_binding_pattern, 4, 0, 0),
  [9244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2306),
  [9246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [9248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4457),
  [9250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [9252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16521),
  [9254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17009),
  [9256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [9258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16439),
  [9260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16952),
  [9262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [9264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16455),
  [9266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16968),
  [9268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [9270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9130),
  [9272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17195),
  [9274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [9276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [9278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15936),
  [9280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16773),
  [9282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [9284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [9286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14467),
  [9288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18109),
  [9290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [9292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [9294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14024),
  [9296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2387),
  [9298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2505),
  [9300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16410),
  [9302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16923),
  [9304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2083),
  [9306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [9308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9865),
  [9310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [9312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6484),
  [9314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10985),
  [9316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10096),
  [9318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7856),
  [9320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11218),
  [9322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17145),
  [9324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7832),
  [9326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8102),
  [9328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9415),
  [9330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15498),
  [9332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16486),
  [9334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16985),
  [9336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9579),
  [9338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17284),
  [9340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6494),
  [9342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10996),
  [9344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9909),
  [9346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8470),
  [9348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6530),
  [9350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11033),
  [9352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10181),
  [9354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7990),
  [9356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10962),
  [9358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7869),
  [9360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8158),
  [9362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9530),
  [9364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15804),
  [9366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16579),
  [9368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17046),
  [9370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18385),
  [9372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [9374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6533),
  [9376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11042),
  [9378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10263),
  [9380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8568),
  [9382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6426),
  [9384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11421),
  [9386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10479),
  [9388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7830),
  [9390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11289),
  [9392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7779),
  [9394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8090),
  [9396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9482),
  [9398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15214),
  [9400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16271),
  [9402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16871),
  [9404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17931),
  [9406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10502),
  [9408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8447),
  [9410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6536),
  [9412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11694),
  [9414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10732),
  [9416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7723),
  [9418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11686),
  [9420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7923),
  [9422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8049),
  [9424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9555),
  [9426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15327),
  [9428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16600),
  [9430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17065),
  [9432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18202),
  [9434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6537),
  [9436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11748),
  [9438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14174),
  [9440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18979),
  [9442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4685),
  [9444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14113),
  [9446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19199),
  [9448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4498),
  [9450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1919),
  [9452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2133),
  [9454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2151),
  [9456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [9458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2055),
  [9460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6527),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11431),
  [9464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2319),
  [9466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4697),
  [9468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14176),
  [9470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18755),
  [9472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [9474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11420),
  [9476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10991),
  [9478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11004),
  [9480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2277),
  [9482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11345),
  [9484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11037),
  [9486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11051),
  [9488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11728),
  [9490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11775),
  [9492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2427),
  [9494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [9496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [9498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1987),
  [9500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4424),
  [9502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [9504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1843),
  [9506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1856),
  [9508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [9510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2293),
  [9512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4624),
  [9514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [9516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4711),
  [9518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14169),
  [9520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19989),
  [9522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4525),
  [9524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [9526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2208),
  [9528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4647),
  [9530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2223),
  [9532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4493),
  [9534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_class_expression, 1, 0, 0),
  [9536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_class_expression, 1, 0, 0),
  [9538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4502),
  [9540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4522),
  [9542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4589),
  [9544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14100),
  [9546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_value_pattern, 1, 0, 25),
  [9548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_value_pattern, 1, 0, 25),
  [9550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6045),
  [9552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4546),
  [9554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_class_expression, 3, 0, 0),
  [9556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_class_expression, 3, 0, 0),
  [9558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_class_expression, 4, 0, 163),
  [9560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_class_expression, 4, 0, 163),
  [9562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class, 4, 0, 0),
  [9564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class, 4, 0, 0),
  [9566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class, 5, 0, 0),
  [9568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class, 5, 0, 0),
  [9570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5979),
  [9572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4625),
  [9574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4705),
  [9576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4537),
  [9578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12581),
  [9580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8060),
  [9582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11725),
  [9584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8248),
  [9586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11634),
  [9588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8134),
  [9590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11533),
  [9592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8159),
  [9594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14617),
  [9596] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 4, 0, 96),
  [9598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 96),
  [9600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 4, 0, 128),
  [9602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 128),
  [9604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 8, 0, 232),
  [9606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 8, 0, 232),
  [9608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 2, 0, 59),
  [9610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 59),
  [9612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4757),
  [9614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8061),
  [9616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10973),
  [9618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_abstract_type, 3, 0, 0),
  [9620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_abstract_type, 3, 0, 0),
  [9622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_pattern, 3, 0, 0),
  [9624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_pattern, 3, 0, 0),
  [9626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 3, 0, 0),
  [9628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 3, 0, 0),
  [9630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 9, 0, 237),
  [9632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 9, 0, 237),
  [9634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 3, 0, 0),
  [9636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 3, 0, 0),
  [9638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 3, 0, 0),
  [9640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 3, 0, 0),
  [9642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_pattern, 3, 0, 96),
  [9644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_pattern, 3, 0, 96),
  [9646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8073),
  [9648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12564),
  [9650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 5, 0, 164),
  [9652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, 0, 164),
  [9654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_let_binding_repeat1, 1, 0, 0),
  [9656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 1, 0, 0),
  [9658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8146),
  [9660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9807),
  [9662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6021),
  [9664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 6, 0, 196),
  [9666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 6, 0, 196),
  [9668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8107),
  [9670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9949),
  [9672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 7, 0, 218),
  [9674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 7, 0, 218),
  [9676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8068),
  [9678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10649),
  [9680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter, 1, 0, 27),
  [9682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 27),
  [9684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_pattern, 4, 0, 129),
  [9686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_pattern, 4, 0, 129),
  [9688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 4, 0, 0),
  [9690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 4, 0, 0),
  [9692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 4, 0, 0),
  [9694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 4, 0, 0),
  [9696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 4, 0, 0),
  [9698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 4, 0, 0),
  [9700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_pattern, 4, 0, 0),
  [9702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_pattern, 4, 0, 0),
  [9704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8083),
  [9706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11380),
  [9708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8132),
  [9710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10791),
  [9712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8170),
  [9714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13933),
  [9716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_expression, 3, 0, 69),
  [9718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assert_expression, 3, 0, 69),
  [9720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14164),
  [9722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18917),
  [9724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4710),
  [9726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 5, 0, 0),
  [9728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 5, 0, 0),
  [9730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 5, 0, 0),
  [9732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 5, 0, 0),
  [9734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 5, 0, 0),
  [9736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 5, 0, 0),
  [9738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_pattern, 5, 0, 168),
  [9740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_pattern, 5, 0, 168),
  [9742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8046),
  [9744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11344),
  [9746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8184),
  [9748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11298),
  [9750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8056),
  [9752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9933),
  [9754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8050),
  [9756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13445),
  [9758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 6, 0, 0),
  [9760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 6, 0, 0),
  [9762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8057),
  [9764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10088),
  [9766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8069),
  [9768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9402),
  [9770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 7, 0, 0),
  [9772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 7, 0, 0),
  [9774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8088),
  [9776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9443),
  [9778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4475),
  [9780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8219),
  [9782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11223),
  [9784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8100),
  [9786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13638),
  [9788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_expression, 2, 0, 36),
  [9790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assert_expression, 2, 0, 36),
  [9792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14190),
  [9794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19247),
  [9796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4551),
  [9798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element, 4, 0, 100),
  [9800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element, 4, 0, 100),
  [9802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [9804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11364),
  [9806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8137),
  [9808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9823),
  [9810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_expression, 2, 0, 36),
  [9812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_expression, 2, 0, 36),
  [9814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_expression, 3, 0, 69),
  [9816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_expression, 3, 0, 69),
  [9818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 2, 0, 0),
  [9820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 2, 0, 0),
  [9822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4539),
  [9824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4607),
  [9826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [9828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [9830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8058),
  [9832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10501),
  [9834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8171),
  [9836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13242),
  [9838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4645),
  [9840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8239),
  [9842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11035),
  [9844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8370),
  [9846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8320),
  [9848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8321),
  [9850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8272),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8273),
  [9854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12928),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8795),
  [9858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8117),
  [9860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7833),
  [9862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8118),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9671),
  [9866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15433),
  [9868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16648),
  [9870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17096),
  [9872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17245),
  [9874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8245),
  [9876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8278),
  [9878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8279),
  [9880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8246),
  [9882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11477),
  [9884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8249),
  [9886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13386),
  [9888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8283),
  [9890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8284),
  [9892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9783),
  [9894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10151),
  [9896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10323),
  [9898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11655),
  [9900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11091),
  [9902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8235),
  [9904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8236),
  [9906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10683),
  [9908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9406),
  [9910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8374),
  [9912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12423),
  [9914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8289),
  [9916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8290),
  [9918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8252),
  [9920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11520),
  [9922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9449),
  [9924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8185),
  [9926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8296),
  [9928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8297),
  [9930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8253),
  [9932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11134),
  [9934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [9936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8126),
  [9938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7867),
  [9940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8127),
  [9942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9614),
  [9944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15318),
  [9946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16293),
  [9948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16878),
  [9950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17266),
  [9952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13629),
  [9954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11835),
  [9956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8692),
  [9958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8149),
  [9960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7759),
  [9962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8152),
  [9964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9598),
  [9966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15657),
  [9968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16623),
  [9970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17083),
  [9972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18209),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8220),
  [9976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9976),
  [9978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8229),
  [9980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8257),
  [9982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8299),
  [9984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8300),
  [9986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8258),
  [9988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6003),
  [9990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8230),
  [9992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8212),
  [9994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8213),
  [9996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(18238),
  [9999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8304),
  [10001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8305),
  [10003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10565),
  [10005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11333),
  [10007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8702),
  [10009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8078),
  [10011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7721),
  [10013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8093),
  [10015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9569),
  [10017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15203),
  [10019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16603),
  [10021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17067),
  [10023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18287),
  [10025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11490),
  [10027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9725),
  [10029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8436),
  [10031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8309),
  [10033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9894),
  [10035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8266),
  [10037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [10039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8240),
  [10041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14367),
  [10043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8314),
  [10045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8315),
  [10047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18238),
  [10049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13936),
  [10051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13120),
  [10053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11508),
  [10055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10521),
  [10057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18378),
  [10059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8031),
  [10061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12472),
  [10063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16592),
  [10065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17061),
  [10067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 5, 0, 149),
  [10069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 5, 0, 149),
  [10071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 7, 0, 211),
  [10073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_expression, 7, 0, 211),
  [10075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 3, 0, 68),
  [10077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_expression, 3, 0, 68),
  [10079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element, 2, 0, 34),
  [10081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element, 2, 0, 34),
  [10083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4588),
  [10085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 3, 0, 0),
  [10087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 3, 0, 0),
  [10089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 8, 0, 227),
  [10091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_expression, 8, 0, 227),
  [10093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 5, 0, 110),
  [10095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 5, 0, 110),
  [10097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_toplevel_directive, 1, 0, 0),
  [10099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_toplevel_directive, 1, 0, 0),
  [10101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12040),
  [10103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13353),
  [10105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18251),
  [10107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18585),
  [10109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13354),
  [10111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14078),
  [10113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13261),
  [10115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9098),
  [10117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_expression, 3, 0, 70),
  [10119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_expression, 3, 0, 70),
  [10121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_clause, 2, 0, 0),
  [10123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_clause, 2, 0, 0),
  [10125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14080),
  [10127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20902),
  [10129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4652),
  [10131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_expression, 3, 0, 0),
  [10133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__tuple_expression, 3, 0, 0),
  [10135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_clause, 3, 0, 0),
  [10137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_clause, 3, 0, 0),
  [10139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 4, 0, 110),
  [10141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_expression, 4, 0, 110),
  [10143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 5, 0, 69),
  [10145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expression, 5, 0, 69),
  [10147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 4, 0, 36),
  [10149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_expression, 4, 0, 36),
  [10151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14563),
  [10153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18327),
  [10155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8094),
  [10157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4534),
  [10159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 4, 0, 36),
  [10161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expression, 4, 0, 36),
  [10163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 5, 0, 69),
  [10165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_expression, 5, 0, 69),
  [10167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10374),
  [10169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16512),
  [10171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17005),
  [10173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 2, 0, 0),
  [10175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 2, 0, 0),
  [10177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element, 5, 0, 134),
  [10179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element, 5, 0, 134),
  [10181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11200),
  [10183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17938),
  [10185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16608),
  [10187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17071),
  [10189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_exception_expression, 4, 0, 87),
  [10191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_exception_expression, 4, 0, 87),
  [10193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_module_expression, 4, 0, 87),
  [10195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_module_expression, 4, 0, 87),
  [10197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_open_expression, 4, 0, 87),
  [10199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_open_expression, 4, 0, 87),
  [10201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sign_operator, 1, 0, 0),
  [10203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sign_operator, 1, 0, 0),
  [10205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_operator, 1, 0, 0),
  [10207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10722),
  [10209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16342),
  [10211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16897),
  [10213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 12),
  [10215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 12),
  [10217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 6, 0, 185),
  [10219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 6, 0, 185),
  [10221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 5, 0, 148),
  [10223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 5, 0, 148),
  [10225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expression, 4, 0, 87),
  [10227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expression, 4, 0, 87),
  [10229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 68),
  [10231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 4, 0, 68),
  [10233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expression, 3, 0, 73),
  [10235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expression, 3, 0, 73),
  [10237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [10239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [10241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8554),
  [10243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [10245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1993),
  [10247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [10249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [10251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1996),
  [10253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1997),
  [10255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1998),
  [10257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sign_expression, 2, 0, 37),
  [10259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sign_expression, 2, 0, 37),
  [10261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_expression, 3, 0, 70),
  [10263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_expression, 3, 0, 70),
  [10265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 110),
  [10267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 4, 0, 110),
  [10269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2001),
  [10271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 36),
  [10273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 36),
  [10275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10559),
  [10277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_case, 3, 0, 98),
  [10279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_case, 3, 0, 98),
  [10281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_case, 4, 0, 133),
  [10283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_case, 4, 0, 133),
  [10285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0),
  [10287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0),
  [10289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [10291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [10293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [10295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [10297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [10299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [10301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [10303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [10305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [10307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [10309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [10311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10725),
  [10313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21315),
  [10315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 68),
  [10317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 3, 0, 68),
  [10319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [10321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10769),
  [10323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cons_expression, 3, 0, 75),
  [10325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cons_expression, 3, 0, 75),
  [10327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_expression, 1, 0, 0),
  [10329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sequence_expression, 1, 0, 0),
  [10331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [10333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_then_clause, 2, 0, 36),
  [10335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_then_clause, 2, 0, 36),
  [10337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_type_rhs, 3, 0, 0),
  [10339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__tuple_type_rhs, 3, 0, 0),
  [10341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1969),
  [10343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__attribute, 2, 0, 0),
  [10345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__attribute, 2, 0, 0),
  [10347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_cases, 2, 0, 0),
  [10349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_cases, 2, 0, 0),
  [10351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3033),
  [10353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_cases, 3, 0, 0),
  [10355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_cases, 3, 0, 0),
  [10357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3033),
  [10360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 3, 0, 55),
  [10362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 3, 0, 55),
  [10364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3021),
  [10366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__proper_tuple_type, 3, 0, 0),
  [10368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__proper_tuple_type, 3, 0, 0),
  [10370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3021),
  [10373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_cases, 1, 0, 0),
  [10375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_cases, 1, 0, 0),
  [10377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aliased_type, 3, 0, 104),
  [10379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_aliased_type, 3, 0, 104),
  [10381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1, 0, 0),
  [10383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type, 1, 0, 0),
  [10385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__labeled_tuple_type, 3, 0, 0),
  [10387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__labeled_tuple_type, 3, 0, 0),
  [10389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_refutation_case, 1, 0, 0),
  [10391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_refutation_case, 1, 0, 0),
  [10393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_operator, 1, 0, 0),
  [10395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10591),
  [10397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [10399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [10401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [10403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2244),
  [10405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [10407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [10409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2247),
  [10411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2248),
  [10413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [10415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [10417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2352),
  [10419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2353),
  [10421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2354),
  [10423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [10425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2356),
  [10427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [10429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3079),
  [10431] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3079),
  [10434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [10436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [10438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2020),
  [10440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [10442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2022),
  [10444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [10446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [10448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [10450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2026),
  [10452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [10454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [10456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [10458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3105),
  [10460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3105),
  [10463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [10465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [10467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [10469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [10471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [10473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [10475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [10477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2064),
  [10479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2065),
  [10481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [10483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [10485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2994),
  [10487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [10489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [10491] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2994),
  [10494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [10496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3028),
  [10498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3028),
  [10501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [10503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [10505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4754),
  [10507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9312),
  [10509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8682),
  [10511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9048),
  [10513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8161),
  [10515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7852),
  [10517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8164),
  [10519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9718),
  [10521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15555),
  [10523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16670),
  [10525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17107),
  [10527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17588),
  [10529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10569),
  [10531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10630),
  [10533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10636),
  [10535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [10537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [10539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [10541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [10543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2433),
  [10545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [10547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [10549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2436),
  [10551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2437),
  [10553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2438),
  [10555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10574),
  [10557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10640),
  [10559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [10561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10646),
  [10563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [10565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [10567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [10569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1925),
  [10571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [10573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [10575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [10577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1929),
  [10579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10789),
  [10581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10650),
  [10583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10682),
  [10585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3108),
  [10587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10585),
  [10589] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(5145),
  [10592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(3465),
  [10595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14856),
  [10598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(12885),
  [10601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14182),
  [10604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14633),
  [10607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(11702),
  [10610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(12255),
  [10613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14605),
  [10616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0),
  [10618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16218),
  [10621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16223),
  [10624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(16493),
  [10627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(4312),
  [10630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(18181),
  [10633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3465),
  [10635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12885),
  [10637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14182),
  [10639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14633),
  [10641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11702),
  [10643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12255),
  [10645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14605),
  [10647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [10649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3319),
  [10651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12873),
  [10653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14162),
  [10655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14608),
  [10657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14541),
  [10659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4238),
  [10661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13841),
  [10663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8750),
  [10665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8914),
  [10667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8075),
  [10669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7816),
  [10671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8076),
  [10673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9645),
  [10675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15336),
  [10677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16646),
  [10679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17095),
  [10681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18119),
  [10683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8768),
  [10685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9033),
  [10687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8089),
  [10689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10594),
  [10691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10600),
  [10693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10724),
  [10695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9808),
  [10697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8673),
  [10699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8898),
  [10701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8130),
  [10703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7836),
  [10705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8131),
  [10707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9690),
  [10709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15470),
  [10711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16658),
  [10713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17101),
  [10715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17366),
  [10717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10609),
  [10719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [10721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [10723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [10725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8901),
  [10727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9476),
  [10729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8707),
  [10731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8969),
  [10733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8032),
  [10735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7771),
  [10737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8033),
  [10739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9615),
  [10741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15815),
  [10743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16642),
  [10745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17093),
  [10747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17240),
  [10749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(3319),
  [10752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(12873),
  [10755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14162),
  [10758] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14608),
  [10761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(14541),
  [10764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(4238),
  [10767] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0), SHIFT_REPEAT(18174),
  [10770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8721),
  [10772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8973),
  [10774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8141),
  [10776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor, 4, 0, 87),
  [10778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12138),
  [10780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor, 4, 0, 87),
  [10782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16733),
  [10784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16784),
  [10786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10743),
  [10788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9376),
  [10790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8677),
  [10792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8997),
  [10794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8140),
  [10796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7842),
  [10798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8142),
  [10800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9706),
  [10802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15510),
  [10804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16668),
  [10806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17106),
  [10808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17464),
  [10810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10614),
  [10812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13610),
  [10814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8687),
  [10816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8865),
  [10818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8023),
  [10820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7857),
  [10822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8024),
  [10824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9383),
  [10826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15599),
  [10828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16672),
  [10830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17108),
  [10832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17714),
  [10834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3001),
  [10836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3001),
  [10839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10759),
  [10841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10623),
  [10843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8685),
  [10845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9034),
  [10847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8048),
  [10849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3108),
  [10852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8783),
  [10854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8892),
  [10856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8156),
  [10858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9312),
  [10860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10263),
  [10862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [10864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2366),
  [10866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2367),
  [10868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [10870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [10872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2370),
  [10874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2371),
  [10876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [10878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [10880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12928),
  [10882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [10884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [10886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13610),
  [10888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9808),
  [10890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11134),
  [10892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2254),
  [10894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2255),
  [10896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [10898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2257),
  [10900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [10902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [10904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2260),
  [10906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [10908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11333),
  [10910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9865),
  [10912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3019),
  [10914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2262),
  [10916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11835),
  [10918] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3019),
  [10921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [10923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9909),
  [10925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [10927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13841),
  [10929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5963),
  [10931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3050),
  [10933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3050),
  [10936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [10938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9476),
  [10940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [10942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2265),
  [10944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9376),
  [10946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10502),
  [10948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [10950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_of, 4, 0, 52),
  [10952] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_of, 4, 0, 52),
  [10954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3015),
  [10956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [10958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [10960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [10962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [10964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [10966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1886),
  [10968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [10970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [10972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1890),
  [10974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1891),
  [10976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [10978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1935),
  [10980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [10982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [10984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1940),
  [10986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [10988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [10990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1956),
  [10992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [10994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [10996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3100),
  [10998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5973),
  [11000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16112),
  [11002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16829),
  [11004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_path, 1, 0, 5),
  [11006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3100),
  [11009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_path, 3, 0, 46),
  [11011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_expression, 1, 0, 0),
  [11013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module_expression, 1, 0, 0),
  [11015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20007),
  [11017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12418),
  [11019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_variable, 2, 0, 0),
  [11021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_variable, 2, 0, 0),
  [11023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3015),
  [11026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 4, 0, 85),
  [11028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 4, 0, 85),
  [11030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_module_expression, 4, 0, 86),
  [11032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_module_expression, 4, 0, 86),
  [11034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [11036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure, 3, 0, 0),
  [11038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structure, 3, 0, 0),
  [11040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [11042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 5, 0, 121),
  [11044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 5, 0, 121),
  [11046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12889),
  [11048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14191),
  [11050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14634),
  [11052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10796),
  [11054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14570),
  [11056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14735),
  [11058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9919),
  [11060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 6, 0, 155),
  [11062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 6, 0, 155),
  [11064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_module_expression, 1, 0, 0),
  [11066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_module_expression, 1, 0, 0),
  [11068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19794),
  [11070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4679),
  [11072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_module_expression, 3, 0, 0),
  [11074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_module_expression, 3, 0, 0),
  [11076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_packed_module, 7, 0, 188),
  [11078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_packed_module, 7, 0, 188),
  [11080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14439),
  [11082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure, 2, 0, 0),
  [11084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structure, 2, 0, 0),
  [11086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_application, 2, 0, 21),
  [11088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_application, 2, 0, 21),
  [11090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_application, 3, 0, 53),
  [11092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_application, 3, 0, 53),
  [11094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 5, 0, 120),
  [11096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 5, 0, 120),
  [11098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 83),
  [11100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 83),
  [11102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signature, 1, 0, 0),
  [11104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9644),
  [11106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [11108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [11110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15459),
  [11112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14195),
  [11114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(13551),
  [11117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14856),
  [11120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(12898),
  [11123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0),
  [11125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14195),
  [11128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14601),
  [11131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(11618),
  [11134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(10563),
  [11137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14612),
  [11140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14890),
  [11143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(16218),
  [11146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(16223),
  [11149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(16493),
  [11152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 84),
  [11154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 84),
  [11156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9629),
  [11158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_type_rhs, 1, 0, 0),
  [11160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__tuple_type_rhs, 1, 0, 0),
  [11162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9939),
  [11164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15424),
  [11166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14206),
  [11169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9003),
  [11171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9829),
  [11173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(12889),
  [11176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14191),
  [11179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14634),
  [11182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(10796),
  [11185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14570),
  [11188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 2, 0, 0), SHIFT_REPEAT(14735),
  [11191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9822),
  [11193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15458),
  [11195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 3, 0, 50),
  [11197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 3, 0, 50),
  [11199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_type, 3, 0, 103),
  [11201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_type, 3, 0, 103),
  [11203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8988),
  [11205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9842),
  [11207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15425),
  [11209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10391),
  [11211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9883),
  [11213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11363),
  [11215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8684),
  [11217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8036),
  [11219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7727),
  [11221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8044),
  [11223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9544),
  [11225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15891),
  [11227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16586),
  [11229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17054),
  [11231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17696),
  [11233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4476),
  [11235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9915),
  [11237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9044),
  [11239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9732),
  [11241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15351),
  [11243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 2, 0, 7),
  [11245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 2, 0, 7),
  [11247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 3, 0, 20),
  [11249] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 3, 0, 20),
  [11251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_equation, 3, 0, 77),
  [11253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_equation, 3, 0, 77),
  [11255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17431),
  [11257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9632),
  [11259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_equation, 2, 0, 43),
  [11261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_equation, 2, 0, 43),
  [11263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13618),
  [11265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8696),
  [11267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8115),
  [11269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7735),
  [11271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8119),
  [11273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9584),
  [11275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15436),
  [11277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17704),
  [11279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9294),
  [11281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9883),
  [11283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15291),
  [11285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_module_path, 4, 0, 0),
  [11287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extended_module_path, 4, 0, 0),
  [11289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_module_path, 3, 0, 46),
  [11291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extended_module_path, 3, 0, 46),
  [11293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11597),
  [11295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15359),
  [11297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10753),
  [11299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8716),
  [11301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8039),
  [11303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7784),
  [11305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8043),
  [11307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9626),
  [11309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15231),
  [11311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17198),
  [11313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10672),
  [11315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8722),
  [11317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8053),
  [11319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7804),
  [11321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8055),
  [11323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9633),
  [11325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15282),
  [11327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17577),
  [11329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 2, 0, 7),
  [11331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 2, 0, 7),
  [11333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10157),
  [11335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11102),
  [11337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8760),
  [11339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8062),
  [11341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7746),
  [11343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8063),
  [11345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9508),
  [11347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15701),
  [11349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18237),
  [11351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 4, 0, 52),
  [11353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 4, 0, 52),
  [11355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9847),
  [11357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11332),
  [11359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8744),
  [11361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8114),
  [11363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7803),
  [11365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8125),
  [11367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9494),
  [11369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15620),
  [11371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16495),
  [11373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16990),
  [11375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17617),
  [11377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signature, 2, 0, 0),
  [11379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 3, 0, 20),
  [11381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 3, 0, 20),
  [11383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9847),
  [11385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15583),
  [11387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11429),
  [11389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8764),
  [11391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8091),
  [11393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7828),
  [11395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8092),
  [11397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9657),
  [11399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15387),
  [11401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17192),
  [11403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10427),
  [11405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_path, 3, 0, 18),
  [11407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_path, 3, 0, 18),
  [11409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_module_path, 1, 0, 5),
  [11411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extended_module_path, 1, 0, 5),
  [11413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_path, 1, 0, 8),
  [11415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_path, 1, 0, 8),
  [11417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_constraint, 4, 0, 114),
  [11419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_constraint, 4, 0, 114),
  [11421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_module, 4, 0, 157),
  [11423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_module, 4, 0, 157),
  [11425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17220),
  [11427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19210),
  [11429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9777),
  [11431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10545),
  [11433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14298),
  [11435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21055),
  [11437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9457),
  [11439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21201),
  [11441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9463),
  [11443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18561),
  [11445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13641),
  [11447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 5, 0, 6),
  [11449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 5, 0, 6),
  [11451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_argument, 1, 0, 0),
  [11453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10451),
  [11455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15744),
  [11457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10140),
  [11459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9781),
  [11461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15377),
  [11463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18742),
  [11465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13692),
  [11467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18780),
  [11469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13678),
  [11471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15378),
  [11473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9917),
  [11475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 5, 0, 0),
  [11477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 5, 0, 0),
  [11479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0),
  [11481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0),
  [11483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 2, 0, 0),
  [11485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 2, 0, 0),
  [11487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 2, 0, 0),
  [11489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 2, 0, 0),
  [11491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 2, 0, 0),
  [11493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 2, 0, 0),
  [11495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructed_type, 2, 0, 0),
  [11497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructed_type, 2, 0, 0),
  [11499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 3, 0, 0),
  [11501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 3, 0, 0),
  [11503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 3, 0, 0),
  [11505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 3, 0, 0),
  [11507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 3, 0, 0),
  [11509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 3, 0, 0),
  [11511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_type, 3, 0, 105),
  [11513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_type, 3, 0, 105),
  [11515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19329),
  [11517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9934),
  [11519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_type, 4, 0, 0),
  [11521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_type, 4, 0, 0),
  [11523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructed_type, 4, 0, 0),
  [11525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructed_type, 4, 0, 0),
  [11527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 4, 0, 0),
  [11529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 4, 0, 0),
  [11531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 4, 0, 0),
  [11533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 4, 0, 0),
  [11535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_type, 5, 0, 0),
  [11537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_type, 5, 0, 0),
  [11539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 5, 0, 0),
  [11541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 5, 0, 0),
  [11543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructed_type, 5, 0, 0),
  [11545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructed_type, 5, 0, 0),
  [11547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 5, 0, 0),
  [11549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 5, 0, 0),
  [11551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 5, 0, 0),
  [11553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 5, 0, 0),
  [11555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_open_type, 5, 0, 173),
  [11557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_open_type, 5, 0, 173),
  [11559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hash_type, 6, 0, 0),
  [11561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hash_type, 6, 0, 0),
  [11563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 6, 0, 0),
  [11565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 6, 0, 0),
  [11567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 6, 0, 0),
  [11569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 6, 0, 0),
  [11571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_variant_type, 7, 0, 0),
  [11573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_variant_type, 7, 0, 0),
  [11575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_path, 1, 0, 60),
  [11577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_path, 1, 0, 60),
  [11579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20073),
  [11581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9912),
  [11583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20330),
  [11585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9764),
  [11587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_path, 3, 0, 130),
  [11589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_path, 3, 0, 130),
  [11591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0),
  [11593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0),
  [11595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16380),
  [11598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19075),
  [11600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9952),
  [11602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, 0, 6),
  [11604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, 0, 6),
  [11606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15582),
  [11608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, 0, 0),
  [11610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, 0, 0),
  [11612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 6, 0, 17),
  [11614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 6, 0, 17),
  [11616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_open_class_expression, 4, 0, 87),
  [11618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_open_class_expression, 4, 0, 87),
  [11620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9002),
  [11622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9786),
  [11624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18791),
  [11626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11381),
  [11628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_function, 4, 0, 87),
  [11630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_function, 4, 0, 87),
  [11632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19047),
  [11634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11491),
  [11636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19118),
  [11638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11445),
  [11640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18960),
  [11642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10083),
  [11644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19789),
  [11646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10974),
  [11648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 4, 0, 17),
  [11650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 4, 0, 17),
  [11652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20082),
  [11654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9967),
  [11656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20257),
  [11658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11150),
  [11660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20297),
  [11662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11189),
  [11664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14778),
  [11666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16526),
  [11668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20732),
  [11670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9827),
  [11672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20945),
  [11674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9814),
  [11676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10157),
  [11678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15779),
  [11680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14059),
  [11682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20028),
  [11684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4637),
  [11686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18591),
  [11688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11439),
  [11690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18754),
  [11692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11287),
  [11694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18785),
  [11696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11347),
  [11698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9749),
  [11700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21082),
  [11702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10506),
  [11704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10372),
  [11706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18582),
  [11708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10380),
  [11710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18912),
  [11712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10340),
  [11714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18609),
  [11716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11756),
  [11718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_class_expression, 3, 0, 70),
  [11720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_class_expression, 3, 0, 70),
  [11722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19316),
  [11724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11677),
  [11726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20983),
  [11728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11727),
  [11730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20937),
  [11732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14618),
  [11734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20017),
  [11736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14496),
  [11738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20736),
  [11740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14567),
  [11742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19370),
  [11744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12565),
  [11746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19974),
  [11748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12449),
  [11750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20132),
  [11752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12459),
  [11754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19413),
  [11756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11365),
  [11758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21198),
  [11760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9809),
  [11762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20741),
  [11764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13065),
  [11766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8838),
  [11768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9811),
  [11770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19111),
  [11772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9938),
  [11774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18741),
  [11776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9741),
  [11778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 1, 0, 0),
  [11780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_binding_repeat1, 1, 0, 0),
  [11782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18783),
  [11784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10651),
  [11786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20773),
  [11788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10719),
  [11790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20997),
  [11792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10741),
  [11794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21313),
  [11796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10792),
  [11798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20705),
  [11800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12951),
  [11802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19887),
  [11804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10578),
  [11806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20434),
  [11808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10590),
  [11810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21135),
  [11812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11474),
  [11814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18942),
  [11816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13950),
  [11818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8938),
  [11820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9826),
  [11822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19612),
  [11824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13966),
  [11826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19788),
  [11828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13944),
  [11830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21345),
  [11832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11315),
  [11834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20892),
  [11836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11350),
  [11838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21209),
  [11840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11281),
  [11842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21374),
  [11844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11328),
  [11846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19689),
  [11848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13457),
  [11850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18640),
  [11852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13404),
  [11854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18753),
  [11856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13487),
  [11858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18611),
  [11860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13232),
  [11862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20754),
  [11864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10150),
  [11866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18493),
  [11868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9956),
  [11870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18556),
  [11872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9980),
  [11874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19093),
  [11876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9403),
  [11878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19493),
  [11880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9419),
  [11882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19632),
  [11884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [11886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4725),
  [11888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20358),
  [11890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9444),
  [11892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20991),
  [11894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9879),
  [11896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9375),
  [11898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9979),
  [11900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10672),
  [11902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15761),
  [11904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9557),
  [11906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_module_type, 3, 0, 0),
  [11908] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_module_type, 3, 0, 0),
  [11910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13058),
  [11912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10753),
  [11914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15601),
  [11916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signature, 3, 0, 0),
  [11918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_signature, 3, 0, 0),
  [11920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 1, 0, 3),
  [11922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 1, 0, 3),
  [11924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6149),
  [11926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8741),
  [11928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8946),
  [11930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9905),
  [11932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15592),
  [11934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 2, 0, 5),
  [11936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 2, 0, 5),
  [11938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12628),
  [11940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16380),
  [11942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11318),
  [11944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13714),
  [11946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11244),
  [11948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [11950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [11952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [11954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [11956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2184),
  [11958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [11960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [11962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [11964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [11966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [11968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0),
  [11970] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0),
  [11972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(16473),
  [11975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 2, 0, 16),
  [11977] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 2, 0, 16),
  [11979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6154),
  [11981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8780),
  [11983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8960),
  [11985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9940),
  [11987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12817),
  [11989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8360),
  [11991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3062),
  [11993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10097),
  [11995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10273),
  [11997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8951),
  [11999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5235),
  [12001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6151),
  [12003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [12005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_module_type, 5, 0, 189),
  [12007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_module_type, 5, 0, 189),
  [12009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6150),
  [12011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 1, 0, 5),
  [12013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 1, 0, 5),
  [12015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12621),
  [12017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9886),
  [12019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9355),
  [12021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9053),
  [12023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9721),
  [12025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_argument, 1, 0, 0),
  [12027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10373),
  [12029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_declaration_repeat1, 1, 0, 0),
  [12031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11386),
  [12033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13594),
  [12035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2192),
  [12037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9632),
  [12039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10366),
  [12041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11558),
  [12043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10486),
  [12045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10429),
  [12047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0),
  [12049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0),
  [12051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11865),
  [12053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9761),
  [12055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10336),
  [12057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signature, 2, 0, 0),
  [12059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_signature, 2, 0, 0),
  [12061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2989),
  [12063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2989),
  [12066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10391),
  [12068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15774),
  [12070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10357),
  [12072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_type, 1, 0, 0),
  [12074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module_type, 1, 0, 0),
  [12076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14036),
  [12078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20159),
  [12080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4417),
  [12082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_item_extension, 4, 0, 0),
  [12084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_item_extension, 4, 0, 0),
  [12086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11102),
  [12088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15441),
  [12090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6539),
  [12092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3064),
  [12094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10125),
  [12096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8827),
  [12098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5247),
  [12100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9539),
  [12102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3065),
  [12104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10252),
  [12106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8962),
  [12108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5238),
  [12110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3072),
  [12112] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3072),
  [12115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15773),
  [12117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7578),
  [12119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3066),
  [12121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10267),
  [12123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8971),
  [12125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11073),
  [12127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5239),
  [12129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16503),
  [12131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16999),
  [12133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 2, 0, 0),
  [12135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 2, 0, 0),
  [12137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10342),
  [12139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_extension, 5, 0, 0),
  [12141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_extension, 5, 0, 0),
  [12143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_item_extension, 5, 0, 0),
  [12145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_item_extension, 5, 0, 0),
  [12147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_parameter, 2, 0, 0),
  [12149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_parameter, 2, 0, 0),
  [12151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10358),
  [12153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [12155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [12157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [12159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1875),
  [12161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [12163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [12165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1878),
  [12167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1879),
  [12169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15762),
  [12171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6325),
  [12173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [12175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8885),
  [12177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [12179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [12181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [12183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [12185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [12187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2009),
  [12189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [12191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [12193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2012),
  [12195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2013),
  [12197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2014),
  [12199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7094),
  [12201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3069),
  [12203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9955),
  [12205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8981),
  [12207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5243),
  [12209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4726),
  [12211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0),
  [12213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0),
  [12215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12759),
  [12217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11310),
  [12219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6155),
  [12221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7581),
  [12223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3068),
  [12225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10285),
  [12227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8979),
  [12229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11197),
  [12231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5241),
  [12233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16590),
  [12235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17058),
  [12237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 3, 0, 0),
  [12239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 3, 0, 0),
  [12241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_open_class_type, 4, 0, 87),
  [12243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_open_class_type, 4, 0, 87),
  [12245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class_type, 4, 0, 0),
  [12247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class_type, 4, 0, 0),
  [12249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [12251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_item_extension, 6, 0, 0),
  [12253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_item_extension, 6, 0, 0),
  [12255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_extension, 3, 0, 0),
  [12257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_extension, 3, 0, 0),
  [12259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variant_declaration, 1, 0, 0),
  [12261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variant_declaration, 1, 0, 0),
  [12263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18231),
  [12265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20582),
  [12267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11218),
  [12269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10014),
  [12271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_parameter, 4, 0, 88),
  [12273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_parameter, 4, 0, 88),
  [12275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [12277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [12279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9059),
  [12281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9867),
  [12283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12782),
  [12285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10516),
  [12287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiated_class_type, 5, 0, 0),
  [12289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiated_class_type, 5, 0, 0),
  [12291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 5, 0, 198),
  [12293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 5, 0, 198),
  [12295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10385),
  [12297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_class_type, 1, 0, 0),
  [12299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_class_type, 1, 0, 0),
  [12301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18239),
  [12303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20600),
  [12305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10962),
  [12307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9884),
  [12309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 6, 0, 198),
  [12311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 6, 0, 198),
  [12313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 1, 0, 0),
  [12315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_binding_repeat1, 1, 0, 0),
  [12317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_extension, 4, 0, 0),
  [12319] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_extension, 4, 0, 0),
  [12321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body_type, 2, 0, 0),
  [12323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body_type, 2, 0, 0),
  [12325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15603),
  [12327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4723),
  [12329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [12331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2230),
  [12333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2231),
  [12335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [12337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2233),
  [12339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2234),
  [12341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 7, 0, 0),
  [12343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 7, 0, 0),
  [12345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 8, 0, 17),
  [12347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 8, 0, 17),
  [12349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12803),
  [12351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11363),
  [12353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15665),
  [12355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2228),
  [12357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2235),
  [12359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [12361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 5, 0, 28),
  [12363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 5, 0, 28),
  [12365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13309),
  [12367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18195),
  [12369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20523),
  [12371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11283),
  [12373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13662),
  [12375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [12377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11332),
  [12379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15669),
  [12381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18220),
  [12383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20543),
  [12385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11515),
  [12387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10140),
  [12389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18386),
  [12391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15443),
  [12393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10311),
  [12395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0),
  [12397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0),
  [12399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8984),
  [12402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9915),
  [12404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9526),
  [12406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8985),
  [12409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10433),
  [12411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_attribute, 4, 0, 0),
  [12413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_attribute, 4, 0, 0),
  [12415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13955),
  [12417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6157),
  [12419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8770),
  [12421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8970),
  [12423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11429),
  [12425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15267),
  [12427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [12429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12490),
  [12431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 6, 0, 63),
  [12433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 6, 0, 63),
  [12435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9629),
  [12437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6156),
  [12439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_item_attribute, 3, 0, 0),
  [12441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_item_attribute, 3, 0, 0),
  [12443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18223),
  [12445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20502),
  [12447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11289),
  [12449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13519),
  [12451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10492),
  [12453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(18386),
  [12456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 7, 0, 6),
  [12458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 7, 0, 6),
  [12460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6025),
  [12462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 1, 0, 0),
  [12464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 1, 0, 0),
  [12466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9644),
  [12468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 3, 0, 122),
  [12470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 3, 0, 122),
  [12472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8984),
  [12474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 4, 0, 156),
  [12476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 4, 0, 156),
  [12478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 4, 0, 122),
  [12480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 4, 0, 122),
  [12482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrain_type, 5, 0, 156),
  [12484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constrain_type, 5, 0, 156),
  [12486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8985),
  [12488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11549),
  [12490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9801),
  [12492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10788),
  [12494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11555),
  [12496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21077),
  [12498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9216),
  [12500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15884),
  [12502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16506),
  [12504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9362),
  [12506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9991),
  [12508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17983),
  [12510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14312),
  [12512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11495),
  [12514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15876),
  [12516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15692),
  [12518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10316),
  [12520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10446),
  [12522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10556),
  [12524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9294),
  [12526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15670),
  [12528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15666),
  [12530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15688),
  [12532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17618),
  [12534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9768),
  [12536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [12538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [12540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [12542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [12544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2104),
  [12546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [12548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2106),
  [12550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [12552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2108),
  [12554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [12556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [12558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8978),
  [12560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, 0, 0),
  [12562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, 0, 0),
  [12564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15269),
  [12566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [12568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(17618),
  [12571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 2, 0, 15),
  [12573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 2, 0, 15),
  [12575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13665),
  [12577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18125),
  [12579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20254),
  [12581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11608),
  [12583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 44),
  [12585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 44),
  [12587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13628),
  [12589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13654),
  [12591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18240),
  [12593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20618),
  [12595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11686),
  [12597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13655),
  [12599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8978),
  [12602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4694),
  [12604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8871),
  [12606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9831),
  [12608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 4, 0, 0),
  [12610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 4, 0, 0),
  [12612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 3, 0, 0),
  [12614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 3, 0, 0),
  [12616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3095),
  [12618] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3095),
  [12621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11566),
  [12623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15200),
  [12625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 44),
  [12627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 44),
  [12629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 131),
  [12631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 131),
  [12633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 3, 0, 98),
  [12635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 3, 0, 98),
  [12637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [12639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9009),
  [12641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14696),
  [12643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7609),
  [12645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9799),
  [12647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15060),
  [12649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [12651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17144),
  [12653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 78),
  [12655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 78),
  [12657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__polymorphic_typed, 2, 0, 40),
  [12659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__polymorphic_typed, 2, 0, 40),
  [12661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__polymorphic_type, 1, 0, 0),
  [12663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__polymorphic_type, 1, 0, 0),
  [12665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [12667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 44),
  [12669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 44),
  [12671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(17712),
  [12674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 5, 0, 123),
  [12676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 5, 0, 123),
  [12678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 6, 0, 120),
  [12680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 6, 0, 120),
  [12682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 158),
  [12684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 158),
  [12686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [12688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7427),
  [12690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 118),
  [12692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 118),
  [12694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 80),
  [12696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 80),
  [12698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 81),
  [12700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 81),
  [12702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [12704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3299),
  [12706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_type, 3, 0, 112),
  [12708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_type, 3, 0, 112),
  [12710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_type, 3, 0, 105),
  [12712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_type, 3, 0, 105),
  [12714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 15),
  [12716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 15),
  [12718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [12720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [12722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [12724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [12726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [12728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2395),
  [12730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2396),
  [12732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2397),
  [12734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17712),
  [12736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [12738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [12740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8234),
  [12742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_function_type, 3, 0, 55),
  [12744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_function_type, 3, 0, 55),
  [12746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 126),
  [12748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 126),
  [12750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [12752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6794),
  [12754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 133),
  [12756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 133),
  [12758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0),
  [12760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0),
  [12762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [12764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 4, 0, 90),
  [12766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 4, 0, 90),
  [12768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [12770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4438),
  [12772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 127),
  [12774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 127),
  [12776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 170),
  [12778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 170),
  [12780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3229),
  [12782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7783),
  [12784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 95),
  [12786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 95),
  [12788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11597),
  [12790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9849),
  [12792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15860),
  [12794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3221),
  [12796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6903),
  [12798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [12800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7015),
  [12802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15862),
  [12804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 97),
  [12806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 97),
  [12808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 131),
  [12810] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 131),
  [12812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 15),
  [12814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 15),
  [12816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 3, 0, 19),
  [12818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 3, 0, 19),
  [12820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2997),
  [12822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [12824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5107),
  [12826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [12828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5392),
  [12830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 50),
  [12832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 50),
  [12834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2997),
  [12837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 57),
  [12839] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 57),
  [12841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 24),
  [12843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 24),
  [12845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [12847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6078),
  [12849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3177),
  [12851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6424),
  [12853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 4, 0, 98),
  [12855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 4, 0, 98),
  [12857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 4, 0, 132),
  [12859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 4, 0, 132),
  [12861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [12863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5155),
  [12865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 236),
  [12867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 236),
  [12869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 4, 0, 133),
  [12871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 4, 0, 133),
  [12873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [12875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5578),
  [12877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [12879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [12881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [12883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [12885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [12887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [12889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2408),
  [12891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2409),
  [12893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2410),
  [12895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [12897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [12899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4736),
  [12901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 117),
  [12903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 117),
  [12905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [12907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4075),
  [12909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(16479),
  [12912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 42),
  [12914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 42),
  [12916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 91),
  [12918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 91),
  [12920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 47),
  [12922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 47),
  [12924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 115),
  [12926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 115),
  [12928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 58),
  [12930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 58),
  [12932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 116),
  [12934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 116),
  [12936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 3),
  [12938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 3),
  [12940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 154),
  [12942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 154),
  [12944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [12946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9623),
  [12948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 229),
  [12950] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 229),
  [12952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 162),
  [12954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 162),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3363),
  [12960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 7, 0, 117),
  [12962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 7, 0, 117),
  [12964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 3, 0, 5),
  [12966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 3, 0, 5),
  [12968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 9, 0, 228),
  [12970] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 9, 0, 228),
  [12972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3219),
  [12974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6872),
  [12976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 6, 0, 190),
  [12978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 6, 0, 190),
  [12980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 158),
  [12982] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 158),
  [12984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 191),
  [12986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 191),
  [12988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 192),
  [12990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 192),
  [12992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 159),
  [12994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 159),
  [12996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 193),
  [12998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 193),
  [13000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 160),
  [13002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 160),
  [13004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 125),
  [13006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 125),
  [13008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [13010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 162),
  [13012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 162),
  [13014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 79),
  [13016] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 79),
  [13018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13643),
  [13020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 1, 0, 6),
  [13022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 1, 0, 6),
  [13024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15184),
  [13026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9567),
  [13028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9340),
  [13030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8847),
  [13032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9900),
  [13034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 169),
  [13036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 169),
  [13038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 199),
  [13040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 199),
  [13042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 200),
  [13044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 200),
  [13046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3231),
  [13048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4996),
  [13050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 170),
  [13052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 170),
  [13054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [13056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [13058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_floating_attribute, 3, 0, 0),
  [13060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_floating_attribute, 3, 0, 0),
  [13062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [13064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7206),
  [13066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 1, 0, 0),
  [13068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 1, 0, 0),
  [13070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15061),
  [13072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9568),
  [13074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9342),
  [13076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 2, 0, 3),
  [13078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 2, 0, 3),
  [13080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 2, 0, 19),
  [13082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 2, 0, 19),
  [13084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12626),
  [13086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12627),
  [13088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10482),
  [13090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 42),
  [13092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 42),
  [13094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 16),
  [13096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 16),
  [13098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 3, 0, 51),
  [13100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 3, 0, 51),
  [13102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12633),
  [13104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12634),
  [13106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13656),
  [13108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_type, 1, 0, 0),
  [13110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_type, 1, 0, 0),
  [13112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 76),
  [13114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 76),
  [13116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 78),
  [13118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 78),
  [13120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 79),
  [13122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 79),
  [13124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 76),
  [13126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 76),
  [13128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 115),
  [13130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 115),
  [13132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 116),
  [13134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 116),
  [13136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 117),
  [13138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 117),
  [13140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 115),
  [13142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 115),
  [13144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 116),
  [13146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 116),
  [13148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 154),
  [13150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 154),
  [13152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_typed, 2, 0, 61),
  [13154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_typed, 2, 0, 61),
  [13156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 3, 0, 90),
  [13158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 3, 0, 90),
  [13160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [13162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5787),
  [13164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [13166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6849),
  [13168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 118),
  [13170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 118),
  [13172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [13174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5966),
  [13176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 2, 0, 17),
  [13178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 2, 0, 17),
  [13180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15054),
  [13182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9571),
  [13184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9365),
  [13186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18232),
  [13188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20563),
  [13190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12311),
  [13192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [13194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7579),
  [13196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_constraint, 4, 0, 56),
  [13198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_constraint, 4, 0, 56),
  [13200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15130),
  [13202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(15130),
  [13205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 8, 0, 154),
  [13207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 8, 0, 154),
  [13209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 7, 0, 190),
  [13211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 7, 0, 190),
  [13213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15185),
  [13215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(15185),
  [13218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 7, 0, 212),
  [13220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 7, 0, 212),
  [13222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 191),
  [13224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 191),
  [13226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 192),
  [13228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 192),
  [13230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 213),
  [13232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 213),
  [13234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 193),
  [13236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 193),
  [13238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 214),
  [13240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 214),
  [13242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 215),
  [13244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 215),
  [13246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 194),
  [13248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 194),
  [13250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 216),
  [13252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 216),
  [13254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8982),
  [13257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [13259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7141),
  [13261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 195),
  [13263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 195),
  [13265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 11, 0, 236),
  [13267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 11, 0, 236),
  [13269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 161),
  [13271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 161),
  [13273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 58),
  [13275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 58),
  [13277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 132),
  [13279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 132),
  [13281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [13283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7157),
  [13285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 124),
  [13287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 124),
  [13289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [13291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4269),
  [13293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 92),
  [13295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 92),
  [13297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 26),
  [13299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 26),
  [13301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 126),
  [13303] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 126),
  [13305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3243),
  [13307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5389),
  [13309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [13311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6328),
  [13313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 10),
  [13315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 10),
  [13317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [13319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7111),
  [13321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 8, 0, 219),
  [13323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 8, 0, 219),
  [13325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_floating_attribute, 4, 0, 0),
  [13327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_floating_attribute, 4, 0, 0),
  [13329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 7, 0, 199),
  [13331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 7, 0, 199),
  [13333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 4, 0, 51),
  [13335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 4, 0, 51),
  [13337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [13339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [13341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 76),
  [13343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 76),
  [13345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 7, 0, 200),
  [13347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 7, 0, 200),
  [13349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 92),
  [13351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 92),
  [13353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 5, 0, 83),
  [13355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 5, 0, 83),
  [13357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [13359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6599),
  [13361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 7, 0, 219),
  [13363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 7, 0, 219),
  [13365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 78),
  [13367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 78),
  [13369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 127),
  [13371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 127),
  [13373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_binding, 5, 0, 84),
  [13375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_binding, 5, 0, 84),
  [13377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3184),
  [13379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3660),
  [13381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 16),
  [13383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 16),
  [13385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_external_repeat1, 2, 0, 0),
  [13387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_external_repeat1, 2, 0, 0),
  [13389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_external_repeat1, 2, 0, 0), SHIFT_REPEAT(13309),
  [13392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3197),
  [13394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [13396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 217),
  [13398] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 217),
  [13400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [13402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [13404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 2, 0, 27),
  [13406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 2, 0, 27),
  [13408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 6, 0, 79),
  [13410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 6, 0, 79),
  [13412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 230),
  [13414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 230),
  [13416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 5, 0, 42),
  [13418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 5, 0, 42),
  [13420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 80),
  [13422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 80),
  [13424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 93),
  [13426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 93),
  [13428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [13430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7622),
  [13432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 8, 0, 212),
  [13434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 8, 0, 212),
  [13436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 8, 0, 228),
  [13438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 8, 0, 228),
  [13440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 169),
  [13442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 169),
  [13444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [13446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7665),
  [13448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 213),
  [13450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 213),
  [13452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 214),
  [13454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 214),
  [13456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 95),
  [13458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 95),
  [13460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 215),
  [13462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 215),
  [13464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [13466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6238),
  [13468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9541),
  [13470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9304),
  [13472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9542),
  [13474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9305),
  [13476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 229),
  [13478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 229),
  [13480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 10, 0, 231),
  [13482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 10, 0, 231),
  [13484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9545),
  [13486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9370),
  [13488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 216),
  [13490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 216),
  [13492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3201),
  [13494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4410),
  [13496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 230),
  [13498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 230),
  [13500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_binding, 4, 0, 123),
  [13502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_binding, 4, 0, 123),
  [13504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 3, 0, 47),
  [13506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 3, 0, 47),
  [13508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 9, 0, 231),
  [13510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 9, 0, 231),
  [13512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [13514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7329),
  [13516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 97),
  [13518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 97),
  [13520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8982),
  [13522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_constraint, 3, 0, 56),
  [13524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_constraint, 3, 0, 56),
  [13526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3217),
  [13528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10307),
  [13530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10350),
  [13532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 62),
  [13534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 62),
  [13536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_binding, 4, 0, 81),
  [13538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_binding, 4, 0, 81),
  [13540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11354),
  [13542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21189),
  [13544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15725),
  [13546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16112),
  [13548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16829),
  [13550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [13552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [13554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [13556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2034),
  [13558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [13560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [13562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [13564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2038),
  [13566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [13568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12577),
  [13570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12578),
  [13572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14299),
  [13574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10560),
  [13576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11403),
  [13578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20781),
  [13580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9261),
  [13582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15722),
  [13584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16610),
  [13586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17073),
  [13588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14070),
  [13590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 3, 0, 7),
  [13592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 3, 0, 7),
  [13594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9553),
  [13596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9329),
  [13598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15127),
  [13600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9599),
  [13602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9333),
  [13604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15017),
  [13606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9601),
  [13608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9335),
  [13610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 3, 0, 54),
  [13612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 3, 0, 54),
  [13614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11249),
  [13616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15147),
  [13618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 3, 0, 55),
  [13620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 3, 0, 55),
  [13622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15111),
  [13624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9622),
  [13626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9363),
  [13628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 6, 0, 82),
  [13630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 6, 0, 82),
  [13632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9554),
  [13634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9332),
  [13636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 5, 0, 52),
  [13638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 5, 0, 52),
  [13640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13644),
  [13642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13650),
  [13644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9556),
  [13646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9343),
  [13648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9586),
  [13650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9377),
  [13652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12713),
  [13654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12714),
  [13656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_module, 4, 0, 20),
  [13658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_module, 4, 0, 20),
  [13660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10396),
  [13662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 4, 0, 18),
  [13664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 4, 0, 18),
  [13666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [13668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 7, 0, 63),
  [13670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 7, 0, 63),
  [13672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_argument, 2, 0, 0),
  [13674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_argument, 2, 0, 0),
  [13676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10486),
  [13679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 6, 0, 28),
  [13681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 6, 0, 28),
  [13683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_definition, 3, 0, 0),
  [13685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_definition, 3, 0, 0),
  [13687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_definition, 4, 0, 0),
  [13689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_definition, 4, 0, 0),
  [13691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10404),
  [13693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10373),
  [13696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_typed, 2, 0, 9),
  [13698] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module_typed, 2, 0, 9),
  [13700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 5, 0, 49),
  [13702] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 5, 0, 49),
  [13704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 4, 0, 89),
  [13706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 4, 0, 89),
  [13708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15072),
  [13710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_definition, 2, 0, 0),
  [13712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_definition, 2, 0, 0),
  [13714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(15072),
  [13717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [13719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9330),
  [13721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functor_type, 2, 0, 22),
  [13723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functor_type, 2, 0, 22),
  [13725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9582),
  [13727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9337),
  [13729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 7, 0, 119),
  [13731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 7, 0, 119),
  [13733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11560),
  [13735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15154),
  [13737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11557),
  [13739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15894),
  [13741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 62),
  [13743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 62),
  [13745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10141),
  [13747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [13749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4411),
  [13751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2333),
  [13753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 5, 0, 124),
  [13755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 5, 0, 124),
  [13757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10182),
  [13759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3246),
  [13761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [13763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [13765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2324),
  [13767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2325),
  [13769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [13771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2327),
  [13773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2328),
  [13775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2329),
  [13777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [13779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2330),
  [13781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [13783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8294),
  [13785] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10385),
  [13788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3196),
  [13790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6601),
  [13792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3234),
  [13794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3301),
  [13796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 2, 0, 26),
  [13798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 2, 0, 26),
  [13800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10025),
  [13802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [13804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4969),
  [13806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [13808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7441),
  [13810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3214),
  [13812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6805),
  [13814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9399),
  [13816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9352),
  [13818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11342),
  [13820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15008),
  [13822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [13824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5549),
  [13826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12490),
  [13828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9896),
  [13830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15708),
  [13832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9401),
  [13834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9353),
  [13836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [13838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7593),
  [13840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [13842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [13844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2307),
  [13846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12475),
  [13848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12353),
  [13850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16543),
  [13852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [13854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16401),
  [13856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3055),
  [13858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [13860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5982),
  [13862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3055),
  [13865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(15049),
  [13868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [13870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5184),
  [13872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3230),
  [13874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7808),
  [13876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9600),
  [13878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9300),
  [13880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 3, 0, 57),
  [13882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 3, 0, 57),
  [13884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10189),
  [13886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [13888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3220),
  [13890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6875),
  [13892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10196),
  [13894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3242),
  [13896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5907),
  [13898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [13900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [13902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3224),
  [13904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [13906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [13908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6081),
  [13910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [13912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6906),
  [13914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [13916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5058),
  [13918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_external_repeat1, 1, 0, 0),
  [13920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_external_repeat1, 1, 0, 0),
  [13922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8960),
  [13925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [13927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7677),
  [13929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 159),
  [13931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 159),
  [13933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10201),
  [13935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 4, 0, 93),
  [13937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 4, 0, 93),
  [13939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10221),
  [13941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10358),
  [13944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [13946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7485),
  [13948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [13950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [13952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10131),
  [13954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 6, 0, 160),
  [13956] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 6, 0, 160),
  [13958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10203),
  [13960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [13962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4418),
  [13964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9438),
  [13966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9334),
  [13968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variant_declaration, 2, 0, 0),
  [13970] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variant_declaration, 2, 0, 0),
  [13972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14543),
  [13974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variant_declaration, 3, 0, 0),
  [13976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variant_declaration, 3, 0, 0),
  [13978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14543),
  [13981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [13983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [13985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(17283),
  [13988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14384),
  [13990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14384),
  [13993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 194),
  [13995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 194),
  [13997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10211),
  [13999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 6, 0, 119),
  [14001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 6, 0, 119),
  [14003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9595),
  [14005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9348),
  [14007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3200),
  [14009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7718),
  [14011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [14013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6854),
  [14015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10161),
  [14017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [14019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9997),
  [14021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3174),
  [14023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7270),
  [14025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12361),
  [14027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17112),
  [14029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10242),
  [14031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10158),
  [14033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9596),
  [14035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9302),
  [14037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9029),
  [14039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9929),
  [14041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [14043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6443),
  [14045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12416),
  [14047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11852),
  [14049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16456),
  [14051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [14053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13971),
  [14055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10516),
  [14058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [14060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4281),
  [14062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 7, 0, 195),
  [14064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 7, 0, 195),
  [14066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10213),
  [14068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3236),
  [14070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7019),
  [14072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15049),
  [14074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 3, 0, 18),
  [14076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 3, 0, 18),
  [14078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11372),
  [14080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_binding, 8, 0, 217),
  [14082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_binding, 8, 0, 217),
  [14084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10223),
  [14086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [14088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3877),
  [14090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [14092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9676),
  [14094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10255),
  [14096] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8946),
  [14099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [14101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [14103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10258),
  [14105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 4, 0, 49),
  [14107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 4, 0, 49),
  [14109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11410),
  [14111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3244),
  [14113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5318),
  [14115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [14117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [14119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10268),
  [14121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10271),
  [14123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10278),
  [14125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_type_definition, 5, 0, 82),
  [14127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_type_definition, 5, 0, 82),
  [14129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [14131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6241),
  [14133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [14135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7114),
  [14137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [14139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7159),
  [14141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3168),
  [14143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7624),
  [14145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17283),
  [14147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15710),
  [14149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [14151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4481),
  [14153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [14155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6330),
  [14157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11561),
  [14159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11563),
  [14161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 2, 0, 0),
  [14163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 2, 0, 0),
  [14165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4375),
  [14167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4375),
  [14169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7235),
  [14171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [14173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7098),
  [14175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7099),
  [14177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7100),
  [14179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7106),
  [14181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7107),
  [14183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7109),
  [14185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7112),
  [14187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4535),
  [14189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4532),
  [14191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4511),
  [14193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6446),
  [14195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6448),
  [14197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6458),
  [14199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6459),
  [14201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6460),
  [14203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6469),
  [14205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6470),
  [14207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6471),
  [14209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [14211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2296),
  [14213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [14215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [14217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [14219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2299),
  [14221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2300),
  [14223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2301),
  [14225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2302),
  [14227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [14229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [14231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [14233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7560),
  [14235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [14237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [14239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7708),
  [14241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 3, 0, 7),
  [14243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 3, 0, 7),
  [14245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7526),
  [14247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7536),
  [14249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7538),
  [14251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7540),
  [14253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7541),
  [14255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7543),
  [14257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7544),
  [14259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [14261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [14263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [14265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [14267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2090),
  [14269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [14271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [14273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2093),
  [14275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2094),
  [14277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [14279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4559),
  [14281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(9009),
  [14284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(14696),
  [14287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0),
  [14289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(9799),
  [14292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(15060),
  [14295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1418),
  [14298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16218),
  [14301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16223),
  [14304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16493),
  [14307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8371),
  [14309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10152),
  [14311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10154),
  [14313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8390),
  [14315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8398),
  [14317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8399),
  [14319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8400),
  [14321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8413),
  [14323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8414),
  [14325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8417),
  [14327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8420),
  [14329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 2, 0, 9),
  [14331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5042),
  [14333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5085),
  [14335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5072),
  [14337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5118),
  [14339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5071),
  [14341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5088),
  [14343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5095),
  [14345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5111),
  [14347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5112),
  [14349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13984),
  [14351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2279),
  [14353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9386),
  [14355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9391),
  [14357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10418),
  [14359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9396),
  [14361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9397),
  [14363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9398),
  [14365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9410),
  [14367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9411),
  [14369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9412),
  [14371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9420),
  [14373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [14375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [14377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [14379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3803),
  [14381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [14383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [14385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3824),
  [14387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [14389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [14391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4530),
  [14393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 3, 0, 0),
  [14395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 3, 0, 0),
  [14397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4407),
  [14399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [14401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7601),
  [14403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7672),
  [14405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7717),
  [14407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7539),
  [14409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7629),
  [14411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7630),
  [14413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7519),
  [14415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7522),
  [14417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7523),
  [14419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4543),
  [14421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [14423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4598),
  [14425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [14427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4415),
  [14429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4286),
  [14431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4287),
  [14433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4288),
  [14435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4289),
  [14437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [14439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4291),
  [14441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4599),
  [14443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 4, 0, 0),
  [14445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 4, 0, 0),
  [14447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7117),
  [14449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0),
  [14451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0),
  [14453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4407),
  [14456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4407),
  [14459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7119),
  [14461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7120),
  [14463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7121),
  [14465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7122),
  [14467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7123),
  [14469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7124),
  [14471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7125),
  [14473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7126),
  [14475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6604),
  [14477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4767),
  [14479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6606),
  [14481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6608),
  [14483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6609),
  [14485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6610),
  [14487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6611),
  [14489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6612),
  [14491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6613),
  [14493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6614),
  [14495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [14497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [14499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [14501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [14503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [14505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3744),
  [14507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [14509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [14511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3749),
  [14513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_definition, 5, 0, 0),
  [14515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_definition, 5, 0, 0),
  [14517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7636),
  [14519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4659),
  [14521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4660),
  [14523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4661),
  [14525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7642),
  [14527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7643),
  [14529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7644),
  [14531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7645),
  [14533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7649),
  [14535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7650),
  [14537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7651),
  [14539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7652),
  [14541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4668),
  [14543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4670),
  [14545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4412),
  [14547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [14549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4414),
  [14551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4674),
  [14553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4213),
  [14555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [14557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4298),
  [14559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [14561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4234),
  [14563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4261),
  [14565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4262),
  [14567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14369),
  [14569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7165),
  [14571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10193),
  [14573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7174),
  [14575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7175),
  [14577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7176),
  [14579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7177),
  [14581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7179),
  [14583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7180),
  [14585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7181),
  [14587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [14589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10200),
  [14591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11369),
  [14593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6001),
  [14595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [14597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6061),
  [14599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6065),
  [14601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [14603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6009),
  [14605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6006),
  [14607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5980),
  [14609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5994),
  [14611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5193),
  [14613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5199),
  [14615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5211),
  [14617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5221),
  [14619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5229),
  [14621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5246),
  [14623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5248),
  [14625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5250),
  [14627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5251),
  [14629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5465),
  [14631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5543),
  [14633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5555),
  [14635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5515),
  [14637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5519),
  [14639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5462),
  [14641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5557),
  [14643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5577),
  [14645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5491),
  [14647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_item, 2, 0, 0),
  [14649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_item, 2, 0, 0),
  [14651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6243),
  [14653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6246),
  [14655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6250),
  [14657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6398),
  [14659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6252),
  [14661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6260),
  [14663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6261),
  [14665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6262),
  [14667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6263),
  [14669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6817),
  [14671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [14673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6837),
  [14675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6838),
  [14677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6839),
  [14679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6843),
  [14681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6844),
  [14683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6845),
  [14685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6846),
  [14687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4635),
  [14689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12936),
  [14691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21266),
  [14693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20446),
  [14695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6856),
  [14697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6858),
  [14699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6861),
  [14701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6862),
  [14703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6863),
  [14705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6865),
  [14707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6866),
  [14709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6867),
  [14711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6869),
  [14713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10018),
  [14715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10029),
  [14717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10031),
  [14719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10034),
  [14721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10035),
  [14723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10041),
  [14725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10048),
  [14727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10054),
  [14729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10056),
  [14731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6881),
  [14733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6887),
  [14735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6892),
  [14737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6893),
  [14739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6894),
  [14741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6897),
  [14743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6898),
  [14745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6899),
  [14747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6900),
  [14749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6910),
  [14751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6912),
  [14753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6913),
  [14755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6914),
  [14757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6915),
  [14759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6916),
  [14761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6917),
  [14763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6918),
  [14765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6919),
  [14767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10175),
  [14769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [14771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [14773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [14775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [14777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [14779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4092),
  [14781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4093),
  [14783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [14785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [14787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6331),
  [14789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6333),
  [14791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6334),
  [14793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6335),
  [14795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6336),
  [14797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6337),
  [14799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6338),
  [14801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6339),
  [14803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6340),
  [14805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [14807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3885),
  [14809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3895),
  [14811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [14813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [14815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [14817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [14819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3924),
  [14821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [14823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0),
  [14825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0),
  [14827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7844),
  [14829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7850),
  [14831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7882),
  [14833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7887),
  [14835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7902),
  [14837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7963),
  [14839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7968),
  [14841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7969),
  [14843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7999),
  [14845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4954),
  [14847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10042),
  [14849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5004),
  [14851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4908),
  [14853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4909),
  [14855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4910),
  [14857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4915),
  [14859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4964),
  [14861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5032),
  [14863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4974),
  [14865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [14867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9276),
  [14869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [14871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3304),
  [14873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [14875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [14877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3307),
  [14879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3308),
  [14881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [14883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3310),
  [14885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3311),
  [14887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7022),
  [14889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6399),
  [14891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6531),
  [14893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6630),
  [14895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6876),
  [14897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6413),
  [14899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6417),
  [14901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6423),
  [14903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6439),
  [14905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6085),
  [14907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6087),
  [14909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6088),
  [14911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6089),
  [14913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6090),
  [14915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6091),
  [14917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6092),
  [14919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6093),
  [14921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6094),
  [14923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [14925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [14927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [14929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3388),
  [14931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3389),
  [14933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3395),
  [14935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3396),
  [14937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [14939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [14941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5951),
  [14943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5940),
  [14945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5824),
  [14947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5827),
  [14949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5839),
  [14951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5943),
  [14953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5947),
  [14955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5950),
  [14957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5751),
  [14959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5344),
  [14961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5349),
  [14963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5408),
  [14965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5362),
  [14967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5365),
  [14969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [14971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5368),
  [14973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5369),
  [14975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5372),
  [14977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5378),
  [14979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [14981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3649),
  [14983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [14985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [14987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3652),
  [14989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [14991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [14993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [14995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [14997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [14999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [15001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [15003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [15005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [15007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3696),
  [15009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3698),
  [15011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [15013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9473),
  [15015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9341),
  [15017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9475),
  [15019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9345),
  [15021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9488),
  [15023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9369),
  [15025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5381),
  [15027] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8885),
  [15030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [15032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [15034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5315),
  [15036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5317),
  [15038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5319),
  [15040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5348),
  [15042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5355),
  [15044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5363),
  [15046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5377),
  [15048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 3, 0, 23),
  [15050] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4375),
  [15053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4375),
  [15056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11467),
  [15058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [15060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9489),
  [15062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9306),
  [15064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9490),
  [15066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9324),
  [15068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9495),
  [15070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9354),
  [15072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3073),
  [15074] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3073),
  [15077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7640),
  [15079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10433),
  [15082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7664),
  [15084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7690),
  [15086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7691),
  [15088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7692),
  [15090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7710),
  [15092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7711),
  [15094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7714),
  [15096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0),
  [15098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0),
  [15100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7521),
  [15102] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10492),
  [15105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10212),
  [15107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module, 4, 0, 20),
  [15109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_module, 4, 0, 20),
  [15111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4741),
  [15113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9612),
  [15115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9364),
  [15117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9613),
  [15119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9358),
  [15121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9618),
  [15123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9351),
  [15125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7304),
  [15127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7352),
  [15129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7364),
  [15131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7365),
  [15133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7366),
  [15135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7383),
  [15137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7387),
  [15139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7389),
  [15141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7406),
  [15143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9974),
  [15145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14369),
  [15148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7455),
  [15150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7473),
  [15152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14531),
  [15154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14531),
  [15157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7498),
  [15159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7499),
  [15161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7500),
  [15163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7505),
  [15165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7506),
  [15167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7508),
  [15169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7509),
  [15171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9984),
  [15173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [15175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [15177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10085),
  [15179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_item, 1, 0, 0),
  [15181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_item, 1, 0, 0),
  [15183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14559),
  [15185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14559),
  [15188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7168),
  [15190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7224),
  [15192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7265),
  [15194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7266),
  [15196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7267),
  [15198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7307),
  [15200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [15202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7309),
  [15204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7313),
  [15206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11551),
  [15208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15138),
  [15210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3654),
  [15212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 4, 0, 23),
  [15214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4259),
  [15216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [15218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18905),
  [15220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9169),
  [15222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17437),
  [15224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21332),
  [15226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [15228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2378),
  [15230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [15232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2380),
  [15234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [15236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [15238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [15240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2384),
  [15242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [15244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [15246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21247),
  [15248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12635),
  [15250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17268),
  [15252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19539),
  [15254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [15256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2348),
  [15258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10316),
  [15261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10033),
  [15263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4320),
  [15265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [15267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 3, 0, 28),
  [15269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10086),
  [15271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10124),
  [15273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [15275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [15277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [15279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2076),
  [15281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [15283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [15285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2079),
  [15287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2080),
  [15289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [15291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10308),
  [15293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10178),
  [15295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10230),
  [15297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10240),
  [15299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10256),
  [15301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8986),
  [15303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8947),
  [15305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15056),
  [15307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10253),
  [15309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13379),
  [15311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15383),
  [15313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10257),
  [15315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10265),
  [15317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3057),
  [15319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 5, 0, 63),
  [15321] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3057),
  [15324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20125),
  [15326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5683),
  [15328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17471),
  [15330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21039),
  [15332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20690),
  [15334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5464),
  [15336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17339),
  [15338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19562),
  [15340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12803),
  [15342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15681),
  [15344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_definition, 4, 0, 0),
  [15346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_definition, 4, 0, 0),
  [15348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15737),
  [15350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14518),
  [15352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15737),
  [15355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_definition, 5, 0, 0),
  [15357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_definition, 5, 0, 0),
  [15359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10446),
  [15362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14518),
  [15365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19770),
  [15367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14571),
  [15369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17398),
  [15371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20551),
  [15373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14538),
  [15375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4259),
  [15378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4259),
  [15381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14538),
  [15384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_module_type, 3, 0, 9),
  [15386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [15388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 4, 0, 63),
  [15390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_specification, 4, 0, 28),
  [15392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8970),
  [15395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10556),
  [15398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [15400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20829),
  [15402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [15404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17503),
  [15406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18962),
  [15408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19973),
  [15410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5570),
  [15412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18309),
  [15414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20684),
  [15416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15890),
  [15418] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4320),
  [15421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4320),
  [15424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_type_definition, 3, 0, 0),
  [15426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_type_definition, 3, 0, 0),
  [15428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11541),
  [15430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11543),
  [15432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2309),
  [15434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [15436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [15438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2312),
  [15440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [15442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2314),
  [15444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2315),
  [15446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2316),
  [15448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [15450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 3, 0, 0),
  [15452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 3, 0, 0),
  [15454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17163),
  [15456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [15458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_toplevel_directive, 2, 0, 0),
  [15460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_toplevel_directive, 2, 0, 0),
  [15462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15063),
  [15464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13519),
  [15466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15325),
  [15468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [15470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [15472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [15474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2048),
  [15476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [15478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [15480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2051),
  [15482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2052),
  [15484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [15486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [15488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [15490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [15492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1912),
  [15494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [15496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [15498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1915),
  [15500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1916),
  [15502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1917),
  [15504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [15506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11466),
  [15508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14012),
  [15510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11537),
  [15512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15662),
  [15515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15662),
  [15517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [15519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [15521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [15523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [15525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [15527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2126),
  [15529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2127),
  [15531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [15533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2129),
  [15535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2130),
  [15537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2131),
  [15539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2141),
  [15541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [15543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [15545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [15547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [15549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [15551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [15553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2147),
  [15555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2148),
  [15557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2149),
  [15559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [15561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [15563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [15565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [15567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2160),
  [15569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [15571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2162),
  [15573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [15575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [15577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [15579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 2, 0, 0),
  [15581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 2, 0, 0),
  [15583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15880),
  [15585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9422),
  [15587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9336),
  [15589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2336),
  [15591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [15593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [15595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [15597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [15599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2340),
  [15601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [15603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2342),
  [15605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2343),
  [15607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [15609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10072),
  [15611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 3, 0, 0),
  [15613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 3, 0, 0),
  [15615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13589),
  [15617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, 0, 0),
  [15619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 4, 0, 0),
  [15621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(13589),
  [15624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 0),
  [15626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 5, 0, 0),
  [15628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3103),
  [15630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [15632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3103),
  [15635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2991),
  [15637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(2991),
  [15640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 3, 0, 0),
  [15642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 3, 0, 0),
  [15644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15435),
  [15646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [15648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [15650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [15652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [15654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [15656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9017),
  [15658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9784),
  [15660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15323),
  [15662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13593),
  [15664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(13593),
  [15667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3087),
  [15669] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3087),
  [15672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [15674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15880),
  [15677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 4, 0, 0),
  [15679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 0),
  [15681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [15683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [15685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9735),
  [15687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10235),
  [15689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15142),
  [15691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9506),
  [15693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9350),
  [15695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15162),
  [15697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9507),
  [15699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9359),
  [15701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15046),
  [15703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9509),
  [15705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9325),
  [15707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [15709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9497),
  [15711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9315),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9559),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9360),
  [15717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16741),
  [15719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3053),
  [15721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3053),
  [15724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3070),
  [15726] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3070),
  [15729] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15435),
  [15732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [15734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11343),
  [15736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9199),
  [15738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3034),
  [15740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3034),
  [15743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3037),
  [15745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3037),
  [15748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10508),
  [15750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10165),
  [15752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [15754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9747),
  [15756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14296),
  [15758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13583),
  [15760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15650),
  [15762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15124),
  [15764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15067),
  [15766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 2, 0, 0),
  [15768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 2, 0, 0),
  [15770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16689),
  [15772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 4, 0, 0),
  [15774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 4, 0, 0),
  [15776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(16689),
  [15779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 5, 0, 0),
  [15781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 5, 0, 0),
  [15783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9802),
  [15785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13604),
  [15787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10482),
  [15790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10456),
  [15792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13605),
  [15794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14550),
  [15796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variant_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(14550),
  [15799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10001),
  [15801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13598),
  [15803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8947),
  [15806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(15056),
  [15809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0),
  [15811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(13379),
  [15814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(15383),
  [15817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16218),
  [15820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16223),
  [15823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16493),
  [15826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_definition, 2, 0, 0),
  [15828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_definition, 2, 0, 0),
  [15830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(17163),
  [15833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [15835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [15837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1822),
  [15839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [15841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [15843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1825),
  [15845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [15847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [15849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [15851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [15853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [15855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1950),
  [15857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1951),
  [15859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1944),
  [15861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [15863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [15865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [15867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [15869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2417),
  [15871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [15873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2418),
  [15875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [15877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2420),
  [15879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [15881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [15883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2423),
  [15885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2424),
  [15887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [15889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [15891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [15893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [15895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [15897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1849),
  [15899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [15901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [15903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1852),
  [15905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1853),
  [15907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [15909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [15911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [15913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2284),
  [15915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [15917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [15919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2286),
  [15921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [15923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [15925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2289),
  [15927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2290),
  [15929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [15931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7372),
  [15933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13657),
  [15935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13657),
  [15937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13642),
  [15939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13617),
  [15941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [15943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [15945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [15947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [15949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [15951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [15953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [15955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [15957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [15959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [15961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [15963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [15965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14586),
  [15967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [15969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6288),
  [15971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5244),
  [15973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6959),
  [15975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [15977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16459),
  [15979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [15981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [15983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7064),
  [15985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [15987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8136),
  [15989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5479),
  [15991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [15993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7066),
  [15995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3111),
  [15997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3111),
  [16000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5467),
  [16002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6363),
  [16004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [16006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [16008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6365),
  [16010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [16012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [16014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [16016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [16018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [16020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [16022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [16024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [16026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1903),
  [16028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [16030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6095),
  [16032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [16034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [16036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7988),
  [16038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5473),
  [16040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [16042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [16044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5475),
  [16046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [16048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [16050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3324),
  [16052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3049),
  [16054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5426),
  [16056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [16058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [16060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [16062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [16064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [16066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1862),
  [16068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [16070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [16072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1865),
  [16074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1866),
  [16076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [16078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [16080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [16082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1826),
  [16084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [16086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6733),
  [16088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5793),
  [16090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [16092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9077),
  [16094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [16096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5800),
  [16098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [16100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [16102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6556),
  [16104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [16106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3031),
  [16108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7621),
  [16110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [16112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2267),
  [16114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [16116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2268),
  [16118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2269),
  [16120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2270),
  [16122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2271),
  [16124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2272),
  [16126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2273),
  [16128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [16130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [16132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7705),
  [16134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [16136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [16138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7625),
  [16140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [16142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6558),
  [16144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6885),
  [16146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3084),
  [16148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3084),
  [16151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5441),
  [16153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [16155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [16157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5370),
  [16159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [16161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [16163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5626),
  [16165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8961),
  [16167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9838),
  [16169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7297),
  [16171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10291),
  [16173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [16175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [16177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [16179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [16181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [16183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7577),
  [16185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3588),
  [16187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [16189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [16191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [16193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [16195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [16197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1834),
  [16199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [16201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [16203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [16205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [16207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1839),
  [16209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [16211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [16213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6183),
  [16215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [16217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7004),
  [16219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3003),
  [16221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3003),
  [16224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [16226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [16228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [16230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [16232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [16234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6185),
  [16236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10481),
  [16238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5047),
  [16240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [16242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [16244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5077),
  [16246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6402),
  [16248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7764),
  [16250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4341),
  [16252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [16254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3851),
  [16256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [16258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4343),
  [16260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6116),
  [16262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3868),
  [16264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7162),
  [16266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7933),
  [16268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4927),
  [16270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3480),
  [16272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3049),
  [16275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6441),
  [16277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6135),
  [16279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3255),
  [16281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5905),
  [16283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5291),
  [16285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3564),
  [16287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3653),
  [16289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4478),
  [16291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [16293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6939),
  [16295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [16297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [16299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [16301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(16459),
  [16304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9055),
  [16306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [16308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9045),
  [16310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 0),
  [16312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [16314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4028),
  [16316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [16318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [16320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [16322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [16324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8428),
  [16326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5039),
  [16328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__structure_repeat1, 2, 0, 0), SHIFT_REPEAT(13551),
  [16331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9659),
  [16333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [16335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [16337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9662),
  [16339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [16341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6649),
  [16343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [16345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15616),
  [16347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9815),
  [16349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3094),
  [16351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [16353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6651),
  [16355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8937),
  [16357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [16359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 3, 0, 0),
  [16361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [16363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4422),
  [16365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12670),
  [16367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7283),
  [16369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [16371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3094),
  [16374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [16376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7287),
  [16378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3715),
  [16380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7376),
  [16382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [16384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11861),
  [16386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(13617),
  [16389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6742),
  [16391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [16393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7379),
  [16395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6697),
  [16397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [16399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [16401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6700),
  [16403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [16405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7042),
  [16407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [16409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4416),
  [16411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [16413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4132),
  [16415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 2, 0, 0),
  [16417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [16419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [16421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8900),
  [16423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [16425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 2, 0, 0),
  [16427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3607),
  [16429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__structure_repeat2, 1, 0, 0),
  [16431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__structure_repeat2, 1, 0, 0),
  [16433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5357),
  [16435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5688),
  [16437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6029),
  [16439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [16441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10099),
  [16443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [16445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4454),
  [16447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [16449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10110),
  [16451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [16453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [16455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [16457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6036),
  [16459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [16461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7442),
  [16463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [16465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [16467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3893),
  [16469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [16471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4279),
  [16473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13024),
  [16475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [16477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [16479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7937),
  [16481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [16483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5568),
  [16485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [16487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7941),
  [16489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8328),
  [16491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [16493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4190),
  [16495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [16497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8232),
  [16499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [16501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [16503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10404),
  [16506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [16508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8331),
  [16510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15616),
  [16513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [16515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6748),
  [16517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structure_item, 1, 0, 0),
  [16519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structure_item, 1, 0, 0),
  [16521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [16523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8006),
  [16525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [16527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [16529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7185),
  [16531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11606),
  [16533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [16535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4195),
  [16537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5262),
  [16539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [16541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [16543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5264),
  [16545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10768),
  [16547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7230),
  [16549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [16551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [16553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7049),
  [16555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [16557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6488),
  [16559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9168),
  [16561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6803),
  [16563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [16565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4451),
  [16567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [16569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6806),
  [16571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [16573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4639),
  [16575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [16577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__match_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(3031),
  [16580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7360),
  [16582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9670),
  [16584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4929),
  [16586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [16588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [16590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4953),
  [16592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7477),
  [16594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [16596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5958),
  [16598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [16600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7489),
  [16602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(17147),
  [16605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [16607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [16609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2170),
  [16611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [16613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [16615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [16617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [16619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [16621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2216),
  [16623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [16625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [16627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2219),
  [16629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2220),
  [16631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [16633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [16635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2114),
  [16637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [16639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [16641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [16643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2118),
  [16645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [16647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [16649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2122),
  [16651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2134),
  [16653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [16655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [16657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [16659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [16661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2200),
  [16663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2201),
  [16665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [16667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [16669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2204),
  [16671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2205),
  [16673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [16675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7314),
  [16677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [16679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4099),
  [16681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7217),
  [16683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [16685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2174),
  [16687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [16689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [16691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [16693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10530),
  [16695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8968),
  [16697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14223),
  [16699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [16701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4077),
  [16703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7148),
  [16705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13590),
  [16707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13662),
  [16709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8990),
  [16711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9860),
  [16713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15501),
  [16715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [16717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6921),
  [16719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [16721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3933),
  [16723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6631),
  [16725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6053),
  [16727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [16729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3916),
  [16731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5964),
  [16733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6681),
  [16735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [16737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3984),
  [16739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6436),
  [16741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7807),
  [16743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [16745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3971),
  [16747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7989),
  [16749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [16751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7223),
  [16753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_expression_repeat1, 2, 0, 0),
  [16755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [16757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [16759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6098),
  [16761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [16763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3990),
  [16765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6133),
  [16767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4501),
  [16769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [16771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3952),
  [16773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4489),
  [16775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6637),
  [16777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [16779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3900),
  [16781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6933),
  [16783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3439),
  [16785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [16787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3996),
  [16789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [16791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 70),
  [16793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15515),
  [16795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5236),
  [16797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [16799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3922),
  [16801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5213),
  [16803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6935),
  [16805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [16807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3938),
  [16809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6788),
  [16811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__instance_variable_name, 1, 0, 11),
  [16813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [16815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7281),
  [16817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [16819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3967),
  [16821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7142),
  [16823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5924),
  [16825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [16827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3998),
  [16829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5929),
  [16831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17147),
  [16833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6237),
  [16835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [16837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3957),
  [16839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6114),
  [16841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7115),
  [16843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [16845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4118),
  [16847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7420),
  [16849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15502),
  [16851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0),
  [16853] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(13657),
  [16856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(13657),
  [16859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(13642),
  [16862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13591),
  [16864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5521),
  [16866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [16868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3927),
  [16870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5497),
  [16872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [16874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [16876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3876),
  [16878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [16880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4955),
  [16882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [16884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3977),
  [16886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4945),
  [16888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10012),
  [16890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [16892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3942),
  [16894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10281),
  [16896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(15515),
  [16899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [16901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [16903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [16905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4005),
  [16907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5299),
  [16909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_expression, 3, 0, 69),
  [16911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [16913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [16915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3903),
  [16917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [16919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [16921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [16923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4031),
  [16925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5293),
  [16927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [16929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [16931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4008),
  [16933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [16935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13595),
  [16937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [16939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [16941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3960),
  [16943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [16945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7155),
  [16947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [16949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3894),
  [16951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7356),
  [16953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6946),
  [16955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [16957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3945),
  [16959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6938),
  [16961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [16963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [16965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4011),
  [16967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [16969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7273),
  [16971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [16973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3833),
  [16975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7027),
  [16977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9911),
  [16979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8355),
  [16981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [16983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3879),
  [16985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8215),
  [16987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5092),
  [16989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [16991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3861),
  [16993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5055),
  [16995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4217),
  [16997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [16999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3905),
  [17001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [17003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13117),
  [17005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8831),
  [17007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 4, 0, 140),
  [17009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13611),
  [17011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6950),
  [17013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [17015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3947),
  [17017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6400),
  [17019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6173),
  [17021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [17023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3930),
  [17025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6083),
  [17027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__signature_item, 1, 0, 0),
  [17029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [17031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__signature_repeat1, 1, 0, 0),
  [17033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6540),
  [17035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [17037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3872),
  [17039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6656),
  [17041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4683),
  [17043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [17045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3956),
  [17047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4640),
  [17049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7488),
  [17051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [17053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3847),
  [17055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7047),
  [17057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4409),
  [17059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [17061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3890),
  [17063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [17065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9594),
  [17067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [17069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3909),
  [17071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8506),
  [17073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13612),
  [17075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [17077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [17079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3951),
  [17081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3843),
  [17083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(13611),
  [17086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7528),
  [17088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [17090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3850),
  [17092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7563),
  [17094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [17096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [17098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3981),
  [17100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [17102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_content, 1, 0, 0),
  [17104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17057),
  [17106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [17108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 201),
  [17110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [17112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 202),
  [17114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10343),
  [17116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [17118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 175),
  [17120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [17122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 142),
  [17124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8957),
  [17126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [17128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 176),
  [17130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [17132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 177),
  [17134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [17136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 221),
  [17138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9051),
  [17140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [17142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 63),
  [17144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8943),
  [17146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [17148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 3, 0, 28),
  [17150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [17152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 181),
  [17154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__typed, 2, 0, 40),
  [17156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__typed, 2, 0, 40),
  [17158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 2, 0, 65),
  [17160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15606),
  [17162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13708),
  [17164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11006),
  [17166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17145),
  [17168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [17170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 144),
  [17172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 1, 0, 0),
  [17174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_escape_sequence, 1, 0, 0),
  [17176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13899),
  [17178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11392),
  [17180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13786),
  [17182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11744),
  [17184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13793),
  [17186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11782),
  [17188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [17190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 147),
  [17192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13798),
  [17194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11039),
  [17196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13802),
  [17198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11053),
  [17200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13693),
  [17202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11527),
  [17204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 1, 0, 0),
  [17206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 1, 0, 0),
  [17208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [17210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 180),
  [17212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13826),
  [17214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10993),
  [17216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13955),
  [17218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9833),
  [17220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15217),
  [17222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [17224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 208),
  [17226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15218),
  [17228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12429),
  [17230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9028),
  [17232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9758),
  [17234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 4, 0, 114),
  [17236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 3, 0, 107),
  [17238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15202),
  [17240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [17242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 3, 0, 109),
  [17244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11487),
  [17246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [17248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11537),
  [17250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_pattern, 3, 0, 96),
  [17252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_pattern, 3, 0, 96),
  [17254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 108),
  [17256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3979),
  [17258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [17260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 226),
  [17262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6719),
  [17264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5841),
  [17266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9672),
  [17268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(17916),
  [17271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11014),
  [17273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 235),
  [17275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 10, 0, 238),
  [17277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7296),
  [17279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5877),
  [17281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10382),
  [17283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12773),
  [17285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16783),
  [17287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11400),
  [17289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 224),
  [17291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6565),
  [17293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 146),
  [17295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 182),
  [17297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 183),
  [17299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 28),
  [17301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 4, 0, 107),
  [17303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7875),
  [17305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 4, 0, 143),
  [17307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [17309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 203),
  [17311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5449),
  [17313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 147),
  [17315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7659),
  [17317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8342),
  [17319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6574),
  [17321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 207),
  [17323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6496),
  [17325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4709),
  [17327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 225),
  [17329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13988),
  [17331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 5, 0, 114),
  [17333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 66),
  [17335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 208),
  [17337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 176),
  [17339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 204),
  [17341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4207),
  [17343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10135),
  [17345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6295),
  [17347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [17349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 225),
  [17351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 177),
  [17353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 149),
  [17355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 223),
  [17357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 6, 0, 178),
  [17359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 179),
  [17361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7451),
  [17363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 205),
  [17365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 206),
  [17367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 209),
  [17369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 205),
  [17371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3760),
  [17373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5014),
  [17375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 148),
  [17377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [17379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10185),
  [17381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6668),
  [17383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_initializer, 3, 0, 67),
  [17385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9250),
  [17387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 4, 0, 87),
  [17389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3330),
  [17391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7205),
  [17393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [17395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12636),
  [17397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 144),
  [17399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 180),
  [17401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17916),
  [17403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7344),
  [17405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8808),
  [17407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9928),
  [17409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11763),
  [17411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 201),
  [17413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [17415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 63),
  [17417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [17419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11572),
  [17421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7399),
  [17423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [17425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 226),
  [17427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7588),
  [17429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11045),
  [17431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [17433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 207),
  [17435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11061),
  [17437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6201),
  [17439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 185),
  [17441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 0),
  [17443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 9, 0, 234),
  [17445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5326),
  [17447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9792),
  [17449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 202),
  [17451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6968),
  [17453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [17455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [17457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [17459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 203),
  [17461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 109),
  [17463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 142),
  [17465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6977),
  [17467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [17469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10998),
  [17471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 87),
  [17473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 206),
  [17475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__or_pattern_anonymous, 3, 0, 0),
  [17477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__or_pattern_anonymous, 3, 0, 0),
  [17479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [17481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4538),
  [17483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6757),
  [17485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3340),
  [17487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7072),
  [17489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 181),
  [17491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 9, 0, 238),
  [17493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 5, 0, 149),
  [17495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5484),
  [17497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 145),
  [17499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 182),
  [17501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6771),
  [17503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7254),
  [17505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 220),
  [17507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 183),
  [17509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_pattern, 3, 0, 96),
  [17511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_pattern, 3, 0, 96),
  [17513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__effect_pattern, 1, 0, 0),
  [17515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__effect_pattern, 1, 0, 0),
  [17517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 5, 0, 178),
  [17519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern, 1, 0, 0),
  [17521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern, 1, 0, 0),
  [17523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 220),
  [17525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 209),
  [17527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7547),
  [17529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 146),
  [17531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern, 1, 0, 29),
  [17533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern, 1, 0, 29),
  [17535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5099),
  [17537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6371),
  [17539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [17541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7163),
  [17543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern, 1, 0, 30),
  [17545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern, 1, 0, 30),
  [17547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 175),
  [17549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7192),
  [17551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 148),
  [17553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 233),
  [17555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 234),
  [17557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9684),
  [17559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 5, 0, 143),
  [17561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6709),
  [17563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4584),
  [17565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8362),
  [17567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_pattern, 2, 0, 59),
  [17569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lazy_pattern, 2, 0, 59),
  [17571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 221),
  [17573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4225),
  [17575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 222),
  [17577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6305),
  [17579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6380),
  [17581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 7, 0, 204),
  [17583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 222),
  [17585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7081),
  [17587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_pattern, 2, 0, 59),
  [17589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_pattern, 2, 0, 59),
  [17591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7390),
  [17593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_pattern, 2, 0, 59),
  [17595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag_pattern, 2, 0, 59),
  [17597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6813),
  [17599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4515),
  [17601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5066),
  [17603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 8, 0, 223),
  [17605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_pattern, 4, 0, 128),
  [17607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_pattern, 4, 0, 128),
  [17609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_effect_pattern, 4, 0, 135),
  [17611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_effect_pattern, 4, 0, 135),
  [17613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4352),
  [17615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11427),
  [17617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 224),
  [17619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 9, 0, 233),
  [17621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7778),
  [17623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4995),
  [17625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6192),
  [17627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 9, 0, 235),
  [17629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5503),
  [17631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6824),
  [17633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_initializer, 2, 0, 67),
  [17635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6055),
  [17637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_pattern, 5, 0, 134),
  [17639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_pattern, 5, 0, 134),
  [17641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_pattern, 3, 0, 99),
  [17643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_pattern, 3, 0, 99),
  [17645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6659),
  [17647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5967),
  [17649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_pattern, 3, 0, 0),
  [17651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__tuple_pattern, 3, 0, 0),
  [17653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [17655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4366),
  [17657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5280),
  [17659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_definition, 3, 0, 65),
  [17661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 179),
  [17663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_definition, 6, 0, 185),
  [17665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7634),
  [17667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(17290),
  [17670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 4, 0, 28),
  [17672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_specification, 2, 0, 61),
  [17674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 3, 0, 28),
  [17676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 5, 0, 63),
  [17678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_specification, 3, 0, 61),
  [17680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 3, 0, 109),
  [17682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17290),
  [17684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_specification, 4, 0, 63),
  [17686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 4, 0, 144),
  [17688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 4, 0, 109),
  [17690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_tuple_element_pattern, 2, 0, 34),
  [17692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6060),
  [17694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_tuple_element_pattern, 2, 0, 34),
  [17696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_specification, 5, 0, 144),
  [17698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20406),
  [17700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [17702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [17704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8989),
  [17707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [17709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14178),
  [17711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10354),
  [17713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13618),
  [17715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15746),
  [17717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14180),
  [17719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14168),
  [17721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11072),
  [17723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8989),
  [17725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14104),
  [17727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10338),
  [17729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14094),
  [17731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14172),
  [17733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14167),
  [17735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10727),
  [17737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14139),
  [17739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cons_pattern, 3, 0, 75),
  [17741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cons_pattern, 3, 0, 75),
  [17743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_pattern, 3, 0, 96),
  [17745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_pattern, 3, 0, 96),
  [17747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15864),
  [17749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception_pattern, 2, 0, 59),
  [17751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exception_pattern, 2, 0, 59),
  [17753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6440),
  [17755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [17757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [17759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [17761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16756),
  [17763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [17765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [17767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [17769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [17771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14143),
  [17773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [17775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [17777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [17779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5998),
  [17781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [17783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [17785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [17787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [17789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [17791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [17793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [17795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10021),
  [17797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [17799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [17801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [17803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2967),
  [17805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15188),
  [17807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9366),
  [17809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19045),
  [17811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19045),
  [17813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20038),
  [17815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4120),
  [17817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [17819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1100),
  [17821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [17823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [17825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [17827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [17829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [17831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [17833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [17835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [17837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [17839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4079),
  [17841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15194),
  [17843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5160),
  [17845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [17847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [17849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [17851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15750),
  [17853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5714),
  [17855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [17857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [17859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [17861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2972),
  [17863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15023),
  [17865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14004),
  [17867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4021),
  [17869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14546),
  [17871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [17873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15129),
  [17875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8771),
  [17877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5138),
  [17879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [17881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [17883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [17885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [17887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [17889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [17891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [17893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9400),
  [17895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [17897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [17899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [17901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_field, 1, 0, 0),
  [17903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4032),
  [17905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15177),
  [17907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [17909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [17911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [17913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [17915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_expression_repeat1, 1, 0, 0),
  [17917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4400),
  [17919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [17921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [17923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [17925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [17927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [17929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [17931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [17933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6284),
  [17935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [17937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [17939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [17941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5920),
  [17943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [17945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1116),
  [17947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [17949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8277),
  [17951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [17953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1060),
  [17955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [17957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17422),
  [17959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6756),
  [17961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [17963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [17965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [17967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [17969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15075),
  [17971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7585),
  [17973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4101),
  [17975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15114),
  [17977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9008),
  [17979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [17981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [17983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [17985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [17987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2983),
  [17989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8659),
  [17991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7595),
  [17993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [17995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [17997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [17999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5119),
  [18001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [18003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [18005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [18007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2985),
  [18009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9121),
  [18011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [18013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6326),
  [18015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [18017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [18019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [18021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [18023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [18025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [18027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [18029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14549),
  [18031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14549),
  [18033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20377),
  [18035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [18037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15180),
  [18039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5360),
  [18041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2971),
  [18043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15131),
  [18045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9039),
  [18047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4080),
  [18049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [18051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [18053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [18055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3814),
  [18057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [18059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [18061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [18063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5334),
  [18065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [18067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [18069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [18071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6945),
  [18073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [18075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [18077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [18079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2987),
  [18081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15096),
  [18083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7633),
  [18085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4119),
  [18087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15199),
  [18089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5495),
  [18091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18270),
  [18093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20074),
  [18095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12221),
  [18097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3848),
  [18099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7952),
  [18101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7443),
  [18103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [18105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [18107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [18109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6228),
  [18111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [18113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [18115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [18117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6534),
  [18119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [18121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [18123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [18125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2977),
  [18127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18164),
  [18129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20351),
  [18131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12277),
  [18133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6592),
  [18135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [18137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [18139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [18141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2970),
  [18143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15002),
  [18145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7928),
  [18147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6438),
  [18149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [18151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [18153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [18155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17932),
  [18157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19621),
  [18159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15163),
  [18161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14999),
  [18163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7935),
  [18165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [18167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [18169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [18171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18172),
  [18173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20443),
  [18175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12767),
  [18177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6240),
  [18179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [18181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [18183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [18185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18199),
  [18187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20476),
  [18189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12776),
  [18191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18283),
  [18193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18615),
  [18195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [18197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [18199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [18201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [18203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2964),
  [18205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15057),
  [18207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8166),
  [18209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3835),
  [18211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15062),
  [18213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5562),
  [18215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6168),
  [18217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [18219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1084),
  [18221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [18223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [18225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15019),
  [18227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5307),
  [18229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17300),
  [18231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20400),
  [18233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12809),
  [18235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3139),
  [18237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [18239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [18241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [18243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6266),
  [18245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [18247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [18249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [18251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10419),
  [18253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6395),
  [18255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [18257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [18259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [18261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(16783),
  [18264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9700),
  [18266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10163),
  [18268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13658),
  [18270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8675),
  [18272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9322),
  [18274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9710),
  [18276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9407),
  [18278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(15137),
  [18281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6070),
  [18283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [18285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8351),
  [18287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8944),
  [18289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15137),
  [18291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9381),
  [18293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9450),
  [18295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12454),
  [18297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8705),
  [18299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9634),
  [18301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13123),
  [18303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11284),
  [18305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [18307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [18309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7897),
  [18311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10653),
  [18313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [18315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9635),
  [18317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10566),
  [18319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9679),
  [18321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13394),
  [18323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9603),
  [18325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12424),
  [18327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9641),
  [18329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11509),
  [18331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9654),
  [18333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13937),
  [18335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9620),
  [18337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9895),
  [18339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10901),
  [18341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8769),
  [18343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10370),
  [18345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8681),
  [18347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9875),
  [18349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8791),
  [18351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9546),
  [18353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11265),
  [18355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_type_repeat1, 1, 0, 0),
  [18357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [18359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9144),
  [18361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9630),
  [18363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10684),
  [18365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9505),
  [18367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9978),
  [18369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_string_content, 1, 0, 0),
  [18371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11447),
  [18373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8777),
  [18375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9513),
  [18377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11092),
  [18379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_field_specification, 1, 0, 0),
  [18381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9387),
  [18383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13632),
  [18385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10624),
  [18387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [18389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10606),
  [18391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_quoted_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(14549),
  [18394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_quoted_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(14549),
  [18397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quoted_string_content_repeat1, 2, 0, 0),
  [18399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9558),
  [18401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10328),
  [18403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13943),
  [18405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8759),
  [18407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6034),
  [18409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(8980),
  [18412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10138),
  [18414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8676),
  [18416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11304),
  [18418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10760),
  [18420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8745),
  [18422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10671),
  [18424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8717),
  [18426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10840),
  [18428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9534),
  [18430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9742),
  [18432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9661),
  [18434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11478),
  [18436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9573),
  [18438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11684),
  [18440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11295),
  [18442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8752),
  [18444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11359),
  [18446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8747),
  [18448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9643),
  [18450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8686),
  [18452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9448),
  [18454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9791),
  [18456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10289),
  [18458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8712),
  [18460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8980),
  [18462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9498),
  [18464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11399),
  [18466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [18468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7752),
  [18470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11523),
  [18472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13651),
  [18474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8690),
  [18476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [18478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8086),
  [18480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9588),
  [18482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14375),
  [18484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14971),
  [18486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9889),
  [18488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8734),
  [18490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13516),
  [18492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8672),
  [18494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9628),
  [18496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8679),
  [18498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11644),
  [18500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8671),
  [18502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9762),
  [18504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8709),
  [18506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6027),
  [18508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15067),
  [18510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11839),
  [18512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8173),
  [18514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11842),
  [18516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [18518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [18520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14652),
  [18522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4508),
  [18524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4509),
  [18526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15348),
  [18528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4510),
  [18530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument_type, 3, 0, 103),
  [18532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_labeled_tuple_element_type, 3, 0, 103), SHIFT(9838),
  [18535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [18537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4609),
  [18539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14655),
  [18541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [18543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15523),
  [18545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4610),
  [18547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4686),
  [18549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4687),
  [18551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [18553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15630),
  [18555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4688),
  [18557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14682),
  [18559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [18561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [18563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11853),
  [18565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11856),
  [18567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [18569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [18571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11864),
  [18573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11868),
  [18575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14143),
  [18577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18334),
  [18579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10654),
  [18581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11807),
  [18583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11876),
  [18585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18341),
  [18587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14175),
  [18589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11879),
  [18591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12325),
  [18593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [18595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11888),
  [18597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11891),
  [18599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [18601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12330),
  [18603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11900),
  [18605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11903),
  [18607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [18609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [18611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7753),
  [18613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [18615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [18617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8243),
  [18619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [18621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3119),
  [18623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3018),
  [18625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15281),
  [18627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [18629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7756),
  [18631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9230),
  [18633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9197),
  [18635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4333),
  [18637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13919),
  [18639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4335),
  [18641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9241),
  [18643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11913),
  [18645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13924),
  [18647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [18649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17467),
  [18651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13848),
  [18653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11917),
  [18655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [18657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18264),
  [18659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8113),
  [18661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0),
  [18663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11925),
  [18665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8261),
  [18667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11928),
  [18669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [18671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12500),
  [18673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11935),
  [18675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [18677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13701),
  [18679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11938),
  [18681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17767),
  [18683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7797),
  [18685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17772),
  [18687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9265),
  [18689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [18691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11949),
  [18693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11952),
  [18695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6008),
  [18697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18384),
  [18699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10678),
  [18701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11962),
  [18703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11966),
  [18705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17796),
  [18707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7820),
  [18709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18388),
  [18711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14072),
  [18713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11296),
  [18715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15195),
  [18717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11976),
  [18719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17797),
  [18721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9206),
  [18723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11979),
  [18725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11924),
  [18727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11988),
  [18729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11991),
  [18731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17485),
  [18733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5682),
  [18735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11999),
  [18737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12002),
  [18739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [18741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12009),
  [18743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12012),
  [18745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12020),
  [18747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11948),
  [18749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12023),
  [18751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12770),
  [18753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12771),
  [18755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12031),
  [18757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12034),
  [18759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [18761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12043),
  [18763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5619),
  [18765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12046),
  [18767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5621),
  [18769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [18771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [18773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [18775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12362),
  [18777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12053),
  [18779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12295),
  [18781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12056),
  [18783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17488),
  [18785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14918),
  [18787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12063),
  [18789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12066),
  [18791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9145),
  [18793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [18795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3016),
  [18797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9153),
  [18799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12073),
  [18801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12076),
  [18803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12838),
  [18805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12839),
  [18807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12368),
  [18809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12084),
  [18811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12087),
  [18813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17490),
  [18815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14948),
  [18817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12094),
  [18819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12097),
  [18821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12104),
  [18823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12107),
  [18825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12117),
  [18827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8123),
  [18829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [18831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12120),
  [18833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [18835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17670),
  [18837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9174),
  [18839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12128),
  [18841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12131),
  [18843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [18845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [18847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10607),
  [18849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3012),
  [18851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12139),
  [18853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12142),
  [18855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8177),
  [18857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8393),
  [18859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [18861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12149),
  [18863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12152),
  [18865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12395),
  [18867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12161),
  [18869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12164),
  [18871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7898),
  [18873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [18875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [18877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10610),
  [18879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [18881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7900),
  [18883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5766),
  [18885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12171),
  [18887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5774),
  [18889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4394),
  [18891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [18893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14962),
  [18895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12174),
  [18897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12398),
  [18899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12181),
  [18901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12184),
  [18903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17517),
  [18905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14722),
  [18907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12191),
  [18909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12195),
  [18911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17518),
  [18913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14774),
  [18915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12202),
  [18917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12205),
  [18919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12212),
  [18921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12215),
  [18923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14662),
  [18925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14674),
  [18927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [18929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [18931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14205),
  [18933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [18935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18156),
  [18937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7920),
  [18939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14209),
  [18941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4156),
  [18943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11796),
  [18945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18158),
  [18947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5919),
  [18949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11799),
  [18951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [18953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [18955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14214),
  [18957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [18959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [18961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3011),
  [18963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8144),
  [18965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18177),
  [18967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7972),
  [18969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18178),
  [18971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5749),
  [18973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18337),
  [18975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [18977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [18979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12310),
  [18981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [18983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11809),
  [18985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11812),
  [18987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [18989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2603),
  [18991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14942),
  [18993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14509),
  [18995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18146),
  [18997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [18999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [19001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_quoted_string_content_repeat1, 1, 0, 0),
  [19003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quoted_string_content_repeat1, 1, 0, 0),
  [19005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5721),
  [19007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [19009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [19011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4336),
  [19013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5603),
  [19015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17316),
  [19017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13817),
  [19019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [19021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14944),
  [19023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14545),
  [19025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17285),
  [19027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_payload, 2, 0, 0),
  [19029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [19031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12225),
  [19033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18065),
  [19035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9179),
  [19037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12232),
  [19039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [19041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8353),
  [19043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3089),
  [19045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3091),
  [19047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8358),
  [19049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5902),
  [19051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5903),
  [19053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4233),
  [19055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4241),
  [19057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5927),
  [19059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [19061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [19063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17770),
  [19065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8072),
  [19067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8295),
  [19069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18304),
  [19071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8380),
  [19073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18308),
  [19075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5937),
  [19077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17326),
  [19079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5727),
  [19081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18319),
  [19083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8197),
  [19085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11822),
  [19087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18320),
  [19089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5913),
  [19091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16264),
  [19093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15685),
  [19095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10049),
  [19097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2595),
  [19099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14536),
  [19101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17275),
  [19103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17993),
  [19105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5594),
  [19107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17110),
  [19109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15867),
  [19111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9825),
  [19113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11826),
  [19115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [19117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2622),
  [19119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14628),
  [19121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17390),
  [19123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [19125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [19127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_argument_type, 4, 0, 138),
  [19129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6030),
  [19131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12290),
  [19133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17169),
  [19135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15897),
  [19137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9871),
  [19139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17182),
  [19141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15906),
  [19143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10555),
  [19145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4395),
  [19147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5781),
  [19149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4265),
  [19151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8367),
  [19153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [19155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [19157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5240),
  [19159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5336),
  [19161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4605),
  [19163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7094),
  [19165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6239),
  [19167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9705),
  [19169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7331),
  [19171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5374),
  [19173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5886),
  [19175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4445),
  [19177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6789),
  [19179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7663),
  [19181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5074),
  [19183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8415),
  [19185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4328),
  [19187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4383),
  [19189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7606),
  [19191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3988),
  [19193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7303),
  [19195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5350),
  [19197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4667),
  [19199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [19201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [19203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16548),
  [19205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13780),
  [19207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [19209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7393),
  [19211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [19213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9688),
  [19215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [19217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6195),
  [19219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13443),
  [19221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15024),
  [19223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16114),
  [19225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6518),
  [19227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7403),
  [19229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4370),
  [19231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [19233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5393),
  [19235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4520),
  [19237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5550),
  [19239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7075),
  [19241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6309),
  [19243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7322),
  [19245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7639),
  [19247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7413),
  [19249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [19251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9957),
  [19253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7417),
  [19255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5103),
  [19257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6318),
  [19259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7454),
  [19261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6205),
  [19263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7085),
  [19265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7350),
  [19267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6775),
  [19269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4239),
  [19271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [19273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5845),
  [19275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5274),
  [19277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6384),
  [19279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6391),
  [19281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 4, 0, 0),
  [19283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18196),
  [19285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9021),
  [19287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7689),
  [19289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5061),
  [19291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6322),
  [19293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6214),
  [19295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12551),
  [19297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4542),
  [19299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7794),
  [19301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7091),
  [19303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [19305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7096),
  [19307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7092),
  [19309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3600),
  [19311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(15938),
  [19314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6499),
  [19316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3356),
  [19318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6796),
  [19320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6392),
  [19322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7104),
  [19324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5065),
  [19326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7958),
  [19328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [19330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7472),
  [19332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15144),
  [19334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6619),
  [19336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7984),
  [19338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7709),
  [19340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_type_constraint_repeat1, 2, 0, 0), SHIFT_REPEAT(15144),
  [19343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6522),
  [19345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7363),
  [19347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5984),
  [19349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7859),
  [19351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6662),
  [19353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6816),
  [19355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [19357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7731),
  [19359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 4, 0, 167),
  [19361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7497),
  [19363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5995),
  [19365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [19367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6672),
  [19369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3507),
  [19371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4997),
  [19373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7378),
  [19375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7504),
  [19377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_typed, 2, 0, 40),
  [19379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6680),
  [19381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6568),
  [19383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4245),
  [19385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6684),
  [19387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3357),
  [19389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [19391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0),
  [19393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6578),
  [19395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [19397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6586),
  [19399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5003),
  [19401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_binding_pattern_repeat1, 2, 0, 0),
  [19403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [19405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [19407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5020),
  [19409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [19411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6589),
  [19413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4355),
  [19415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4994),
  [19417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5314),
  [19419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6873),
  [19421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [19423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4940),
  [19425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3874),
  [19427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8345),
  [19429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7234),
  [19431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4379),
  [19433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6712),
  [19435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11225),
  [19437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9675),
  [19439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5882),
  [19441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3807),
  [19443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3300),
  [19445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9699),
  [19447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6828),
  [19449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5284),
  [19451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3334),
  [19453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [19455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6329),
  [19457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6723),
  [19459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7535),
  [19461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3661),
  [19463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9539),
  [19465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6764),
  [19467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [19469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7184),
  [19471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6904),
  [19473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5340),
  [19475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6732),
  [19477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 4, 0, 167),
  [19479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5164),
  [19481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5330),
  [19483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7542),
  [19485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5487),
  [19487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6734),
  [19489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6062),
  [19491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5791),
  [19493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [19495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6836),
  [19497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7638),
  [19499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4655),
  [19501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7167),
  [19503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7668),
  [19505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [19507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [19509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4528),
  [19511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 3, 0, 96),
  [19513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3605),
  [19515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [19517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5144),
  [19519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7221),
  [19521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4442),
  [19523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5507),
  [19525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7256),
  [19527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10144),
  [19529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7306),
  [19531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7016),
  [19533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [19535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6842),
  [19537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7531),
  [19539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6539),
  [19541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4054),
  [19543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 3, 0, 96),
  [19545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [19547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5988),
  [19549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 3, 0, 0),
  [19551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20105),
  [19553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14626),
  [19555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18376),
  [19557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18655),
  [19559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14530),
  [19561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17234),
  [19563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6971),
  [19565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5520),
  [19567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6509),
  [19569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [19571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6785),
  [19573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3634),
  [19575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5337),
  [19577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6981),
  [19579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4619),
  [19581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5972),
  [19583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6989),
  [19585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [19587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5109),
  [19589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [19591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7290),
  [19593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [19595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6990),
  [19597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3638),
  [19599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10145),
  [19601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5949),
  [19603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6079),
  [19605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5530),
  [19607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [19609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4065),
  [19611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8402),
  [19613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7143),
  [19615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8360),
  [19617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6374),
  [19619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10290),
  [19621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4739),
  [19623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10194),
  [19625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13443),
  [19627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19658),
  [19629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7430),
  [19631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15584),
  [19633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20622),
  [19635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7468),
  [19637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18930),
  [19639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [19641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15801),
  [19643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13621),
  [19645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16277),
  [19647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21228),
  [19649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6282),
  [19651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19808),
  [19653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3317),
  [19655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19010),
  [19657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5981),
  [19659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15086),
  [19661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9531),
  [19663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9314),
  [19665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18475),
  [19667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 1, 0, 0),
  [19669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15355),
  [19671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18798),
  [19673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [19675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20089),
  [19677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5102),
  [19679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20155),
  [19681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5259),
  [19683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19946),
  [19685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9651),
  [19687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14784),
  [19689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15503),
  [19691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15798),
  [19693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15693),
  [19695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9096),
  [19697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20748),
  [19699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6798),
  [19701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10680),
  [19703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 2, 0, 14),
  [19705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20828),
  [19707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5016),
  [19709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_item_repeat1, 2, 0, 0), SHIFT_REPEAT(17057),
  [19712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19799),
  [19714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7371),
  [19716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13659),
  [19718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16337),
  [19720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21023),
  [19722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5775),
  [19724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19763),
  [19726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15219),
  [19728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15460),
  [19730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2934),
  [19732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16300),
  [19734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15368),
  [19736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11168),
  [19738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12566),
  [19740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9139),
  [19742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19124),
  [19744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7929),
  [19746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18634),
  [19748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5436),
  [19750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 1, 0, 2),
  [19752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18500),
  [19754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5463),
  [19756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15270),
  [19758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 5, 0, 0),
  [19760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8199),
  [19762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8959),
  [19764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tag_spec, 1, 0, 0),
  [19766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15799),
  [19768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8082),
  [19770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5747),
  [19772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15667),
  [19774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tag_specification_repeat1, 2, 0, 0),
  [19776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tag_specification_repeat1, 2, 0, 0), SHIFT_REPEAT(9021),
  [19779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20139),
  [19781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10077),
  [19783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15718),
  [19785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 3, 0, 41),
  [19787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19642),
  [19789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6694),
  [19791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21053),
  [19793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15364),
  [19795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20012),
  [19797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6955),
  [19799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7822),
  [19801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 3, 0, 0),
  [19803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14029),
  [19805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21237),
  [19807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4450),
  [19809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15863),
  [19811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20424),
  [19813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6481),
  [19815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18974),
  [19817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7700),
  [19819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19353),
  [19821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [19823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18668),
  [19825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7209),
  [19827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19302),
  [19829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6644),
  [19831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18948),
  [19833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6180),
  [19835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15605),
  [19837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13646),
  [19839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17188),
  [19841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15271),
  [19843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11540),
  [19845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15116),
  [19847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19209),
  [19849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [19851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15951),
  [19853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15040),
  [19855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9209),
  [19857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21249),
  [19859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [19861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13663),
  [19863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17133),
  [19865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15444),
  [19867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15326),
  [19869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [19871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13683),
  [19873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16565),
  [19875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5700),
  [19877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21387),
  [19879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5397),
  [19881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [19883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9054),
  [19885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 1, 0, 0),
  [19887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15765),
  [19889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20239),
  [19891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4641),
  [19893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4429),
  [19895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 1, 0, 0),
  [19897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15379),
  [19899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18814),
  [19901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6553),
  [19903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19341),
  [19905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [19907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19266),
  [19909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7357),
  [19911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13668),
  [19913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17172),
  [19915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20751),
  [19917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [19919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21254),
  [19921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [19923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15182),
  [19925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9527),
  [19927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9323),
  [19929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_param, 2, 0, 0),
  [19931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20371),
  [19933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6741),
  [19935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18956),
  [19937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6359),
  [19939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15775),
  [19941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20802),
  [19943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [19945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14757),
  [19947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13850),
  [19949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [19951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 1, 0, 0),
  [19953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15753),
  [19955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15769),
  [19957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19791),
  [19959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7061),
  [19961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14075),
  [19963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15191),
  [19965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9528),
  [19967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9328),
  [19969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18773),
  [19971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4330),
  [19973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7978),
  [19975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20818),
  [19977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8269),
  [19979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5856),
  [19981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15426),
  [19983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11550),
  [19985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_instantiated_class_type_repeat1, 2, 0, 0),
  [19987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11708),
  [19989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9031),
  [19991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4477),
  [19993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8369),
  [19995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8889),
  [19997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6285),
  [19999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8288),
  [20001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9740),
  [20003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16249),
  [20005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6300),
  [20007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9754),
  [20009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6311),
  [20011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9756),
  [20013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9953),
  [20015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13968),
  [20017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8896),
  [20019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [20021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11428),
  [20023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16131),
  [20025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [20027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9561),
  [20029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8866),
  [20031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9562),
  [20033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [20035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9081),
  [20037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8923),
  [20039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [20041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10793),
  [20043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8902),
  [20045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7375),
  [20047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10860),
  [20049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9024),
  [20051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9477),
  [20053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9801),
  [20055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7395),
  [20057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16178),
  [20059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7405),
  [20061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9479),
  [20063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10254),
  [20065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16267),
  [20067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8907),
  [20069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7936),
  [20071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4220),
  [20073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7748),
  [20075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10716),
  [20077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16269),
  [20079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7904),
  [20081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5860),
  [20083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12524),
  [20085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4231),
  [20087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10740),
  [20089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16270),
  [20091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8911),
  [20093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4897),
  [20095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5037),
  [20097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10750),
  [20099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5006),
  [20101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17589),
  [20103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10685),
  [20105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21393),
  [20107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9563),
  [20109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10756),
  [20111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5022),
  [20113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7780),
  [20115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11408),
  [20117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11377),
  [20119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11674),
  [20121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16183),
  [20123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5640),
  [20125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12440),
  [20127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8916),
  [20129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [20131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3278),
  [20133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [20135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9000),
  [20137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7063),
  [20139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5096),
  [20141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14642),
  [20143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12486),
  [20145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10632),
  [20147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8919),
  [20149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6958),
  [20151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6973),
  [20153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9995),
  [20155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16285),
  [20157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6983),
  [20159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9540),
  [20161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9846),
  [20163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15785),
  [20165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8922),
  [20167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [20169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16724),
  [20171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7077),
  [20173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11724),
  [20175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16184),
  [20177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6376),
  [20179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10577),
  [20181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16290),
  [20183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6386),
  [20185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16196),
  [20187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7087),
  [20189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8927),
  [20191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [20193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10589),
  [20195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16291),
  [20197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8810),
  [20199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7704),
  [20201] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_instantiated_class_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8959),
  [20204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [20206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8105),
  [20208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8944),
  [20210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3336),
  [20212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9535),
  [20214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8822),
  [20216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5425),
  [20218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [20220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10596),
  [20222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10605),
  [20224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11582),
  [20226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8930),
  [20228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5790),
  [20230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13452),
  [20232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7271),
  [20234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10409),
  [20236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5850),
  [20238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18160),
  [20240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5889),
  [20242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11646),
  [20244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8992),
  [20246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8933),
  [20248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5404),
  [20250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9030),
  [20252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6555),
  [20254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9520),
  [20256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5380),
  [20258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9521),
  [20260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4552),
  [20262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5301),
  [20264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8936),
  [20266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [20268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13671),
  [20270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16302),
  [20272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3745),
  [20274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6570),
  [20276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [20278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9790),
  [20280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9564),
  [20282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16768),
  [20284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13941),
  [20286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16304),
  [20288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8941),
  [20290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [20292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10616),
  [20294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17156),
  [20296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6580),
  [20298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3555),
  [20300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3493),
  [20302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13977),
  [20304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16305),
  [20306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2835),
  [20308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5329),
  [20310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13972),
  [20312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13934),
  [20314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9522),
  [20316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10173),
  [20318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [20320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10613),
  [20322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15117),
  [20324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4583),
  [20326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [20328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7736),
  [20330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18258),
  [20332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9548),
  [20334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9057),
  [20336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [20338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9549),
  [20340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9824),
  [20342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10612),
  [20344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11471),
  [20346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17166),
  [20348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10711),
  [20350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16321),
  [20352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5342),
  [20354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8850),
  [20356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9926),
  [20358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10058),
  [20360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [20362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16411),
  [20364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16150),
  [20366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11280),
  [20368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16323),
  [20370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11314),
  [20372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17175),
  [20374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3625),
  [20376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15475),
  [20378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11327),
  [20380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16324),
  [20382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11470),
  [20384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11356),
  [20386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7747),
  [20388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11507),
  [20390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11362),
  [20392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9445),
  [20394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17905),
  [20396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8807),
  [20398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6485),
  [20400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8806),
  [20402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4340),
  [20404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10071),
  [20406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16745),
  [20408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11413),
  [20410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14321),
  [20412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12580),
  [20414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attribute_id_repeat1, 2, 0, 0), SHIFT_REPEAT(18160),
  [20417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4146),
  [20419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [20421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11114),
  [20423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16338),
  [20425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11521),
  [20427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16132),
  [20429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16894),
  [20431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abstract_type, 2, 0, 0),
  [20433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4361),
  [20435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13395),
  [20437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16340),
  [20439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4617),
  [20441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4372),
  [20443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13485),
  [20445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16341),
  [20447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13537),
  [20449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13366),
  [20451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9474),
  [20453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_declaration_repeat1, 2, 0, 0),
  [20455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_constructor_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(17640),
  [20458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9575),
  [20460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18218),
  [20462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9576),
  [20464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9780),
  [20466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8814),
  [20468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9658),
  [20470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9525),
  [20472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9533),
  [20474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16417),
  [20476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14047),
  [20478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15399),
  [20480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9390),
  [20482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16354),
  [20484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16206),
  [20486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9680),
  [20488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_params_repeat1, 2, 0, 0),
  [20490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_params_repeat1, 2, 0, 0), SHIFT_REPEAT(14554),
  [20493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9947),
  [20495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16356),
  [20497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7655),
  [20499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9692),
  [20501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10570),
  [20503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10387),
  [20505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9977),
  [20507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16357),
  [20509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16128),
  [20511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10000),
  [20513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8904),
  [20515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7620),
  [20517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10017),
  [20519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16060),
  [20521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6501),
  [20523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13627),
  [20525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15551),
  [20527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9551),
  [20529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9577),
  [20531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8819),
  [20533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5957),
  [20535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10304),
  [20537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16759),
  [20539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8882),
  [20541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9707),
  [20543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9708),
  [20545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14493),
  [20547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16209),
  [20549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9298),
  [20551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16370),
  [20553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9536),
  [20555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16352),
  [20557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5960),
  [20559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14595),
  [20561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15649),
  [20563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9317),
  [20565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15965),
  [20567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9418),
  [20569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16375),
  [20571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18265),
  [20573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5976),
  [20575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7646),
  [20577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9429),
  [20579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16376),
  [20581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6511),
  [20583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9711),
  [20585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [20587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7894),
  [20589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16686),
  [20591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9436),
  [20593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15747),
  [20595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9440),
  [20597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9908),
  [20599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15971),
  [20601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7671),
  [20603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16931),
  [20605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7578),
  [20607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14566),
  [20609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16210),
  [20611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8826),
  [20613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5261),
  [20615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10352),
  [20617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16151),
  [20619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10123),
  [20621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9739),
  [20623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15973),
  [20625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16776),
  [20627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9841),
  [20629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9282),
  [20631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16390),
  [20633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8148),
  [20635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15984),
  [20637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9730),
  [20639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5276),
  [20641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14619),
  [20643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9456),
  [20645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16391),
  [20647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16288),
  [20649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10174),
  [20651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5214),
  [20653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9757),
  [20655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9462),
  [20657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16392),
  [20659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14629),
  [20661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13292),
  [20663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16675),
  [20665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15975),
  [20667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9468),
  [20669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7707),
  [20671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9471),
  [20673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16524),
  [20675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8833),
  [20677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5472),
  [20679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_instance_variable_specification_repeat1, 2, 0, 0),
  [20681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_instance_variable_specification_repeat1, 2, 0, 0), SHIFT_REPEAT(16114),
  [20684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2948),
  [20686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17143),
  [20688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13455),
  [20690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_method_specification_repeat1, 2, 0, 0),
  [20692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_method_specification_repeat1, 2, 0, 0), SHIFT_REPEAT(16300),
  [20695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16403),
  [20697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10329),
  [20699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16152),
  [20701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4615),
  [20703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5655),
  [20705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10419),
  [20708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5493),
  [20710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8977),
  [20712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7251),
  [20714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11505),
  [20716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13652),
  [20718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16407),
  [20720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8934),
  [20722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5510),
  [20724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9465),
  [20726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9466),
  [20728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13675),
  [20730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16408),
  [20732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14938),
  [20734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10530),
  [20736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13685),
  [20738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10564),
  [20740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11498),
  [20742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16018),
  [20744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13689),
  [20746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7311),
  [20748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9470),
  [20750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [20752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8291),
  [20754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8839),
  [20756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6182),
  [20758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10410),
  [20760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11463),
  [20762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16024),
  [20764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5799),
  [20766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7354),
  [20768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7581),
  [20770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11444),
  [20772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16026),
  [20774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6197),
  [20776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8843),
  [20778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [20780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10327),
  [20782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12487),
  [20784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11256),
  [20786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6207),
  [20788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11302),
  [20790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11300),
  [20792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11374),
  [20794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8844),
  [20796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6648),
  [20798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13117),
  [20800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9590),
  [20802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9591),
  [20804] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4146),
  [20807] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(4146),
  [20810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4759),
  [20812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11781),
  [20814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16224),
  [20816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6664),
  [20818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6674),
  [20820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11985),
  [20822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16534),
  [20824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15930),
  [20826] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__abstract_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16894),
  [20829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__abstract_type_repeat1, 2, 0, 0),
  [20831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [20833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9592),
  [20835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13225),
  [20837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10758),
  [20839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9511),
  [20841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9011),
  [20843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7438),
  [20845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8851),
  [20847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [20849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12448),
  [20851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16226),
  [20853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [20855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9501),
  [20857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8288),
  [20860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat1, 2, 0, 0),
  [20862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6714),
  [20864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9196),
  [20866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12512),
  [20868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [20870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10364),
  [20872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16069),
  [20874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6725),
  [20876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7457),
  [20878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12458),
  [20880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16227),
  [20882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11268),
  [20884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16690),
  [20886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11525),
  [20888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9502),
  [20890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [20892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9107),
  [20894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12629),
  [20896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11294),
  [20898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15122),
  [20900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8860),
  [20902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10098),
  [20904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12464),
  [20906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7240),
  [20908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11149),
  [20910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16074),
  [20912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12466),
  [20914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12542),
  [20916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7475),
  [20918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13306),
  [20920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17129),
  [20922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10167),
  [20924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12882),
  [20926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11188),
  [20928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16075),
  [20930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10218),
  [20932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15006),
  [20934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11203),
  [20936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11214),
  [20938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9537),
  [20940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11502),
  [20942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8867),
  [20944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6745),
  [20946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15187),
  [20948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12775),
  [20950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6766),
  [20952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15042),
  [20954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11436),
  [20956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6778),
  [20958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15100),
  [20960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5696),
  [20962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12547),
  [20964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15038),
  [20966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8217),
  [20968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15095),
  [20970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15020),
  [20972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15058),
  [20974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9041),
  [20976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7229),
  [20978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15113),
  [20980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8876),
  [20982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8327),
  [20984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15159),
  [20986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5695),
  [20988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15139),
  [20990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15004),
  [20992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17745),
  [20994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9515),
  [20996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15150),
  [20998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9516),
  [21000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15066),
  [21002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15044),
  [21004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8872),
  [21006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6802),
  [21008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5921),
  [21010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12520),
  [21012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15027),
  [21014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9349),
  [21016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15012),
  [21018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16102),
  [21020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15108),
  [21022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15010),
  [21024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15097),
  [21026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7171),
  [21028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15193),
  [21030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9517),
  [21032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15026),
  [21034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15101),
  [21036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15166),
  [21038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15015),
  [21040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9800),
  [21042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16105),
  [21044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15051),
  [21046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14994),
  [21048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7227),
  [21050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15157),
  [21052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15105),
  [21054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6820),
  [21056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15167),
  [21058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15050),
  [21060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9878),
  [21062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16106),
  [21064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15037),
  [21066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5930),
  [21068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15119),
  [21070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15043),
  [21072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9794),
  [21074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15133),
  [21076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9605),
  [21078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9767),
  [21080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15007),
  [21082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9606),
  [21084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6831),
  [21086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15045),
  [21088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15089),
  [21090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15135),
  [21092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15172),
  [21094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9326),
  [21096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11722),
  [21098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16246),
  [21100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag_specification, 1, 0, 0),
  [21102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8732),
  [21104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8881),
  [21106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [21108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13197),
  [21110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8932),
  [21112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4631),
  [21114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8350),
  [21116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat2, 2, 0, 0),
  [21118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat2, 2, 0, 0), SHIFT_REPEAT(18242),
  [21121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9273),
  [21123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9607),
  [21125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17149),
  [21127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11539),
  [21129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11542),
  [21131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12811),
  [21133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8823),
  [21135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7476),
  [21137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [21139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17165),
  [21141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11559),
  [21143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11562),
  [21145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11789),
  [21147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9932),
  [21149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16248),
  [21151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11552),
  [21153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8996),
  [21155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5043),
  [21157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12569),
  [21159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [21161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15149),
  [21163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14684),
  [21165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10306),
  [21167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [21169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [21171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14672),
  [21173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15247),
  [21175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7946),
  [21177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9701),
  [21179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7618),
  [21181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17344),
  [21183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14845),
  [21185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9687),
  [21187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18347),
  [21189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14554),
  [21191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15593),
  [21193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14952),
  [21195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15315),
  [21197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4121),
  [21199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16969),
  [21201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8155),
  [21203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9971),
  [21205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14742),
  [21207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [21209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4789),
  [21211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14746),
  [21213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [21215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14661),
  [21217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14751),
  [21219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [21221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17342),
  [21223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18989),
  [21225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15252),
  [21227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [21229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6044),
  [21231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19548),
  [21233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14799),
  [21235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15084),
  [21237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14763),
  [21239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14707),
  [21241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7623),
  [21243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [21245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14705),
  [21247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15250),
  [21249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15536),
  [21251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14977),
  [21253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [21255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8749),
  [21257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19954),
  [21259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10714),
  [21261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15034),
  [21263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14658),
  [21265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15563),
  [21267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15533),
  [21269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7627),
  [21271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14721),
  [21273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5795),
  [21275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9998),
  [21277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5771),
  [21279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14775),
  [21281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7975),
  [21283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15328),
  [21285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5807),
  [21287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15341),
  [21289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4484),
  [21291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14891),
  [21293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6031),
  [21295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15223),
  [21297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [21299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5772),
  [21301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9631),
  [21303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [21305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [21307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14487),
  [21309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15522),
  [21311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [21313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14841),
  [21315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [21317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [21319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14423),
  [21321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14695),
  [21323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [21325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7450),
  [21327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15330),
  [21329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9589),
  [21331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17400),
  [21333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14959),
  [21335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14681),
  [21337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14440),
  [21339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14668),
  [21341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [21343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14697),
  [21345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6508),
  [21347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14568),
  [21349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13700),
  [21351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15371),
  [21353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5440),
  [21355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14973),
  [21357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5881),
  [21359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15531),
  [21361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [21363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15614),
  [21365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4554),
  [21367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [21369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15132),
  [21371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14781),
  [21373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9416),
  [21375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3157),
  [21377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15656),
  [21379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14665),
  [21381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14719),
  [21383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4228),
  [21385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9712),
  [21387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14940),
  [21389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5971),
  [21391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [21393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10332),
  [21395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14677),
  [21397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7706),
  [21399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [21401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14671),
  [21403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14740),
  [21405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [21407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [21409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16761),
  [21411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9413),
  [21413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [21415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_variable_expression, 1, 0, 0),
  [21417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15548),
  [21419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9426),
  [21421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14881),
  [21423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5442),
  [21425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14932),
  [21427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14014),
  [21429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15339),
  [21431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5383),
  [21433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17439),
  [21435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14786),
  [21437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7656),
  [21439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8225),
  [21441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20412),
  [21443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [21445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10644),
  [21447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [21449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14963),
  [21451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14492),
  [21453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4992),
  [21455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14795),
  [21457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6557),
  [21459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [21461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14998),
  [21463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [21465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [21467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15759),
  [21469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14497),
  [21471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [21473] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(16761),
  [21476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8325),
  [21478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10737),
  [21480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9906),
  [21482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15342),
  [21484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5822),
  [21486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9453),
  [21488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14730),
  [21490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7662),
  [21492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14552),
  [21494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17473),
  [21496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14657),
  [21498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5288),
  [21500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14204),
  [21502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7986),
  [21504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15451),
  [21506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15078),
  [21508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10573),
  [21510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5590),
  [21512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14664),
  [21514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15349),
  [21516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6560),
  [21518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14322),
  [21520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10608),
  [21522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14723),
  [21524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5263),
  [21526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9843),
  [21528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_instance_variable_specification_repeat1, 1, 0, 0),
  [21530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [21532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17505),
  [21534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [21536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [21538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14755),
  [21540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [21542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14764),
  [21544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14806),
  [21546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4932),
  [21548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15572),
  [21550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5266),
  [21552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14768),
  [21554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15169),
  [21556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9560),
  [21558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14325),
  [21560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14211),
  [21562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15347),
  [21564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [21566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [21568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [21570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14780),
  [21572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17526),
  [21574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15486),
  [21576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7716),
  [21578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14802),
  [21580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [21582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15227),
  [21584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14849),
  [21586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [21588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15098),
  [21590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14796),
  [21592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15580),
  [21594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15350),
  [21596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2415),
  [21599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9454),
  [21601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [21603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15463),
  [21605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17974),
  [21607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9382),
  [21609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17549),
  [21611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14909),
  [21613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [21615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14927),
  [21617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7598),
  [21619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15259),
  [21621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4958),
  [21623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14789),
  [21625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [21627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15280),
  [21629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [21631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5149),
  [21633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13346),
  [21635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5818),
  [21637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15361),
  [21639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15176),
  [21641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14803),
  [21643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15005),
  [21645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14817),
  [21647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [21649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9459),
  [21651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13962),
  [21653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14654),
  [21655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17573),
  [21657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9158),
  [21659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14965),
  [21661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4053),
  [21663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9617),
  [21665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15264),
  [21667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9655),
  [21669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15083),
  [21671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [21673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6447),
  [21675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17596),
  [21677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5832),
  [21679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15212),
  [21681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15697),
  [21683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10773),
  [21685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14666),
  [21687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4738),
  [21689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14923),
  [21691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3535),
  [21693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(15001),
  [21696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_expression_repeat1, 2, 0, 0),
  [21698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14805),
  [21700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6577),
  [21702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15087),
  [21704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14884),
  [21706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5474),
  [21708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10318),
  [21710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14824),
  [21712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5019),
  [21714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15362),
  [21716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [21718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [21720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14953),
  [21722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8165),
  [21724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15618),
  [21726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5477),
  [21728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17620),
  [21730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8751),
  [21732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14713),
  [21734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6308),
  [21736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [21738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [21740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6327),
  [21742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15115),
  [21744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9547),
  [21746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17642),
  [21748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15363),
  [21750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14915),
  [21752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8122),
  [21754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17402),
  [21756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14651),
  [21758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [21760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6595),
  [21762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14680),
  [21764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [21766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15145),
  [21768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7841),
  [21770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3436),
  [21772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14743),
  [21774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15625),
  [21776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17652),
  [21778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15676),
  [21780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13952),
  [21782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15237),
  [21784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14829),
  [21786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14679),
  [21788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7285),
  [21790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13648),
  [21792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15055),
  [21794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7924),
  [21796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9388),
  [21798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15638),
  [21800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7289),
  [21802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17669),
  [21804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14951),
  [21806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5506),
  [21808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14857),
  [21810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14978),
  [21812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18151),
  [21814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_method_specification_repeat1, 1, 0, 0),
  [21816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15070),
  [21818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14819),
  [21820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5045),
  [21822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17685),
  [21824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14362),
  [21826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7755),
  [21828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13664),
  [21830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [21832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14363),
  [21834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9235),
  [21836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14976),
  [21838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9727),
  [21840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14980),
  [21842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8366),
  [21844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15134),
  [21846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(16788),
  [21849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_declaration_repeat1, 2, 0, 0),
  [21851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [21853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14083),
  [21855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17703),
  [21857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [21859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3775),
  [21861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14717),
  [21863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14596),
  [21865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5628),
  [21867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15600),
  [21869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [21871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17723),
  [21873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15394),
  [21875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15648),
  [21877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7793),
  [21879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [21881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7596),
  [21883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11638),
  [21885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5703),
  [21887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15198),
  [21889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3010),
  [21891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14376),
  [21893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3041),
  [21895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17738),
  [21897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4337),
  [21899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [21901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14380),
  [21903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4338),
  [21905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14694),
  [21907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6184),
  [21909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15059),
  [21911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11415),
  [21913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14733),
  [21915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9499),
  [21917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17983),
  [21919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17753),
  [21921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14769),
  [21923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7349),
  [21925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15653),
  [21927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6187),
  [21929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21348),
  [21931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [21933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6902),
  [21935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15032),
  [21937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8782),
  [21939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17768),
  [21941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5600),
  [21943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [21945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14715),
  [21947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [21949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11779),
  [21951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11270),
  [21953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11432),
  [21955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10326),
  [21957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [21959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17311),
  [21961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17783),
  [21963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15659),
  [21965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14690),
  [21967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7377),
  [21969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14791),
  [21971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13787),
  [21973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [21975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14734),
  [21977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6204),
  [21979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17794),
  [21981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [21983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14370),
  [21985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14787),
  [21987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3818),
  [21989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3109),
  [21991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17806),
  [21993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5444),
  [21995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9574),
  [21997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14739),
  [21999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4164),
  [22001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17815),
  [22003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14967),
  [22005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14702),
  [22007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4642),
  [22009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14377),
  [22011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17872),
  [22013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17830),
  [22015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15691),
  [22017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3823),
  [22019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4165),
  [22021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14864),
  [22023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [22025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14851),
  [22027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [22029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14347),
  [22031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17844),
  [22033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15277),
  [22035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [22037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9734),
  [22039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14712),
  [22041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5069),
  [22043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20425),
  [22045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14905),
  [22047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [22049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14777),
  [22051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [22053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [22055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19909),
  [22057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17854),
  [22059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15680),
  [22061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6653),
  [22063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17868),
  [22065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [22067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_copy_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(16744),
  [22070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_copy_expression_repeat1, 2, 0, 0),
  [22072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [22074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [22076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14788),
  [22078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11465),
  [22080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [22082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17881),
  [22084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15684),
  [22086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15400),
  [22088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3594),
  [22090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14893),
  [22092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14794),
  [22094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6671),
  [22096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [22098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14800),
  [22100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17895),
  [22102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [22104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9656),
  [22106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6230),
  [22108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18321),
  [22110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15329),
  [22112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4223),
  [22114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19059),
  [22116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14797),
  [22118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17907),
  [22120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [22122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14826),
  [22124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5418),
  [22126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10362),
  [22128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11260),
  [22130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17919),
  [22132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13954),
  [22134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [22136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14590),
  [22138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15713),
  [22140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17930),
  [22142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15278),
  [22144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14901),
  [22146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [22148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5198),
  [22150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8940),
  [22152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17440),
  [22154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15238),
  [22156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7381),
  [22158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17945),
  [22160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [22162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8361),
  [22164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15260),
  [22166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17953),
  [22168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4830),
  [22170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14836),
  [22172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6698),
  [22174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14937),
  [22176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14714),
  [22178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7440),
  [22180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12446),
  [22182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [22184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 64),
  [22186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17965),
  [22188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15711),
  [22190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6702),
  [22192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15717),
  [22194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7445),
  [22196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [22198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 2, 0, 64),
  [22200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [22202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17975),
  [22204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [22206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9604),
  [22208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [22210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14388),
  [22212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14906),
  [22214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14855),
  [22216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14812),
  [22218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3636),
  [22220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14511),
  [22222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7899),
  [22224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17984),
  [22226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [22228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [22230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14515),
  [22232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5779),
  [22234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15411),
  [22236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15716),
  [22238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14350),
  [22240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8081),
  [22242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15409),
  [22244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19975),
  [22246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17995),
  [22248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(10451),
  [22251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14876),
  [22253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6722),
  [22255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6535),
  [22257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [22259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14683),
  [22261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6287),
  [22263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18007),
  [22265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13763),
  [22267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6245),
  [22269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14756),
  [22271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [22273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14888),
  [22275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18016),
  [22277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8389),
  [22279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18020),
  [22281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12455),
  [22283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18026),
  [22285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4179),
  [22287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15745),
  [22289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14698),
  [22291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18031),
  [22293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18035),
  [22295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18041),
  [22297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18045),
  [22299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18050),
  [22301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18056),
  [22303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18060),
  [22305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11276),
  [22307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18067),
  [22309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14704),
  [22311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7065),
  [22313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18072),
  [22315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18077),
  [22317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18083),
  [22319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18089),
  [22321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18090),
  [22323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6303),
  [22325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18091),
  [22327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18092),
  [22329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18093),
  [22331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18095),
  [22333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18097),
  [22335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18098),
  [22337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18100),
  [22339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18101),
  [22341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18102),
  [22343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18103),
  [22345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18104),
  [22347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18106),
  [22349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18108),
  [22351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18110),
  [22353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18111),
  [22355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18112),
  [22357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18113),
  [22359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18114),
  [22361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18116),
  [22363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18118),
  [22365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18120),
  [22367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18122),
  [22369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14828),
  [22371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14576),
  [22373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9147),
  [22375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7670),
  [22377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10618),
  [22379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9663),
  [22381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11311),
  [22383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8041),
  [22385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14955),
  [22387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [22389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14835),
  [22391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3093),
  [22393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14526),
  [22395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8735),
  [22397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [22399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14947),
  [22401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6960),
  [22403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4398),
  [22405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18353),
  [22407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18354),
  [22409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18355),
  [22411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14527),
  [22413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15295),
  [22415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7068),
  [22417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4399),
  [22419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14972),
  [22421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10100),
  [22423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15285),
  [22425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6964),
  [22427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8704),
  [22429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [22431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15749),
  [22433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10113),
  [22435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11146),
  [22437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [22439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [22441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [22443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19575),
  [22445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14875),
  [22447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15324),
  [22449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9514),
  [22451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14785),
  [22453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7471),
  [22455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14957),
  [22457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6169),
  [22459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11319),
  [22461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [22463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14988),
  [22465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2280),
  [22468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15033),
  [22470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [22472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6961),
  [22474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [22476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3029),
  [22478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14860),
  [22480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7944),
  [22482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15756),
  [22484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [22486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11185),
  [22488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14985),
  [22490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10188),
  [22492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15547),
  [22494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3122),
  [22497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_binding_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(4666),
  [22500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6268),
  [22502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14710),
  [22504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14902),
  [22506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15288),
  [22508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14792),
  [22510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14969),
  [22512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17286),
  [22514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17287),
  [22516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17288),
  [22518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [22520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexing_operator_path, 1, 0, 0),
  [22522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexing_operator_path, 1, 0, 0),
  [22524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [22526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [22528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [22530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [22532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [22534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [22536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [22538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14960),
  [22540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6980),
  [22542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14720),
  [22544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17598),
  [22546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14863),
  [22548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6747),
  [22550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15240),
  [22552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3140),
  [22554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7973),
  [22556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14968),
  [22558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11711),
  [22560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9256),
  [22562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [22564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17354),
  [22566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17355),
  [22568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17356),
  [22570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14420),
  [22572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18290),
  [22574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15783),
  [22576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6750),
  [22578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14716),
  [22580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [22582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [22584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [22586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9218),
  [22588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [22590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10068),
  [22592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14718),
  [22594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20421),
  [22596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14471),
  [22598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [22600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15118),
  [22602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [22604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14528),
  [22606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5598),
  [22608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15787),
  [22610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14954),
  [22612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6774),
  [22614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17408),
  [22616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17409),
  [22618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17410),
  [22620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15602),
  [22622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15246),
  [22624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [22626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [22628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [22630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [22632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10062),
  [22634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18213),
  [22636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15736),
  [22638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7491),
  [22640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14669),
  [22642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7720),
  [22644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14823),
  [22646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [22648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10535),
  [22650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18326),
  [22652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17444),
  [22654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17445),
  [22656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17446),
  [22658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11198),
  [22660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [22662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [22664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [22666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [22668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9512),
  [22670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17478),
  [22672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17479),
  [22674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17480),
  [22676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8026),
  [22678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [22680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [22682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [22684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17508),
  [22686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17509),
  [22688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17510),
  [22690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [22692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [22694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [22696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14708),
  [22698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7402),
  [22700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15448),
  [22702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4345),
  [22704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17530),
  [22706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17531),
  [22708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17532),
  [22710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3138),
  [22713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [22715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [22717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [22719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14453),
  [22721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14896),
  [22723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4603),
  [22725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [22727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15631),
  [22729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17553),
  [22731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17554),
  [22733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17555),
  [22735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [22737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [22739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [22741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [22743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17579),
  [22745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17580),
  [22747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17581),
  [22749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [22751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1046),
  [22753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [22755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14897),
  [22757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7268),
  [22759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14984),
  [22761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6364),
  [22763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14745),
  [22765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6487),
  [22767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17603),
  [22769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17604),
  [22771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17605),
  [22773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [22775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [22777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [22779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15257),
  [22781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5129),
  [22783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15826),
  [22785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7108),
  [22787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17626),
  [22789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17627),
  [22791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17628),
  [22793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [22795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [22797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [22799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15298),
  [22801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6367),
  [22803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17644),
  [22805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17645),
  [22807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17646),
  [22809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [22811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [22813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [22815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9318),
  [22817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [22819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15303),
  [22821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17656),
  [22823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17657),
  [22825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17658),
  [22827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [22829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [22831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [22833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14699),
  [22835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14593),
  [22837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8354),
  [22839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14895),
  [22841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17674),
  [22843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17675),
  [22845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17676),
  [22847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [22849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [22851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [22853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14594),
  [22855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5917),
  [22857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [22859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14711),
  [22861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14779),
  [22863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6804),
  [22865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17691),
  [22867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17692),
  [22869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17693),
  [22871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [22873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [22875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [22877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [22879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14831),
  [22881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8329),
  [22883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__abstract_type_repeat1, 1, 0, 4),
  [22885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17709),
  [22887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17710),
  [22889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17711),
  [22891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [22893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [22895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [22897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [22899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14724),
  [22901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15210),
  [22903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6290),
  [22905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17727),
  [22907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17728),
  [22909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17729),
  [22911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15452),
  [22913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [22915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [22917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [22919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13389),
  [22921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17742),
  [22923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17743),
  [22925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17744),
  [22927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14910),
  [22929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [22931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [22933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [22935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15840),
  [22937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6808),
  [22939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [22941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17757),
  [22943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17758),
  [22945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17759),
  [22947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [22949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [22951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [22953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [22955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17773),
  [22957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17774),
  [22959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17775),
  [22961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15837),
  [22963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [22965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [22967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [22969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [22971] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(15082),
  [22974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_pattern_repeat1, 2, 0, 0),
  [22976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9681),
  [22978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17787),
  [22980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17788),
  [22982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17789),
  [22984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [22986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [22988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [22990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9249),
  [22992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14834),
  [22994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4369),
  [22996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [22998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14598),
  [23000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17798),
  [23002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17799),
  [23004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17800),
  [23006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [23008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [23010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [23012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [23014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [23016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4267),
  [23018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17809),
  [23020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17810),
  [23022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17811),
  [23024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [23026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [23028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [23030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14600),
  [23032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [23034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [23036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15301),
  [23038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15877),
  [23040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8336),
  [23042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14847),
  [23044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17818),
  [23046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17819),
  [23048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17820),
  [23050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [23052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [23054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [23056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4311),
  [23058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9903),
  [23060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17833),
  [23062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17834),
  [23064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17835),
  [23066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14607),
  [23068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [23070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [23072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [23074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [23076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9719),
  [23078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4673),
  [23080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_binding_pattern, 2, 0, 64),
  [23082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14916),
  [23084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7025),
  [23086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17846),
  [23088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17847),
  [23090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17848),
  [23092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [23094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [23096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [23098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [23100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexing_operator_path, 3, 0, 0),
  [23102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexing_operator_path, 3, 0, 0),
  [23104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4334),
  [23106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13476),
  [23108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17857),
  [23110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17858),
  [23112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17859),
  [23114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [23116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [23118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [23120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6635),
  [23122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15499),
  [23124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6490),
  [23126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17873),
  [23128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17874),
  [23130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17875),
  [23132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [23134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [23136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [23138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9193),
  [23140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17884),
  [23142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17885),
  [23144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17886),
  [23146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [23148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [23150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [23152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15855),
  [23154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10575),
  [23156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17896),
  [23158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17897),
  [23160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17898),
  [23162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [23164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [23166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [23168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9872),
  [23170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14676),
  [23172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17908),
  [23174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17909),
  [23176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17910),
  [23178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [23180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [23182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [23184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14919),
  [23186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17924),
  [23188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17925),
  [23190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17926),
  [23192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [23194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [23196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [23198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [23200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14673),
  [23202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17935),
  [23204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17936),
  [23206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17937),
  [23208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [23210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [23212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [23214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17947),
  [23216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17948),
  [23218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17949),
  [23220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [23222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [23224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [23226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14727),
  [23228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6383),
  [23230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14894),
  [23232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6827),
  [23234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14736),
  [23236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4479),
  [23238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [23240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17957),
  [23242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17958),
  [23244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17959),
  [23246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [23248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [23250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [23252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7589),
  [23254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17276),
  [23256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9638),
  [23258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17967),
  [23260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17968),
  [23262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17969),
  [23264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [23266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [23268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [23270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6251),
  [23272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14738),
  [23274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7084),
  [23276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17979),
  [23278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17980),
  [23280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17981),
  [23282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6277),
  [23284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [23286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [23288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [23290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14750),
  [23292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_binding_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(4602),
  [23295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17987),
  [23297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17988),
  [23299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17989),
  [23301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [23303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [23305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [23307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14924),
  [23309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15530),
  [23311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [23313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18000),
  [23315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18001),
  [23317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18002),
  [23319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [23321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1281),
  [23323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [23325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9951),
  [23328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13992),
  [23330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18010),
  [23332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18011),
  [23334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18012),
  [23336] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_binding_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(14996),
  [23339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_binding_pattern_repeat1, 2, 0, 0),
  [23341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [23343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1288),
  [23345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [23347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18017),
  [23349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18018),
  [23351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18019),
  [23353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14964),
  [23355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5051),
  [23357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18021),
  [23359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18022),
  [23361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18023),
  [23363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18027),
  [23365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18028),
  [23367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18029),
  [23369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18032),
  [23371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18033),
  [23373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18034),
  [23375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18036),
  [23377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18037),
  [23379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18038),
  [23381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18042),
  [23383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18043),
  [23385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18044),
  [23387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18046),
  [23389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18047),
  [23391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18048),
  [23393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18051),
  [23395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18052),
  [23397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18053),
  [23399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18057),
  [23401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18058),
  [23403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18059),
  [23405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18061),
  [23407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18062),
  [23409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18063),
  [23411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18068),
  [23413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18069),
  [23415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18070),
  [23417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18073),
  [23419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18074),
  [23421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18075),
  [23423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18078),
  [23425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18079),
  [23427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18080),
  [23429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18084),
  [23431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18085),
  [23433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18086),
  [23435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14987),
  [23437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17272),
  [23439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18751),
  [23441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [23443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14638),
  [23445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14840),
  [23447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9660),
  [23449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19267),
  [23451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [23453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10583),
  [23455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14649),
  [23457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [23459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14732),
  [23461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20021),
  [23463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15206),
  [23465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7774),
  [23467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17904),
  [23469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15892),
  [23471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [23473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15871),
  [23475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21210),
  [23477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21214),
  [23479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21217),
  [23481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13264),
  [23483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14850),
  [23485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [23487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15482),
  [23489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9665),
  [23491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [23493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9101),
  [23495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13783),
  [23497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [23499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14678),
  [23501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8720),
  [23503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20959),
  [23505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18422),
  [23507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17193),
  [23509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17204),
  [23511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [23513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15021),
  [23515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [23517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14833),
  [23519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7482),
  [23521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15312),
  [23523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [23525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15415),
  [23527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15907),
  [23529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9920),
  [23531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14687),
  [23533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15898),
  [23535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14700),
  [23537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [23539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14900),
  [23541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4029),
  [23543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14692),
  [23545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [23547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [23549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5669),
  [23551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9621),
  [23553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15789),
  [23555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14753),
  [23557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7938),
  [23559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15488),
  [23561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15908),
  [23563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9943),
  [23565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20642),
  [23567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10748),
  [23569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17911),
  [23571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19487),
  [23573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4586),
  [23575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13592),
  [23577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8834),
  [23579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [23581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9958),
  [23583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10490),
  [23585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [23587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6396),
  [23589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20969),
  [23591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14291),
  [23593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_params, 1, 0, 0),
  [23595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19488),
  [23597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2210),
  [23599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [23601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10084),
  [23603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8918),
  [23605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [23607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7146),
  [23609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20710),
  [23611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14222),
  [23613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [23615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7917),
  [23617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8809),
  [23619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4353),
  [23621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8467),
  [23623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4778),
  [23625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20149),
  [23627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7845),
  [23629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3283),
  [23631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4360),
  [23633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [23635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [23637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11451),
  [23639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [23641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5143),
  [23643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18740),
  [23645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9769),
  [23647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9357),
  [23649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [23651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6911),
  [23653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8005),
  [23655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18731),
  [23657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4378),
  [23659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19187),
  [23661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14373),
  [23663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13489),
  [23665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10032),
  [23667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20595),
  [23669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7903),
  [23671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18792),
  [23673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [23675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9760),
  [23677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [23679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5209),
  [23681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18871),
  [23683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14267),
  [23685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4636),
  [23687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19390),
  [23689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12600),
  [23691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [23693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2334),
  [23695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [23697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8007),
  [23699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17377),
  [23701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [23703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11299),
  [23705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7464),
  [23707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20501),
  [23709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11273),
  [23711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14228),
  [23713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20409),
  [23715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14265),
  [23717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4050),
  [23719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10689),
  [23721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17237),
  [23723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8817),
  [23725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6497),
  [23727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9016),
  [23729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [23731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [23733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [23735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14537),
  [23737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14236),
  [23739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8965),
  [23741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [23743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8820),
  [23745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [23747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18291),
  [23749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4771),
  [23751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20726),
  [23753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12412),
  [23755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9371),
  [23757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [23759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14547),
  [23761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18312),
  [23763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20308),
  [23765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20309),
  [23767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20310),
  [23769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7257),
  [23771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13978),
  [23773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16582),
  [23775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [23777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8967),
  [23779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [23781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8226),
  [23783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20363),
  [23785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5660),
  [23787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20984),
  [23789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8816),
  [23791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9673),
  [23793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12612),
  [23795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7719),
  [23797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20662),
  [23799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [23801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10735),
  [23803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [23805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [23807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8920),
  [23809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6969),
  [23811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5546),
  [23813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [23815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10747),
  [23817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20267),
  [23819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_params, 4, 0, 0),
  [23821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9007),
  [23823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7073),
  [23825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7147),
  [23827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4956),
  [23829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9744),
  [23831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19870),
  [23833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7222),
  [23835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9685),
  [23837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10764),
  [23839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6978),
  [23841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8837),
  [23843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4540),
  [23845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13390),
  [23847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [23849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18695),
  [23851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4061),
  [23853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19983),
  [23855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5044),
  [23857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18545),
  [23859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9698),
  [23861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5548),
  [23863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18549),
  [23865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17319),
  [23867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6988),
  [23869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5078),
  [23871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14295),
  [23873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20380),
  [23875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9988),
  [23877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9504),
  [23879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7187),
  [23881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [23883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8999),
  [23885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5083),
  [23887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18656),
  [23889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5553),
  [23891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18652),
  [23893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14266),
  [23895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9566),
  [23897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8974),
  [23899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [23901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [23903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14290),
  [23905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17461),
  [23907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8157),
  [23909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17475),
  [23911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20402),
  [23913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20403),
  [23915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20404),
  [23917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6394),
  [23919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [23921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16103),
  [23923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [23925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8976),
  [23927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [23929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [23931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [23933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10070),
  [23935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [23937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [23939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8434),
  [23941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [23943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7855),
  [23945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20384),
  [23947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5081),
  [23949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4654),
  [23951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3755),
  [23953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18915),
  [23955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5687),
  [23957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14292),
  [23959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7604),
  [23961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5174),
  [23963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20894),
  [23965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6506),
  [23967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [23969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20999),
  [23971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7910),
  [23973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20742),
  [23975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8821),
  [23977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6057),
  [23979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8924),
  [23981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6372),
  [23983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17637),
  [23985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10274),
  [23987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [23989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14565),
  [23991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9018),
  [23993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5106),
  [23995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11626),
  [23997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14293),
  [23999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7082),
  [24001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [24003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3303),
  [24005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7548),
  [24007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9019),
  [24009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6620),
  [24011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14289),
  [24013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3795),
  [24015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17752),
  [24017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5968),
  [24019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17760),
  [24021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20470),
  [24023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20471),
  [24025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20472),
  [24027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8915),
  [24029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7635),
  [24031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16396),
  [24033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6381),
  [24035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10579),
  [24037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9948),
  [24039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6348),
  [24041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19471),
  [24043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17828),
  [24045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6390),
  [24047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5891),
  [24049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19624),
  [24051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [24053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5986),
  [24055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11734),
  [24057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17915),
  [24059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17929),
  [24061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6353),
  [24063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19498),
  [24065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9431),
  [24067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8890),
  [24069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6296),
  [24071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [24073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9006),
  [24075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14904),
  [24077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20328),
  [24079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6992),
  [24081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18142),
  [24083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18149),
  [24085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20497),
  [24087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20498),
  [24089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20499),
  [24091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16730),
  [24093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7823),
  [24095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20450),
  [24097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5756),
  [24099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19771),
  [24101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5524),
  [24103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20286),
  [24105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7090),
  [24107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14268),
  [24109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18225),
  [24111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20432),
  [24113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [24115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7660),
  [24117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7278),
  [24119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20334),
  [24121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10477),
  [24123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [24125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21014),
  [24127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6517),
  [24129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9441),
  [24131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18243),
  [24133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_guard, 2, 0, 36),
  [24135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20769),
  [24137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13867),
  [24139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8928),
  [24141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [24143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5659),
  [24145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8917),
  [24147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7657),
  [24149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20924),
  [24151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8087),
  [24153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20201),
  [24155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18298),
  [24157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18302),
  [24159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20520),
  [24161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20521),
  [24163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20522),
  [24165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16980),
  [24167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10593),
  [24169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [24171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7959),
  [24173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20835),
  [24175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5671),
  [24177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20296),
  [24179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7023),
  [24181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20301),
  [24183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [24185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [24187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14276),
  [24189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18397),
  [24191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8903),
  [24193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7391),
  [24195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [24197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7688),
  [24199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [24201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [24203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14569),
  [24205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9776),
  [24207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9012),
  [24209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17762),
  [24211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6632),
  [24213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20758),
  [24215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17739),
  [24217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20540),
  [24219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20541),
  [24221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20542),
  [24223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16347),
  [24225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7007),
  [24227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20393),
  [24229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11534),
  [24231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8829),
  [24233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5272),
  [24235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [24237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20418),
  [24239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14760),
  [24241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20435),
  [24243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14770),
  [24245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4719),
  [24247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17863),
  [24249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8169),
  [24251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20469),
  [24253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8801),
  [24255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17514),
  [24257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [24259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17590),
  [24261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20560),
  [24263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20561),
  [24265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20562),
  [24267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16213),
  [24269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7010),
  [24271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20514),
  [24273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4672),
  [24275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21357),
  [24277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [24279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4860),
  [24281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14798),
  [24283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20749),
  [24285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [24287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5281),
  [24289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18262),
  [24291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6616),
  [24293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14234),
  [24295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9458),
  [24297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [24299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8378),
  [24301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8832),
  [24303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4086),
  [24305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17199),
  [24307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6883),
  [24309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17260),
  [24311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20579),
  [24313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20580),
  [24315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20581),
  [24317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16731),
  [24319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7798),
  [24321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21164),
  [24323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [24325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16827),
  [24327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5218),
  [24329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7400),
  [24331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7826),
  [24333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21093),
  [24335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9464),
  [24337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18369),
  [24339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8931),
  [24341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5842),
  [24343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [24345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12522),
  [24347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4772),
  [24349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20646),
  [24351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_type, 2, 0, 102),
  [24353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [24355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12971),
  [24357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17392),
  [24359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10039),
  [24361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7810),
  [24363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21256),
  [24365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17449),
  [24367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20597),
  [24369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20598),
  [24371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20599),
  [24373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16086),
  [24375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6086),
  [24377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9472),
  [24379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7236),
  [24381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18819),
  [24383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17736),
  [24385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7851),
  [24387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5878),
  [24389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17977),
  [24391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7530),
  [24393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18005),
  [24395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20615),
  [24397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20616),
  [24399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20617),
  [24401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16589),
  [24403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14286),
  [24405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6528),
  [24407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18516),
  [24409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5944),
  [24411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7486),
  [24413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18501),
  [24415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4216),
  [24417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18665),
  [24419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18224),
  [24421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4614),
  [24423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14244),
  [24425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10667),
  [24427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10964),
  [24429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5580),
  [24431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20774),
  [24433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9080),
  [24435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17569),
  [24437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8836),
  [24439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5485),
  [24441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17894),
  [24443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20632),
  [24445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20633),
  [24447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20634),
  [24449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16199),
  [24451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8798),
  [24453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6433),
  [24455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18547),
  [24457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [24459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19450),
  [24461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7412),
  [24463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5722),
  [24465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20290),
  [24467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17370),
  [24469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12498),
  [24471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10292),
  [24473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17951),
  [24475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18204),
  [24477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20648),
  [24479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20649),
  [24481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20650),
  [24483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9089),
  [24485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20461),
  [24487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4153),
  [24489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17218),
  [24491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17419),
  [24493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5504),
  [24495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14274),
  [24497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17441),
  [24499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20664),
  [24501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20665),
  [24503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20666),
  [24505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4550),
  [24507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8935),
  [24509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5302),
  [24511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17639),
  [24513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14261),
  [24515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [24517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8949),
  [24519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4208),
  [24521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7745),
  [24523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20464),
  [24525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10390),
  [24527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19164),
  [24529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9142),
  [24531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17856),
  [24533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8095),
  [24535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17921),
  [24537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20680),
  [24539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20681),
  [24541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20682),
  [24543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6306),
  [24545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3373),
  [24547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4246),
  [24549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18722),
  [24551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18228),
  [24553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5825),
  [24555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18766),
  [24557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5518),
  [24559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [24561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18356),
  [24563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13679),
  [24565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8027),
  [24567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18367),
  [24569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20696),
  [24571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20697),
  [24573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20698),
  [24575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10580),
  [24577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8994),
  [24579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7300),
  [24581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17197),
  [24583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10279),
  [24585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18812),
  [24587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5324),
  [24589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [24591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14073),
  [24593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5834),
  [24595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18800),
  [24597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17225),
  [24599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8987),
  [24601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17232),
  [24603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20712),
  [24605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20713),
  [24607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20714),
  [24609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11554),
  [24611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13624),
  [24613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [24615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7795),
  [24617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17257),
  [24619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10286),
  [24621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18837),
  [24623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7043),
  [24625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7594),
  [24627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7584),
  [24629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20678),
  [24631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8893),
  [24633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [24635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17323),
  [24637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5717),
  [24639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17327),
  [24641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20728),
  [24643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20729),
  [24645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20730),
  [24647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6735),
  [24649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12257),
  [24651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17374),
  [24653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7955),
  [24655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9036),
  [24657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6566),
  [24659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7298),
  [24661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21094),
  [24663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17420),
  [24665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4322),
  [24667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17427),
  [24669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20744),
  [24671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20745),
  [24673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20746),
  [24675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8034),
  [24677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7345),
  [24679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17476),
  [24681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9748),
  [24683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8939),
  [24685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [24687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17545),
  [24689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5912),
  [24691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20789),
  [24693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17557),
  [24695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20760),
  [24697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20761),
  [24699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20762),
  [24701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5589),
  [24703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19087),
  [24705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9877),
  [24707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17593),
  [24709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [24711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8322),
  [24713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8840),
  [24715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6193),
  [24717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [24719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8035),
  [24721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19101),
  [24723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5952),
  [24725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19207),
  [24727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8154),
  [24729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17665),
  [24731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19107),
  [24733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17682),
  [24735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20776),
  [24737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20777),
  [24739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20778),
  [24741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7362),
  [24743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3762),
  [24745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17732),
  [24747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6005),
  [24749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7101),
  [24751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11453),
  [24753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17790),
  [24755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7260),
  [24757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19159),
  [24759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6202),
  [24761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17807),
  [24763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20791),
  [24765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20792),
  [24767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20793),
  [24769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13630),
  [24771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17842),
  [24773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6468),
  [24775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19167),
  [24777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7110),
  [24779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19182),
  [24781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19138),
  [24783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7834),
  [24785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19141),
  [24787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9270),
  [24789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17900),
  [24791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20806),
  [24793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20807),
  [24795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20808),
  [24797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14232),
  [24799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [24801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17946),
  [24803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5615),
  [24805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19148),
  [24807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8312),
  [24809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19178),
  [24811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6213),
  [24813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18009),
  [24815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20821),
  [24817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20822),
  [24819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20823),
  [24821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18130),
  [24823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8324),
  [24825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19195),
  [24827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18170),
  [24829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20836),
  [24831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20837),
  [24833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20838),
  [24835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [24837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6575),
  [24839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6529),
  [24841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19212),
  [24843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18193),
  [24845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [24847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14147),
  [24849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [24851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9151),
  [24853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [24855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20613),
  [24857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17575),
  [24859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18230),
  [24861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20851),
  [24863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20852),
  [24865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20853),
  [24867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8357),
  [24869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7462),
  [24871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20939),
  [24873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18257),
  [24875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5101),
  [24877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6860),
  [24879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19568),
  [24881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [24883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6886),
  [24885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18333),
  [24887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20866),
  [24889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20867),
  [24891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20868),
  [24893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18381),
  [24895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8830),
  [24897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5335),
  [24899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8908),
  [24901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7837),
  [24903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6317),
  [24905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10658),
  [24907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18389),
  [24909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20881),
  [24911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20882),
  [24913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20883),
  [24915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7545),
  [24917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20804),
  [24919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18268),
  [24921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9262),
  [24923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8864),
  [24925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [24927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 153),
  [24929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8846),
  [24931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6660),
  [24933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17841),
  [24935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20896),
  [24937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20897),
  [24939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20898),
  [24941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18313),
  [24943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5197),
  [24945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11394),
  [24947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14021),
  [24949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8942),
  [24951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [24953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17324),
  [24955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20911),
  [24957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20912),
  [24959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20913),
  [24961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6669),
  [24963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4226),
  [24965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8897),
  [24967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [24969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6332),
  [24971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13000),
  [24973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19603),
  [24975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12985),
  [24977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20916),
  [24979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17613),
  [24981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20926),
  [24983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20927),
  [24985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20928),
  [24987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5347),
  [24989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6624),
  [24991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19466),
  [24993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6679),
  [24995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17749),
  [24997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18214),
  [24999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17972),
  [25001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20941),
  [25003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20942),
  [25005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20943),
  [25007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9873),
  [25009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18502),
  [25011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3569),
  [25013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9163),
  [25015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13928),
  [25017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13691),
  [25019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6626),
  [25021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19500),
  [25023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9224),
  [25025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19772),
  [25027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7587),
  [25029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5364),
  [25031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18357),
  [25033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20956),
  [25035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20957),
  [25037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20958),
  [25039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7925),
  [25041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9532),
  [25043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15016),
  [25045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6634),
  [25047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19602),
  [25049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3583),
  [25051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17228),
  [25053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20971),
  [25055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20972),
  [25057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20973),
  [25059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11710),
  [25061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6646),
  [25063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6585),
  [25065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5642),
  [25067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20492),
  [25069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 113),
  [25071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17329),
  [25073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20986),
  [25075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20987),
  [25077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20988),
  [25079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9821),
  [25081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6675),
  [25083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19627),
  [25085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [25087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14243),
  [25089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17421),
  [25091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21001),
  [25093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21002),
  [25095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21003),
  [25097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13947),
  [25099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [25101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7559),
  [25103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20819),
  [25105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17513),
  [25107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21016),
  [25109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21017),
  [25111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21018),
  [25113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7893),
  [25115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20495),
  [25117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9608),
  [25119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19944),
  [25121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8853),
  [25123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6710),
  [25125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14417),
  [25127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8664),
  [25129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20558),
  [25131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17609),
  [25133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21030),
  [25135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21031),
  [25137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21032),
  [25139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5512),
  [25141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8803),
  [25143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17699),
  [25145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21044),
  [25147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21045),
  [25149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21046),
  [25151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14269),
  [25153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [25155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7858),
  [25157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19214),
  [25159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5637),
  [25161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6593),
  [25163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [25165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6868),
  [25167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19782),
  [25169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9015),
  [25171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7452),
  [25173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [25175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19787),
  [25177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17793),
  [25179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21058),
  [25181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21059),
  [25183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21060),
  [25185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7032),
  [25187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20117),
  [25189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4107),
  [25191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19807),
  [25193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3639),
  [25195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19857),
  [25197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17933),
  [25199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21072),
  [25201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21073),
  [25203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21074),
  [25205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6731),
  [25207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6105),
  [25209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17999),
  [25211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21084),
  [25213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21085),
  [25215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21086),
  [25217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18064),
  [25219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21096),
  [25221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21097),
  [25223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21098),
  [25225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [25227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8383),
  [25229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18094),
  [25231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21101),
  [25233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21102),
  [25235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21103),
  [25237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9214),
  [25239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19915),
  [25241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18105),
  [25243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21106),
  [25245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21107),
  [25247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21108),
  [25249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18115),
  [25251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21111),
  [25253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21112),
  [25255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21113),
  [25257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [25259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19924),
  [25261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14285),
  [25263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18127),
  [25265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21116),
  [25267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21117),
  [25269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21118),
  [25271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18133),
  [25273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21121),
  [25275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21122),
  [25277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21123),
  [25279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3675),
  [25281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18139),
  [25283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21126),
  [25285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21127),
  [25287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21128),
  [25289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8854),
  [25291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7211),
  [25293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18148),
  [25295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21131),
  [25297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21132),
  [25299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21133),
  [25301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18165),
  [25303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21136),
  [25305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21137),
  [25307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21138),
  [25309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6101),
  [25311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19964),
  [25313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18636),
  [25315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18179),
  [25317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21141),
  [25319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21142),
  [25321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21143),
  [25323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18198),
  [25325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21146),
  [25327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21147),
  [25329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21148),
  [25331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7310),
  [25333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18206),
  [25335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21151),
  [25337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21152),
  [25339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21153),
  [25341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6103),
  [25343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19985),
  [25345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7703),
  [25347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20538),
  [25349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18222),
  [25351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21156),
  [25353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21157),
  [25355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21158),
  [25357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9610),
  [25359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20044),
  [25361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [25363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [25365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20011),
  [25367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [25369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20014),
  [25371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7103),
  [25373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7264),
  [25375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20033),
  [25377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7332),
  [25379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20036),
  [25381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14914),
  [25383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7950),
  [25385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20055),
  [25387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7961),
  [25389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20058),
  [25391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13961),
  [25393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [25395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12461),
  [25397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7239),
  [25399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11664),
  [25401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [25403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4903),
  [25405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20083),
  [25407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [25409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4926),
  [25411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20088),
  [25413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4899),
  [25415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13969),
  [25417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20946),
  [25419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3451),
  [25421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20121),
  [25423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [25425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20124),
  [25427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3455),
  [25429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13216),
  [25431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7469),
  [25433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6419),
  [25435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20156),
  [25437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7575),
  [25439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20834),
  [25441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6421),
  [25443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20160),
  [25445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11416),
  [25447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7034),
  [25449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20169),
  [25451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6425),
  [25453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8863),
  [25455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10136),
  [25457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [25459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14513),
  [25461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [25463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6120),
  [25465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20200),
  [25467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5343),
  [25469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20278),
  [25471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11464),
  [25473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14046),
  [25475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [25477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6122),
  [25479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20205),
  [25481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [25483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9148),
  [25485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6244),
  [25487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20284),
  [25489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6124),
  [25491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20287),
  [25493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16843),
  [25495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10186),
  [25497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9307),
  [25499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20109),
  [25501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7496),
  [25503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12279),
  [25505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3476),
  [25507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20235),
  [25509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [25511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20240),
  [25513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_variant_type_repeat2, 1, 0, 0),
  [25515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3482),
  [25517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8419),
  [25519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20271),
  [25521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10248),
  [25523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12769),
  [25525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17229),
  [25527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9990),
  [25529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11191),
  [25531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14262),
  [25533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20306),
  [25535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8002),
  [25537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20311),
  [25539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5922),
  [25541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5858),
  [25543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20292),
  [25545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5874),
  [25547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20294),
  [25549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9970),
  [25551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8423),
  [25553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20299),
  [25555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5786),
  [25557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5287),
  [25559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20315),
  [25561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [25563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4453),
  [25565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7558),
  [25567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [25569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8186),
  [25571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [25573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [25575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11330),
  [25577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8097),
  [25579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5407),
  [25581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20352),
  [25583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12778),
  [25585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5417),
  [25587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20355),
  [25589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5451),
  [25591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9795),
  [25593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5654),
  [25595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20967),
  [25597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7591),
  [25599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20849),
  [25601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [25603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20387),
  [25605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [25607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20395),
  [25609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8868),
  [25611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6758),
  [25613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11682),
  [25615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [25617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11435),
  [25619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [25621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6026),
  [25623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [25625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6819),
  [25627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5534),
  [25629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11352),
  [25631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6772),
  [25633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [25635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20444),
  [25637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5872),
  [25639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [25641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [25643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20453),
  [25645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3808),
  [25647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9129),
  [25649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18315),
  [25651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9125),
  [25653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20508),
  [25655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12313),
  [25657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6784),
  [25659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14507),
  [25661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14055),
  [25663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7299),
  [25665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [25667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8172),
  [25669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10543),
  [25671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8221),
  [25673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4237),
  [25675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7483),
  [25677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5713),
  [25679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9128),
  [25681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20537),
  [25683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8875),
  [25685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [25687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5614),
  [25689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20515),
  [25691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12841),
  [25693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14246),
  [25695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6019),
  [25697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9131),
  [25699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7948),
  [25701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20518),
  [25703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14294),
  [25705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9049),
  [25707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7164),
  [25709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7839),
  [25711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18925),
  [25713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14253),
  [25715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18197),
  [25717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12223),
  [25719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14278),
  [25721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4460),
  [25723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20864),
  [25725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7170),
  [25727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5415),
  [25729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18234),
  [25731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8133),
  [25733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7460),
  [25735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [25737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10648),
  [25739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10742),
  [25741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5494),
  [25743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20143),
  [25745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8873),
  [25747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6814),
  [25749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4346),
  [25751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20694),
  [25753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11211),
  [25755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6905),
  [25757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7463),
  [25759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11485),
  [25761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7198),
  [25763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8825),
  [25765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7590),
  [25767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14368),
  [25769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8802),
  [25771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [25773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [25775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20954),
  [25777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10866),
  [25779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7052),
  [25781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20630),
  [25783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10622),
  [25785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20968),
  [25787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20977),
  [25789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6857),
  [25791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20980),
  [25793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8913),
  [25795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4998),
  [25797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7245),
  [25799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4752),
  [25801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21183),
  [25803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8852),
  [25805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6013),
  [25807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9887),
  [25809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6825),
  [25811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21005),
  [25813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8244),
  [25815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21006),
  [25817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5754),
  [25819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [25821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3610),
  [25823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10782),
  [25825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21010),
  [25827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [25829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7765),
  [25831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14257),
  [25833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5017),
  [25835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [25837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20577),
  [25839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8954),
  [25841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [25843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4198),
  [25845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21078),
  [25847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21232),
  [25849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6835),
  [25851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19728),
  [25853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7507),
  [25855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8888),
  [25857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8343),
  [25859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [25861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21236),
  [25863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [25865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5665),
  [25867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21150),
  [25869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17207),
  [25871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_params, 3, 0, 0),
  [25873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8880),
  [25875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5313),
  [25877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [25879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [25881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17244),
  [25883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20176),
  [25885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20177),
  [25887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20178),
  [25889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13945),
  [25891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6064),
  [25893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21181),
  [25895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8906),
  [25897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [25899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4912),
  [25901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11336),
  [25903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17183),
  [25905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [25907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8956),
  [25909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [25911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [25913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21368),
  [25915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [25917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5888),
  [25919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4201),
  [25921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21193),
  [25923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11751),
  [25925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5067),
  [25927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20136),
  [25929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14630),
  [25931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6028),
  [25933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21234),
  [25935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8401),
  [25937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [25939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10302),
  [25941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14631),
  [25943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20145),
  [25945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21384),
  [25947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10709),
  [25949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9338),
  [25951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10621),
  [25953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7600),
  [25955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21388),
  [25957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14173),
  [25959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [25961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18489),
  [25963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4702),
  [25965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [25967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9022),
  [25969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4516),
  [25971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [25973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8891),
  [25975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11329),
  [25977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4527),
  [25979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20879),
  [25981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8884),
  [25983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [25985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4115),
  [25987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20909),
  [25989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [25991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4443),
  [25993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21396),
  [25995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8363),
  [25997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5140),
  [25999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11494),
  [26001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9215),
  [26003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10019),
  [26005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14275),
  [26007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11564),
  [26009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [26011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11790),
  [26013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7556),
  [26015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21399),
  [26017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12570),
  [26019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11556),
  [26021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11567),
  [26023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19484),
  [26025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17416),
  [26027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13991),
  [26029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7250),
  [26031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9695),
  [26033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [26035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5805),
  [26037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13512),
  [26039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6346),
  [26041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5876),
  [26043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14181),
  [26045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5114),
  [26047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13474),
  [26049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [26051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [26053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9785),
  [26055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [26057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9696),
  [26059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [26061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [26063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5746),
  [26065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6406),
  [26067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [26069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17922),
  [26071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7884),
  [26073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9697),
  [26075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10473),
  [26077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7407),
  [26079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6347),
  [26081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7890),
  [26083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [26085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7408),
  [26087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [26089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [26091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7527),
  [26093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [26095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7675),
  [26097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [26099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6986),
  [26101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [26103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16574),
  [26105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4377),
  [26107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10474),
  [26109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10780),
  [26111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6987),
  [26113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8096),
  [26115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8175),
  [26117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9587),
  [26119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5710),
  [26121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11855),
  [26123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5712),
  [26125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [26127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5592),
  [26129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11805),
  [26131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10103),
  [26133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5715),
  [26135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11859),
  [26137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18143),
  [26139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [26141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5906),
  [26143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7276),
  [26145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17217),
  [26147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5941),
  [26149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [26151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [26153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [26155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [26157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13373),
  [26159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [26161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7487),
  [26163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9796),
  [26165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5648),
  [26167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13550),
  [26169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5680),
  [26171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5596),
  [26173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5698),
  [26175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [26177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9812),
  [26179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5956),
  [26181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [26183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [26185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18387),
  [26187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6411),
  [26189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [26191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6349),
  [26193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7853),
  [26195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14184),
  [26197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5480),
  [26199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8139),
  [26201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9242),
  [26203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6350),
  [26205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9243),
  [26207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6351),
  [26209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2884),
  [26211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [26213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4779),
  [26215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14037),
  [26217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16845),
  [26219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9702),
  [26221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9703),
  [26223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14043),
  [26225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9704),
  [26227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [26229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [26231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9192),
  [26233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [26235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11867),
  [26237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [26239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5063),
  [26241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5705),
  [26243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6445),
  [26245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9835),
  [26247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5552),
  [26249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11871),
  [26251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17892),
  [26253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16529),
  [26255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [26257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10010),
  [26259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2872),
  [26261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5544),
  [26263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5446),
  [26265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [26267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13493),
  [26269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9538),
  [26271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4199),
  [26273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [26275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [26277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [26279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9830),
  [26281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [26283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [26285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17840),
  [26287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [26289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [26291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10381),
  [26293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [26295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6889),
  [26297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8991),
  [26299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17428),
  [26301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [26303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [26305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [26307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5561),
  [26309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [26311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16079),
  [26313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [26315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6410),
  [26317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10416),
  [26319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [26321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [26323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6304),
  [26325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [26327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11878),
  [26329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [26331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [26333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [26335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [26337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [26339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [26341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11882),
  [26343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18344),
  [26345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [26347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7053),
  [26349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7054),
  [26351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10231),
  [26353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14217),
  [26355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5498),
  [26357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13428),
  [26359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7204),
  [26361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [26363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16056),
  [26365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [26367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [26369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9720),
  [26371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4597),
  [26373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2923),
  [26375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [26377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17379),
  [26379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9264),
  [26381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [26383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5502),
  [26385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7906),
  [26387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6407),
  [26389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [26391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [26393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2925),
  [26395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [26397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7414),
  [26399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12721),
  [26401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17115),
  [26403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [26405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10095),
  [26407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [26409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10232),
  [26411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6896),
  [26413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6408),
  [26415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [26417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5575),
  [26419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11890),
  [26421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6942),
  [26423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13473),
  [26425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5091),
  [26427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6943),
  [26429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7415),
  [26431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8564),
  [26433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11894),
  [26435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17539),
  [26437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7416),
  [26439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4240),
  [26441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [26443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2251),
  [26445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [26447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13482),
  [26449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7725),
  [26451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9106),
  [26453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12724),
  [26455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12725),
  [26457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9862),
  [26459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2937),
  [26461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2938),
  [26463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17781),
  [26465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7291),
  [26467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7732),
  [26469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10044),
  [26471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [26473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [26475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8815),
  [26477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10447),
  [26479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [26481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7616),
  [26483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8143),
  [26485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2940),
  [26487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [26489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3739),
  [26491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9119),
  [26493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5412),
  [26495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16260),
  [26497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [26499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5556),
  [26501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [26503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10495),
  [26505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10450),
  [26507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10499),
  [26509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [26511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [26513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11902),
  [26515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5413),
  [26517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16097),
  [26519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5644),
  [26521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [26523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7751),
  [26525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [26527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11906),
  [26529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18030),
  [26531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5382),
  [26533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5414),
  [26535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [26537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4248),
  [26539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4765),
  [26541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [26543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4114),
  [26545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13523),
  [26547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6985),
  [26549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5517),
  [26551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5445),
  [26553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7864),
  [26555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8372),
  [26557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [26559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [26561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [26563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18323),
  [26565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4766),
  [26567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5625),
  [26569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8373),
  [26571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [26573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9755),
  [26575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4616),
  [26577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6502),
  [26579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10148),
  [26581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [26583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [26585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [26587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [26589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [26591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16717),
  [26593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13543),
  [26595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6492),
  [26597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [26599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11384),
  [26601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [26603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5639),
  [26605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5169),
  [26607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5419),
  [26609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11916),
  [26611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5422),
  [26613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9627),
  [26615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5423),
  [26617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5829),
  [26619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5170),
  [26621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5172),
  [26623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11920),
  [26625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18416),
  [26627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [26629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10386),
  [26631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5308),
  [26633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5316),
  [26635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3713),
  [26637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13687),
  [26639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13558),
  [26641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12294),
  [26643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5134),
  [26645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11252),
  [26647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4561),
  [26649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7295),
  [26651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2956),
  [26653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [26655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17221),
  [26657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7991),
  [26659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8691),
  [26661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10666),
  [26663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5207),
  [26665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [26667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5836),
  [26669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2958),
  [26671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [26673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14871),
  [26675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5210),
  [26677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5219),
  [26679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16961),
  [26681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [26683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [26685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [26687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7532),
  [26689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [26691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10283),
  [26693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7533),
  [26695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11927),
  [26697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7534),
  [26699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8106),
  [26701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7253),
  [26703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12298),
  [26705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11931),
  [26707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17238),
  [26709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9115),
  [26711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17523),
  [26713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10424),
  [26715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [26717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5866),
  [26719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10503),
  [26721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13400),
  [26723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9118),
  [26725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10288),
  [26727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7772),
  [26729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5563),
  [26731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10487),
  [26733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7312),
  [26735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [26737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [26739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17313),
  [26741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7050),
  [26743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6562),
  [26745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [26747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10522),
  [26749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5541),
  [26751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4653),
  [26753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7461),
  [26755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [26757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2800),
  [26759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5699),
  [26761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11337),
  [26763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [26765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15929),
  [26767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7773),
  [26769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [26771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11393),
  [26773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5933),
  [26775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8286),
  [26777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11937),
  [26779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5286),
  [26781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7614),
  [26783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [26785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5719),
  [26787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [26789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11941),
  [26791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17341),
  [26793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7005),
  [26795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14010),
  [26797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [26799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [26801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [26803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [26805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [26807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [26809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13439),
  [26811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [26813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [26815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9246),
  [26817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7515),
  [26819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [26821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [26823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [26825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17401),
  [26827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [26829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [26831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [26833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4495),
  [26835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [26837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6932),
  [26839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [26841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [26843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [26845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8395),
  [26847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10539),
  [26849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7343),
  [26851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16041),
  [26853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3756),
  [26855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6504),
  [26857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7518),
  [26859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6080),
  [26861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [26863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6891),
  [26865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8040),
  [26867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7382),
  [26869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10454),
  [26871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11951),
  [26873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8878),
  [26875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [26877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4632),
  [26879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11955),
  [26881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17450),
  [26883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6947),
  [26885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6895),
  [26887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [26889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10301),
  [26891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5701),
  [26893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13464),
  [26895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3717),
  [26897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10458),
  [26899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3669),
  [26901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [26903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8375),
  [26905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [26907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [26909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17537),
  [26911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [26913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4751),
  [26915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8397),
  [26917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5602),
  [26919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9839),
  [26921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10517),
  [26923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2887),
  [26925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [26927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6907),
  [26929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6908),
  [26931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6909),
  [26933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16174),
  [26935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4348),
  [26937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10309),
  [26939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [26941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7359),
  [26943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8103),
  [26945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [26947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10526),
  [26949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11965),
  [26951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6189),
  [26953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8104),
  [26955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10529),
  [26957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8319),
  [26959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7607),
  [26961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [26963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11969),
  [26965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17578),
  [26967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [26969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [26971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14602),
  [26973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8013),
  [26975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7861),
  [26977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8014),
  [26979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [26981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13538),
  [26983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4497),
  [26985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5013),
  [26987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [26989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [26991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6082),
  [26993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [26995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [26997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [26999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17649),
  [27001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [27003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5481),
  [27005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [27007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [27009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9212),
  [27011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6931),
  [27013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [27015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [27017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2963),
  [27019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [27021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5704),
  [27023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6312),
  [27025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [27027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16307),
  [27029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5706),
  [27031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5015),
  [27033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7212),
  [27035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7361),
  [27037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6047),
  [27039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14374),
  [27041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [27043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11978),
  [27045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [27047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6368),
  [27049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [27051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [27053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6313),
  [27055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13631),
  [27057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11982),
  [27059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17705),
  [27061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9647),
  [27063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6314),
  [27065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13639),
  [27067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character_content, 1, 0, 0),
  [27069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [27071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [27073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [27075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13397),
  [27077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11625),
  [27079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6602),
  [27081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6198),
  [27083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [27085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [27087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17780),
  [27089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7831),
  [27091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7838),
  [27093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [27095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10040),
  [27097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7874),
  [27099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6200),
  [27101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [27103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [27105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [27107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7078),
  [27109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6603),
  [27111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16429),
  [27113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5026),
  [27115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [27117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10484),
  [27119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [27121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11990),
  [27123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [27125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8042),
  [27127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6920),
  [27129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6925),
  [27131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11994),
  [27133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17817),
  [27135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6927),
  [27137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [27139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3384),
  [27141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5611),
  [27143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10531),
  [27145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3385),
  [27147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [27149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13440),
  [27151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [27153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8335),
  [27155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [27157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [27159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17879),
  [27161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5613),
  [27163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [27165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [27167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10261),
  [27169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [27171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [27173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13454),
  [27175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7080),
  [27177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16491),
  [27179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [27181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14088),
  [27183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [27185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12001),
  [27187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [27189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14090),
  [27191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11257),
  [27193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10435),
  [27195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12005),
  [27197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17918),
  [27199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7546),
  [27201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6571),
  [27203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6208),
  [27205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6209),
  [27207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [27209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6210),
  [27211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13467),
  [27213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7213),
  [27215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10405),
  [27217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8338),
  [27219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2798),
  [27221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [27223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17985),
  [27225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7849),
  [27227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10346),
  [27229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6211),
  [27231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9223),
  [27233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6212),
  [27235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [27237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
  [27239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [27241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9931),
  [27243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5616),
  [27245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16583),
  [27247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [27249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2306),
  [27251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8347),
  [27253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12011),
  [27255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7044),
  [27257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [27259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8348),
  [27261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3391),
  [27263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7272),
  [27265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12015),
  [27267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18039),
  [27269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9183),
  [27271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7815),
  [27273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [27275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6483),
  [27277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5990),
  [27279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [27281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6215),
  [27283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13494),
  [27285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11255),
  [27287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6216),
  [27289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6217),
  [27291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [27293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [27295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18155),
  [27297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8317),
  [27299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2882),
  [27301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6573),
  [27303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17720),
  [27305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7113),
  [27307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10046),
  [27309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [27311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [27313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2319),
  [27315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13521),
  [27317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8514),
  [27319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16747),
  [27321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [27323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [27325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [27327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [27329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12022),
  [27331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8326),
  [27333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10060),
  [27335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10491),
  [27337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6315),
  [27339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6292),
  [27341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12026),
  [27343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18182),
  [27345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5202),
  [27347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8067),
  [27349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6377),
  [27351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13531),
  [27353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6532),
  [27355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [27357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [27359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [27361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [27363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18217),
  [27365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5961),
  [27367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4781),
  [27369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9649),
  [27371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7045),
  [27373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7046),
  [27375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [27377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [27379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [27381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [27383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4301),
  [27385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16811),
  [27387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13645),
  [27389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [27391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5965),
  [27393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [27395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12033),
  [27397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2740),
  [27399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [27401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [27403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [27405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12037),
  [27407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18244),
  [27409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17615),
  [27411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16388),
  [27413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7953),
  [27415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10347),
  [27417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7863),
  [27419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13561),
  [27421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11322),
  [27423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2332),
  [27425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11323),
  [27427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [27429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [27431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18305),
  [27433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [27435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [27437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [27439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10066),
  [27441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [27443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [27445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [27447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [27449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17031),
  [27451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8004),
  [27453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7435),
  [27455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [27457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [27459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12045),
  [27461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5120),
  [27463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10055),
  [27465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [27467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10359),
  [27469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12049),
  [27471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18371),
  [27473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6316),
  [27475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4302),
  [27477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [27479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10361),
  [27481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [27483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [27485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6379),
  [27487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13453),
  [27489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [27491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4221),
  [27493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [27495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [27497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18408),
  [27499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7029),
  [27501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7030),
  [27503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [27505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [27507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [27509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [27511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12329),
  [27513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6703),
  [27515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16630),
  [27517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1829),
  [27519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [27521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8432),
  [27523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12055),
  [27525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7425),
  [27527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [27529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11133),
  [27531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6654),
  [27533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12059),
  [27535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17460),
  [27537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [27539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [27541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10303),
  [27543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8403),
  [27545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8404),
  [27547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13492),
  [27549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7009),
  [27551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [27553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12334),
  [27555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2850),
  [27557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [27559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17552),
  [27561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17805),
  [27563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [27565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7055),
  [27567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2853),
  [27569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [27571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5991),
  [27573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9981),
  [27575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [27577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16334),
  [27579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5997),
  [27581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6000),
  [27583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [27585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12065),
  [27587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4224),
  [27589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4304),
  [27591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6388),
  [27593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [27595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12069),
  [27597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17997),
  [27599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7020),
  [27601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9122),
  [27603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6751),
  [27605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [27607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3541),
  [27609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [27611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13449),
  [27613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9890),
  [27615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9918),
  [27617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [27619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2857),
  [27621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17231),
  [27623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6389),
  [27625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [27627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [27629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9946),
  [27631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6665),
  [27633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [27635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [27637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2859),
  [27639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4402),
  [27641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8376),
  [27643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8411),
  [27645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16244),
  [27647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4663),
  [27649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14013),
  [27651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10437),
  [27653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6667),
  [27655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12075),
  [27657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [27659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9583),
  [27661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5892),
  [27663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7503),
  [27665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4569),
  [27667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12079),
  [27669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17376),
  [27671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5893),
  [27673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [27675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [27677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [27679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10527),
  [27681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [27683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13405),
  [27685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [27687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [27689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [27691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2870),
  [27693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17550),
  [27695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6222),
  [27697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5894),
  [27699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6223),
  [27701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6224),
  [27703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7767),
  [27705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6677),
  [27707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [27709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [27711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4403),
  [27713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4405),
  [27715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9014),
  [27717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16873),
  [27719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4494),
  [27721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [27723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6042),
  [27725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13483),
  [27727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12086),
  [27729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5983),
  [27731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6678),
  [27733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [27735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10440),
  [27737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12090),
  [27739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17679),
  [27741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [27743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5985),
  [27745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11334),
  [27747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [27749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [27751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6161),
  [27753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17880),
  [27755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13466),
  [27757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5996),
  [27759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9778),
  [27761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [27763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2888),
  [27765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [27767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17891),
  [27769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6046),
  [27771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7647),
  [27773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7847),
  [27775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6225),
  [27777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6226),
  [27779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6227),
  [27781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [27783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [27785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6625),
  [27787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4763),
  [27789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6162),
  [27791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15999),
  [27793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5992),
  [27795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6352),
  [27797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [27799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__quoted_string, 3, 0, 0),
  [27801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12096),
  [27803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [27805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [27807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9585),
  [27809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [27811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6542),
  [27813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12100),
  [27815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18087),
  [27817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19810),
  [27819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6163),
  [27821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7843),
  [27823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21200),
  [27825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19947),
  [27827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [27829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13575),
  [27831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [27833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [27835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [27837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [27839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18322),
  [27841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15261),
  [27843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6354),
  [27845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6583),
  [27847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6627),
  [27849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10523),
  [27851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [27853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [27855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [27857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7436),
  [27859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13496),
  [27861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [27863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16266),
  [27865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6543),
  [27867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14142),
  [27869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6512),
  [27871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12106),
  [27873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6584),
  [27875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [27877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12110),
  [27879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18377),
  [27881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6319),
  [27883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [27885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [27887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14144),
  [27889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8737),
  [27891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [27893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13402),
  [27895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3415),
  [27897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6320),
  [27899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3581),
  [27901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [27903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [27905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17216),
  [27907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8070),
  [27909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6513),
  [27911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6544),
  [27913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10363),
  [27915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8162),
  [27917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [27919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [27921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3582),
  [27923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7031),
  [27925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9787),
  [27927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16531),
  [27929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2632),
  [27931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14053),
  [27933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6514),
  [27935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [27937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12119),
  [27939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8099),
  [27941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4184),
  [27943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [27945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18025),
  [27947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12123),
  [27949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17242),
  [27951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6321),
  [27953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14447),
  [27955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5897),
  [27957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [27959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13425),
  [27961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6864),
  [27963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [27965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [27967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17314),
  [27969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [27971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [27973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [27975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5658),
  [27977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [27979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2910),
  [27981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [27983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3417),
  [27985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [27987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [27989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16775),
  [27991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7088),
  [27993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10192),
  [27995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [27997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12130),
  [27999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [28001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [28003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [28005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [28007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12134),
  [28009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17343),
  [28011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [28013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [28015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6636),
  [28017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13020),
  [28019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [28021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13432),
  [28023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5898),
  [28025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10441),
  [28027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14061),
  [28029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2914),
  [28031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [28033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17396),
  [28035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14879),
  [28037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [28039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5899),
  [28041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7916),
  [28043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4769),
  [28045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2916),
  [28047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2918),
  [28049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10398),
  [28051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17028),
  [28053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5753),
  [28055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [28057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [28059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12141),
  [28061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [28063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [28065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5450),
  [28067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9437),
  [28069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [28071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12145),
  [28073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17433),
  [28075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7992),
  [28077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8009),
  [28079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5569),
  [28081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13450),
  [28083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6403),
  [28085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [28087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [28089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17489),
  [28091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16726),
  [28093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [28095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9157),
  [28097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7024),
  [28099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5048),
  [28101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [28103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [28105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [28107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15947),
  [28109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [28111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9834),
  [28113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10206),
  [28115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5458),
  [28117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12151),
  [28119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [28121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7089),
  [28123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5290),
  [28125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [28127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6705),
  [28129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12155),
  [28131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17534),
  [28133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7446),
  [28135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [28137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7785),
  [28139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [28141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5123),
  [28143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13477),
  [28145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5035),
  [28147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [28149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [28151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [28153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17584),
  [28155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6515),
  [28157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3841),
  [28159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [28161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10505),
  [28163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [28165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2962),
  [28167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [28169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10317),
  [28171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7744),
  [28173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10322),
  [28175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16021),
  [28177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14926),
  [28179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12367),
  [28181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [28183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [28185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12163),
  [28187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3279),
  [28189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5295),
  [28191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5297),
  [28193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8377),
  [28195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12167),
  [28197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17631),
  [28199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3842),
  [28201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6404),
  [28203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6164),
  [28205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11353),
  [28207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11355),
  [28209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13486),
  [28211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6165),
  [28213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [28215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7805),
  [28217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2742),
  [28219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [28221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17678),
  [28223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [28225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10500),
  [28227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [28229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [28231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [28233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [28235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [28237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10510),
  [28239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [28241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [28243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16104),
  [28245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [28247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7333),
  [28249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12373),
  [28251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18185),
  [28253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12173),
  [28255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6715),
  [28257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11433),
  [28259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12177),
  [28261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17718),
  [28263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17994),
  [28265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6166),
  [28267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [28269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5075),
  [28271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6718),
  [28273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13495),
  [28275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5492),
  [28277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3257),
  [28279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [28281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [28283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [28285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17769),
  [28287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18301),
  [28289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6628),
  [28291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [28293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10392),
  [28295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [28297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [28299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [28301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5761),
  [28303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9247),
  [28305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16172),
  [28307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5817),
  [28309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8450),
  [28311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [28313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7658),
  [28315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12183),
  [28317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [28319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7787),
  [28321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [28323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6870),
  [28325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12187),
  [28327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17825),
  [28329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [28331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13926),
  [28333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [28335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7782),
  [28337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10367),
  [28339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7549),
  [28341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [28343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [28345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17899),
  [28347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14832),
  [28349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6231),
  [28351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6232),
  [28353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [28355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [28357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2756),
  [28359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [28361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6729),
  [28363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [28365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16268),
  [28367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17191),
  [28369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6629),
  [28371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6730),
  [28373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12194),
  [28375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6096),
  [28377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [28379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10368),
  [28381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7683),
  [28383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12198),
  [28385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17954),
  [28387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [28389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7726),
  [28391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16851),
  [28393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6516),
  [28395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8388),
  [28397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6412),
  [28399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [28401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [28403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17991),
  [28405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [28407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3540),
  [28409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2763),
  [28411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [28413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16330),
  [28415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16365),
  [28417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10483),
  [28419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12204),
  [28421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7940),
  [28423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12208),
  [28425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18006),
  [28427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6234),
  [28429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5331),
  [28431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [28433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6235),
  [28435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [28437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6236),
  [28439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [28441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [28443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18049),
  [28445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10674),
  [28447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [28449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [28451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [28453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3281),
  [28455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5744),
  [28457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [28459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12214),
  [28461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4193),
  [28463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12218),
  [28465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18081),
  [28467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [28469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [28471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [28473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6112),
  [28475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [28477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5545),
  [28479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8484),
  [28481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4181),
  [28483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18096),
  [28485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7728),
  [28487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13548),
  [28489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13544),
  [28491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7729),
  [28493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7458),
  [28495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4182),
  [28497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5205),
  [28499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14199),
  [28501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18107),
  [28503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6113),
  [28505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [28507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7567),
  [28509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [28511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14201),
  [28513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10191),
  [28515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18117),
  [28517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7568),
  [28519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [28521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [28523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9869),
  [28525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7678),
  [28527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [28529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18129),
  [28531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16263),
  [28533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [28535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9236),
  [28537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7680),
  [28539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [28541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7681),
  [28543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [28545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18134),
  [28547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10453),
  [28549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3759),
  [28551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2945),
  [28553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18275),
  [28555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7682),
  [28557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8841),
  [28559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5581),
  [28561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18141),
  [28563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7573),
  [28565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14009),
  [28567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7766),
  [28569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [28571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10528),
  [28573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10532),
  [28575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18153),
  [28577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [28579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9609),
  [28581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [28583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7854),
  [28585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10514),
  [28587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18166),
  [28589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [28591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2636),
  [28593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [28595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [28597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [28599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7684),
  [28601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16975),
  [28603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18180),
  [28605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10432),
  [28607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6102),
  [28609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14603),
  [28611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6063),
  [28613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [28615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5050),
  [28617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18200),
  [28619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [28621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [28623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [28625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5052),
  [28627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [28629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18207),
  [28631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12397),
  [28633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6104),
  [28635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9746),
  [28637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [28639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10572),
  [28641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7385),
  [28643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18226),
  [28645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9023),
  [28647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9817),
  [28649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12401),
  [28651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3862),
  [28653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18324),
  [28655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4562),
  [28657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [28659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3864),
  [28661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6117),
  [28663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10388),
  [28665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10407),
  [28667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10452),
  [28669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [28671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [28673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [28675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9818),
  [28677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [28679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14979),
  [28681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [28683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6118),
  [28685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [28687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [28689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [28691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7140),
  [28693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [28695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3869),
  [28697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4381),
  [28699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9667),
  [28701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4393),
  [28703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4413),
  [28705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [28707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7908),
  [28709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [28711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16518),
  [28713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [28715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7334),
  [28717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7687),
  [28719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8200),
  [28721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5732),
  [28723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3871),
  [28725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4202),
  [28727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9611),
  [28729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7919),
  [28731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [28733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7922),
  [28735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [28737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7565),
  [28739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10455),
  [28741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10464),
  [28743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10465),
  [28745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13572),
  [28747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5551),
  [28749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7954),
  [28751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8405),
  [28753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4950),
  [28755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7962),
  [28757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14124),
  [28759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14163),
  [28761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7190),
  [28763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8064),
  [28765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4558),
  [28767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4911),
  [28769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [28771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5031),
  [28773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [28775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4523),
  [28777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14005),
  [28779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10348),
  [28781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7939),
  [28783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9901),
  [28785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11576),
  [28787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11631),
  [28789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11715),
  [28791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10130),
  [28793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4923),
  [28795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5332),
  [28797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5547),
  [28799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6605),
  [28801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [28803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [28805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [28807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10225),
  [28809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14000),
  [28811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8188),
  [28813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [28815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14899),
  [28817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [28819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4062),
  [28821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [28823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [28825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12630),
  [28827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [28829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13399),
  [28831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4979),
  [28833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [28835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7200),
  [28837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18336),
  [28839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [28841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [28843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [28845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7201),
  [28847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [28849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5910),
  [28851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7033),
  [28853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7203),
  [28855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [28857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [28859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3452),
  [28861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18124),
  [28863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8271),
  [28865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [28867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8210),
  [28869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8410),
  [28871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [28873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7466),
  [28875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12465),
  [28877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5249),
  [28879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7983),
  [28881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17152),
  [28883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13406),
  [28885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13813),
  [28887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10761),
  [28889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4365),
  [28891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6434),
  [28893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6435),
  [28895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18363),
  [28897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [28899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18366),
  [28901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8187),
  [28903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11180),
  [28905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18372),
  [28907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11181),
  [28909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11182),
  [28911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6545),
  [28913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8211),
  [28915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [28917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6420),
  [28919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8406),
  [28921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10127),
  [28923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6422),
  [28925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7909),
  [28927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5770),
  [28929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5776),
  [28931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [28933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8109),
  [28935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13529),
  [28937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4976),
  [28939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7035),
  [28941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13407),
  [28943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4064),
  [28945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [28947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11675),
  [28949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6131),
  [28951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4579),
  [28953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21326),
  [28955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21327),
  [28957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21328),
  [28959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7246),
  [28961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [28963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6132),
  [28965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6442),
  [28967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14016),
  [28969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14019),
  [28971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6993),
  [28973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6994),
  [28975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6996),
  [28977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14001),
  [28979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7480),
  [28981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [28983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7694),
  [28985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10351),
  [28987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10353),
  [28989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [28991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [28993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13409),
  [28995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7695),
  [28997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7697),
  [28999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8110),
  [29001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6121),
  [29003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8128),
  [29005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16098),
  [29007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [29009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14859),
  [29011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6123),
  [29013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10375),
  [29015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [29017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10762),
  [29019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13410),
  [29021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [29023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10169),
  [29025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5851),
  [29027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13411),
  [29029] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [29031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [29033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10533),
  [29035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [29037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5785),
  [29039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10184),
  [29041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [29043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [29045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4707),
  [29047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7494),
  [29049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [29051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7966),
  [29053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [29055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [29057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6136),
  [29059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6032),
  [29061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6014),
  [29063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5268),
  [29065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6023),
  [29067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11798),
  [29069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [29071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8052),
  [29073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [29075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4780),
  [29077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [29079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3352),
  [29081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10227),
  [29083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10233),
  [29085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10234),
  [29087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7987),
  [29089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10238),
  [29091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10675),
  [29093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10247),
  [29095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14604),
  [29097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10449),
  [29099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13983),
  [29101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11802),
  [29103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6444),
  [29105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17795),
  [29107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5939),
  [29109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7733),
  [29111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5926),
  [29113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10305),
  [29115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13987),
  [29117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10272),
  [29119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17279),
  [29121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3353),
  [29123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10277),
  [29125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3256),
  [29127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8422),
  [29129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8147),
  [29131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7012),
  [29133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5147),
  [29135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7013),
  [29137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7014),
  [29139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5352),
  [29141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10355),
  [29143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5148),
  [29145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9170),
  [29147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5150),
  [29149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14883),
  [29151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8301),
  [29153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17292),
  [29155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8214),
  [29157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8303),
  [29159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17299),
  [29161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [29163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5869),
  [29165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12231),
  [29167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5883),
  [29169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [29171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11204),
  [29173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10493),
  [29175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8424),
  [29177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [29179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6137),
  [29181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9046),
  [29183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9177),
  [29185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8011),
  [29187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6546),
  [29189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20482),
  [29191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20484),
  [29193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20486),
  [29195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [29197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [29199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9185),
  [29201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5454),
  [29203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5356),
  [29205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9180),
  [29207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9182),
  [29209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5455),
  [29211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16494),
  [29213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13540),
  [29215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [29217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [29219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5821),
  [29221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6547),
  [29223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [29225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14670),
  [29227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9844),
  [29229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [29231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9171),
  [29233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7280),
  [29235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6801),
  [29237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9186),
  [29239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [29241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [29243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5529),
  [29245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10376),
  [29247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [29249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10047),
  [29251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10488),
  [29253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4604),
  [29255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13513),
  [29257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [29259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5531),
  [29261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4468),
  [29263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3148),
  [29265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [29267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5416),
  [29269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9140),
  [29271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14197),
  [29273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5431),
  [29275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4235),
  [29277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14200),
  [29279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [29281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [29283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5604),
  [29285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17348),
  [29287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10400),
  [29289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10518),
  [29291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [29293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [29295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5292),
  [29297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6139),
  [29299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6140),
  [29301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9149),
  [29303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8238),
  [29305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__quoted_string, 2, 0, 0),
  [29307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6141),
  [29309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3150),
  [29311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17360),
  [29313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8282),
  [29315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8223),
  [29317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6752),
  [29319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17367),
  [29321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9930),
  [29323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19473),
  [29325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [29327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6519),
  [29329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8000),
  [29331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8003),
  [29333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13985),
  [29335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [29337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7008),
  [29339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9986),
  [29341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [29343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [29345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [29347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7876),
  [29349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18828),
  [29351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18829),
  [29353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18830),
  [29355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4136),
  [29357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13964),
  [29359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [29361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2939),
  [29363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17222),
  [29365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17317),
  [29367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13463),
  [29369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20166),
  [29371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5884),
  [29373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [29375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [29377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3589),
  [29379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 1, 0, 0),
  [29381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14685),
  [29383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3590),
  [29385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12430),
  [29387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18436),
  [29389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [29391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12780),
  [29393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2621),
  [29395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12431),
  [29397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14203),
  [29399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8408),
  [29401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12432),
  [29403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6767),
  [29405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18306),
  [29407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [29409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10597),
  [29411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14688),
  [29413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8012),
  [29415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6770),
  [29417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14479),
  [29419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6520),
  [29421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4988),
  [29423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5010),
  [29425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [29427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [29429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12956),
  [29431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [29433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [29435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6521),
  [29437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7825),
  [29439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7749),
  [29441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7722),
  [29443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [29445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2952),
  [29447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5304),
  [29449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12235),
  [29451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2960),
  [29453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6247),
  [29455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6248),
  [29457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17413),
  [29459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8231),
  [29461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6249),
  [29463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17417),
  [29465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [29467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6450),
  [29469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6451),
  [29471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6782),
  [29473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8066),
  [29475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19338),
  [29477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19339),
  [29479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19340),
  [29481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6783),
  [29483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [29485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7069),
  [29487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6452),
  [29489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16208),
  [29491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [29493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4236),
  [29495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6454),
  [29497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18404),
  [29499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6455),
  [29501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6456),
  [29503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [29505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7762),
  [29507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13744),
  [29509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8569),
  [29511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [29513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17448),
  [29515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8237),
  [29517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6253),
  [29519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17451),
  [29521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10064),
  [29523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19740),
  [29525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19742),
  [29527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19744),
  [29529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7740),
  [29531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7479),
  [29533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10065),
  [29535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10078),
  [29537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6254),
  [29539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6255),
  [29541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8019),
  [29543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9099),
  [29545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [29547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6461),
  [29549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9097),
  [29551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6462),
  [29553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7011),
  [29555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17482),
  [29557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8241),
  [29559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6463),
  [29561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17486),
  [29563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [29565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19998),
  [29567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20001),
  [29569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20004),
  [29571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6465),
  [29573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [29575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10781),
  [29577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [29579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7754),
  [29581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6466),
  [29583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [29585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11811),
  [29587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10511),
  [29589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6467),
  [29591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [29593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8247),
  [29595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9146),
  [29597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17512),
  [29599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13525),
  [29601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20258),
  [29603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20259),
  [29605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20260),
  [29607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [29609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [29611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [29613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [29615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3911),
  [29617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [29619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [29621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9154),
  [29623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5908),
  [29625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6143),
  [29627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6071),
  [29629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8251),
  [29631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6144),
  [29633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17536),
  [29635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [29637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20594),
  [29639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20602),
  [29641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20609),
  [29643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [29645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [29647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [29649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [29651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [29653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [29655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14165),
  [29657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9782),
  [29659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9828),
  [29661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7943),
  [29663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9892),
  [29665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8254),
  [29667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [29669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17560),
  [29671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [29673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21029),
  [29675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21033),
  [29677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21035),
  [29679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4972),
  [29681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4918),
  [29683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [29685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4982),
  [29687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [29689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11815),
  [29691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13958),
  [29693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8260),
  [29695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17785),
  [29697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17586),
  [29699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13963),
  [29701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21372),
  [29703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21373),
  [29705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21375),
  [29707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13953),
  [29709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10562),
  [29711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13369),
  [29713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2264),
  [29715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13371),
  [29717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13391),
  [29719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8268),
  [29721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10402),
  [29723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17608),
  [29725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [29727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18484),
  [29729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18485),
  [29731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18486),
  [29733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3248),
  [29735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2016),
  [29737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [29739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4657),
  [29741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10625),
  [29743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6473),
  [29745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8276),
  [29747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10626),
  [29749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17633),
  [29751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6474),
  [29753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18551),
  [29755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18552),
  [29757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18553),
  [29759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6475),
  [29761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [29763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7131),
  [29765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [29767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10341),
  [29769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [29771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9914),
  [29773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6146),
  [29775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8281),
  [29777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5277),
  [29779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17648),
  [29781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6147),
  [29783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18606),
  [29785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18607),
  [29787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18608),
  [29789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6148),
  [29791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10406),
  [29793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [29795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [29797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10408),
  [29799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3447),
  [29801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12611),
  [29803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [29805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8285),
  [29807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12614),
  [29809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17660),
  [29811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10037),
  [29813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18661),
  [29815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18662),
  [29817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18663),
  [29819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10053),
  [29821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9141),
  [29823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [29825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [29827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10061),
  [29829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [29831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [29833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5788),
  [29835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5789),
  [29837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8292),
  [29839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17680),
  [29841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5794),
  [29843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18716),
  [29845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18717),
  [29847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18718),
  [29849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10393),
  [29851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5384),
  [29853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [29855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5385),
  [29857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5386),
  [29859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [29861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8298),
  [29863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [29865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17695),
  [29867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [29869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18770),
  [29871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18771),
  [29873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18772),
  [29875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4396),
  [29877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [29879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12969),
  [29881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [29883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5469),
  [29885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [29887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [29889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8302),
  [29891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7965),
  [29893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17713),
  [29895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [29897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18824),
  [29899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18825),
  [29901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18826),
  [29903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9421),
  [29905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8307),
  [29907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9423),
  [29909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9424),
  [29911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10858),
  [29913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8051),
  [29915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5279),
  [29917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9432),
  [29919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9434),
  [29921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8306),
  [29923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9439),
  [29925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17733),
  [29927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [29929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18878),
  [29931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18879),
  [29933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18880),
  [29935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13620),
  [29937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7194),
  [29939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13623),
  [29941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13625),
  [29943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14621),
  [29945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4272),
  [29947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [29949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8310),
  [29951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13203),
  [29953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17748),
  [29955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10765),
  [29957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18932),
  [29959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18933),
  [29961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18934),
  [29963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9173),
  [29965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14811),
  [29967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [29969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7580),
  [29971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8316),
  [29973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [29975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17761),
  [29977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10581),
  [29979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18986),
  [29981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18987),
  [29983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18988),
  [29985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10584),
  [29987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4401),
  [29989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9083),
  [29991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [29993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [29995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13879),
  [29997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8396),
  [29999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5406),
  [30001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8323),
  [30003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17777),
  [30005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13545),
  [30007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19039),
  [30009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19040),
  [30011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19041),
  [30013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6097),
  [30015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [30017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20423),
  [30019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [30021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14110),
  [30023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6809),
  [30025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10412),
  [30027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [30029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13380),
  [30031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12896),
  [30033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17791),
  [30035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4480),
  [30037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19081),
  [30039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19082),
  [30041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19083),
  [30043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6015),
  [30045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__infix_operator, 1, 0, 0),
  [30047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7437),
  [30049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13427),
  [30051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5900),
  [30053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14111),
  [30055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10250),
  [30057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17802),
  [30059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19121),
  [30061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19122),
  [30063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19123),
  [30065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [30067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5823),
  [30069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [30071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7582),
  [30073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5865),
  [30075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9733),
  [30077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7583),
  [30079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6414),
  [30081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17812),
  [30083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3291),
  [30085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19161),
  [30087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19162),
  [30089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19163),
  [30091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [30093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [30095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [30097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5587),
  [30099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [30101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [30103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7191),
  [30105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17822),
  [30107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5591),
  [30109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19201),
  [30111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19202),
  [30113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19203),
  [30115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5588),
  [30117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [30119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12970),
  [30121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18280),
  [30123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5999),
  [30125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14098),
  [30127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [30129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10251),
  [30131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17837),
  [30133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13413),
  [30135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19241),
  [30137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19242),
  [30139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19243),
  [30141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9678),
  [30143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [30145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14118),
  [30147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [30149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6415),
  [30151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13031),
  [30153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [30155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8112),
  [30157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17849),
  [30159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19281),
  [30161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19282),
  [30163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19283),
  [30165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12819),
  [30167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [30169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [30171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11157),
  [30173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5723),
  [30175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [30177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21419),
  [30179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4973),
  [30181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [30183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6769),
  [30185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17861),
  [30187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5049),
  [30189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19321),
  [30191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19322),
  [30193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19323),
  [30195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7673),
  [30197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6776),
  [30199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6780),
  [30201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9722),
  [30203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7517),
  [30205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5126),
  [30207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10414),
  [30209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10417),
  [30211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17876),
  [30213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5668),
  [30215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19361),
  [30217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19362),
  [30219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19363),
  [30221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7674),
  [30223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9203),
  [30225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5156),
  [30227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8339),
  [30229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [30231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5127),
  [30233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5128),
  [30235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [30237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5159),
  [30239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5161),
  [30241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17887),
  [30243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [30245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19401),
  [30247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19402),
  [30249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19403),
  [30251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17659),
  [30253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5812),
  [30255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12988),
  [30257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [30259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7396),
  [30261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6821),
  [30263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7492),
  [30265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7493),
  [30267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8849),
  [30269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7244),
  [30271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17901),
  [30273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5443),
  [30275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19441),
  [30277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19442),
  [30279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19443),
  [30281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5130),
  [30283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7219),
  [30285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4777),
  [30287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5904),
  [30289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16680),
  [30291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10460),
  [30293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10461),
  [30295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7220),
  [30297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [30299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17913),
  [30301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [30303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19481),
  [30305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19482),
  [30307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19483),
  [30309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4067),
  [30311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17309),
  [30313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [30315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4109),
  [30317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6823),
  [30319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11908),
  [30321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [30323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16203),
  [30325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17928),
  [30327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [30329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19520),
  [30331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19521),
  [30333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19522),
  [30335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [30337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10434),
  [30339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8065),
  [30341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [30343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6840),
  [30345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6841),
  [30347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6847),
  [30349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5664),
  [30351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10601),
  [30353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17940),
  [30355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19559),
  [30357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19560),
  [30359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19561),
  [30361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [30363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10421),
  [30365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9194),
  [30367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [30369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6781),
  [30371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7769),
  [30373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [30375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11585),
  [30377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17950),
  [30379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [30381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19597),
  [30383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19598),
  [30385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19599),
  [30387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10444),
  [30389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [30391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9798),
  [30393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11825),
  [30395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7342),
  [30397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5007),
  [30399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10436),
  [30401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [30403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10751),
  [30405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5132),
  [30407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17961),
  [30409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10425),
  [30411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19635),
  [30413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19636),
  [30415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19637),
  [30417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7676),
  [30419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8259),
  [30421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5757),
  [30423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9380),
  [30425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [30427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10134),
  [30429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10657),
  [30431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7799),
  [30433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14185),
  [30435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17970),
  [30437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5011),
  [30439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19673),
  [30441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19674),
  [30443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19675),
  [30445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9820),
  [30447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7802),
  [30449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13706),
  [30451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6269),
  [30453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7398),
  [30455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6270),
  [30457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6271),
  [30459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7348),
  [30461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11829),
  [30463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17612),
  [30465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19710),
  [30467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19711),
  [30469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19712),
  [30471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6833),
  [30473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [30475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [30477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6786),
  [30479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5597),
  [30481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [30483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [30485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19747),
  [30487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19748),
  [30489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19749),
  [30491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6787),
  [30493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6066),
  [30495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5496),
  [30497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5826),
  [30499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5662),
  [30501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [30503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4768),
  [30505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6035),
  [30507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10394),
  [30509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19784),
  [30511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19785),
  [30513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19786),
  [30515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [30517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9200),
  [30519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6272),
  [30521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [30523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10766),
  [30525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6273),
  [30527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9683),
  [30529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3783),
  [30531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7242),
  [30533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8098),
  [30535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [30537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19820),
  [30539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19821),
  [30541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19822),
  [30543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [30545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6274),
  [30547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20869),
  [30549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4200),
  [30551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13546),
  [30553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [30555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [30557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5310),
  [30559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19844),
  [30561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19845),
  [30563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19846),
  [30565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7243),
  [30567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17018),
  [30569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4111),
  [30571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_payload, 3, 0, 0),
  [30573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6416),
  [30575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7789),
  [30577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7827),
  [30579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7102),
  [30581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [30583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19866),
  [30585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19867),
  [30587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19868),
  [30589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7178),
  [30591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13465),
  [30593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19878),
  [30595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19879),
  [30597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19880),
  [30599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4890),
  [30601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4892),
  [30603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19890),
  [30605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19891),
  [30607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19892),
  [30609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5115),
  [30611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4893),
  [30613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19900),
  [30615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19901),
  [30617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19902),
  [30619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [30621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19910),
  [30623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19911),
  [30625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19912),
  [30627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [30629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3819),
  [30631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19920),
  [30633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19921),
  [30635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19922),
  [30637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4921),
  [30639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6974),
  [30641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19930),
  [30643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19931),
  [30645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19932),
  [30647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4951),
  [30649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4560),
  [30651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19940),
  [30653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19941),
  [30655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19942),
  [30657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14050),
  [30659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19950),
  [30661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19951),
  [30663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19952),
  [30665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14051),
  [30667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19960),
  [30669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19961),
  [30671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19962),
  [30673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5122),
  [30675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7225),
  [30677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19970),
  [30679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19971),
  [30681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19972),
  [30683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [30685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5679),
  [30687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19980),
  [30689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19981),
  [30691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19982),
  [30693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3427),
  [30695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [30697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19990),
  [30699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19991),
  [30701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19992),
  [30703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5080),
  [30705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5056),
  [30707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10166),
  [30709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4243),
  [30711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [30713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7806),
  [30715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5121),
  [30717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9759),
  [30719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4834),
  [30721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [30723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [30725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5854),
  [30727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9190),
  [30729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5500),
  [30731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [30733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [30735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4894),
  [30737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6976),
  [30739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5179),
  [30741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5181),
  [30743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4810),
  [30745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5183),
  [30747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6012),
  [30749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5089),
  [30751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [30753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3701),
  [30755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11947),
  [30757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [30759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2810),
  [30761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17346),
  [30763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20103),
  [30765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10462),
  [30767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16697),
  [30769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14008),
  [30771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4212),
  [30773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [30775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8054),
  [30777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [30779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [30781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9469),
  [30783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [30785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [30787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [30789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [30791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [30793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [30795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [30797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20196),
  [30799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [30801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7775),
  [30803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7743),
  [30805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20209),
  [30807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [30809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20213),
  [30811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [30813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8262),
  [30815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13778),
  [30817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [30819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [30821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13910),
  [30823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10466),
  [30825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16754),
  [30827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [30829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7252),
  [30831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [30833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [30835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [30837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6024),
  [30839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [30841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7712),
  [30843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [30845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4669),
  [30847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16782),
  [30849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7520),
  [30851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6301),
  [30853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8352),
  [30855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16065),
  [30857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [30859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [30861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2293),
  [30863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16806),
  [30865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4376),
  [30867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4060),
  [30869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [30871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2238),
  [30873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16819),
  [30875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16826),
  [30877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16831),
  [30879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16837),
  [30881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16847),
  [30883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16853),
  [30885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16860),
  [30887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16865),
  [30889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16869),
  [30891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16876),
  [30893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16882),
  [30895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16889),
  [30897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16895),
  [30899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16902),
  [30901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16908),
  [30903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16915),
  [30905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16920),
  [30907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16928),
  [30909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16935),
  [30911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16941),
  [30913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16950),
  [30915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16957),
  [30917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16965),
  [30919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16972),
  [30921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16977),
  [30923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16982),
  [30925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16988),
  [30927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16996),
  [30929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17002),
  [30931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17007),
  [30933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17011),
  [30935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17019),
  [30937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17025),
  [30939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17030),
  [30941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17036),
  [30943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17044),
  [30945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17051),
  [30947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17056),
  [30949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17060),
  [30951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17062),
  [30953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17064),
  [30955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17066),
  [30957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17068),
  [30959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17070),
  [30961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17072),
  [30963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17074),
  [30965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17076),
  [30967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17078),
  [30969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17080),
  [30971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17082),
  [30973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17084),
  [30975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18764),
  [30977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7351),
  [30979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10797),
  [30981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4162),
  [30983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [30985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7524),
  [30987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [30989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [30991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10438),
  [30993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11961),
  [30995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17535),
  [30997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [30999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [31001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6940),
  [31003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7957),
  [31005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8274),
  [31007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8275),
  [31009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7809),
  [31011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [31013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [31015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [31017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [31019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [31021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [31023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [31025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10443),
  [31027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11472),
  [31029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [31031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11841),
  [31033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20411),
  [31035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8176),
  [31037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4037),
  [31039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4733),
  [31041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [31043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5676),
  [31045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [31047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4676),
  [31049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [31051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3432),
  [31053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5867),
  [31055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9211),
  [31057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [31059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [31061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3433),
  [31063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16835),
  [31065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11845),
  [31067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7553),
  [31069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [31071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17563),
  [31073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11357),
  [31075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7484),
  [31077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4169),
  [31079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4485),
  [31081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7781),
  [31083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [31085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [31087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10721),
  [31089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8280),
  [31091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [31093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14188),
  [31095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [31097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [31099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7525),
  [31101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [31103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17942),
  [31105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10770),
  [31107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6345),
  [31109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4444),
  [31111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [31113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5632),
  [31115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7557),
  [31117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7790),
  [31119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [31121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [31123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7792),
  [31125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [31127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10795),
  [31129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [31131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [31133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3800),
  [31135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9693),
  [31137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [31139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9694),
  [31141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10420),
  [31143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [31145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4486),
  [31147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10423),
  [31149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10369),
  [31151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [31153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 4, 0, 0),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token__left_quoted_string_delimiter = 1,
  ts_external_token__right_quoted_string_delimiter = 2,
  ts_external_token_DQUOTE = 3,
  ts_external_token_line_number_directive = 4,
  ts_external_token__null = 5,
  ts_external_token__error_sentinel = 6,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token__left_quoted_string_delimiter] = sym__left_quoted_string_delimiter,
  [ts_external_token__right_quoted_string_delimiter] = sym__right_quoted_string_delimiter,
  [ts_external_token_DQUOTE] = anon_sym_DQUOTE,
  [ts_external_token_line_number_directive] = sym_line_number_directive,
  [ts_external_token__null] = sym__null,
  [ts_external_token__error_sentinel] = sym__error_sentinel,
};

static const bool ts_external_scanner_states[10][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token__left_quoted_string_delimiter] = true,
    [ts_external_token__right_quoted_string_delimiter] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
    [ts_external_token__error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token__left_quoted_string_delimiter] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_DQUOTE] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token__right_quoted_string_delimiter] = true,
    [ts_external_token_line_number_directive] = true,
    [ts_external_token__null] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token__left_quoted_string_delimiter] = true,
    [ts_external_token_line_number_directive] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token__right_quoted_string_delimiter] = true,
    [ts_external_token_line_number_directive] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_ocaml_interface_external_scanner_create(void);
void tree_sitter_ocaml_interface_external_scanner_destroy(void *);
bool tree_sitter_ocaml_interface_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_ocaml_interface_external_scanner_serialize(void *, char *);
void tree_sitter_ocaml_interface_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_ocaml_interface(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym__lowercase_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_ocaml_interface_external_scanner_create,
      tree_sitter_ocaml_interface_external_scanner_destroy,
      tree_sitter_ocaml_interface_external_scanner_scan,
      tree_sitter_ocaml_interface_external_scanner_serialize,
      tree_sitter_ocaml_interface_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
